diff --git a/books/bookvol10.2.pamphlet b/books/bookvol10.2.pamphlet
index fa1363d..13cdeda 100644
--- a/books/bookvol10.2.pamphlet
+++ b/books/bookvol10.2.pamphlet
@@ -8697,6 +8697,63 @@ digraph pic {
 
 \end{chunk}
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\pagehead{LeftOreRing}{LORER}
+\pagepic{ps/v102leftorering.eps}{LORER}{1.00}
+\begin{chunk}{LeftOreRing.help}
+====================================================================
+LeftOreRing 
+====================================================================
+
+This is the category of left ore rings, that is, the commutative
+rings without zero divisors where we can compute least left
+common multiples.
+
+See [Delenclos 06], [Bronstein 96a]
+
+See Also:
+o )show LeftOreRing
+
+\end{chunk}
+
+\begin{chunk}{category LORER LeftOreRing}
+)abbrev category LORER LeftOreRing
+++ Description:
+++ This is the category of left ore rings, that is noncommutative
+++ rings without zero divisors where we can compute the least left
+++ common multiple.
+LeftOreRing : Category == EntireRing with
+   lcmCoef : (%, %) -> Record(llcm_res : %, coeff1 : %, coeff2 : %)
+     ++ lcmCoef(c1, c2) computes (llcm_res, coeff1, coeff2) such that
+     ++ llcm_res is least left common multiple of c1 and c2
+     ++ and llcm_res = coeff1*c1 = coeff2*c2
+
+\end{chunk}
+\begin{chunk}{LORER.dotabb}
+"LORER"
+ [color=lightblue,href="bookvol10.2.pdf#nameddest=LORER"];
+"LORER" -> "BMODULE"
+
+\end{chunk}
+\begin{chunk}{LORER.dotfull}
+"LeftOreRing()"
+ [color=lightblue,href="bookvol10.2.pdf#nameddest=LORER"];
+"LeftOreRing()" -> "EntireRing()"
+
+\end{chunk}
+\begin{chunk}{LORER.dotpic}
+digraph pic {
+ fontsize=10;
+ bgcolor="#ECEA81";
+ node [shape=box, color=white, style=filled];
+
+"LeftOreRing()" [color=lightblue];
+"LeftOreRing()" -> "EntireRing()"
+
+"Category" [color=lightblue];
+}
+
+\end{chunk}
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \pagehead{HomogeneousAggregate}{HOAGG}
 \pagepic{ps/v102homogeneousaggregate.ps}{HOAGG}{1.00}
 
@@ -51573,7 +51630,7 @@ These exports come from \refto{IntegralDomain}():
 ++ into irreducibles. However, if such a \spadfun{factor} operation exist, 
 ++ factorization will be unique up to order and units.
 
-GcdDomain(): Category == IntegralDomain with
+GcdDomain(): Category == Join(IntegralDomain, LeftOreRing) with
     gcd: (%,%) -> %
       ++ gcd(x,y) returns the greatest common divisor of x and y.
       -- gcd(x,y) = gcd(y,x) in the presence of canonicalUnitNormal,
@@ -51593,15 +51650,20 @@ GcdDomain(): Category == IntegralDomain with
       ++ gcdPolynomial(p,q) returns the greatest common divisor (gcd) of 
       ++ univariate polynomials over the domain
   add
+
    lcm(x: %,y: %) ==
      y = 0 => 0
      x = 0 => 0
      LCM : Union(%,"failed") := y exquo gcd(x,y)
      LCM case % =>  x * LCM
      error "bad gcd in lcm computation"
+
    lcm(l:List %) == reduce(lcm,l,1,0)
+
    gcd(l:List %) == reduce(gcd,l,0,1)
+
    SUP ==> SparseUnivariatePolynomial
+
    gcdPolynomial(p1,p2) ==
      zero? p1 => unitCanonical p2
      zero? p2 => unitCanonical p1
@@ -51621,6 +51683,13 @@ GcdDomain(): Category == IntegralDomain with
      zero? e1 => p1
      monomial(1,e1)*p1
 
+   -- See [Delenclos 06], [Bronstein 96a]
+   lcmCoef(c1, c2) ==
+     g := gcd(c1, c2)
+     cc1 := (c2 exquo g)::%
+     cc2 := (c1 exquo g)::%
+     [cc1*c1, cc1, cc2]
+   
 \end{chunk}
 \begin{chunk}{GCDDOM.dotabb}
 "GCDDOM"
@@ -54171,18 +54240,23 @@ EuclideanDomain(): Category == PrincipalIdealDomain with
   add
       x,y,z: %
       l: List %
+
       sizeLess?(x,y) ==
             zero? y => false
             zero? x => true
             euclideanSize(x)<euclideanSize(y)
+
       x quo y == divide(x,y).quotient --divide must be user-supplied
+
       x rem y == divide(x,y).remainder
+
       x exquo y ==
          zero? x => 0
          zero? y => "failed"
          qr:=divide(x,y)
          zero?(qr.remainder) => qr.quotient
          "failed"
+
       gcd(x,y) ==                --Euclidean Algorithm
          x:=unitCanonical x
          y:=unitCanonical y
@@ -54195,12 +54269,14 @@ EuclideanDomain(): Category == PrincipalIdealDomain with
                                  -- b) ensures gcd(x,y)=gcd(y,x)
                                  --    if canonicalUnitNormal
          x
+
       IdealElt ==> Record(coef1:%,coef2:%,generator:%)
+
       unitNormalizeIdealElt(s:IdealElt):IdealElt ==
          (u,c,a):=unitNormal(s.generator)
---         one? a => s
          (a = 1) => s
          [a*s.coef1,a*s.coef2,c]$IdealElt
+
       extendedEuclidean(x,y) ==         --Extended Euclidean Algorithm
          s1:=unitNormalizeIdealElt([1$%,0$%,x]$IdealElt)
          s2:=unitNormalizeIdealElt([0$%,1$%,y]$IdealElt)
@@ -54221,14 +54297,15 @@ EuclideanDomain(): Category == PrincipalIdealDomain with
          s1
 
       TwoCoefs ==> Record(coef1:%,coef2:%)
+
       extendedEuclidean(x,y,z) ==
          zero? z => [0,0]$TwoCoefs
          s:= extendedEuclidean(x,y)
          (w:= z exquo s.generator) case "failed" => "failed"
-         zero? y =>
-            [s.coef1 * w, s.coef2 * w]$TwoCoefs
+         zero? y => [s.coef1 * w, s.coef2 * w]$TwoCoefs
          qr:= divide((s.coef1 * w), y)
          [qr.remainder, s.coef2 * w + qr.quotient * x]$TwoCoefs
+
       principalIdeal l ==
          l = [] => error "empty list passed to principalIdeal"
          rest l = [] =>
@@ -54240,11 +54317,13 @@ EuclideanDomain(): Category == PrincipalIdealDomain with
          v:=principalIdeal rest l
          u:= extendedEuclidean(first l,v.generator)
          [[u.coef1,:[u.coef2*vv for vv in v.coef]],u.generator]
+
       expressIdealMember(l,z) ==
          z = 0 => [0 for v in l]
          pid := principalIdeal l
          (q := z exquo (pid.generator)) case "failed" => "failed"
          [q*v for v in pid.coef]
+
       multiEuclidean(l,z) ==
          n := #l
          zero? n => error "empty list passed to multiEuclidean"
@@ -55883,19 +55962,32 @@ Field(): Category == Join(EuclideanDomain,UniqueFactorizationDomain,
     add
       x,y: %
       n: Integer
+
       UCA ==> Record(unit:%,canonical:%,associate:%)
+
       unitNormal(x) ==
           if zero? x then [1$%,0$%,1$%]$UCA else [x,1$%,inv(x)]$UCA
+
       unitCanonical(x) == if zero? x then x else 1
+
       associates?(x,y) == if zero? x then zero? y else not(zero? y)
+
       inv x ==((u:=recip x) case "failed" => error "not invertible"; u)
+
       x exquo y == (y=0 => "failed"; x / y)
+
       gcd(x,y) == 1
+
       euclideanSize(x) == 0
+
       prime? x == false
+
       squareFree x == x::Factored(%)
+
       factor x == x::Factored(%)
+
       x / y == (zero? y => error "catdef: division by zero"; x * inv(y))
+
       divide(x,y) == [x / y,0]
 
 \end{chunk}
@@ -68385,9 +68477,8 @@ digraph pic {
 )set message auto off
 )clear all
 
---S 1 of 1
+--S 1 of 4
 )show UnivariatePolynomialCategory
---R 
 --R UnivariatePolynomialCategory(R: Ring)  is a category constructor
 --R Abbreviation for UnivariatePolynomialCategory is UPOLYC 
 --R This constructor is exposed in this frame.
@@ -68415,7 +68506,8 @@ digraph pic {
 --R one? : % -> Boolean                   pseudoRemainder : (%,%) -> %
 --R recip : % -> Union(%,"failed")        reductum : % -> %
 --R retract : % -> R                      sample : () -> %
---R zero? : % -> Boolean                  ?~=? : (%,%) -> Boolean
+--R unvectorise : Vector(R) -> %          zero? : % -> Boolean
+--R ?~=? : (%,%) -> Boolean              
 --R ?*? : (Fraction(Integer),%) -> % if R has ALGEBRA(FRAC(INT))
 --R ?*? : (%,Fraction(Integer)) -> % if R has ALGEBRA(FRAC(INT))
 --R ?*? : (NonNegativeInteger,%) -> %
@@ -68499,6 +68591,7 @@ digraph pic {
 --R karatsubaDivide : (%,NonNegativeInteger) -> Record(quotient: %,remainder: %)
 --R lcm : (%,%) -> % if R has GCDDOM
 --R lcm : List(%) -> % if R has GCDDOM
+--R lcmCoef : (%,%) -> Record(llcmres: %,coeff1: %,coeff2: %) if R has GCDDOM
 --R mainVariable : % -> Union(SingletonAsOrderedSet,"failed")
 --R makeSUP : % -> SparseUnivariatePolynomial(R)
 --R mapExponents : ((NonNegativeInteger -> NonNegativeInteger),%) -> %
@@ -68564,9 +68657,31 @@ digraph pic {
 --R unmakeSUP : SparseUnivariatePolynomial(R) -> %
 --R variables : % -> List(SingletonAsOrderedSet)
 --R vectorise : (%,NonNegativeInteger) -> Vector(R)
---R
 --E 1
 
+--S 2 of 4
+t1:UP(x,FRAC(INT)):=3*x^3+4*x^2+5*x+6
+--R
+--R          3     2
+--R   (1)  3x  + 4x  + 5x + 6
+--R                              Type: UnivariatePolynomial(x,Fraction(Integer))
+--E 2
+
+--S 3 of 4
+t2:=vectorise(t1,4)
+--R
+--R   (2)  [6,5,4,3]
+--R                                              Type: Vector(Fraction(Integer))
+--E 3
+
+--S 4 of 4
+t3:UP(x,FRAC(INT)):=unvectorise(t2)
+--R
+--R          3     2
+--R   (3)  3x  + 4x  + 5x + 6
+--R                              Type: UnivariatePolynomial(x,Fraction(Integer))
+--E 4
+
 )spool
 )lisp (bye)
 \end{chunk}
@@ -69101,6 +69216,16 @@ UnivariatePolynomialCategory(R:Ring): Category ==
       ++ vectorise(p, n) returns \spad{[a0,...,a(n-1)]} where
       ++ \spad{p = a0 + a1*x + ... + a(n-1)*x**(n-1)} + higher order terms.
       ++ The degree of polynomial p can be different from \spad{n-1}.
+      ++
+      ++X t1:UP(x,FRAC(INT)):=3*x^3+4*x^2+5*x+6
+      ++X t2:=vectorise(t1,4)
+    unvectorise : Vector R -> %
+      ++ unvectorise(v) returns the polynomial which has for coefficients the
+      ++ entries of v in the increasing order.
+      ++
+      ++X t1:UP(x,FRAC(INT)):=3*x^3+4*x^2+5*x+6
+      ++X t2:=vectorise(t1,4)
+      ++X t3:UP(x,FRAC(INT)):=unvectorise(t2)
     makeSUP: % -> SparseUnivariatePolynomial R
       ++ makeSUP(p) converts the polynomial p to be of type
       ++ SparseUnivariatePolynomial over the same coefficients.
@@ -69289,6 +69414,12 @@ UnivariatePolynomialCategory(R:Ring): Category ==
         qsetelt_!(v, i, coefficient(p, (i - m)::NonNegativeInteger))
       v
 
+    unvectorise(v : Vector R) : % ==
+        p : % := 0
+        for i in 1..#v repeat
+            p := p + monomial(v(i), (i-1)::NonNegativeInteger)
+        p
+
     retract(p:%):R ==
       zero? p => 0
       zero? degree p => leadingCoefficient p
@@ -82209,42 +82340,40 @@ Note that this code is not included in the generated catdef.spad file.
 
 \begin{chunk}{GCDDOM.lsp BOOTSTRAP}
 
-(|/VERSIONCHECK| 2) 
+(/VERSIONCHECK 2) 
 
 (SETQ |GcdDomain;AL| (QUOTE NIL)) 
 
 (DEFUN |GcdDomain| NIL 
-  (LET (#:G83171) 
-    (COND 
-      (|GcdDomain;AL|) 
-      (T (SETQ |GcdDomain;AL| (|GcdDomain;|)))))) 
+ (LET (#:G22291)
+  (COND (|GcdDomain;AL|) (T (SETQ |GcdDomain;AL| (|GcdDomain;|)))))) 
 
 (DEFUN |GcdDomain;| NIL 
-  (PROG (#1=#:G83169) 
-    (RETURN 
-      (PROG1 
-        (LETT #1# 
-          (|Join| 
-            (|IntegralDomain|)
-            (|mkCategory| 
-              (QUOTE |domain|)
-              (QUOTE (
-                ((|gcd| (|$| |$| |$|)) T)
-                ((|gcd| (|$| (|List| |$|))) T)
-                ((|lcm| (|$| |$| |$|)) T)
-                ((|lcm| (|$| (|List| |$|))) T)
-                ((|gcdPolynomial| 
-                  ((|SparseUnivariatePolynomial| |$|)
-                   (|SparseUnivariatePolynomial| |$|)
-                   (|SparseUnivariatePolynomial| |$|)))
-                  T)))
-              NIL 
-              (QUOTE ((|SparseUnivariatePolynomial| |$|) (|List| |$|)))
-              NIL)) 
-            |GcdDomain|)
-        (SETELT #1# 0 (QUOTE (|GcdDomain|))))))) 
+ (PROG (#0=#:G22289)
+  (RETURN
+   (PROG1 
+    (LETT #0#
+     (|Join|
+      (|IntegralDomain|)
+      (|LeftOreRing|)
+      (|mkCategory|
+       (QUOTE |domain|)
+       (QUOTE (
+        ((|gcd| ($ $ $)) T)
+        ((|gcd| ($ (|List| $))) T)
+        ((|lcm| ($ $ $)) T)
+        ((|lcm| ($ (|List| $))) T)
+        ((|gcdPolynomial|
+         ((|SparseUnivariatePolynomial| $)
+          (|SparseUnivariatePolynomial| $)
+          (|SparseUnivariatePolynomial| $))) T)))
+       NIL
+       (QUOTE ((|SparseUnivariatePolynomial| $) (|List| $)))
+       NIL))
+     |GcdDomain|)
+    (SETELT #0# 0 (QUOTE (|GcdDomain|))))))) 
 
-(setf (get (QUOTE |GcdDomain|) (QUOTE NILADIC)) T) 
+(SETF (GET (QUOTE |GcdDomain|) (QUOTE NILADIC)) T) 
 
 \end{chunk}
 \section{GCDDOM-.lsp BOOTSTRAP}
@@ -82260,259 +82389,214 @@ Note that this code is not included in the generated catdef.spad file.
 
 \begin{chunk}{GCDDOM-.lsp BOOTSTRAP}
 
-(|/VERSIONCHECK| 2) 
+(/VERSIONCHECK 2) 
 
-(DEFUN |GCDDOM-;lcm;3S;1| (|x| |y| |$|) 
-  (PROG (LCM) 
-    (RETURN 
-      (SEQ 
-        (COND 
-          ((OR 
-              (SPADCALL |y| (|spadConstant| |$| 7) (QREFELT |$| 9))
-              (SPADCALL |x| (|spadConstant| |$| 7) (QREFELT |$| 9))) 
-            (|spadConstant| |$| 7))
-          ((QUOTE T) 
-            (SEQ 
-              (LETT LCM 
-                (SPADCALL |y| 
-                  (SPADCALL |x| |y| (QREFELT |$| 10))
-                  (QREFELT |$| 12))
-                |GCDDOM-;lcm;3S;1|)
-              (EXIT 
-                (COND 
-                  ((QEQCAR LCM 0) (SPADCALL |x| (QCDR LCM) (QREFELT |$| 13)))
-                  ((QUOTE T) (|error| "bad gcd in lcm computation"))))))))))) 
+(DEFUN |GCDDOM-;lcm;3S;1| (|x| |y| $)
+ (PROG (LCM)
+  (RETURN
+   (SEQ
+    (COND
+     ((OR (SPADCALL |y| (|spadConstant| $ 7) (QREFELT $ 9))
+          (SPADCALL |x| (|spadConstant| $ 7) (QREFELT $ 9)))
+      (|spadConstant| $ 7))
+     ((QUOTE T)
+      (SEQ
+       (LETT LCM 
+        (SPADCALL |y| (SPADCALL |x| |y| (QREFELT $ 10)) (QREFELT $ 12))
+        |GCDDOM-;lcm;3S;1|)
+       (EXIT
+        (COND
+         ((QEQCAR LCM 0) (SPADCALL |x| (QCDR LCM) (QREFELT $ 13)))
+         ((QUOTE T) (|error| "bad gcd in lcm computation"))))))))))) 
 
-(DEFUN |GCDDOM-;lcm;LS;2| (|l| |$|) 
-  (SPADCALL 
-    (ELT |$| 15)
-    |l|
-    (|spadConstant| |$| 16)
-    (|spadConstant| |$| 7)
-    (QREFELT |$| 19))) 
+(DEFUN |GCDDOM-;lcm;LS;2| (|l| $)
+ (SPADCALL (ELT $ 15) |l| (|spadConstant| $ 16) (|spadConstant| $ 7)
+  (QREFELT $ 19))) 
 
-(DEFUN |GCDDOM-;gcd;LS;3| (|l| |$|) 
-  (SPADCALL 
-    (ELT |$| 10)
-    |l|
-    (|spadConstant| |$| 7)
-    (|spadConstant| |$| 16)
-    (QREFELT |$| 19))) 
+(DEFUN |GCDDOM-;gcd;LS;3| (|l| $)
+ (SPADCALL (ELT $ 10) |l| (|spadConstant| $ 7) (|spadConstant| $ 16)
+  (QREFELT $ 19))) 
 
-(DEFUN |GCDDOM-;gcdPolynomial;3Sup;4| (|p1| |p2| |$|) 
-  (PROG (|e2| |e1| |c1| |p| |c2| #1=#:G83191) 
-    (RETURN 
-      (SEQ 
-        (COND 
-          ((SPADCALL |p1| (QREFELT |$| 24)) (SPADCALL |p2| (QREFELT |$| 25)))
-          ((SPADCALL |p2| (QREFELT |$| 24)) (SPADCALL |p1| (QREFELT |$| 25)))
-          ((QUOTE T) 
-            (SEQ 
-              (LETT |c1| 
-                (SPADCALL |p1| (QREFELT |$| 26))
-                |GCDDOM-;gcdPolynomial;3Sup;4|)
-              (LETT |c2| 
-                (SPADCALL |p2| (QREFELT |$| 26))
-                |GCDDOM-;gcdPolynomial;3Sup;4|)
-              (LETT |p1| 
-                (PROG2 
-                  (LETT #1# 
-                    (SPADCALL |p1| |c1| (QREFELT |$| 27))
-                    |GCDDOM-;gcdPolynomial;3Sup;4|)
-                  (QCDR #1#)
-                  (|check-union| 
-                    (QEQCAR #1# 0)
-                    (|SparseUnivariatePolynomial| (QREFELT |$| 6))
-                    #1#))
-                |GCDDOM-;gcdPolynomial;3Sup;4|)
-              (LETT |p2| 
-                (PROG2 
-                  (LETT #1# 
-                    (SPADCALL |p2| |c2| (QREFELT |$| 27))
-                    |GCDDOM-;gcdPolynomial;3Sup;4|)
-                  (QCDR #1#)
-                  (|check-union| 
-                    (QEQCAR #1# 0)
-                    (|SparseUnivariatePolynomial| (QREFELT |$| 6))
-                    #1#))
-                |GCDDOM-;gcdPolynomial;3Sup;4|)
-              (SEQ 
-                (LETT |e1| 
-                  (SPADCALL |p1| (QREFELT |$| 29))
-                  |GCDDOM-;gcdPolynomial;3Sup;4|)
-                (EXIT 
-                  (COND 
-                    ((|<| 0 |e1|)
-                      (LETT |p1| 
-                        (PROG2 
-                          (LETT #1# 
-                            (SPADCALL |p1| 
-                              (SPADCALL 
-                               (|spadConstant| |$| 16) |e1| (QREFELT |$| 32))
-                              (QREFELT |$| 33))
-                            |GCDDOM-;gcdPolynomial;3Sup;4|)
-                          (QCDR #1#)
-                          (|check-union| 
-                            (QEQCAR #1# 0)
-                            (|SparseUnivariatePolynomial| (QREFELT |$| 6))
-                            #1#))
-                        |GCDDOM-;gcdPolynomial;3Sup;4|)))))
-              (SEQ 
-                (LETT |e2| 
-                  (SPADCALL |p2| (QREFELT |$| 29))
-                  |GCDDOM-;gcdPolynomial;3Sup;4|)
-                (EXIT 
-                  (COND 
-                    ((|<| 0 |e2|)
-                      (LETT |p2| 
-                        (PROG2 
-                          (LETT #1# 
-                            (SPADCALL |p2| 
-                              (SPADCALL 
-                                (|spadConstant| |$| 16)
-                                |e2|
-                                (QREFELT |$| 32)) 
-                              (QREFELT |$| 33)) 
-                            |GCDDOM-;gcdPolynomial;3Sup;4|)
-                          (QCDR #1#)
-                          (|check-union| 
-                            (QEQCAR #1# 0)
-                            (|SparseUnivariatePolynomial| (QREFELT |$| 6))
-                            #1#))
-                        |GCDDOM-;gcdPolynomial;3Sup;4|)))))
-              (LETT |e1| 
-                (MIN |e1| |e2|)
-                |GCDDOM-;gcdPolynomial;3Sup;4|)
-              (LETT |c1| 
-                (SPADCALL |c1| |c2| (QREFELT |$| 10))
-                |GCDDOM-;gcdPolynomial;3Sup;4|)
-              (LETT |p1| 
-                (COND 
-                  ((OR 
-                       (EQL (SPADCALL |p1| (QREFELT |$| 34)) 0)
-                       (EQL (SPADCALL |p2| (QREFELT |$| 34)) 0))
-                     (SPADCALL |c1| 0 (QREFELT |$| 32))) 
-                  ((QUOTE T) 
-                    (SEQ 
-                      (LETT |p| 
-                        (SPADCALL |p1| |p2| (QREFELT |$| 35))
-                        |GCDDOM-;gcdPolynomial;3Sup;4|)
-                      (EXIT 
-                        (COND 
-                          ((EQL (SPADCALL |p| (QREFELT |$| 34)) 0)
-                            (SPADCALL |c1| 0 (QREFELT |$| 32)))
-                          ((QUOTE T) 
-                            (SEQ 
-                              (LETT |c2| 
-                                (SPADCALL 
-                                  (SPADCALL |p1| (QREFELT |$| 36))
-                                  (SPADCALL |p2| (QREFELT |$| 36))
-                                  (QREFELT |$| 10))
-                                |GCDDOM-;gcdPolynomial;3Sup;4|)
-                              (EXIT 
-                                (SPADCALL 
-                                  (SPADCALL |c1| 
-                                    (SPADCALL 
-                                      (PROG2 
-                                        (LETT #1# 
-                                          (SPADCALL 
-                                            (SPADCALL 
-                                              |c2| 
-                                              |p| 
-                                              (QREFELT |$| 37)) 
-                                            (SPADCALL |p| (QREFELT |$| 36))
-                                            (QREFELT |$| 27))
-                                          |GCDDOM-;gcdPolynomial;3Sup;4|) 
-                                       (QCDR #1#)
-                                       (|check-union| 
-                                         (QEQCAR #1# 0)
-                                         (|SparseUnivariatePolynomial| 
-                                           (QREFELT |$| 6))
-                                         #1#)) 
-                                      (QREFELT |$| 38))
-                                    (QREFELT |$| 37))
-                                  (QREFELT |$| 25))))))))))
-                |GCDDOM-;gcdPolynomial;3Sup;4|)
+(DEFUN |GCDDOM-;gcdPolynomial;3Sup;4| (|p1| |p2| $)
+ (PROG (|e2| |e1| |c1| |p| |c2| #0=#:G22304)
+  (RETURN
+   (SEQ
+    (COND
+     ((SPADCALL |p1| (QREFELT $ 24)) (SPADCALL |p2| (QREFELT $ 25)))
+     ((SPADCALL |p2| (QREFELT $ 24)) (SPADCALL |p1| (QREFELT $ 25)))
+     ((QUOTE T)
+      (SEQ
+       (LETT |c1|
+        (SPADCALL |p1| (QREFELT $ 26)) |GCDDOM-;gcdPolynomial;3Sup;4|)
+       (LETT |c2|
+        (SPADCALL |p2| (QREFELT $ 26)) |GCDDOM-;gcdPolynomial;3Sup;4|)
+       (LETT |p1|
+        (PROG2
+         (LETT #0# (SPADCALL |p1| |c1| (QREFELT $ 27)) |GCDDOM-;gcdPolynomial;3Sup;4|)
+         (QCDR #0#)
+         (|check-union| (QEQCAR #0# 0)
+          (|SparseUnivariatePolynomial| (QREFELT $ 6)) #0#))
+        |GCDDOM-;gcdPolynomial;3Sup;4|)
+       (LETT |p2|
+        (PROG2
+         (LETT #0#
+          (SPADCALL |p2| |c2| (QREFELT $ 27))
+          |GCDDOM-;gcdPolynomial;3Sup;4|)
+         (QCDR #0#)
+         (|check-union| (QEQCAR #0# 0)
+           (|SparseUnivariatePolynomial| (QREFELT $ 6)) #0#))
+        |GCDDOM-;gcdPolynomial;3Sup;4|)
+       (SEQ
+        (LETT |e1|
+         (SPADCALL |p1| (QREFELT $ 29))
+         |GCDDOM-;gcdPolynomial;3Sup;4|)
+        (EXIT
+         (COND
+          ((< 0 |e1|)
+           (LETT |p1|
+            (PROG2
+             (LETT #0#
+              (SPADCALL |p1|
+               (SPADCALL (|spadConstant| $ 16) |e1| (QREFELT $ 32))
+               (QREFELT $ 33))
+              |GCDDOM-;gcdPolynomial;3Sup;4|)
+             (QCDR #0#)
+             (|check-union| (QEQCAR #0# 0)
+              (|SparseUnivariatePolynomial| (QREFELT $ 6)) #0#))
+            |GCDDOM-;gcdPolynomial;3Sup;4|)))))
+       (SEQ 
+        (LETT |e2|
+         (SPADCALL |p2| (QREFELT $ 29))
+         |GCDDOM-;gcdPolynomial;3Sup;4|)
+        (EXIT
+         (COND
+          ((< 0 |e2|)
+           (LETT |p2|
+            (PROG2
+             (LETT #0#
+              (SPADCALL |p2|
+               (SPADCALL (|spadConstant| $ 16) |e2| (QREFELT $ 32))
+               (QREFELT $ 33))
+              |GCDDOM-;gcdPolynomial;3Sup;4|)
+             (QCDR #0#)
+             (|check-union| (QEQCAR #0# 0)
+              (|SparseUnivariatePolynomial| (QREFELT $ 6)) #0#))
+            |GCDDOM-;gcdPolynomial;3Sup;4|)))))
+       (LETT |e1| (MIN |e1| |e2|) |GCDDOM-;gcdPolynomial;3Sup;4|)
+       (LETT |c1| 
+        (SPADCALL |c1| |c2| (QREFELT $ 10))
+        |GCDDOM-;gcdPolynomial;3Sup;4|)
+       (LETT |p1|
+        (COND
+         ((OR (EQL (SPADCALL |p1| (QREFELT $ 34)) 0)
+              (EQL (SPADCALL |p2| (QREFELT $ 34)) 0))
+          (SPADCALL |c1| 0 (QREFELT $ 32)))
+         ((QUOTE T)
+          (SEQ
+           (LETT |p|
+            (SPADCALL |p1| |p2| (QREFELT $ 35))
+            |GCDDOM-;gcdPolynomial;3Sup;4|)
+          (EXIT
+           (COND
+            ((EQL (SPADCALL |p| (QREFELT $ 34)) 0)
+              (SPADCALL |c1| 0 (QREFELT $ 32)))
+            ((QUOTE T)
+             (SEQ
+              (LETT |c2|
+               (SPADCALL
+                (SPADCALL |p1| (QREFELT $ 36))
+                (SPADCALL |p2| (QREFELT $ 36))
+                (QREFELT $ 10))
+               |GCDDOM-;gcdPolynomial;3Sup;4|)
               (EXIT
-               (COND
-                ((ZEROP |e1|) |p1|)
-                ((QUOTE T)
-                  (SPADCALL
-                   (SPADCALL (|spadConstant| |$| 16) |e1| (QREFELT |$| 32))
-                   |p1| (QREFELT |$| 39)))))))))))) 
+               (SPADCALL
+                (SPADCALL |c1|
+                 (SPADCALL
+                  (PROG2 
+                   (LETT #0# 
+                    (SPADCALL
+                     (SPADCALL |c2| |p| (QREFELT $ 37))
+                     (SPADCALL |p| (QREFELT $ 36))
+                     (QREFELT $ 27))
+                    |GCDDOM-;gcdPolynomial;3Sup;4|)
+                   (QCDR #0#)
+                   (|check-union| (QEQCAR #0# 0)
+                     (|SparseUnivariatePolynomial| (QREFELT $ 6)) #0#))
+                  (QREFELT $ 38))
+                 (QREFELT $ 37))
+                (QREFELT $ 25))))))))))
+        |GCDDOM-;gcdPolynomial;3Sup;4|)
+       (EXIT
+        (COND
+         ((ZEROP |e1|) |p1|)
+         ((QUOTE T)
+          (SPADCALL
+           (SPADCALL (|spadConstant| $ 16) |e1| (QREFELT $ 32))
+           |p1| (QREFELT $ 39)))))))))))) 
 
-(DEFUN |GcdDomain&| (|#1|) 
-  (PROG (|DV$1| |dv$| |$| |pv$|) 
-    (RETURN 
-      (PROGN 
-        (LETT |DV$1| (|devaluate| |#1|) . #1=(|GcdDomain&|))
-        (LETT |dv$| (LIST (QUOTE |GcdDomain&|) |DV$1|) . #1#)
-        (LETT |$| (make-array 42) . #1#)
-        (QSETREFV |$| 0 |dv$|)
-        (QSETREFV |$| 3 (LETT |pv$| (|buildPredVector| 0 0 NIL) . #1#))
-        (|stuffDomainSlots| |$|)
-        (QSETREFV |$| 6 |#1|)
-        |$|)))) 
+(DEFUN |GCDDOM-;lcmCoef;2SR;5| (|c1| |c2| $)
+ (PROG (|g| |cc1| #0=#:G22318 |cc2|)
+  (RETURN
+   (SEQ
+    (LETT |g| (SPADCALL |c1| |c2| (QREFELT $ 10)) |GCDDOM-;lcmCoef;2SR;5|)
+    (LETT |cc1|
+     (PROG2
+      (LETT #0# (SPADCALL |c2| |g| (QREFELT $ 12)) |GCDDOM-;lcmCoef;2SR;5|)
+      (QCDR #0#)
+      (|check-union| (QEQCAR #0# 0) (QREFELT $ 6) #0#))
+     |GCDDOM-;lcmCoef;2SR;5|)
+    (LETT |cc2|
+     (PROG2 
+      (LETT #0# 
+       (SPADCALL |c1| |g| (QREFELT $ 12))
+       |GCDDOM-;lcmCoef;2SR;5|)
+      (QCDR #0#)
+      (|check-union| (QEQCAR #0# 0) (QREFELT $ 6) #0#))
+     |GCDDOM-;lcmCoef;2SR;5|)
+    (EXIT (VECTOR (SPADCALL |cc1| |c1| (QREFELT $ 13)) |cc1| |cc2|)))))) 
 
-(setf (get
-  (QUOTE |GcdDomain&|)
-  (QUOTE |infovec|))
-  (LIST 
-    (QUOTE 
-      #(NIL NIL NIL NIL NIL NIL 
-        (|local| |#1|)
-        (0 . |Zero|)
-        (|Boolean|)
-        (4 . |=|)
-        (10 . |gcd|)
-        (|Union| |$| (QUOTE "failed"))
-        (16 . |exquo|)
-        (22 . |*|)
-        |GCDDOM-;lcm;3S;1| 
-        (28 . |lcm|)
-        (34 . |One|)
-        (|Mapping| 6 6 6)
-        (|List| 6)
-        (38 . |reduce|)
-        (|List| |$|)
-        |GCDDOM-;lcm;LS;2| 
-        |GCDDOM-;gcd;LS;3| 
-        (|SparseUnivariatePolynomial| 6)
-        (46 . |zero?|)
-        (51 . |unitCanonical|)
-        (56 . |content|)
-        (61 . |exquo|)
-        (|NonNegativeInteger|)
-        (67 . |minimumDegree|)
-        (72 . |Zero|)
-        (76 . |One|)
-        (80 . |monomial|)
-        (86 . |exquo|)
-        (92 . |degree|)
-        (97 . |subResultantGcd|)
-        (103 . |leadingCoefficient|)
-        (108 . |*|)
-        (114 . |primitivePart|)
-        (119 . |*|)
-        (|SparseUnivariatePolynomial| |$|)
-        |GCDDOM-;gcdPolynomial;3Sup;4|)) 
-    (QUOTE #(|lcm| 125 |gcdPolynomial| 136 |gcd| 142))
-    (QUOTE NIL)
+(DEFUN |GcdDomain&| (|#1|)
+ (PROG (DV$1 |dv$| $ |pv$|)
+  (RETURN
+   (PROGN
+    (LETT DV$1 (|devaluate| |#1|) . #0=(|GcdDomain&|))
+    (LETT |dv$| (LIST (QUOTE |GcdDomain&|) DV$1) . #0#)
+    (LETT $ (MAKE-ARRAY 44) . #0#)
+    (QSETREFV $ 0 |dv$|)
+    (QSETREFV $ 3 (LETT |pv$| (|buildPredVector| 0 0 NIL) . #0#))
+    (|stuffDomainSlots| $)
+    (QSETREFV $ 6 |#1|)
+    $)))) 
+
+(SETF (GET (QUOTE |GcdDomain&|) (QUOTE |infovec|))
+ (LIST
+  (QUOTE #(NIL NIL NIL NIL NIL NIL (|local| |#1|) (0 . |Zero|) (|Boolean|)
+    (4 . =) (10 . |gcd|) (|Union| $ (QUOTE "failed")) (16 . |exquo|)
+    (22 . *) |GCDDOM-;lcm;3S;1| (28 . |lcm|) (34 . |One|) (|Mapping| 6 6 6)
+    (|List| 6) (38 . |reduce|) (|List| $) |GCDDOM-;lcm;LS;2|
+    |GCDDOM-;gcd;LS;3| (|SparseUnivariatePolynomial| 6) (46 . |zero?|)
+    (51 . |unitCanonical|) (56 . |content|) (61 . |exquo|)
+    (|NonNegativeInteger|) (67 . |minimumDegree|) (72 . |Zero|) (76 . |One|)
+    (80 . |monomial|) (86 . |exquo|) (92 . |degree|) (97 . |subResultantGcd|)
+    (103 . |leadingCoefficient|) (108 . *) (114 . |primitivePart|) (119 . *)
+    (|SparseUnivariatePolynomial| $) |GCDDOM-;gcdPolynomial;3Sup;4|
+    (|Record| (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $))
+    |GCDDOM-;lcmCoef;2SR;5|))
+  (QUOTE #(|lcmCoef| 125 |lcm| 131 |gcdPolynomial| 142 |gcd| 148))
+  (QUOTE NIL)
+  (CONS 
+   (|makeByteWordVec2| 1 (QUOTE NIL))
+   (CONS 
+    (QUOTE #())
     (CONS 
-      (|makeByteWordVec2| 1 (QUOTE NIL))
-      (CONS 
-        (QUOTE #())
-        (CONS 
-          (QUOTE #()) 
-            (|makeByteWordVec2| 41 
-             (QUOTE (0 6 0 7 2 6 8 0 0 9 2 6 0 0 0 10 2 6 11 0 0 12 2 6 0 0 0
-                     13 2 6 0 0 0 15 0 6 0 16 4 18 6 17 0 6 6 19 1 23 8 0 24
-                     1 23 0 0 25 1 23 6 0 26 2 23 11 0 6 27 1 23 28 0 29 0 23
-                     0 30 0 23 0 31 2 23 0 6 28 32 2 23 11 0 0 33 1 23 28 0
-                     34 2 23 0 0 0 35 1 23 6 0 36 2 23 0 6 0 37 1 23 0 0 38 2
-                     23 0 0 0 39 1 0 0 20 21 2 0 0 0 0 14 2 0 40 40 40 41 1 0
-                     0 20 22)))))) 
-   (QUOTE |lookupComplete|))) 
+     (QUOTE #())
+     (|makeByteWordVec2| 43 (QUOTE (0 6 0 7 2 6 8 0 0 9 2 6 0 0 0 10 2 6 
+       11 0 0 12 2 6 0 0 0 13 2 6 0 0 0 15 0 6 0 16 4 18 6 17 0 6 6 19 1 
+       23 8 0 24 1 23 0 0 25 1 23 6 0 26 2 23 11 0 6 27 1 23 28 0 29 0 
+       23 0 30 0 23 0 31 2 23 0 6 28 32 2 23 11 0 0 33 1 23 28 0 34 2 
+       23 0 0 0 35 1 23 6 0 36 2 23 0 6 0 37 1 23 0 0 38 2 23 0 0 0 39 
+       2 0 42 0 0 43 2 0 0 0 0 14 1 0 0 20 21 2 0 40 40 40 41 1 0 0 20 22))))))
+  (QUOTE |lookupComplete|))) 
 
 \end{chunk}
 \section{HOAGG.lsp BOOTSTRAP}
@@ -90717,144 +90801,106 @@ Note that this code is not included in the generated catdef.spad file.
 
 \begin{chunk}{UPOLYC.lsp BOOTSTRAP}
 
-(|/VERSIONCHECK| 2) 
+(/VERSIONCHECK 2) 
 
 (SETQ |UnivariatePolynomialCategory;CAT| (QUOTE NIL)) 
 
 (SETQ |UnivariatePolynomialCategory;AL| (QUOTE NIL)) 
 
-(DEFUN |UnivariatePolynomialCategory| (#1=#:G103214) 
-  (LET (#2=#:G103215) 
-    (COND 
-      ((SETQ #2# (|assoc| (|devaluate| #1#) |UnivariatePolynomialCategory;AL|))
-         (CDR #2#))
-      (T 
-        (SETQ |UnivariatePolynomialCategory;AL| 
-          (|cons5| 
-            (CONS 
-              (|devaluate| #1#)
-              (SETQ #2# (|UnivariatePolynomialCategory;| #1#)))
-            |UnivariatePolynomialCategory;AL|))
-         #2#)))) 
+(DEFUN |UnivariatePolynomialCategory| (#0=#:G1438)
+ (LET (#1=#:G1439)
+  (COND
+   ((SETQ #1# (|assoc| (|devaluate| #0#) |UnivariatePolynomialCategory;AL|))
+    (CDR #1#))
+   (T
+    (SETQ |UnivariatePolynomialCategory;AL|
+     (|cons5|
+      (CONS (|devaluate| #0#) (SETQ #1# (|UnivariatePolynomialCategory;| #0#)))
+      |UnivariatePolynomialCategory;AL|))
+    #1#)))) 
 
-(DEFUN |UnivariatePolynomialCategory;| (|t#1|) 
-  (PROG (#1=#:G103213) 
-    (RETURN 
-      (PROG1 
-        (LETT #1# 
-          (|sublisV| 
-            (PAIR (QUOTE (|t#1|)) (LIST (|devaluate| |t#1|)))
-            (|sublisV| 
-              (PAIR 
-                (QUOTE (#2=#:G103211 #3=#:G103212))
-                (LIST 
-                  (QUOTE (|NonNegativeInteger|))
-                  (QUOTE (|SingletonAsOrderedSet|))))
-              (COND 
-                (|UnivariatePolynomialCategory;CAT|)
-                ((QUOTE T) 
-                  (LETT |UnivariatePolynomialCategory;CAT| 
-                    (|Join| 
-                      (|PolynomialCategory| 
-                        (QUOTE |t#1|) (QUOTE #2#) (QUOTE #3#))
-                      (|Eltable| (QUOTE |t#1|) (QUOTE |t#1|))
-                      (|Eltable| (QUOTE |$|) (QUOTE |$|))
-                      (|DifferentialRing|)
-                      (|DifferentialExtension| (QUOTE |t#1|))
-                      (|mkCategory| 
-                        (QUOTE |domain|)
-                        (QUOTE (
-                          ((|vectorise| 
-                            ((|Vector| |t#1|) |$| (|NonNegativeInteger|))) T)
-                          ((|makeSUP| 
-                            ((|SparseUnivariatePolynomial| |t#1|) |$|)) T)
-                          ((|unmakeSUP| 
-                            (|$| (|SparseUnivariatePolynomial| |t#1|))) T)
-                          ((|multiplyExponents| 
-                            (|$| |$| (|NonNegativeInteger|))) T)
-                          ((|divideExponents| 
-                            ((|Union| |$| "failed")
-                             |$| 
-                             (|NonNegativeInteger|))) T)
-                          ((|monicDivide| 
-                            ((|Record| 
-                               (|:| |quotient| |$|)
-                               (|:| |remainder| |$|))
-                             |$| 
-                             |$|)) T)
-                          ((|karatsubaDivide| 
-                            ((|Record| 
-                               (|:| |quotient| |$|)
-                               (|:| |remainder| |$|)) 
-                             |$| 
-                             (|NonNegativeInteger|))) T)
-                          ((|shiftRight| (|$| |$| (|NonNegativeInteger|))) T)
-                          ((|shiftLeft| (|$| |$| (|NonNegativeInteger|))) T)
-                          ((|pseudoRemainder| (|$| |$| |$|)) T)
-                          ((|differentiate| 
-                            (|$| |$| (|Mapping| |t#1| |t#1|) |$|)) T)
-                          ((|discriminant| (|t#1| |$|)) 
-                            (|has| |t#1| (|CommutativeRing|)))
-                          ((|resultant| (|t#1| |$| |$|)) 
-                            (|has| |t#1| (|CommutativeRing|)))
-                          ((|elt| 
-                             ((|Fraction| |$|) 
-                              (|Fraction| |$|)
-                              (|Fraction| |$|)))
-                            (|has| |t#1| (|IntegralDomain|)))
-                          ((|order| ((|NonNegativeInteger|) |$| |$|)) 
-                            (|has| |t#1| (|IntegralDomain|)))
-                          ((|subResultantGcd| (|$| |$| |$|)) 
-                            (|has| |t#1| (|IntegralDomain|)))
-                          ((|composite| ((|Union| |$| "failed") |$| |$|)) 
-                            (|has| |t#1| (|IntegralDomain|)))
-                          ((|composite| 
-                             ((|Union| (|Fraction| |$|) "failed")
-                              (|Fraction| |$|)
-                              |$|)) 
-                            (|has| |t#1| (|IntegralDomain|)))
-                          ((|pseudoQuotient| (|$| |$| |$|)) 
-                            (|has| |t#1| (|IntegralDomain|)))
-                          ((|pseudoDivide| 
-                             ((|Record| 
-                               (|:| |coef| |t#1|)
-                               (|:| |quotient| |$|)
-                               (|:| |remainder| |$|)) 
-                             |$| 
-                             |$|)) 
-                            (|has| |t#1| (|IntegralDomain|)))
-                          ((|separate| 
-                             ((|Record| 
-                               (|:| |primePart| |$|)
-                               (|:| |commonPart| |$|)) 
-                             |$| 
-                             |$|)) 
-                            (|has| |t#1| (|GcdDomain|)))
-                          ((|elt| (|t#1| (|Fraction| |$|) |t#1|)) 
-                            (|has| |t#1| (|Field|)))
-                          ((|integrate| (|$| |$|)) 
-                            (|has| |t#1| 
-                              (|Algebra| (|Fraction| (|Integer|)))))))
-                         (QUOTE (
-                           ((|StepThrough|) (|has| |t#1| (|StepThrough|)))
-                           ((|Eltable| 
-                              (|Fraction| |$|)
-                              (|Fraction| |$|)) 
-                             (|has| |t#1| (|IntegralDomain|)))
-                           ((|EuclideanDomain|) (|has| |t#1| (|Field|)))
-                           (|additiveValuation| (|has| |t#1| (|Field|)))))
-                         (QUOTE (
-                           (|Fraction| |$|)
-                           (|NonNegativeInteger|)
-                           (|SparseUnivariatePolynomial| |t#1|)
-                           (|Vector| |t#1|)))
-                         NIL))
-                    . #4=(|UnivariatePolynomialCategory|))))))
-            . #4#)
-         (SETELT #1# 0 
-           (LIST 
-             (QUOTE |UnivariatePolynomialCategory|)
-             (|devaluate| |t#1|))))))) 
+(DEFUN |UnivariatePolynomialCategory;| (|t#1|)
+ (PROG (#0=#:G1437)
+  (RETURN
+   (PROG1
+    (LETT #0#
+     (|sublisV|
+      (PAIR (QUOTE (|t#1|)) (LIST (|devaluate| |t#1|)))
+      (|sublisV|
+       (PAIR
+        (QUOTE (#1=#:G1435 #2=#:G1436))
+        (LIST
+         (QUOTE (|NonNegativeInteger|))
+         (QUOTE (|SingletonAsOrderedSet|))))
+       (COND
+        (|UnivariatePolynomialCategory;CAT|)
+        ((QUOTE T)
+         (LETT |UnivariatePolynomialCategory;CAT|
+          (|Join|
+           (|PolynomialCategory| (QUOTE |t#1|) (QUOTE #1#) (QUOTE #2#))
+           (|Eltable| (QUOTE |t#1|) (QUOTE |t#1|))
+           (|Eltable| (QUOTE $) (QUOTE $))
+           (|DifferentialRing|)
+           (|DifferentialExtension| (QUOTE |t#1|))
+           (|mkCategory|
+            (QUOTE |domain|)
+            (QUOTE
+             (((|vectorise| ((|Vector| |t#1|) $ (|NonNegativeInteger|))) T)
+              ((|unvectorise| ($ (|Vector| |t#1|))) T)
+              ((|makeSUP| ((|SparseUnivariatePolynomial| |t#1|) $)) T)
+              ((|unmakeSUP| ($ (|SparseUnivariatePolynomial| |t#1|))) T)
+              ((|multiplyExponents| ($ $ (|NonNegativeInteger|))) T)
+              ((|divideExponents|
+                ((|Union| $ "failed") $ (|NonNegativeInteger|))) T)
+              ((|monicDivide|
+                ((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $)) T)
+              ((|karatsubaDivide|
+                ((|Record| (|:| |quotient| $) (|:| |remainder| $)) $
+                 (|NonNegativeInteger|))) T)
+              ((|shiftRight| ($ $ (|NonNegativeInteger|))) T)
+              ((|shiftLeft| ($ $ (|NonNegativeInteger|))) T)
+              ((|pseudoRemainder| ($ $ $)) T)
+              ((|differentiate| ($ $ (|Mapping| |t#1| |t#1|) $)) T)
+              ((|discriminant| (|t#1| $)) (|has| |t#1| (|CommutativeRing|)))
+              ((|resultant| (|t#1| $ $)) (|has| |t#1| (|CommutativeRing|)))
+              ((|elt| ((|Fraction| $) (|Fraction| $) (|Fraction| $)))
+                (|has| |t#1| (|IntegralDomain|)))
+              ((|order| ((|NonNegativeInteger|) $ $))
+                (|has| |t#1| (|IntegralDomain|)))
+              ((|subResultantGcd| ($ $ $))
+                (|has| |t#1| (|IntegralDomain|)))
+              ((|composite| ((|Union| $ "failed") $ $))
+                (|has| |t#1| (|IntegralDomain|)))
+              ((|composite|
+                 ((|Union| (|Fraction| $) "failed") (|Fraction| $) $))
+                (|has| |t#1| (|IntegralDomain|)))
+              ((|pseudoQuotient| ($ $ $)) (|has| |t#1| (|IntegralDomain|)))
+              ((|pseudoDivide| 
+                ((|Record| (|:| |coef| |t#1|) (|:| |quotient| $)
+                           (|:| |remainder| $)) $ $))
+                (|has| |t#1| (|IntegralDomain|)))
+              ((|separate|
+                ((|Record| (|:| |primePart| $) (|:| |commonPart| $)) $ $))
+                (|has| |t#1| (|GcdDomain|)))
+              ((|elt| (|t#1| (|Fraction| $) |t#1|)) (|has| |t#1| (|Field|)))
+              ((|integrate| ($ $))
+                (|has| |t#1| (|Algebra| (|Fraction| (|Integer|)))))))
+            (QUOTE (
+             ((|StepThrough|) (|has| |t#1| (|StepThrough|)))
+             ((|Eltable| (|Fraction| $) (|Fraction| $))
+               (|has| |t#1| (|IntegralDomain|)))
+             ((|EuclideanDomain|) (|has| |t#1| (|Field|)))
+             (|additiveValuation| (|has| |t#1| (|Field|)))))
+            (QUOTE (
+             (|Fraction| $)
+             (|NonNegativeInteger|)
+             (|SparseUnivariatePolynomial| |t#1|)
+             (|Vector| |t#1|)))
+            NIL))
+        . #3=(|UnivariatePolynomialCategory|))))))
+      . #3#)
+    (SETELT #0# 0
+     (LIST (QUOTE |UnivariatePolynomialCategory|) (|devaluate| |t#1|))))))) 
 
 \end{chunk}
 \section{UPOLYC-.lsp BOOTSTRAP}
@@ -90868,1376 +90914,1097 @@ Note that this code is not included in the generated catdef.spad file.
 
 \begin{chunk}{UPOLYC-.lsp BOOTSTRAP}
 
-(|/VERSIONCHECK| 2) 
+(/VERSIONCHECK 2) 
 
-(DEFUN |UPOLYC-;variables;SL;1| (|p| |$|) 
-  (COND 
-    ((OR 
-      (SPADCALL |p| (QREFELT |$| 9))
-      (ZEROP (SPADCALL |p| (QREFELT |$| 11)))) 
+(DEFUN |UPOLYC-;variables;SL;1| (|p| $)
+ (COND
+  ((OR (SPADCALL |p| (QREFELT $ 9)) (ZEROP (SPADCALL |p| (QREFELT $ 11))))
      NIL)
-    ((QUOTE T) (LIST (SPADCALL (QREFELT |$| 13)))))) 
+  ((QUOTE T) (LIST (SPADCALL (QREFELT $ 13)))))) 
 
-(DEFUN |UPOLYC-;degree;SSaosNni;2| (|p| |v| |$|) 
-  (SPADCALL |p| (QREFELT |$| 11))) 
+(DEFUN |UPOLYC-;degree;SSaosNni;2| (|p| |v| $) (SPADCALL |p| (QREFELT $ 11))) 
 
-(DEFUN |UPOLYC-;totalDegree;SLNni;3| (|p| |lv| |$|) 
-  (COND ((NULL |lv|) 0) ((QUOTE T) (SPADCALL |p| (QREFELT |$| 17))))) 
+(DEFUN |UPOLYC-;totalDegree;SLNni;3| (|p| |lv| $)
+ (COND ((NULL |lv|) 0) ((QUOTE T) (SPADCALL |p| (QREFELT $ 17))))) 
 
-(DEFUN |UPOLYC-;degree;SLL;4| (|p| |lv| |$|) 
-  (COND ((NULL |lv|) NIL) ((QUOTE T) (LIST (SPADCALL |p| (QREFELT |$| 11)))))) 
+(DEFUN |UPOLYC-;degree;SLL;4| (|p| |lv| $)
+ (COND ((NULL |lv|) NIL) ((QUOTE T) (LIST (SPADCALL |p| (QREFELT $ 11)))))) 
 
-(DEFUN |UPOLYC-;eval;SLLS;5| (|p| |lv| |lq| |$|) 
-  (COND 
-    ((NULL |lv|) |p|)
-    ((NULL (NULL (CDR |lv|))) 
-      (|error| "can only eval a univariate polynomial once"))
-    ((QUOTE T) 
-      (SPADCALL |p| (|SPADfirst| |lv|) (|SPADfirst| |lq|) (QREFELT |$| 21))))) 
+(DEFUN |UPOLYC-;eval;SLLS;5| (|p| |lv| |lq| $)
+ (COND
+  ((NULL |lv|) |p|)
+  ((NULL (NULL (CDR |lv|)))
+    (|error| "can only eval a univariate polynomial once"))
+   ((QUOTE T)
+    (SPADCALL |p| (|SPADfirst| |lv|) (|SPADfirst| |lq|) (QREFELT $ 21))))) 
 
-(DEFUN |UPOLYC-;eval;SSaos2S;6| (|p| |v| |q| |$|) 
-  (SPADCALL |p| |q| (QREFELT |$| 24))) 
+(DEFUN |UPOLYC-;eval;SSaos2S;6| (|p| |v| |q| $)
+ (SPADCALL |p| |q| (QREFELT $ 24))) 
 
-(DEFUN |UPOLYC-;eval;SLLS;7| (|p| |lv| |lr| |$|) 
-  (COND 
-    ((NULL |lv|) |p|)
-    ((NULL (NULL (CDR |lv|))) 
-      (|error| "can only eval a univariate polynomial once"))
-    ((QUOTE T) 
-      (SPADCALL |p| (|SPADfirst| |lv|) (|SPADfirst| |lr|) (QREFELT |$| 26))))) 
+(DEFUN |UPOLYC-;eval;SLLS;7| (|p| |lv| |lr| $)
+ (COND
+  ((NULL |lv|) |p|)
+  ((NULL (NULL (CDR |lv|)))
+    (|error| "can only eval a univariate polynomial once"))
+   ((QUOTE T) 
+    (SPADCALL |p| (|SPADfirst| |lv|) (|SPADfirst| |lr|) (QREFELT $ 26))))) 
 
-(DEFUN |UPOLYC-;eval;SSaosRS;8| (|p| |v| |r| |$|) 
-  (SPADCALL (SPADCALL |p| |r| (QREFELT |$| 29)) (QREFELT |$| 30))) 
+(DEFUN |UPOLYC-;eval;SSaosRS;8| (|p| |v| |r| $)
+ (SPADCALL (SPADCALL |p| |r| (QREFELT $ 29)) (QREFELT $ 30))) 
 
-(DEFUN |UPOLYC-;eval;SLS;9| (|p| |le| |$|) 
-  (COND 
-    ((NULL |le|) |p|)
-    ((NULL (NULL (CDR |le|))) 
-      (|error| "can only eval a univariate polynomial once"))
-    ((QUOTE T) 
-      (COND 
-        ((QEQCAR 
-           (SPADCALL 
-             (SPADCALL (|SPADfirst| |le|) (QREFELT |$| 33))
-             (QREFELT |$| 35))
-            1)
-          |p|)
-        ((QUOTE T) 
-          (SPADCALL |p| 
-            (SPADCALL (|SPADfirst| |le|) (QREFELT |$| 36))
-            (QREFELT |$| 24))))))) 
+(DEFUN |UPOLYC-;eval;SLS;9| (|p| |le| $)
+ (COND
+  ((NULL |le|) |p|)
+  ((NULL (NULL (CDR |le|)))
+    (|error| "can only eval a univariate polynomial once"))
+  ((QUOTE T)
+   (COND
+    ((QEQCAR 
+      (SPADCALL 
+       (SPADCALL (|SPADfirst| |le|) (QREFELT $ 33))
+       (QREFELT $ 35)) 1) |p|)
+    ((QUOTE T)
+     (SPADCALL |p|
+      (SPADCALL (|SPADfirst| |le|) (QREFELT $ 36)) (QREFELT $ 24))))))) 
 
-(DEFUN |UPOLYC-;mainVariable;SU;10| (|p| |$|) 
-  (COND 
-    ((ZEROP (SPADCALL |p| (QREFELT |$| 11))) (CONS 1 "failed"))
-    ((QUOTE T) (CONS 0 (SPADCALL (QREFELT |$| 13)))))) 
+(DEFUN |UPOLYC-;mainVariable;SU;10| (|p| $)
+ (COND
+  ((ZEROP (SPADCALL |p| (QREFELT $ 11))) (CONS 1 "failed"))
+  ((QUOTE T) (CONS 0 (SPADCALL (QREFELT $ 13)))))) 
 
-(DEFUN |UPOLYC-;minimumDegree;SSaosNni;11| (|p| |v| |$|) 
-  (SPADCALL |p| (QREFELT |$| 40))) 
+(DEFUN |UPOLYC-;minimumDegree;SSaosNni;11| (|p| |v| $)
+ (SPADCALL |p| (QREFELT $ 40))) 
 
-(DEFUN |UPOLYC-;minimumDegree;SLL;12| (|p| |lv| |$|) 
-  (COND ((NULL |lv|) NIL) ((QUOTE T) (LIST (SPADCALL |p| (QREFELT |$| 40)))))) 
+(DEFUN |UPOLYC-;minimumDegree;SLL;12| (|p| |lv| $)
+ (COND ((NULL |lv|) NIL) ((QUOTE T) (LIST (SPADCALL |p| (QREFELT $ 40)))))) 
 
-(DEFUN |UPOLYC-;monomial;SSaosNniS;13| (|p| |v| |n| |$|) 
-  (SPADCALL 
-    (CONS (FUNCTION |UPOLYC-;monomial;SSaosNniS;13!0|) (VECTOR |$| |n|))
-    |p|
-    (QREFELT |$| 45))) 
+(DEFUN |UPOLYC-;monomial;SSaosNniS;13| (|p| |v| |n| $)
+ (PROG NIL
+  (RETURN
+   (SPADCALL
+    (CONS (FUNCTION |UPOLYC-;monomial;SSaosNniS;13!0|) (VECTOR $ |n|))
+    |p| (QREFELT $ 45))))) 
 
-(DEFUN |UPOLYC-;monomial;SSaosNniS;13!0| (|#1| |$$|) 
-  (SPADCALL |#1| (QREFELT |$$| 1) (QREFELT (QREFELT |$$| 0) 43))) 
+(DEFUN |UPOLYC-;monomial;SSaosNniS;13!0| (|x1| $$)
+ (PROG (|n| $)
+  (LETT |n| (QREFELT $$ 1) . #0=(|UPOLYC-;monomial;SSaosNniS;13|))
+  (LETT $ (QREFELT $$ 0) . #0#)
+  (RETURN (PROGN (SPADCALL |x1| |n| (QREFELT $ 43)))))) 
 
-(DEFUN |UPOLYC-;coerce;SaosS;14| (|v| |$|) 
-  (SPADCALL (|spadConstant| |$| 48) 1 (QREFELT |$| 49))) 
+(DEFUN |UPOLYC-;coerce;SaosS;14| (|v| $)
+ (SPADCALL (|spadConstant| $ 48) 1 (QREFELT $ 49))) 
 
-(DEFUN |UPOLYC-;makeSUP;SSup;15| (|p| |$|) 
-  (COND 
-    ((SPADCALL |p| (QREFELT |$| 9)) (|spadConstant| |$| 52))
-    ((QUOTE T) 
-      (SPADCALL 
-        (SPADCALL 
-          (SPADCALL |p| (QREFELT |$| 53))
-          (SPADCALL |p| (QREFELT |$| 11))
-          (QREFELT |$| 54))
-        (SPADCALL 
-          (SPADCALL |p| (QREFELT |$| 55))
-          (QREFELT |$| 56))
-        (QREFELT |$| 57))))) 
+(DEFUN |UPOLYC-;makeSUP;SSup;15| (|p| $)
+ (COND
+  ((SPADCALL |p| (QREFELT $ 9)) (|spadConstant| $ 52))
+  ((QUOTE T)
+   (SPADCALL
+    (SPADCALL
+     (SPADCALL |p| (QREFELT $ 53))
+     (SPADCALL |p| (QREFELT $ 11))
+     (QREFELT $ 54))
+    (SPADCALL
+     (SPADCALL |p| (QREFELT $ 55))
+     (QREFELT $ 56))
+    (QREFELT $ 57))))) 
 
-(DEFUN |UPOLYC-;unmakeSUP;SupS;16| (|sp| |$|) 
-  (COND 
-    ((SPADCALL |sp| (QREFELT |$| 59)) (|spadConstant| |$| 60))
-    ((QUOTE T) 
-      (SPADCALL 
-        (SPADCALL 
-          (SPADCALL |sp| (QREFELT |$| 61))
-          (SPADCALL |sp| (QREFELT |$| 62))
-          (QREFELT |$| 49)) 
-        (SPADCALL (SPADCALL |sp| (QREFELT |$| 63)) (QREFELT |$| 64))
-      (QREFELT |$| 65))))) 
-
-(DEFUN |UPOLYC-;karatsubaDivide;SNniR;17| (|p| |n| |$|) 
-  (SPADCALL |p| 
-    (SPADCALL (|spadConstant| |$| 48) |n| (QREFELT |$| 49))
-    (QREFELT |$| 68))) 
-
-(DEFUN |UPOLYC-;shiftRight;SNniS;18| (|p| |n| |$|) 
-  (QCAR 
-    (SPADCALL |p| 
-      (SPADCALL (|spadConstant| |$| 48) |n| (QREFELT |$| 49))
-      (QREFELT |$| 68)))) 
-
-(DEFUN |UPOLYC-;shiftLeft;SNniS;19| (|p| |n| |$|) 
-  (SPADCALL |p| 
-    (SPADCALL (|spadConstant| |$| 48) |n| (QREFELT |$| 49)) (QREFELT |$| 71))) 
-
-(DEFUN |UPOLYC-;solveLinearPolynomialEquation;LSupU;20| (|lpp| |pp| |$|) 
-  (SPADCALL |lpp| |pp| (QREFELT |$| 77))) 
-
-(DEFUN |UPOLYC-;factorPolynomial;SupF;21| (|pp| |$|) 
-  (SPADCALL |pp| (QREFELT |$| 83))) 
-
-(DEFUN |UPOLYC-;factorSquareFreePolynomial;SupF;22| (|pp| |$|) 
-  (SPADCALL |pp| (QREFELT |$| 86))) 
-
-(DEFUN |UPOLYC-;factor;SF;23| (|p| |$|) 
-  (PROG (|ansR| #1=#:G103310 |w| #2=#:G103311) 
-    (RETURN 
-      (SEQ 
-        (COND 
-          ((ZEROP (SPADCALL |p| (QREFELT |$| 11)))
-            (SEQ 
-              (LETT |ansR| 
-                (SPADCALL 
-                  (SPADCALL |p| (QREFELT |$| 53))
-                  (QREFELT |$| 89)) 
-                |UPOLYC-;factor;SF;23|)
-              (EXIT 
-                (SPADCALL 
-                  (SPADCALL 
-                    (SPADCALL |ansR| (QREFELT |$| 91))
-                    (QREFELT |$| 30)) 
-                  (PROGN 
-                    (LETT #1# NIL |UPOLYC-;factor;SF;23|)
-                    (SEQ 
-                      (LETT |w| NIL |UPOLYC-;factor;SF;23|)
-                      (LETT #2# 
-                        (SPADCALL |ansR| (QREFELT |$| 95))
-                        |UPOLYC-;factor;SF;23|)
-                      G190
-                      (COND 
-                        ((OR 
-                          (ATOM #2#)
-                          (PROGN 
-                            (LETT |w| (CAR #2#) |UPOLYC-;factor;SF;23|)
-                            NIL))
-                         (GO G191)))
-                      (SEQ 
-                        (EXIT 
-                          (LETT #1# 
-                            (CONS 
-                              (VECTOR 
-                                (QVELT |w| 0)
-                                (SPADCALL (QVELT |w| 1) (QREFELT |$| 30))
-                                (QVELT |w| 2)) 
-                               #1#)
-                             |UPOLYC-;factor;SF;23|)))
-                      (LETT #2# (CDR #2#) |UPOLYC-;factor;SF;23|)
-                      (GO G190)
-                      G191
-                      (EXIT (NREVERSE0 #1#))))
-                  (QREFELT |$| 99)))))
-          ((QUOTE T) 
-            (SPADCALL 
-              (ELT |$| 64)
-              (SPADCALL (SPADCALL |p| (QREFELT |$| 56)) (QREFELT |$| 100))
-              (QREFELT |$| 104)))))))) 
+(DEFUN |UPOLYC-;unmakeSUP;SupS;16| (|sp| $)
+ (COND
+  ((SPADCALL |sp| (QREFELT $ 59)) (|spadConstant| $ 60))
+  ((QUOTE T)
+   (SPADCALL
+    (SPADCALL
+     (SPADCALL |sp| (QREFELT $ 61))
+     (SPADCALL |sp| (QREFELT $ 62))
+     (QREFELT $ 49))
+    (SPADCALL (SPADCALL |sp| (QREFELT $ 63)) (QREFELT $ 64))
+    (QREFELT $ 65))))) 
 
-(DEFUN |UPOLYC-;vectorise;SNniV;24| (|p| |n| |$|) 
-  (PROG (|v| |m| |i| #1=#:G103316 #2=#:G103312) 
-    (RETURN 
-      (SEQ 
-        (LETT |m| 
-          (SPADCALL 
-            (LETT |v| 
-              (SPADCALL |n| (|spadConstant| |$| 106) (QREFELT |$| 108))
-              |UPOLYC-;vectorise;SNniV;24|)
-            (QREFELT |$| 110))
-          |UPOLYC-;vectorise;SNniV;24|)
-        (SEQ 
-          (LETT |i| 
-            (SPADCALL |v| (QREFELT |$| 110))
-            |UPOLYC-;vectorise;SNniV;24|)
-          (LETT #1# (QVSIZE |v|) |UPOLYC-;vectorise;SNniV;24|)
+(DEFUN |UPOLYC-;karatsubaDivide;SNniR;17| (|p| |n| $)
+ (SPADCALL |p|
+  (SPADCALL (|spadConstant| $ 48) |n| (QREFELT $ 49))
+  (QREFELT $ 68))) 
+
+(DEFUN |UPOLYC-;shiftRight;SNniS;18| (|p| |n| $)
+ (QCAR
+  (SPADCALL |p|
+   (SPADCALL (|spadConstant| $ 48) |n| (QREFELT $ 49))
+   (QREFELT $ 68)))) 
+
+(DEFUN |UPOLYC-;shiftLeft;SNniS;19| (|p| |n| $)
+ (SPADCALL |p|
+  (SPADCALL (|spadConstant| $ 48) |n| (QREFELT $ 49))
+  (QREFELT $ 71))) 
+
+(DEFUN |UPOLYC-;solveLinearPolynomialEquation;LSupU;20| (|lpp| |pp| $)
+ (SPADCALL |lpp| |pp| (QREFELT $ 77))) 
+
+(DEFUN |UPOLYC-;factorPolynomial;SupF;21| (|pp| $)
+ (SPADCALL |pp| (QREFELT $ 83))) 
+
+(DEFUN |UPOLYC-;factorSquareFreePolynomial;SupF;22| (|pp| $)
+ (SPADCALL |pp| (QREFELT $ 86))) 
+
+(DEFUN |UPOLYC-;factor;SF;23| (|p| $)
+ (PROG (|ansR| #0=#:G1523 |w| #1=#:G1524)
+  (RETURN
+   (SEQ
+    (COND
+     ((ZEROP (SPADCALL |p| (QREFELT $ 11)))
+      (SEQ
+       (LETT |ansR|
+        (SPADCALL (SPADCALL |p| (QREFELT $ 53)) (QREFELT $ 89))
+        |UPOLYC-;factor;SF;23|)
+       (EXIT
+        (SPADCALL
+         (SPADCALL (SPADCALL |ansR| (QREFELT $ 91)) (QREFELT $ 30))
+         (PROGN
+          (LETT #0# NIL |UPOLYC-;factor;SF;23|)
+          (SEQ
+           (LETT |w| NIL |UPOLYC-;factor;SF;23|)
+           (LETT #1# (SPADCALL |ansR| (QREFELT $ 95)) |UPOLYC-;factor;SF;23|)
           G190
-          (COND ((|>| |i| #1#) (GO G191)))
-          (SEQ 
-            (EXIT 
-              (SPADCALL |v| |i| 
-                (SPADCALL |p| 
-                  (PROG1 
-                    (LETT #2# (|-| |i| |m|) |UPOLYC-;vectorise;SNniV;24|)
-                    (|check-subtype| 
-                      (|>=| #2# 0)
-                      (QUOTE (|NonNegativeInteger|))
-                      #2#)) 
-                  (QREFELT |$| 111))
-                (QREFELT |$| 112))))
-          (LETT |i| (|+| |i| 1) |UPOLYC-;vectorise;SNniV;24|)
-          (GO G190)
+           (COND
+            ((OR (ATOM #1#)
+                 (PROGN (LETT |w| (CAR #1#) |UPOLYC-;factor;SF;23|) NIL))
+              (GO G191)))
+           (SEQ 
+            (EXIT
+             (LETT #0#
+              (CONS
+               (VECTOR 
+                (QVELT |w| 0)
+                (SPADCALL (QVELT |w| 1) (QREFELT $ 30))
+                (QVELT |w| 2))
+               #0#)
+              |UPOLYC-;factor;SF;23|)))
+           (LETT #1# (CDR #1#) |UPOLYC-;factor;SF;23|)
+           (GO G190)
           G191
-          (EXIT NIL))
-        (EXIT |v|))))) 
+           (EXIT (NREVERSE0 #0#))))
+         (QREFELT $ 99)))))
+     ((QUOTE T)
+      (SPADCALL (ELT $ 64)
+       (SPADCALL (SPADCALL |p| (QREFELT $ 56)) (QREFELT $ 100))
+       (QREFELT $ 104)))))))) 
 
-(DEFUN |UPOLYC-;retract;SR;25| (|p| |$|) 
-  (COND 
-    ((SPADCALL |p| (QREFELT |$| 9)) (|spadConstant| |$| 106))
-    ((ZEROP (SPADCALL |p| (QREFELT |$| 11))) (SPADCALL |p| (QREFELT |$| 53)))
-    ((QUOTE T) (|error| "Polynomial is not of degree 0")))) 
+(DEFUN |UPOLYC-;vectorise;SNniV;24| (|p| |n| $)
+ (PROG (|v| |m| |i| #0=#:G1529 #1=#:G1525)
+  (RETURN
+   (SEQ
+    (LETT |m|
+     (SPADCALL
+      (LETT |v|
+       (SPADCALL |n| (|spadConstant| $ 106) (QREFELT $ 108))
+       |UPOLYC-;vectorise;SNniV;24|)
+      (QREFELT $ 110))
+     |UPOLYC-;vectorise;SNniV;24|)
+    (SEQ (LETT |i| (SPADCALL |v| (QREFELT $ 110)) |UPOLYC-;vectorise;SNniV;24|) (LETT #0#
+  (QVSIZE |v|)
+  |UPOLYC-;vectorise;SNniV;24|)
+  G190
+  (COND ((> |i| #0#) (GO G191)))
+  (SEQ
+   (EXIT
+    (SPADCALL |v| |i|
+     (SPADCALL |p|
+      (PROG1
+       (LETT #1# (- |i| |m|) |UPOLYC-;vectorise;SNniV;24|)
+       (|check-subtype| (>= #1# 0) (QUOTE (|NonNegativeInteger|)) #1#))
+      (QREFELT $ 111))
+     (QREFELT $ 112))))
+  (LETT |i| (+ |i| 1) |UPOLYC-;vectorise;SNniV;24|) (GO G190) G191 (EXIT NIL))
+    (EXIT |v|))))) 
+
+(DEFUN |UPOLYC-;unvectorise;VS;25| (|v| $)
+ (PROG (|i| #0=#:G1534 #1=#:G1530 |p|)
+  (RETURN
+   (SEQ
+    (LETT |p| (|spadConstant| $ 60) |UPOLYC-;unvectorise;VS;25|)
+    (SEQ
+     (LETT |i| 1 |UPOLYC-;unvectorise;VS;25|)
+     (LETT #0# (QVSIZE |v|) |UPOLYC-;unvectorise;VS;25|)
+     G190
+     (COND ((QSGREATERP |i| #0#) (GO G191)))
+     (SEQ
+      (EXIT
+       (LETT |p|
+        (SPADCALL |p|
+         (SPADCALL
+          (SPADCALL |v| |i| (QREFELT $ 114))
+          (PROG1
+           (LETT #1# (- |i| 1) |UPOLYC-;unvectorise;VS;25|)
+           (|check-subtype| (>= #1# 0) (QUOTE (|NonNegativeInteger|)) #1#))
+          (QREFELT $ 49))
+         (QREFELT $ 65))
+        |UPOLYC-;unvectorise;VS;25|)))
+     (LETT |i| (QSADD1 |i|) |UPOLYC-;unvectorise;VS;25|)
+     (GO G190)
+     G191
+     (EXIT NIL))
+    (EXIT |p|))))) 
 
-(DEFUN |UPOLYC-;retractIfCan;SU;26| (|p| |$|) 
-  (COND 
-    ((SPADCALL |p| (QREFELT |$| 9)) (CONS 0 (|spadConstant| |$| 106)))
-    ((ZEROP (SPADCALL |p| (QREFELT |$| 11)))
-       (CONS 0 (SPADCALL |p| (QREFELT |$| 53))))
-    ((QUOTE T) (CONS 1 "failed")))) 
+(DEFUN |UPOLYC-;retract;SR;26| (|p| $)
+ (COND
+  ((SPADCALL |p| (QREFELT $ 9)) (|spadConstant| $ 106))
+  ((ZEROP (SPADCALL |p| (QREFELT $ 11))) (SPADCALL |p| (QREFELT $ 53)))
+  ((QUOTE T) (|error| "Polynomial is not of degree 0")))) 
 
-(DEFUN |UPOLYC-;init;S;27| (|$|) 
-  (SPADCALL (|spadConstant| |$| 117) (QREFELT |$| 30))) 
+(DEFUN |UPOLYC-;retractIfCan;SU;27| (|p| $)
+ (COND
+  ((SPADCALL |p| (QREFELT $ 9)) (CONS 0 (|spadConstant| $ 106)))
+  ((ZEROP (SPADCALL |p| (QREFELT $ 11)))
+   (CONS 0 (SPADCALL |p| (QREFELT $ 53))))
+  ((QUOTE T) (CONS 1 "failed")))) 
 
-(DEFUN |UPOLYC-;nextItemInner| (|n| |$|) 
-  (PROG (|nn| |n1| |n2| #1=#:G103337 |n3|) 
-    (RETURN 
-      (SEQ 
-        (COND 
-          ((SPADCALL |n| (QREFELT |$| 9))
-            (CONS 
-              0 
-              (SPADCALL 
-                (PROG2 
-                  (LETT #1# 
-                    (SPADCALL (|spadConstant| |$| 106) (QREFELT |$| 120))
-                    |UPOLYC-;nextItemInner|) 
-                  (QCDR #1#)
-                  (|check-union| (QEQCAR #1# 0) (QREFELT |$| 7) #1#))
-                (QREFELT |$| 30))))
-          ((ZEROP (SPADCALL |n| (QREFELT |$| 11)))
-            (SEQ 
-              (LETT |nn| 
-                (SPADCALL (SPADCALL |n| (QREFELT |$| 53)) (QREFELT |$| 120))
-                |UPOLYC-;nextItemInner|)
-              (EXIT 
-                (COND 
-                  ((QEQCAR |nn| 1) (CONS 1 "failed"))
-                  ((QUOTE T) 
-                    (CONS 0 (SPADCALL (QCDR |nn|) (QREFELT |$| 30))))))))
-          ((QUOTE T) 
-            (SEQ 
-              (LETT |n1| 
-                (SPADCALL |n| (QREFELT |$| 55))
-                |UPOLYC-;nextItemInner|)
-              (LETT |n2| 
-                (|UPOLYC-;nextItemInner| |n1| |$|)
+(DEFUN |UPOLYC-;init;S;28| ($)
+ (SPADCALL (|spadConstant| $ 119) (QREFELT $ 30))) 
+
+(DEFUN |UPOLYC-;nextItemInner| (|n| $)
+ (PROG (|nn| |n1| |n2| #0=#:G1555 |n3|)
+  (RETURN
+   (SEQ
+    (COND
+     ((SPADCALL |n| (QREFELT $ 9))
+      (CONS 0
+       (SPADCALL
+        (PROG2
+         (LETT #0#
+          (SPADCALL (|spadConstant| $ 106) (QREFELT $ 122))
+          |UPOLYC-;nextItemInner|)
+         (QCDR #0#)
+         (|check-union| (QEQCAR #0# 0) (QREFELT $ 7) #0#))
+        (QREFELT $ 30))))
+     ((ZEROP (SPADCALL |n| (QREFELT $ 11)))
+       (SEQ
+        (LETT |nn|
+         (SPADCALL (SPADCALL |n| (QREFELT $ 53)) (QREFELT $ 122))
+         |UPOLYC-;nextItemInner|)
+        (EXIT
+        (COND
+         ((QEQCAR |nn| 1) (CONS 1 "failed"))
+         ((QUOTE T) (CONS 0 (SPADCALL (QCDR |nn|) (QREFELT $ 30))))))))
+     ((QUOTE T)
+      (SEQ
+       (LETT |n1| (SPADCALL |n| (QREFELT $ 55)) |UPOLYC-;nextItemInner|)
+       (LETT |n2| (|UPOLYC-;nextItemInner| |n1| $) |UPOLYC-;nextItemInner|)
+       (EXIT
+        (COND
+         ((QEQCAR |n2| 0)
+           (CONS 0
+            (SPADCALL
+             (SPADCALL
+              (SPADCALL |n| (QREFELT $ 53))
+              (SPADCALL |n| (QREFELT $ 11))
+              (QREFELT $ 49))
+            (QCDR |n2|)
+            (QREFELT $ 65))))
+         ((< (+ 1 (SPADCALL |n1| (QREFELT $ 11)))
+             (SPADCALL |n| (QREFELT $ 11)))
+           (CONS 0
+            (SPADCALL
+             (SPADCALL
+              (SPADCALL |n| (QREFELT $ 53))
+              (SPADCALL |n| (QREFELT $ 11))
+              (QREFELT $ 49))
+             (SPADCALL
+              (PROG2
+               (LETT #0#
+                (SPADCALL (|spadConstant| $ 119) (QREFELT $ 122))
                 |UPOLYC-;nextItemInner|)
-              (EXIT 
-                (COND 
-                  ((QEQCAR |n2| 0)
-                    (CONS 
-                      0 
-                      (SPADCALL 
-                        (SPADCALL 
-                          (SPADCALL |n| (QREFELT |$| 53))
-                          (SPADCALL |n| (QREFELT |$| 11))
-                          (QREFELT |$| 49)) 
-                        (QCDR |n2|) 
-                        (QREFELT |$| 65))))
-                  ((|<| 
-                     (|+| 1 (SPADCALL |n1| (QREFELT |$| 11)))
-                     (SPADCALL |n| (QREFELT |$| 11)))
-                    (CONS 
-                      0 
-                      (SPADCALL 
-                        (SPADCALL 
-                          (SPADCALL |n| (QREFELT |$| 53))
-                          (SPADCALL |n| (QREFELT |$| 11))
-                          (QREFELT |$| 49))
-                        (SPADCALL 
-                          (PROG2 
-                            (LETT #1# 
-                              (SPADCALL 
-                                (|spadConstant| |$| 117)
-                                (QREFELT |$| 120))
-                              |UPOLYC-;nextItemInner|)
-                            (QCDR #1#)
-                            (|check-union| (QEQCAR #1# 0) (QREFELT |$| 7) #1#))
-                          (|+| 1 (SPADCALL |n1| (QREFELT |$| 11)))
-                          (QREFELT |$| 49))
-                        (QREFELT |$| 65))))
-                  ((QUOTE T) 
-                    (SEQ 
-                      (LETT |n3| 
-                        (SPADCALL 
-                          (SPADCALL |n| (QREFELT |$| 53))
-                          (QREFELT |$| 120))
-                        |UPOLYC-;nextItemInner|)
-                      (EXIT 
-                        (COND 
-                          ((QEQCAR |n3| 1) (CONS 1 "failed"))
-                          ((QUOTE T) 
-                            (CONS 
-                              0 
-                              (SPADCALL 
-                                (QCDR |n3|)
-                                (SPADCALL |n| (QREFELT |$| 11))
-                                (QREFELT |$| 49))))))))))))))))) 
-
-(DEFUN |UPOLYC-;nextItem;SU;29| (|n| |$|) 
-  (PROG (|n1| #1=#:G103350) 
-    (RETURN 
-      (SEQ 
-        (LETT |n1| (|UPOLYC-;nextItemInner| |n| |$|) |UPOLYC-;nextItem;SU;29|)
-        (EXIT 
-          (COND 
-            ((QEQCAR |n1| 1)
-              (CONS 
-                0 
-                (SPADCALL 
-                  (PROG2 
-                    (LETT #1# 
-                      (SPADCALL (|spadConstant| |$| 117) (QREFELT |$| 120))
-                      |UPOLYC-;nextItem;SU;29|)
-                    (QCDR #1#)
-                    (|check-union| (QEQCAR #1# 0) (QREFELT |$| 7) #1#))
-                 (|+| 1 (SPADCALL |n| (QREFELT |$| 11)))
-               (QREFELT |$| 49))))
-            ((QUOTE T) |n1|))))))) 
-
-(DEFUN |UPOLYC-;content;SSaosS;30| (|p| |v| |$|) 
-  (SPADCALL (SPADCALL |p| (QREFELT |$| 123)) (QREFELT |$| 30))) 
-
-(DEFUN |UPOLYC-;primeFactor| (|p| |q| |$|) 
-  (PROG (#1=#:G103356 |p1|) 
-    (RETURN 
-      (SEQ 
-        (LETT |p1| 
-           (PROG2 
-             (LETT #1# 
-               (SPADCALL |p| 
-                 (SPADCALL |p| |q| (QREFELT |$| 125))
-                 (QREFELT |$| 126))
-               |UPOLYC-;primeFactor|)
-             (QCDR #1#)
-             (|check-union| (QEQCAR #1# 0) (QREFELT |$| 6) #1#))
-           |UPOLYC-;primeFactor|)
-        (EXIT 
-          (COND 
-            ((SPADCALL |p1| |p| (QREFELT |$| 127)) |p|)
-            ((QUOTE T) (|UPOLYC-;primeFactor| |p1| |q| |$|)))))))) 
+               (QCDR #0#)
+               (|check-union| (QEQCAR #0# 0) (QREFELT $ 7) #0#))
+              (+ 1 (SPADCALL |n1| (QREFELT $ 11)))
+              (QREFELT $ 49))
+             (QREFELT $ 65))))
+         ((QUOTE T)
+          (SEQ
+           (LETT |n3|
+            (SPADCALL (SPADCALL |n| (QREFELT $ 53)) (QREFELT $ 122))
+            |UPOLYC-;nextItemInner|)
+           (EXIT
+            (COND
+             ((QEQCAR |n3| 1) (CONS 1 "failed"))
+             ((QUOTE T)
+              (CONS 0
+               (SPADCALL (QCDR |n3|)
+                (SPADCALL |n| (QREFELT $ 11)) (QREFELT $ 49))))))))))))))))) 
 
-(DEFUN |UPOLYC-;separate;2SR;32| (|p| |q| |$|) 
-  (PROG (|a| #1=#:G103362) 
-    (RETURN 
-      (SEQ 
-        (LETT |a| 
-          (|UPOLYC-;primeFactor| |p| |q| |$|)
-          |UPOLYC-;separate;2SR;32|)
-        (EXIT 
-          (CONS 
-            |a| 
-            (PROG2 
-              (LETT #1# 
-                (SPADCALL |p| |a| (QREFELT |$| 126))
-                |UPOLYC-;separate;2SR;32|)
-              (QCDR #1#)
-              (|check-union| (QEQCAR #1# 0) (QREFELT |$| 6) #1#)))))))) 
+(DEFUN |UPOLYC-;nextItem;SU;30| (|n| $)
+ (PROG (|n1| #0=#:G1568)
+  (RETURN
+   (SEQ
+    (LETT |n1| (|UPOLYC-;nextItemInner| |n| $) |UPOLYC-;nextItem;SU;30|)
+    (EXIT
+     (COND
+      ((QEQCAR |n1| 1)
+        (CONS 0
+         (SPADCALL
+          (PROG2
+           (LETT #0#
+            (SPADCALL (|spadConstant| $ 119) (QREFELT $ 122))
+            |UPOLYC-;nextItem;SU;30|)
+           (QCDR #0#)
+           (|check-union| (QEQCAR #0# 0) (QREFELT $ 7) #0#))
+          (+ 1 (SPADCALL |n| (QREFELT $ 11))) (QREFELT $ 49))))
+      ((QUOTE T) |n1|))))))) 
 
-(DEFUN |UPOLYC-;differentiate;SM2S;33| (|x| |deriv| |x'| |$|) 
-  (PROG (|dg| |lc| #1=#:G103367 |d|) 
-    (RETURN 
-      (SEQ 
-        (LETT |d| (|spadConstant| |$| 60) |UPOLYC-;differentiate;SM2S;33|)
-        (SEQ G190 
-          (COND 
-            ((NULL 
-               (|<| 0 
-                 (LETT |dg| 
-                   (SPADCALL |x| (QREFELT |$| 11))
-                   |UPOLYC-;differentiate;SM2S;33|)))
-              (GO G191)))
-          (SEQ 
-            (LETT |lc| 
-              (SPADCALL |x| (QREFELT |$| 53))
-              |UPOLYC-;differentiate;SM2S;33|)
-            (LETT |d| 
-              (SPADCALL 
-                (SPADCALL |d| 
-                  (SPADCALL |x'| 
-                    (SPADCALL 
-                      (SPADCALL |dg| |lc| (QREFELT |$| 131))
-                      (PROG1 
-                        (LETT #1# (|-| |dg| 1) |UPOLYC-;differentiate;SM2S;33|)
-                        (|check-subtype| 
-                          (|>=| #1# 0) 
-                          (QUOTE (|NonNegativeInteger|)) 
-                          #1#))
-                      (QREFELT |$| 49)) 
-                    (QREFELT |$| 71)) 
-                  (QREFELT |$| 65)) 
-                  (SPADCALL 
-                    (SPADCALL |lc| |deriv|)
-                    |dg|
-                    (QREFELT |$| 49)) 
-                (QREFELT |$| 65))
-              |UPOLYC-;differentiate;SM2S;33|)
-            (EXIT 
-              (LETT |x| 
-                (SPADCALL |x| (QREFELT |$| 55))
-                |UPOLYC-;differentiate;SM2S;33|)))
-           NIL
-           (GO G190)
-           G191
-           (EXIT NIL))
-        (EXIT 
-          (SPADCALL |d| 
-            (SPADCALL 
-              (SPADCALL 
-                (SPADCALL |x| (QREFELT |$| 53))
-                |deriv|)
-              (QREFELT |$| 30)) 
-            (QREFELT |$| 65))))))) 
-
-(DEFUN |UPOLYC-;ncdiff| (|n| |x'| |$|) 
-  (PROG (#1=#:G103385 |n1|) 
-    (RETURN 
-      (COND 
-        ((ZEROP |n|) (|spadConstant| |$| 60))
-        ((ZEROP 
-          (LETT |n1| 
-            (PROG1 
-              (LETT #1# (|-| |n| 1) |UPOLYC-;ncdiff|)
-              (|check-subtype| 
-                (|>=| #1# 0)
-                (QUOTE (|NonNegativeInteger|))
-                #1#))
-            |UPOLYC-;ncdiff|))
-          |x'|)
-        ((QUOTE T) 
-          (SPADCALL 
-            (SPADCALL |x'| 
-              (SPADCALL (|spadConstant| |$| 48) |n1| (QREFELT |$| 49))
-              (QREFELT |$| 71)) 
-            (SPADCALL 
-              (SPADCALL (|spadConstant| |$| 48) 1 (QREFELT |$| 49))
-              (|UPOLYC-;ncdiff| |n1| |x'| |$|)
-              (QREFELT |$| 71)) 
-            (QREFELT |$| 65))))))) 
+(DEFUN |UPOLYC-;content;SSaosS;31| (|p| |v| $)
+ (SPADCALL (SPADCALL |p| (QREFELT $ 125)) (QREFELT $ 30))) 
 
-(DEFUN |UPOLYC-;differentiate;SM2S;35| (|x| |deriv| |x'| |$|) 
-  (PROG (|dg| |lc| |d|) 
-    (RETURN 
-      (SEQ 
-        (LETT |d| (|spadConstant| |$| 60) |UPOLYC-;differentiate;SM2S;35|)
-        (SEQ G190 
-          (COND 
-            ((NULL 
-               (|<| 0 
-                 (LETT |dg| 
-                   (SPADCALL |x| (QREFELT |$| 11))
-                   |UPOLYC-;differentiate;SM2S;35|)))
-              (GO G191)))
-          (SEQ 
-            (LETT |lc| 
-              (SPADCALL |x| (QREFELT |$| 53))
-              |UPOLYC-;differentiate;SM2S;35|)
-            (LETT |d| 
-              (SPADCALL 
-                (SPADCALL |d| 
-                  (SPADCALL 
-                    (SPADCALL |lc| |deriv|)
-                    |dg|
-                    (QREFELT |$| 49)) 
-                  (QREFELT |$| 65)) 
-                (SPADCALL |lc| 
-                  (|UPOLYC-;ncdiff| |dg| |x'| |$|)
-                  (QREFELT |$| 134)) 
-              (QREFELT |$| 65)) 
-              |UPOLYC-;differentiate;SM2S;35|)
-            (EXIT 
-              (LETT |x| 
-                (SPADCALL |x| (QREFELT |$| 55))
-                |UPOLYC-;differentiate;SM2S;35|)))
-           NIL 
-           (GO G190) 
-           G191 
-           (EXIT NIL))
-        (EXIT 
-          (SPADCALL |d| 
-            (SPADCALL 
-              (SPADCALL (SPADCALL |x| (QREFELT |$| 53)) |deriv|)
-              (QREFELT |$| 30)) 
-            (QREFELT |$| 65))))))) 
+(DEFUN |UPOLYC-;primeFactor| (|p| |q| $)
+ (PROG (#0=#:G1574 |p1|)
+  (RETURN
+   (SEQ
+    (LETT |p1|
+     (PROG2
+      (LETT #0# (SPADCALL |p| (SPADCALL |p| |q| (QREFELT $ 127)) (QREFELT $ 128)) |UPOLYC-;primeFactor|)
+      (QCDR #0#)
+      (|check-union| (QEQCAR #0# 0) (QREFELT $ 6) #0#))
+     |UPOLYC-;primeFactor|)
+    (EXIT
+     (COND
+      ((SPADCALL |p1| |p| (QREFELT $ 129)) |p|)
+      ((QUOTE T) (|UPOLYC-;primeFactor| |p1| |q| $)))))))) 
 
-(DEFUN |UPOLYC-;differentiate;SMS;36| (|x| |deriv| |$|) 
-  (SPADCALL |x| |deriv| (|spadConstant| |$| 47) (QREFELT |$| 135))) 
+(DEFUN |UPOLYC-;separate;2SR;33| (|p| |q| $)
+ (PROG (|a| #0=#:G1580)
+  (RETURN
+   (SEQ
+    (LETT |a| (|UPOLYC-;primeFactor| |p| |q| $) |UPOLYC-;separate;2SR;33|)
+    (EXIT
+     (CONS |a|
+      (PROG2
+       (LETT #0# (SPADCALL |p| |a| (QREFELT $ 128)) |UPOLYC-;separate;2SR;33|)
+       (QCDR #0#)
+       (|check-union| (QEQCAR #0# 0) (QREFELT $ 6) #0#)))))))) 
 
-(DEFUN |UPOLYC-;differentiate;2S;37| (|x| |$|) 
-  (PROG (|dg| #1=#:G103394 |d|) 
-    (RETURN 
-      (SEQ 
-        (LETT |d| (|spadConstant| |$| 60) |UPOLYC-;differentiate;2S;37|)
-        (SEQ G190 
-          (COND 
-            ((NULL 
-              (|<| 0 
-                (LETT |dg| 
-                  (SPADCALL |x| (QREFELT |$| 11))
-                  |UPOLYC-;differentiate;2S;37|))) 
-            (GO G191)))
-          (SEQ 
-            (LETT |d| 
-              (SPADCALL |d| 
-                (SPADCALL 
-                  (SPADCALL |dg| 
-                    (SPADCALL |x| (QREFELT |$| 53)) (QREFELT |$| 131))
-                  (PROG1 
-                    (LETT #1# (|-| |dg| 1) |UPOLYC-;differentiate;2S;37|)
-                    (|check-subtype| 
-                      (|>=| #1# 0) 
-                      (QUOTE (|NonNegativeInteger|))
-                      #1#))
-                  (QREFELT |$| 49))
-                (QREFELT |$| 65))
-              |UPOLYC-;differentiate;2S;37|)
-            (EXIT 
-              (LETT |x| 
-                (SPADCALL |x| (QREFELT |$| 55))
-                |UPOLYC-;differentiate;2S;37|)))
-           NIL
-           (GO G190)
-           G191
-           (EXIT NIL))
-        (EXIT |d|))))) 
+(DEFUN |UPOLYC-;differentiate;SM2S;34| (|x| |deriv| |x'| $)
+ (PROG (|dg| |lc| #0=#:G1585 |d|)
+  (RETURN
+   (SEQ
+    (LETT |d| (|spadConstant| $ 60) |UPOLYC-;differentiate;SM2S;34|)
+    (SEQ G190
+     (COND
+      ((NULL (< 0 
+         (LETT |dg|
+          (SPADCALL |x| (QREFELT $ 11)) |UPOLYC-;differentiate;SM2S;34|)))
+       (GO G191)))
+     (SEQ 
+      (LETT |lc| (SPADCALL |x| (QREFELT $ 53)) |UPOLYC-;differentiate;SM2S;34|)
+      (LETT |d| 
+       (SPADCALL
+        (SPADCALL |d|
+         (SPADCALL |x'|
+          (SPADCALL
+           (SPADCALL |dg| |lc| (QREFELT $ 133))
+            (PROG1
+             (LETT #0# (- |dg| 1) |UPOLYC-;differentiate;SM2S;34|)
+              (|check-subtype| (>= #0# 0) (QUOTE (|NonNegativeInteger|)) #0#))
+            (QREFELT $ 49))
+           (QREFELT $ 71))
+         (QREFELT $ 65))
+        (SPADCALL (SPADCALL |lc| |deriv|) |dg| (QREFELT $ 49)) (QREFELT $ 65))
+       |UPOLYC-;differentiate;SM2S;34|)
+      (EXIT
+       (LETT |x|
+        (SPADCALL |x| (QREFELT $ 55)) |UPOLYC-;differentiate;SM2S;34|)))
+      NIL
+      (GO G190)
+      G191
+      (EXIT NIL))
+    (EXIT
+     (SPADCALL |d|
+      (SPADCALL
+       (SPADCALL (SPADCALL |x| (QREFELT $ 53)) |deriv|)
+       (QREFELT $ 30))
+      (QREFELT $ 65))))))) 
 
-(DEFUN |UPOLYC-;differentiate;SSaosS;38| (|x| |v| |$|) 
-  (SPADCALL |x| (QREFELT |$| 138))) 
+(DEFUN |UPOLYC-;ncdiff| (|n| |x'| $)
+ (PROG (#0=#:G1603 |n1|)
+  (RETURN
+   (COND
+    ((ZEROP |n|) (|spadConstant| $ 60))
+    ((ZEROP 
+      (LETT |n1|
+       (PROG1
+        (LETT #0# (- |n| 1) |UPOLYC-;ncdiff|)
+        (|check-subtype| (>= #0# 0) (QUOTE (|NonNegativeInteger|)) #0#))
+       |UPOLYC-;ncdiff|))
+      |x'|)
+    ((QUOTE T)
+     (SPADCALL
+      (SPADCALL |x'|
+       (SPADCALL (|spadConstant| $ 48) |n1| (QREFELT $ 49)) (QREFELT $ 71))
+      (SPADCALL
+       (SPADCALL (|spadConstant| $ 48) 1 (QREFELT $ 49))
+       (|UPOLYC-;ncdiff| |n1| |x'| $)
+       (QREFELT $ 71))
+      (QREFELT $ 65))))))) 
 
-(DEFUN |UPOLYC-;elt;3F;39| (|g| |f| |$|) 
-  (SPADCALL 
-    (SPADCALL 
-      (SPADCALL |g| (QREFELT |$| 141))
-      |f|
-      (QREFELT |$| 143)) 
-    (SPADCALL (SPADCALL |g| (QREFELT |$| 144)) |f| (QREFELT |$| 143))
-    (QREFELT |$| 145))) 
-
-(DEFUN |UPOLYC-;pseudoQuotient;3S;40| (|p| |q| |$|) 
-  (PROG (|n| #1=#:G103440 #2=#:G103442) 
-    (RETURN 
-      (SEQ 
-        (LETT |n| 
-          (|+| 
-            (|-| 
-              (SPADCALL |p| (QREFELT |$| 11))
-              (SPADCALL |q| (QREFELT |$| 11))) 1)
-           |UPOLYC-;pseudoQuotient;3S;40|)
-        (EXIT 
-          (COND 
-            ((|<| |n| 1) (|spadConstant| |$| 60))
-            ((QUOTE T) 
-              (PROG2 
-                (LETT #2# 
-                  (SPADCALL 
-                    (SPADCALL 
-                      (SPADCALL 
-                        (SPADCALL 
-                          (SPADCALL |q| (QREFELT |$| 53))
-                          (PROG1 
-                            (LETT #1# |n| |UPOLYC-;pseudoQuotient;3S;40|)
-                            (|check-subtype| 
-                              (|>=| #1# 0) 
-                              (QUOTE (|NonNegativeInteger|))
-                              #1#))
-                          (QREFELT |$| 147)) 
-                        |p| 
-                        (QREFELT |$| 134)) 
-                      (SPADCALL |p| |q| (QREFELT |$| 148))
-                      (QREFELT |$| 149)) 
-                    |q| 
-                    (QREFELT |$| 126))
-                  |UPOLYC-;pseudoQuotient;3S;40|)
-                (QCDR #2#)
-                (|check-union| (QEQCAR #2# 0) (QREFELT |$| 6) #2#))))))))) 
-
-(DEFUN |UPOLYC-;pseudoDivide;2SR;41| (|p| |q| |$|) 
-  (PROG (|n| |prem| #1=#:G103448 |lc| #2=#:G103450) 
-    (RETURN 
-      (SEQ 
-        (LETT |n| 
-          (|+| 
-            (|-| 
-              (SPADCALL |p| (QREFELT |$| 11))
-              (SPADCALL |q| (QREFELT |$| 11))) 1)
-          |UPOLYC-;pseudoDivide;2SR;41|)
-        (EXIT 
-          (COND 
-            ((|<| |n| 1)
-              (VECTOR (|spadConstant| |$| 48) (|spadConstant| |$| 60) |p|))
-            ((QUOTE T) 
-              (SEQ 
-                (LETT |prem| 
-                  (SPADCALL |p| |q| (QREFELT |$| 148))
-                  |UPOLYC-;pseudoDivide;2SR;41|)
-                (LETT |lc| 
-                  (SPADCALL 
-                    (SPADCALL |q| (QREFELT |$| 53))
-                    (PROG1 
-                      (LETT #1# |n| |UPOLYC-;pseudoDivide;2SR;41|)
-                      (|check-subtype| 
-                        (|>=| #1# 0)
-                        (QUOTE (|NonNegativeInteger|)) #1#))
-                    (QREFELT |$| 147))
-                  |UPOLYC-;pseudoDivide;2SR;41|)
-                (EXIT 
-                  (VECTOR |lc| 
-                    (PROG2 
-                      (LETT #2# 
-                        (SPADCALL 
-                          (SPADCALL 
-                            (SPADCALL |lc| |p| (QREFELT |$| 134))
-                            |prem|
-                            (QREFELT |$| 149))
-                          |q|
-                          (QREFELT |$| 126))
-                        |UPOLYC-;pseudoDivide;2SR;41|)
-                      (QCDR #2#)
-                      (|check-union| (QEQCAR #2# 0) (QREFELT |$| 6) #2#))
-                    |prem|)))))))))) 
-
-(DEFUN |UPOLYC-;composite;FSU;42| (|f| |q| |$|) 
-  (PROG (|n| |d|) 
-    (RETURN 
-      (SEQ 
-        (LETT |n| 
-          (SPADCALL (SPADCALL |f| (QREFELT |$| 141)) |q| (QREFELT |$| 153))
-          |UPOLYC-;composite;FSU;42|)
-        (EXIT 
+(DEFUN |UPOLYC-;differentiate;SM2S;36| (|x| |deriv| |x'| $)
+ (PROG (|dg| |lc| |d|)
+  (RETURN
+   (SEQ
+    (LETT |d| (|spadConstant| $ 60) |UPOLYC-;differentiate;SM2S;36|)
+    (SEQ
+      G190
+      (COND
+       ((NULL (< 0
+         (LETT |dg|
+           (SPADCALL |x| (QREFELT $ 11)) |UPOLYC-;differentiate;SM2S;36|)))
+        (GO G191)))
+      (SEQ
+       (LETT |lc|
+        (SPADCALL |x| (QREFELT $ 53)) |UPOLYC-;differentiate;SM2S;36|)
+       (LETT |d|
+        (SPADCALL
+         (SPADCALL |d|
+          (SPADCALL (SPADCALL |lc| |deriv|) |dg| (QREFELT $ 49))
+          (QREFELT $ 65))
+         (SPADCALL |lc| (|UPOLYC-;ncdiff| |dg| |x'| $) (QREFELT $ 136))
+         (QREFELT $ 65))
+        |UPOLYC-;differentiate;SM2S;36|)
+       (EXIT
+        (LETT |x|
+         (SPADCALL |x| (QREFELT $ 55)) |UPOLYC-;differentiate;SM2S;36|)))
+      NIL
+      (GO G190)
+      G191
+      (EXIT NIL))
+    (EXIT
+     (SPADCALL |d|
+      (SPADCALL
+       (SPADCALL (SPADCALL |x| (QREFELT $ 53)) |deriv|) (QREFELT $ 30))
+      (QREFELT $ 65))))))) 
+
+(DEFUN |UPOLYC-;differentiate;SMS;37| (|x| |deriv| $)
+ (SPADCALL |x| |deriv| (|spadConstant| $ 47) (QREFELT $ 137))) 
+
+(DEFUN |UPOLYC-;differentiate;2S;38| (|x| $)
+ (PROG (|dg| #0=#:G1612 |d|)
+  (RETURN
+   (SEQ
+    (LETT |d| (|spadConstant| $ 60) |UPOLYC-;differentiate;2S;38|)
+    (SEQ
+     G190
+     (COND
+      ((NULL (< 0 
+        (LETT |dg|
+         (SPADCALL |x| (QREFELT $ 11)) |UPOLYC-;differentiate;2S;38|)))
+       (GO G191)))
+     (SEQ
+      (LETT |d|
+       (SPADCALL |d|
+        (SPADCALL
+         (SPADCALL |dg| (SPADCALL |x| (QREFELT $ 53)) (QREFELT $ 133))
+         (PROG1
+          (LETT #0# (- |dg| 1) |UPOLYC-;differentiate;2S;38|)
+          (|check-subtype| (>= #0# 0) (QUOTE (|NonNegativeInteger|)) #0#))
+         (QREFELT $ 49))
+        (QREFELT $ 65))
+       |UPOLYC-;differentiate;2S;38|)
+      (EXIT
+       (LETT |x| (SPADCALL |x| (QREFELT $ 55)) |UPOLYC-;differentiate;2S;38|)))
+     NIL
+     (GO G190)
+     G191
+     (EXIT NIL))
+    (EXIT |d|))))) 
+
+(DEFUN |UPOLYC-;differentiate;SSaosS;39| (|x| |v| $)
+ (SPADCALL |x| (QREFELT $ 140))) 
+
+(DEFUN |UPOLYC-;elt;3F;40| (|g| |f| $)
+ (SPADCALL
+  (SPADCALL (SPADCALL |g| (QREFELT $ 143)) |f| (QREFELT $ 145))
+  (SPADCALL (SPADCALL |g| (QREFELT $ 146)) |f| (QREFELT $ 145))
+  (QREFELT $ 147))) 
+
+(DEFUN |UPOLYC-;pseudoQuotient;3S;41| (|p| |q| $)
+ (PROG (|n| #0=#:G1658 #1=#:G1660)
+  (RETURN
+   (SEQ
+    (LETT |n|
+     (+ (- (SPADCALL |p| (QREFELT $ 11)) (SPADCALL |q| (QREFELT $ 11))) 1)
+     |UPOLYC-;pseudoQuotient;3S;41|)
+    (EXIT
+     (COND
+      ((< |n| 1) (|spadConstant| $ 60))
+      ((QUOTE T)
+       (PROG2
+        (LETT #1# 
+         (SPADCALL
+          (SPADCALL
+           (SPADCALL
+            (SPADCALL
+             (SPADCALL |q| (QREFELT $ 53))
+              (PROG1
+               (LETT #0# |n| |UPOLYC-;pseudoQuotient;3S;41|)
+               (|check-subtype| (>= #0# 0) (QUOTE (|NonNegativeInteger|)) #0#))
+              (QREFELT $ 149))
+            |p| (QREFELT $ 136))
+           (SPADCALL |p| |q| (QREFELT $ 150)) (QREFELT $ 151))
+          |q| (QREFELT $ 128))
+         |UPOLYC-;pseudoQuotient;3S;41|)
+        (QCDR #1#)
+        (|check-union| (QEQCAR #1# 0) (QREFELT $ 6) #1#))))))))) 
+
+(DEFUN |UPOLYC-;pseudoDivide;2SR;42| (|p| |q| $)
+ (PROG (|n| |prem| #0=#:G1666 |lc| #1=#:G1668)
+  (RETURN
+   (SEQ
+    (LETT |n|
+     (+ (- (SPADCALL |p| (QREFELT $ 11)) (SPADCALL |q| (QREFELT $ 11))) 1)
+     |UPOLYC-;pseudoDivide;2SR;42|)
+    (EXIT
+     (COND
+      ((< |n| 1) (VECTOR (|spadConstant| $ 48) (|spadConstant| $ 60) |p|))
+      ((QUOTE T)
+       (SEQ
+        (LETT |prem|
+         (SPADCALL |p| |q| (QREFELT $ 150)) |UPOLYC-;pseudoDivide;2SR;42|)
+        (LETT |lc|
+         (SPADCALL
+          (SPADCALL |q| (QREFELT $ 53))
+          (PROG1
+           (LETT #0# |n| |UPOLYC-;pseudoDivide;2SR;42|)
+            (|check-subtype| (>= #0# 0) (QUOTE (|NonNegativeInteger|)) #0#))
+          (QREFELT $ 149))
+         |UPOLYC-;pseudoDivide;2SR;42|)
+        (EXIT
+         (VECTOR |lc|
+          (PROG2
+           (LETT #1#
+            (SPADCALL
+             (SPADCALL
+              (SPADCALL |lc| |p| (QREFELT $ 136)) |prem| (QREFELT $ 151))
+             |q| (QREFELT $ 128))
+            |UPOLYC-;pseudoDivide;2SR;42|)
+           (QCDR #1#)
+           (|check-union| (QEQCAR #1# 0) (QREFELT $ 6) #1#))
+          |prem|)))))))))) 
+
+(DEFUN |UPOLYC-;composite;FSU;43| (|f| |q| $)
+ (PROG (|n| |d|)
+  (RETURN
+   (SEQ
+    (LETT |n| 
+     (SPADCALL (SPADCALL |f| (QREFELT $ 143)) |q| (QREFELT $ 155))
+     |UPOLYC-;composite;FSU;43|)
+    (EXIT
+     (COND
+      ((QEQCAR |n| 1) (CONS 1 "failed"))
+      ((QUOTE T)
+       (SEQ
+        (LETT |d|
+         (SPADCALL (SPADCALL |f| (QREFELT $ 146)) |q| (QREFELT $ 155))
+         |UPOLYC-;composite;FSU;43|)
+        (EXIT
+         (COND
+          ((QEQCAR |d| 1) (CONS 1 "failed"))
+          ((QUOTE T)
+           (CONS 0
+            (SPADCALL (QCDR |n|) (QCDR |d|) (QREFELT $ 156)))))))))))))) 
+
+(DEFUN |UPOLYC-;composite;2SU;44| (|p| |q| $)
+ (PROG (|cqr| |v| |u| |w| #0=#:G1694)
+  (RETURN
+   (SEQ
+    (COND
+     ((SPADCALL |p| (QREFELT $ 159)) (CONS 0 |p|))
+     ((QUOTE T)
+      (SEQ
+       (EXIT
+        (SEQ
+         (LETT |cqr|
+          (SPADCALL |p| |q| (QREFELT $ 160)) |UPOLYC-;composite;2SU;44|)
+         (COND
+          ((SPADCALL (QVELT |cqr| 2) (QREFELT $ 159))
+           (SEQ
+            (LETT |v|
+             (SPADCALL (QVELT |cqr| 2) (QVELT |cqr| 0) (QREFELT $ 161))
+             |UPOLYC-;composite;2SU;44|)
+            (EXIT
+             (COND
+              ((QEQCAR |v| 0)
+               (SEQ
+                (LETT |u|
+                 (SPADCALL (QVELT |cqr| 1) |q| (QREFELT $ 155))
+                 |UPOLYC-;composite;2SU;44|)
+                (EXIT
+                 (COND
+                  ((QEQCAR |u| 0)
+                   (SEQ
+                    (LETT |w|
+                     (SPADCALL (QCDR |u|) (QVELT |cqr| 0) (QREFELT $ 161))
+                     |UPOLYC-;composite;2SU;44|)
+                    (EXIT
+                     (COND
+                      ((QEQCAR |w| 0)
+                       (PROGN
+                        (LETT #0#
+                         (CONS 0 
+                          (SPADCALL (QCDR |v|)
+                           (SPADCALL
+                            (SPADCALL (|spadConstant| $ 48) 1 (QREFELT $ 49))
+                            (QCDR |w|)
+                            (QREFELT $ 71))
+                           (QREFELT $ 65)))
+                         |UPOLYC-;composite;2SU;44|)
+                        (GO #0#))))))))))))))))
+         (EXIT (CONS 1 "failed")))) #0# (EXIT #0#)))))))) 
+
+(DEFUN |UPOLYC-;elt;S2F;45| (|p| |f| $)
+ (PROG (|n| #0=#:G1701 |ans|)
+  (RETURN
+   (SEQ
+    (COND
+     ((SPADCALL |p| (QREFELT $ 9)) (|spadConstant| $ 163))
+     ((QUOTE T)
+      (SEQ
+       (LETT |ans| 
+        (SPADCALL
+         (SPADCALL (SPADCALL |p| (QREFELT $ 53)) (QREFELT $ 30))
+         (QREFELT $ 164))
+         |UPOLYC-;elt;S2F;45|)
+       (LETT |n| (SPADCALL |p| (QREFELT $ 11)) |UPOLYC-;elt;S2F;45|)
+       (SEQ
+        G190
+        (COND
+         ((NULL 
           (COND 
-            ((QEQCAR |n| 1) (CONS 1 "failed"))
-            ((QUOTE T) 
-              (SEQ 
-                (LETT |d| 
-                  (SPADCALL 
-                    (SPADCALL |f| (QREFELT |$| 144)) |q| (QREFELT |$| 153))
-                  |UPOLYC-;composite;FSU;42|)
-                (EXIT 
-                  (COND 
-                    ((QEQCAR |d| 1) (CONS 1 "failed"))
-                    ((QUOTE T) 
-                      (CONS 
-                        0 
-                        (SPADCALL 
-                          (QCDR |n|) 
-                          (QCDR |d|) 
-                          (QREFELT |$| 154)))))))))))))) 
-
-(DEFUN |UPOLYC-;composite;2SU;43| (|p| |q| |$|) 
-  (PROG (|cqr| |v| |u| |w| #1=#:G103476) 
-    (RETURN 
-      (SEQ 
-        (COND 
-          ((SPADCALL |p| (QREFELT |$| 157)) (CONS 0 |p|))
-          ((QUOTE T) 
-            (SEQ 
-              (EXIT 
-                (SEQ 
-                  (LETT |cqr| 
-                    (SPADCALL |p| |q| (QREFELT |$| 158))
-                    |UPOLYC-;composite;2SU;43|)
-                  (COND 
-                    ((SPADCALL (QVELT |cqr| 2) (QREFELT |$| 157))
-                      (SEQ 
-                        (LETT |v| 
-                          (SPADCALL 
-                            (QVELT |cqr| 2)
-                            (QVELT |cqr| 0)
-                            (QREFELT |$| 159))
-                          |UPOLYC-;composite;2SU;43|)
-                        (EXIT 
-                          (COND 
-                            ((QEQCAR |v| 0)
-                              (SEQ 
-                                (LETT |u| 
-                                  (SPADCALL 
-                                    (QVELT |cqr| 1) 
-                                    |q| 
-                                    (QREFELT |$| 153))
-                                  |UPOLYC-;composite;2SU;43|)
-                                (EXIT 
-                                  (COND 
-                                    ((QEQCAR |u| 0)
-                                      (SEQ 
-                                        (LETT |w| 
-                                          (SPADCALL 
-                                            (QCDR |u|)
-                                            (QVELT |cqr| 0)
-                                            (QREFELT |$| 159))
-                                          |UPOLYC-;composite;2SU;43|)
-                                        (EXIT 
-                                          (COND 
-                                            ((QEQCAR |w| 0)
-                                              (PROGN 
-                                                (LETT #1# 
-                                                  (CONS 
-                                                    0 
-                                                    (SPADCALL 
-                                                      (QCDR |v|)
-                                                      (SPADCALL 
-                                                        (SPADCALL 
-                                                       (|spadConstant| |$| 48)
-                                                       1
-                                                       (QREFELT |$| 49)) 
-                                                     (QCDR |w|) 
-                                                     (QREFELT |$| 71))
-                                                    (QREFELT |$| 65)))
-                                                  |UPOLYC-;composite;2SU;43|)
-                                                (GO #1#))))))))))))))))
-                  (EXIT (CONS 1 "failed"))))
-              #1# 
-              (EXIT #1#)))))))) 
-
-(DEFUN |UPOLYC-;elt;S2F;44| (|p| |f| |$|) 
-  (PROG (|n| #1=#:G103483 |ans|) 
-    (RETURN 
-      (SEQ 
+           ((SPADCALL
+            (LETT |p|
+             (SPADCALL |p| (QREFELT $ 55)) |UPOLYC-;elt;S2F;45|) (QREFELT $ 9))
+            (QUOTE NIL))
+           ((QUOTE T) (QUOTE T))))
+          (GO G191)))
+        (SEQ 
+         (EXIT
+          (LETT |ans|
+           (SPADCALL
+            (SPADCALL |ans|
+             (SPADCALL |f|
+              (PROG1
+               (LETT #0#
+                (- |n|
+                 (LETT |n|
+                  (SPADCALL |p| (QREFELT $ 11))
+                  |UPOLYC-;elt;S2F;45|))
+                |UPOLYC-;elt;S2F;45|)
+               (|check-subtype| (>= #0# 0) (QUOTE (|NonNegativeInteger|)) #0#))
+              (QREFELT $ 165))
+             (QREFELT $ 166))
+            (SPADCALL
+             (SPADCALL (SPADCALL |p| (QREFELT $ 53)) (QREFELT $ 30))
+             (QREFELT $ 164))
+            (QREFELT $ 167))
+           |UPOLYC-;elt;S2F;45|)))
+        NIL
+        (GO G190) 
+        G191 
+        (EXIT NIL))
+       (EXIT 
         (COND 
-          ((SPADCALL |p| (QREFELT |$| 9)) (|spadConstant| |$| 161))
-          ((QUOTE T) 
-            (SEQ 
-              (LETT |ans| 
-                (SPADCALL 
-                  (SPADCALL (SPADCALL |p| (QREFELT |$| 53)) (QREFELT |$| 30))
-                  (QREFELT |$| 162))
-                |UPOLYC-;elt;S2F;44|)
-              (LETT |n| (SPADCALL |p| (QREFELT |$| 11)) |UPOLYC-;elt;S2F;44|)
-              (SEQ G190 
-                (COND 
-                  ((NULL 
-                    (COND 
-                      ((SPADCALL 
-                        (LETT |p| 
-                          (SPADCALL |p| (QREFELT |$| 55))
-                          |UPOLYC-;elt;S2F;44|)
-                        (QREFELT |$| 9))
-                       (QUOTE NIL))
-                      ((QUOTE T) (QUOTE T))))
-                   (GO G191)))
-                (SEQ 
-                  (EXIT 
-                    (LETT |ans| 
-                      (SPADCALL 
-                        (SPADCALL |ans| 
-                          (SPADCALL |f| 
-                            (PROG1 
-                              (LETT #1# 
-                                (|-| |n| 
-                                  (LETT |n| 
-                                    (SPADCALL |p| (QREFELT |$| 11))
-                                    |UPOLYC-;elt;S2F;44|))
-                                |UPOLYC-;elt;S2F;44|)
-                              (|check-subtype| 
-                                (|>=| #1# 0)
-                                (QUOTE (|NonNegativeInteger|))
-                                #1#))
-                            (QREFELT |$| 163))
-                          (QREFELT |$| 164))
-                        (SPADCALL 
-                          (SPADCALL 
-                            (SPADCALL |p| (QREFELT |$| 53))
-                            (QREFELT |$| 30))
-                          (QREFELT |$| 162))
-                        (QREFELT |$| 165))
-                      |UPOLYC-;elt;S2F;44|)))
-                NIL 
-                (GO G190)
-                G191
-                (EXIT NIL))
-              (EXIT 
-                (COND 
-                  ((ZEROP |n|) |ans|)
-                  ((QUOTE T) 
-                    (SPADCALL |ans| 
-                      (SPADCALL |f| |n| (QREFELT |$| 166))
-                      (QREFELT |$| 164)))))))))))) 
-
-(DEFUN |UPOLYC-;order;2SNni;45| (|p| |q| |$|) 
-  (PROG (|u| #1=#:G103497 |ans|) 
-    (RETURN 
-      (SEQ 
-        (EXIT 
-          (COND 
-            ((SPADCALL |p| (QREFELT |$| 9))
-              (|error| "order: arguments must be nonzero"))
-            ((|<| (SPADCALL |q| (QREFELT |$| 11)) 1)
-              (|error| "order: place must be non-trivial"))
-            ((QUOTE T) 
-              (SEQ 
-                (LETT |ans| 0 |UPOLYC-;order;2SNni;45|)
-                (EXIT 
-                  (SEQ G190 
-                    NIL 
-                    (SEQ 
-                      (LETT |u| 
-                        (SPADCALL |p| |q| (QREFELT |$| 126))
-                        |UPOLYC-;order;2SNni;45|)
-                      (EXIT 
-                        (COND 
-                          ((QEQCAR |u| 1)
-                            (PROGN 
-                              (LETT #1# |ans| |UPOLYC-;order;2SNni;45|)
-                              (GO #1#)))
-                          ((QUOTE T) 
-                            (SEQ 
-                              (LETT |p| (QCDR |u|) |UPOLYC-;order;2SNni;45|)
-                              (EXIT 
-                                (LETT 
-                                  |ans|
-                                  (|+| |ans| 1)
-                                  |UPOLYC-;order;2SNni;45|)))))))
-                    NIL 
-                    (GO G190)
-                    G191
-                    (EXIT NIL)))))))
-         #1# 
-         (EXIT #1#))))) 
+         ((ZEROP |n|) |ans|)
+         ((QUOTE T)
+          (SPADCALL |ans|
+           (SPADCALL |f| |n| (QREFELT $ 168)) (QREFELT $ 166)))))))))))) 
 
-(DEFUN |UPOLYC-;squareFree;SF;46| (|p| |$|) 
-  (SPADCALL |p| (QREFELT |$| 170))) 
+(DEFUN |UPOLYC-;order;2SNni;46| (|p| |q| $)
+ (PROG (|u| #0=#:G1715 |ans|)
+  (RETURN
+   (SEQ
+    (EXIT
+     (COND
+      ((SPADCALL |p| (QREFELT $ 9))
+       (|error| "order: arguments must be nonzero"))
+      ((< (SPADCALL |q| (QREFELT $ 11)) 1)
+       (|error| "order: place must be non-trivial"))
+      ((QUOTE T)
+       (SEQ
+        (LETT |ans| 0 |UPOLYC-;order;2SNni;46|)
+        (EXIT
+         (SEQ 
+         G190 
+         NIL 
+         (SEQ
+          (LETT |u|
+           (SPADCALL |p| |q| (QREFELT $ 128)) |UPOLYC-;order;2SNni;46|)
+          (EXIT
+           (COND
+            ((QEQCAR |u| 1)
+             (PROGN (LETT #0# |ans| |UPOLYC-;order;2SNni;46|) (GO #0#)))
+            ((QUOTE T)
+             (SEQ
+              (LETT |p| (QCDR |u|) |UPOLYC-;order;2SNni;46|)
+              (EXIT (LETT |ans| (+ |ans| 1) |UPOLYC-;order;2SNni;46|)))))))
+         NIL
+         (GO G190)
+         G191
+         (EXIT NIL))))))) 
+     #0# (EXIT #0#))))) 
 
-(DEFUN |UPOLYC-;squareFreePart;2S;47| (|p| |$|) 
-  (SPADCALL |p| (QREFELT |$| 172))) 
+(DEFUN |UPOLYC-;squareFree;SF;47| (|p| $) (SPADCALL |p| (QREFELT $ 172))) 
 
-(DEFUN |UPOLYC-;gcdPolynomial;3Sup;48| (|pp| |qq| |$|) 
-  (COND 
-    ((SPADCALL |pp| (QREFELT |$| 174)) (SPADCALL |qq| (QREFELT |$| 175)))
-    ((SPADCALL |qq| (QREFELT |$| 174)) (SPADCALL |pp| (QREFELT |$| 175)))
-    ((QUOTE T) 
-      (SPADCALL 
-        (SPADCALL 
-          (SPADCALL 
-            (SPADCALL |pp| (QREFELT |$| 176))
-            (SPADCALL |qq| (QREFELT |$| 176)) (QREFELT |$| 125))
-          (SPADCALL 
-            (SPADCALL 
-              (SPADCALL |pp| (QREFELT |$| 177))
-              (SPADCALL |qq| (QREFELT |$| 177)) (QREFELT |$| 178))
-            (QREFELT |$| 177))
-          (QREFELT |$| 179))
-        (QREFELT |$| 175))))) 
+(DEFUN |UPOLYC-;squareFreePart;2S;48| (|p| $) (SPADCALL |p| (QREFELT $ 174))) 
 
-(DEFUN |UPOLYC-;squareFreePolynomial;SupF;49| (|pp| |$|) 
-  (SPADCALL |pp| (QREFELT |$| 182))) 
+(DEFUN |UPOLYC-;gcdPolynomial;3Sup;49| (|pp| |qq| $)
+ (COND
+  ((SPADCALL |pp| (QREFELT $ 176)) (SPADCALL |qq| (QREFELT $ 177)))
+  ((SPADCALL |qq| (QREFELT $ 176)) (SPADCALL |pp| (QREFELT $ 177)))
+  ((QUOTE T)
+   (SPADCALL
+    (SPADCALL
+     (SPADCALL
+      (SPADCALL |pp| (QREFELT $ 178))
+      (SPADCALL |qq| (QREFELT $ 178))
+      (QREFELT $ 127))
+     (SPADCALL
+      (SPADCALL
+       (SPADCALL |pp| (QREFELT $ 179))
+       (SPADCALL |qq| (QREFELT $ 179))
+       (QREFELT $ 180))
+      (QREFELT $ 179))
+     (QREFELT $ 181))
+    (QREFELT $ 177))))) 
 
-(DEFUN |UPOLYC-;elt;F2R;50| (|f| |r| |$|) 
-  (SPADCALL 
-    (SPADCALL 
-      (SPADCALL |f| (QREFELT |$| 141))
-      |r|
-      (QREFELT |$| 29))
-    (SPADCALL (SPADCALL |f| (QREFELT |$| 144)) |r| (QREFELT |$| 29))
-    (QREFELT |$| 184))) 
+(DEFUN |UPOLYC-;squareFreePolynomial;SupF;50| (|pp| $)
+ (SPADCALL |pp| (QREFELT $ 184))) 
 
-(DEFUN |UPOLYC-;euclideanSize;SNni;51| (|x| |$|) 
-  (COND 
-    ((SPADCALL |x| (QREFELT |$| 9))
-      (|error| "euclideanSize called on 0 in Univariate Polynomial"))
-    ((QUOTE T) (SPADCALL |x| (QREFELT |$| 11))))) 
+(DEFUN |UPOLYC-;elt;F2R;51| (|f| |r| $)
+ (SPADCALL
+  (SPADCALL (SPADCALL |f| (QREFELT $ 143)) |r| (QREFELT $ 29))
+  (SPADCALL (SPADCALL |f| (QREFELT $ 146)) |r| (QREFELT $ 29))
+  (QREFELT $ 186))) 
 
-(DEFUN |UPOLYC-;divide;2SR;52| (|x| |y| |$|) 
-  (PROG (|lc| |f| #1=#:G103510 |n| |quot|) 
-    (RETURN 
-      (SEQ 
-        (COND 
-          ((SPADCALL |y| (QREFELT |$| 9)) 
-            (|error| "division by 0 in Univariate Polynomials"))
-          ((QUOTE T) 
-            (SEQ 
-              (LETT |quot| (|spadConstant| |$| 60) |UPOLYC-;divide;2SR;52|)
-              (LETT |lc| 
-                (SPADCALL (SPADCALL |y| (QREFELT |$| 53)) (QREFELT |$| 187))
-                |UPOLYC-;divide;2SR;52|)
-              (SEQ G190 
-                (COND 
-                  ((NULL 
-                     (COND 
-                       ((OR 
-                          (SPADCALL |x| (QREFELT |$| 9))
-                          (|<| 
-                            (SPADCALL |x| (QREFELT |$| 11))
-                            (SPADCALL |y| (QREFELT |$| 11))))
-                        (QUOTE NIL)) ((QUOTE T) (QUOTE T))))
-                    (GO G191)))
-                (SEQ 
-                  (LETT |f| 
-                    (SPADCALL |lc| 
-                      (SPADCALL |x| (QREFELT |$| 53))
-                      (QREFELT |$| 188))
-                    |UPOLYC-;divide;2SR;52|)
-                  (LETT |n| 
-                    (PROG1 
-                      (LETT #1# 
-                        (|-| 
-                          (SPADCALL |x| (QREFELT |$| 11))
-                          (SPADCALL |y| (QREFELT |$| 11)))
-                         |UPOLYC-;divide;2SR;52|)
-                      (|check-subtype| 
-                        (|>=| #1# 0)
-                        (QUOTE (|NonNegativeInteger|))
-                        #1#))
-                    |UPOLYC-;divide;2SR;52|)
-                  (LETT |quot| 
-                    (SPADCALL |quot| 
-                      (SPADCALL |f| |n| (QREFELT |$| 49))
-                      (QREFELT |$| 65))
-                    |UPOLYC-;divide;2SR;52|)
-                  (EXIT 
-                    (LETT |x| 
-                      (SPADCALL |x| 
-                        (SPADCALL 
-                          (SPADCALL |f| |n| (QREFELT |$| 49))
-                          |y|
-                          (QREFELT |$| 71))
-                        (QREFELT |$| 149))
-                      |UPOLYC-;divide;2SR;52|)))
-                 NIL 
-                 (GO G190)
-                 G191
-                 (EXIT NIL))
-              (EXIT (CONS |quot| |x|))))))))) 
+(DEFUN |UPOLYC-;euclideanSize;SNni;52| (|x| $)
+ (COND
+  ((SPADCALL |x| (QREFELT $ 9))
+   (|error| "euclideanSize called on 0 in Univariate Polynomial"))
+  ((QUOTE T)
+   (SPADCALL |x| (QREFELT $ 11))))) 
 
-(DEFUN |UPOLYC-;integrate;2S;53| (|p| |$|) 
-  (PROG (|l| |d| |ans|) 
-    (RETURN 
-      (SEQ 
-        (LETT |ans| (|spadConstant| |$| 60) |UPOLYC-;integrate;2S;53|)
-        (SEQ G190 
-          (COND 
-            ((NULL 
-              (COND 
-                ((SPADCALL |p| (|spadConstant| |$| 60) (QREFELT |$| 127))
-                  (QUOTE NIL))
-                ((QUOTE T) (QUOTE T)))) (GO G191)))
-          (SEQ 
-            (LETT |l| 
-              (SPADCALL |p| (QREFELT |$| 53))
-              |UPOLYC-;integrate;2S;53|)
-            (LETT |d| 
-              (|+| 1 (SPADCALL |p| (QREFELT |$| 11)))
-              |UPOLYC-;integrate;2S;53|)
-            (LETT |ans| 
-              (SPADCALL |ans| 
-                (SPADCALL 
-                  (SPADCALL (SPADCALL |d| (QREFELT |$| 191)) (QREFELT |$| 192))
-                  (SPADCALL |l| |d| (QREFELT |$| 49)) (QREFELT |$| 193))
-                (QREFELT |$| 65))
-              |UPOLYC-;integrate;2S;53|)
-            (EXIT 
-              (LETT |p| 
-                (SPADCALL |p| (QREFELT |$| 55))
-                |UPOLYC-;integrate;2S;53|)))
-          NIL
-          (GO G190)
-          G191
-          (EXIT NIL))
-        (EXIT |ans|))))) 
+(DEFUN |UPOLYC-;divide;2SR;53| (|x| |y| $)
+ (PROG (|lc| |f| #0=#:G1728 |n| |quot|)
+  (RETURN
+   (SEQ
+    (COND
+     ((SPADCALL |y| (QREFELT $ 9))
+      (|error| "division by 0 in Univariate Polynomials"))
+     ((QUOTE T)
+      (SEQ
+       (LETT |quot| (|spadConstant| $ 60) |UPOLYC-;divide;2SR;53|)
+       (LETT |lc|
+        (SPADCALL (SPADCALL |y| (QREFELT $ 53)) (QREFELT $ 189))
+        |UPOLYC-;divide;2SR;53|)
+       (SEQ
+        G190
+        (COND
+         ((NULL 
+           (COND
+            ((OR (SPADCALL |x| (QREFELT $ 9))
+                 (< (SPADCALL |x| (QREFELT $ 11))
+                    (SPADCALL |y| (QREFELT $ 11))))
+              (QUOTE NIL))
+            ((QUOTE T) (QUOTE T))))
+          (GO G191)))
+        (SEQ
+         (LETT |f|
+          (SPADCALL |lc| (SPADCALL |x| (QREFELT $ 53)) (QREFELT $ 190))
+          |UPOLYC-;divide;2SR;53|)
+         (LETT |n|
+          (PROG1
+           (LETT #0#
+            (- (SPADCALL |x| (QREFELT $ 11)) (SPADCALL |y| (QREFELT $ 11)))
+            |UPOLYC-;divide;2SR;53|)
+           (|check-subtype| (>= #0# 0) (QUOTE (|NonNegativeInteger|)) #0#))
+          |UPOLYC-;divide;2SR;53|)
+         (LETT |quot|
+          (SPADCALL |quot| (SPADCALL |f| |n| (QREFELT $ 49)) (QREFELT $ 65))
+          |UPOLYC-;divide;2SR;53|)
+         (EXIT
+          (LETT |x|
+           (SPADCALL |x|
+            (SPADCALL (SPADCALL |f| |n| (QREFELT $ 49)) |y| (QREFELT $ 71))
+            (QREFELT $ 151))
+           |UPOLYC-;divide;2SR;53|)))
+        NIL
+        (GO G190)
+        G191
+        (EXIT NIL))
+       (EXIT (CONS |quot| |x|))))))))) 
 
-(DEFUN |UnivariatePolynomialCategory&| (|#1| |#2|) 
-  (PROG (|DV$1| |DV$2| |dv$| |$| |pv$|) 
-    (RETURN 
-      (PROGN 
-        (LETT |DV$1| (|devaluate| |#1|) . #1=(|UnivariatePolynomialCategory&|))
-        (LETT |DV$2| (|devaluate| |#2|) . #1#)
-        (LETT |dv$| 
-          (LIST (QUOTE |UnivariatePolynomialCategory&|) |DV$1| |DV$2|) . #1#)
-        (LETT |$| (make-array 201) . #1#)
-        (QSETREFV |$| 0 |dv$|)
-        (QSETREFV |$| 3 
-          (LETT |pv$| 
-            (|buildPredVector| 0 0 
-              (LIST 
-                (|HasCategory| |#2| 
-                  (QUOTE (|Algebra| (|Fraction| (|Integer|)))))
-                (|HasCategory| |#2| (QUOTE (|Field|)))
-                (|HasCategory| |#2| (QUOTE (|GcdDomain|)))
-                (|HasCategory| |#2| (QUOTE (|IntegralDomain|)))
-                (|HasCategory| |#2| (QUOTE (|CommutativeRing|)))
-                (|HasCategory| |#2| (QUOTE (|StepThrough|))))) . #1#))
-        (|stuffDomainSlots| |$|)
-        (QSETREFV |$| 6 |#1|)
-        (QSETREFV |$| 7 |#2|)
-        (COND 
-          ((|HasCategory| |#2| (QUOTE (|PolynomialFactorizationExplicit|)))
-            (PROGN 
-              (QSETREFV |$| 81 
-                (CONS 
-                  (|dispatchFunction|
-                     |UPOLYC-;solveLinearPolynomialEquation;LSupU;20|)
-                  |$|))
-              (QSETREFV |$| 85 
-                (CONS 
-                  (|dispatchFunction| |UPOLYC-;factorPolynomial;SupF;21|) 
-                  |$|))
-              (QSETREFV |$| 87 
-                 (CONS 
-                    (|dispatchFunction|
-                       |UPOLYC-;factorSquareFreePolynomial;SupF;22|)
-                    |$|))
-              (QSETREFV |$| 105 
-                (CONS (|dispatchFunction| |UPOLYC-;factor;SF;23|) |$|)))))
-        (COND 
-          ((|testBitVector| |pv$| 6)
-            (PROGN 
-              (QSETREFV |$| 118 
-                (CONS (|dispatchFunction| |UPOLYC-;init;S;27|) |$|))
-              NIL
-              (QSETREFV |$| 122 
-                (CONS (|dispatchFunction| |UPOLYC-;nextItem;SU;29|) |$|)))))
-        (COND 
-          ((|testBitVector| |pv$| 3)
-            (PROGN 
-              (QSETREFV |$| 124 
-                (CONS (|dispatchFunction| |UPOLYC-;content;SSaosS;30|) |$|))
-              NIL
-              (QSETREFV |$| 129 
-                (CONS (|dispatchFunction| |UPOLYC-;separate;2SR;32|) |$|)))))
-        (COND 
-          ((|testBitVector| |pv$| 5)
-            (QSETREFV |$| 133 
-              (CONS 
-                (|dispatchFunction| |UPOLYC-;differentiate;SM2S;33|)
-                |$|))) 
-          ((QUOTE T) 
-            (PROGN 
-              (QSETREFV |$| 133 
-                (CONS 
-                  (|dispatchFunction| |UPOLYC-;differentiate;SM2S;35|)
-                  |$|)))))
-        (COND 
-          ((|testBitVector| |pv$| 4)
-            (PROGN 
-              (QSETREFV |$| 146 
-                (CONS (|dispatchFunction| |UPOLYC-;elt;3F;39|) |$|))
-              (QSETREFV |$| 150 
-                (CONS (|dispatchFunction| |UPOLYC-;pseudoQuotient;3S;40|) |$|))
-              (QSETREFV |$| 152 
-                (CONS (|dispatchFunction| |UPOLYC-;pseudoDivide;2SR;41|) |$|))
-              (QSETREFV |$| 156 
-                (CONS (|dispatchFunction| |UPOLYC-;composite;FSU;42|) |$|))
-              (QSETREFV |$| 160 
-                (CONS (|dispatchFunction| |UPOLYC-;composite;2SU;43|) |$|))
-              (QSETREFV |$| 167 
-                (CONS (|dispatchFunction| |UPOLYC-;elt;S2F;44|) |$|))
-              (QSETREFV |$| 168 
-                (CONS (|dispatchFunction| |UPOLYC-;order;2SNni;45|) |$|)))))
-        (COND 
-          ((|testBitVector| |pv$| 3)
-            (PROGN 
-              (QSETREFV |$| 171 
-                (CONS (|dispatchFunction| |UPOLYC-;squareFree;SF;46|) |$|))
-              (QSETREFV |$| 173 
-                (CONS 
-                  (|dispatchFunction| |UPOLYC-;squareFreePart;2S;47|)
-                  |$|)))))
-        (COND 
-          ((|HasCategory| |#2| (QUOTE (|PolynomialFactorizationExplicit|)))
-            (PROGN 
-              (QSETREFV |$| 180 
-                (CONS 
-                  (|dispatchFunction| |UPOLYC-;gcdPolynomial;3Sup;48|)
-                  |$|))
-              (QSETREFV |$| 183 
-                (CONS 
-                  (|dispatchFunction| |UPOLYC-;squareFreePolynomial;SupF;49|)
-                  |$|)))))
-        (COND 
-          ((|testBitVector| |pv$| 2)
-            (PROGN 
-              (QSETREFV |$| 185 
-                (CONS (|dispatchFunction| |UPOLYC-;elt;F2R;50|) |$|))
-              (QSETREFV |$| 186 
-                (CONS 
-                  (|dispatchFunction| |UPOLYC-;euclideanSize;SNni;51|)
-                  |$|))
-              (QSETREFV |$| 189 
-                (CONS (|dispatchFunction| |UPOLYC-;divide;2SR;52|) |$|)))))
-        (COND 
-          ((|testBitVector| |pv$| 1)
-             (QSETREFV |$| 194 
-               (CONS 
-                 (|dispatchFunction| |UPOLYC-;integrate;2S;53|)
-                 |$|)))) |$|)))) 
+(DEFUN |UPOLYC-;integrate;2S;54| (|p| $)
+ (PROG (|l| |d| |ans|)
+  (RETURN
+   (SEQ
+    (LETT |ans| (|spadConstant| $ 60) |UPOLYC-;integrate;2S;54|)
+    (SEQ
+     G190
+     (COND
+      ((NULL 
+       (COND 
+        ((SPADCALL |p| (|spadConstant| $ 60) (QREFELT $ 129)) (QUOTE NIL))
+        ((QUOTE T) (QUOTE T))))
+       (GO G191)))
+     (SEQ
+      (LETT |l| (SPADCALL |p| (QREFELT $ 53)) |UPOLYC-;integrate;2S;54|)
+      (LETT |d| (+ 1 (SPADCALL |p| (QREFELT $ 11))) |UPOLYC-;integrate;2S;54|)
+      (LETT |ans|
+       (SPADCALL |ans|
+        (SPADCALL
+         (SPADCALL (SPADCALL |d| (QREFELT $ 193)) (QREFELT $ 194))
+         (SPADCALL |l| |d| (QREFELT $ 49))
+         (QREFELT $ 195))
+        (QREFELT $ 65))
+       |UPOLYC-;integrate;2S;54|)
+      (EXIT
+       (LETT |p| (SPADCALL |p| (QREFELT $ 55)) |UPOLYC-;integrate;2S;54|)))
+     NIL
+     (GO G190)
+     G191
+     (EXIT NIL))
+    (EXIT |ans|))))) 
 
-(setf (get
-  (QUOTE |UnivariatePolynomialCategory&|)
-  (QUOTE |infovec|))
-  (LIST 
-    (QUOTE 
-      #(NIL NIL NIL NIL NIL NIL 
-        (|local| |#1|)
-        (|local| |#2|)
-        (|Boolean|)
-        (0 . |zero?|)
-        (|NonNegativeInteger|)
-        (5 . |degree|)
-        (|SingletonAsOrderedSet|)
-        (10 . |create|)
-        (|List| 12)
-        |UPOLYC-;variables;SL;1| 
-        |UPOLYC-;degree;SSaosNni;2| 
-        (14 . |totalDegree|)
-        |UPOLYC-;totalDegree;SLNni;3| 
-        (|List| 10)
-        |UPOLYC-;degree;SLL;4| 
-        (19 . |eval|)
-        (|List| |$|)
-        |UPOLYC-;eval;SLLS;5| 
-        (26 . |elt|)
-        |UPOLYC-;eval;SSaos2S;6| 
-        (32 . |eval|)
-        (|List| 7)
-        |UPOLYC-;eval;SLLS;7| 
-        (39 . |elt|)
-        (45 . |coerce|)
-        |UPOLYC-;eval;SSaosRS;8| 
-        (|Equation| 6)
-        (50 . |lhs|)
-        (|Union| 12 (QUOTE "failed"))
-        (55 . |mainVariable|)
-        (60 . |rhs|)
-        (|List| 197)
-        |UPOLYC-;eval;SLS;9| 
-        |UPOLYC-;mainVariable;SU;10| 
-        (65 . |minimumDegree|)
-        |UPOLYC-;minimumDegree;SSaosNni;11| 
-        |UPOLYC-;minimumDegree;SLL;12| 
-        (70 . |+|)
-        (|Mapping| 10 10)
-        (76 . |mapExponents|)
-        |UPOLYC-;monomial;SSaosNniS;13| 
-        (82 . |One|)
-        (86 . |One|)
-        (90 . |monomial|)
-        |UPOLYC-;coerce;SaosS;14| 
-        (|SparseUnivariatePolynomial| 7)
-        (96 . |Zero|)
-        (100 . |leadingCoefficient|)
-        (105 . |monomial|)
-        (111 . |reductum|)
-        (116 . |makeSUP|)
-        (121 . |+|)
-        |UPOLYC-;makeSUP;SSup;15| 
-        (127 . |zero?|)
-        (132 . |Zero|)
-        (136 . |leadingCoefficient|)
-        (141 . |degree|)
-        (146 . |reductum|)
-        (151 . |unmakeSUP|)
-        (156 . |+|)
-        |UPOLYC-;unmakeSUP;SupS;16| 
-        (|Record| (|:| |quotient| |$|) (|:| |remainder| |$|))
-        (162 . |monicDivide|)
-        |UPOLYC-;karatsubaDivide;SNniR;17| 
-        |UPOLYC-;shiftRight;SNniS;18| 
-        (168 . |*|)
-        |UPOLYC-;shiftLeft;SNniS;19| 
-        (|Union| 74 (QUOTE "failed"))
-        (|List| 75)
-        (|SparseUnivariatePolynomial| 6)
-        (|PolynomialFactorizationByRecursionUnivariate| 7 6)
-        (174 . |solveLinearPolynomialEquationByRecursion|)
-        (|Union| 79 (QUOTE "failed"))
-        (|List| 80)
-        (|SparseUnivariatePolynomial| |$|)
-        (180 . |solveLinearPolynomialEquation|)
-        (|Factored| 75)
-        (186 . |factorByRecursion|)
-        (|Factored| 80)
-        (191 . |factorPolynomial|)
-        (196 . |factorSquareFreeByRecursion|)
-        (201 . |factorSquareFreePolynomial|)
-        (|Factored| |$|)
-        (206 . |factor|)
-        (|Factored| 7)
-        (211 . |unit|)
-        (|Union| (QUOTE "nil") (QUOTE "sqfr") (QUOTE "irred") (QUOTE "prime"))
-        (|Record| (|:| |flg| 92) (|:| |fctr| 7) (|:| |xpnt| 109))
-        (|List| 93)
-        (216 . |factorList|)
-        (|Record| (|:| |flg| 92) (|:| |fctr| 6) (|:| |xpnt| 109))
-        (|List| 96)
-        (|Factored| 6)
-        (221 . |makeFR|)
-        (227 . |factorPolynomial|)
-        (|Mapping| 6 51)
-        (|Factored| 51)
-        (|FactoredFunctions2| 51 6)
-        (232 . |map|)
-        (238 . |factor|)
-        (243 . |Zero|)
-        (|Vector| 7)
-        (247 . |new|)
-        (|Integer|)
-        (253 . |minIndex|)
-        (258 . |coefficient|)
-        (264 . |qsetelt!|)
-        |UPOLYC-;vectorise;SNniV;24| 
-        |UPOLYC-;retract;SR;25| 
-        (|Union| 7 (QUOTE "failed"))
-        |UPOLYC-;retractIfCan;SU;26| 
-        (271 . |init|)
-        (275 . |init|)
-        (|Union| |$| (QUOTE "failed"))
-        (279 . |nextItem|)
-        (284 . |One|)
-        (288 . |nextItem|)
-        (293 . |content|)
-        (298 . |content|)
-        (304 . |gcd|)
-        (310 . |exquo|)
-        (316 . |=|)
-        (|Record| (|:| |primePart| |$|) (|:| |commonPart| |$|))
-        (322 . |separate|)
-        (328 . |Zero|)
-        (332 . |*|)
-        (|Mapping| 7 7)
-        (338 . |differentiate|)
-        (345 . |*|)
-        (351 . |differentiate|)
-        |UPOLYC-;differentiate;SMS;36| 
-        |UPOLYC-;differentiate;2S;37| 
-        (358 . |differentiate|)
-        |UPOLYC-;differentiate;SSaosS;38| 
-        (|Fraction| 6)
-        (363 . |numer|)
-        (|Fraction| |$|)
-        (368 . |elt|)
-        (374 . |denom|)
-        (379 . |/|)
-        (385 . |elt|)
-        (391 . |**|)
-        (397 . |pseudoRemainder|)
-        (403 . |-|)
-        (409 . |pseudoQuotient|)
-        (|Record| (|:| |coef| 7) (|:| |quotient| |$|) (|:| |remainder| |$|))
-        (415 . |pseudoDivide|)
-        (421 . |composite|)
-        (427 . |/|)
-        (|Union| 142 (QUOTE "failed"))
-        (433 . |composite|)
-        (439 . |ground?|)
-        (444 . |pseudoDivide|)
-        (450 . |exquo|)
-        (456 . |composite|)
-        (462 . |Zero|)
-        (466 . |coerce|)
-        (471 . |**|)
-        (477 . |*|)
-        (483 . |+|)
-        (489 . |**|)
-        (495 . |elt|)
-        (501 . |order|)
-        (|UnivariatePolynomialSquareFree| 7 6)
-        (507 . |squareFree|)
-        (512 . |squareFree|)
-        (517 . |squareFreePart|)
-        (522 . |squareFreePart|)
-        (527 . |zero?|)
-        (532 . |unitCanonical|)
-        (537 . |content|)
-        (542 . |primitivePart|)
-        (547 . |subResultantGcd|)
-        (553 . |*|)
-        (559 . |gcdPolynomial|)
-        (|UnivariatePolynomialSquareFree| 6 75)
-        (565 . |squareFree|)
-        (570 . |squareFreePolynomial|)
-        (575 . |/|)
-        (581 . |elt|)
-        (587 . |euclideanSize|)
-        (592 . |inv|)
-        (597 . |*|)
-        (603 . |divide|)
-        (|Fraction| 109)
-        (609 . |coerce|)
-        (614 . |inv|)
-        (619 . |*|)
-        (625 . |integrate|)
-        (|Symbol|)
-        (|List| 195)
-        (|Equation| |$|)
-        (|Union| 109 (QUOTE "failed"))
-        (|Union| 190 (QUOTE "failed"))
-        (|OutputForm|))) 
-    (QUOTE 
-      #(|vectorise| 630 |variables| 636 |unmakeSUP| 641 |totalDegree| 646 
-        |squareFreePolynomial| 652 |squareFreePart| 657 |squareFree| 662
-        |solveLinearPolynomialEquation| 667 |shiftRight| 673 |shiftLeft| 679
-        |separate| 685 |retractIfCan| 691 |retract| 696 |pseudoQuotient| 701
-        |pseudoDivide| 707 |order| 713 |nextItem| 719 |monomial| 724
-        |minimumDegree| 731 |makeSUP| 743 |mainVariable| 748
-        |karatsubaDivide| 753 |integrate| 759 |init| 764 |gcdPolynomial| 768
-        |factorSquareFreePolynomial| 774 |factorPolynomial| 779 |factor| 784
-        |eval| 789 |euclideanSize| 823 |elt| 828 |divide| 846
-        |differentiate| 852 |degree| 876 |content| 888 |composite| 894
-        |coerce| 906)) 
-    (QUOTE NIL) 
-    (CONS 
-      (|makeByteWordVec2| 1 (QUOTE NIL))
-      (CONS 
-        (QUOTE #())
+(DEFUN |UnivariatePolynomialCategory&| (|#1| |#2|)
+ (PROG (DV$1 DV$2 |dv$| $ |pv$|)
+  (RETURN
+   (PROGN
+    (LETT DV$1 (|devaluate| |#1|) . #0=(|UnivariatePolynomialCategory&|))
+    (LETT DV$2 (|devaluate| |#2|) . #0#)
+    (LETT |dv$| (LIST (QUOTE |UnivariatePolynomialCategory&|) DV$1 DV$2) . #0#)
+    (LETT $ (MAKE-ARRAY 203) . #0#)
+    (QSETREFV $ 0 |dv$|)
+    (QSETREFV $ 3
+     (LETT |pv$| 
+      (|buildPredVector| 0 0
+       (LIST
+        (|HasCategory| |#2| (QUOTE (|Algebra| (|Fraction| (|Integer|)))))
+        (|HasCategory| |#2| (QUOTE (|Field|)))
+        (|HasCategory| |#2| (QUOTE (|GcdDomain|)))
+        (|HasCategory| |#2| (QUOTE (|IntegralDomain|)))
+        (|HasCategory| |#2| (QUOTE (|CommutativeRing|)))
+        (|HasCategory| |#2| (QUOTE (|StepThrough|)))))
+       . #0#))
+    (|stuffDomainSlots| $)
+    (QSETREFV $ 6 |#1|)
+    (QSETREFV $ 7 |#2|)
+    (COND
+     ((|HasCategory| |#2| (QUOTE (|PolynomialFactorizationExplicit|)))
+      (PROGN
+       (QSETREFV $ 81
         (CONS 
-          (QUOTE #())
-          (|makeByteWordVec2| 194 
-            (QUOTE 
-              (1 6 8 0 9 1 6 10 0 11 0 12 0 13 1 6 10 0 17 3 6 0 0 12 0 21 2
-               6 0 0 0 24 3 6 0 0 12 7 26 2 6 7 0 7 29 1 6 0 7 30 1 32 6 0 33
-               1 6 34 0 35 1 32 6 0 36 1 6 10 0 40 2 10 0 0 0 43 2 6 0 44 0
-               45 0 6 0 47 0 7 0 48 2 6 0 7 10 49 0 51 0 52 1 6 7 0 53 2 51
-               0 7 10 54 1 6 0 0 55 1 6 51 0 56 2 51 0 0 0 57 1 51 8 0 59 0
-               6 0 60 1 51 7 0 61 1 51 10 0 62 1 51 0 0 63 1 6 0 51 64 2 6 0
-               0 0 65 2 6 67 0 0 68 2 6 0 0 0 71 2 76 73 74 75 77 2 0 78 79
-               80 81 1 76 82 75 83 1 0 84 80 85 1 76 82 75 86 1 0 84 80 87 1
-               7 88 0 89 1 90 7 0 91 1 90 94 0 95 2 98 0 6 97 99 1 7 84 80
-               100 2 103 98 101 102 104 1 0 88 0 105 0 7 0 106 2 107 0 10 7
-               108 1 107 109 0 110 2 6 7 0 10 111 3 107 7 0 109 7 112 0 7 0
-               117 0 0 0 118 1 7 119 0 120 0 75 0 121 1 0 119 0 122 1 6 7 0
-               123 2 0 0 0 12 124 2 6 0 0 0 125 2 6 119 0 0 126 2 6 8 0 0 127
-               2 0 128 0 0 129 0 75 0 130 2 7 0 10 0 131 3 0 0 0 132 0 133 2
-               6 0 7 0 134 3 6 0 0 132 0 135 1 6 0 0 138 1 140 6 0 141 2 6
-               142 0 142 143 1 140 6 0 144 2 140 0 0 0 145 2 0 142 142 142
-               146 2 7 0 0 10 147 2 6 0 0 0 148 2 6 0 0 0 149 2 0 0 0 0 150
-               2 0 151 0 0 152 2 6 119 0 0 153 2 140 0 6 6 154 2 0 155 142 0
-               156 1 6 8 0 157 2 6 151 0 0 158 2 6 119 0 7 159 2 0 119 0 0
-               160 0 140 0 161 1 140 0 6 162 2 140 0 0 109 163 2 140 0 0 0
-               164 2 140 0 0 0 165 2 140 0 0 10 166 2 0 142 0 142 167 2 0 10
-               0 0 168 1 169 98 6 170 1 0 88 0 171 1 169 6 6 172 1 0 0 0 173
-               1 75 8 0 174 1 75 0 0 175 1 75 6 0 176 1 75 0 0 177 2 75 0 0
-               0 178 2 75 0 6 0 179 2 0 80 80 80 180 1 181 82 75 182 1 0 84
-               80 183 2 7 0 0 0 184 2 0 7 142 7 185 1 0 10 0 186 1 7 0 0 187
-               2 7 0 0 0 188 2 0 67 0 0 189 1 190 0 109 191 1 190 0 0 192 2
-               6 0 190 0 193 1 0 0 0 194 2 0 107 0 10 113 1 0 14 0 15 1 0 0
-               51 66 2 0 10 0 14 18 1 0 84 80 183 1 0 0 0 173 1 0 88 0 171 2
-               0 78 79 80 81 2 0 0 0 10 70 2 0 0 0 10 72 2 0 128 0 0 129 1 0
-               115 0 116 1 0 7 0 114 2 0 0 0 0 150 2 0 151 0 0 152 2 0 10 0
-               0 168 1 0 119 0 122 3 0 0 0 12 10 46 2 0 19 0 14 42 2 0 10 0
-               12 41 1 0 51 0 58 1 0 34 0 39 2 0 67 0 10 69 1 0 0 0 194 0 0
-               0 118 2 0 80 80 80 180 1 0 84 80 87 1 0 84 80 85 1 0 88 0 105
-               3 0 0 0 12 0 25 3 0 0 0 14 22 23 3 0 0 0 14 27 28 3 0 0 0 12
-               7 31 2 0 0 0 37 38 1 0 10 0 186 2 0 142 0 142 167 2 0 7 142 7
-               185 2 0 142 142 142 146 2 0 67 0 0 189 3 0 0 0 132 0 133 2 0
-               0 0 132 136 1 0 0 0 137 2 0 0 0 12 139 2 0 10 0 12 16 2 0 19
-               0 14 20 2 0 0 0 12 124 2 0 119 0 0 160 2 0 155 142 0 156 1 0
-               0 12 50)))))) 
-       (QUOTE |lookupComplete|))) 
+         (|dispatchFunction| |UPOLYC-;solveLinearPolynomialEquation;LSupU;20|)
+         $))
+       (QSETREFV $ 85
+        (CONS (|dispatchFunction| |UPOLYC-;factorPolynomial;SupF;21|) $))
+       (QSETREFV $ 87 
+        (CONS
+         (|dispatchFunction| |UPOLYC-;factorSquareFreePolynomial;SupF;22|)
+         $))
+       (QSETREFV $ 105 (CONS (|dispatchFunction| |UPOLYC-;factor;SF;23|) $)))))
+     (COND
+      ((|testBitVector| |pv$| 6)
+       (PROGN
+        (QSETREFV $ 120 (CONS (|dispatchFunction| |UPOLYC-;init;S;28|) $))
+        NIL
+        (QSETREFV $ 124
+         (CONS (|dispatchFunction| |UPOLYC-;nextItem;SU;30|) $)))))
+     (COND
+      ((|testBitVector| |pv$| 3)
+       (PROGN
+        (QSETREFV $ 126
+         (CONS (|dispatchFunction| |UPOLYC-;content;SSaosS;31|) $))
+        NIL
+        (QSETREFV $ 131
+         (CONS (|dispatchFunction| |UPOLYC-;separate;2SR;33|) $)))))
+     (COND
+      ((|testBitVector| |pv$| 5)
+       (QSETREFV $ 135
+        (CONS (|dispatchFunction| |UPOLYC-;differentiate;SM2S;34|) $)))
+      ((QUOTE T)
+       (PROGN
+        (QSETREFV $ 135
+         (CONS (|dispatchFunction| |UPOLYC-;differentiate;SM2S;36|) $)))))
+     (COND
+      ((|testBitVector| |pv$| 4)
+       (PROGN
+        (QSETREFV $ 148 (CONS (|dispatchFunction| |UPOLYC-;elt;3F;40|) $))
+        (QSETREFV $ 152
+          (CONS (|dispatchFunction| |UPOLYC-;pseudoQuotient;3S;41|) $))
+        (QSETREFV $ 154 
+          (CONS (|dispatchFunction| |UPOLYC-;pseudoDivide;2SR;42|) $))
+        (QSETREFV $ 158 
+          (CONS (|dispatchFunction| |UPOLYC-;composite;FSU;43|) $))
+        (QSETREFV $ 162 
+          (CONS (|dispatchFunction| |UPOLYC-;composite;2SU;44|) $))
+        (QSETREFV $ 169 (CONS (|dispatchFunction| |UPOLYC-;elt;S2F;45|) $))
+        (QSETREFV $ 170 
+          (CONS (|dispatchFunction| |UPOLYC-;order;2SNni;46|) $)))))
+     (COND
+      ((|testBitVector| |pv$| 3)
+       (PROGN
+        (QSETREFV $ 173 
+         (CONS (|dispatchFunction| |UPOLYC-;squareFree;SF;47|) $))
+        (QSETREFV $ 175 
+         (CONS (|dispatchFunction| |UPOLYC-;squareFreePart;2S;48|) $)))))
+     (COND
+      ((|HasCategory| |#2| (QUOTE (|PolynomialFactorizationExplicit|)))
+       (PROGN
+        (QSETREFV $ 182 
+         (CONS (|dispatchFunction| |UPOLYC-;gcdPolynomial;3Sup;49|) $))
+        (QSETREFV $ 185 
+         (CONS
+          (|dispatchFunction| |UPOLYC-;squareFreePolynomial;SupF;50|)
+          $)))))
+     (COND
+      ((|testBitVector| |pv$| 2)
+       (PROGN
+        (QSETREFV $ 187 (CONS (|dispatchFunction| |UPOLYC-;elt;F2R;51|) $))
+        (QSETREFV $ 188
+         (CONS (|dispatchFunction| |UPOLYC-;euclideanSize;SNni;52|) $))
+        (QSETREFV $ 191
+         (CONS (|dispatchFunction| |UPOLYC-;divide;2SR;53|) $)))))
+     (COND
+      ((|testBitVector| |pv$| 1)
+       (QSETREFV $ 196
+        (CONS (|dispatchFunction| |UPOLYC-;integrate;2S;54|) $))))
+     $)))) 
+
+(SETF
+ (GET (QUOTE |UnivariatePolynomialCategory&|) (QUOTE |infovec|))
+ (LIST
+  (QUOTE
+    #(NIL NIL NIL NIL NIL NIL (|local| |#1|) (|local| |#2|) (|Boolean|)
+      (0 . |zero?|) (|NonNegativeInteger|) (5 . |degree|)
+      (|SingletonAsOrderedSet|) (10 . |create|) (|List| 12)
+      |UPOLYC-;variables;SL;1| |UPOLYC-;degree;SSaosNni;2|
+      (14 . |totalDegree|) |UPOLYC-;totalDegree;SLNni;3| (|List| 10)
+      |UPOLYC-;degree;SLL;4| (19 . |eval|) (|List| $) |UPOLYC-;eval;SLLS;5|
+      (26 . |elt|) |UPOLYC-;eval;SSaos2S;6| (32 . |eval|) (|List| 7)
+      |UPOLYC-;eval;SLLS;7| (39 . |elt|) (45 . |coerce|)
+      |UPOLYC-;eval;SSaosRS;8| (|Equation| 6) (50 . |lhs|)
+      (|Union| 12 (QUOTE "failed")) (55 . |mainVariable|) (60 . |rhs|)
+      (|List| 199) |UPOLYC-;eval;SLS;9| |UPOLYC-;mainVariable;SU;10|
+      (65 . |minimumDegree|) |UPOLYC-;minimumDegree;SSaosNni;11|
+      |UPOLYC-;minimumDegree;SLL;12| (70 . +) (|Mapping| 10 10)
+      (76 . |mapExponents|) |UPOLYC-;monomial;SSaosNniS;13| (82 . |One|)
+      (86 . |One|) (90 . |monomial|) |UPOLYC-;coerce;SaosS;14|
+      (|SparseUnivariatePolynomial| 7) (96 . |Zero|) 
+      (100 . |leadingCoefficient|) (105 . |monomial|) (111 . |reductum|)
+      (116 . |makeSUP|) (121 . +) |UPOLYC-;makeSUP;SSup;15| (127 . |zero?|)
+      (132 . |Zero|) (136 . |leadingCoefficient|) (141 . |degree|)
+      (146 . |reductum|) (151 . |unmakeSUP|) (156 . +)
+      |UPOLYC-;unmakeSUP;SupS;16| (|Record| (|:| |quotient| $)
+      (|:| |remainder| $)) (162 . |monicDivide|)
+      |UPOLYC-;karatsubaDivide;SNniR;17| |UPOLYC-;shiftRight;SNniS;18|
+      (168 . *) |UPOLYC-;shiftLeft;SNniS;19| (|Union| 74 (QUOTE "failed"))
+      (|List| 75) (|SparseUnivariatePolynomial| 6)
+      (|PolynomialFactorizationByRecursionUnivariate| 7 6)
+      (174 . |solveLinearPolynomialEquationByRecursion|)
+      (|Union| 79 (QUOTE "failed")) (|List| 80)
+      (|SparseUnivariatePolynomial| $)
+      (180 . |solveLinearPolynomialEquation|) (|Factored| 75)
+      (186 . |factorByRecursion|) (|Factored| 80) (191 . |factorPolynomial|)
+      (196 . |factorSquareFreeByRecursion|)
+      (201 . |factorSquareFreePolynomial|) (|Factored| $) (206 . |factor|)
+      (|Factored| 7) (211 . |unit|) (|Union| (QUOTE "nil") (QUOTE "sqfr")
+      (QUOTE "irred") (QUOTE "prime")) (|Record| (|:| |flg| 92)
+      (|:| |fctr| 7) (|:| |xpnt| 109)) (|List| 93) (216 . |factorList|)
+      (|Record| (|:| |flg| 92) (|:| |fctr| 6) (|:| |xpnt| 109)) (|List| 96)
+      (|Factored| 6) (221 . |makeFR|) (227 . |factorPolynomial|)
+      (|Mapping| 6 51) (|Factored| 51) (|FactoredFunctions2| 51 6)
+      (232 . |map|) (238 . |factor|) (243 . |Zero|) (|Vector| 7)
+      (247 . |new|) (|Integer|) (253 . |minIndex|) (258 . |coefficient|)
+      (264 . |qsetelt!|) |UPOLYC-;vectorise;SNniV;24| (271 . |elt|)
+      |UPOLYC-;unvectorise;VS;25| |UPOLYC-;retract;SR;26|
+      (|Union| 7 (QUOTE "failed")) |UPOLYC-;retractIfCan;SU;27|
+      (277 . |init|) (281 . |init|) (|Union| $ (QUOTE "failed"))
+      (285 . |nextItem|) (290 . |One|) (294 . |nextItem|) (299 . |content|)
+      (304 . |content|) (310 . |gcd|) (316 . |exquo|) (322 . =)
+      (|Record| (|:| |primePart| $) (|:| |commonPart| $)) (328 . |separate|)
+      (334 . |Zero|) (338 . *) (|Mapping| 7 7) (344 . |differentiate|)
+      (351 . *) (357 . |differentiate|) |UPOLYC-;differentiate;SMS;37|
+      |UPOLYC-;differentiate;2S;38| (364 . |differentiate|)
+      |UPOLYC-;differentiate;SSaosS;39| (|Fraction| 6) (369 . |numer|)
+      (|Fraction| $) (374 . |elt|) (380 . |denom|) (385 . /) (391 . |elt|)
+      (397 . **) (403 . |pseudoRemainder|) (409 . -) (415 . |pseudoQuotient|)
+      (|Record| (|:| |coef| 7) (|:| |quotient| $) (|:| |remainder| $)) 
+      (421 . |pseudoDivide|) (427 . |composite|) (433 . /) 
+      (|Union| 144 (QUOTE "failed")) (439 . |composite|) (445 . |ground?|)
+      (450 . |pseudoDivide|) (456 . |exquo|) (462 . |composite|)
+      (468 . |Zero|) (472 . |coerce|) (477 . **) (483 . *) (489 . +)
+      (495 . **) (501 . |elt|) (507 . |order|)
+      (|UnivariatePolynomialSquareFree| 7 6) (513 . |squareFree|)
+      (518 . |squareFree|) (523 . |squareFreePart|) (528 . |squareFreePart|)
+      (533 . |zero?|) (538 . |unitCanonical|) (543 . |content|)
+      (548 . |primitivePart|) (553 . |subResultantGcd|) (559 . *)
+      (565 . |gcdPolynomial|) (|UnivariatePolynomialSquareFree| 6 75)
+      (571 . |squareFree|) (576 . |squareFreePolynomial|) (581 . /)
+      (587 . |elt|) (593 . |euclideanSize|) (598 . |inv|) (603 . *)
+      (609 . |divide|) (|Fraction| 109) (615 . |coerce|) (620 . |inv|)
+      (625 . *) (631 . |integrate|) (|List| 198) (|Symbol|) (|Equation| $)
+      (|Union| 109 (QUOTE "failed")) (|Union| 192 (QUOTE "failed"))
+      (|OutputForm|)))
+   (QUOTE #(|vectorise| 636 |variables| 642 |unvectorise| 647 
+            |unmakeSUP| 652 |totalDegree| 657 |squareFreePolynomial| 663 
+            |squareFreePart| 668 |squareFree| 673 
+            |solveLinearPolynomialEquation| 678 |shiftRight| 684 
+            |shiftLeft| 690 |separate| 696 |retractIfCan| 702 
+            |retract| 707 |pseudoQuotient| 712 |pseudoDivide| 718 
+            |order| 724 |nextItem| 730 |monomial| 735 |minimumDegree| 742 
+            |makeSUP| 754 |mainVariable| 759 |karatsubaDivide| 764 
+            |integrate| 770 |init| 775 |gcdPolynomial| 779 
+            |factorSquareFreePolynomial| 785 |factorPolynomial| 790 
+            |factor| 795 |eval| 800 |euclideanSize| 834 |elt| 839 
+            |divide| 857 |differentiate| 863 |degree| 887 |content| 899 
+            |composite| 905 |coerce| 917))
+   (QUOTE NIL)
+   (CONS (|makeByteWordVec2| 1 (QUOTE NIL))
+    (CONS 
+     (QUOTE #())
+     (CONS
+      (QUOTE #())
+      (|makeByteWordVec2| 196 (QUOTE (1 6 8 0 9 1 6 10 0 11 0 12 0 13 1 6 
+        10 0 17 3 6 0 0 12 0 21 2 6 0 0 0 24 3 6 0 0 12 7 26 2 6 7 0 7 29 
+        1 6 0 7 30 1 32 6 0 33 1 6 34 0 35 1 32 6 0 36 1 6 10 0 40 2 10 0 
+        0 0 43 2 6 0 44 0 45 0 6 0 47 0 7 0 48 2 6 0 7 10 49 0 51 0 52 1 
+        6 7 0 53 2 51 0 7 10 54 1 6 0 0 55 1 6 51 0 56 2 51 0 0 0 57 1 51 
+        8 0 59 0 6 0 60 1 51 7 0 61 1 51 10 0 62 1 51 0 0 63 1 6 0 51 64 
+        2 6 0 0 0 65 2 6 67 0 0 68 2 6 0 0 0 71 2 76 73 74 75 77 2 0 78 
+        79 80 81 1 76 82 75 83 1 0 84 80 85 1 76 82 75 86 1 0 84 80 87 
+        1 7 88 0 89 1 90 7 0 91 1 90 94 0 95 2 98 0 6 97 99 1 7 84 80 
+        100 2 103 98 101 102 104 1 0 88 0 105 0 7 0 106 2 107 0 10 7 108 
+        1 107 109 0 110 2 6 7 0 10 111 3 107 7 0 109 7 112 2 107 7 0 109 
+        114 0 7 0 119 0 0 0 120 1 7 121 0 122 0 75 0 123 1 0 121 0 124 1 
+        6 7 0 125 2 0 0 0 12 126 2 6 0 0 0 127 2 6 121 0 0 128 2 6 8 0 0 
+        129 2 0 130 0 0 131 0 75 0 132 2 7 0 10 0 133 3 0 0 0 134 0 135 
+        2 6 0 7 0 136 3 6 0 0 134 0 137 1 6 0 0 140 1 142 6 0 143 2 6 144 
+        0 144 145 1 142 6 0 146 2 142 0 0 0 147 2 0 144 144 144 148 2 7 0 
+        0 10 149 2 6 0 0 0 150 2 6 0 0 0 151 2 0 0 0 0 152 2 0 153 0 0 154 
+        2 6 121 0 0 155 2 142 0 6 6 156 2 0 157 144 0 158 1 6 8 0 159 2 6 
+        153 0 0 160 2 6 121 0 7 161 2 0 121 0 0 162 0 142 0 163 1 142 0 6 
+        164 2 142 0 0 109 165 2 142 0 0 0 166 2 142 0 0 0 167 2 142 0 0 10 
+        168 2 0 144 0 144 169 2 0 10 0 0 170 1 171 98 6 172 1 0 88 0 173 1 
+        171 6 6 174 1 0 0 0 175 1 75 8 0 176 1 75 0 0 177 1 75 6 0 178 1 
+        75 0 0 179 2 75 0 0 0 180 2 75 0 6 0 181 2 0 80 80 80 182 1 183 82 
+        75 184 1 0 84 80 185 2 7 0 0 0 186 2 0 7 144 7 187 1 0 10 0 188 1 
+        7 0 0 189 2 7 0 0 0 190 2 0 67 0 0 191 1 192 0 109 193 1 192 0 0 
+        194 2 6 0 192 0 195 1 0 0 0 196 2 0 107 0 10 113 1 0 14 0 15 1 0 
+        0 107 115 1 0 0 51 66 2 0 10 0 14 18 1 0 84 80 185 1 0 0 0 175 1 
+        0 88 0 173 2 0 78 79 80 81 2 0 0 0 10 70 2 0 0 0 10 72 2 0 130 0 
+        0 131 1 0 117 0 118 1 0 7 0 116 2 0 0 0 0 152 2 0 153 0 0 154 2 
+        0 10 0 0 170 1 0 121 0 124 3 0 0 0 12 10 46 2 0 10 0 12 41 2 0 
+        19 0 14 42 1 0 51 0 58 1 0 34 0 39 2 0 67 0 10 69 1 0 0 0 196 
+        0 0 0 120 2 0 80 80 80 182 1 0 84 80 87 1 0 84 80 85 1 0 88 0 
+        105 3 0 0 0 14 22 23 3 0 0 0 12 0 25 3 0 0 0 12 7 31 3 0 0 0 14 
+        27 28 2 0 0 0 37 38 1 0 10 0 188 2 0 144 0 144 169 2 0 7 144 7 
+        187 2 0 144 144 144 148 2 0 67 0 0 191 3 0 0 0 134 0 135 2 0 0 
+        0 134 138 1 0 0 0 139 2 0 0 0 12 141 2 0 19 0 14 20 2 0 10 0 12 
+        16 2 0 0 0 12 126 2 0 121 0 0 162 2 0 157 144 0 158 1 0 0 12 50))))))
+   (QUOTE |lookupComplete|))) 
 
 \end{chunk}
 \section{URAGG.lsp BOOTSTRAP}
diff --git a/books/bookvol5.pamphlet b/books/bookvol5.pamphlet
index 2f3aff1..793eaa6 100644
--- a/books/bookvol5.pamphlet
+++ b/books/bookvol5.pamphlet
@@ -24828,6 +24828,7 @@ otherwise the new algebra won't be loaded by the interpreter when needed.
    (|LazyStreamAggregate| . LZSTAGG)
    (|LeftAlgebra| . LALG)
    (|LeftModule| . LMODULE)
+   (|LeftOreRing| . LORER)
    (|LeftUnitaryAttribute| . ATLUNIT)
    (|LieAlgebra| . LIECAT)
    (|LinearAggregate| . LNAGG)
diff --git a/books/bookvolbib.pamphlet b/books/bookvolbib.pamphlet
index b0fc641..d825fdd 100644
--- a/books/bookvolbib.pamphlet
+++ b/books/bookvolbib.pamphlet
@@ -4510,6 +4510,22 @@ general linear functional systems such as systems of differential or
 ($q-$)difference equations.
 \end{adjustwidth}
 
+\bibitem[Bronstein 96a]{Bro96a} Bronstein, Manuel; Petkovsek, Marko\\
+``An introduction to pseudo-linear algebra''\\
+Theoretical Computer Science V157 pp3-33 (1966)\\
+\verb|www-sop.inria.fr/cafe/Manuel.Bronstein/publications/mb_papers.html|
+%\verb|axiom-developer.org/axiom-website/papers/Bro96a.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+Pseudo-linear algebra is the study of common properties of linear
+differential and difference operators. We introduce in this paper its
+basic objects (pseudo-derivations, skew polynomials, and pseudo-linear
+operators) and describe several recent algorithms on them, which, when
+applied in the differential and difference cases, yield algorithms for
+uncoupling and solving systems of linear differential and difference
+equations in closed form.
+\end{adjustwidth}
+
 \bibitem[Bronstein xb]{Broxb} Bronstein, Manuel\\
 ``Computer Algebra Algorithms for Linear Ordinary Differential and
 Difference equations''\\
@@ -4543,23 +4559,9 @@ some fast heuristics that can produce some factorizations while using
 only linear computations.
 \end{adjustwidth}
 
-\bibitem[Bronstein xa]{Broxa} Bronstein, Manuel; Petkovsek, Marko\\
-``An introduction to pseudo-linear algebra''\\
-\verb|www-sop.inria.fr/cafe/Manuel.Bronstein/publications/mb_papers.html|
-%\verb|axiom-developer.org/axiom-website/papers/Broxa.pdf|
-
-\begin{adjustwidth}{2.5em}{0pt}
-Pseudo-linear algebra is the study of common properties of linear
-differential and difference operators. We introduce in this paper its
-basic objects (pseudo-derivations, skew polynomials, and pseudo-linear
-operators) and describe several recent algorithms on them, which, when
-applied in the differential and difference cases, yield algorithms for
-uncoupling and solving systems of linear differential and difference
-equations in closed form.
-\end{adjustwidth}
-
 \bibitem[Bronstein 90]{Bro90} Bronstein, Manuel\\
-``On Solutions of Linear Ordinary Differential Equations in their Coefficient Field''\\
+``On Solutions of Linear Ordinary Differential Equations in their 
+Coefficient Field''\\
 \verb|www-sop.inria.fr/cafe/Manuel.Bronstein/publications/mb_papers.html|
 
 \begin{adjustwidth}{2.5em}{0pt}
@@ -5096,5 +5098,41 @@ mentioned algorithms in the field of ODE's conclude this paper.
 \verb|faculty.up.edu/wootton/calc2/section7.4.pdf|
 %\verb|axiom-developer.org/axiom-website/papers/Woot14.pdf|
 
+\subsection{Ore Rings} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+This is used as a reference for the LeftOreRing category, in particular,
+the least left common multiple (lcmCoef) function.
+
+\bibitem[Delenclos 06]{DL06} Delenclos, Jonathon; Leroy, Andr\'e\\
+``Noncommutative Symmetric functions and $W$-polynomials''\\
+\verb|arxiv.org/pdf/math/0606614.pdf|
+%\verb|axiom-developer.org/axiom-website/papers/DL06.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+Let $K$, $S$, $D$ be a division ring an endomorphism and a
+$S$-derivation of $K$, respectively. In this setting we introduce
+generalized noncommutative symmetric functions and obtain Vi\'ete
+formula and decompositions of different operators. $W$-polynomials
+show up naturally, their connetions with $P$-independency. Vandermonde
+and Wronskian matrices are briefly studied. The different linear
+factorizations of $W$-polynomials are analysed. Connections between
+the existence of LLCM (least left common multiples) of monic linear
+polynomials with coefficients in a ring and the left duo property are
+established at the end of the paper.
+\end{adjustwidth}
+
+\bibitem[Abramov 05]{Abra05} Abramov, S.A.; Le, H.Q.; Li, Z.\\
+``Univariate Ore Polynomial Rings in Computer Algebra''\\
+\verb|www.mmrc.iss.ac.cn/~zmli/papers/oretools.pdf|
+%\verb|axiom-developer.org/axiom-website/papers/Abra05.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+We present some algorithms related to rings of Ore polynomials (or,
+briefly, Ore rings) and describe a computer algebra library for basic
+operations in an arbitrary Ore ring. The library can be used as a
+basis for various algorithms in Ore rings, in particular, in
+differential, shift, and $q$-shift rings.
+\end{adjustwidth}
+
 \end{thebibliography}
 \end{document}
diff --git a/changelog b/changelog
index 05799e3..c16d78a 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,15 @@
+20140708 tpd src/axiom-website/patches.html 20140708.01.tpd.patch
+20140708 tpd books/bookvolbib add DL06, Bro96a to document LeftOreRing
+20140708 tpd src/share/algebra/users.daase/index.kaf add LeftOreRing
+20140708 tpd src/share/algebra/operation.daase add LeftOreRing
+20140708 tpd src/share/algebra/interp.daase add LeftOreRing
+20140708 tpd src/share/algebra/dependents.daase/index.kaf add LeftOreRing
+20140708 tpd src/share/algebra/compress.daase add LeftOreRing
+20140708 tpd src/share/algebra/category.daase add LeftOreRing
+20140708 tpd src/share/algebra/browse.daase add LeftOreRing
+20140708 tpd src/algebra/Makefile add LeftOreRing
+20140708 tpd books/bookvol5 add LeftOreRing
+20140708 tpd books/bookvol10.2 add LeftOreRing
 20140707 tpd src/axiom-website/patches.html 20140707.02.tpd.patch
 20140707 tpd books/bookvolbib add Mohr98, Jeff99
 20140707 tpd src/axiom-website/patches.html 20140707.01.tpd.patch
diff --git a/patch b/patch
index 2fa739f..657fe66 100644
--- a/patch
+++ b/patch
@@ -1,3 +1,11 @@
-books/bookvolbib add Mohr98, Jeff99
+src/algebra/Makefile add LeftOreRing
+
+Add LeftOreRing
+Extending GcdDomain
+adding DL06, Bro96a to bibliography to document LeftOreRing
+update databases
+update BOOTSTRAP for GCDDOM and UPOLYC
+add unvectorise to UPOLYC
+
+
 
-More web searching for Axiom related references.
diff --git a/src/algebra/Makefile.pamphlet b/src/algebra/Makefile.pamphlet
index ce831f5..ed668f4 100644
--- a/src/algebra/Makefile.pamphlet
+++ b/src/algebra/Makefile.pamphlet
@@ -395,7 +395,7 @@ digraph pic {
 Save this in a file, say bsd.dot.
 To create the correct postscript file use the command:
 \begin{verbatim}
-   dot -Tps bsd.dot >ps/v103basicstochasticdifferential.ps
+   dot -Teps bsd.dot >ps/v103basicstochasticdifferential.eps
 \end{verbatim}
 Notice that the output goes into a ps subdirectory. It is named
 with the v103 prefix, meaning it is intended for volume 10.3.
@@ -1720,7 +1720,8 @@ LAYER3=\
   ${OUT}/DIFEXT.o   ${OUT}/DIFEXT-.o ${OUT}/DLAGG.o    ${OUT}/DSTRCAT.o  \
   ${OUT}/ELAGG.o    \
   ${OUT}/ELAGG-.o   ${OUT}/ES1.o     ${OUT}/ES2.o      ${OUT}/GRMOD.o    \
-  ${OUT}/GRMOD-.o   ${OUT}/HYPCAT.o  ${OUT}/HYPCAT-.o  ${OUT}/MKCHSET.o  \
+  ${OUT}/GRMOD-.o   ${OUT}/HYPCAT.o  ${OUT}/HYPCAT-.o  ${OUT}/LORER.o    \
+  ${OUT}/MKCHSET.o  \
   ${OUT}/MODRING.o  ${OUT}/MODULE.o  ${OUT}/MODULE-.o  ${OUT}/NASRING.o  \
   ${OUT}/NASRING-.o ${OUT}/OAMON.o   ${OUT}/SORTPAK.o  ${OUT}/ZMOD.o \
   layer3done
@@ -1877,6 +1878,12 @@ LAYER3=\
 /*"HYPCAT-" -> "LMODULE"*/
 "HYPCAT-" -> "ELEMFUN"
 
+"LORER" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LORER"]
+/*"LORER" -> {"ENTIRER"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"LORER" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"LORER" -> {"MONOID"; "LMODULE"; "RMODULE"}*/
+"LORER" -> "BMODULE"
+
 "MKCHSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MKCHSET"]
 "MKCHSET" -> "CACHSET"
 /*"MKCHSET" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 2b91091..d21aa36 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4532,6 +4532,8 @@ books/bookvolbib add references Meij91, Mohr94
 books/bookvolbib add many new references
 <a href="patches/20140707.02.tpd.patch">20140707.02.tpd.patch</a>
 books/bookvolbib add Mohr98, Jeff99
+<a href="patches/20140708.01.tpd.patch">20140708.01.tpd.patch</a>
+src/algebra/Makefile add LeftOreRing
  </body>
 </html>
 
diff --git a/src/share/algebra/browse.daase b/src/share/algebra/browse.daase
index 55078ec..3fa727e 100644
--- a/src/share/algebra/browse.daase
+++ b/src/share/algebra/browse.daase
@@ -1,12 +1,12 @@
 
-(2388990 . 3575754975)       
+(2394220 . 3613822956)       
 (-18 A S) 
 ((|constructor| (NIL "One-dimensional-array aggregates serves as models for one-dimensional arrays. Categorically, these aggregates are finite linear aggregates with the \\spadatt{shallowlyMutable} property, that is, any component of the array may be changed without affecting the identity of the overall array. Array data structures are typically represented by a fixed area in storage and cannot efficiently grow or shrink on demand as can list structures (see however \\spadtype{FlexibleArray} for a data structure which is a cross between a list and an array). Iteration over, and access to, elements of arrays is extremely fast (and often can be optimized to open-code). Insertion and deletion however is generally slow since an entirely new data structure must be created for the result."))) 
 NIL 
 NIL 
 (-19 S) 
 ((|constructor| (NIL "One-dimensional-array aggregates serves as models for one-dimensional arrays. Categorically, these aggregates are finite linear aggregates with the \\spadatt{shallowlyMutable} property, that is, any component of the array may be changed without affecting the identity of the overall array. Array data structures are typically represented by a fixed area in storage and cannot efficiently grow or shrink on demand as can list structures (see however \\spadtype{FlexibleArray} for a data structure which is a cross between a list and an array). Iteration over, and access to, elements of arrays is extremely fast (and often can be optimized to open-code). Insertion and deletion however is generally slow since an entirely new data structure must be created for the result."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
 (-20 S) 
 ((|constructor| (NIL "The class of abelian groups, \\spadignore{i.e.} additive monoids where each element has an additive inverse. \\blankline Axioms\\br \\tab{5}\\spad{-(-x) = x}\\br \\tab{5}\\spad{x+(-x) = 0}")) (* (($ (|Integer|) $) "\\spad{n*x} is the product of \\spad{x} by the integer \\spad{n.}")) (- (($ $ $) "\\spad{x-y} is the difference of \\spad{x} and \\spad{y} \\spadignore{i.e.} \\spad{x + (-y)}.") (($ $) "\\spad{-x} is the additive inverse of \\spad{x.}"))) 
@@ -38,7 +38,7 @@ NIL
 NIL 
 (-27) 
 ((|constructor| (NIL "Model for algebraically closed fields.")) (|zerosOf| (((|List| $) (|SparseUnivariatePolynomial| $) (|Symbol|)) "\\spad{zerosOf(p, \\spad{y)}} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. \\indented{1}{The yi's are expressed in radicals if possible, and otherwise} \\indented{1}{as implicit algebraic quantities} \\indented{1}{which display as \\spad{'yi}.} \\indented{1}{The returned symbols y1,...,yn are bound in the interpreter} \\indented{1}{to respective root values.} \\blankline \\spad{X} \\spad{a:SparseUnivariatePolynomial(Integer):=-3*x^3+2*x+13} \\spad{X} zerosOf(a,x)") (((|List| $) (|SparseUnivariatePolynomial| $)) "\\spad{zerosOf(p)} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. \\indented{1}{The yi's are expressed in radicals if possible, and otherwise} \\indented{1}{as implicit algebraic quantities.} \\indented{1}{The returned symbols y1,...,yn are bound in the interpreter} \\indented{1}{to respective root values.} \\blankline \\spad{X} \\spad{a:SparseUnivariatePolynomial(Integer):=-3*x^3+2*x+13} \\spad{X} zerosOf(a)") (((|List| $) (|Polynomial| $)) "\\spad{zerosOf(p)} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. \\indented{1}{The yi's are expressed in radicals if possible.} \\indented{1}{Otherwise they are implicit algebraic quantities.} \\indented{1}{The returned symbols y1,...,yn are bound in the interpreter} \\indented{1}{to respective root values.} \\indented{1}{Error: if \\spad{p} has more than one variable \\spad{y.}} \\blankline \\spad{X} \\spad{a:Polynomial(Integer):=-3*x^2+2*x-13} \\spad{X} zerosOf(a)")) (|zeroOf| (($ (|SparseUnivariatePolynomial| $) (|Symbol|)) "\\spad{zeroOf(p, \\spad{y)}} returns \\spad{y} such that \\spad{p(y) = 0}; \\indented{1}{if possible, \\spad{y} is expressed in terms of radicals.} \\indented{1}{Otherwise it is an implicit algebraic quantity which} \\indented{1}{displays as \\spad{'y}.} \\blankline \\spad{X} \\spad{a:SparseUnivariatePolynomial(Integer):=-3*x^3+2*x+13} \\spad{X} zeroOf(a,x)") (($ (|SparseUnivariatePolynomial| $)) "\\spad{zeroOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}; \\indented{1}{if possible, \\spad{y} is expressed in terms of radicals.} \\indented{1}{Otherwise it is an implicit algebraic quantity.} \\blankline \\spad{X} \\spad{a:SparseUnivariatePolynomial(Integer):=-3*x^3+2*x+13} \\spad{X} zeroOf(a)") (($ (|Polynomial| $)) "\\spad{zeroOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. \\indented{1}{If possible, \\spad{y} is expressed in terms of radicals.} \\indented{1}{Otherwise it is an implicit algebraic quantity.} \\indented{1}{Error: if \\spad{p} has more than one variable \\spad{y.}} \\blankline \\spad{X} \\spad{a:Polynomial(Integer):=-3*x^2+2*x-13} \\spad{X} zeroOf(a)")) (|rootsOf| (((|List| $) (|SparseUnivariatePolynomial| $) (|Symbol|)) "\\spad{rootsOf(p, \\spad{y)}} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}; \\indented{1}{The returned roots display as \\spad{'y1},...,\\spad{'yn}.} \\indented{1}{Note that the returned symbols y1,...,yn are bound in the interpreter} \\indented{1}{to respective root values.} \\blankline \\spad{X} \\spad{a:SparseUnivariatePolynomial(Integer):=-3*x^3+2*x+13} \\spad{X} rootsOf(a,x)") (((|List| $) (|SparseUnivariatePolynomial| $)) "\\spad{rootsOf(p)} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. \\indented{1}{Note that the returned symbols y1,...,yn are bound in the interpreter} \\indented{1}{to respective root values.} \\blankline \\spad{X} \\spad{a:SparseUnivariatePolynomial(Integer):=-3*x^3+2*x+13} \\spad{X} rootsOf(a)") (((|List| $) (|Polynomial| $)) "\\spad{rootsOf(p)} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. \\indented{1}{Note that the returned symbols y1,...,yn are bound in the} \\indented{1}{interpreter to respective root values.} \\indented{1}{Error: if \\spad{p} has more than one variable \\spad{y.}} \\blankline \\spad{X} \\spad{a:Polynomial(Integer):=-3*x^3+2*x+13} \\spad{X} rootsOf(a)")) (|rootOf| (($ (|SparseUnivariatePolynomial| $) (|Symbol|)) "\\spad{rootOf(p, \\spad{y)}} returns \\spad{y} such that \\spad{p(y) = 0}. \\indented{1}{The object returned displays as \\spad{'y}.} \\blankline \\spad{X} \\spad{a:SparseUnivariatePolynomial(Integer):=-3*x^3+2*x+13} \\spad{X} rootOf(a,x)") (($ (|SparseUnivariatePolynomial| $)) "\\spad{rootOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. \\blankline \\spad{X} \\spad{a:SparseUnivariatePolynomial(Integer):=-3*x^3+2*x+13} \\spad{X} rootOf(a)") (($ (|Polynomial| $)) "\\spad{rootOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. \\indented{1}{Error: if \\spad{p} has more than one variable \\spad{y.}} \\blankline \\spad{X} \\spad{a:Polynomial(Integer):=-3*x^3+2*x+13} \\spad{X} rootOf(a)"))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
 (-28 S R) 
 ((|constructor| (NIL "Model for algebraically closed function spaces.")) (|zerosOf| (((|List| $) $ (|Symbol|)) "\\spad{zerosOf(p, \\spad{y)}} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. The yi's are expressed in radicals if possible, and otherwise as implicit algebraic quantities which display as \\spad{'yi}. The returned symbols y1,...,yn are bound in the interpreter to respective root values.") (((|List| $) $) "\\spad{zerosOf(p)} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. The yi's are expressed in radicals if possible. The returned symbols y1,...,yn are bound in the interpreter to respective root values. Error: if \\spad{p} has more than one variable.")) (|zeroOf| (($ $ (|Symbol|)) "\\spad{zeroOf(p, \\spad{y)}} returns \\spad{y} such that \\spad{p(y) = 0}. The value \\spad{y} is expressed in terms of radicals if possible,and otherwise as an implicit algebraic quantity which displays as \\spad{'y}.") (($ $) "\\spad{zeroOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. The value \\spad{y} is expressed in terms of radicals if possible,and otherwise as an implicit algebraic quantity. Error: if \\spad{p} has more than one variable.")) (|rootsOf| (((|List| $) $ (|Symbol|)) "\\spad{rootsOf(p, \\spad{y)}} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}; The returned roots display as \\spad{'y1},...,\\spad{'yn}. Note that the returned symbols y1,...,yn are bound in the interpreter to respective root values.") (((|List| $) $) "\\spad{rootsOf(p, \\spad{y)}} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}; Note that the returned symbols y1,...,yn are bound in the interpreter to respective root values. Error: if \\spad{p} has more than one variable \\spad{y.}")) (|rootOf| (($ $ (|Symbol|)) "\\spad{rootOf(p,y)} returns \\spad{y} such that \\spad{p(y) = 0}. The object returned displays as \\spad{'y}.") (($ $) "\\spad{rootOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. Error: if \\spad{p} has more than one variable \\spad{y.}"))) 
@@ -46,7 +46,7 @@ NIL
 NIL 
 (-29 R) 
 ((|constructor| (NIL "Model for algebraically closed function spaces.")) (|zerosOf| (((|List| $) $ (|Symbol|)) "\\spad{zerosOf(p, \\spad{y)}} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. The yi's are expressed in radicals if possible, and otherwise as implicit algebraic quantities which display as \\spad{'yi}. The returned symbols y1,...,yn are bound in the interpreter to respective root values.") (((|List| $) $) "\\spad{zerosOf(p)} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}. The yi's are expressed in radicals if possible. The returned symbols y1,...,yn are bound in the interpreter to respective root values. Error: if \\spad{p} has more than one variable.")) (|zeroOf| (($ $ (|Symbol|)) "\\spad{zeroOf(p, \\spad{y)}} returns \\spad{y} such that \\spad{p(y) = 0}. The value \\spad{y} is expressed in terms of radicals if possible,and otherwise as an implicit algebraic quantity which displays as \\spad{'y}.") (($ $) "\\spad{zeroOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. The value \\spad{y} is expressed in terms of radicals if possible,and otherwise as an implicit algebraic quantity. Error: if \\spad{p} has more than one variable.")) (|rootsOf| (((|List| $) $ (|Symbol|)) "\\spad{rootsOf(p, \\spad{y)}} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}; The returned roots display as \\spad{'y1},...,\\spad{'yn}. Note that the returned symbols y1,...,yn are bound in the interpreter to respective root values.") (((|List| $) $) "\\spad{rootsOf(p, \\spad{y)}} returns \\spad{[y1,...,yn]} such that \\spad{p(yi) = 0}; Note that the returned symbols y1,...,yn are bound in the interpreter to respective root values. Error: if \\spad{p} has more than one variable \\spad{y.}")) (|rootOf| (($ $ (|Symbol|)) "\\spad{rootOf(p,y)} returns \\spad{y} such that \\spad{p(y) = 0}. The object returned displays as \\spad{'y}.") (($ $) "\\spad{rootOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. Error: if \\spad{p} has more than one variable \\spad{y.}"))) 
-((-4599 . T) (-4597 . T) (-4596 . T) ((-4604 "*") . T) (-4595 . T) (-4600 . T) (-4594 . T) (-3389 . T)) 
+((-4622 . T) (-4620 . T) (-4619 . T) ((-4627 "*") . T) (-4618 . T) (-4623 . T) (-4617 . T) (-2623 . T)) 
 NIL 
 (-30) 
 ((|constructor| (NIL "Plot a NON-SINGULAR plane algebraic curve p(x,y) = 0.")) (|refine| (($ $ (|DoubleFloat|)) "\\indented{1}{refine(p,x) is not documented} \\blankline \\spad{X} sketch:=makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT \\spad{X} refined:=refine(sketch,0.1)")) (|makeSketch| (($ (|Polynomial| (|Integer|)) (|Symbol|) (|Symbol|) (|Segment| (|Fraction| (|Integer|))) (|Segment| (|Fraction| (|Integer|)))) "\\indented{1}{makeSketch(p,x,y,a..b,c..d) creates an ACPLOT of the} \\indented{1}{curve \\spad{p = 0} in the region a \\spad{<=} \\spad{x} \\spad{<=} \\spad{b,} \\spad{c} \\spad{<=} \\spad{y} \\spad{<=} \\spad{d.}} \\indented{1}{More specifically, 'makeSketch' plots a non-singular algebraic curve} \\indented{1}{\\spad{p = 0} in an rectangular region xMin \\spad{<=} \\spad{x} \\spad{<=} xMax,} \\indented{1}{yMin \\spad{<=} \\spad{y} \\spad{<=} yMax. The user inputs} \\indented{1}{\\spad{makeSketch(p,x,y,xMin..xMax,yMin..yMax)}.} \\indented{1}{Here \\spad{p} is a polynomial in the variables \\spad{x} and \\spad{y} with} \\indented{1}{integer coefficients \\spad{(p} belongs to the domain} \\indented{1}{\\spad{Polynomial Integer}). The case} \\indented{1}{where \\spad{p} is a polynomial in only one of the variables is} \\indented{1}{allowed.\\space{2}The variables \\spad{x} and \\spad{y} are input to specify the} \\indented{1}{the coordinate axes.\\space{2}The horizontal axis is the x-axis and} \\indented{1}{the vertical axis is the y-axis.\\space{2}The rational numbers} \\indented{1}{xMin,...,yMax specify the boundaries of the region in} \\indented{1}{which the curve is to be plotted.} \\blankline \\spad{X} makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT"))) 
@@ -68,14 +68,14 @@ NIL
 ((|constructor| (NIL "The following is all the categories and domains related to projective space and part of the PAFF package"))) 
 NIL 
 NIL 
-(-35 -3465 K) 
+(-35 -3832 K) 
 ((|constructor| (NIL "The following is all the categories and domains related to projective space and part of the PAFF package"))) 
 NIL 
 NIL 
-(-36 R -3313) 
+(-36 R -3958) 
 ((|constructor| (NIL "This package provides algebraic functions over an integral domain.")) (|iroot| ((|#2| |#1| (|Integer|)) "\\spad{iroot(p, \\spad{n)}} should be a non-exported function.")) (|definingPolynomial| ((|#2| |#2|) "\\spad{definingPolynomial(f)} returns the defining polynomial of \\spad{f} as an element of \\spad{F}. Error: if \\spad{f} is not a kernel.")) (|minPoly| (((|SparseUnivariatePolynomial| |#2|) (|Kernel| |#2|)) "\\spad{minPoly(k)} returns the defining polynomial of \\spad{k}.")) (** ((|#2| |#2| (|Fraction| (|Integer|))) "\\spad{x \\spad{**} \\spad{q}} is \\spad{x} raised to the rational power \\spad{q}.")) (|droot| (((|OutputForm|) (|List| |#2|)) "\\spad{droot(l)} should be a non-exported function.")) (|inrootof| ((|#2| (|SparseUnivariatePolynomial| |#2|) |#2|) "\\spad{inrootof(p, \\spad{x)}} should be a non-exported function.")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} is \\spad{true} if \\spad{op} is an algebraic operator, that is, an \\spad{n}th root or implicit algebraic operator.")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns a copy of \\spad{op} with the domain-dependent properties appropriate for \\spad{F}. Error: if \\spad{op} is not an algebraic operator, that is, an \\spad{n}th root or implicit algebraic operator.")) (|rootOf| ((|#2| (|SparseUnivariatePolynomial| |#2|) (|Symbol|)) "\\spad{rootOf(p, \\spad{y)}} returns \\spad{y} such that \\spad{p(y) = 0}. The object returned displays as \\spad{'y}."))) 
 NIL 
-((|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572))))) 
+((|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592))))) 
 (-37 K) 
 ((|constructor| (NIL "The following is all the categories and domains related to projective space and part of the PAFF package")) (|pointValue| (((|List| |#1|) $) "\\spad{pointValue returns} the coordinates of the point or of the point of origin that represent an infinitly close point")) (|setelt| ((|#1| $ (|Integer|) |#1|) "\\spad{setelt sets} the value of a specified coordinates")) (|elt| ((|#1| $ (|Integer|)) "\\spad{elt returns} the value of a specified coordinates")) (|list| (((|List| |#1|) $) "\\spad{list returns} the list of the coordinates")) (|rational?| (((|Boolean|) $) "\\spad{rational?(p)} test if the point is rational according to the characteristic of the ground field.") (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{rational?(p,n)} test if the point is rational according to \\spad{n.}")) (|removeConjugate| (((|List| $) (|List| $)) "\\spad{removeConjugate(lp)} returns removeConjugate(lp,n) where \\spad{n} is the characteristic of the ground field.") (((|List| $) (|List| $) (|NonNegativeInteger|)) "\\spad{removeConjugate(lp,n)} returns a list of points such that no points in the list is the conjugate (according to \\spad{n)} of another point.")) (|conjugate| (($ $) "\\spad{conjugate(p)} returns conjugate(p,n) where \\spad{n} is the characteristic of the ground field.") (($ $ (|NonNegativeInteger|)) "\\spad{conjugate(p,n)} returns p**n, that is all the coordinates of \\spad{p} to the power of \\spad{n}")) (|orbit| (((|List| $) $ (|NonNegativeInteger|)) "\\spad{orbit(p,n)} returns the orbit of the point \\spad{p} according to \\spad{n,} that is orbit(p,n) = \\spad{\\{} \\spad{p,} p**n, p**(n**2), p**(n**3), ..... \\spad{\\}}") (((|List| $) $) "\\spad{orbit(p)} returns the orbit of the point \\spad{p} according to the characteristic of \\spad{K,} that is, for \\spad{q=} char \\spad{K,} orbit(p) = \\spad{\\{} \\spad{p,} p**q, p**(q**2), p**(q**3), ..... \\spad{\\}}")) (|coerce| (($ (|List| |#1|)) "\\spad{coerce a} list of \\spad{K} to a affine point.")) (|affinePoint| (($ (|List| |#1|)) "\\spad{affinePoint creates} a affine point from a list"))) 
 NIL 
@@ -83,10 +83,10 @@ NIL
 (-38 S) 
 ((|constructor| (NIL "The notion of aggregate serves to model any data structure aggregate, designating any collection of objects, with heterogenous or homogeneous members, with a finite or infinite number of members, explicitly or implicitly represented. An aggregate can in principle represent everything from a string of characters to abstract sets such as \"the set of \\spad{x} satisfying relation r(x)\" An attribute \"finiteAggregate\" is used to assert that a domain has a finite number of elements.")) (|#| (((|NonNegativeInteger|) $) "\\spad{# u} returns the number of items in u.")) (|sample| (($) "\\spad{sample yields} a value of type \\%")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{size?(u,n)} tests if \\spad{u} has exactly \\spad{n} elements.")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{more?(u,n)} tests if \\spad{u} has greater than \\spad{n} elements.")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{less?(u,n)} tests if \\spad{u} has less than \\spad{n} elements.")) (|empty?| (((|Boolean|) $) "\\spad{empty?(u)} tests if \\spad{u} has 0 elements.")) (|empty| (($) "\\spad{empty()}$D creates an aggregate of type \\spad{D} with 0 elements. Note that The \\spad{$D} can be dropped if understood by context, for example \\axiom{u: \\spad{D} \\spad{:=} empty()}.")) (|copy| (($ $) "\\spad{copy(u)} returns a top-level (non-recursive) copy of u. Note that for collections, \\axiom{copy(u) \\spad{==} \\spad{[x} for \\spad{x} in u]}.")) (|eq?| (((|Boolean|) $ $) "\\spad{eq?(u,v)} tests if \\spad{u} and \\spad{v} are same objects."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4602))) 
+((|HasAttribute| |#1| (QUOTE -4625))) 
 (-39) 
 ((|constructor| (NIL "The notion of aggregate serves to model any data structure aggregate, designating any collection of objects, with heterogenous or homogeneous members, with a finite or infinite number of members, explicitly or implicitly represented. An aggregate can in principle represent everything from a string of characters to abstract sets such as \"the set of \\spad{x} satisfying relation r(x)\" An attribute \"finiteAggregate\" is used to assert that a domain has a finite number of elements.")) (|#| (((|NonNegativeInteger|) $) "\\spad{# u} returns the number of items in u.")) (|sample| (($) "\\spad{sample yields} a value of type \\%")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{size?(u,n)} tests if \\spad{u} has exactly \\spad{n} elements.")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{more?(u,n)} tests if \\spad{u} has greater than \\spad{n} elements.")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{less?(u,n)} tests if \\spad{u} has less than \\spad{n} elements.")) (|empty?| (((|Boolean|) $) "\\spad{empty?(u)} tests if \\spad{u} has 0 elements.")) (|empty| (($) "\\spad{empty()}$D creates an aggregate of type \\spad{D} with 0 elements. Note that The \\spad{$D} can be dropped if understood by context, for example \\axiom{u: \\spad{D} \\spad{:=} empty()}.")) (|copy| (($ $) "\\spad{copy(u)} returns a top-level (non-recursive) copy of u. Note that for collections, \\axiom{copy(u) \\spad{==} \\spad{[x} for \\spad{x} in u]}.")) (|eq?| (((|Boolean|) $ $) "\\spad{eq?(u,v)} tests if \\spad{u} and \\spad{v} are same objects."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
 (-40) 
 ((|constructor| (NIL "Category for the inverse hyperbolic trigonometric functions.")) (|atanh| (($ $) "\\spad{atanh(x)} returns the hyperbolic arc-tangent of \\spad{x.}")) (|asinh| (($ $) "\\spad{asinh(x)} returns the hyperbolic arc-sine of \\spad{x.}")) (|asech| (($ $) "\\spad{asech(x)} returns the hyperbolic arc-secant of \\spad{x.}")) (|acsch| (($ $) "\\spad{acsch(x)} returns the hyperbolic arc-cosecant of \\spad{x.}")) (|acoth| (($ $) "\\spad{acoth(x)} returns the hyperbolic arc-cotangent of \\spad{x.}")) (|acosh| (($ $) "\\spad{acosh(x)} returns the hyperbolic arc-cosine of \\spad{x.}"))) 
@@ -94,7 +94,7 @@ NIL
 NIL 
 (-41 |Key| |Entry|) 
 ((|constructor| (NIL "An association list is a list of key entry pairs which may be viewed as a table. It is a poor mans version of a table: searching for a key is a linear operation.")) (|assoc| (((|Union| (|Record| (|:| |key| |#1|) (|:| |entry| |#2|)) "failed") |#1| $) "\\spad{assoc(k,u)} returns the element \\spad{x} in association list \\spad{u} stored with key \\spad{k,} or \"failed\" if \\spad{u} has no key \\spad{k.}"))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
 (-42 S R) 
 ((|constructor| (NIL "The category of associative algebras (modules which are themselves rings). \\blankline Axioms\\br \\tab{5}\\spad{(b+c)::% = (b::\\%) + (c::\\%)}\\br \\tab{5}\\spad{(b*c)::% = (b::\\%) * (c::\\%)}\\br \\tab{5}\\spad{(1::R)::% = 1::%}\\br \\tab{5}\\spad{b*x = (b::\\%)*x}\\br \\tab{5}\\spad{r*(a*b) = (r*a)*b = a*(r*b)}")) (|coerce| (($ |#2|) "\\spad{coerce(r)} maps the ring element \\spad{r} to a member of the algebra."))) 
@@ -102,20 +102,20 @@ NIL
 NIL 
 (-43 R) 
 ((|constructor| (NIL "The category of associative algebras (modules which are themselves rings). \\blankline Axioms\\br \\tab{5}\\spad{(b+c)::% = (b::\\%) + (c::\\%)}\\br \\tab{5}\\spad{(b*c)::% = (b::\\%) * (c::\\%)}\\br \\tab{5}\\spad{(1::R)::% = 1::%}\\br \\tab{5}\\spad{b*x = (b::\\%)*x}\\br \\tab{5}\\spad{r*(a*b) = (r*a)*b = a*(r*b)}")) (|coerce| (($ |#1|) "\\spad{coerce(r)} maps the ring element \\spad{r} to a member of the algebra."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
 (-44 UP) 
 ((|constructor| (NIL "Factorization of univariate polynomials with coefficients in \\spadtype{AlgebraicNumber}.")) (|doublyTransitive?| (((|Boolean|) |#1|) "\\spad{doublyTransitive?(p)} is \\spad{true} if \\spad{p} is irreducible over over the field \\spad{K} generated by its coefficients, and if \\spad{p(X) / \\spad{(X} - a)} is irreducible over \\spad{K(a)} where \\spad{p(a) = 0}.")) (|split| (((|Factored| |#1|) |#1|) "\\spad{split(p)} returns a prime factorisation of \\spad{p} over its splitting field.")) (|factor| (((|Factored| |#1|) |#1|) "\\spad{factor(p)} returns a prime factorisation of \\spad{p} over the field generated by its coefficients.") (((|Factored| |#1|) |#1| (|List| (|AlgebraicNumber|))) "\\spad{factor(p, [a1,...,an])} returns a prime factorisation of \\spad{p} over the field generated by its coefficients and a1,...,an."))) 
 NIL 
 NIL 
-(-45 -3313 UP UPUP -3195) 
+(-45 -3958 UP UPUP -1704) 
 ((|constructor| (NIL "Function field defined by f(x, \\spad{y)} = 0.")) (|knownInfBasis| (((|Void|) (|NonNegativeInteger|)) "\\spad{knownInfBasis(n)} is not documented"))) 
-((-4595 |has| (-413 |#2|) (-368)) (-4600 |has| (-413 |#2|) (-368)) (-4594 |has| (-413 |#2|) (-368)) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-413 |#2|) (QUOTE (-149))) (|HasCategory| (-413 |#2|) (QUOTE (-151))) (|HasCategory| (-413 |#2|) (QUOTE (-353))) (|HasCategory| (-413 |#2|) (QUOTE (-368))) (-1841 (|HasCategory| (-413 |#2|) (QUOTE (-368))) (|HasCategory| (-413 |#2|) (QUOTE (-353)))) (|HasCategory| (-413 |#2|) (QUOTE (-374))) (|HasCategory| (-413 |#2|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| (-413 |#2|) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-413 |#2|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-374))) (-1841 (|HasCategory| (-413 |#2|) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (-12 (|HasCategory| (-413 |#2|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (-1841 (-12 (|HasCategory| (-413 |#2|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (-12 (|HasCategory| (-413 |#2|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-413 |#2|) (QUOTE (-353))))) (-12 (|HasCategory| (-413 |#2|) (QUOTE (-227))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (-1841 (-12 (|HasCategory| (-413 |#2|) (QUOTE (-227))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (|HasCategory| (-413 |#2|) (QUOTE (-353))))) 
-(-46 R -3313) 
+((-4618 |has| (-433 |#2|) (-388)) (-4623 |has| (-433 |#2|) (-388)) (-4617 |has| (-433 |#2|) (-388)) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-433 |#2|) (QUOTE (-169))) (|HasCategory| (-433 |#2|) (QUOTE (-171))) (|HasCategory| (-433 |#2|) (QUOTE (-373))) (|HasCategory| (-433 |#2|) (QUOTE (-388))) (-3836 (|HasCategory| (-433 |#2|) (QUOTE (-388))) (|HasCategory| (-433 |#2|) (QUOTE (-373)))) (|HasCategory| (-433 |#2|) (QUOTE (-394))) (|HasCategory| (-433 |#2|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| (-433 |#2|) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-433 |#2|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-394))) (-3836 (|HasCategory| (-433 |#2|) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (-12 (|HasCategory| (-433 |#2|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (-3836 (-12 (|HasCategory| (-433 |#2|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (-12 (|HasCategory| (-433 |#2|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-433 |#2|) (QUOTE (-373))))) (-12 (|HasCategory| (-433 |#2|) (QUOTE (-247))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (-3836 (-12 (|HasCategory| (-433 |#2|) (QUOTE (-247))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (|HasCategory| (-433 |#2|) (QUOTE (-373))))) 
+(-46 R -3958) 
 ((|constructor| (NIL "AlgebraicManipulations provides functions to simplify and expand expressions involving algebraic operators.")) (|rootKerSimp| ((|#2| (|BasicOperator|) |#2| (|NonNegativeInteger|)) "\\spad{rootKerSimp(op,f,n)} should be local but conditional.")) (|rootSimp| ((|#2| |#2|) "\\spad{rootSimp(f)} transforms every radical of the form \\spad{(a * b**(q*n+r))**(1/n)} appearing in \\spad{f} into \\spad{b**q * (a * b**r)**(1/n)}. This transformation is not in general valid for all complex numbers \\spad{b.}")) (|rootProduct| ((|#2| |#2|) "\\spad{rootProduct(f)} combines every product of the form \\spad{(a**(1/n))**m * (a**(1/s))**t} into a single power of a root of \\spad{a}, and transforms every radical power of the form \\spad{(a**(1/n))**m} into a simpler form.")) (|rootPower| ((|#2| |#2|) "\\spad{rootPower(f)} transforms every radical power of the form \\spad{(a**(1/n))**m} into a simpler form if \\spad{m} and \\spad{n} have a common factor.")) (|ratPoly| (((|SparseUnivariatePolynomial| |#2|) |#2|) "\\spad{ratPoly(f)} returns a polynomial \\spad{p} such that \\spad{p} has no algebraic coefficients, and \\spad{p(f) = 0}.")) (|ratDenom| ((|#2| |#2| (|List| (|Kernel| |#2|))) "\\spad{ratDenom(f, [a1,...,an])} removes the ai's which are algebraic from the denominators in \\spad{f.}") ((|#2| |#2| (|List| |#2|)) "\\spad{ratDenom(f, [a1,...,an])} removes the ai's which are algebraic kernels from the denominators in \\spad{f.}") ((|#2| |#2| |#2|) "\\spad{ratDenom(f, a)} removes \\spad{a} from the denominators in \\spad{f} if \\spad{a} is an algebraic kernel.") ((|#2| |#2|) "\\spad{ratDenom(f)} rationalizes the denominators appearing in \\spad{f} by moving all the algebraic quantities into the numerators.")) (|rootSplit| ((|#2| |#2|) "\\spad{rootSplit(f)} transforms every radical of the form \\spad{(a/b)**(1/n)} appearing in \\spad{f} into \\spad{a**(1/n) / b**(1/n)}. This transformation is not in general valid for all complex numbers \\spad{a} and \\spad{b.}")) (|coerce| (($ (|SparseMultivariatePolynomial| |#1| (|Kernel| $))) "\\spad{coerce(x)} \\undocumented")) (|denom| (((|SparseMultivariatePolynomial| |#1| (|Kernel| $)) $) "\\spad{denom(x)} \\undocumented")) (|numer| (((|SparseMultivariatePolynomial| |#1| (|Kernel| $)) $) "\\spad{numer(x)} \\undocumented"))) 
 NIL 
-((-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (LIST (QUOTE -436) (|devaluate| |#1|))))) 
+((-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (LIST (QUOTE -456) (|devaluate| |#1|))))) 
 (-47 OV E P) 
 ((|constructor| (NIL "This package factors multivariate polynomials over the domain of \\spadtype{AlgebraicNumber} by allowing the user to specify a list of algebraic numbers generating the particular extension to factor over.")) (|factor| (((|Factored| (|SparseUnivariatePolynomial| |#3|)) (|SparseUnivariatePolynomial| |#3|) (|List| (|AlgebraicNumber|))) "\\spad{factor(p,lan)} factors the polynomial \\spad{p} over the extension generated by the algebraic numbers given by the list lan. \\spad{p} is presented as a univariate polynomial with multivariate coefficients.") (((|Factored| |#3|) |#3| (|List| (|AlgebraicNumber|))) "\\spad{factor(p,lan)} factors the polynomial \\spad{p} over the extension generated by the algebraic numbers given by the list lan."))) 
 NIL 
@@ -123,34 +123,34 @@ NIL
 (-48 R A) 
 ((|constructor| (NIL "AlgebraPackage assembles a variety of useful functions for general algebras.")) (|basis| (((|Vector| |#2|) (|Vector| |#2|)) "\\spad{basis(va)} selects a basis from the elements of va.")) (|radicalOfLeftTraceForm| (((|List| |#2|)) "\\spad{radicalOfLeftTraceForm()} returns basis for null space of \\spad{leftTraceMatrix()}, if the algebra is associative, alternative or a Jordan algebra, then this space equals the radical (maximal nil ideal) of the algebra.")) (|basisOfCentroid| (((|List| (|Matrix| |#1|))) "\\spad{basisOfCentroid()} returns a basis of the centroid, \\spadignore{i.e.} the endomorphism ring of \\spad{A} considered as \\spad{(A,A)}-bimodule.")) (|basisOfRightNucloid| (((|List| (|Matrix| |#1|))) "\\spad{basisOfRightNucloid()} returns a basis of the space of endomorphisms of \\spad{A} as left module. Note that right nucloid coincides with right nucleus if \\spad{A} has a unit.")) (|basisOfLeftNucloid| (((|List| (|Matrix| |#1|))) "\\spad{basisOfLeftNucloid()} returns a basis of the space of endomorphisms of \\spad{A} as right module. Note that left nucloid coincides with left nucleus if \\spad{A} has a unit.")) (|basisOfCenter| (((|List| |#2|)) "\\spad{basisOfCenter()} returns a basis of the space of all \\spad{x} of \\spad{A} satisfying \\spad{commutator(x,a) = 0} and \\spad{associator(x,a,b) = associator(a,x,b) = associator(a,b,x) = 0} for all \\spad{a},b in \\spad{A}.")) (|basisOfNucleus| (((|List| |#2|)) "\\spad{basisOfNucleus()} returns a basis of the space of all \\spad{x} of \\spad{A} satisfying \\spad{associator(x,a,b) = associator(a,x,b) = associator(a,b,x) = 0} for all \\spad{a},b in \\spad{A}.")) (|basisOfMiddleNucleus| (((|List| |#2|)) "\\spad{basisOfMiddleNucleus()} returns a basis of the space of all \\spad{x} of \\spad{A} satisfying \\spad{0 = associator(a,x,b)} for all \\spad{a},b in \\spad{A}.")) (|basisOfRightNucleus| (((|List| |#2|)) "\\spad{basisOfRightNucleus()} returns a basis of the space of all \\spad{x} of \\spad{A} satisfying \\spad{0 = associator(a,b,x)} for all \\spad{a},b in \\spad{A}.")) (|basisOfLeftNucleus| (((|List| |#2|)) "\\spad{basisOfLeftNucleus()} returns a basis of the space of all \\spad{x} of \\spad{A} satisfying \\spad{0 = associator(x,a,b)} for all \\spad{a},b in \\spad{A}.")) (|basisOfRightAnnihilator| (((|List| |#2|) |#2|) "\\spad{basisOfRightAnnihilator(a)} returns a basis of the space of all \\spad{x} of \\spad{A} satisfying \\spad{0 = a*x}.")) (|basisOfLeftAnnihilator| (((|List| |#2|) |#2|) "\\spad{basisOfLeftAnnihilator(a)} returns a basis of the space of all \\spad{x} of \\spad{A} satisfying \\spad{0 = x*a}.")) (|basisOfCommutingElements| (((|List| |#2|)) "\\spad{basisOfCommutingElements()} returns a basis of the space of all \\spad{x} of \\spad{A} satisfying \\spad{0 = commutator(x,a)} for all \\spad{a} in \\spad{A}.")) (|biRank| (((|NonNegativeInteger|) |#2|) "\\spad{biRank(x)} determines the number of linearly independent elements in \\spad{x}, \\spad{x*bi}, \\spad{bi*x}, \\spad{bi*x*bj}, \\spad{i,j=1,...,n}, where \\spad{b=[b1,...,bn]} is a basis. Note that if \\spad{A} has a unit, then doubleRank, weakBiRank, and biRank coincide.")) (|weakBiRank| (((|NonNegativeInteger|) |#2|) "\\spad{weakBiRank(x)} determines the number of linearly independent elements in the \\spad{bi*x*bj}, \\spad{i,j=1,...,n}, where \\spad{b=[b1,...,bn]} is a basis.")) (|doubleRank| (((|NonNegativeInteger|) |#2|) "\\spad{doubleRank(x)} determines the number of linearly independent elements in \\spad{b1*x},...,\\spad{x*bn}, where \\spad{b=[b1,...,bn]} is a basis.")) (|rightRank| (((|NonNegativeInteger|) |#2|) "\\spad{rightRank(x)} determines the number of linearly independent elements in \\spad{b1*x},...,\\spad{bn*x}, where \\spad{b=[b1,...,bn]} is a basis.")) (|leftRank| (((|NonNegativeInteger|) |#2|) "\\spad{leftRank(x)} determines the number of linearly independent elements in \\spad{x*b1},...,\\spad{x*bn}, where \\spad{b=[b1,...,bn]} is a basis."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-303)))) 
+((|HasCategory| |#1| (QUOTE (-323)))) 
 (-49 R |n| |ls| |gamma|) 
 ((|constructor| (NIL "AlgebraGivenByStructuralConstants implements finite rank algebras over a commutative ring, given by the structural constants \\spad{gamma} with respect to a fixed basis \\spad{[a1,..,an]}, where \\spad{gamma} is an \\spad{n}-vector of \\spad{n} by \\spad{n} matrices \\spad{[(gammaijk) for \\spad{k} in 1..rank()]} defined by \\spad{ai * aj = \\spad{gammaij1} * \\spad{a1} + \\spad{...} + gammaijn * an}. The symbols for the fixed basis have to be given as a list of symbols.")) (|coerce| (($ (|Vector| |#1|)) "\\spad{coerce(v)} converts a vector to a member of the algebra by forming a linear combination with the basis element. Note: the vector is assumed to have length equal to the dimension of the algebra."))) 
-((-4599 |has| |#1| (-562)) (-4597 . T) (-4596 . T)) 
-((|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) 
+((-4622 |has| |#1| (-582)) (-4620 . T) (-4619 . T)) 
+((|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) 
 (-50 |Key| |Entry|) 
 ((|constructor| (NIL "\\spadtype{AssociationList} implements association lists. These may be viewed as lists of pairs where the first part is a key and the second is the stored value. For example, the key might be a string with a persons employee identification number and the value might be a record with personnel data."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (-1841 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-848))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-1098)))) (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-848)))) (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098)))))) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (-3836 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-869))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-1119)))) (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-869)))) (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119)))))) 
 (-51 S R E) 
 ((|constructor| (NIL "Abelian monoid ring elements (not necessarily of finite support) of this ring are of the form formal SUM (r_i * e_i) where the r_i are coefficents and the e_i, elements of the ordered abelian monoid, are thought of as exponents or monomials. The monomials commute with each other, and with the coefficients (which themselves may or may not be commutative). See \\spadtype{FiniteAbelianMonoidRing} for the case of finite support a useful common model for polynomials and power series. Conceptually at least, only the non-zero terms are ever operated on.")) (/ (($ $ |#2|) "\\spad{p/c} divides \\spad{p} by the coefficient \\spad{c.}")) (|coefficient| ((|#2| $ |#3|) "\\spad{coefficient(p,e)} extracts the coefficient of the monomial with exponent \\spad{e} from polynomial \\spad{p,} or returns zero if exponent is not present.")) (|reductum| (($ $) "\\spad{reductum(u)} returns \\spad{u} minus its leading monomial returns zero if handed the zero element.")) (|monomial| (($ |#2| |#3|) "\\spad{monomial(r,e)} makes a term from a coefficient \\spad{r} and an exponent e.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(p)} tests if \\spad{p} is a single monomial.")) (|map| (($ (|Mapping| |#2| |#2|) $) "\\spad{map(fn,u)} maps function \\spad{fn} onto the coefficients of the non-zero monomials of u.")) (|degree| ((|#3| $) "\\spad{degree(p)} returns the maximum of the exponents of the terms of \\spad{p.}")) (|leadingMonomial| (($ $) "\\spad{leadingMonomial(p)} returns the monomial of \\spad{p} with the highest degree.")) (|leadingCoefficient| ((|#2| $) "\\spad{leadingCoefficient(p)} returns the coefficient highest degree term of \\spad{p.}"))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368)))) 
+((|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388)))) 
 (-52 R E) 
 ((|constructor| (NIL "Abelian monoid ring elements (not necessarily of finite support) of this ring are of the form formal SUM (r_i * e_i) where the r_i are coefficents and the e_i, elements of the ordered abelian monoid, are thought of as exponents or monomials. The monomials commute with each other, and with the coefficients (which themselves may or may not be commutative). See \\spadtype{FiniteAbelianMonoidRing} for the case of finite support a useful common model for polynomials and power series. Conceptually at least, only the non-zero terms are ever operated on.")) (/ (($ $ |#1|) "\\spad{p/c} divides \\spad{p} by the coefficient \\spad{c.}")) (|coefficient| ((|#1| $ |#2|) "\\spad{coefficient(p,e)} extracts the coefficient of the monomial with exponent \\spad{e} from polynomial \\spad{p,} or returns zero if exponent is not present.")) (|reductum| (($ $) "\\spad{reductum(u)} returns \\spad{u} minus its leading monomial returns zero if handed the zero element.")) (|monomial| (($ |#1| |#2|) "\\spad{monomial(r,e)} makes a term from a coefficient \\spad{r} and an exponent e.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(p)} tests if \\spad{p} is a single monomial.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(fn,u)} maps function \\spad{fn} onto the coefficients of the non-zero monomials of u.")) (|degree| ((|#2| $) "\\spad{degree(p)} returns the maximum of the exponents of the terms of \\spad{p.}")) (|leadingMonomial| (($ $) "\\spad{leadingMonomial(p)} returns the monomial of \\spad{p} with the highest degree.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(p)} returns the coefficient highest degree term of \\spad{p.}"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
 (-53) 
 ((|constructor| (NIL "Algebraic closure of the rational numbers, with mathematical =")) (|norm| (($ $ (|List| (|Kernel| $))) "\\spad{norm(f,l)} computes the norm of the algebraic number \\spad{f} with respect to the extension generated by kernels \\spad{l}") (($ $ (|Kernel| $)) "\\spad{norm(f,k)} computes the norm of the algebraic number \\spad{f} with respect to the extension generated by kernel \\spad{k}") (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|List| (|Kernel| $))) "\\spad{norm(p,l)} computes the norm of the polynomial \\spad{p} with respect to the extension generated by kernels \\spad{l}") (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|Kernel| $)) "\\spad{norm(p,k)} computes the norm of the polynomial \\spad{p} with respect to the extension generated by kernel \\spad{k}")) (|reduce| (($ $) "\\spad{reduce(f)} simplifies all the unreduced algebraic numbers present in \\spad{f} by applying their defining relations.")) (|denom| (((|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $)) $) "\\spad{denom(f)} returns the denominator of \\spad{f} viewed as a polynomial in the kernels over \\spad{Z.}")) (|numer| (((|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $)) $) "\\spad{numer(f)} returns the numerator of \\spad{f} viewed as a polynomial in the kernels over \\spad{Z.}")) (|coerce| (($ (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $))) "\\spad{coerce(p)} returns \\spad{p} viewed as an algebraic number."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| $ (QUOTE (-1054))) (|HasCategory| $ (LIST (QUOTE -1044) (QUOTE (-572))))) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| $ (QUOTE (-1075))) (|HasCategory| $ (LIST (QUOTE -1065) (QUOTE (-592))))) 
 (-54) 
 ((|constructor| (NIL "This domain implements anonymous functions"))) 
 NIL 
 NIL 
 (-55 R |lVar|) 
 ((|constructor| (NIL "The domain of antisymmetric polynomials.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f,p)} changes each coefficient of \\spad{p} by the application of \\spad{f.}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(p)} returns the homogeneous degree of \\spad{p.}")) (|retractable?| (((|Boolean|) $) "\\spad{retractable?(p)} tests if \\spad{p} is a 0-form, \\spadignore{i.e.} if degree(p) = 0.")) (|homogeneous?| (((|Boolean|) $) "\\spad{homogeneous?(p)} tests if all of the terms of \\spad{p} have the same degree.")) (|exp| (($ (|List| (|Integer|))) "\\spad{exp([i1,...in])} returns \\spad{u_1\\^{i_1} \\spad{...} u_n\\^{i_n}}")) (|generator| (($ (|NonNegativeInteger|)) "\\spad{generator(n)} returns the \\spad{n}th multiplicative generator, a basis term.")) (|coefficient| ((|#1| $ $) "\\spad{coefficient(p,u)} returns the coefficient of the term in \\spad{p} containing the basis term \\spad{u} if such a term exists, and 0 otherwise. Error: if the second argument \\spad{u} is not a basis element.")) (|reductum| (($ $) "\\spad{reductum(p)}, where \\spad{p} is an antisymmetric polynomial, returns \\spad{p} minus the leading term of \\spad{p} if \\spad{p} has at least two terms, and 0 otherwise.")) (|leadingBasisTerm| (($ $) "\\spad{leadingBasisTerm(p)} returns the leading basis term of antisymmetric polynomial \\spad{p.}")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(p)} returns the leading coefficient of antisymmetric polynomial \\spad{p.}"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
 (-56 S) 
 ((|constructor| (NIL "\\spadtype{AnyFunctions1} implements several utility functions for working with \\spadtype{Any}. These functions are used to go back and forth between objects of \\spadtype{Any} and objects of other types.")) (|retract| ((|#1| (|Any|)) "\\spad{retract(a)} tries to convert \\spad{a} into an object of type \\spad{S}. If possible, it returns the object. Error: if no such retraction is possible.")) (|retractable?| (((|Boolean|) (|Any|)) "\\spad{retractable?(a)} tests if \\spad{a} can be converted into an object of type \\spad{S}.")) (|retractIfCan| (((|Union| |#1| "failed") (|Any|)) "\\spad{retractIfCan(a)} tries change \\spad{a} into an object of type \\spad{S}. If it can, then such an object is returned. Otherwise, \"failed\" is returned.")) (|coerce| (((|Any|) |#1|) "\\spad{coerce(s)} creates an object of \\spadtype{Any} from the object \\spad{s} of type \\spad{S}."))) 
@@ -161,14 +161,14 @@ NIL
 NIL 
 NIL 
 (-58) 
-((|constructor| (NIL "This package contains useful functions that expose Axiom system internals")) (|summary| (((|Void|)) "\\indented{1}{summary() prints a short list of useful console commands} \\blankline \\spad{X} summary()")) (|credits| (((|Void|)) "\\indented{1}{credits() prints a list of people who contributed to Axiom} \\blankline \\spad{X} credits()")) (|getAncestors| (((|Set| (|Symbol|)) (|Symbol|)) "\\indented{1}{The getAncestor(s) takes a category and returns the list of domains} \\indented{1}{that have that category as ancestors} \\blankline \\spad{X} getAncestors 'IndexedAggregate")) (|getDomains| (((|Set| (|Symbol|)) (|Symbol|)) "\\indented{1}{The getDomains(s) takes a category and returns the list of domains} \\indented{1}{that have that category} \\blankline \\spad{X} getDomains 'IndexedAggregate"))) 
+((|constructor| (NIL "This package contains useful functions that expose Axiom system internals")) (|reportInstantiations| (((|Void|) (|Boolean|)) "\\indented{1}{A debugging tool to show instantiation information} \\blankline \\spad{X} reportInstantiations(true) \\spad{X} 1 \\spad{X} reportInstantiations(false)")) (|summary| (((|Void|)) "\\indented{1}{summary() prints a short list of useful console commands} \\blankline \\spad{X} summary()")) (|credits| (((|Void|)) "\\indented{1}{credits() prints a list of people who contributed to Axiom} \\blankline \\spad{X} credits()")) (|getAncestors| (((|Set| (|Symbol|)) (|Symbol|)) "\\indented{1}{The getAncestor(s) takes a category and returns the list of domains} \\indented{1}{that have that category as ancestors} \\blankline \\spad{X} getAncestors 'IndexedAggregate")) (|getDomains| (((|Set| (|Symbol|)) (|Symbol|)) "\\indented{1}{The getDomains(s) takes a category and returns the list of domains} \\indented{1}{that have that category} \\blankline \\spad{X} getDomains 'IndexedAggregate"))) 
 NIL 
 NIL 
 (-59 R M P) 
 ((|constructor| (NIL "\\spad{ApplyUnivariateSkewPolynomial} (internal) allows univariate skew polynomials to be applied to appropriate modules.")) (|apply| ((|#2| |#3| (|Mapping| |#2| |#2|) |#2|) "\\spad{apply(p, \\spad{f,} \\spad{m)}} returns \\spad{p(m)} where the action is given by \\spad{x \\spad{m} = f(m)}. \\spad{f} must be an R-pseudo linear map on \\spad{M.}"))) 
 NIL 
 NIL 
-(-60 |Base| R -3313) 
+(-60 |Base| R -3958) 
 ((|constructor| (NIL "This package apply rewrite rules to expressions, calling the pattern matcher.")) (|localUnquote| ((|#3| |#3| (|List| (|Symbol|))) "\\spad{localUnquote(f,ls)} is a local function.")) (|applyRules| ((|#3| (|List| (|RewriteRule| |#1| |#2| |#3|)) |#3| (|PositiveInteger|)) "\\spad{applyRules([r1,...,rn], expr, \\spad{n)}} applies the rules r1,...,rn to \\spad{f} a most \\spad{n} times.") ((|#3| (|List| (|RewriteRule| |#1| |#2| |#3|)) |#3|) "\\spad{applyRules([r1,...,rn], expr)} applies the rules r1,...,rn to \\spad{f} an unlimited number of times, \\spadignore{i.e.} until none of r1,...,rn is applicable to the expression."))) 
 NIL 
 NIL 
@@ -178,7 +178,7 @@ NIL
 NIL 
 (-62 R |Row| |Col|) 
 ((|constructor| (NIL "Two dimensional array categories and domains")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\indented{1}{map!(f,a)\\space{2}assign \\spad{a(i,j)} to \\spad{f(a(i,j))}} \\indented{1}{for all \\spad{i, \\spad{j}}} \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} map!(-,arr)")) (|map| (($ (|Mapping| |#1| |#1| |#1|) $ $ |#1|) "\\indented{1}{map(f,a,b,r) returns \\spad{c}, where \\spad{c(i,j) = f(a(i,j),b(i,j))}} \\indented{1}{when both \\spad{a(i,j)} and \\spad{b(i,j)} exist;} \\indented{1}{else \\spad{c(i,j) = f(r, b(i,j))} when \\spad{a(i,j)} does not exist;} \\indented{1}{else \\spad{c(i,j) = f(a(i,j),r)} when \\spad{b(i,j)} does not exist;} \\indented{1}{otherwise \\spad{c(i,j) = f(r,r)}.} \\blankline \\spad{X} adder(a:Integer,b:Integer):Integer \\spad{==} a+b \\spad{X} \\spad{arr1} : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} \\spad{arr2} : \\spad{ARRAY2} INT \\spad{:=} new(3,3,10) \\spad{X} map(adder,arr1,arr2,17)") (($ (|Mapping| |#1| |#1| |#1|) $ $) "\\indented{1}{map(f,a,b) returns \\spad{c}, where \\spad{c(i,j) = f(a(i,j),b(i,j))}} \\indented{1}{for all \\spad{i, \\spad{j}}} \\blankline \\spad{X} adder(a:Integer,b:Integer):Integer \\spad{==} a+b \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} map(adder,arr,arr)") (($ (|Mapping| |#1| |#1|) $) "\\indented{1}{map(f,a) returns \\spad{b}, where \\spad{b(i,j) = f(a(i,j))}} \\indented{1}{for all \\spad{i, \\spad{j}}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} map(-,arr) \\spad{X} map((x \\spad{+->} \\spad{x} + x),arr)")) (|setColumn!| (($ $ (|Integer|) |#3|) "\\indented{1}{setColumn!(m,j,v) sets to \\spad{j}th column of \\spad{m} to \\spad{v}} \\blankline \\spad{X} T1:=TwoDimensionalArray Integer \\spad{X} arr:T1:= new(5,4,0) \\spad{X} T2:=OneDimensionalArray Integer \\spad{X} \\spad{acol:=construct([1,2,3,4,5]::List(INT))$T2} \\spad{X} \\spad{setColumn!(arr,1,acol)$T1}")) (|setRow!| (($ $ (|Integer|) |#2|) "\\indented{1}{setRow!(m,i,v) sets to \\spad{i}th row of \\spad{m} to \\spad{v}} \\blankline \\spad{X} T1:=TwoDimensionalArray Integer \\spad{X} arr:T1:= new(5,4,0) \\spad{X} T2:=OneDimensionalArray Integer \\spad{X} \\spad{arow:=construct([1,2,3,4]::List(INT))$T2} \\spad{X} \\spad{setRow!(arr,1,arow)$T1}")) (|qsetelt!| ((|#1| $ (|Integer|) (|Integer|) |#1|) "\\indented{1}{qsetelt!(m,i,j,r) sets the element in the \\spad{i}th row and jth} \\indented{1}{column of \\spad{m} to \\spad{r}} \\indented{1}{NO error check to determine if indices are in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,0) \\spad{X} qsetelt!(arr,1,1,17)")) (|setelt| ((|#1| $ (|Integer|) (|Integer|) |#1|) "\\indented{1}{setelt(m,i,j,r) sets the element in the \\spad{i}th row and jth} \\indented{1}{column of \\spad{m} to \\spad{r}} \\indented{1}{error check to determine if indices are in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,0) \\spad{X} setelt(arr,1,1,17)")) (|parts| (((|List| |#1|) $) "\\indented{1}{parts(m) returns a list of the elements of \\spad{m} in row major order} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} parts(arr)")) (|column| ((|#3| $ (|Integer|)) "\\indented{1}{column(m,j) returns the \\spad{j}th column of \\spad{m}} \\indented{1}{error check to determine if index is in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} column(arr,1)")) (|row| ((|#2| $ (|Integer|)) "\\indented{1}{row(m,i) returns the \\spad{i}th row of \\spad{m}} \\indented{1}{error check to determine if index is in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} row(arr,1)")) (|qelt| ((|#1| $ (|Integer|) (|Integer|)) "\\indented{1}{qelt(m,i,j) returns the element in the \\spad{i}th row and jth} \\indented{1}{column of the array \\spad{m}} \\indented{1}{NO error check to determine if indices are in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} qelt(arr,1,1)")) (|elt| ((|#1| $ (|Integer|) (|Integer|) |#1|) "\\indented{1}{elt(m,i,j,r) returns the element in the \\spad{i}th row and jth} \\indented{1}{column of the array \\spad{m,} if \\spad{m} has an \\spad{i}th row and a \\spad{j}th column,} \\indented{1}{and returns \\spad{r} otherwise} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} elt(arr,1,1,6) \\spad{X} elt(arr,1,10,6)") ((|#1| $ (|Integer|) (|Integer|)) "\\indented{1}{elt(m,i,j) returns the element in the \\spad{i}th row and jth} \\indented{1}{column of the array \\spad{m}} \\indented{1}{error check to determine if indices are in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} elt(arr,1,1)")) (|ncols| (((|NonNegativeInteger|) $) "\\indented{1}{ncols(m) returns the number of columns in the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} ncols(arr)")) (|nrows| (((|NonNegativeInteger|) $) "\\indented{1}{nrows(m) returns the number of rows in the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} nrows(arr)")) (|maxColIndex| (((|Integer|) $) "\\indented{1}{maxColIndex(m) returns the index of the 'last' column of the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} maxColIndex(arr)")) (|minColIndex| (((|Integer|) $) "\\indented{1}{minColIndex(m) returns the index of the 'first' column of the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} minColIndex(arr)")) (|maxRowIndex| (((|Integer|) $) "\\indented{1}{maxRowIndex(m) returns the index of the 'last' row of the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} maxRowIndex(arr)")) (|minRowIndex| (((|Integer|) $) "\\indented{1}{minRowIndex(m) returns the index of the 'first' row of the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,10) \\spad{X} minRowIndex(arr)")) (|fill!| (($ $ |#1|) "\\indented{1}{fill!(m,r) fills \\spad{m} with r's} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,0) \\spad{X} fill!(arr,10)")) (|new| (($ (|NonNegativeInteger|) (|NonNegativeInteger|) |#1|) "\\indented{1}{new(m,n,r) is an m-by-n array all of whose entries are \\spad{r}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,4,0)")) (|finiteAggregate| ((|attribute|) "two-dimensional arrays are finite")) (|shallowlyMutable| ((|attribute|) "one may destructively alter arrays"))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
 (-63 A B) 
 ((|constructor| (NIL "This package provides tools for operating on one-dimensional arrays with unary and binary functions involving different underlying types")) (|map| (((|OneDimensionalArray| |#2|) (|Mapping| |#2| |#1|) (|OneDimensionalArray| |#1|)) "\\indented{1}{map(f,a) applies function \\spad{f} to each member of one-dimensional array} \\indented{1}{\\spad{a} resulting in a new one-dimensional array over a} \\indented{1}{possibly different underlying domain.} \\blankline \\spad{X} T1:=OneDimensionalArrayFunctions2(Integer,Integer) \\spad{X} map(x+->x+2,[i for \\spad{i} in 1..10])$T1")) (|reduce| ((|#2| (|Mapping| |#2| |#1| |#2|) (|OneDimensionalArray| |#1|) |#2|) "\\indented{1}{reduce(f,a,r) applies function \\spad{f} to each} \\indented{1}{successive element of the} \\indented{1}{one-dimensional array \\spad{a} and an accumulant initialized to \\spad{r.}} \\indented{1}{For example, \\spad{reduce(_+$Integer,[1,2,3],0)}} \\indented{1}{does \\spad{3+(2+(1+0))}. Note that third argument \\spad{r}} \\indented{1}{may be regarded as the identity element for the function \\spad{f.}} \\blankline \\spad{X} T1:=OneDimensionalArrayFunctions2(Integer,Integer) \\spad{X} adder(a:Integer,b:Integer):Integer \\spad{==} a+b \\spad{X} reduce(adder,[i for \\spad{i} in 1..10],0)$T1")) (|scan| (((|OneDimensionalArray| |#2|) (|Mapping| |#2| |#1| |#2|) (|OneDimensionalArray| |#1|) |#2|) "\\indented{1}{scan(f,a,r) successively applies} \\indented{1}{\\spad{reduce(f,x,r)} to more and more leading sub-arrays} \\indented{1}{x of one-dimensional array \\spad{a}.} \\indented{1}{More precisely, if \\spad{a} is \\spad{[a1,a2,...]}, then} \\indented{1}{\\spad{scan(f,a,r)} returns} \\indented{1}{\\spad{[reduce(f,[a1],r),reduce(f,[a1,a2],r),...]}.} \\blankline \\spad{X} T1:=OneDimensionalArrayFunctions2(Integer,Integer) \\spad{X} adder(a:Integer,b:Integer):Integer \\spad{==} a+b \\spad{X} scan(adder,[i for \\spad{i} in 1..10],0)$T1"))) 
@@ -186,65 +186,65 @@ NIL
 NIL 
 (-64 S) 
 ((|constructor| (NIL "This is the domain of 1-based one dimensional arrays")) (|oneDimensionalArray| (($ (|NonNegativeInteger|) |#1|) "\\indented{1}{oneDimensionalArray(n,s) creates an array from \\spad{n} copies of element \\spad{s}} \\blankline \\spad{X} oneDimensionalArray(10,0.0)") (($ (|List| |#1|)) "\\indented{1}{oneDimensionalArray(l) creates an array from a list of elements \\spad{l}} \\blankline \\spad{X} oneDimensionalArray \\spad{[i**2} for \\spad{i} in 1..10]"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
 (-65 R) 
 ((|constructor| (NIL "A TwoDimensionalArray is a two dimensional array with 1-based indexing for both rows and columns.")) (|shallowlyMutable| ((|attribute|) "One may destructively alter TwoDimensionalArray's."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-66 -3201) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-66 -4095) 
 ((|constructor| (NIL "\\spadtype{ASP10} produces Fortran for Type 10 ASPs, needed for NAG routine d02kef. This ASP computes the values of a set of functions, for example: \\blankline \\tab{5}SUBROUTINE COEFFN(P,Q,DQDL,X,ELAM,JINT)\\br \\tab{5}DOUBLE PRECISION ELAM,P,Q,X,DQDL\\br \\tab{5}INTEGER JINT\\br \\tab{5}P=1.0D0\\br \\tab{5}Q=((-1.0D0*X**3)+ELAM*X*X-2.0D0)/(X*X)\\br \\tab{5}DQDL=1.0D0\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-67 -3201) 
+(-67 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp12} produces Fortran for Type 12 ASPs, needed for NAG routine d02kef etc., for example: \\blankline \\tab{5}SUBROUTINE MONIT (MAXIT,IFLAG,ELAM,FINFO)\\br \\tab{5}DOUBLE PRECISION ELAM,FINFO(15)\\br \\tab{5}INTEGER MAXIT,IFLAG\\br \\tab{5}IF(MAXIT.EQ.-1)THEN\\br \\tab{7}PRINT*,\"Output from Monit\"\\br \\tab{5}ENDIF\\br \\tab{5}PRINT*,MAXIT,IFLAG,ELAM,(FINFO(I),I=1,4)\\br \\tab{5}RETURN\\br \\tab{5}END\\")) (|outputAsFortran| (((|Void|)) "\\spad{outputAsFortran()} generates the default code for \\spadtype{ASP12}."))) 
 NIL 
 NIL 
-(-68 -3201) 
+(-68 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp19} produces Fortran for Type 19 ASPs, evaluating a set of functions and their jacobian at a given point, for example: \\blankline \\tab{5}SUBROUTINE LSFUN2(M,N,XC,FVECC,FJACC,LJC)\\br \\tab{5}DOUBLE PRECISION FVECC(M),FJACC(LJC,N),XC(N)\\br \\tab{5}INTEGER M,N,LJC\\br \\tab{5}INTEGER I,J\\br \\tab{5}DO 25003 I=1,LJC\\br \\tab{7}DO 25004 J=1,N\\br \\tab{9}FJACC(I,J)=0.0D0\\br 25004 CONTINUE\\br 25003 CONTINUE\\br \\tab{5}FVECC(1)=((XC(1)-0.14D0)*XC(3)+(15.0D0*XC(1)-2.1D0)*XC(2)+1.0D0)/(\\br \\tab{4}&XC(3)+15.0D0*XC(2))\\br \\tab{5}FVECC(2)=((XC(1)-0.18D0)*XC(3)+(7.0D0*XC(1)-1.26D0)*XC(2)+1.0D0)/(\\br \\tab{4}&XC(3)+7.0D0*XC(2))\\br \\tab{5}FVECC(3)=((XC(1)-0.22D0)*XC(3)+(4.333333333333333D0*XC(1)-0.953333\\br \\tab{4}&3333333333D0)*XC(2)+1.0D0)/(XC(3)+4.333333333333333D0*XC(2))\\br \\tab{5}FVECC(4)=((XC(1)-0.25D0)*XC(3)+(3.0D0*XC(1)-0.75D0)*XC(2)+1.0D0)/(\\br \\tab{4}&XC(3)+3.0D0*XC(2))\\br \\tab{5}FVECC(5)=((XC(1)-0.29D0)*XC(3)+(2.2D0*XC(1)-0.6379999999999999D0)*\\br \\tab{4}&XC(2)+1.0D0)/(XC(3)+2.2D0*XC(2))\\br \\tab{5}FVECC(6)=((XC(1)-0.32D0)*XC(3)+(1.666666666666667D0*XC(1)-0.533333\\br \\tab{4}&3333333333D0)*XC(2)+1.0D0)/(XC(3)+1.666666666666667D0*XC(2))\\br \\tab{5}FVECC(7)=((XC(1)-0.35D0)*XC(3)+(1.285714285714286D0*XC(1)-0.45D0)*\\br \\tab{4}&XC(2)+1.0D0)/(XC(3)+1.285714285714286D0*XC(2))\\br \\tab{5}FVECC(8)=((XC(1)-0.39D0)*XC(3)+(XC(1)-0.39D0)*XC(2)+1.0D0)/(XC(3)+\\br \\tab{4}&XC(2))\\br \\tab{5}FVECC(9)=((XC(1)-0.37D0)*XC(3)+(XC(1)-0.37D0)*XC(2)+1.285714285714\\br \\tab{4}&286D0)/(XC(3)+XC(2))\\br \\tab{5}FVECC(10)=((XC(1)-0.58D0)*XC(3)+(XC(1)-0.58D0)*XC(2)+1.66666666666\\br \\tab{4}&6667D0)/(XC(3)+XC(2))\\br \\tab{5}FVECC(11)=((XC(1)-0.73D0)*XC(3)+(XC(1)-0.73D0)*XC(2)+2.2D0)/(XC(3)\\br \\tab{4}&+XC(2))\\br \\tab{5}FVECC(12)=((XC(1)-0.96D0)*XC(3)+(XC(1)-0.96D0)*XC(2)+3.0D0)/(XC(3)\\br \\tab{4}&+XC(2))\\br \\tab{5}FVECC(13)=((XC(1)-1.34D0)*XC(3)+(XC(1)-1.34D0)*XC(2)+4.33333333333\\br \\tab{4}&3333D0)/(XC(3)+XC(2))\\br \\tab{5}FVECC(14)=((XC(1)-2.1D0)*XC(3)+(XC(1)-2.1D0)*XC(2)+7.0D0)/(XC(3)+X\\br \\tab{4}&C(2))\\br \\tab{5}FVECC(15)=((XC(1)-4.39D0)*XC(3)+(XC(1)-4.39D0)*XC(2)+15.0D0)/(XC(3\\br \\tab{4}&)+XC(2))\\br \\tab{5}FJACC(1,1)=1.0D0\\br \\tab{5}FJACC(1,2)=-15.0D0/(XC(3)**2+30.0D0*XC(2)*XC(3)+225.0D0*XC(2)**2)\\br \\tab{5}FJACC(1,3)=-1.0D0/(XC(3)**2+30.0D0*XC(2)*XC(3)+225.0D0*XC(2)**2)\\br \\tab{5}FJACC(2,1)=1.0D0\\br \\tab{5}FJACC(2,2)=-7.0D0/(XC(3)**2+14.0D0*XC(2)*XC(3)+49.0D0*XC(2)**2)\\br \\tab{5}FJACC(2,3)=-1.0D0/(XC(3)**2+14.0D0*XC(2)*XC(3)+49.0D0*XC(2)**2)\\br \\tab{5}FJACC(3,1)=1.0D0\\br \\tab{5}FJACC(3,2)=((-0.1110223024625157D-15*XC(3))-4.333333333333333D0)/(\\br \\tab{4}&XC(3)**2+8.666666666666666D0*XC(2)*XC(3)+18.77777777777778D0*XC(2)\\br \\tab{4}&**2)\\br \\tab{5}FJACC(3,3)=(0.1110223024625157D-15*XC(2)-1.0D0)/(XC(3)**2+8.666666\\br \\tab{4}&666666666D0*XC(2)*XC(3)+18.77777777777778D0*XC(2)**2)\\br \\tab{5}FJACC(4,1)=1.0D0\\br \\tab{5}FJACC(4,2)=-3.0D0/(XC(3)**2+6.0D0*XC(2)*XC(3)+9.0D0*XC(2)**2)\\br \\tab{5}FJACC(4,3)=-1.0D0/(XC(3)**2+6.0D0*XC(2)*XC(3)+9.0D0*XC(2)**2)\\br \\tab{5}FJACC(5,1)=1.0D0\\br \\tab{5}FJACC(5,2)=((-0.1110223024625157D-15*XC(3))-2.2D0)/(XC(3)**2+4.399\\br \\tab{4}&999999999999D0*XC(2)*XC(3)+4.839999999999998D0*XC(2)**2)\\br \\tab{5}FJACC(5,3)=(0.1110223024625157D-15*XC(2)-1.0D0)/(XC(3)**2+4.399999\\br \\tab{4}&999999999D0*XC(2)*XC(3)+4.839999999999998D0*XC(2)**2)\\br \\tab{5}FJACC(6,1)=1.0D0\\br \\tab{5}FJACC(6,2)=((-0.2220446049250313D-15*XC(3))-1.666666666666667D0)/(\\br \\tab{4}&XC(3)**2+3.333333333333333D0*XC(2)*XC(3)+2.777777777777777D0*XC(2)\\br \\tab{4}&**2)\\br \\tab{5}FJACC(6,3)=(0.2220446049250313D-15*XC(2)-1.0D0)/(XC(3)**2+3.333333\\br \\tab{4}&333333333D0*XC(2)*XC(3)+2.777777777777777D0*XC(2)**2)\\br \\tab{5}FJACC(7,1)=1.0D0\\br \\tab{5}FJACC(7,2)=((-0.5551115123125783D-16*XC(3))-1.285714285714286D0)/(\\br \\tab{4}&XC(3)**2+2.571428571428571D0*XC(2)*XC(3)+1.653061224489796D0*XC(2)\\br \\tab{4}&**2)\\br \\tab{5}FJACC(7,3)=(0.5551115123125783D-16*XC(2)-1.0D0)/(XC(3)**2+2.571428\\br \\tab{4}&571428571D0*XC(2)*XC(3)+1.653061224489796D0*XC(2)**2)\\br \\tab{5}FJACC(8,1)=1.0D0\\br \\tab{5}FJACC(8,2)=-1.0D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(8,3)=-1.0D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(9,1)=1.0D0\\br \\tab{5}FJACC(9,2)=-1.285714285714286D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)*\\br \\tab{4}&*2)\\br \\tab{5}FJACC(9,3)=-1.285714285714286D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)*\\br \\tab{4}&*2)\\br \\tab{5}FJACC(10,1)=1.0D0\\br \\tab{5}FJACC(10,2)=-1.666666666666667D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)\\br \\tab{4}&**2)\\br \\tab{5}FJACC(10,3)=-1.666666666666667D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)\\br \\tab{4}&**2)\\br \\tab{5}FJACC(11,1)=1.0D0\\br \\tab{5}FJACC(11,2)=-2.2D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(11,3)=-2.2D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(12,1)=1.0D0\\br \\tab{5}FJACC(12,2)=-3.0D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(12,3)=-3.0D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(13,1)=1.0D0\\br \\tab{5}FJACC(13,2)=-4.333333333333333D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)\\br \\tab{4}&**2)\\br \\tab{5}FJACC(13,3)=-4.333333333333333D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)\\br \\tab{4}&**2)\\br \\tab{5}FJACC(14,1)=1.0D0\\br \\tab{5}FJACC(14,2)=-7.0D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(14,3)=-7.0D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(15,1)=1.0D0\\br \\tab{5}FJACC(15,2)=-15.0D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}FJACC(15,3)=-15.0D0/(XC(3)**2+2.0D0*XC(2)*XC(3)+XC(2)**2)\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-69 -3201) 
+(-69 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp1} produces Fortran for Type 1 ASPs, needed for various NAG routines. Type 1 ASPs take a univariate expression (in the symbol \\spad{x)} and turn it into a Fortran Function like the following: \\blankline \\tab{5}DOUBLE PRECISION FUNCTION F(X)\\br \\tab{5}DOUBLE PRECISION X\\br \\tab{5}F=DSIN(X)\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|))) "\\spad{coerce(f)} takes an object from the appropriate instantiation of \\spadtype{FortranExpression} and turns it into an ASP."))) 
 NIL 
 NIL 
-(-70 -3201) 
+(-70 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp20} produces Fortran for Type 20 ASPs, for example: \\blankline \\tab{5}SUBROUTINE QPHESS(N,NROWH,NCOLH,JTHCOL,HESS,X,HX)\\br \\tab{5}DOUBLE PRECISION HX(N),X(N),HESS(NROWH,NCOLH)\\br \\tab{5}INTEGER JTHCOL,N,NROWH,NCOLH\\br \\tab{5}HX(1)=2.0D0*X(1)\\br \\tab{5}HX(2)=2.0D0*X(2)\\br \\tab{5}HX(3)=2.0D0*X(4)+2.0D0*X(3)\\br \\tab{5}HX(4)=2.0D0*X(4)+2.0D0*X(3)\\br \\tab{5}HX(5)=2.0D0*X(5)\\br \\tab{5}HX(6)=(-2.0D0*X(7))+(-2.0D0*X(6))\\br \\tab{5}HX(7)=(-2.0D0*X(7))+(-2.0D0*X(6))\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Matrix| (|FortranExpression| (|construct|) (|construct| (QUOTE X) (QUOTE HESS)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-71 -3201) 
+(-71 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp24} produces Fortran for Type 24 ASPs which evaluate a multivariate function at a point (needed for NAG routine e04jaf), for example: \\blankline \\tab{5}SUBROUTINE FUNCT1(N,XC,FC)\\br \\tab{5}DOUBLE PRECISION FC,XC(N)\\br \\tab{5}INTEGER N\\br \\tab{5}FC=10.0D0*XC(4)**4+(-40.0D0*XC(1)*XC(4)**3)+(60.0D0*XC(1)**2+5\\br \\tab{4}&.0D0)*XC(4)**2+((-10.0D0*XC(3))+(-40.0D0*XC(1)**3))*XC(4)+16.0D0*X\\br \\tab{4}&C(3)**4+(-32.0D0*XC(2)*XC(3)**3)+(24.0D0*XC(2)**2+5.0D0)*XC(3)**2+\\br \\tab{4}&(-8.0D0*XC(2)**3*XC(3))+XC(2)**4+100.0D0*XC(2)**2+20.0D0*XC(1)*XC(\\br \\tab{4}&2)+10.0D0*XC(1)**4+XC(1)**2\\br \\tab{5}RETURN\\br \\tab{5}END\\br")) (|coerce| (($ (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|))) "\\spadtype{FortranExpression} and turns it into an ASP. coerce(f) takes an object from the appropriate instantiation of"))) 
 NIL 
 NIL 
-(-72 -3201) 
+(-72 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp27} produces Fortran for Type 27 ASPs, needed for NAG routine f02fjf ,for example: \\blankline \\tab{5}FUNCTION DOT(IFLAG,N,Z,W,RWORK,LRWORK,IWORK,LIWORK)\\br \\tab{5}DOUBLE PRECISION W(N),Z(N),RWORK(LRWORK)\\br \\tab{5}INTEGER N,LIWORK,IFLAG,LRWORK,IWORK(LIWORK)\\br \\tab{5}DOT=(W(16)+(-0.5D0*W(15)))*Z(16)+((-0.5D0*W(16))+W(15)+(-0.5D0*W(1\\br \\tab{4}&4)))*Z(15)+((-0.5D0*W(15))+W(14)+(-0.5D0*W(13)))*Z(14)+((-0.5D0*W(\\br \\tab{4}&14))+W(13)+(-0.5D0*W(12)))*Z(13)+((-0.5D0*W(13))+W(12)+(-0.5D0*W(1\\br \\tab{4}&1)))*Z(12)+((-0.5D0*W(12))+W(11)+(-0.5D0*W(10)))*Z(11)+((-0.5D0*W(\\br \\tab{4}&11))+W(10)+(-0.5D0*W(9)))*Z(10)+((-0.5D0*W(10))+W(9)+(-0.5D0*W(8))\\br \\tab{4}&)*Z(9)+((-0.5D0*W(9))+W(8)+(-0.5D0*W(7)))*Z(8)+((-0.5D0*W(8))+W(7)\\br \\tab{4}&+(-0.5D0*W(6)))*Z(7)+((-0.5D0*W(7))+W(6)+(-0.5D0*W(5)))*Z(6)+((-0.\\br \\tab{4}&5D0*W(6))+W(5)+(-0.5D0*W(4)))*Z(5)+((-0.5D0*W(5))+W(4)+(-0.5D0*W(3\\br \\tab{4}&)))*Z(4)+((-0.5D0*W(4))+W(3)+(-0.5D0*W(2)))*Z(3)+((-0.5D0*W(3))+W(\\br \\tab{4}&2)+(-0.5D0*W(1)))*Z(2)+((-0.5D0*W(2))+W(1))*Z(1)\\br \\tab{5}RETURN\\br \\tab{5}END"))) 
 NIL 
 NIL 
-(-73 -3201) 
+(-73 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp28} produces Fortran for Type 28 ASPs, used in NAG routine f02fjf, for example: \\blankline \\tab{5}SUBROUTINE IMAGE(IFLAG,N,Z,W,RWORK,LRWORK,IWORK,LIWORK)\\br \\tab{5}DOUBLE PRECISION Z(N),W(N),IWORK(LRWORK),RWORK(LRWORK)\\br \\tab{5}INTEGER N,LIWORK,IFLAG,LRWORK\\br \\tab{5}W(1)=0.01707454969713436D0*Z(16)+0.001747395874954051D0*Z(15)+0.00\\br \\tab{4}&2106973900813502D0*Z(14)+0.002957434991769087D0*Z(13)+(-0.00700554\\br \\tab{4}&0882865317D0*Z(12))+(-0.01219194009813166D0*Z(11))+0.0037230647365\\br \\tab{4}&3087D0*Z(10)+0.04932374658377151D0*Z(9)+(-0.03586220812223305D0*Z(\\br \\tab{4}&8))+(-0.04723268012114625D0*Z(7))+(-0.02434652144032987D0*Z(6))+0.\\br \\tab{4}&2264766947290192D0*Z(5)+(-0.1385343580686922D0*Z(4))+(-0.116530050\\br \\tab{4}&8238904D0*Z(3))+(-0.2803531651057233D0*Z(2))+1.019463911841327D0*Z\\br \\tab{4}&(1)\\br \\tab{5}W(2)=0.0227345011107737D0*Z(16)+0.008812321197398072D0*Z(15)+0.010\\br \\tab{4}&94012210519586D0*Z(14)+(-0.01764072463999744D0*Z(13))+(-0.01357136\\br \\tab{4}&72105995D0*Z(12))+0.00157466157362272D0*Z(11)+0.05258889186338282D\\br \\tab{4}&0*Z(10)+(-0.01981532388243379D0*Z(9))+(-0.06095390688679697D0*Z(8)\\br \\tab{4}&)+(-0.04153119955569051D0*Z(7))+0.2176561076571465D0*Z(6)+(-0.0532\\br \\tab{4}&5555586632358D0*Z(5))+(-0.1688977368984641D0*Z(4))+(-0.32440166056\\br \\tab{4}&67343D0*Z(3))+0.9128222941872173D0*Z(2)+(-0.2419652703415429D0*Z(1\\br \\tab{4}&))\\br \\tab{5}W(3)=0.03371198197190302D0*Z(16)+0.02021603150122265D0*Z(15)+(-0.0\\br \\tab{4}&06607305534689702D0*Z(14))+(-0.03032392238968179D0*Z(13))+0.002033\\br \\tab{4}&305231024948D0*Z(12)+0.05375944956767728D0*Z(11)+(-0.0163213312502\\br \\tab{4}&9967D0*Z(10))+(-0.05483186562035512D0*Z(9))+(-0.04901428822579872D\\br \\tab{4}&0*Z(8))+0.2091097927887612D0*Z(7)+(-0.05760560341383113D0*Z(6))+(-\\br \\tab{4}&0.1236679206156403D0*Z(5))+(-0.3523683853026259D0*Z(4))+0.88929961\\br \\tab{4}&32269974D0*Z(3)+(-0.2995429545781457D0*Z(2))+(-0.02986582812574917\\br \\tab{4}&D0*Z(1))\\br \\tab{5}W(4)=0.05141563713660119D0*Z(16)+0.005239165960779299D0*Z(15)+(-0.\\br \\tab{4}&01623427735779699D0*Z(14))+(-0.01965809746040371D0*Z(13))+0.054688\\br \\tab{4}&97337339577D0*Z(12)+(-0.014224695935687D0*Z(11))+(-0.0505181779315\\br \\tab{4}&6355D0*Z(10))+(-0.04353074206076491D0*Z(9))+0.2012230497530726D0*Z\\br \\tab{4}&(8)+(-0.06630874514535952D0*Z(7))+(-0.1280829963720053D0*Z(6))+(-0\\br \\tab{4}&.305169742604165D0*Z(5))+0.8600427128450191D0*Z(4)+(-0.32415033802\\br \\tab{4}&68184D0*Z(3))+(-0.09033531980693314D0*Z(2))+0.09089205517109111D0*\\br \\tab{4}&Z(1)\\br \\tab{5}W(5)=0.04556369767776375D0*Z(16)+(-0.001822737697581869D0*Z(15))+(\\br \\tab{4}&-0.002512226501941856D0*Z(14))+0.02947046460707379D0*Z(13)+(-0.014\\br \\tab{4}&45079632086177D0*Z(12))+(-0.05034242196614937D0*Z(11))+(-0.0376966\\br \\tab{4}&3291725935D0*Z(10))+0.2171103102175198D0*Z(9)+(-0.0824949256021352\\br \\tab{4}&4D0*Z(8))+(-0.1473995209288945D0*Z(7))+(-0.315042193418466D0*Z(6))\\br \\tab{4}&+0.9591623347824002D0*Z(5)+(-0.3852396953763045D0*Z(4))+(-0.141718\\br \\tab{4}&5427288274D0*Z(3))+(-0.03423495461011043D0*Z(2))+0.319820917706851\\br \\tab{4}&6D0*Z(1)\\br \\tab{5}W(6)=0.04015147277405744D0*Z(16)+0.01328585741341559D0*Z(15)+0.048\\br \\tab{4}&26082005465965D0*Z(14)+(-0.04319641116207706D0*Z(13))+(-0.04931323\\br \\tab{4}&319055762D0*Z(12))+(-0.03526886317505474D0*Z(11))+0.22295383396730\\br \\tab{4}&01D0*Z(10)+(-0.07375317649315155D0*Z(9))+(-0.1589391311991561D0*Z(\\br \\tab{4}&8))+(-0.328001910890377D0*Z(7))+0.952576555482747D0*Z(6)+(-0.31583\\br \\tab{4}&09975786731D0*Z(5))+(-0.1846882042225383D0*Z(4))+(-0.0703762046700\\br \\tab{4}&4427D0*Z(3))+0.2311852964327382D0*Z(2)+0.04254083491825025D0*Z(1)\\br \\tab{5}W(7)=0.06069778964023718D0*Z(16)+0.06681263884671322D0*Z(15)+(-0.0\\br \\tab{4}&2113506688615768D0*Z(14))+(-0.083996867458326D0*Z(13))+(-0.0329843\\br \\tab{4}&8523869648D0*Z(12))+0.2276878326327734D0*Z(11)+(-0.067356038933017\\br \\tab{4}&95D0*Z(10))+(-0.1559813965382218D0*Z(9))+(-0.3363262957694705D0*Z(\\br \\tab{4}&8))+0.9442791158560948D0*Z(7)+(-0.3199955249404657D0*Z(6))+(-0.136\\br \\tab{4}&2463839920727D0*Z(5))+(-0.1006185171570586D0*Z(4))+0.2057504515015\\br \\tab{4}&423D0*Z(3)+(-0.02065879269286707D0*Z(2))+0.03160990266745513D0*Z(1\\br \\tab{4}&)\\br \\tab{5}W(8)=0.126386868896738D0*Z(16)+0.002563370039476418D0*Z(15)+(-0.05\\br \\tab{4}&581757739455641D0*Z(14))+(-0.07777893205900685D0*Z(13))+0.23117338\\br \\tab{4}&45834199D0*Z(12)+(-0.06031581134427592D0*Z(11))+(-0.14805474755869\\br \\tab{4}&52D0*Z(10))+(-0.3364014128402243D0*Z(9))+0.9364014128402244D0*Z(8)\\br \\tab{4}&+(-0.3269452524413048D0*Z(7))+(-0.1396841886557241D0*Z(6))+(-0.056\\br \\tab{4}&1733845834199D0*Z(5))+0.1777789320590069D0*Z(4)+(-0.04418242260544\\br \\tab{4}&359D0*Z(3))+(-0.02756337003947642D0*Z(2))+0.07361313110326199D0*Z(\\br \\tab{4}&1)\\br \\tab{5}W(9)=0.07361313110326199D0*Z(16)+(-0.02756337003947642D0*Z(15))+(-\\br \\tab{4}&0.04418242260544359D0*Z(14))+0.1777789320590069D0*Z(13)+(-0.056173\\br \\tab{4}&3845834199D0*Z(12))+(-0.1396841886557241D0*Z(11))+(-0.326945252441\\br \\tab{4}&3048D0*Z(10))+0.9364014128402244D0*Z(9)+(-0.3364014128402243D0*Z(8\\br \\tab{4}&))+(-0.1480547475586952D0*Z(7))+(-0.06031581134427592D0*Z(6))+0.23\\br \\tab{4}&11733845834199D0*Z(5)+(-0.07777893205900685D0*Z(4))+(-0.0558175773\\br \\tab{4}&9455641D0*Z(3))+0.002563370039476418D0*Z(2)+0.126386868896738D0*Z(\\br \\tab{4}&1)\\br \\tab{5}W(10)=0.03160990266745513D0*Z(16)+(-0.02065879269286707D0*Z(15))+0\\br \\tab{4}&.2057504515015423D0*Z(14)+(-0.1006185171570586D0*Z(13))+(-0.136246\\br \\tab{4}&3839920727D0*Z(12))+(-0.3199955249404657D0*Z(11))+0.94427911585609\\br \\tab{4}&48D0*Z(10)+(-0.3363262957694705D0*Z(9))+(-0.1559813965382218D0*Z(8\\br \\tab{4}&))+(-0.06735603893301795D0*Z(7))+0.2276878326327734D0*Z(6)+(-0.032\\br \\tab{4}&98438523869648D0*Z(5))+(-0.083996867458326D0*Z(4))+(-0.02113506688\\br \\tab{4}&615768D0*Z(3))+0.06681263884671322D0*Z(2)+0.06069778964023718D0*Z(\\br \\tab{4}&1)\\br \\tab{5}W(11)=0.04254083491825025D0*Z(16)+0.2311852964327382D0*Z(15)+(-0.0\\br \\tab{4}&7037620467004427D0*Z(14))+(-0.1846882042225383D0*Z(13))+(-0.315830\\br \\tab{4}&9975786731D0*Z(12))+0.952576555482747D0*Z(11)+(-0.328001910890377D\\br \\tab{4}&0*Z(10))+(-0.1589391311991561D0*Z(9))+(-0.07375317649315155D0*Z(8)\\br \\tab{4}&)+0.2229538339673001D0*Z(7)+(-0.03526886317505474D0*Z(6))+(-0.0493\\br \\tab{4}&1323319055762D0*Z(5))+(-0.04319641116207706D0*Z(4))+0.048260820054\\br \\tab{4}&65965D0*Z(3)+0.01328585741341559D0*Z(2)+0.04015147277405744D0*Z(1)\\br \\tab{5}W(12)=0.3198209177068516D0*Z(16)+(-0.03423495461011043D0*Z(15))+(-\\br \\tab{4}&0.1417185427288274D0*Z(14))+(-0.3852396953763045D0*Z(13))+0.959162\\br \\tab{4}&3347824002D0*Z(12)+(-0.315042193418466D0*Z(11))+(-0.14739952092889\\br \\tab{4}&45D0*Z(10))+(-0.08249492560213524D0*Z(9))+0.2171103102175198D0*Z(8\\br \\tab{4}&)+(-0.03769663291725935D0*Z(7))+(-0.05034242196614937D0*Z(6))+(-0.\\br \\tab{4}&01445079632086177D0*Z(5))+0.02947046460707379D0*Z(4)+(-0.002512226\\br \\tab{4}&501941856D0*Z(3))+(-0.001822737697581869D0*Z(2))+0.045563697677763\\br \\tab{4}&75D0*Z(1)\\br \\tab{5}W(13)=0.09089205517109111D0*Z(16)+(-0.09033531980693314D0*Z(15))+(\\br \\tab{4}&-0.3241503380268184D0*Z(14))+0.8600427128450191D0*Z(13)+(-0.305169\\br \\tab{4}&742604165D0*Z(12))+(-0.1280829963720053D0*Z(11))+(-0.0663087451453\\br \\tab{4}&5952D0*Z(10))+0.2012230497530726D0*Z(9)+(-0.04353074206076491D0*Z(\\br \\tab{4}&8))+(-0.05051817793156355D0*Z(7))+(-0.014224695935687D0*Z(6))+0.05\\br \\tab{4}&468897337339577D0*Z(5)+(-0.01965809746040371D0*Z(4))+(-0.016234277\\br \\tab{4}&35779699D0*Z(3))+0.005239165960779299D0*Z(2)+0.05141563713660119D0\\br \\tab{4}&*Z(1)\\br \\tab{5}W(14)=(-0.02986582812574917D0*Z(16))+(-0.2995429545781457D0*Z(15))\\br \\tab{4}&+0.8892996132269974D0*Z(14)+(-0.3523683853026259D0*Z(13))+(-0.1236\\br \\tab{4}&679206156403D0*Z(12))+(-0.05760560341383113D0*Z(11))+0.20910979278\\br \\tab{4}&87612D0*Z(10)+(-0.04901428822579872D0*Z(9))+(-0.05483186562035512D\\br \\tab{4}&0*Z(8))+(-0.01632133125029967D0*Z(7))+0.05375944956767728D0*Z(6)+0\\br \\tab{4}&.002033305231024948D0*Z(5)+(-0.03032392238968179D0*Z(4))+(-0.00660\\br \\tab{4}&7305534689702D0*Z(3))+0.02021603150122265D0*Z(2)+0.033711981971903\\br \\tab{4}&02D0*Z(1)\\br \\tab{5}W(15)=(-0.2419652703415429D0*Z(16))+0.9128222941872173D0*Z(15)+(-0\\br \\tab{4}&.3244016605667343D0*Z(14))+(-0.1688977368984641D0*Z(13))+(-0.05325\\br \\tab{4}&555586632358D0*Z(12))+0.2176561076571465D0*Z(11)+(-0.0415311995556\\br \\tab{4}&9051D0*Z(10))+(-0.06095390688679697D0*Z(9))+(-0.01981532388243379D\\br \\tab{4}&0*Z(8))+0.05258889186338282D0*Z(7)+0.00157466157362272D0*Z(6)+(-0.\\br \\tab{4}&0135713672105995D0*Z(5))+(-0.01764072463999744D0*Z(4))+0.010940122\\br \\tab{4}&10519586D0*Z(3)+0.008812321197398072D0*Z(2)+0.0227345011107737D0*Z\\br \\tab{4}&(1)\\br \\tab{5}W(16)=1.019463911841327D0*Z(16)+(-0.2803531651057233D0*Z(15))+(-0.\\br \\tab{4}&1165300508238904D0*Z(14))+(-0.1385343580686922D0*Z(13))+0.22647669\\br \\tab{4}&47290192D0*Z(12)+(-0.02434652144032987D0*Z(11))+(-0.04723268012114\\br \\tab{4}&625D0*Z(10))+(-0.03586220812223305D0*Z(9))+0.04932374658377151D0*Z\\br \\tab{4}&(8)+0.00372306473653087D0*Z(7)+(-0.01219194009813166D0*Z(6))+(-0.0\\br \\tab{4}&07005540882865317D0*Z(5))+0.002957434991769087D0*Z(4)+0.0021069739\\br \\tab{4}&00813502D0*Z(3)+0.001747395874954051D0*Z(2)+0.01707454969713436D0*\\br \\tab{4}&Z(1)\\br \\tab{5}RETURN\\br \\tab{5}END\\br"))) 
 NIL 
 NIL 
-(-74 -3201) 
+(-74 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp29} produces Fortran for Type 29 ASPs, needed for NAG routine f02fjf, for example: \\blankline \\tab{5}SUBROUTINE MONIT(ISTATE,NEXTIT,NEVALS,NEVECS,K,F,D)\\br \\tab{5}DOUBLE PRECISION D(K),F(K)\\br \\tab{5}INTEGER K,NEXTIT,NEVALS,NVECS,ISTATE\\br \\tab{5}CALL F02FJZ(ISTATE,NEXTIT,NEVALS,NEVECS,K,F,D)\\br \\tab{5}RETURN\\br \\tab{5}END\\br")) (|outputAsFortran| (((|Void|)) "\\spad{outputAsFortran()} generates the default code for \\spadtype{ASP29}."))) 
 NIL 
 NIL 
-(-75 -3201) 
+(-75 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp30} produces Fortran for Type 30 ASPs, needed for NAG routine f04qaf, for example: \\blankline \\tab{5}SUBROUTINE APROD(MODE,M,N,X,Y,RWORK,LRWORK,IWORK,LIWORK)\\br \\tab{5}DOUBLE PRECISION X(N),Y(M),RWORK(LRWORK)\\br \\tab{5}INTEGER M,N,LIWORK,IFAIL,LRWORK,IWORK(LIWORK),MODE\\br \\tab{5}DOUBLE PRECISION A(5,5)\\br \\tab{5}EXTERNAL F06PAF\\br \\tab{5}A(1,1)=1.0D0\\br \\tab{5}A(1,2)=0.0D0\\br \\tab{5}A(1,3)=0.0D0\\br \\tab{5}A(1,4)=-1.0D0\\br \\tab{5}A(1,5)=0.0D0\\br \\tab{5}A(2,1)=0.0D0\\br \\tab{5}A(2,2)=1.0D0\\br \\tab{5}A(2,3)=0.0D0\\br \\tab{5}A(2,4)=0.0D0\\br \\tab{5}A(2,5)=-1.0D0\\br \\tab{5}A(3,1)=0.0D0\\br \\tab{5}A(3,2)=0.0D0\\br \\tab{5}A(3,3)=1.0D0\\br \\tab{5}A(3,4)=-1.0D0\\br \\tab{5}A(3,5)=0.0D0\\br \\tab{5}A(4,1)=-1.0D0\\br \\tab{5}A(4,2)=0.0D0\\br \\tab{5}A(4,3)=-1.0D0\\br \\tab{5}A(4,4)=4.0D0\\br \\tab{5}A(4,5)=-1.0D0\\br \\tab{5}A(5,1)=0.0D0\\br \\tab{5}A(5,2)=-1.0D0\\br \\tab{5}A(5,3)=0.0D0\\br \\tab{5}A(5,4)=-1.0D0\\br \\tab{5}A(5,5)=4.0D0\\br \\tab{5}IF(MODE.EQ.1)THEN\\br \\tab{7}CALL F06PAF('N',M,N,1.0D0,A,M,X,1,1.0D0,Y,1)\\br \\tab{5}ELSEIF(MODE.EQ.2)THEN\\br \\tab{7}CALL F06PAF('T',M,N,1.0D0,A,M,Y,1,1.0D0,X,1)\\br \\tab{5}ENDIF\\br \\tab{5}RETURN\\br \\tab{5}END"))) 
 NIL 
 NIL 
-(-76 -3201) 
+(-76 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp31} produces Fortran for Type 31 ASPs, needed for NAG routine d02ejf, for example: \\blankline \\tab{5}SUBROUTINE PEDERV(X,Y,PW)\\br \\tab{5}DOUBLE PRECISION X,Y(*)\\br \\tab{5}DOUBLE PRECISION PW(3,3)\\br \\tab{5}PW(1,1)=-0.03999999999999999D0\\br \\tab{5}PW(1,2)=10000.0D0*Y(3)\\br \\tab{5}PW(1,3)=10000.0D0*Y(2)\\br \\tab{5}PW(2,1)=0.03999999999999999D0\\br \\tab{5}PW(2,2)=(-10000.0D0*Y(3))+(-60000000.0D0*Y(2))\\br \\tab{5}PW(2,3)=-10000.0D0*Y(2)\\br \\tab{5}PW(3,1)=0.0D0\\br \\tab{5}PW(3,2)=60000000.0D0*Y(2)\\br \\tab{5}PW(3,3)=0.0D0\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-77 -3201) 
+(-77 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp33} produces Fortran for Type 33 ASPs, needed for NAG routine d02kef. The code is a dummy ASP: \\blankline \\tab{5}SUBROUTINE REPORT(X,V,JINT)\\br \\tab{5}DOUBLE PRECISION V(3),X\\br \\tab{5}INTEGER JINT\\br \\tab{5}RETURN\\br \\tab{5}END")) (|outputAsFortran| (((|Void|)) "\\spad{outputAsFortran()} generates the default code for \\spadtype{ASP33}."))) 
 NIL 
 NIL 
-(-78 -3201) 
+(-78 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp34} produces Fortran for Type 34 ASPs, needed for NAG routine f04mbf, for example: \\blankline \\tab{5}SUBROUTINE MSOLVE(IFLAG,N,X,Y,RWORK,LRWORK,IWORK,LIWORK)\\br \\tab{5}DOUBLE PRECISION RWORK(LRWORK),X(N),Y(N)\\br \\tab{5}INTEGER I,J,N,LIWORK,IFLAG,LRWORK,IWORK(LIWORK)\\br \\tab{5}DOUBLE PRECISION W1(3),W2(3),MS(3,3)\\br \\tab{5}IFLAG=-1\\br \\tab{5}MS(1,1)=2.0D0\\br \\tab{5}MS(1,2)=1.0D0\\br \\tab{5}MS(1,3)=0.0D0\\br \\tab{5}MS(2,1)=1.0D0\\br \\tab{5}MS(2,2)=2.0D0\\br \\tab{5}MS(2,3)=1.0D0\\br \\tab{5}MS(3,1)=0.0D0\\br \\tab{5}MS(3,2)=1.0D0\\br \\tab{5}MS(3,3)=2.0D0\\br \\tab{5}CALL F04ASF(MS,N,X,N,Y,W1,W2,IFLAG)\\br \\tab{5}IFLAG=-IFLAG\\br \\tab{5}RETURN\\br \\tab{5}END"))) 
 NIL 
 NIL 
-(-79 -3201) 
+(-79 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp35} produces Fortran for Type 35 ASPs, needed for NAG routines c05pbf, c05pcf, for example: \\blankline \\tab{5}SUBROUTINE FCN(N,X,FVEC,FJAC,LDFJAC,IFLAG)\\br \\tab{5}DOUBLE PRECISION X(N),FVEC(N),FJAC(LDFJAC,N)\\br \\tab{5}INTEGER LDFJAC,N,IFLAG\\br \\tab{5}IF(IFLAG.EQ.1)THEN\\br \\tab{7}FVEC(1)=(-1.0D0*X(2))+X(1)\\br \\tab{7}FVEC(2)=(-1.0D0*X(3))+2.0D0*X(2)\\br \\tab{7}FVEC(3)=3.0D0*X(3)\\br \\tab{5}ELSEIF(IFLAG.EQ.2)THEN\\br \\tab{7}FJAC(1,1)=1.0D0\\br \\tab{7}FJAC(1,2)=-1.0D0\\br \\tab{7}FJAC(1,3)=0.0D0\\br \\tab{7}FJAC(2,1)=0.0D0\\br \\tab{7}FJAC(2,2)=2.0D0\\br \\tab{7}FJAC(2,3)=-1.0D0\\br \\tab{7}FJAC(3,1)=0.0D0\\br \\tab{7}FJAC(3,2)=0.0D0\\br \\tab{7}FJAC(3,3)=3.0D0\\br \\tab{5}ENDIF\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
@@ -256,4821 +256,4905 @@ NIL
 ((|constructor| (NIL "\\spadtype{Asp42} produces Fortran for Type 42 ASPs, needed for NAG routines d02raf and d02saf in particular. These ASPs are in fact three Fortran routines which return a vector of functions, and their derivatives \\spad{wrt} Y(i) and also a continuation parameter EPS, for example: \\blankline \\tab{5}SUBROUTINE G(EPS,YA,YB,BC,N)\\br \\tab{5}DOUBLE PRECISION EPS,YA(N),YB(N),BC(N)\\br \\tab{5}INTEGER N\\br \\tab{5}BC(1)=YA(1)\\br \\tab{5}BC(2)=YA(2)\\br \\tab{5}BC(3)=YB(2)-1.0D0\\br \\tab{5}RETURN\\br \\tab{5}END\\br \\tab{5}SUBROUTINE JACOBG(EPS,YA,YB,AJ,BJ,N)\\br \\tab{5}DOUBLE PRECISION EPS,YA(N),AJ(N,N),BJ(N,N),YB(N)\\br \\tab{5}INTEGER N\\br \\tab{5}AJ(1,1)=1.0D0\\br \\tab{5}AJ(1,2)=0.0D0\\br \\tab{5}AJ(1,3)=0.0D0\\br \\tab{5}AJ(2,1)=0.0D0\\br \\tab{5}AJ(2,2)=1.0D0\\br \\tab{5}AJ(2,3)=0.0D0\\br \\tab{5}AJ(3,1)=0.0D0\\br \\tab{5}AJ(3,2)=0.0D0\\br \\tab{5}AJ(3,3)=0.0D0\\br \\tab{5}BJ(1,1)=0.0D0\\br \\tab{5}BJ(1,2)=0.0D0\\br \\tab{5}BJ(1,3)=0.0D0\\br \\tab{5}BJ(2,1)=0.0D0\\br \\tab{5}BJ(2,2)=0.0D0\\br \\tab{5}BJ(2,3)=0.0D0\\br \\tab{5}BJ(3,1)=0.0D0\\br \\tab{5}BJ(3,2)=1.0D0\\br \\tab{5}BJ(3,3)=0.0D0\\br \\tab{5}RETURN\\br \\tab{5}END\\br \\tab{5}SUBROUTINE JACGEP(EPS,YA,YB,BCEP,N)\\br \\tab{5}DOUBLE PRECISION EPS,YA(N),YB(N),BCEP(N)\\br \\tab{5}INTEGER N\\br \\tab{5}BCEP(1)=0.0D0\\br \\tab{5}BCEP(2)=0.0D0\\br \\tab{5}BCEP(3)=0.0D0\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE EPS)) (|construct| (QUOTE YA) (QUOTE YB)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-82 -3201) 
+(-82 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp49} produces Fortran for Type 49 ASPs, needed for NAG routines e04dgf, e04ucf, for example: \\blankline \\tab{5}SUBROUTINE OBJFUN(MODE,N,X,OBJF,OBJGRD,NSTATE,IUSER,USER)\\br \\tab{5}DOUBLE PRECISION X(N),OBJF,OBJGRD(N),USER(*)\\br \\tab{5}INTEGER N,IUSER(*),MODE,NSTATE\\br \\tab{5}OBJF=X(4)*X(9)+((-1.0D0*X(5))+X(3))*X(8)+((-1.0D0*X(3))+X(1))*X(7)\\br \\tab{4}&+(-1.0D0*X(2)*X(6))\\br \\tab{5}OBJGRD(1)=X(7)\\br \\tab{5}OBJGRD(2)=-1.0D0*X(6)\\br \\tab{5}OBJGRD(3)=X(8)+(-1.0D0*X(7))\\br \\tab{5}OBJGRD(4)=X(9)\\br \\tab{5}OBJGRD(5)=-1.0D0*X(8)\\br \\tab{5}OBJGRD(6)=-1.0D0*X(2)\\br \\tab{5}OBJGRD(7)=(-1.0D0*X(3))+X(1)\\br \\tab{5}OBJGRD(8)=(-1.0D0*X(5))+X(3)\\br \\tab{5}OBJGRD(9)=X(4)\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|))) "\\spad{coerce(f)} takes an object from the appropriate instantiation of \\spadtype{FortranExpression} and turns it into an ASP."))) 
 NIL 
 NIL 
-(-83 -3201) 
+(-83 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp4} produces Fortran for Type 4 ASPs, which take an expression in X(1) \\spad{..} X(NDIM) and produce a real function of the form: \\blankline \\tab{5}DOUBLE PRECISION FUNCTION FUNCTN(NDIM,X)\\br \\tab{5}DOUBLE PRECISION X(NDIM)\\br \\tab{5}INTEGER NDIM\\br \\tab{5}FUNCTN=(4.0D0*X(1)*X(3)**2*DEXP(2.0D0*X(1)*X(3)))/(X(4)**2+(2.0D0*\\br \\tab{4}&X(2)+2.0D0)*X(4)+X(2)**2+2.0D0*X(2)+1.0D0)\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|))) "\\spad{coerce(f)} takes an object from the appropriate instantiation of \\spadtype{FortranExpression} and turns it into an ASP."))) 
 NIL 
 NIL 
-(-84 -3201) 
+(-84 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp50} produces Fortran for Type 50 ASPs, needed for NAG routine e04fdf, for example: \\blankline \\tab{5}SUBROUTINE LSFUN1(M,N,XC,FVECC)\\br \\tab{5}DOUBLE PRECISION FVECC(M),XC(N)\\br \\tab{5}INTEGER I,M,N\\br \\tab{5}FVECC(1)=((XC(1)-2.4D0)*XC(3)+(15.0D0*XC(1)-36.0D0)*XC(2)+1.0D0)/(\\br \\tab{4}&XC(3)+15.0D0*XC(2))\\br \\tab{5}FVECC(2)=((XC(1)-2.8D0)*XC(3)+(7.0D0*XC(1)-19.6D0)*XC(2)+1.0D0)/(X\\br \\tab{4}&C(3)+7.0D0*XC(2))\\br \\tab{5}FVECC(3)=((XC(1)-3.2D0)*XC(3)+(4.333333333333333D0*XC(1)-13.866666\\br \\tab{4}&66666667D0)*XC(2)+1.0D0)/(XC(3)+4.333333333333333D0*XC(2))\\br \\tab{5}FVECC(4)=((XC(1)-3.5D0)*XC(3)+(3.0D0*XC(1)-10.5D0)*XC(2)+1.0D0)/(X\\br \\tab{4}&C(3)+3.0D0*XC(2))\\br \\tab{5}FVECC(5)=((XC(1)-3.9D0)*XC(3)+(2.2D0*XC(1)-8.579999999999998D0)*XC\\br \\tab{4}&(2)+1.0D0)/(XC(3)+2.2D0*XC(2))\\br \\tab{5}FVECC(6)=((XC(1)-4.199999999999999D0)*XC(3)+(1.666666666666667D0*X\\br \\tab{4}&C(1)-7.0D0)*XC(2)+1.0D0)/(XC(3)+1.666666666666667D0*XC(2))\\br \\tab{5}FVECC(7)=((XC(1)-4.5D0)*XC(3)+(1.285714285714286D0*XC(1)-5.7857142\\br \\tab{4}&85714286D0)*XC(2)+1.0D0)/(XC(3)+1.285714285714286D0*XC(2))\\br \\tab{5}FVECC(8)=((XC(1)-4.899999999999999D0)*XC(3)+(XC(1)-4.8999999999999\\br \\tab{4}&99D0)*XC(2)+1.0D0)/(XC(3)+XC(2))\\br \\tab{5}FVECC(9)=((XC(1)-4.699999999999999D0)*XC(3)+(XC(1)-4.6999999999999\\br \\tab{4}&99D0)*XC(2)+1.285714285714286D0)/(XC(3)+XC(2))\\br \\tab{5}FVECC(10)=((XC(1)-6.8D0)*XC(3)+(XC(1)-6.8D0)*XC(2)+1.6666666666666\\br \\tab{4}&67D0)/(XC(3)+XC(2))\\br \\tab{5}FVECC(11)=((XC(1)-8.299999999999999D0)*XC(3)+(XC(1)-8.299999999999\\br \\tab{4}&999D0)*XC(2)+2.2D0)/(XC(3)+XC(2))\\br \\tab{5}FVECC(12)=((XC(1)-10.6D0)*XC(3)+(XC(1)-10.6D0)*XC(2)+3.0D0)/(XC(3)\\br \\tab{4}&+XC(2))\\br \\tab{5}FVECC(13)=((XC(1)-1.34D0)*XC(3)+(XC(1)-1.34D0)*XC(2)+4.33333333333\\br \\tab{4}&3333D0)/(XC(3)+XC(2))\\br \\tab{5}FVECC(14)=((XC(1)-2.1D0)*XC(3)+(XC(1)-2.1D0)*XC(2)+7.0D0)/(XC(3)+X\\br \\tab{4}&C(2))\\br \\tab{5}FVECC(15)=((XC(1)-4.39D0)*XC(3)+(XC(1)-4.39D0)*XC(2)+15.0D0)/(XC(3\\br \\tab{4}&)+XC(2))\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-85 -3201) 
+(-85 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp55} produces Fortran for Type 55 ASPs, needed for NAG routines e04dgf and e04ucf, for example: \\blankline \\tab{5}SUBROUTINE CONFUN(MODE,NCNLN,N,NROWJ,NEEDC,X,C,CJAC,NSTATE,IUSER\\br \\tab{4}&,USER)\\br \\tab{5}DOUBLE PRECISION C(NCNLN),X(N),CJAC(NROWJ,N),USER(*)\\br \\tab{5}INTEGER N,IUSER(*),NEEDC(NCNLN),NROWJ,MODE,NCNLN,NSTATE\\br \\tab{5}IF(NEEDC(1).GT.0)THEN\\br \\tab{7}C(1)=X(6)**2+X(1)**2\\br \\tab{7}CJAC(1,1)=2.0D0*X(1)\\br \\tab{7}CJAC(1,2)=0.0D0\\br \\tab{7}CJAC(1,3)=0.0D0\\br \\tab{7}CJAC(1,4)=0.0D0\\br \\tab{7}CJAC(1,5)=0.0D0\\br \\tab{7}CJAC(1,6)=2.0D0*X(6)\\br \\tab{5}ENDIF\\br \\tab{5}IF(NEEDC(2).GT.0)THEN\\br \\tab{7}C(2)=X(2)**2+(-2.0D0*X(1)*X(2))+X(1)**2\\br \\tab{7}CJAC(2,1)=(-2.0D0*X(2))+2.0D0*X(1)\\br \\tab{7}CJAC(2,2)=2.0D0*X(2)+(-2.0D0*X(1))\\br \\tab{7}CJAC(2,3)=0.0D0\\br \\tab{7}CJAC(2,4)=0.0D0\\br \\tab{7}CJAC(2,5)=0.0D0\\br \\tab{7}CJAC(2,6)=0.0D0\\br \\tab{5}ENDIF\\br \\tab{5}IF(NEEDC(3).GT.0)THEN\\br \\tab{7}C(3)=X(3)**2+(-2.0D0*X(1)*X(3))+X(2)**2+X(1)**2\\br \\tab{7}CJAC(3,1)=(-2.0D0*X(3))+2.0D0*X(1)\\br \\tab{7}CJAC(3,2)=2.0D0*X(2)\\br \\tab{7}CJAC(3,3)=2.0D0*X(3)+(-2.0D0*X(1))\\br \\tab{7}CJAC(3,4)=0.0D0\\br \\tab{7}CJAC(3,5)=0.0D0\\br \\tab{7}CJAC(3,6)=0.0D0\\br \\tab{5}ENDIF\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-86 -3201) 
+(-86 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp6} produces Fortran for Type 6 ASPs, needed for NAG routines c05nbf, c05ncf. These represent vectors of functions of X(i) and look like: \\blankline \\tab{5}SUBROUTINE FCN(N,X,FVEC,IFLAG) \\tab{5}DOUBLE PRECISION X(N),FVEC(N) \\tab{5}INTEGER N,IFLAG \\tab{5}FVEC(1)=(-2.0D0*X(2))+(-2.0D0*X(1)**2)+3.0D0*X(1)+1.0D0 \\tab{5}FVEC(2)=(-2.0D0*X(3))+(-2.0D0*X(2)**2)+3.0D0*X(2)+(-1.0D0*X(1))+1. \\tab{4}&0D0 \\tab{5}FVEC(3)=(-2.0D0*X(4))+(-2.0D0*X(3)**2)+3.0D0*X(3)+(-1.0D0*X(2))+1. \\tab{4}&0D0 \\tab{5}FVEC(4)=(-2.0D0*X(5))+(-2.0D0*X(4)**2)+3.0D0*X(4)+(-1.0D0*X(3))+1. \\tab{4}&0D0 \\tab{5}FVEC(5)=(-2.0D0*X(6))+(-2.0D0*X(5)**2)+3.0D0*X(5)+(-1.0D0*X(4))+1. \\tab{4}&0D0 \\tab{5}FVEC(6)=(-2.0D0*X(7))+(-2.0D0*X(6)**2)+3.0D0*X(6)+(-1.0D0*X(5))+1. \\tab{4}&0D0 \\tab{5}FVEC(7)=(-2.0D0*X(8))+(-2.0D0*X(7)**2)+3.0D0*X(7)+(-1.0D0*X(6))+1. \\tab{4}&0D0 \\tab{5}FVEC(8)=(-2.0D0*X(9))+(-2.0D0*X(8)**2)+3.0D0*X(8)+(-1.0D0*X(7))+1. \\tab{4}&0D0 \\tab{5}FVEC(9)=(-2.0D0*X(9)**2)+3.0D0*X(9)+(-1.0D0*X(8))+1.0D0 \\tab{5}RETURN \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-87 -3201) 
+(-87 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp73} produces Fortran for Type 73 ASPs, needed for NAG routine d03eef, for example: \\blankline \\tab{5}SUBROUTINE PDEF(X,Y,ALPHA,BETA,GAMMA,DELTA,EPSOLN,PHI,PSI)\\br \\tab{5}DOUBLE PRECISION ALPHA,EPSOLN,PHI,X,Y,BETA,DELTA,GAMMA,PSI\\br \\tab{5}ALPHA=DSIN(X)\\br \\tab{5}BETA=Y\\br \\tab{5}GAMMA=X*Y\\br \\tab{5}DELTA=DCOS(X)*DSIN(Y)\\br \\tab{5}EPSOLN=Y+X\\br \\tab{5}PHI=X\\br \\tab{5}PSI=Y\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE X) (QUOTE Y)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-88 -3201) 
+(-88 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp74} produces Fortran for Type 74 ASPs, needed for NAG routine d03eef, for example: \\blankline \\tab{5} SUBROUTINE BNDY(X,Y,A,B,C,IBND)\\br \\tab{5} DOUBLE PRECISION A,B,C,X,Y\\br \\tab{5} INTEGER IBND\\br \\tab{5} IF(IBND.EQ.0)THEN\\br \\tab{7} A=0.0D0\\br \\tab{7} B=1.0D0\\br \\tab{7} C=-1.0D0*DSIN(X)\\br \\tab{5} ELSEIF(IBND.EQ.1)THEN\\br \\tab{7} A=1.0D0\\br \\tab{7} B=0.0D0\\br \\tab{7} C=DSIN(X)*DSIN(Y)\\br \\tab{5} ELSEIF(IBND.EQ.2)THEN\\br \\tab{7} A=1.0D0\\br \\tab{7} B=0.0D0\\br \\tab{7} C=DSIN(X)*DSIN(Y)\\br \\tab{5} ELSEIF(IBND.EQ.3)THEN\\br \\tab{7} A=0.0D0\\br \\tab{7} B=1.0D0\\br \\tab{7} C=-1.0D0*DSIN(Y)\\br \\tab{5} ENDIF\\br \\tab{5} END")) (|coerce| (($ (|Matrix| (|FortranExpression| (|construct| (QUOTE X) (QUOTE Y)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-89 -3201) 
+(-89 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp77} produces Fortran for Type 77 ASPs, needed for NAG routine d02gbf, for example: \\blankline \\tab{5}SUBROUTINE FCNF(X,F)\\br \\tab{5}DOUBLE PRECISION X\\br \\tab{5}DOUBLE PRECISION F(2,2)\\br \\tab{5}F(1,1)=0.0D0\\br \\tab{5}F(1,2)=1.0D0\\br \\tab{5}F(2,1)=0.0D0\\br \\tab{5}F(2,2)=-10.0D0\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Matrix| (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-90 -3201) 
+(-90 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp78} produces Fortran for Type 78 ASPs, needed for NAG routine d02gbf, for example: \\blankline \\tab{5}SUBROUTINE FCNG(X,G)\\br \\tab{5}DOUBLE PRECISION G(*),X\\br \\tab{5}G(1)=0.0D0\\br \\tab{5}G(2)=0.0D0\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-91 -3201) 
+(-91 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp7} produces Fortran for Type 7 ASPs, needed for NAG routines d02bbf, d02gaf. These represent a vector of functions of the scalar \\spad{X} and the array \\spad{Z,} and look like: \\blankline \\tab{5}SUBROUTINE FCN(X,Z,F)\\br \\tab{5}DOUBLE PRECISION F(*),X,Z(*)\\br \\tab{5}F(1)=DTAN(Z(3))\\br \\tab{5}F(2)=((-0.03199999999999999D0*DCOS(Z(3))*DTAN(Z(3)))+(-0.02D0*Z(2)\\br \\tab{4}&**2))/(Z(2)*DCOS(Z(3)))\\br \\tab{5}F(3)=-0.03199999999999999D0/(X*Z(2)**2)\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-92 -3201) 
+(-92 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp80} produces Fortran for Type 80 ASPs, needed for NAG routine d02kef, for example: \\blankline \\tab{5}SUBROUTINE BDYVAL(XL,XR,ELAM,YL,YR)\\br \\tab{5}DOUBLE PRECISION ELAM,XL,YL(3),XR,YR(3)\\br \\tab{5}YL(1)=XL\\br \\tab{5}YL(2)=2.0D0\\br \\tab{5}YR(1)=1.0D0\\br \\tab{5}YR(2)=-1.0D0*DSQRT(XR+(-1.0D0*ELAM))\\br \\tab{5}RETURN\\br \\tab{5}END")) (|coerce| (($ (|Matrix| (|FortranExpression| (|construct| (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-93 -3201) 
+(-93 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp8} produces Fortran for Type 8 ASPs, needed for NAG routine d02bbf. This ASP prints intermediate values of the computed solution of an ODE and might look like: \\blankline \\tab{5}SUBROUTINE OUTPUT(XSOL,Y,COUNT,M,N,RESULT,FORWRD)\\br \\tab{5}DOUBLE PRECISION Y(N),RESULT(M,N),XSOL\\br \\tab{5}INTEGER M,N,COUNT\\br \\tab{5}LOGICAL FORWRD\\br \\tab{5}DOUBLE PRECISION X02ALF,POINTS(8)\\br \\tab{5}EXTERNAL X02ALF\\br \\tab{5}INTEGER I\\br \\tab{5}POINTS(1)=1.0D0\\br \\tab{5}POINTS(2)=2.0D0\\br \\tab{5}POINTS(3)=3.0D0\\br \\tab{5}POINTS(4)=4.0D0\\br \\tab{5}POINTS(5)=5.0D0\\br \\tab{5}POINTS(6)=6.0D0\\br \\tab{5}POINTS(7)=7.0D0\\br \\tab{5}POINTS(8)=8.0D0\\br \\tab{5}COUNT=COUNT+1\\br \\tab{5}DO 25001 I=1,N\\br \\tab{7} RESULT(COUNT,I)=Y(I)\\br 25001 CONTINUE\\br \\tab{5}IF(COUNT.EQ.M)THEN\\br \\tab{7}IF(FORWRD)THEN\\br \\tab{9}XSOL=X02ALF()\\br \\tab{7}ELSE\\br \\tab{9}XSOL=-X02ALF()\\br \\tab{7}ENDIF\\br \\tab{5}ELSE\\br \\tab{7} XSOL=POINTS(COUNT)\\br \\tab{5}ENDIF\\br \\tab{5}END"))) 
 NIL 
 NIL 
-(-94 -3201) 
+(-94 -4095) 
 ((|constructor| (NIL "\\spadtype{Asp9} produces Fortran for Type 9 ASPs, needed for NAG routines d02bhf, d02cjf, d02ejf. These ASPs represent a function of a scalar \\spad{X} and a vector \\spad{Y,} for example: \\blankline \\tab{5}DOUBLE PRECISION FUNCTION G(X,Y)\\br \\tab{5}DOUBLE PRECISION X,Y(*)\\br \\tab{5}G=X+Y(1)\\br \\tab{5}RETURN\\br \\tab{5}END \\blankline If the user provides a constant value for \\spad{G,} then extra information is added via COMMON blocks used by certain routines. This specifies that the value returned by \\spad{G} in this case is to be ignored.")) (|coerce| (($ (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|))) "\\spad{coerce(f)} takes an object from the appropriate instantiation of \\spadtype{FortranExpression} and turns it into an ASP."))) 
 NIL 
 NIL 
 (-95 R L) 
 ((|constructor| (NIL "\\spadtype{AssociatedEquations} provides functions to compute the associated equations needed for factoring operators")) (|associatedEquations| (((|Record| (|:| |minor| (|List| (|PositiveInteger|))) (|:| |eq| |#2|) (|:| |minors| (|List| (|List| (|PositiveInteger|)))) (|:| |ops| (|List| |#2|))) |#2| (|PositiveInteger|)) "\\spad{associatedEquations(op, \\spad{m)}} returns \\spad{[w, eq, \\spad{lw,} lop]} such that \\spad{eq(w) = 0} where \\spad{w} is the given minor, and \\spad{lw_i = lop_i(w)} for all the other minors.")) (|uncouplingMatrices| (((|Vector| (|Matrix| |#1|)) (|Matrix| |#1|)) "\\spad{uncouplingMatrices(M)} returns \\spad{[A_1,...,A_n]} such that if \\spad{y = [y_1,...,y_n]} is a solution of \\spad{y' = \\spad{M} \\spad{y},} then \\spad{[$y_j',y_j'',...,y_j^{(n)}$] = $A_j \\spad{y$}} for all j's.")) (|associatedSystem| (((|Record| (|:| |mat| (|Matrix| |#1|)) (|:| |vec| (|Vector| (|List| (|PositiveInteger|))))) |#2| (|PositiveInteger|)) "\\spad{associatedSystem(op, \\spad{m)}} returns \\spad{[M,w]} such that the \\spad{m}-th associated equation system to \\spad{L} is \\spad{w' = \\spad{M} \\spad{w}.}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368)))) 
+((|HasCategory| |#1| (QUOTE (-388)))) 
 (-96 S) 
 ((|constructor| (NIL "A stack represented as a flexible array.")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} member?(3,a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} count(4,a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} count(x+->(x>2),a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} any?(x+->(x=4),a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} every?(x+->(x=4),a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} b:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} map!(x+->x+10,a) \\spad{X} a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} map(x+->x+10,a) \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} eq?(a,b)")) (|copy| (($ $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} copy a")) (|sample| (($) "\\blankline \\spad{X} sample()$ArrayStack(INT)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()$(ArrayStack INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} empty? a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,2,3,4,5])$ArrayStack(INT)")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} size?(a,5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} more?(a,9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} less?(a,9)")) (|depth| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} depth a")) (|top| ((|#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} top a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} insert!(8,a) \\spad{X} a")) (|push!| ((|#1| |#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} push!(9,a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} extract! a \\spad{X} a")) (|pop!| ((|#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,2,3,4,5] \\spad{X} pop! a \\spad{X} a")) (|arrayStack| (($ (|List| |#1|)) "\\indented{1}{arrayStack([x,y,...,z]) creates an array stack with first (top)} \\indented{1}{element \\spad{x,} second element y,...,and last element \\spad{z.}} \\blankline \\spad{E} c:ArrayStack INT:= arrayStack [1,2,3,4,5]"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-97 S) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-97) 
+((|constructor| (NIL "The class of all euclidean domains such that \\spad{euclideanSize(a*b) = euclideanSize(a)+euclideanSize(b)}"))) 
+((-2623 . T)) 
+NIL 
+(-98) 
+((|constructor| (NIL "An approximation to the real numbers."))) 
+((-2623 . T)) 
+NIL 
+(-99) 
+((|constructor| (NIL "Approximate numbers with arbitrarily large exponents"))) 
+((-2623 . T)) 
+NIL 
+(-100) 
+((|constructor| (NIL "Approximate numbers for which the user can set the precision for subsequent calculations."))) 
+((-2623 . T)) 
+NIL 
+(-101) 
+((|constructor| (NIL "The class of all integral domains such that \\spad{unitCanonical(a)*unitCanonical(b) = unitCanonical(a*b)}"))) 
+((-2623 . T)) 
+NIL 
+(-102) 
+((|constructor| (NIL "The class of all domains which have canonical represenntation, that is, mathematically equal elements ahve the same data structure."))) 
+((-2623 . T)) 
+NIL 
+(-103) 
+((|constructor| (NIL "Central is \\spad{true} if, given an algebra over a ring \\spad{R,} the image of \\spad{R} is the center of the algebra. For example, the set of members of the algebra which commute with all others is precisely the image of \\spad{R} in the algebra."))) 
+((-2623 . T)) 
+NIL 
+(-104) 
+((|constructor| (NIL "The class of all commutative semigroups in multiplicative notation. In other words domain \\spad{D} with \\spad{\"*\": (D,D) \\spad{->} \\spad{D}} which is commutative. Typially applied to rings."))) 
+((-2623 . T)) 
+NIL 
+(-105) 
+((|constructor| (NIL "The class of all integral domains such that we can choose a canonical representative for each class of associate elements. That is, \\spad{associates?(a,b)} returns \\spad{true} if and only if \\spad{unitCanonical(a)} = \\spad{unitCanonical(b)}"))) 
+((-2623 . T)) 
+NIL 
+(-106) 
+((|constructor| (NIL "The class of all aggregates with a finite number of arguments"))) 
+((-2623 . T)) 
+NIL 
+(-107) 
+((|constructor| (NIL "JacobiIdentity means that \\spad{[x,[y,z]]+[y,[z,x]]+[z,[x,y]] = 0} holds. See LieAlgebra."))) 
+((-2623 . T)) 
+NIL 
+(-108) 
+((|constructor| (NIL "The class of all domains which have a lazy representation"))) 
+((-2623 . T)) 
+NIL 
+(-109) 
+((|constructor| (NIL "LeftUnitary is \\spad{true} if \\spad{1 * \\spad{x} = \\spad{x}} for all \\spad{x.}"))) 
+((-2623 . T)) 
+NIL 
+(-110) 
+((|constructor| (NIL "The class of all euclidean domains such that \\spad{euclideanSize(a*b)=euclideanSize(a)*euclideanSize(b)}"))) 
+((-2623 . T)) 
+NIL 
+(-111) 
+((|constructor| (NIL "Notherian is \\spad{true} if all of its ideals are finitely generated."))) 
+((-2623 . T)) 
+NIL 
+(-112) 
+((|constructor| (NIL "NullSquare means that \\spad{[x,x] = 0} holds. See LieAlgebra."))) 
+((-2623 . T)) 
+NIL 
+(-113) 
+((|constructor| (NIL "The class of all semirings such that \\spad{x * \\spad{y} \\spad{~=} 0} implies both \\spad{x} and \\spad{y} are non-zero."))) 
+((-2623 . T)) 
+NIL 
+(-114) 
+((|constructor| (NIL "PartiallyOrderedSet is \\spad{true} if a set with \\spad{<} is transitive, but \\spad{not(a \\spad{<b} or a = b)}. It does not imply \\spad{b < a}"))) 
+((-2623 . T)) 
+NIL 
+(-115 S) 
 ((|constructor| (NIL "Category for the inverse trigonometric functions.")) (|atan| (($ $) "\\spad{atan(x)} returns the arc-tangent of \\spad{x.}")) (|asin| (($ $) "\\spad{asin(x)} returns the arc-sine of \\spad{x.}")) (|asec| (($ $) "\\spad{asec(x)} returns the arc-secant of \\spad{x.}")) (|acsc| (($ $) "\\spad{acsc(x)} returns the arc-cosecant of \\spad{x.}")) (|acot| (($ $) "\\spad{acot(x)} returns the arc-cotangent of \\spad{x.}")) (|acos| (($ $) "\\spad{acos(x)} returns the arc-cosine of \\spad{x.}"))) 
 NIL 
 NIL 
-(-98) 
+(-116) 
 ((|constructor| (NIL "Category for the inverse trigonometric functions.")) (|atan| (($ $) "\\spad{atan(x)} returns the arc-tangent of \\spad{x.}")) (|asin| (($ $) "\\spad{asin(x)} returns the arc-sine of \\spad{x.}")) (|asec| (($ $) "\\spad{asec(x)} returns the arc-secant of \\spad{x.}")) (|acsc| (($ $) "\\spad{acsc(x)} returns the arc-cosecant of \\spad{x.}")) (|acot| (($ $) "\\spad{acot(x)} returns the arc-cotangent of \\spad{x.}")) (|acos| (($ $) "\\spad{acos(x)} returns the arc-cosine of \\spad{x.}"))) 
 NIL 
 NIL 
-(-99) 
+(-117) 
+((|constructor| (NIL "The class of all domains which have immediate components that are updateable in place (mutable). The properties of any component domain are irrevelant to the ShallowlyMutableAttribute."))) 
+((-2623 . T)) 
+NIL 
+(-118) 
 ((|constructor| (NIL "\\axiomType{AttributeButtons} implements a database and associated adjustment mechanisms for a set of attributes. \\blankline For ODEs these attributes are \"stiffness\", \"stability\" (\\spadignore{i.e.} how much affect the cosine or sine component of the solution has on the stability of the result), \"accuracy\" and \"expense\" (\\spadignore{i.e.} how expensive is the evaluation of the ODE). All these have bearing on the cost of calculating the solution given that reducing the step-length to achieve greater accuracy requires considerable number of evaluations and calculations. \\blankline The effect of each of these attributes can be altered by increasing or decreasing the button value. \\blankline For Integration there is a button for increasing and decreasing the preset number of function evaluations for each method. This is automatically used by ANNA when a method fails due to insufficient workspace or where the limit of function evaluations has been reached before the required accuracy is achieved.")) (|setButtonValue| (((|Float|) (|String|) (|String|) (|Float|)) "\\axiom{setButtonValue(attributeName,routineName,n)} sets the value of the button of attribute \\spad{attributeName} to routine \\spad{routineName} to \\spad{n}. \\spad{n} must be in the range [0..1]. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\", \"stability\", \"accuracy\", \"expense\" or \"functionEvaluations\".") (((|Float|) (|String|) (|Float|)) "\\axiom{setButtonValue(attributeName,n)} sets the value of all buttons of attribute \\spad{attributeName} to \\spad{n}. \\spad{n} must be in the range [0..1]. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\", \"stability\", \"accuracy\", \"expense\" or \"functionEvaluations\".")) (|setAttributeButtonStep| (((|Float|) (|Float|)) "\\axiom{setAttributeButtonStep(n)} sets the value of the steps for increasing and decreasing the button values. \\axiom{n} must be greater than 0 and less than 1. The preset value is 0.5.")) (|resetAttributeButtons| (((|Void|)) "\\axiom{resetAttributeButtons()} resets the Attribute buttons to a neutral level.")) (|getButtonValue| (((|Float|) (|String|) (|String|)) "\\axiom{getButtonValue(routineName,attributeName)} returns the current value for the effect of the attribute \\axiom{attributeName} with routine \\axiom{routineName}. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\", \"stability\", \"accuracy\", \"expense\" or \"functionEvaluations\".")) (|decrease| (((|Float|) (|String|)) "\\axiom{decrease(attributeName)} decreases the value for the effect of the attribute \\axiom{attributeName} with all routines. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\", \"stability\", \"accuracy\", \"expense\" or \"functionEvaluations\".") (((|Float|) (|String|) (|String|)) "\\axiom{decrease(routineName,attributeName)} decreases the value for the effect of the attribute \\axiom{attributeName} with routine \\axiom{routineName}. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\", \"stability\", \"accuracy\", \"expense\" or \"functionEvaluations\".")) (|increase| (((|Float|) (|String|)) "\\axiom{increase(attributeName)} increases the value for the effect of the attribute \\axiom{attributeName} with all routines. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\", \"stability\", \"accuracy\", \"expense\" or \"functionEvaluations\".") (((|Float|) (|String|) (|String|)) "\\axiom{increase(routineName,attributeName)} increases the value for the effect of the attribute \\axiom{attributeName} with routine \\axiom{routineName}. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\", \"stability\", \"accuracy\", \"expense\" or \"functionEvaluations\"."))) 
-((-4602 . T)) 
+((-4625 . T)) 
 NIL 
-(-100) 
+(-119) 
 ((|constructor| (NIL "This category exports the attributes in the AXIOM Library")) (|approximate| ((|attribute|) "\\spad{approximate} means \"is an approximation to the real numbers\".")) (|canonical| ((|attribute|) "\\spad{canonical} is \\spad{true} if and only if distinct elements have distinct data structures. For example, a domain of mathematical objects which has the \\spad{canonical} attribute means that two objects are mathematically equal if and only if their data structures are equal.")) (|multiplicativeValuation| ((|attribute|) "\\spad{multiplicativeValuation} implies \\spad{euclideanSize(a*b)=euclideanSize(a)*euclideanSize(b)}.")) (|additiveValuation| ((|attribute|) "\\spad{additiveValuation} implies \\spad{euclideanSize(a*b)=euclideanSize(a)+euclideanSize(b)}.")) (|noetherian| ((|attribute|) "\\spad{noetherian} is \\spad{true} if all of its ideals are finitely generated.")) (|central| ((|attribute|) "\\spad{central} is \\spad{true} if, given an algebra over a ring \\spad{R,} the image of \\spad{R} is the center of the algebra, For example, the set of members of the algebra which commute with all others is precisely the image of \\spad{R} in the algebra.")) (|partiallyOrderedSet| ((|attribute|) "\\spad{partiallyOrderedSet} is \\spad{true} if a set with \\spadop{<} which is transitive, but \\spad{not(a < \\spad{b} or a = \\spad{b)}} does not necessarily imply \\spad{b<a}.")) (|arbitraryPrecision| ((|attribute|) "\\spad{arbitraryPrecision} means the user can set the precision for subsequent calculations.")) (|canonicalsClosed| ((|attribute|) "\\spad{canonicalsClosed} is \\spad{true} if \\spad{unitCanonical(a)*unitCanonical(b) = unitCanonical(a*b)}.")) (|canonicalUnitNormal| ((|attribute|) "\\spad{canonicalUnitNormal} is \\spad{true} if we can choose a canonical representative for each class of associate elements, that is \\spad{associates?(a,b)} returns \\spad{true} if and only if \\spad{unitCanonical(a) = unitCanonical(b)}.")) (|noZeroDivisors| ((|attribute|) "\\spad{noZeroDivisors} is \\spad{true} if \\spad{x * \\spad{y} \\~~= 0} implies both \\spad{x} and \\spad{y} are non-zero.")) (|rightUnitary| ((|attribute|) "\\spad{rightUnitary} is \\spad{true} if \\spad{x * 1 = \\spad{x}} for all \\spad{x.}")) (|leftUnitary| ((|attribute|) "\\spad{leftUnitary} is \\spad{true} if \\spad{1 * \\spad{x} = \\spad{x}} for all \\spad{x.}")) (|unitsKnown| ((|attribute|) "\\spad{unitsKnown} is \\spad{true} if a monoid (a multiplicative semigroup with a 1) has \\spad{unitsKnown} means that the operation \\spadfun{recip} can only return \"failed\" if its argument is not a unit.")) (|shallowlyMutable| ((|attribute|) "\\spad{shallowlyMutable} is \\spad{true} if its values have immediate components that are updateable (mutable). Note that the properties of any component domain are irrevelant to the \\spad{shallowlyMutable} proper.")) (|commutative| ((|attribute| "*") "\\spad{commutative(\"*\")} is \\spad{true} if it has an operation \\spad{\"*\": (D,D) \\spad{->} \\spad{D}} which is commutative.")) (|finiteAggregate| ((|attribute|) "\\spad{finiteAggregate} is \\spad{true} if it is an aggregate with a finite number of elements."))) 
-((-4602 . T) ((-4604 "*") . T) (-4603 . T) (-4599 . T) (-4597 . T) (-4596 . T) (-4595 . T) (-4600 . T) (-4594 . T) (-4593 . T) (-4592 . T) (-4591 . T) (-4590 . T) (-4598 . T) (-4601 . T) (|NullSquare| . T) (|JacobiIdentity| . T) (-4589 . T) (-3410 . T)) 
+((-4625 . T) ((-4627 "*") . T) (-4626 . T) (-4622 . T) (-4620 . T) (-4619 . T) (-4618 . T) (-4623 . T) (-4617 . T) (-4616 . T) (-4615 . T) (-4614 . T) (-4613 . T) (-4621 . T) (-4624 . T) (|NullSquare| . T) (|JacobiIdentity| . T) (-4612 . T) (-2642 . T)) 
 NIL 
-(-101 R) 
+(-120) 
+((|constructor| (NIL "The class of all monoids (multiplicative semigroups with a 1) such that the operation recop can only return \"failed\" if its argument is not a unit."))) 
+((-2623 . T)) 
+NIL 
+(-121 R) 
 ((|constructor| (NIL "Automorphism \\spad{R} is the multiplicative group of automorphisms of \\spad{R.}")) (|morphism| (($ (|Mapping| |#1| |#1| (|Integer|))) "\\spad{morphism(f)} returns the morphism given by \\spad{f^n(x) = f(x,n)}.") (($ (|Mapping| |#1| |#1|) (|Mapping| |#1| |#1|)) "\\spad{morphism(f, \\spad{g)}} returns the invertible morphism given by \\spad{f,} where \\spad{g} is the inverse of \\spad{f..}") (($ (|Mapping| |#1| |#1|)) "\\spad{morphism(f)} returns the non-invertible morphism given by \\spad{f.}"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-102) 
+(-122) 
 ((|constructor| (NIL "This package provides a functions to support a web server for the new Axiom Browser functions."))) 
 NIL 
 NIL 
-(-103 R UP) 
+(-123 R UP) 
 ((|constructor| (NIL "This package provides balanced factorisations of polynomials.")) (|balancedFactorisation| (((|Factored| |#2|) |#2| (|List| |#2|)) "\\spad{balancedFactorisation(a, [b1,...,bn])} returns a factorisation \\spad{a = \\spad{p1^e1} \\spad{...} pm^em} such that each \\spad{pi} is balanced with respect to \\spad{[b1,...,bm]}.") (((|Factored| |#2|) |#2| |#2|) "\\spad{balancedFactorisation(a, \\spad{b)}} returns a factorisation \\spad{a = \\spad{p1^e1} \\spad{...} pm^em} such that each \\spad{pi} is balanced with respect to \\spad{b.}"))) 
 NIL 
 NIL 
-(-104 S) 
+(-124 S) 
 ((|constructor| (NIL "BasicType is the basic category for describing a collection of elements with = (equality).")) (~= (((|Boolean|) $ $) "\\spad{x~=y} tests if \\spad{x} and \\spad{y} are not equal.")) (= (((|Boolean|) $ $) "\\spad{x=y} tests if \\spad{x} and \\spad{y} are equal."))) 
 NIL 
 NIL 
-(-105) 
+(-125) 
 ((|constructor| (NIL "BasicType is the basic category for describing a collection of elements with = (equality).")) (~= (((|Boolean|) $ $) "\\spad{x~=y} tests if \\spad{x} and \\spad{y} are not equal.")) (= (((|Boolean|) $ $) "\\spad{x=y} tests if \\spad{x} and \\spad{y} are equal."))) 
 NIL 
 NIL 
-(-106 S) 
+(-126 S) 
 ((|constructor| (NIL "\\spadtype{BalancedBinaryTree(S)} is the domain of balanced binary trees (bbtree). A balanced binary tree of \\spad{2**k} leaves, for some \\spad{k > 0}, is symmetric, that is, the left and right subtree of each interior node have identical shape. In general, the left and right subtree of a given node can differ by at most leaf node.")) (|mapDown!| (($ $ |#1| (|Mapping| (|List| |#1|) |#1| |#1| |#1|)) "\\indented{1}{mapDown!(t,p,f) returns \\spad{t} after traversing \\spad{t} in \"preorder\"} \\indented{1}{(node then left then right) fashion replacing the successive} \\indented{1}{interior nodes as follows. Let \\spad{l} and \\spad{r} denote the left and} \\indented{1}{right subtrees of \\spad{t.} The root value \\spad{x} of \\spad{t} is replaced by \\spad{p.}} \\indented{1}{Then f(value \\spad{l,} value \\spad{r,} \\spad{p),} where \\spad{l} and \\spad{r} denote the left} \\indented{1}{and right subtrees of \\spad{t,} is evaluated producing two values} \\indented{1}{pl and \\spad{pr.} Then \\spad{mapDown!(l,pl,f)} and \\spad{mapDown!(l,pr,f)}} \\indented{1}{are evaluated.} \\blankline \\spad{X} T1:=BalancedBinaryTree Integer \\spad{X} t2:=balancedBinaryTree(4, 0)$T1 \\spad{X} setleaves!(t2,[1,2,3,4]::List(Integer)) \\spad{X} adder3(i:Integer,j:Integer,k:Integer):List Integer \\spad{==} [i+j,j+k] \\spad{X} mapDown!(t2,4::INT,adder3) \\spad{X} \\spad{t2}") (($ $ |#1| (|Mapping| |#1| |#1| |#1|)) "\\indented{1}{mapDown!(t,p,f) returns \\spad{t} after traversing \\spad{t} in \"preorder\"} \\indented{1}{(node then left then right) fashion replacing the successive} \\indented{1}{interior nodes as follows. The root value \\spad{x} is} \\indented{1}{replaced by \\spad{q} \\spad{:=} f(p,x). The mapDown!(l,q,f) and} \\indented{1}{mapDown!(r,q,f) are evaluated for the left and right subtrees} \\indented{1}{l and \\spad{r} of \\spad{t.}} \\blankline \\spad{X} T1:=BalancedBinaryTree Integer \\spad{X} t2:=balancedBinaryTree(4, 0)$T1 \\spad{X} setleaves!(t2,[1,2,3,4]::List(Integer)) \\spad{X} adder(i:Integer,j:Integer):Integer \\spad{==} i+j \\spad{X} mapDown!(t2,4::INT,adder) \\spad{X} \\spad{t2}")) (|mapUp!| (($ $ $ (|Mapping| |#1| |#1| |#1| |#1| |#1|)) "\\indented{1}{mapUp!(t,t1,f) traverses balanced binary tree \\spad{t} in an \"endorder\"} \\indented{1}{(left then right then node) fashion returning \\spad{t} with the value} \\indented{1}{at each successive interior node of \\spad{t} replaced \\spad{by}} \\indented{1}{f(l,r,l1,r1) where \\spad{l} and \\spad{r} are the values at the immediate} \\indented{1}{left and right nodes. Values \\spad{l1} and \\spad{r1} are values at the} \\indented{1}{corresponding nodes of a balanced binary tree \\spad{t1,} of identical} \\indented{1}{shape at \\spad{t.}} \\blankline \\spad{X} T1:=BalancedBinaryTree Integer \\spad{X} t2:=balancedBinaryTree(4, 0)$T1 \\spad{X} setleaves!(t2,[1,2,3,4]::List(Integer)) \\spad{X} adder4(i:INT,j:INT,k:INT,l:INT):INT \\spad{==} i+j+k+l \\spad{X} mapUp!(t2,t2,adder4) \\spad{X} \\spad{t2}") ((|#1| $ (|Mapping| |#1| |#1| |#1|)) "\\indented{1}{mapUp!(t,f) traverses balanced binary tree \\spad{t} in an \"endorder\"} \\indented{1}{(left then right then node) fashion returning \\spad{t} with the value} \\indented{1}{at each successive interior node of \\spad{t} replaced \\spad{by}} \\indented{1}{f(l,r) where \\spad{l} and \\spad{r} are the values at the immediate} \\indented{1}{left and right nodes.} \\blankline \\spad{X} T1:=BalancedBinaryTree Integer \\spad{X} t2:=balancedBinaryTree(4, 0)$T1 \\spad{X} setleaves!(t2,[1,2,3,4]::List(Integer)) \\spad{X} adder(a:Integer,b:Integer):Integer \\spad{==} a+b \\spad{X} mapUp!(t2,adder) \\spad{X} \\spad{t2}")) (|setleaves!| (($ $ (|List| |#1|)) "\\indented{1}{setleaves!(t, \\spad{ls)} sets the leaves of \\spad{t} in left-to-right order} \\indented{1}{to the elements of ls.} \\blankline \\spad{X} t1:=balancedBinaryTree(4, 0) \\spad{X} setleaves!(t1,[1,2,3,4])")) (|balancedBinaryTree| (($ (|NonNegativeInteger|) |#1|) "\\indented{1}{balancedBinaryTree(n, \\spad{s)} creates a balanced binary tree with} \\indented{1}{n nodes each with value \\spad{s.}} \\blankline \\spad{X} balancedBinaryTree(4, 0)"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-107 R) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-127 R) 
 ((|constructor| (NIL "Provide linear, quadratic, and cubic spline bezier curves")) (|cubicBezier| (((|Mapping| (|List| |#1|) |#1|) (|List| |#1|) (|List| |#1|) (|List| |#1|) (|List| |#1|)) "\\indented{1}{A cubic Bezier curve is a simple interpolation between the} \\indented{1}{starting point, a left-middle point,, a right-middle point,} \\indented{1}{and the ending point based on a parameter \\spad{t.}} \\indented{1}{Given a start point a=[x1,y1], the left-middle point b=[x2,y2],} \\indented{1}{the right-middle point c=[x3,y3] and an endpoint d=[x4,y4]} \\indented{1}{f(t) \\spad{==} \\spad{[(1-t)^3} \\spad{x1} + 3t(1-t)^2 \\spad{x2} + 3t^2 (1-t) \\spad{x3} + \\spad{t^3} x4,} \\indented{10}{(1-t)^3 \\spad{y1} + 3t(1-t)^2 \\spad{y2} + 3t^2 (1-t) \\spad{y3} + \\spad{t^3} y4]} \\blankline \\spad{X} n:=cubicBezier([2.0,2.0],[2.0,4.0],[6.0,4.0],[6.0,2.0]) \\spad{X} [n(t/10.0) for \\spad{t} in 0..10 by 1]")) (|quadraticBezier| (((|Mapping| (|List| |#1|) |#1|) (|List| |#1|) (|List| |#1|) (|List| |#1|)) "\\indented{1}{A quadratic Bezier curve is a simple interpolation between the} \\indented{1}{starting point, a middle point, and the ending point based on} \\indented{1}{a parameter \\spad{t.}} \\indented{1}{Given a start point a=[x1,y1], a middle point b=[x2,y2],} \\indented{1}{and an endpoint c=[x3,y3]} \\indented{1}{f(t) \\spad{==} \\spad{[(1-t)^2} \\spad{x1} + 2t(1-t) \\spad{x2} + \\spad{t^2} x3,} \\indented{10}{(1-t)^2 \\spad{y1} + 2t(1-t) \\spad{y2} + \\spad{t^2} y3]} \\blankline \\spad{X} n:=quadraticBezier([2.0,2.0],[4.0,4.0],[6.0,2.0]) \\spad{X} [n(t/10.0) for \\spad{t} in 0..10 by 1]")) (|linearBezier| (((|Mapping| (|List| |#1|) |#1|) (|List| |#1|) (|List| |#1|)) "\\indented{1}{A linear Bezier curve is a simple interpolation between the} \\indented{1}{starting point and the ending point based on a parameter \\spad{t.}} \\indented{1}{Given a start point a=[x1,y1] and an endpoint b=[x2,y2]} \\indented{1}{f(t) \\spad{==} \\spad{[(1-t)*x1} + t*x2, \\spad{(1-t)*y1} + t*y2]} \\blankline \\spad{X} n:=linearBezier([2.0,2.0],[4.0,4.0]) \\spad{X} [n(t/10.0) for \\spad{t} in 0..10 by 1]"))) 
 NIL 
 NIL 
-(-108 R UP M |Row| |Col|) 
+(-128 R UP M |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{BezoutMatrix} contains functions for computing resultants and discriminants using Bezout matrices.")) (|bezoutDiscriminant| ((|#1| |#2|) "\\spad{bezoutDiscriminant(p)} computes the discriminant of a polynomial \\spad{p} by computing the determinant of a Bezout matrix.")) (|bezoutResultant| ((|#1| |#2| |#2|) "\\spad{bezoutResultant(p,q)} computes the resultant of the two polynomials \\spad{p} and \\spad{q} by computing the determinant of a Bezout matrix.")) (|bezoutMatrix| ((|#3| |#2| |#2|) "\\spad{bezoutMatrix(p,q)} returns the Bezout matrix for the two polynomials \\spad{p} and \\spad{q.}")) (|sylvesterMatrix| ((|#3| |#2| |#2|) "\\spad{sylvesterMatrix(p,q)} returns the Sylvester matrix for the two polynomials \\spad{p} and \\spad{q.}"))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE (-4604 "*")))) 
-(-109) 
+((|HasAttribute| |#1| (QUOTE (-4627 "*")))) 
+(-129) 
 ((|constructor| (NIL "A Domain which implements a table containing details of points at which particular functions have evaluation problems.")) (|bfEntry| (((|Record| (|:| |zeros| (|Stream| (|DoubleFloat|))) (|:| |ones| (|Stream| (|DoubleFloat|))) (|:| |singularities| (|Stream| (|DoubleFloat|)))) (|Symbol|)) "\\spad{bfEntry(k)} returns the entry in the \\axiomType{BasicFunctions} table corresponding to \\spad{k}")) (|bfKeys| (((|List| (|Symbol|))) "\\spad{bfKeys()} returns the names of each function in the \\axiomType{BasicFunctions} table"))) 
-((-4602 . T)) 
+((-4625 . T)) 
 NIL 
-(-110 A S) 
+(-130 A S) 
 ((|constructor| (NIL "A bag aggregate is an aggregate for which one can insert and extract objects, and where the order in which objects are inserted determines the order of extraction. Examples of bags are stacks, queues, and dequeues.")) (|inspect| ((|#2| $) "\\spad{inspect(u)} returns an (random) element from a bag.")) (|insert!| (($ |#2| $) "\\spad{insert!(x,u)} inserts item \\spad{x} into bag u.")) (|extract!| ((|#2| $) "\\spad{extract!(u)} destructively removes a (random) item from bag u.")) (|bag| (($ (|List| |#2|)) "\\spad{bag([x,y,...,z])} creates a bag with elements x,y,...,z.")) (|shallowlyMutable| ((|attribute|) "shallowlyMutable means that elements of bags may be destructively changed."))) 
 NIL 
 NIL 
-(-111 S) 
+(-131 S) 
 ((|constructor| (NIL "A bag aggregate is an aggregate for which one can insert and extract objects, and where the order in which objects are inserted determines the order of extraction. Examples of bags are stacks, queues, and dequeues.")) (|inspect| ((|#1| $) "\\spad{inspect(u)} returns an (random) element from a bag.")) (|insert!| (($ |#1| $) "\\spad{insert!(x,u)} inserts item \\spad{x} into bag u.")) (|extract!| ((|#1| $) "\\spad{extract!(u)} destructively removes a (random) item from bag u.")) (|bag| (($ (|List| |#1|)) "\\spad{bag([x,y,...,z])} creates a bag with elements x,y,...,z.")) (|shallowlyMutable| ((|attribute|) "shallowlyMutable means that elements of bags may be destructively changed."))) 
-((-4603 . T) (-3389 . T)) 
+((-4626 . T) (-2623 . T)) 
 NIL 
-(-112) 
+(-132) 
 ((|constructor| (NIL "This domain allows rational numbers to be presented as repeating binary expansions.")) (|binary| (($ (|Fraction| (|Integer|))) "\\indented{1}{binary(r) converts a rational number to a binary expansion.} \\blankline \\spad{X} binary(22/7)")) (|fractionPart| (((|Fraction| (|Integer|)) $) "\\spad{fractionPart(b)} returns the fractional part of a binary expansion.")) (|coerce| (((|RadixExpansion| 2) $) "\\spad{coerce(b)} converts a binary expansion to a radix expansion with base 2.") (((|Fraction| (|Integer|)) $) "\\spad{coerce(b)} converts a binary expansion to a rational number."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-572) (QUOTE (-910))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-572) (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-151))) (|HasCategory| (-572) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-572) (QUOTE (-1028))) (|HasCategory| (-572) (QUOTE (-821))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1144))) (|HasCategory| (-572) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| (-572) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| (-572) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| (-572) (QUOTE (-227))) (|HasCategory| (-572) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-572) (LIST (QUOTE -527) (QUOTE (-1170)) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -283) (QUOTE (-572)) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-303))) (|HasCategory| (-572) (QUOTE (-554))) (|HasCategory| (-572) (QUOTE (-848))) (-1841 (|HasCategory| (-572) (QUOTE (-821))) (|HasCategory| (-572) (QUOTE (-848)))) (|HasCategory| (-572) (LIST (QUOTE -634) (QUOTE (-572)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-910)))) (|HasCategory| (-572) (QUOTE (-149))))) 
-(-113) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-592) (QUOTE (-931))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-592) (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-171))) (|HasCategory| (-592) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-592) (QUOTE (-1049))) (|HasCategory| (-592) (QUOTE (-842))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1165))) (|HasCategory| (-592) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| (-592) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| (-592) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| (-592) (QUOTE (-247))) (|HasCategory| (-592) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-592) (LIST (QUOTE -547) (QUOTE (-1191)) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -303) (QUOTE (-592)) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-323))) (|HasCategory| (-592) (QUOTE (-574))) (|HasCategory| (-592) (QUOTE (-869))) (-3836 (|HasCategory| (-592) (QUOTE (-842))) (|HasCategory| (-592) (QUOTE (-869)))) (|HasCategory| (-592) (LIST (QUOTE -654) (QUOTE (-592)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-931)))) (|HasCategory| (-592) (QUOTE (-169))))) 
+(-133) 
 ((|constructor| (NIL "This domain provides an implementation of binary files. Data is accessed one byte at a time as a small integer.")) (|position!| (((|SingleInteger|) $ (|SingleInteger|)) "\\spad{position!(f, i)} sets the current byte-position to i.")) (|position| (((|SingleInteger|) $) "\\spad{position(f)} returns the current byte-position in the file \\spad{f.}")) (|readIfCan!| (((|Union| (|SingleInteger|) "failed") $) "\\spad{readIfCan!(f)} returns a value from the file \\spad{f,} if possible. If \\spad{f} is not open for reading, or if \\spad{f} is at the end of file then \\spad{\"failed\"} is the result."))) 
 NIL 
 NIL 
-(-114) 
+(-134) 
 ((|constructor| (NIL "\\spadtype{Bits} provides logical functions for Indexed Bits.")) (|bits| (($ (|NonNegativeInteger|) (|Boolean|)) "\\spad{bits(n,b)} creates bits with \\spad{n} values of \\spad{b}"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-121) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-121) (QUOTE (-848))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-121) (QUOTE (-1098))) (-12 (|HasCategory| (-121) (LIST (QUOTE -305) (QUOTE (-121)))) (|HasCategory| (-121) (QUOTE (-1098))))) 
-(-115) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-141) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-141) (QUOTE (-869))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-141) (QUOTE (-1119))) (-12 (|HasCategory| (-141) (LIST (QUOTE -325) (QUOTE (-141)))) (|HasCategory| (-141) (QUOTE (-1119))))) 
+(-135) 
 ((|constructor| (NIL "This package provides an interface to the Blas library (level 1)")) (|zaxpy| (((|PrimitiveArray| (|Complex| (|DoubleFloat|))) (|SingleInteger|) (|Complex| (|DoubleFloat|)) (|PrimitiveArray| (|Complex| (|DoubleFloat|))) (|SingleInteger|) (|PrimitiveArray| (|Complex| (|DoubleFloat|))) (|SingleInteger|)) "\\spad{zaxpy(n,da,x,incx,y,incy)} computes a \\spad{y} = a*x + \\spad{y} for each of the chosen elements of the vectors \\spad{x} and \\spad{y} and a constant multiplier a Note that the vector \\spad{y} is modified with the results. \\blankline \\spad{X} a:PRIMARR(COMPLEX(DFLOAT)) \\spad{X} a:=[[3.+4.*\\%i, -4.+5.*\\%i, 5.+6.*%i, 7.-8.*%i, -9.-2.*\\%i]] \\spad{X} b:PRIMARR(COMPLEX(DFLOAT)) \\spad{X} b:=[[3.+4.*\\%i, -4.+5.*\\%i, 5.+6.*%i, 7.-8.*%i, -9.-2.*\\%i]] \\spad{X} zaxpy(3,2.0,a,1,b,1) \\spad{X} b:=[[3.+4.*\\%i, -4.+5.*\\%i, 5.+6.*%i, 7.-8.*%i, -9.-2.*\\%i]] \\spad{X} zaxpy(5,2.0,a,1,b,1) \\spad{X} b:=[[3.+4.*\\%i, -4.+5.*\\%i, 5.+6.*%i, 7.-8.*%i, -9.-2.*\\%i]] \\spad{X} zaxpy(3,2.0,a,3,b,3) \\spad{X} b:=[[3.+4.*\\%i, -4.+5.*\\%i, 5.+6.*%i, 7.-8.*%i, -9.-2.*\\%i]] \\spad{X} zaxpy(4,2.0,a,2,b,2)")) (|izamax| (((|Integer|) (|SingleInteger|) (|PrimitiveArray| (|Complex| (|DoubleFloat|))) (|SingleInteger|)) "\\spad{izamax computes} the largest absolute value of the elements of the array and returns the index of the first instance of the maximum. \\blankline \\spad{X} a:PRIMARR(COMPLEX(DFLOAT)) \\spad{X} a:=[[3.+4.*\\%i,-4.+5.*\\%i,5.+6.*\\%i,7.-8.*\\%i,-9.-2.*\\%i]] \\spad{X} izamax(5,a,1) \\spad{--} should be 3 \\spad{X} izamax(0,a,1) \\spad{--} should be \\spad{-1} \\spad{X} izamax(5,a,-1) \\spad{--} should be \\spad{-1} \\spad{X} izamax(3,a,1) \\spad{--} should be 2 \\spad{X} izamax(3,a,2) \\spad{--} should be 1")) (|isamax| (((|Integer|) (|Integer|) (|PrimitiveArray| (|Float|)) (|Integer|)) "\\spad{isamax computes} the largest absolute value of the elements of the array and returns the index of the first instance of the maximum. \\blankline \\spad{X} a:PRIMARR(FLOAT):=[[3.0, 4.0, -3.0, 5.0, -1.0]] \\spad{X} isamax(5,a,1) \\spad{--} should be 3 \\spad{X} isamax(3,a,1) \\spad{--} should be 1 \\spad{X} isamax(0,a,1) \\spad{--} should be \\spad{-1} \\spad{X} isamax(-5,a,1) \\spad{--} should be \\spad{-1} \\spad{X} isamax(5,a,-1) \\spad{--} should be \\spad{-1} \\spad{X} isamax(5,a,2) \\spad{--} should be 0 \\spad{X} isamax(1,a,0) \\spad{--} should be \\spad{-1} \\spad{X} isamax(1,a,-1) \\spad{--} should be \\spad{-1} \\spad{X} a:PRIMARR(FLOAT):=[[3.0, 4.0, -3.0, -5.0, -1.0]] \\spad{X} isamax(5,a,1) \\spad{--} should be 3")) (|idamax| (((|Integer|) (|Integer|) (|PrimitiveArray| (|DoubleFloat|)) (|Integer|)) "\\spad{idamax computes} the largest absolute value of the elements of the array and returns the index of the first instance of the maximum. \\blankline \\spad{X} a:PRIMARR(DFLOAT):=[[3.0, 4.0, -3.0, 5.0, -1.0]] \\spad{X} idamax(5,a,1) \\spad{--} should be 3 \\spad{X} idamax(3,a,1) \\spad{--} should be 1 \\spad{X} idamax(0,a,1) \\spad{--} should be \\spad{-1} \\spad{X} idamax(-5,a,1) \\spad{--} should be \\spad{-1} \\spad{X} idamax(5,a,-1) \\spad{--} should be \\spad{-1} \\spad{X} idamax(5,a,2) \\spad{--} should be 0 \\spad{X} idamax(1,a,0) \\spad{--} should be \\spad{-1} \\spad{X} idamax(1,a,-1) \\spad{--} should be \\spad{-1} \\spad{X} a:PRIMARR(DFLOAT):=[[3.0, 4.0, -3.0, -5.0, -1.0]] \\spad{X} idamax(5,a,1) \\spad{--} should be 3")) (|icamax| (((|Integer|) (|Integer|) (|PrimitiveArray| (|Complex| (|Float|))) (|Integer|)) "\\spad{icamax computes} the largest absolute value of the elements of the array and returns the index of the first instance of the maximum \\blankline \\spad{X} a:PRIMARR(COMPLEX(FLOAT)) \\spad{X} a:=[[3.+4.*\\%i,-4.+5.*\\%i,5.+6.*\\%i,7.-8.*\\%i,-9.-2.*\\%i]] \\spad{X} icamax(5,a,1) \\spad{--} should be 3 \\spad{X} icamax(0,a,1) \\spad{--} should be \\spad{-1} \\spad{X} icamax(5,a,-1) \\spad{--} should be \\spad{-1} \\spad{X} icamax(3,a,1) \\spad{--} should be 2 \\spad{X} icamax(3,a,2) \\spad{--} should be 1")) (|dznrm2| (((|DoubleFloat|) (|SingleInteger|) (|PrimitiveArray| (|Complex| (|DoubleFloat|))) (|SingleInteger|)) "\\spad{dznrm2 returns} the norm of a complex vector. It computes sqrt(sum(v*conjugate(v))) \\blankline \\spad{X} a:PRIMARR(COMPLEX(DFLOAT)) \\spad{X} a:=[[3.+4.*\\%i,-4.+5.*\\%i,5.+6.*\\%i,7.-8.*\\%i,-9.-2.*\\%i]] \\spad{X} dznrm2(5,a,1) \\spad{--} should be 18.028 \\spad{X} dznrm2(3,a,2) \\spad{--} should be 13.077 \\spad{X} dznrm2(3,a,1) \\spad{--} should be 11.269 \\spad{X} dznrm2(3,a,-1) \\spad{--} should be 0.0 \\spad{X} dznrm2(-3,a,-1) \\spad{--} should be 0.0 \\spad{X} dznrm2(1,a,1) \\spad{--} should be 5.0 \\spad{X} dznrm2(1,a,2) \\spad{--} should be 5.0")) (|dzasum| (((|DoubleFloat|) (|SingleInteger|) (|PrimitiveArray| (|Complex| (|DoubleFloat|))) (|SingleInteger|)) "\\spad{dzasum takes} the sum over all of the array where each element of the array sum is the sum of the absolute value of the real part and the absolute value of the imaginary part of each array element: \\indented{3}{for \\spad{i} in array do sum = sum + (real(a(i)) + imag(a(i)))} \\blankline \\spad{X} d:PRIMARR(COMPLEX(DFLOAT)):=[[1.0+2.0*\\%i,-3.0+4.0*\\%i,5.0-6.0*\\%i]] \\spad{X} dzasum(3,d,1) \\spad{--} 21.0 \\spad{X} dzasum(3,d,2) \\spad{--} 14.0 \\spad{X} dzasum(-3,d,1) \\spad{--} 0.0")) (|dswap| (((|List| (|PrimitiveArray| (|DoubleFloat|))) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\spad{dswap swaps} elements from the first vector with the second Note that the arrays are modified in place. \\blankline \\spad{X} dx:PRIMARR(DFLOAT):=[[1.0, 2.0, 3.0, 4.0, 5.0, 6.0]] \\spad{X} dy:PRIMARR(DFLOAT):=[[1.0, 2.0, 3.0, 4.0, 5.0, 6.0]] \\spad{X} dswap(5,dx,1,dy,1) \\spad{X} dx:PRIMARR(DFLOAT):=[[1.0, 2.0, 3.0, 4.0, 5.0, 6.0]] \\spad{X} dy:PRIMARR(DFLOAT):=[[1.0, 2.0, 3.0, 4.0, 5.0, 6.0]] \\spad{X} dswap(3,dx,2,dy,2) \\spad{X} dx:PRIMARR(DFLOAT):=[[1.0, 2.0, 3.0, 4.0, 5.0, 6.0]] \\spad{X} dy:PRIMARR(DFLOAT):=[[1.0, 2.0, 3.0, 4.0, 5.0, 6.0]] \\spad{X} dswap(5,dx,1,dy,-1)")) (|dscal| (((|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|DoubleFloat|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\spad{dscal scales} each element of the vector by the scalar so dscal(n,da,dx,incx) = da*dx for \\spad{n} elements, incremented by incx Note that the \\spad{dx} array is modified in place. \\blankline \\spad{X} dx:PRIMARR(DFLOAT):=[[1.0, 2.0, 3.0, 4.0, 5.0, 6.0]] \\spad{X} dscal(6,2.0,dx,1) \\spad{X} \\spad{dx} \\spad{X} dx:PRIMARR(DFLOAT):=[[1.0, 2.0, 3.0, 4.0, 5.0, 6.0]] \\spad{X} dscal(3,0.5,dx,1) \\spad{X} \\spad{dx}")) (|drot| (((|List| (|PrimitiveArray| (|DoubleFloat|))) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{drot computes} a 2D plane Givens rotation spanned by two coordinate axes. It modifies the arrays in place. The call drot(n,dx,incx,dy,incy,c,s) has the \\spad{dx} array which contains the \\spad{y} axis locations and dy which contains the \\spad{y} axis locations. They are rotated in parallel where \\spad{c} is the cosine of the angle and \\spad{s} is the sine of the angle and \\spad{c^2+s^2} = 1 \\blankline \\spad{X} dx:PRIMARR(DFLOAT):=[[6,0, 1.0, 4.0, -1.0, -1.0]] \\spad{X} dy:PRIMARR(DFLOAT):=[[5.0, 1.0, -4.0, 4.0, -4.0]] \\spad{X} drot(5,dx,1,dy,1,0.707106781,0.707106781) \\spad{--} rotate by 45 degrees \\spad{X} \\spad{dx} \\spad{--} \\spad{dx} has been modified \\spad{X} dy \\spad{--} dy has been modified \\spad{X} drot(5,dx,1,dy,1,0.707106781,-0.707106781) \\spad{--} rotate by \\spad{-45} degrees \\spad{X} \\spad{dx} \\spad{--} \\spad{dx} has been modified \\spad{X} dy \\spad{--} dy has been modified")) (|drotg| (((|PrimitiveArray| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{drotg computes} a 2D plane Givens rotation spanned by two coordinate axes. \\blankline \\spad{X} a:MATRIX(DFLOAT):=[[6,5,0],[5,1,4],[0,4,3]] \\spad{X} drotg(elt(a,1,1),elt(a,1,2),0.0D0,0.0D0)")) (|dnrm2| (((|DoubleFloat|) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\spad{dnrm2 takes} the norm of the vector, ||x|| \\blankline \\spad{X} a:PRIMARR(DFLOAT):=[[3.0, -4.0, 5.0, -7.0, 9.0]] \\spad{X} dnrm2(3,a,1) \\spad{--} 7.0710678118654755 = \\spad{sqrt(3.0^2} + \\spad{-4.0^2} + 5.0^2) \\spad{X} dnrm2(5,a,1) \\spad{--} 13.416407864998739 = sqrt(180.0) \\spad{X} dnrm2(3,a,2) \\spad{--} 10.72380529476361 = sqrt(115.0)")) (|ddot| (((|DoubleFloat|) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\spad{ddot(n,x,incx,y,incy)} computes the vector dot product of elements from the vector \\spad{x} and the vector \\spad{y} If the indicies are negative the elements are taken relative to the far end of the vector. \\blankline \\spad{X} x:PRIMARR(DFLOAT):=[[1.0,2.0,3.0,4.0,5.0]] \\spad{X} y:PRIMARR(DFLOAT):=[[5.0,6.0,7.0,8.0,9.0]] \\spad{X} ddot(0,a,1,b,1) \\spad{--} handle 0 elements \\spad{==>} 0 \\spad{X} ddot(3,a,1,b,1) \\spad{--} (1,2,3) * (5,6,7) \\spad{==>} 38.0 \\spad{X} ddot(3,a,1,b,2) \\spad{--} increment = 2 in \\spad{b} (1,2,3) * (5,7,9) \\spad{==>} 46.0 \\spad{X} ddot(3,a,2,b,1) \\spad{--} increment = 2 in a (1,3,5) * (5,6,7) \\spad{==>} 58.0 \\spad{X} ddot(3,a,1,b,-2) \\spad{--} increment = \\spad{-2} in \\spad{b} (1,2,3) * (9,7,5) \\spad{==>} 38.0 \\spad{X} ddot(2,a,-2,b,1) \\spad{--} increment = \\spad{-2} in a (5,3,1) * (5,6,7) \\spad{==>} 50.0 \\spad{X} ddot(3,a,-2,b,-2) \\spad{--} (5,3,1) * (9,7,5) \\spad{==>} 71.0")) (|dcopy| (((|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\spad{dcopy(n,x,incx,y,incy)} copies \\spad{y} from \\spad{x} for each of the chosen elements of the vectors \\spad{x} and \\spad{y} Note that the vector \\spad{y} is modified with the results. \\blankline \\spad{X} x:PRIMARR(DFLOAT):=[[1.0,2.0,3.0,4.0,5.0,6.0]] \\spad{X} y:PRIMARR(DFLOAT):=[[0.0,0.0,0.0,0.0,0.0,0.0]] \\spad{X} dcopy(6,x,1,y,1) \\spad{X} \\spad{y} \\spad{X} m:PRIMARR(DFLOAT):=[[1.0,2.0,3.0]] \\spad{X} n:PRIMARR(DFLOAT):=[[0.0,0.0,0.0,0.0,0.0,0.0]] \\spad{X} dcopy(3,m,1,n,2) \\spad{X} \\spad{n}")) (|daxpy| (((|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|DoubleFloat|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\spad{daxpy(n,da,x,incx,y,incy)} computes a \\spad{y} = a*x + \\spad{y} for each of the chosen elements of the vectors \\spad{x} and \\spad{y} and a constant multiplier a Note that the vector \\spad{y} is modified with the results. \\blankline \\spad{X} x:PRIMARR(DFLOAT):=[[1.0,2.0,3.0,4.0,5.0,6.0]] \\spad{X} y:PRIMARR(DFLOAT):=[[1.0,2.0,3.0,4.0,5.0,6.0]] \\spad{X} daxpy(6,2.0,x,1,y,1) \\spad{X} \\spad{y} \\spad{X} m:PRIMARR(DFLOAT):=[[1.0,2.0,3.0]] \\spad{X} n:PRIMARR(DFLOAT):=[[1.0,2.0,3.0,4.0,5.0,6.0]] \\spad{X} daxpy(3,-2.0,m,1,n,2) \\spad{X} \\spad{n}")) (|dasum| (((|DoubleFloat|) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\spad{dasum(n,array,incx)} computes the sum of \\spad{n} elements in \\spad{array} using a stride of \\spad{incx} \\blankline \\spad{X} dx:PRIMARR(DFLOAT):=[[1.0,2.0,3.0,4.0,5.0,6.0]] \\spad{X} dasum(6,dx,1) \\spad{X} dasum(3,dx,2)")) (|dcabs1| (((|DoubleFloat|) (|Complex| (|DoubleFloat|))) "\\spad{dcabs1(z)} computes \\spad{(+} (abs (realpart \\spad{z))} (abs (imagpart z))) \\blankline \\spad{X} t1:Complex DoubleFloat \\spad{:=} complex(1.0,0) \\spad{X} dcabs1(t1)"))) 
 NIL 
 NIL 
-(-116) 
+(-136) 
 ((|constructor| (NIL "This domain is part of the PAFF package"))) 
 ((|HamburgerNoether| . T)) 
 NIL 
-(-117) 
+(-137) 
 NIL 
 NIL 
 NIL 
-(-118) 
+(-138) 
 ((|constructor| (NIL "This domain is part of the PAFF package"))) 
 ((|QuadraticTransform| . T)) 
 NIL 
-(-119 K |symb| |PolyRing| E BLMET) 
+(-139 K |symb| |PolyRing| E BLMET) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|stepBlowUp| (((|Record| (|:| |mult| (|NonNegativeInteger|)) (|:| |subMult| (|NonNegativeInteger|)) (|:| |blUpRec| (|List| (|Record| (|:| |recTransStr| (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) |#1|)) (|:| |recPoint| (|AffinePlane| |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) |#1|) (|AffinePlane| |#1|) |#5| |#1|) "\\spad{stepBlowUp(pol,pt,n)} blow-up the point \\spad{pt} on the curve defined by \\spad{pol} in the affine neighbourhood specified by \\spad{n.}")) (|quadTransform| (((|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) |#1|) (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) |#1|) (|NonNegativeInteger|) |#5|) "\\spad{quadTransform(pol,n,chart)} apply the quadratique transformation to \\spad{pol} specified by \\spad{chart} has in quadTransform(pol,chart) and extract x**n to it, where \\spad{x} is the variable specified by the first integer in \\spad{chart} (blow-up exceptional coordinate).")) (|applyTransform| ((|#3| |#3| |#5|) "quadTransform(pol,chart) apply the quadratique transformation to pol specified by chart which consist of 3 integers. The last one indicates which varibles is set to 1, the first on indicates which variable remains unchange, and the second one indicates which variable oon which the transformation is applied. For example, [2,3,1] correspond to the following: \\spad{x} \\spad{->} 1, \\spad{y} \\spad{->} \\spad{y,} \\spad{z} \\spad{->} \\spad{yz} (here the variable are [x,y,z] in BlUpRing)."))) 
 NIL 
 NIL 
-(-120 R S) 
+(-140 R S) 
 ((|constructor| (NIL "A \\spadtype{BiModule} is both a left and right module with respect to potentially different rings. \\blankline Axiom\\br \\tab{5}\\spad{r*(x*s) = (r*x)*s}")) (|rightUnitary| ((|attribute|) "\\spad{x * 1 = \\spad{x}}")) (|leftUnitary| ((|attribute|) "\\spad{1 * \\spad{x} = \\spad{x}}"))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-121) 
+(-141) 
 ((|constructor| (NIL "\\spadtype{Boolean} is the elementary logic with 2 values: \\spad{true} and \\spad{false}")) (|test| (((|Boolean|) $) "\\spad{test(b)} returns \\spad{b} and is provided for compatibility with the new compiler.")) (|implies| (($ $ $) "\\spad{implies(a,b)} returns the logical implication of Boolean \\spad{a} and \\spad{b.}")) (|nor| (($ $ $) "\\spad{nor(a,b)} returns the logical negation of \\spad{a} or \\spad{b.}")) (|nand| (($ $ $) "\\spad{nand(a,b)} returns the logical negation of \\spad{a} and \\spad{b.}")) (|xor| (($ $ $) "\\spad{xor(a,b)} returns the logical exclusive or of Boolean \\spad{a} and \\spad{b.}")) (|or| (($ $ $) "\\spad{a or \\spad{b}} returns the logical inclusive or of Boolean \\spad{a} and \\spad{b.}")) (|and| (($ $ $) "\\spad{a and \\spad{b}} returns the logical and of Boolean \\spad{a} and \\spad{b.}")) (|not| (($ $) "\\spad{not \\spad{n}} returns the negation of \\spad{n.}")) (^ (($ $) "\\spad{^ \\spad{n}} returns the negation of \\spad{n.}")) (|false| (($) "\\spad{false} is a logical constant.")) (|true| (($) "\\spad{true} is a logical constant."))) 
 NIL 
 NIL 
-(-122 A) 
+(-142 A) 
 ((|constructor| (NIL "This package exports functions to set some commonly used properties of operators, including properties which contain functions.")) (|constantOpIfCan| (((|Union| |#1| "failed") (|BasicOperator|)) "\\spad{constantOpIfCan(op)} returns \\spad{a} if \\spad{op} is the constant nullary operator always returning \\spad{a}, \"failed\" otherwise.")) (|constantOperator| (((|BasicOperator|) |#1|) "\\spad{constantOperator(a)} returns a nullary operator op such that \\spad{op()} always evaluate to \\spad{a}.")) (|derivative| (((|Union| (|List| (|Mapping| |#1| (|List| |#1|))) "failed") (|BasicOperator|)) "\\spad{derivative(op)} returns the value of the \"\\%diff\" property of \\spad{op} if it has one, and \"failed\" otherwise.") (((|BasicOperator|) (|BasicOperator|) (|Mapping| |#1| |#1|)) "\\spad{derivative(op, foo)} attaches foo as the \"\\%diff\" property of op. If \\spad{op} has an \"\\%diff\" property \\spad{f,} then applying a derivation \\spad{D} to op(a) returns \\spad{f(a) * D(a)}. Argument \\spad{op} must be unary.") (((|BasicOperator|) (|BasicOperator|) (|List| (|Mapping| |#1| (|List| |#1|)))) "\\spad{derivative(op, [foo1,...,foon])} attaches [foo1,...,foon] as the \"\\%diff\" property of op. If \\spad{op} has an \"\\%diff\" property \\spad{[f1,...,fn]} then applying a derivation \\spad{D} to \\spad{op(a1,...,an)} returns \\spad{f1(a1,...,an) * D(a1) + \\spad{...} + fn(a1,...,an) * D(an)}.")) (|evaluate| (((|Union| (|Mapping| |#1| (|List| |#1|)) "failed") (|BasicOperator|)) "\\spad{evaluate(op)} returns the value of the \"\\%eval\" property of \\spad{op} if it has one, and \"failed\" otherwise.") (((|BasicOperator|) (|BasicOperator|) (|Mapping| |#1| |#1|)) "\\spad{evaluate(op, foo)} attaches foo as the \"\\%eval\" property of op. If \\spad{op} has an \"\\%eval\" property \\spad{f,} then applying \\spad{op} to a returns the result of \\spad{f(a)}. Argument \\spad{op} must be unary.") (((|BasicOperator|) (|BasicOperator|) (|Mapping| |#1| (|List| |#1|))) "\\spad{evaluate(op, foo)} attaches foo as the \"\\%eval\" property of op. If \\spad{op} has an \"\\%eval\" property \\spad{f,} then applying \\spad{op} to \\spad{(a1,...,an)} returns the result of \\spad{f(a1,...,an)}.") (((|Union| |#1| "failed") (|BasicOperator|) (|List| |#1|)) "\\spad{evaluate(op, [a1,...,an])} checks if \\spad{op} has an \"\\%eval\" property \\spad{f.} If it has, then \\spad{f(a1,...,an)} is returned, and \"failed\" otherwise."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-848)))) 
-(-123) 
+((|HasCategory| |#1| (QUOTE (-869)))) 
+(-143) 
 ((|constructor| (NIL "Basic system operators. A basic operator is an object that can be applied to a list of arguments from a set, the result being a kernel over that set.")) (|setProperties| (($ $ (|AssociationList| (|String|) (|None|))) "\\spad{setProperties(op, \\spad{l)}} sets the property list of \\spad{op} to \\spad{l.} Argument \\spad{op} is modified \"in place\", \\spadignore{i.e.} no copy is made.")) (|setProperty| (($ $ (|String|) (|None|)) "\\spad{setProperty(op, \\spad{s,} \\spad{v)}} attaches property \\spad{s} to op, and sets its value to \\spad{v.} Argument \\spad{op} is modified \"in place\", \\spadignore{i.e.} no copy is made.")) (|property| (((|Union| (|None|) "failed") $ (|String|)) "\\spad{property(op, \\spad{s)}} returns the value of property \\spad{s} if it is attached to op, and \"failed\" otherwise.")) (|deleteProperty!| (($ $ (|String|)) "\\spad{deleteProperty!(op, \\spad{s)}} unattaches property \\spad{s} from op. Argument \\spad{op} is modified \"in place\", \\spadignore{i.e.} no copy is made.")) (|assert| (($ $ (|String|)) "\\spad{assert(op, \\spad{s)}} attaches property \\spad{s} to op. Argument \\spad{op} is modified \"in place\", \\spadignore{i.e.} no copy is made.")) (|has?| (((|Boolean|) $ (|String|)) "\\spad{has?(op, \\spad{s)}} tests if property \\spad{s} is attached to op.")) (|is?| (((|Boolean|) $ (|Symbol|)) "\\spad{is?(op, \\spad{s)}} tests if the name of \\spad{op} is \\spad{s.}")) (|input| (((|Union| (|Mapping| (|InputForm|) (|List| (|InputForm|))) "failed") $) "\\spad{input(op)} returns the \"\\%input\" property of \\spad{op} if it has one attached, \"failed\" otherwise.") (($ $ (|Mapping| (|InputForm|) (|List| (|InputForm|)))) "\\spad{input(op, foo)} attaches foo as the \"\\%input\" property of op. If \\spad{op} has a \"\\%input\" property \\spad{f,} then \\spad{op(a1,...,an)} gets converted to InputForm as \\spad{f(a1,...,an)}.")) (|display| (($ $ (|Mapping| (|OutputForm|) (|OutputForm|))) "\\spad{display(op, foo)} attaches foo as the \"\\%display\" property of op. If \\spad{op} has a \"\\%display\" property \\spad{f,} then \\spad{op(a)} gets converted to OutputForm as \\spad{f(a)}. Argument \\spad{op} must be unary.") (($ $ (|Mapping| (|OutputForm|) (|List| (|OutputForm|)))) "\\spad{display(op, foo)} attaches foo as the \"\\%display\" property of op. If \\spad{op} has a \"\\%display\" property \\spad{f,} then \\spad{op(a1,...,an)} gets converted to OutputForm as \\spad{f(a1,...,an)}.") (((|Union| (|Mapping| (|OutputForm|) (|List| (|OutputForm|))) "failed") $) "\\spad{display(op)} returns the \"\\%display\" property of \\spad{op} if it has one attached, and \"failed\" otherwise.")) (|comparison| (($ $ (|Mapping| (|Boolean|) $ $)) "\\spad{comparison(op, foo?)} attaches foo? as the \"\\%less?\" property to op. If \\spad{op1} and \\spad{op2} have the same name, and one of them has a \"\\%less?\" property \\spad{f,} then \\spad{f(op1, op2)} is called to decide whether \\spad{op1 < op2}.")) (|equality| (($ $ (|Mapping| (|Boolean|) $ $)) "\\spad{equality(op, foo?)} attaches foo? as the \"\\%equal?\" property to op. If \\spad{op1} and \\spad{op2} have the same name, and one of them has an \"\\%equal?\" property \\spad{f,} then \\spad{f(op1, op2)} is called to decide whether \\spad{op1} and \\spad{op2} should be considered equal.")) (|weight| (($ $ (|NonNegativeInteger|)) "\\spad{weight(op, \\spad{n)}} attaches the weight \\spad{n} to op.") (((|NonNegativeInteger|) $) "\\spad{weight(op)} returns the weight attached to op.")) (|nary?| (((|Boolean|) $) "\\spad{nary?(op)} tests if \\spad{op} has arbitrary arity.")) (|unary?| (((|Boolean|) $) "\\spad{unary?(op)} tests if \\spad{op} is unary.")) (|nullary?| (((|Boolean|) $) "\\spad{nullary?(op)} tests if \\spad{op} is nullary.")) (|arity| (((|Union| (|NonNegativeInteger|) "failed") $) "\\spad{arity(op)} returns \\spad{n} if \\spad{op} is n-ary, and \"failed\" if \\spad{op} has arbitrary arity.")) (|operator| (($ (|Symbol|) (|NonNegativeInteger|)) "\\spad{operator(f, \\spad{n)}} makes \\spad{f} into an n-ary operator.") (($ (|Symbol|)) "\\spad{operator(f)} makes \\spad{f} into an operator with arbitrary arity.")) (|copy| (($ $) "\\spad{copy(op)} returns a copy of op.")) (|properties| (((|AssociationList| (|String|) (|None|)) $) "\\spad{properties(op)} returns the list of all the properties currently attached to op.")) (|name| (((|Symbol|) $) "\\spad{name(op)} returns the name of op."))) 
 NIL 
 NIL 
-(-124 -3313 UP) 
+(-144 -3958 UP) 
 ((|constructor| (NIL "\\spadtype{BoundIntegerRoots} provides functions to find lower bounds on the integer roots of a polynomial.")) (|integerBound| (((|Integer|) |#2|) "\\spad{integerBound(p)} returns a lower bound on the negative integer roots of \\spad{p,} and 0 if \\spad{p} has no negative integer roots."))) 
 NIL 
 NIL 
-(-125 |p|) 
+(-145 |p|) 
 ((|constructor| (NIL "Stream-based implementation of \\spad{Zp:} p-adic numbers are represented as sum(i = 0.., a[i] * p^i), where the a[i] lie in \\spad{-(p} - 1)/2,...,(p - 1)/2."))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-126 |p|) 
+(-146 |p|) 
 ((|constructor| (NIL "Stream-based implementation of \\spad{Qp:} numbers are represented as sum(i = k.., a[i] * p^i), where the a[i] lie in \\spad{-(p} - 1)/2,...,(p - 1)/2."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-125 |#1|) (QUOTE (-910))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-125 |#1|) (QUOTE (-149))) (|HasCategory| (-125 |#1|) (QUOTE (-151))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-125 |#1|) (QUOTE (-1028))) (|HasCategory| (-125 |#1|) (QUOTE (-821))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-125 |#1|) (QUOTE (-1144))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| (-125 |#1|) (QUOTE (-227))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -527) (QUOTE (-1170)) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -305) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -283) (LIST (QUOTE -125) (|devaluate| |#1|)) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (QUOTE (-303))) (|HasCategory| (-125 |#1|) (QUOTE (-554))) (|HasCategory| (-125 |#1|) (QUOTE (-848))) (-1841 (|HasCategory| (-125 |#1|) (QUOTE (-821))) (|HasCategory| (-125 |#1|) (QUOTE (-848)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-125 |#1|) (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-125 |#1|) (QUOTE (-910)))) (|HasCategory| (-125 |#1|) (QUOTE (-149))))) 
-(-127 A S) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-145 |#1|) (QUOTE (-931))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-145 |#1|) (QUOTE (-169))) (|HasCategory| (-145 |#1|) (QUOTE (-171))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-145 |#1|) (QUOTE (-1049))) (|HasCategory| (-145 |#1|) (QUOTE (-842))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-145 |#1|) (QUOTE (-1165))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| (-145 |#1|) (QUOTE (-247))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -547) (QUOTE (-1191)) (LIST (QUOTE -145) (|devaluate| |#1|)))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -325) (LIST (QUOTE -145) (|devaluate| |#1|)))) (|HasCategory| (-145 |#1|) (LIST (QUOTE -303) (LIST (QUOTE -145) (|devaluate| |#1|)) (LIST (QUOTE -145) (|devaluate| |#1|)))) (|HasCategory| (-145 |#1|) (QUOTE (-323))) (|HasCategory| (-145 |#1|) (QUOTE (-574))) (|HasCategory| (-145 |#1|) (QUOTE (-869))) (-3836 (|HasCategory| (-145 |#1|) (QUOTE (-842))) (|HasCategory| (-145 |#1|) (QUOTE (-869)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-145 |#1|) (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-145 |#1|) (QUOTE (-931)))) (|HasCategory| (-145 |#1|) (QUOTE (-169))))) 
+(-147 A S) 
 ((|constructor| (NIL "A binary-recursive aggregate has 0, 1 or 2 children and serves as a model for a binary tree or a doubly-linked aggregate structure")) (|setright!| (($ $ $) "\\spad{setright!(a,x)} sets the right child of \\spad{t} to be \\spad{x.}")) (|setleft!| (($ $ $) "\\spad{setleft!(a,b)} sets the left child of \\axiom{a} to be \\spad{b.}")) (|setelt| (($ $ "right" $) "\\spad{setelt(a,\"right\",b)} (also written \\axiom{b . right \\spad{:=} \\spad{b})} is equivalent to \\axiom{setright!(a,b)}.") (($ $ "left" $) "\\spad{setelt(a,\"left\",b)} (also written \\axiom{a . left \\spad{:=} \\spad{b})} is equivalent to \\axiom{setleft!(a,b)}.")) (|right| (($ $) "\\spad{right(a)} returns the right child.")) (|elt| (($ $ "right") "\\spad{elt(a,\"right\")} (also written: \\axiom{a . right}) is equivalent to \\axiom{right(a)}.") (($ $ "left") "\\spad{elt(u,\"left\")} (also written: \\axiom{a . left}) is equivalent to \\axiom{left(a)}.")) (|left| (($ $) "\\spad{left(u)} returns the left child."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4603))) 
-(-128 S) 
+((|HasAttribute| |#1| (QUOTE -4626))) 
+(-148 S) 
 ((|constructor| (NIL "A binary-recursive aggregate has 0, 1 or 2 children and serves as a model for a binary tree or a doubly-linked aggregate structure")) (|setright!| (($ $ $) "\\spad{setright!(a,x)} sets the right child of \\spad{t} to be \\spad{x.}")) (|setleft!| (($ $ $) "\\spad{setleft!(a,b)} sets the left child of \\axiom{a} to be \\spad{b.}")) (|setelt| (($ $ "right" $) "\\spad{setelt(a,\"right\",b)} (also written \\axiom{b . right \\spad{:=} \\spad{b})} is equivalent to \\axiom{setright!(a,b)}.") (($ $ "left" $) "\\spad{setelt(a,\"left\",b)} (also written \\axiom{a . left \\spad{:=} \\spad{b})} is equivalent to \\axiom{setleft!(a,b)}.")) (|right| (($ $) "\\spad{right(a)} returns the right child.")) (|elt| (($ $ "right") "\\spad{elt(a,\"right\")} (also written: \\axiom{a . right}) is equivalent to \\axiom{right(a)}.") (($ $ "left") "\\spad{elt(u,\"left\")} (also written: \\axiom{a . left}) is equivalent to \\axiom{left(a)}.")) (|left| (($ $) "\\spad{left(u)} returns the left child."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-129 UP) 
+(-149 UP) 
 ((|constructor| (NIL "This package has no description")) (|noLinearFactor?| (((|Boolean|) |#1|) "\\spad{noLinearFactor?(p)} returns \\spad{true} if \\spad{p} can be shown to have no linear factor by a theorem of Lehmer, \\spad{false} else. \\spad{I} insist on the fact that \\spad{false} does not mean that \\spad{p} has a linear factor.")) (|brillhartTrials| (((|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{brillhartTrials(n)} sets to \\spad{n} the number of tests in \\spadfun{brillhartIrreducible?} and returns the previous value.") (((|NonNegativeInteger|)) "\\spad{brillhartTrials()} returns the number of tests in \\spadfun{brillhartIrreducible?}.")) (|brillhartIrreducible?| (((|Boolean|) |#1| (|Boolean|)) "\\spad{brillhartIrreducible?(p,noLinears)} returns \\spad{true} if \\spad{p} can be shown to be irreducible by a remark of Brillhart, \\spad{false} else. If \\spad{noLinears} is \\spad{true}, we are being told \\spad{p} has no linear factors \\spad{false} does not mean that \\spad{p} is reducible.") (((|Boolean|) |#1|) "\\spad{brillhartIrreducible?(p)} returns \\spad{true} if \\spad{p} can be shown to be irreducible by a remark of Brillhart, \\spad{false} is inconclusive."))) 
 NIL 
 NIL 
-(-130) 
+(-150) 
 ((|constructor| (NIL "Based on Symbol: a domain of symbols representing basic stochastic differentials, used in StochasticDifferential(R) in the underlying sparse multivariate polynomial representation. \\blankline We create new \\spad{BSD} only by coercion from Symbol using a special function introduce! first of all to add to a private set SDset. We allow a separate function convertIfCan which will check whether the argument has previously been declared as a BSD.")) (|getSmgl| (((|Union| (|Symbol|) "failed") $) "\\indented{1}{getSmgl(bsd) returns the semimartingale \\axiom{S} related} \\indented{1}{to the basic stochastic differential \\axiom{bsd} \\spad{by}} \\indented{1}{\\axiom{introduce!}} \\blankline \\spad{X} introduce!(t,dt) \\spad{--} \\spad{dt} is a new stochastic differential \\spad{X} getSmgl(dt::BSD)")) (|copyIto| (((|Table| (|Symbol|) $)) "\\indented{1}{copyIto() returns the table relating semimartingales} \\indented{1}{to basic stochastic differentials.} \\blankline \\spad{X} introduce!(t,dt) \\spad{--} \\spad{dt} is a new stochastic differential \\spad{X} copyIto()")) (|copyBSD| (((|List| $)) "\\indented{1}{copyBSD() returns \\axiom{setBSD} as a list of \\axiom{BSD}.} \\blankline \\spad{X} introduce!(t,dt) \\spad{--} \\spad{dt} is a new stochastic differential \\spad{X} copyBSD()")) (|d| (((|Union| $ (|Integer|)) (|Symbol|)) "\\spad{d(X)} returns \\axiom{dX} if \\axiom{tableIto(X)=dX} and otherwise returns \\axiom{0}")) (|introduce!| (((|Union| $ "failed") (|Symbol|) (|Symbol|)) "\\indented{1}{introduce!(X,dX) returns \\axiom{dX} as \\axiom{BSD} if it} \\indented{1}{isn't already in \\axiom{BSD}} \\blankline \\spad{X} introduce!(t,dt) \\spad{--} \\spad{dt} is a new stochastic differential \\spad{X} copyBSD()")) (|convert| (($ (|Symbol|)) "\\spad{convert(dX)} transforms \\axiom{dX} into a \\axiom{BSD} if possible and otherwise produces an error.")) (|convertIfCan| (((|Union| $ "failed") (|Symbol|)) "\\spad{convertIfCan(ds)} transforms \\axiom{dX} into a \\axiom{BSD} if possible (if \\axiom{introduce(X,dX)} has been invoked previously)."))) 
 NIL 
 NIL 
-(-131 S) 
+(-151 S) 
 ((|constructor| (NIL "BinarySearchTree(S) is the domain of a binary trees where elements are ordered across the tree. A binary search tree is either empty or has a value which is an \\spad{S,} and a right and left which are both BinaryTree(S) Elements are ordered across the tree.")) (|split| (((|Record| (|:| |less| $) (|:| |greater| $)) |#1| $) "\\indented{1}{split(x,b) splits binary tree \\spad{b} into two trees, one with elements} \\indented{1}{greater than \\spad{x,} the other with elements less than \\spad{x.}} \\blankline \\spad{X} t1:=binarySearchTree [1,2,3,4] \\spad{X} split(3,t1)")) (|insertRoot!| (($ |#1| $) "\\indented{1}{insertRoot!(x,b) inserts element \\spad{x} as a root of binary search tree \\spad{b.}} \\blankline \\spad{X} t1:=binarySearchTree [1,2,3,4] \\spad{X} insertRoot!(5,t1)")) (|insert!| (($ |#1| $) "\\indented{1}{insert!(x,b) inserts element \\spad{x} as leaves into binary search tree \\spad{b.}} \\blankline \\spad{X} t1:=binarySearchTree [1,2,3,4] \\spad{X} insert!(5,t1)")) (|binarySearchTree| (($ (|List| |#1|)) "\\indented{1}{binarySearchTree(l) is not documented} \\blankline \\spad{X} binarySearchTree [1,2,3,4]"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-132 S) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-152 S) 
 ((|constructor| (NIL "The bit aggregate category models aggregates representing large quantities of Boolean data.")) (|xor| (($ $ $) "\\spad{xor(a,b)} returns the logical exclusive-or of bit aggregates \\axiom{a} and \\axiom{b}.")) (|or| (($ $ $) "\\spad{a or \\spad{b}} returns the logical or of bit aggregates \\axiom{a} and \\axiom{b}.")) (|and| (($ $ $) "\\spad{a and \\spad{b}} returns the logical and of bit aggregates \\axiom{a} and \\axiom{b}.")) (|nor| (($ $ $) "\\spad{nor(a,b)} returns the logical nor of bit aggregates \\axiom{a} and \\axiom{b}.")) (|nand| (($ $ $) "\\spad{nand(a,b)} returns the logical nand of bit aggregates \\axiom{a} and \\axiom{b}.")) (^ (($ $) "\\spad{^ \\spad{b}} returns the logical not of bit aggregate \\axiom{b}.")) (|not| (($ $) "\\spad{not(b)} returns the logical not of bit aggregate \\axiom{b}."))) 
 NIL 
 NIL 
-(-133) 
+(-153) 
 ((|constructor| (NIL "The bit aggregate category models aggregates representing large quantities of Boolean data.")) (|xor| (($ $ $) "\\spad{xor(a,b)} returns the logical exclusive-or of bit aggregates \\axiom{a} and \\axiom{b}.")) (|or| (($ $ $) "\\spad{a or \\spad{b}} returns the logical or of bit aggregates \\axiom{a} and \\axiom{b}.")) (|and| (($ $ $) "\\spad{a and \\spad{b}} returns the logical and of bit aggregates \\axiom{a} and \\axiom{b}.")) (|nor| (($ $ $) "\\spad{nor(a,b)} returns the logical nor of bit aggregates \\axiom{a} and \\axiom{b}.")) (|nand| (($ $ $) "\\spad{nand(a,b)} returns the logical nand of bit aggregates \\axiom{a} and \\axiom{b}.")) (^ (($ $) "\\spad{^ \\spad{b}} returns the logical not of bit aggregate \\axiom{b}.")) (|not| (($ $) "\\spad{not(b)} returns the logical not of bit aggregate \\axiom{b}."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-134 A S) 
+(-154 A S) 
 ((|constructor| (NIL "\\spadtype{BinaryTreeCategory(S)} is the category of binary trees: a tree which is either empty or else is a \\spadfun{node} consisting of a value and a \\spadfun{left} and \\spadfun{right}, both binary trees.")) (|node| (($ $ |#2| $) "\\spad{node(left,v,right)} creates a binary tree with value \\spad{v}, a binary tree \\spad{left}, and a binary tree \\spad{right}. \\blankline")) (|finiteAggregate| ((|attribute|) "Binary trees have a finite number of components")) (|shallowlyMutable| ((|attribute|) "Binary trees have updateable components"))) 
 NIL 
 NIL 
-(-135 S) 
+(-155 S) 
 ((|constructor| (NIL "\\spadtype{BinaryTreeCategory(S)} is the category of binary trees: a tree which is either empty or else is a \\spadfun{node} consisting of a value and a \\spadfun{left} and \\spadfun{right}, both binary trees.")) (|node| (($ $ |#1| $) "\\spad{node(left,v,right)} creates a binary tree with value \\spad{v}, a binary tree \\spad{left}, and a binary tree \\spad{right}. \\blankline")) (|finiteAggregate| ((|attribute|) "Binary trees have a finite number of components")) (|shallowlyMutable| ((|attribute|) "Binary trees have updateable components"))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-136 S) 
+(-156 S) 
 ((|constructor| (NIL "BinaryTournament creates a binary tournament with the elements of \\spad{ls} as values at the nodes.")) (|insert!| (($ |#1| $) "\\indented{1}{insert!(x,b) inserts element \\spad{x} as leaves into binary tournament \\spad{b.}} \\blankline \\spad{X} t1:=binaryTournament [1,2,3,4] \\spad{X} insert!(5,t1) \\spad{X} \\spad{t1}")) (|binaryTournament| (($ (|List| |#1|)) "\\indented{1}{binaryTournament(ls) creates a binary tournament with the} \\indented{1}{elements of \\spad{ls} as values at the nodes.} \\blankline \\spad{X} binaryTournament [1,2,3,4]"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-137 S) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-157 S) 
 ((|constructor| (NIL "\\spadtype{BinaryTree(S)} is the domain of all binary trees. A binary tree over \\spad{S} is either empty or has a \\spadfun{value} which is an \\spad{S} and a \\spadfun{right} and \\spadfun{left} which are both binary trees.")) (|binaryTree| (($ $ |#1| $) "\\indented{1}{binaryTree(l,v,r) creates a binary tree with} \\indented{1}{value \\spad{v} with left subtree \\spad{l} and right subtree \\spad{r.}} \\blankline \\spad{X} t1:=binaryTree([1,2,3]) \\spad{X} t2:=binaryTree([4,5,6]) \\spad{X} binaryTree(t1,[7,8,9],t2)") (($ |#1|) "\\indented{1}{binaryTree(v) is an non-empty binary tree} \\indented{1}{with value \\spad{v,} and left and right empty.} \\blankline \\spad{X} t1:=binaryTree([1,2,3])"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-138) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-158) 
 ((|constructor| (NIL "This is an \\spadtype{AbelianMonoid} with the cancellation property, \\spadignore{i.e.} \\tab{5}\\spad{ a+b = a+c \\spad{=>} \\spad{b=c} }.\\br This is formalised by the partial subtraction operator, which satisfies the Axioms\\br \\tab{5}\\spad{c = a+b \\spad{<=>} \\spad{c-b} = a}")) (|subtractIfCan| (((|Union| $ "failed") $ $) "\\spad{subtractIfCan(x, \\spad{y)}} returns an element \\spad{z} such that \\spad{z+y=x} or \"failed\" if no such element exists."))) 
 NIL 
 NIL 
-(-139) 
+(-159) 
 ((|constructor| (NIL "A cachable set is a set whose elements keep an integer as part of their structure.")) (|setPosition| (((|Void|) $ (|NonNegativeInteger|)) "\\spad{setPosition(x, \\spad{n)}} associates the integer \\spad{n} to \\spad{x.}")) (|position| (((|NonNegativeInteger|) $) "\\spad{position(x)} returns the integer \\spad{n} associated to \\spad{x.}"))) 
 NIL 
 NIL 
-(-140) 
+(-160) 
 ((|constructor| (NIL "Members of the domain CardinalNumber are values indicating the cardinality of sets, both finite and infinite. Arithmetic operations are defined on cardinal numbers as follows. \\blankline If \\spad{x = \\spad{#X}} and \\spad{y = \\spad{#Y}} then\\br \\tab{5}\\spad{x+y = \\#(X+Y)} \\tab{5}disjoint union\\br \\tab{5}\\spad{x-y = \\#(X-Y)} \\tab{5}relative complement\\br \\tab{5}\\spad{x*y = \\#(X*Y)} \\tab{5}cartesian product\\br \\tab{5}\\spad{x**y = \\#(X**Y)} \\tab{4}\\spad{X**Y = \\spad{g|} g:Y->X} \\blankline The non-negative integers have a natural construction as cardinals\\br \\spad{0 = \\#\\{\\}}, \\spad{1 = \\{0\\}}, \\spad{2 = \\{0, 1\\}}, ..., \\spad{n = \\{i| 0 \\spad{<=} \\spad{i} < n\\}}. \\blankline That \\spad{0} acts as a zero for the multiplication of cardinals is equivalent to the axiom of choice. \\blankline The generalized continuum hypothesis asserts \\spad{\\br} \\spad{2**Aleph \\spad{i} = Aleph(i+1)} and is independent of the axioms of set theory [Goedel 1940]. \\blankline Three commonly encountered cardinal numbers are\\br \\tab{5}\\spad{a = \\spad{#Z}} \\tab{5}countable infinity\\br \\tab{5}\\spad{c = \\spad{#R}} \\tab{5}the continuum\\br \\tab{5}\\spad{f = \\# \\spad{g} | g:[0,1]->R\\} \\blankline In this domain, these values are obtained using\\br \\tab{5}\\spad{a \\spad{:=} Aleph 0}, \\spad{c \\spad{:=} 2**a}, \\spad{f \\spad{:=} 2**c}.")) (|generalizedContinuumHypothesisAssumed| (((|Boolean|) (|Boolean|)) "\\indented{1}{generalizedContinuumHypothesisAssumed(bool)} \\indented{1}{is used to dictate whether the hypothesis is to be assumed.} \\blankline \\spad{X} generalizedContinuumHypothesisAssumed \\spad{true} \\spad{X} a:=Aleph 0 \\spad{X} c:=2**a \\spad{X} f:=2**c")) (|generalizedContinuumHypothesisAssumed?| (((|Boolean|)) "\\indented{1}{generalizedContinuumHypothesisAssumed?()} \\indented{1}{tests if the hypothesis is currently assumed.} \\blankline \\spad{X} generalizedContinuumHypothesisAssumed?")) (|countable?| (((|Boolean|) $) "\\indented{1}{countable?(\\spad{a}) determines} \\indented{1}{whether \\spad{a} is a countable cardinal,} \\indented{1}{\\spadignore{i.e.} an integer or \\spad{Aleph 0}.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} countable? \\spad{c2} \\spad{X} A0:=Aleph 0 \\spad{X} countable? \\spad{A0} \\spad{X} A1:=Aleph 1 \\spad{X} countable? \\spad{A1}")) (|finite?| (((|Boolean|) $) "\\indented{1}{finite?(\\spad{a}) determines whether} \\indented{1}{\\spad{a} is a finite cardinal, \\spadignore{i.e.} an integer.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} finite? \\spad{c2} \\spad{X} A0:=Aleph 0 \\spad{X} finite? \\spad{A0}")) (|Aleph| (($ (|NonNegativeInteger|)) "\\indented{1}{Aleph(n) provides the named (infinite) cardinal number.} \\blankline \\spad{X} A0:=Aleph 0")) (** (($ $ $) "\\indented{1}{\\spad{x**y} returns \\spad{\\#(X**Y)} where \\spad{X**Y} is defined} \\indented{2}{as \\spad{\\{g| g:Y->X\\}}.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} \\spad{c2**c2} \\spad{X} A1:=Aleph 1 \\spad{X} \\spad{A1**c2} \\spad{X} generalizedContinuumHypothesisAssumed \\spad{true} \\spad{X} \\spad{A1**A1}")) (- (((|Union| $ "failed") $ $) "\\indented{1}{\\spad{x - \\spad{y}} returns an element \\spad{z} such that} \\indented{1}{\\spad{z+y=x} or \"failed\" if no such element exists.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} \\spad{c2-c2} \\spad{X} A1:=Aleph 1 \\spad{X} \\spad{A1-c2}")) (|commutative| ((|attribute| "*") "a domain \\spad{D} has \\spad{commutative(\"*\")} if it has an operation \\spad{\"*\": (D,D) \\spad{->} \\spad{D}} which is commutative."))) 
-(((-4604 "*") . T)) 
+(((-4627 "*") . T)) 
 NIL 
-(-141 |minix| -3465 S T$) 
+(-161 |minix| -3832 S T$) 
 ((|constructor| (NIL "This package provides functions to enable conversion of tensors given conversion of the components.")) (|map| (((|CartesianTensor| |#1| |#2| |#4|) (|Mapping| |#4| |#3|) (|CartesianTensor| |#1| |#2| |#3|)) "\\spad{map(f,ts)} does a componentwise conversion of the tensor \\spad{ts} to a tensor with components of type \\spad{T.}")) (|reshape| (((|CartesianTensor| |#1| |#2| |#4|) (|List| |#4|) (|CartesianTensor| |#1| |#2| |#3|)) "\\spad{reshape(lt,ts)} organizes the list of components \\spad{lt} into a tensor with the same shape as \\spad{ts.}"))) 
 NIL 
 NIL 
-(-142 |minix| -3465 R) 
+(-162 |minix| -3832 R) 
 ((|constructor| (NIL "CartesianTensor(minix,dim,R) provides Cartesian tensors with components belonging to a commutative ring \\spad{R.} These tensors can have any number of indices. Each index takes values from \\spad{minix} to \\spad{minix + dim - 1}.")) (|sample| (($) "\\spad{sample()} returns an object of type \\spad{%.}")) (|unravel| (($ (|List| |#3|)) "\\spad{unravel(t)} produces a tensor from a list of components such that \\indented{2}{\\spad{unravel(ravel(t)) = t}.}")) (|ravel| (((|List| |#3|) $) "\\indented{1}{ravel(t) produces a list of components from a tensor such that} \\indented{3}{\\spad{unravel(ravel(t)) = t}.} \\blankline \\spad{X} n:SquareMatrix(2,Integer):=matrix [[2,3],[0,1]] \\spad{X} tn:CartesianTensor(1,2,Integer):=n \\spad{X} ravel \\spad{tn}")) (|leviCivitaSymbol| (($) "\\indented{1}{leviCivitaSymbol() is the rank \\spad{dim} tensor defined \\spad{by}} \\indented{1}{\\spad{leviCivitaSymbol()(i1,...idim) = +1/0/-1}} \\indented{1}{if \\spad{i1,...,idim} is an even/is nota /is an odd permutation} \\indented{1}{of \\spad{minix,...,minix+dim-1}.} \\blankline \\spad{X} lcs:CartesianTensor(1,2,Integer):=leviCivitaSymbol()")) (|kroneckerDelta| (($) "\\indented{1}{kroneckerDelta() is the rank 2 tensor defined \\spad{by}} \\indented{4}{\\spad{kroneckerDelta()(i,j)}} \\indented{7}{\\spad{= 1\\space{2}if \\spad{i} = \\spad{j}}} \\indented{7}{\\spad{= 0 if\\space{2}i \\spad{\\^=} \\spad{j}}} \\blankline \\spad{X} delta:CartesianTensor(1,2,Integer):=kroneckerDelta()")) (|reindex| (($ $ (|List| (|Integer|))) "\\indented{1}{reindex(t,[i1,...,idim]) permutes the indices of \\spad{t.}} \\indented{1}{For example, if \\spad{r = reindex(t, [4,1,2,3])}} \\indented{1}{for a rank 4 tensor \\spad{t,}} \\indented{1}{then \\spad{r} is the rank for tensor given \\spad{by}} \\indented{5}{\\spad{r(i,j,k,l) = t(l,i,j,k)}.} \\blankline \\spad{X} n:SquareMatrix(2,Integer):=matrix [[2,3],[0,1]] \\spad{X} tn:CartesianTensor(1,2,Integer):=n \\spad{X} p:=product(tn,tn) \\spad{X} reindex(p,[4,3,2,1])")) (|transpose| (($ $ (|Integer|) (|Integer|)) "\\indented{1}{transpose(t,i,j) exchanges the \\spad{i}-th and \\spad{j}-th} \\indented{1}{indices of \\spad{t.} For example, if \\spad{r = transpose(t,2,3)}} \\indented{1}{for a rank 4 tensor \\spad{t,} then \\spad{r} is the rank 4 tensor} \\indented{1}{given \\spad{by}} \\indented{5}{\\spad{r(i,j,k,l) = t(i,k,j,l)}.} \\blankline \\spad{X} m:SquareMatrix(2,Integer):=matrix [[1,2],[4,5]] \\spad{X} tm:CartesianTensor(1,2,Integer):=m \\spad{X} tn:CartesianTensor(1,2,Integer):=[tm,tm] \\spad{X} transpose(tn,1,2)") (($ $) "\\indented{1}{transpose(t) exchanges the first and last indices of \\spad{t.}} \\indented{1}{For example, if \\spad{r = transpose(t)} for a rank 4} \\indented{1}{tensor \\spad{t,} then \\spad{r} is the rank 4 tensor given \\spad{by}} \\indented{5}{\\spad{r(i,j,k,l) = t(l,j,k,i)}.} \\blankline \\spad{X} m:SquareMatrix(2,Integer):=matrix [[1,2],[4,5]] \\spad{X} Tm:CartesianTensor(1,2,Integer):=m \\spad{X} transpose(Tm)")) (|contract| (($ $ (|Integer|) (|Integer|)) "\\indented{1}{contract(t,i,j) is the contraction of tensor \\spad{t} which} \\indented{1}{sums along the \\spad{i}-th and \\spad{j}-th indices.} \\indented{1}{For example,\\space{2}if} \\indented{1}{\\spad{r = contract(t,1,3)} for a rank 4 tensor \\spad{t,} then} \\indented{1}{\\spad{r} is the rank 2 \\spad{(= 4 - 2)} tensor given \\spad{by}} \\indented{5}{\\spad{r(i,j) = sum(h=1..dim,t(h,i,h,j))}.} \\blankline \\spad{X} m:SquareMatrix(2,Integer):=matrix [[1,2],[4,5]] \\spad{X} Tm:CartesianTensor(1,2,Integer):=m \\spad{X} v:DirectProduct(2,Integer):=directProduct [3,4] \\spad{X} Tv:CartesianTensor(1,2,Integer):=v \\spad{X} Tmv:=contract(Tm,2,1)") (($ $ (|Integer|) $ (|Integer|)) "\\indented{1}{contract(t,i,s,j) is the inner product of tenors \\spad{s} and \\spad{t}} \\indented{1}{which sums along the \\spad{k1}-th index of} \\indented{1}{t and the \\spad{k2}-th index of \\spad{s.}} \\indented{1}{For example, if \\spad{r = contract(s,2,t,1)} for rank 3 tensors} \\indented{1}{rank 3 tensors \\spad{s} and \\spad{t}, then \\spad{r} is} \\indented{1}{the rank 4 \\spad{(= 3 + 3 - 2)} tensor\\space{2}given \\spad{by}} \\indented{5}{\\spad{r(i,j,k,l) = sum(h=1..dim,s(i,h,j)*t(h,k,l))}.} \\blankline \\spad{X} m:SquareMatrix(2,Integer):=matrix [[1,2],[4,5]] \\spad{X} Tm:CartesianTensor(1,2,Integer):=m \\spad{X} v:DirectProduct(2,Integer):=directProduct [3,4] \\spad{X} Tv:CartesianTensor(1,2,Integer):=v \\spad{X} Tmv:=contract(Tm,2,Tv,1)")) (* (($ $ $) "\\indented{1}{s*t is the inner product of the tensors \\spad{s} and \\spad{t} which contracts} \\indented{1}{the last index of \\spad{s} with the first index of \\spad{t,} that is,} \\indented{5}{\\spad{t*s = contract(t,rank \\spad{t,} \\spad{s,} 1)}} \\indented{5}{\\spad{t*s = sum(k=1..N, t[i1,..,iN,k]*s[k,j1,..,jM])}} \\indented{1}{This is compatible with the use of \\spad{M*v} to denote} \\indented{1}{the matrix-vector inner product.} \\blankline \\spad{X} m:SquareMatrix(2,Integer):=matrix [[1,2],[4,5]] \\spad{X} Tm:CartesianTensor(1,2,Integer):=m \\spad{X} v:DirectProduct(2,Integer):=directProduct [3,4] \\spad{X} Tv:CartesianTensor(1,2,Integer):=v \\spad{X} Tm*Tv")) (|product| (($ $ $) "\\indented{1}{product(s,t) is the outer product of the tensors \\spad{s} and \\spad{t.}} \\indented{1}{For example, if \\spad{r = product(s,t)} for rank 2 tensors} \\indented{1}{s and \\spad{t,} then \\spad{r} is a rank 4 tensor given \\spad{by}} \\indented{5}{\\spad{r(i,j,k,l) = s(i,j)*t(k,l)}.} \\blankline \\spad{X} m:SquareMatrix(2,Integer):=matrix [[1,2],[4,5]] \\spad{X} Tm:CartesianTensor(1,2,Integer):=m \\spad{X} n:SquareMatrix(2,Integer):=matrix [[2,3],[0,1]] \\spad{X} Tn:CartesianTensor(1,2,Integer):=n \\spad{X} Tmn:=product(Tm,Tn)")) (|elt| ((|#3| $ (|List| (|Integer|))) "\\indented{1}{elt(t,[i1,...,iN]) gives a component of a rank \\spad{N} tensor.} \\blankline \\spad{X} v:=[2,3] \\spad{X} tv:CartesianTensor(1,2,Integer):=v \\spad{X} tm:CartesianTensor(1,2,Integer):=[tv,tv] \\spad{X} tn:CartesianTensor(1,2,Integer):=[tm,tm] \\spad{X} tp:CartesianTensor(1,2,Integer):=[tn,tn] \\spad{X} tq:CartesianTensor(1,2,Integer):=[tp,tp] \\spad{X} elt(tq,[2,2,2,2,2])") ((|#3| $ (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\indented{1}{elt(t,i,j,k,l) gives a component of a rank 4 tensor.} \\blankline \\spad{X} v:=[2,3] \\spad{X} tv:CartesianTensor(1,2,Integer):=v \\spad{X} tm:CartesianTensor(1,2,Integer):=[tv,tv] \\spad{X} tn:CartesianTensor(1,2,Integer):=[tm,tm] \\spad{X} tp:CartesianTensor(1,2,Integer):=[tn,tn] \\spad{X} elt(tp,2,2,2,2) \\spad{X} tp[2,2,2,2]") ((|#3| $ (|Integer|) (|Integer|) (|Integer|)) "\\indented{1}{elt(t,i,j,k) gives a component of a rank 3 tensor.} \\blankline \\spad{X} v:=[2,3] \\spad{X} tv:CartesianTensor(1,2,Integer):=v \\spad{X} tm:CartesianTensor(1,2,Integer):=[tv,tv] \\spad{X} tn:CartesianTensor(1,2,Integer):=[tm,tm] \\spad{X} elt(tn,2,2,2) \\spad{X} tn[2,2,2]") ((|#3| $ (|Integer|) (|Integer|)) "\\indented{1}{elt(t,i,j) gives a component of a rank 2 tensor.} \\blankline \\spad{X} v:=[2,3] \\spad{X} tv:CartesianTensor(1,2,Integer):=v \\spad{X} tm:CartesianTensor(1,2,Integer):=[tv,tv] \\spad{X} elt(tm,2,2) \\spad{X} tm[2,2]") ((|#3| $ (|Integer|)) "\\indented{1}{elt(t,i) gives a component of a rank 1 tensor.} \\blankline \\spad{X} v:=[2,3] \\spad{X} tv:CartesianTensor(1,2,Integer):=v \\spad{X} elt(tv,2) \\spad{X} tv[2]") ((|#3| $) "\\indented{1}{elt(t) gives the component of a rank 0 tensor.} \\blankline \\spad{X} \\spad{tv:CartesianTensor(1,2,Integer):=8} \\spad{X} elt(tv) \\spad{X} tv[]")) (|rank| (((|NonNegativeInteger|) $) "\\indented{1}{rank(t) returns the tensorial rank of \\spad{t} (that is, the} \\indented{1}{number of indices).\\space{2}This is the same as the graded module} \\indented{1}{degree.} \\blankline \\spad{X} CT:=CARTEN(1,2,Integer) \\spad{X} \\spad{t0:CT:=8} \\spad{X} rank \\spad{t0}")) (|coerce| (($ (|List| $)) "\\indented{1}{coerce([t_1,...,t_dim]) allows tensors to be constructed} \\indented{1}{using lists.} \\blankline \\spad{X} v:=[2,3] \\spad{X} tv:CartesianTensor(1,2,Integer):=v \\spad{X} tm:CartesianTensor(1,2,Integer):=[tv,tv]") (($ (|List| |#3|)) "\\indented{1}{coerce([r_1,...,r_dim]) allows tensors to be constructed} \\indented{1}{using lists.} \\blankline \\spad{X} v:=[2,3] \\spad{X} tv:CartesianTensor(1,2,Integer):=v") (($ (|SquareMatrix| |#2| |#3|)) "\\indented{1}{coerce(m) views a matrix as a rank 2 tensor.} \\blankline \\spad{X} v:SquareMatrix(2,Integer):=[[1,2],[3,4]] \\spad{X} tv:CartesianTensor(1,2,Integer):=v") (($ (|DirectProduct| |#2| |#3|)) "\\indented{1}{coerce(v) views a vector as a rank 1 tensor.} \\blankline \\spad{X} v:DirectProduct(2,Integer):=directProduct [3,4] \\spad{X} tv:CartesianTensor(1,2,Integer):=v"))) 
 NIL 
 NIL 
-(-143) 
+(-163) 
 ((|constructor| (NIL "This domain allows classes of characters to be defined and manipulated efficiently.")) (|alphanumeric| (($) "\\spad{alphanumeric()} returns the class of all characters for which alphanumeric? is true.")) (|alphabetic| (($) "\\spad{alphabetic()} returns the class of all characters for which alphabetic? is true.")) (|lowerCase| (($) "\\spad{lowerCase()} returns the class of all characters for which lowerCase? is true.")) (|upperCase| (($) "\\spad{upperCase()} returns the class of all characters for which upperCase? is true.")) (|hexDigit| (($) "\\spad{hexDigit()} returns the class of all characters for which hexDigit? is true.")) (|digit| (($) "\\spad{digit()} returns the class of all characters for which digit? is true.")) (|charClass| (($ (|List| (|Character|))) "\\spad{charClass(l)} creates a character class which contains exactly the characters given in the list \\spad{l.}") (($ (|String|)) "\\spad{charClass(s)} creates a character class which contains exactly the characters given in the string \\spad{s.}"))) 
-((-4602 . T) (-4592 . T) (-4603 . T)) 
-((|HasCategory| (-148) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-148) (QUOTE (-374))) (|HasCategory| (-148) (QUOTE (-848))) (|HasCategory| (-148) (QUOTE (-1098))) (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-374)))) (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-1098)))))) 
-(-144 R Q A) 
+((-4625 . T) (-4615 . T) (-4626 . T)) 
+((|HasCategory| (-168) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-168) (QUOTE (-394))) (|HasCategory| (-168) (QUOTE (-869))) (|HasCategory| (-168) (QUOTE (-1119))) (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-394)))) (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-1119)))))) 
+(-164 R Q A) 
 ((|constructor| (NIL "CommonDenominator provides functions to compute the common denominator of a finite linear aggregate of elements of the quotient field of an integral domain.")) (|splitDenominator| (((|Record| (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) "\\spad{splitDenominator([q1,...,qn])} returns \\spad{[[p1,...,pn], \\spad{d]}} such that \\spad{qi = pi/d} and \\spad{d} is a common denominator for the qi's.")) (|clearDenominator| ((|#3| |#3|) "\\spad{clearDenominator([q1,...,qn])} returns \\spad{[p1,...,pn]} such that \\spad{qi = pi/d} where \\spad{d} is a common denominator for the qi's.")) (|commonDenominator| ((|#1| |#3|) "\\spad{commonDenominator([q1,...,qn])} returns a common denominator \\spad{d} for q1,...,qn."))) 
 NIL 
 NIL 
-(-145) 
+(-165) 
 ((|constructor| (NIL "This is a low-level domain which implements matrices (two dimensional arrays) of complex double precision floating point numbers. Indexing is 0 based, there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|) (|Integer|)) "\\indented{1}{qnew(n, \\spad{m)} creates a new uninitialized \\spad{n} by \\spad{m} matrix.} \\blankline \\spad{X} t1:CDFMAT:=qnew(3,4)"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-171 (-217)) (QUOTE (-1098))) (-12 (|HasCategory| (-171 (-217)) (LIST (QUOTE -305) (LIST (QUOTE -171) (QUOTE (-217))))) (|HasCategory| (-171 (-217)) (QUOTE (-1098)))) (|HasCategory| (-171 (-217)) (QUOTE (-303))) (|HasCategory| (-171 (-217)) (QUOTE (-562))) (|HasAttribute| (-171 (-217)) (QUOTE (-4604 "*"))) (|HasCategory| (-171 (-217)) (QUOTE (-174))) (|HasCategory| (-171 (-217)) (QUOTE (-368)))) 
-(-146) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-191 (-237)) (QUOTE (-1119))) (-12 (|HasCategory| (-191 (-237)) (LIST (QUOTE -325) (LIST (QUOTE -191) (QUOTE (-237))))) (|HasCategory| (-191 (-237)) (QUOTE (-1119)))) (|HasCategory| (-191 (-237)) (QUOTE (-323))) (|HasCategory| (-191 (-237)) (QUOTE (-582))) (|HasAttribute| (-191 (-237)) (QUOTE (-4627 "*"))) (|HasCategory| (-191 (-237)) (QUOTE (-194))) (|HasCategory| (-191 (-237)) (QUOTE (-388)))) 
+(-166) 
 ((|constructor| (NIL "This is a low-level domain which implements vectors (one dimensional arrays) of complex double precision floating point numbers. Indexing is 0 based, there is no bound checking (unless provided by lower level).")) (|vector| (($ (|List| (|Complex| (|DoubleFloat|)))) "\\indented{1}{vector(l) converts the list \\spad{l} to a vector.} \\blankline \\spad{X} t1:List(Complex(DoubleFloat)):=[1+2*\\%i,3+4*\\%i,-5-6*\\%i] \\spad{X} t2:CDFVEC:=vector(t1)")) (|qnew| (($ (|Integer|)) "\\indented{1}{qnew(n) creates a new uninitialized vector of length \\spad{n.}} \\blankline \\spad{X} t1:CDFVEC:=qnew 7"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-171 (-217)) (QUOTE (-1098))) (|HasCategory| (-171 (-217)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-171 (-217)) (QUOTE (-848))) (-1841 (|HasCategory| (-171 (-217)) (QUOTE (-848))) (|HasCategory| (-171 (-217)) (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-171 (-217)) (QUOTE (-25))) (|HasCategory| (-171 (-217)) (QUOTE (-23))) (|HasCategory| (-171 (-217)) (QUOTE (-21))) (|HasCategory| (-171 (-217)) (QUOTE (-722))) (|HasCategory| (-171 (-217)) (QUOTE (-1054))) (-12 (|HasCategory| (-171 (-217)) (QUOTE (-1009))) (|HasCategory| (-171 (-217)) (QUOTE (-1054)))) (-12 (|HasCategory| (-171 (-217)) (LIST (QUOTE -305) (LIST (QUOTE -171) (QUOTE (-217))))) (|HasCategory| (-171 (-217)) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-171 (-217)) (LIST (QUOTE -305) (LIST (QUOTE -171) (QUOTE (-217))))) (|HasCategory| (-171 (-217)) (QUOTE (-848)))) (-12 (|HasCategory| (-171 (-217)) (LIST (QUOTE -305) (LIST (QUOTE -171) (QUOTE (-217))))) (|HasCategory| (-171 (-217)) (QUOTE (-1098)))))) 
-(-147) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-191 (-237)) (QUOTE (-1119))) (|HasCategory| (-191 (-237)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-191 (-237)) (QUOTE (-869))) (-3836 (|HasCategory| (-191 (-237)) (QUOTE (-869))) (|HasCategory| (-191 (-237)) (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-191 (-237)) (QUOTE (-25))) (|HasCategory| (-191 (-237)) (QUOTE (-23))) (|HasCategory| (-191 (-237)) (QUOTE (-21))) (|HasCategory| (-191 (-237)) (QUOTE (-743))) (|HasCategory| (-191 (-237)) (QUOTE (-1075))) (-12 (|HasCategory| (-191 (-237)) (QUOTE (-1030))) (|HasCategory| (-191 (-237)) (QUOTE (-1075)))) (-12 (|HasCategory| (-191 (-237)) (LIST (QUOTE -325) (LIST (QUOTE -191) (QUOTE (-237))))) (|HasCategory| (-191 (-237)) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-191 (-237)) (LIST (QUOTE -325) (LIST (QUOTE -191) (QUOTE (-237))))) (|HasCategory| (-191 (-237)) (QUOTE (-869)))) (-12 (|HasCategory| (-191 (-237)) (LIST (QUOTE -325) (LIST (QUOTE -191) (QUOTE (-237))))) (|HasCategory| (-191 (-237)) (QUOTE (-1119)))))) 
+(-167) 
 ((|constructor| (NIL "Category for the usual combinatorial functions.")) (|permutation| (($ $ $) "\\spad{permutation(n, \\spad{m)}} returns the number of permutations of \\spad{n} objects taken \\spad{m} at a time. Note that \\spad{permutation(n,m) = n!/(n-m)!}.")) (|factorial| (($ $) "\\spad{factorial(n)} computes the factorial of \\spad{n} (denoted in the literature by \\spad{n!}) Note that \\spad{n! = \\spad{n} (n-1)! when \\spad{n} > 0}; also, \\spad{0! = 1}.")) (|binomial| (($ $ $) "\\indented{1}{binomial(n,r) returns the \\spad{(n,r)} binomial coefficient} \\indented{1}{(often denoted in the literature by \\spad{C(n,r)}).} \\indented{1}{Note that \\spad{C(n,r) = n!/(r!(n-r)!)} where \\spad{n \\spad{>=} \\spad{r} \\spad{>=} 0}.} \\blankline \\spad{X} [binomial(5,i) for \\spad{i} in 0..5]"))) 
 NIL 
 NIL 
-(-148) 
+(-168) 
 ((|constructor| (NIL "This domain provides the basic character data type.")) (|alphanumeric?| (((|Boolean|) $) "\\spad{alphanumeric?(c)} tests if \\spad{c} is either a letter or number, for example, one of 0..9, a..z or A..Z. \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [alphanumeric? \\spad{c} for \\spad{c} in chars]")) (|lowerCase?| (((|Boolean|) $) "\\spad{lowerCase?(c)} tests if \\spad{c} is an lower case letter, for example, one of a..z. \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [lowerCase? \\spad{c} for \\spad{c} in chars]")) (|upperCase?| (((|Boolean|) $) "\\spad{upperCase?(c)} tests if \\spad{c} is an upper case letter, for example, one of A..Z. \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [upperCase? \\spad{c} for \\spad{c} in chars]")) (|alphabetic?| (((|Boolean|) $) "\\spad{alphabetic?(c)} tests if \\spad{c} is a letter, for example, one of a..z or A..Z. \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [alphabetic? \\spad{c} for \\spad{c} in chars]")) (|hexDigit?| (((|Boolean|) $) "\\spad{hexDigit?(c)} tests if \\spad{c} is a hexadecimal numeral, for example, one of 0..9, a..f or A..F. \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [hexDigit? \\spad{c} for \\spad{c} in chars]")) (|digit?| (((|Boolean|) $) "\\spad{digit?(c)} tests if \\spad{c} is a digit character, for example, one of 0..9. \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [digit? \\spad{c} for \\spad{c} in chars]")) (|lowerCase| (($ $) "\\spad{lowerCase(c)} converts an upper case letter to the corresponding lower case letter. If \\spad{c} is not an upper case letter, then it is returned unchanged. \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [lowerCase \\spad{c} for \\spad{c} in chars]")) (|upperCase| (($ $) "\\spad{upperCase(c)} converts a lower case letter to the corresponding upper case letter. If \\spad{c} is not a lower case letter, then it is returned unchanged. \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [upperCase \\spad{c} for \\spad{c} in chars]")) (|escape| (($) "\\spad{escape()} provides the escape character, \\spad{_}, which is used to allow quotes and other characters within strings. \\blankline \\spad{X} escape()")) (|quote| (($) "\\spad{quote()} provides the string quote character, \\spad{\"}. \\blankline \\spad{X} quote()")) (|space| (($) "\\spad{space()} provides the blank character. \\blankline \\spad{X} space()")) (|char| (($ (|String|)) "\\spad{char(s)} provides a character from a string \\spad{s} of length one. \\blankline \\spad{X} [char \\spad{c} for \\spad{c} in [\"a\",\"A\",\"X\",\"8\",\"+\"]]") (($ (|Integer|)) "\\spad{char(i)} provides a character corresponding to the integer code i. It is always \\spad{true} that \\spad{ord char \\spad{i} = i}. \\blankline \\spad{X} [char \\spad{c} for \\spad{c} in [97,65,88,56,43]]")) (|ord| (((|Integer|) $) "\\spad{ord(c)} provides an integral code corresponding to the character \\spad{c.} It is always \\spad{true} that \\spad{char ord \\spad{c} = \\spad{c}.} \\blankline \\spad{X} chars \\spad{:=} [char \"a\", char \"A\", char \"X\", char \"8\", char \"+\"] \\spad{X} [ord \\spad{c} for \\spad{c} in chars]"))) 
 NIL 
 NIL 
-(-149) 
+(-169) 
 ((|constructor| (NIL "Rings of Characteristic Non Zero")) (|charthRoot| (((|Union| $ "failed") $) "\\spad{charthRoot(x)} returns the \\spad{p}th root of \\spad{x} where \\spad{p} is the characteristic of the ring."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-150 R) 
+(-170 R) 
 ((|constructor| (NIL "This package provides a characteristicPolynomial function for any matrix over a commutative ring.")) (|characteristicPolynomial| ((|#1| (|Matrix| |#1|) |#1|) "\\spad{characteristicPolynomial(m,r)} computes the characteristic polynomial of the matrix \\spad{m} evaluated at the point \\spad{r.} In particular, if \\spad{r} is the polynomial \\spad{'x,} then it returns the characteristic polynomial expressed as a polynomial in \\spad{'x.}"))) 
 NIL 
 NIL 
-(-151) 
+(-171) 
 ((|constructor| (NIL "Rings of Characteristic Zero."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-152 -3313 UP UPUP) 
+(-172 -3958 UP UPUP) 
 ((|constructor| (NIL "Tools to send a point to infinity on an algebraic curve.")) (|chvar| (((|Record| (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (|Fraction| |#2|)) (|:| |c2| (|Fraction| |#2|)) (|:| |deg| (|NonNegativeInteger|))) |#3| |#3|) "\\spad{chvar(f(x,y), p(x,y))} returns \\spad{[g(z,t), q(z,t), c1(z), c2(z), \\spad{n]}} such that under the change of variable \\spad{x = c1(z)}, \\spad{y = \\spad{t} * c2(z)}, one gets \\spad{f(x,y) = g(z,t)}. The algebraic relation between \\spad{x} and \\spad{y} is \\spad{p(x, \\spad{y)} = 0}. The algebraic relation between \\spad{z} and \\spad{t} is \\spad{q(z, \\spad{t)} = 0}.")) (|eval| ((|#3| |#3| (|Fraction| |#2|) (|Fraction| |#2|)) "\\spad{eval(p(x,y), f(x), g(x))} returns \\spad{p(f(x), \\spad{y} * g(x))}.")) (|goodPoint| ((|#1| |#3| |#3|) "\\spad{goodPoint(p, \\spad{q)}} returns an integer a such that a is neither a pole of \\spad{p(x,y)} nor a branch point of \\spad{q(x,y) = 0}.")) (|rootPoly| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| (|Fraction| |#2|)) (|:| |radicand| |#2|)) (|Fraction| |#2|) (|NonNegativeInteger|)) "\\spad{rootPoly(g, \\spad{n)}} returns \\spad{[m, \\spad{c,} \\spad{P]}} such that \\spad{c * \\spad{g} \\spad{**} (1/n) = \\spad{P} \\spad{**} (1/m)} thus if \\spad{y**n = \\spad{g},} then \\spad{z**m = \\spad{P}} where \\spad{z = \\spad{c} * \\spad{y}.}")) (|radPoly| (((|Union| (|Record| (|:| |radicand| (|Fraction| |#2|)) (|:| |deg| (|NonNegativeInteger|))) "failed") |#3|) "\\spad{radPoly(p(x, y))} returns \\spad{[c(x), \\spad{n]}} if \\spad{p} is of the form \\spad{y**n - c(x)}, \"failed\" otherwise.")) (|mkIntegral| (((|Record| (|:| |coef| (|Fraction| |#2|)) (|:| |poly| |#3|)) |#3|) "\\spad{mkIntegral(p(x,y))} returns \\spad{[c(x), q(x,z)]} such that \\spad{z = \\spad{c} * \\spad{y}} is integral. The algebraic relation between \\spad{x} and \\spad{y} is \\spad{p(x, \\spad{y)} = 0}. The algebraic relation between \\spad{x} and \\spad{z} is \\spad{q(x, \\spad{z)} = 0}."))) 
 NIL 
 NIL 
-(-153 R CR) 
+(-173 R CR) 
 ((|constructor| (NIL "This package provides the generalized euclidean algorithm which is needed as the basic step for factoring polynomials.")) (|solveLinearPolynomialEquation| (((|Union| (|List| (|SparseUnivariatePolynomial| |#2|)) "failed") (|List| (|SparseUnivariatePolynomial| |#2|)) (|SparseUnivariatePolynomial| |#2|)) "\\spad{solveLinearPolynomialEquation([f1, ..., fn], \\spad{g)}} where (fi relatively prime to each other) returns a list of \\spad{ai} such that \\spad{g} = sum \\spad{ai} prod \\spad{fj} \\spad{(j} \\spad{\\=} i) or equivalently g/prod \\spad{fj} = sum (ai/fi) or returns \"failed\" if no such list exists"))) 
 NIL 
 NIL 
-(-154 A S) 
+(-174 A S) 
 ((|constructor| (NIL "A collection is a homogeneous aggregate which can built from list of members. The operation used to build the aggregate is generically named construct. However, each collection provides its own special function with the same name as the data type, except with an initial lower case letter, For example, list for List, flexibleArray for FlexibleArray, and so on.")) (|removeDuplicates| (($ $) "\\spad{removeDuplicates(u)} returns a copy of \\spad{u} with all duplicates removed.")) (|select| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{select(p,u)} returns a copy of \\spad{u} containing only those elements such \\axiom{p(x)} is true. Note that \\axiom{select(p,u) \\spad{==} \\spad{[x} for \\spad{x} in \\spad{u} | p(x)]}.")) (|remove| (($ |#2| $) "\\spad{remove(x,u)} returns a copy of \\spad{u} with all elements \\axiom{y = \\spad{x}} removed. Note that \\axiom{remove(y,c) \\spad{==} \\spad{[x} for \\spad{x} in \\spad{c} | \\spad{x} \\spad{^=} y]}.") (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{remove(p,u)} returns a copy of \\spad{u} removing all elements \\spad{x} such that \\axiom{p(x)} is true. Note that \\axiom{remove(p,u) \\spad{==} \\spad{[x} for \\spad{x} in \\spad{u} | not p(x)]}.")) (|reduce| ((|#2| (|Mapping| |#2| |#2| |#2|) $ |#2| |#2|) "\\spad{reduce(f,u,x,z)} reduces the binary operation \\spad{f} across u, stopping when an \"absorbing element\" \\spad{z} is encountered. As for \\axiom{reduce(f,u,x)}, \\spad{x} is the identity operation of \\spad{f.} Same as \\axiom{reduce(f,u,x)} when \\spad{u} contains no element \\spad{z.} Thus the third argument \\spad{x} is returned when \\spad{u} is empty.") ((|#2| (|Mapping| |#2| |#2| |#2|) $ |#2|) "\\spad{reduce(f,u,x)} reduces the binary operation \\spad{f} across u, where \\spad{x} is the identity operation of \\spad{f.} Same as \\axiom{reduce(f,u)} if \\spad{u} has 2 or more elements. Returns \\axiom{f(x,y)} if \\spad{u} has one element \\spad{y,} \\spad{x} if \\spad{u} is empty. For example, \\axiom{reduce(+,u,0)} returns the sum of the elements of u.") ((|#2| (|Mapping| |#2| |#2| |#2|) $) "\\spad{reduce(f,u)} reduces the binary operation \\spad{f} across u. For example, if \\spad{u} is \\axiom{[x,y,...,z]} then \\axiom{reduce(f,u)} returns \\axiom{f(..f(f(x,y),...),z)}. Note that if \\spad{u} has one element \\spad{x,} \\axiom{reduce(f,u)} returns \\spad{x.} Error: if \\spad{u} is empty. \\blankline \\spad{C} )clear all \\spad{X} reduce(+,[C[i]*x**i for \\spad{i} in 1..5])")) (|find| (((|Union| |#2| "failed") (|Mapping| (|Boolean|) |#2|) $) "\\axiom{find(p,u)} returns the first \\spad{x} in \\spad{u} such that \\axiom{p(x)} is true, and \"failed\" otherwise.")) (|construct| (($ (|List| |#2|)) "\\axiom{construct(x,y,...,z)} returns the collection of elements \\axiom{x,y,...,z} ordered as given. Equivalently written as \\axiom{[x,y,...,z]$D}, where \\spad{D} is the domain. \\spad{D} may be omitted for those of type List."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (QUOTE (-1098))) (|HasAttribute| |#1| (QUOTE -4602))) 
-(-155 S) 
+((|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (QUOTE (-1119))) (|HasAttribute| |#1| (QUOTE -4625))) 
+(-175 S) 
 ((|constructor| (NIL "A collection is a homogeneous aggregate which can built from list of members. The operation used to build the aggregate is generically named construct. However, each collection provides its own special function with the same name as the data type, except with an initial lower case letter, For example, list for List, flexibleArray for FlexibleArray, and so on.")) (|removeDuplicates| (($ $) "\\spad{removeDuplicates(u)} returns a copy of \\spad{u} with all duplicates removed.")) (|select| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{select(p,u)} returns a copy of \\spad{u} containing only those elements such \\axiom{p(x)} is true. Note that \\axiom{select(p,u) \\spad{==} \\spad{[x} for \\spad{x} in \\spad{u} | p(x)]}.")) (|remove| (($ |#1| $) "\\spad{remove(x,u)} returns a copy of \\spad{u} with all elements \\axiom{y = \\spad{x}} removed. Note that \\axiom{remove(y,c) \\spad{==} \\spad{[x} for \\spad{x} in \\spad{c} | \\spad{x} \\spad{^=} y]}.") (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{remove(p,u)} returns a copy of \\spad{u} removing all elements \\spad{x} such that \\axiom{p(x)} is true. Note that \\axiom{remove(p,u) \\spad{==} \\spad{[x} for \\spad{x} in \\spad{u} | not p(x)]}.")) (|reduce| ((|#1| (|Mapping| |#1| |#1| |#1|) $ |#1| |#1|) "\\spad{reduce(f,u,x,z)} reduces the binary operation \\spad{f} across u, stopping when an \"absorbing element\" \\spad{z} is encountered. As for \\axiom{reduce(f,u,x)}, \\spad{x} is the identity operation of \\spad{f.} Same as \\axiom{reduce(f,u,x)} when \\spad{u} contains no element \\spad{z.} Thus the third argument \\spad{x} is returned when \\spad{u} is empty.") ((|#1| (|Mapping| |#1| |#1| |#1|) $ |#1|) "\\spad{reduce(f,u,x)} reduces the binary operation \\spad{f} across u, where \\spad{x} is the identity operation of \\spad{f.} Same as \\axiom{reduce(f,u)} if \\spad{u} has 2 or more elements. Returns \\axiom{f(x,y)} if \\spad{u} has one element \\spad{y,} \\spad{x} if \\spad{u} is empty. For example, \\axiom{reduce(+,u,0)} returns the sum of the elements of u.") ((|#1| (|Mapping| |#1| |#1| |#1|) $) "\\spad{reduce(f,u)} reduces the binary operation \\spad{f} across u. For example, if \\spad{u} is \\axiom{[x,y,...,z]} then \\axiom{reduce(f,u)} returns \\axiom{f(..f(f(x,y),...),z)}. Note that if \\spad{u} has one element \\spad{x,} \\axiom{reduce(f,u)} returns \\spad{x.} Error: if \\spad{u} is empty. \\blankline \\spad{C} )clear all \\spad{X} reduce(+,[C[i]*x**i for \\spad{i} in 1..5])")) (|find| (((|Union| |#1| "failed") (|Mapping| (|Boolean|) |#1|) $) "\\axiom{find(p,u)} returns the first \\spad{x} in \\spad{u} such that \\axiom{p(x)} is true, and \"failed\" otherwise.")) (|construct| (($ (|List| |#1|)) "\\axiom{construct(x,y,...,z)} returns the collection of elements \\axiom{x,y,...,z} ordered as given. Equivalently written as \\axiom{[x,y,...,z]$D}, where \\spad{D} is the domain. \\spad{D} may be omitted for those of type List."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-156 |n| K Q) 
+(-176 |n| K Q) 
 ((|constructor| (NIL "CliffordAlgebra(n, \\spad{K,} \\spad{Q)} defines a vector space of dimension \\spad{2**n} over \\spad{K,} given a quadratic form \\spad{Q} on \\spad{K**n}. \\blankline If \\spad{e[i]}, \\spad{1<=i<=n} is a basis for \\spad{K**n} then 1, \\spad{e[i]} (\\spad{1<=i<=n}), \\spad{e[i1]*e[i2]} (\\spad{1<=i1<i2<=n}),...,\\spad{e[1]*e[2]*..*e[n]} is a basis for the Clifford Algebra. \\blankline The algebra is defined by the relations\\br \\tab{5}\\spad{e[i]*e[j] = -e[j]*e[i]} (\\spad{i \\~~= j}),\\br \\tab{5}\\spad{e[i]*e[i] = Q(e[i])} \\blankline Examples of Clifford Algebras are: gaussians, quaternions, exterior algebras and spin algebras.")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} computes the multiplicative inverse of \\spad{x} or \"failed\" if \\spad{x} is not invertible.")) (|coefficient| ((|#2| $ (|List| (|PositiveInteger|))) "\\spad{coefficient(x,[i1,i2,...,iN])} extracts the coefficient of \\spad{e(i1)*e(i2)*...*e(iN)} in \\spad{x.}")) (|monomial| (($ |#2| (|List| (|PositiveInteger|))) "\\spad{monomial(c,[i1,i2,...,iN])} produces the value given by \\spad{c*e(i1)*e(i2)*...*e(iN)}.")) (|e| (($ (|PositiveInteger|)) "\\spad{e(n)} produces the appropriate unit element."))) 
-((-4597 . T) (-4596 . T) (-4599 . T)) 
+((-4620 . T) (-4619 . T) (-4622 . T)) 
 NIL 
-(-157) 
+(-177) 
 ((|constructor| (NIL "Automatic clipping for 2-dimensional plots The purpose of this package is to provide reasonable plots of functions with singularities.")) (|clipWithRanges| (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|List| (|List| (|Point| (|DoubleFloat|)))) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{clipWithRanges(pointLists,xMin,xMax,yMin,yMax)} performs clipping on a list of lists of points, \\spad{pointLists}. Clipping is done within the specified ranges of \\spad{xMin}, \\spad{xMax} and \\spad{yMin}, \\spad{yMax}. This function is used internally by the \\fakeAxiomFun{iClipParametric} subroutine in this package.")) (|clipParametric| (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|Plot|) (|Fraction| (|Integer|)) (|Fraction| (|Integer|))) "\\spad{clipParametric(p,frac,sc)} performs two-dimensional clipping on a plot, \\spad{p,} from the domain \\spadtype{Plot} for the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)}; the fraction parameter is specified by \\spad{frac} and the scale parameter is specified by \\spad{sc} for use in the \\fakeAxiomFun{iClipParametric} subroutine, which is called by this function.") (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|Plot|)) "\\spad{clipParametric(p)} performs two-dimensional clipping on a plot, \\spad{p,} from the domain \\spadtype{Plot} for the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)}; the default parameters \\spad{1/2} for the fraction and \\spad{5/1} for the scale are used in the \\fakeAxiomFun{iClipParametric} subroutine, which is called by this function.")) (|clip| (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|List| (|List| (|Point| (|DoubleFloat|))))) "\\spad{clip(ll)} performs two-dimensional clipping on a list of lists of points, \\spad{ll}; the default parameters \\spad{1/2} for the fraction and \\spad{5/1} for the scale are used in the \\fakeAxiomFun{iClipParametric} subroutine, which is called by this function.") (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|List| (|Point| (|DoubleFloat|)))) "\\spad{clip(l)} performs two-dimensional clipping on a curve \\spad{l,} which is a list of points; the default parameters \\spad{1/2} for the fraction and \\spad{5/1} for the scale are used in the \\fakeAxiomFun{iClipParametric} subroutine, which is called by this function.") (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|Plot|) (|Fraction| (|Integer|)) (|Fraction| (|Integer|))) "\\spad{clip(p,frac,sc)} performs two-dimensional clipping on a plot, \\spad{p,} from the domain \\spadtype{Plot} for the graph of one variable \\spad{y = f(x)}; the fraction parameter is specified by \\spad{frac} and the scale parameter is specified by \\spad{sc} for use in the \\spadfun{clip} function.") (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|Plot|)) "\\spad{clip(p)} performs two-dimensional clipping on a plot, \\spad{p,} from the domain \\spadtype{Plot} for the graph of one variable, \\spad{y = f(x)}; the default parameters \\spad{1/4} for the fraction and \\spad{5/1} for the scale are used in the \\spadfun{clip} function."))) 
 NIL 
 NIL 
-(-158 UP |Par|) 
+(-178 UP |Par|) 
 ((|constructor| (NIL "This package provides functions complexZeros for finding the complex zeros of univariate polynomials with complex rational number coefficients. The results are to any user specified precision and are returned as either complex rational number or complex floating point numbers depending on the type of the second argument which specifies the precision.")) (|complexZeros| (((|List| (|Complex| |#2|)) |#1| |#2|) "\\spad{complexZeros(poly, eps)} finds the complex zeros of the univariate polynomial \\spad{poly} to precision eps with solutions returned as complex floats or rationals depending on the type of eps."))) 
 NIL 
 NIL 
-(-159) 
+(-179) 
 ((|constructor| (NIL "Color() specifies a domain of 27 colors provided in the Axiom system (the colors mix additively).")) (|color| (($ (|Integer|)) "\\spad{color(i)} returns a color of the indicated hue i.")) (|numberOfHues| (((|PositiveInteger|)) "\\spad{numberOfHues()} returns the number of total hues, set in totalHues.")) (|hue| (((|Integer|) $) "\\spad{hue(c)} returns the hue index of the indicated color \\spad{c.}")) (|blue| (($) "\\spad{blue()} returns the position of the blue hue from total hues.")) (|green| (($) "\\spad{green()} returns the position of the green hue from total hues.")) (|yellow| (($) "\\spad{yellow()} returns the position of the yellow hue from total hues.")) (|red| (($) "\\spad{red()} returns the position of the red hue from total hues.")) (+ (($ $ $) "\\spad{c1 + \\spad{c2}} additively mixes the two colors \\spad{c1} and \\spad{c2.}")) (* (($ (|DoubleFloat|) $) "\\spad{s * \\spad{c},} returns the color \\spad{c,} whose weighted shade has been scaled by \\spad{s.}") (($ (|PositiveInteger|) $) "\\spad{s * \\spad{c},} returns the color \\spad{c,} whose weighted shade has been scaled by \\spad{s.}"))) 
 NIL 
 NIL 
-(-160 R -3313) 
+(-180 R -3958) 
 ((|constructor| (NIL "Provides combinatorial functions over an integral domain.")) (|ipow| ((|#2| (|List| |#2|)) "\\spad{ipow(l)} should be local but conditional.")) (|iidprod| ((|#2| (|List| |#2|)) "\\spad{iidprod(l)} should be local but conditional.")) (|iidsum| ((|#2| (|List| |#2|)) "\\spad{iidsum(l)} should be local but conditional.")) (|iipow| ((|#2| (|List| |#2|)) "\\spad{iipow(l)} should be local but conditional.")) (|iiperm| ((|#2| (|List| |#2|)) "\\spad{iiperm(l)} should be local but conditional.")) (|iibinom| ((|#2| (|List| |#2|)) "\\spad{iibinom(l)} should be local but conditional.")) (|iifact| ((|#2| |#2|) "\\spad{iifact(x)} should be local but conditional.")) (|product| ((|#2| |#2| (|SegmentBinding| |#2|)) "\\spad{product(f(n), \\spad{n} = a..b)} returns f(a) * \\spad{...} * f(b) as a formal product.") ((|#2| |#2| (|Symbol|)) "\\spad{product(f(n), \\spad{n)}} returns the formal product P(n) which verifies P(n+1)/P(n) = f(n).")) (|summation| ((|#2| |#2| (|SegmentBinding| |#2|)) "\\spad{summation(f(n), \\spad{n} = a..b)} returns f(a) + \\spad{...} + f(b) as a formal sum.") ((|#2| |#2| (|Symbol|)) "\\spad{summation(f(n), \\spad{n)}} returns the formal sum S(n) which verifies S(n+1) - S(n) = f(n).")) (|factorials| ((|#2| |#2| (|Symbol|)) "\\spad{factorials(f, \\spad{x)}} rewrites the permutations and binomials in \\spad{f} involving \\spad{x} in terms of factorials.") ((|#2| |#2|) "\\spad{factorials(f)} rewrites the permutations and binomials in \\spad{f} in terms of factorials.")) (|factorial| ((|#2| |#2|) "\\spad{factorial(n)} returns the factorial of \\spad{n,} \\spadignore{i.e.} \\spad{n!;}")) (|permutation| ((|#2| |#2| |#2|) "\\spad{permutation(n, \\spad{r)}} returns the number of permutations of \\spad{n} objects taken \\spad{r} at a time, \\spadignore{i.e.} n!/(n-r)!.")) (|binomial| ((|#2| |#2| |#2|) "\\indented{1}{binomial(n, \\spad{r)} returns the number of subsets of \\spad{r} objects} \\indented{1}{taken among \\spad{n} objects, \\spadignore{i.e.} n!/(r! * (n-r)!);} \\blankline \\spad{X} [binomial(5,i) for \\spad{i} in 0..5]")) (** ((|#2| |#2| |#2|) "\\spad{a \\spad{**} \\spad{b}} is the formal exponential a**b.")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns a copy of \\spad{op} with the domain-dependent properties appropriate for \\spad{F;} error if \\spad{op} is not a combinatorial operator.")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} is \\spad{true} if \\spad{op} is a combinatorial operator."))) 
 NIL 
 NIL 
-(-161 I) 
+(-181 I) 
 ((|constructor| (NIL "The \\spadtype{IntegerCombinatoricFunctions} package provides some standard functions in combinatorics.")) (|stirling2| ((|#1| |#1| |#1|) "\\spad{stirling2(n,m)} returns the Stirling number of the second kind denoted \\spad{SS[n,m]}.")) (|stirling1| ((|#1| |#1| |#1|) "\\spad{stirling1(n,m)} returns the Stirling number of the first kind denoted \\spad{S[n,m]}.")) (|permutation| ((|#1| |#1| |#1|) "\\spad{permutation(n)} returns \\spad{!P(n,r) = n!/(n-r)!}. This is the number of permutations of \\spad{n} objects taken \\spad{r} at a time.")) (|partition| ((|#1| |#1|) "\\spad{partition(n)} returns the number of partitions of the integer \\spad{n.} This is the number of distinct ways that \\spad{n} can be written as a sum of positive integers.")) (|multinomial| ((|#1| |#1| (|List| |#1|)) "\\spad{multinomial(n,[m1,m2,...,mk])} returns the multinomial coefficient \\spad{n!/(m1! \\spad{m2!} \\spad{...} mk!)}.")) (|factorial| ((|#1| |#1|) "\\spad{factorial(n)} returns \\spad{n!}. this is the product of all integers between 1 and \\spad{n} (inclusive). Note that \\spad{0!} is defined to be 1.")) (|binomial| ((|#1| |#1| |#1|) "\\indented{1}{\\spad{binomial(n,r)} returns the binomial coefficient} \\indented{1}{\\spad{C(n,r) = n!/(r! (n-r)!)}, where \\spad{n \\spad{>=} \\spad{r} \\spad{>=} 0}.} \\indented{1}{This is the number of combinations of \\spad{n} objects taken \\spad{r} at a time.} \\blankline \\spad{X} [binomial(5,i) for \\spad{i} in 0..5]"))) 
 NIL 
 NIL 
-(-162) 
+(-182) 
 ((|constructor| (NIL "CombinatorialOpsCategory is the category obtaining by adjoining summations and products to the usual combinatorial operations.")) (|product| (($ $ (|SegmentBinding| $)) "\\spad{product(f(n), \\spad{n} = a..b)} returns f(a) * \\spad{...} * f(b) as a formal product.") (($ $ (|Symbol|)) "\\spad{product(f(n), \\spad{n)}} returns the formal product P(n) which verifies P(n+1)/P(n) = f(n).")) (|summation| (($ $ (|SegmentBinding| $)) "\\spad{summation(f(n), \\spad{n} = a..b)} returns f(a) + \\spad{...} + f(b) as a formal sum.") (($ $ (|Symbol|)) "\\spad{summation(f(n), \\spad{n)}} returns the formal sum S(n) which verifies S(n+1) - S(n) = f(n).")) (|factorials| (($ $ (|Symbol|)) "\\spad{factorials(f, \\spad{x)}} rewrites the permutations and binomials in \\spad{f} involving \\spad{x} in terms of factorials.") (($ $) "\\spad{factorials(f)} rewrites the permutations and binomials in \\spad{f} in terms of factorials."))) 
 NIL 
 NIL 
-(-163) 
+(-183) 
 ((|constructor| (NIL "A type for basic commutators")) (|mkcomm| (($ $ $) "\\spad{mkcomm(i,j)} is not documented") (($ (|Integer|)) "\\spad{mkcomm(i)} is not documented"))) 
 NIL 
 NIL 
-(-164) 
+(-184) 
 ((|constructor| (NIL "This package exports the elementary operators, with some semantics already attached to them. The semantics that is attached here is not dependent on the set in which the operators will be applied.")) (|operator| (((|BasicOperator|) (|Symbol|)) "\\spad{operator(s)} returns an operator with name \\spad{s,} with the appropriate semantics if \\spad{s} is known. If \\spad{s} is not known, the result has no semantics."))) 
 NIL 
 NIL 
-(-165 R UP UPUP) 
+(-185 R UP UPUP) 
 ((|constructor| (NIL "A package for swapping the order of two variables in a tower of two UnivariatePolynomialCategory extensions.")) (|swap| ((|#3| |#3|) "\\spad{swap(p(x,y))} returns p(y,x)."))) 
 NIL 
 NIL 
-(-166) 
+(-186) 
 ((|constructor| (NIL "The class of set equipped with possibly unnatural linear order (needed for technical reasons).")) (|smaller?| (((|Boolean|) $ $) "\\spad{smaller?(x, \\spad{y)}} is a strict total ordering on the elements of the set."))) 
 NIL 
 NIL 
-(-167 S R) 
+(-187 S R) 
 ((|constructor| (NIL "This category represents the extension of a ring by a square root of \\spad{-1.}")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(x)} returns \\spad{x} as a rational number, or \"failed\" if \\spad{x} is not a rational number.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(x)} returns \\spad{x} as a rational number. Error: if \\spad{x} is not a rational number.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(x)} tests if \\spad{x} is a rational number.")) (|polarCoordinates| (((|Record| (|:| |r| |#2|) (|:| |phi| |#2|)) $) "\\spad{polarCoordinates(x)} returns \\spad{(r,} phi) such that \\spad{x} = \\spad{r} * exp(\\%i * phi).")) (|argument| ((|#2| $) "\\spad{argument(x)} returns the angle made by (0,1) and (0,x).")) (|abs| (($ $) "\\spad{abs(x)} returns the absolute value of \\spad{x} = sqrt(norm(x)).")) (|exquo| (((|Union| $ "failed") $ |#2|) "\\spad{exquo(x, \\spad{r)}} returns the exact quotient of \\spad{x} by \\spad{r,} or \"failed\" if \\spad{r} does not divide \\spad{x} exactly.")) (|norm| ((|#2| $) "\\spad{norm(x)} returns \\spad{x} * conjugate(x)")) (|real| ((|#2| $) "\\spad{real(x)} returns real part of \\spad{x.}")) (|imag| ((|#2| $) "\\spad{imag(x)} returns imaginary part of \\spad{x.}")) (|conjugate| (($ $) "\\spad{conjugate(x + \\spad{%i} \\spad{y)}} returns \\spad{x} - \\spad{%i} \\spad{y.}")) (|imaginary| (($) "\\spad{imaginary()} = sqrt(-1) = \\%i.")) (|complex| (($ |#2| |#2|) "\\spad{complex(x,y)} constructs \\spad{x} + \\%i*y.") ((|attribute|) "indicates that \\% has sqrt(-1)"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (QUOTE (-554))) (|HasCategory| |#2| (QUOTE (-1009))) (|HasCategory| |#2| (QUOTE (-1190))) (|HasCategory| |#2| (QUOTE (-1063))) (|HasCategory| |#2| (QUOTE (-1028))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (QUOTE (-368))) (|HasAttribute| |#2| (QUOTE -4598)) (|HasAttribute| |#2| (QUOTE -4601)) (|HasCategory| |#2| (QUOTE (-303))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-848)))) 
-(-168 R) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (QUOTE (-574))) (|HasCategory| |#2| (QUOTE (-1030))) (|HasCategory| |#2| (QUOTE (-1211))) (|HasCategory| |#2| (QUOTE (-1084))) (|HasCategory| |#2| (QUOTE (-1049))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (QUOTE (-388))) (|HasAttribute| |#2| (QUOTE -4621)) (|HasAttribute| |#2| (QUOTE -4624)) (|HasCategory| |#2| (QUOTE (-323))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-869)))) 
+(-188 R) 
 ((|constructor| (NIL "This category represents the extension of a ring by a square root of \\spad{-1.}")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(x)} returns \\spad{x} as a rational number, or \"failed\" if \\spad{x} is not a rational number.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(x)} returns \\spad{x} as a rational number. Error: if \\spad{x} is not a rational number.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(x)} tests if \\spad{x} is a rational number.")) (|polarCoordinates| (((|Record| (|:| |r| |#1|) (|:| |phi| |#1|)) $) "\\spad{polarCoordinates(x)} returns \\spad{(r,} phi) such that \\spad{x} = \\spad{r} * exp(\\%i * phi).")) (|argument| ((|#1| $) "\\spad{argument(x)} returns the angle made by (0,1) and (0,x).")) (|abs| (($ $) "\\spad{abs(x)} returns the absolute value of \\spad{x} = sqrt(norm(x)).")) (|exquo| (((|Union| $ "failed") $ |#1|) "\\spad{exquo(x, \\spad{r)}} returns the exact quotient of \\spad{x} by \\spad{r,} or \"failed\" if \\spad{r} does not divide \\spad{x} exactly.")) (|norm| ((|#1| $) "\\spad{norm(x)} returns \\spad{x} * conjugate(x)")) (|real| ((|#1| $) "\\spad{real(x)} returns real part of \\spad{x.}")) (|imag| ((|#1| $) "\\spad{imag(x)} returns imaginary part of \\spad{x.}")) (|conjugate| (($ $) "\\spad{conjugate(x + \\spad{%i} \\spad{y)}} returns \\spad{x} - \\spad{%i} \\spad{y.}")) (|imaginary| (($) "\\spad{imaginary()} = sqrt(-1) = \\%i.")) (|complex| (($ |#1| |#1|) "\\spad{complex(x,y)} constructs \\spad{x} + \\%i*y.") ((|attribute|) "indicates that \\% has sqrt(-1)"))) 
-((-4595 -1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4598 |has| |#1| (-6 -4598)) (-4601 |has| |#1| (-6 -4601)) (-3363 . T) (-3389 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 -3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4621 |has| |#1| (-6 -4621)) (-4624 |has| |#1| (-6 -4624)) (-4001 . T) (-2623 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-169 RR PR) 
+(-189 RR PR) 
 ((|constructor| (NIL "This package has no description")) (|factor| (((|Factored| |#2|) |#2|) "\\spad{factor(p)} factorizes the polynomial \\spad{p} with complex coefficients."))) 
 NIL 
 NIL 
-(-170 R S) 
+(-190 R S) 
 ((|constructor| (NIL "This package extends maps from underlying rings to maps between complex over those rings.")) (|map| (((|Complex| |#2|) (|Mapping| |#2| |#1|) (|Complex| |#1|)) "\\spad{map(f,u)} maps \\spad{f} onto real and imaginary parts of u."))) 
 NIL 
 NIL 
-(-171 R) 
+(-191 R) 
 ((|constructor| (NIL "\\spadtype{Complex(R)} creates the domain of elements of the form \\spad{a + \\spad{b} * i} where \\spad{a} and \\spad{b} come from the ring \\spad{R,} and \\spad{i} is a new element such that \\spad{i**2 = -1}."))) 
-((-4595 -1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4598 |has| |#1| (-6 -4598)) (-4601 |has| |#1| (-6 -4601)) (-3363 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-353)))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-1190))) (-12 (|HasCategory| |#1| (QUOTE (-1009))) (|HasCategory| |#1| (QUOTE (-1190)))) (|HasCategory| |#1| (QUOTE (-1028))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -283) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-829))) (|HasCategory| |#1| (QUOTE (-1063))) (-12 (|HasCategory| |#1| (QUOTE (-1063))) (|HasCategory| |#1| (QUOTE (-1190)))) (|HasCategory| |#1| (QUOTE (-554))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-303))) (-1841 (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-353)))) (|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-227))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -283) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-353)))) (|HasCategory| |#1| (QUOTE (-227))) (-12 (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-353)))) (-12 (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-374)))) (-12 (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-829)))) (-12 (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-1028)))) (-12 (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-1190))))) (-12 (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-368))) (-12 (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-910))))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-910))))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasAttribute| |#1| (QUOTE -4598)) (|HasAttribute| |#1| (QUOTE -4601)) (-12 (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-353))))) 
-(-172 R S CS) 
+((-4618 -3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4621 |has| |#1| (-6 -4621)) (-4624 |has| |#1| (-6 -4624)) (-4001 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-373)))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-1211))) (-12 (|HasCategory| |#1| (QUOTE (-1030))) (|HasCategory| |#1| (QUOTE (-1211)))) (|HasCategory| |#1| (QUOTE (-1049))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-850))) (|HasCategory| |#1| (QUOTE (-1084))) (-12 (|HasCategory| |#1| (QUOTE (-1084))) (|HasCategory| |#1| (QUOTE (-1211)))) (|HasCategory| |#1| (QUOTE (-574))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-323))) (-3836 (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-373)))) (|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-247))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-373)))) (|HasCategory| |#1| (QUOTE (-247))) (-12 (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-373)))) (-12 (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-394)))) (-12 (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-850)))) (-12 (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-1049)))) (-12 (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-1211))))) (-12 (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-388))) (-12 (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-931))))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-931))))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasAttribute| |#1| (QUOTE -4621)) (|HasAttribute| |#1| (QUOTE -4624)) (-12 (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-373))))) 
+(-192 R S CS) 
 ((|constructor| (NIL "This package supports converting complex expressions to patterns")) (|convert| (((|Pattern| |#1|) |#3|) "\\spad{convert(cs)} converts the complex expression \\spad{cs} to a pattern"))) 
 NIL 
 NIL 
-(-173) 
+(-193) 
 ((|constructor| (NIL "This domain implements some global properties of subspaces.")) (|copy| (($ $) "\\spad{copy(x)} is not documented")) (|solid| (((|Boolean|) $ (|Boolean|)) "\\spad{solid(x,b)} is not documented")) (|close| (((|Boolean|) $ (|Boolean|)) "\\spad{close(x,b)} is not documented")) (|solid?| (((|Boolean|) $) "\\spad{solid?(x)} is not documented")) (|closed?| (((|Boolean|) $) "\\spad{closed?(x)} is not documented")) (|new| (($) "\\spad{new()} is not documented"))) 
 NIL 
 NIL 
-(-174) 
+(-194) 
 ((|constructor| (NIL "The category of commutative rings with unity, \\spadignore{i.e.} rings where \\spadop{*} is commutative, and which have a multiplicative identity element.")) (|commutative| ((|attribute| "*") "multiplication is commutative."))) 
-(((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-175 R) 
+(-195 R) 
 ((|constructor| (NIL "\\spadtype{ContinuedFraction} implements general continued fractions. This version is not restricted to simple, finite fractions and uses the \\spadtype{Stream} as a representation. The arithmetic functions assume that the approximants alternate below/above the convergence point. This is enforced by ensuring the partial numerators and partial denominators are greater than 0 in the Euclidean domain view of \\spad{R} (\\spadignore{i.e.} \\spad{sizeLess?(0, x)}).")) (|complete| (($ $) "\\spad{complete(x)} causes all entries in \\spadvar{x} to be computed. Normally entries are only computed as needed. If \\spadvar{x} is an infinite continued fraction, a user-initiated interrupt is necessary to stop the computation.")) (|extend| (($ $ (|Integer|)) "\\spad{extend(x,n)} causes the first \\spadvar{n} entries in the continued fraction \\spadvar{x} to be computed. Normally entries are only computed as needed.")) (|denominators| (((|Stream| |#1|) $) "\\spad{denominators(x)} returns the stream of denominators of the approximants of the continued fraction \\spadvar{x}. If the continued fraction is finite, then the stream will be finite.")) (|numerators| (((|Stream| |#1|) $) "\\spad{numerators(x)} returns the stream of numerators of the approximants of the continued fraction \\spadvar{x}. If the continued fraction is finite, then the stream will be finite.")) (|convergents| (((|Stream| (|Fraction| |#1|)) $) "\\spad{convergents(x)} returns the stream of the convergents of the continued fraction \\spadvar{x}. If the continued fraction is finite, then the stream will be finite.")) (|approximants| (((|Stream| (|Fraction| |#1|)) $) "\\spad{approximants(x)} returns the stream of approximants of the continued fraction \\spadvar{x}. If the continued fraction is finite, then the stream will be infinite and periodic with period 1.")) (|reducedForm| (($ $) "\\spad{reducedForm(x)} puts the continued fraction \\spadvar{x} in reduced form, \\spadignore{i.e.} the function returns an equivalent continued fraction of the form \\spad{continuedFraction(b0,[1,1,1,...],[b1,b2,b3,...])}.")) (|wholePart| ((|#1| $) "\\spad{wholePart(x)} extracts the whole part of \\spadvar{x}. That is, if \\spad{x = continuedFraction(b0, [a1,a2,a3,...], [b1,b2,b3,...])}, then \\spad{wholePart(x) = b0}.")) (|partialQuotients| (((|Stream| |#1|) $) "\\spad{partialQuotients(x)} extracts the partial quotients in \\spadvar{x}. That is, if \\spad{x = continuedFraction(b0, [a1,a2,a3,...], [b1,b2,b3,...])}, then \\spad{partialQuotients(x) = [b0,b1,b2,b3,...]}.")) (|partialDenominators| (((|Stream| |#1|) $) "\\spad{partialDenominators(x)} extracts the denominators in \\spadvar{x}. That is, if \\spad{x = continuedFraction(b0, [a1,a2,a3,...], [b1,b2,b3,...])}, then \\spad{partialDenominators(x) = [b1,b2,b3,...]}.")) (|partialNumerators| (((|Stream| |#1|) $) "\\spad{partialNumerators(x)} extracts the numerators in \\spadvar{x}. That is, if \\spad{x = continuedFraction(b0, [a1,a2,a3,...], [b1,b2,b3,...])}, then \\spad{partialNumerators(x) = [a1,a2,a3,...]}.")) (|reducedContinuedFraction| (($ |#1| (|Stream| |#1|)) "\\spad{reducedContinuedFraction(b0,b)} constructs a continued fraction in the following way: if \\spad{b = [b1,b2,...]} then the result is the continued fraction \\spad{b0 + 1/(b1 + 1/(b2 + ...))}. That is, the result is the same as \\spad{continuedFraction(b0,[1,1,1,...],[b1,b2,b3,...])}.")) (|continuedFraction| (($ |#1| (|Stream| |#1|) (|Stream| |#1|)) "\\spad{continuedFraction(b0,a,b)} constructs a continued fraction in the following way: if \\spad{a = [a1,a2,...]} and \\spad{b = [b1,b2,...]} then the result is the continued fraction \\spad{b0 + \\spad{a1/(b1} + \\spad{a2/(b2} + ...))}.") (($ (|Fraction| |#1|)) "\\spad{continuedFraction(r)} converts the fraction \\spadvar{r} with components of type \\spad{R} to a continued fraction over \\spad{R}."))) 
-(((-4604 "*") . T) (-4595 . T) (-4600 . T) (-4594 . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") . T) (-4618 . T) (-4623 . T) (-4617 . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-176 R) 
+(-196 R) 
 ((|constructor| (NIL "CoordinateSystems provides coordinate transformation functions for plotting. Functions in this package return conversion functions which take points expressed in other coordinate systems and return points with the corresponding Cartesian coordinates.")) (|conical| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1| |#1|) "\\spad{conical(a,b)} transforms from conical coordinates to Cartesian coordinates: \\spad{conical(a,b)} is a function which will map the point \\spad{(lambda,mu,nu)} to \\spad{x = lambda*mu*nu/(a*b)}, \\spad{y = lambda/a*sqrt((mu**2-a**2)*(nu**2-a**2)/(a**2-b**2))}, \\spad{z = lambda/b*sqrt((mu**2-b**2)*(nu**2-b**2)/(b**2-a**2))}.")) (|toroidal| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{toroidal(a)} transforms from toroidal coordinates to Cartesian coordinates: \\spad{toroidal(a)} is a function which will map the point \\spad{(u,v,phi)} to \\spad{x = a*sinh(v)*cos(phi)/(cosh(v)-cos(u))}, \\spad{y = a*sinh(v)*sin(phi)/(cosh(v)-cos(u))}, \\spad{z = a*sin(u)/(cosh(v)-cos(u))}.")) (|bipolarCylindrical| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{bipolarCylindrical(a)} transforms from bipolar cylindrical coordinates to Cartesian coordinates: \\spad{bipolarCylindrical(a)} is a function which will map the point \\spad{(u,v,z)} to \\spad{x = a*sinh(v)/(cosh(v)-cos(u))}, \\spad{y = a*sin(u)/(cosh(v)-cos(u))}, \\spad{z}.")) (|bipolar| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{bipolar(a)} transforms from bipolar coordinates to Cartesian coordinates: \\spad{bipolar(a)} is a function which will map the point \\spad{(u,v)} to \\spad{x = a*sinh(v)/(cosh(v)-cos(u))}, \\spad{y = a*sin(u)/(cosh(v)-cos(u))}.")) (|oblateSpheroidal| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{oblateSpheroidal(a)} transforms from oblate spheroidal coordinates to Cartesian coordinates: \\spad{oblateSpheroidal(a)} is a function which will map the point \\spad{(xi,eta,phi)} to \\spad{x = a*sinh(xi)*sin(eta)*cos(phi)}, \\spad{y = a*sinh(xi)*sin(eta)*sin(phi)}, \\spad{z = a*cosh(xi)*cos(eta)}.")) (|prolateSpheroidal| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{prolateSpheroidal(a)} transforms from prolate spheroidal coordinates to Cartesian coordinates: \\spad{prolateSpheroidal(a)} is a function which will map the point \\spad{(xi,eta,phi)} to \\spad{x = a*sinh(xi)*sin(eta)*cos(phi)}, \\spad{y = a*sinh(xi)*sin(eta)*sin(phi)}, \\spad{z = a*cosh(xi)*cos(eta)}.")) (|ellipticCylindrical| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{ellipticCylindrical(a)} transforms from elliptic cylindrical coordinates to Cartesian coordinates: \\spad{ellipticCylindrical(a)} is a function which will map the point \\spad{(u,v,z)} to \\spad{x = a*cosh(u)*cos(v)}, \\spad{y = a*sinh(u)*sin(v)}, \\spad{z}.")) (|elliptic| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{elliptic(a)} transforms from elliptic coordinates to Cartesian coordinates: \\spad{elliptic(a)} is a function which will map the point \\spad{(u,v)} to \\spad{x = a*cosh(u)*cos(v)}, \\spad{y = a*sinh(u)*sin(v)}.")) (|paraboloidal| (((|Point| |#1|) (|Point| |#1|)) "\\spad{paraboloidal(pt)} transforms \\spad{pt} from paraboloidal coordinates to Cartesian coordinates: the function produced will map the point \\spad{(u,v,phi)} to \\spad{x = u*v*cos(phi)}, \\spad{y = u*v*sin(phi)}, \\spad{z = 1/2 * \\spad{(u**2} - v**2)}.")) (|parabolicCylindrical| (((|Point| |#1|) (|Point| |#1|)) "\\spad{parabolicCylindrical(pt)} transforms \\spad{pt} from parabolic cylindrical coordinates to Cartesian coordinates: the function produced will map the point \\spad{(u,v,z)} to \\spad{x = 1/2*(u**2 - v**2)}, \\spad{y = u*v}, \\spad{z}.")) (|parabolic| (((|Point| |#1|) (|Point| |#1|)) "\\spad{parabolic(pt)} transforms \\spad{pt} from parabolic coordinates to Cartesian coordinates: the function produced will map the point \\spad{(u,v)} to \\spad{x = 1/2*(u**2 - v**2)}, \\spad{y = u*v}.")) (|spherical| (((|Point| |#1|) (|Point| |#1|)) "\\spad{spherical(pt)} transforms \\spad{pt} from spherical coordinates to Cartesian coordinates: the function produced will map the point \\spad{(r,theta,phi)} to \\spad{x = r*sin(phi)*cos(theta)}, \\spad{y = r*sin(phi)*sin(theta)}, \\spad{z = r*cos(phi)}.")) (|cylindrical| (((|Point| |#1|) (|Point| |#1|)) "\\spad{cylindrical(pt)} transforms \\spad{pt} from polar coordinates to Cartesian coordinates: the function produced will map the point \\spad{(r,theta,z)} to \\spad{x = \\spad{r} * cos(theta)}, \\spad{y = \\spad{r} * sin(theta)}, \\spad{z}.")) (|polar| (((|Point| |#1|) (|Point| |#1|)) "\\spad{polar(pt)} transforms \\spad{pt} from polar coordinates to Cartesian coordinates: the function produced will map the point \\spad{(r,theta)} to \\spad{x = \\spad{r} * cos(theta)} ,{} \\spad{y = \\spad{r} * sin(theta)}.")) (|cartesian| (((|Point| |#1|) (|Point| |#1|)) "\\spad{cartesian(pt)} returns the Cartesian coordinates of point \\spad{pt.}"))) 
 NIL 
 NIL 
-(-177 R |PolR| E) 
+(-197 R |PolR| E) 
 ((|constructor| (NIL "This package implements characteristicPolynomials for monogenic algebras using resultants")) (|characteristicPolynomial| ((|#2| |#3|) "\\spad{characteristicPolynomial(e)} returns the characteristic polynomial of \\spad{e} using resultants"))) 
 NIL 
 NIL 
-(-178 R S CS) 
+(-198 R S CS) 
 ((|constructor| (NIL "This package supports matching patterns involving complex expressions")) (|patternMatch| (((|PatternMatchResult| |#1| |#3|) |#3| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#3|)) "\\spad{patternMatch(cexpr, pat, res)} matches the pattern \\spad{pat} to the complex expression cexpr. res contains the variables of \\spad{pat} which are already matched and their matches."))) 
 NIL 
-((|HasCategory| (-959 |#2|) (LIST (QUOTE -887) (|devaluate| |#1|)))) 
-(-179 R) 
+((|HasCategory| (-980 |#2|) (LIST (QUOTE -908) (|devaluate| |#1|)))) 
+(-199 R) 
 ((|constructor| (NIL "This package has no documentation")) (|multiEuclideanTree| (((|List| |#1|) (|List| |#1|) |#1|) "\\spad{multiEuclideanTree(l,r)} \\undocumented{}")) (|chineseRemainder| (((|List| |#1|) (|List| (|List| |#1|)) (|List| |#1|)) "\\spad{chineseRemainder(llv,lm)} returns a list of values, each of which corresponds to the Chinese remainder of the associated element of \\axiom{llv} and axiom{lm}. This is more efficient than applying chineseRemainder several times.") ((|#1| (|List| |#1|) (|List| |#1|)) "\\spad{chineseRemainder(lv,lm)} returns a value \\axiom{v} such that, if \\spad{x} is \\axiom{lv.i} modulo \\axiom{lm.i} for all \\axiom{i}, then \\spad{x} is \\axiom{v} modulo \\axiom{lm(1)*lm(2)*...*lm(n)}.")) (|modTree| (((|List| |#1|) |#1| (|List| |#1|)) "\\spad{modTree(r,l)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-180 R UP) 
+(-200 R UP) 
 ((|constructor| (NIL "\\spadtype{ComplexRootFindingPackage} provides functions to find all roots of a polynomial \\spad{p} over the complex number by using Plesken's idea to calculate in the polynomial ring modulo \\spad{f} and employing the Chinese Remainder Theorem. In this first version, the precision (see digits) is not increased when this is necessary to avoid rounding errors. Hence it is the user's responsibility to increase the precision if necessary. Note also, if this package is called with \\spadignore{e.g.} \\spadtype{Fraction Integer}, the precise calculations could require a lot of time. Also note that evaluating the zeros is not necessarily a good check whether the result is correct: already evaluation can cause rounding errors.")) (|startPolynomial| (((|Record| (|:| |start| |#2|) (|:| |factors| (|Factored| |#2|))) |#2|) "\\spad{startPolynomial(p)} uses the ideas of Schoenhage's variant of Graeffe's method to construct circles which separate roots to get a good start polynomial, \\spadignore{i.e.} one whose image under the Chinese Remainder Isomorphism has both entries of norm smaller and greater or equal to 1. In case the roots are found during internal calculations. The corresponding factors are in factors which are otherwise 1.")) (|setErrorBound| ((|#1| |#1|) "\\spad{setErrorBound(eps)} changes the internal error bound, by default being 10 \\spad{**} (-3) to eps, if \\spad{R} is a member in the category \\spadtype{QuotientFieldCategory Integer}. The internal globalDigits is set to \\em \\spad{ceiling(1/r)**2*10} being 10**7 by default.")) (|schwerpunkt| (((|Complex| |#1|) |#2|) "\\spad{schwerpunkt(p)} determines the 'Schwerpunkt' of the roots of the polynomial \\spad{p} of degree \\spad{n,} \\spadignore{i.e.} the center of gravity, which is coeffient of \\spad{x**(n-1)} divided by \\spad{n} times coefficient of \\spad{x**n}.")) (|rootRadius| ((|#1| |#2|) "\\spad{rootRadius(p)} calculates the root radius of \\spad{p} with a maximal error quotient of 1+globalEps, where globalEps is the internal error bound, which can be set by setErrorBound.") ((|#1| |#2| |#1|) "\\spad{rootRadius(p,errQuot)} calculates the root radius of \\spad{p} with a maximal error quotient of errQuot.")) (|reciprocalPolynomial| ((|#2| |#2|) "\\spad{reciprocalPolynomial(p)} calulates a polynomial which has exactly the inverses of the non-zero roots of \\spad{p} as roots, and the same number of 0-roots.")) (|pleskenSplit| (((|Factored| |#2|) |#2| |#1|) "\\spad{pleskenSplit(poly, eps)} determines a start polynomial start by using \"startPolynomial then it increases the exponent \\spad{n} of start \\spad{**} \\spad{n} mod \\spad{poly} to get an approximate factor of poly, in general of degree \"degree \\spad{poly} -1\". Then a divisor cascade is calculated and the best splitting is chosen, as soon as the error is small enough.") (((|Factored| |#2|) |#2| |#1| (|Boolean|)) "\\spad{pleskenSplit(poly,eps,info)} determines a start polynomial start by using \"startPolynomial then it increases the exponent \\spad{n} of start \\spad{**} \\spad{n} mod \\spad{poly} to get an approximate factor of poly, in general of degree \"degree \\spad{poly} -1\". Then a divisor cascade is calculated and the best splitting is chosen, as soon as the error is small enough. If \\spad{info} is true, then information messages are issued.")) (|norm| ((|#1| |#2|) "\\spad{norm(p)} determines sum of absolute values of coefficients Note that this function depends on abs.")) (|graeffe| ((|#2| |#2|) "\\spad{graeffe \\spad{p}} determines \\spad{q} such that \\spad{q(-z**2) = p(z)*p(-z)}. Note that the roots of \\spad{q} are the squares of the roots of \\spad{p.}")) (|factor| (((|Factored| |#2|) |#2|) "\\spad{factor(p)} tries to factor \\spad{p} into linear factors with error atmost globalEps, the internal error bound, which can be set by setErrorBound. An overall error bound \\spad{eps0} is determined and iterated tree-like calls to pleskenSplit are used to get the factorization.") (((|Factored| |#2|) |#2| |#1|) "\\spad{factor(p, eps)} tries to factor \\spad{p} into linear factors with error atmost eps. An overall error bound \\spad{eps0} is determined and iterated tree-like calls to pleskenSplit are used to get the factorization.") (((|Factored| |#2|) |#2| |#1| (|Boolean|)) "\\spad{factor(p, eps, info)} tries to factor \\spad{p} into linear factors with error atmost eps. An overall error bound \\spad{eps0} is determined and iterated tree-like calls to pleskenSplit are used to get the factorization. If info is true, then information messages are given.")) (|divisorCascade| (((|List| (|Record| (|:| |factors| (|List| |#2|)) (|:| |error| |#1|))) |#2| |#2|) "\\spad{divisorCascade(p,tp)} assumes that degree of polynomial \\spad{tp} is smaller than degree of polynomial \\spad{p,} both monic. A sequence of divisions is calculated using the remainder, made monic, as divisor for the the next division. The result contains also the error of the factorizations, \\spadignore{i.e.} the norm of the remainder polynomial.") (((|List| (|Record| (|:| |factors| (|List| |#2|)) (|:| |error| |#1|))) |#2| |#2| (|Boolean|)) "\\spad{divisorCascade(p,tp)} assumes that degree of polynomial \\spad{tp} is smaller than degree of polynomial \\spad{p,} both monic. A sequence of divisions are calculated using the remainder, made monic, as divisor for the the next division. The result contains also the error of the factorizations, \\spadignore{i.e.} the norm of the remainder polynomial. If info is true, then information messages are issued.")) (|complexZeros| (((|List| (|Complex| |#1|)) |#2| |#1|) "\\spad{complexZeros(p, eps)} tries to determine all complex zeros of the polynomial \\spad{p} with accuracy given by eps.") (((|List| (|Complex| |#1|)) |#2|) "\\spad{complexZeros(p)} tries to determine all complex zeros of the polynomial \\spad{p} with accuracy given by the package constant globalEps which you may change by setErrorBound."))) 
 NIL 
 NIL 
-(-181 S ST) 
+(-201 S ST) 
 ((|constructor| (NIL "This package provides tools for working with cyclic streams.")) (|computeCycleEntry| ((|#2| |#2| |#2|) "\\indented{1}{computeCycleEntry(x,cycElt), where cycElt is a pointer to a} \\indented{1}{node in the cyclic part of the cyclic stream \\spad{x,} returns a} \\indented{1}{pointer to the first node in the cycle} \\blankline \\spad{X} p:=repeating([1,2,3]) \\spad{X} q:=cons(4,p) \\spad{X} computeCycleEntry(q,cycleElt(q))")) (|computeCycleLength| (((|NonNegativeInteger|) |#2|) "\\indented{1}{computeCycleLength(s) returns the length of the cycle of a} \\indented{1}{cyclic stream \\spad{t,} where \\spad{s} is a pointer to a node in the} \\indented{1}{cyclic part of \\spad{t.}} \\blankline \\spad{X} p:=repeating([1,2,3]) \\spad{X} q:=cons(4,p) \\spad{X} computeCycleLength(cycleElt(q))")) (|cycleElt| (((|Union| |#2| "failed") |#2|) "\\indented{1}{cycleElt(s) returns a pointer to a node in the cycle if the stream} \\indented{1}{s is cyclic and returns \"failed\" if \\spad{s} is not cyclic} \\blankline \\spad{X} p:=repeating([1,2,3]) \\spad{X} q:=cons(4,p) \\spad{X} cycleElt \\spad{q} \\spad{X} r:=[1,2,3]::Stream(Integer) \\spad{X} cycleElt \\spad{r}"))) 
 NIL 
 NIL 
-(-182 R -3313) 
+(-202 R -3958) 
 ((|constructor| (NIL "\\spadtype{ComplexTrigonometricManipulations} provides function that compute the real and imaginary parts of complex functions.")) (|complexForm| (((|Complex| (|Expression| |#1|)) |#2|) "\\spad{complexForm(f)} returns \\spad{[real \\spad{f,} imag f]}.")) (|trigs| ((|#2| |#2|) "\\spad{trigs(f)} rewrites all the complex logs and exponentials appearing in \\spad{f} in terms of trigonometric functions.")) (|real?| (((|Boolean|) |#2|) "\\spad{real?(f)} returns \\spad{true} if \\spad{f = real \\spad{f}.}")) (|imag| (((|Expression| |#1|) |#2|) "\\spad{imag(f)} returns the imaginary part of \\spad{f} where \\spad{f} is a complex function.")) (|real| (((|Expression| |#1|) |#2|) "\\spad{real(f)} returns the real part of \\spad{f} where \\spad{f} is a complex function.")) (|complexElementary| ((|#2| |#2| (|Symbol|)) "\\spad{complexElementary(f, \\spad{x)}} rewrites the kernels of \\spad{f} involving \\spad{x} in terms of the 2 fundamental complex transcendental elementary functions: \\spad{log, exp}.") ((|#2| |#2|) "\\spad{complexElementary(f)} rewrites \\spad{f} in terms of the 2 fundamental complex transcendental elementary functions: \\spad{log, exp}.")) (|complexNormalize| ((|#2| |#2| (|Symbol|)) "\\spad{complexNormalize(f, \\spad{x)}} rewrites \\spad{f} using the least possible number of complex independent kernels involving \\spad{x}.") ((|#2| |#2|) "\\spad{complexNormalize(f)} rewrites \\spad{f} using the least possible number of complex independent kernels."))) 
 NIL 
 NIL 
-(-183 R) 
+(-203 R) 
 ((|constructor| (NIL "CoerceVectorMatrixPackage is an unexposed, technical package for data conversions")) (|coerce| (((|Vector| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|Vector| (|Matrix| |#1|))) "\\spad{coerce(v)} coerces a vector \\spad{v} with entries in \\spadtype{Matrix \\spad{R}} as vector over \\spadtype{Matrix Fraction Polynomial \\spad{R}}")) (|coerceP| (((|Vector| (|Matrix| (|Polynomial| |#1|))) (|Vector| (|Matrix| |#1|))) "\\spad{coerceP(v)} coerces a vector \\spad{v} with entries in \\spadtype{Matrix \\spad{R}} as vector over \\spadtype{Matrix Polynomial \\spad{R}}"))) 
 NIL 
 NIL 
-(-184) 
+(-204) 
 ((|constructor| (NIL "Polya-Redfield enumeration by cycle indices.")) (|skewSFunction| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{skewSFunction(li1,li2)} is the S-function \\indented{1}{of the partition difference \\spad{li1 - li2}} \\indented{1}{expressed in terms of power sum symmetric functions.}")) (|SFunction| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|List| (|Integer|))) "\\spad{SFunction(li)} is the S-function of the partition \\spad{li} \\indented{1}{expressed in terms of power sum symmetric functions.}")) (|wreath| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|SymmetricPolynomial| (|Fraction| (|Integer|))) (|SymmetricPolynomial| (|Fraction| (|Integer|)))) "\\spad{wreath(s1,s2)} is the cycle index of the wreath product \\indented{1}{of the two groups whose cycle indices are \\spad{s1} and} \\indented{1}{\\spad{s2}.}")) (|eval| (((|Fraction| (|Integer|)) (|SymmetricPolynomial| (|Fraction| (|Integer|)))) "\\spad{eval \\spad{s}} is the sum of the coefficients of a cycle index.")) (|cup| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|SymmetricPolynomial| (|Fraction| (|Integer|))) (|SymmetricPolynomial| (|Fraction| (|Integer|)))) "\\spad{cup(s1,s2)}, introduced by Redfield, \\indented{1}{is the scalar product of two cycle indices, in which the} \\indented{1}{power sums are retained to produce a cycle index.}")) (|cap| (((|Fraction| (|Integer|)) (|SymmetricPolynomial| (|Fraction| (|Integer|))) (|SymmetricPolynomial| (|Fraction| (|Integer|)))) "\\spad{cap(s1,s2)}, introduced by Redfield, \\indented{1}{is the scalar product of two cycle indices.}")) (|graphs| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{graphs \\spad{n}} is the cycle index of the group induced on \\indented{1}{the edges of a graph by applying the symmetric function to the} \\indented{1}{n nodes.}")) (|dihedral| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{dihedral \\spad{n}} is the cycle index of the \\indented{1}{dihedral group of degree \\spad{n.}}")) (|cyclic| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{cyclic \\spad{n}} is the cycle index of the \\indented{1}{cyclic group of degree \\spad{n.}}")) (|alternating| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{alternating \\spad{n}} is the cycle index of the \\indented{1}{alternating group of degree \\spad{n.}}")) (|elementary| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{elementary \\spad{n}} is the \\spad{n} th elementary symmetric \\indented{1}{function expressed in terms of power sums.}")) (|powerSum| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{powerSum \\spad{n}} is the \\spad{n} th power sum symmetric \\indented{1}{function.}")) (|complete| (((|SymmetricPolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{complete \\spad{n}} is the \\spad{n} th complete homogeneous \\indented{1}{symmetric function expressed in terms of power sums.} \\indented{1}{Alternatively it is the cycle index of the symmetric} \\indented{1}{group of degree \\spad{n.}}"))) 
 NIL 
 NIL 
-(-185) 
+(-205) 
 ((|constructor| (NIL "This package has no description")) (|cyclotomicFactorization| (((|Factored| (|SparseUnivariatePolynomial| (|Integer|))) (|Integer|)) "\\spad{cyclotomicFactorization(n)} \\undocumented{}")) (|cyclotomic| (((|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "\\spad{cyclotomic(n)} \\undocumented{}")) (|cyclotomicDecomposition| (((|List| (|SparseUnivariatePolynomial| (|Integer|))) (|Integer|)) "\\spad{cyclotomicDecomposition(n)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-186) 
+(-206) 
 ((|constructor| (NIL "\\axiomType{d01AgentsPackage} is a package of numerical agents to be used to investigate attributes of an input function so as to decide the \\axiomFun{measure} of an appropriate numerical integration routine. It contains functions \\axiomFun{rangeIsFinite} to test the input range and \\axiomFun{functionIsContinuousAtEndPoints} to check for continuity at the end points of the range.")) (|changeName| (((|Result|) (|Symbol|) (|Symbol|) (|Result|)) "\\spad{changeName(s,t,r)} changes the name of item \\axiom{s} in \\axiom{r} to \\axiom{t}.")) (|commaSeparate| (((|String|) (|List| (|String|))) "\\spad{commaSeparate(l)} produces a comma separated string from a list of strings.")) (|sdf2lst| (((|List| (|String|)) (|Stream| (|DoubleFloat|))) "\\spad{sdf2lst(ln)} coerces a Stream of \\axiomType{DoubleFloat} to \\axiomType{List String}")) (|ldf2lst| (((|List| (|String|)) (|List| (|DoubleFloat|))) "\\spad{ldf2lst(ln)} coerces a List of \\axiomType{DoubleFloat} to \\axiomType{List String}")) (|df2st| (((|String|) (|DoubleFloat|)) "\\spad{df2st(n)} coerces a \\axiomType{DoubleFloat} to \\axiomType{String}")) (|singularitiesOf| (((|Stream| (|DoubleFloat|)) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{singularitiesOf(args)} returns a list of potential singularities of the function within the given range")) (|problemPoints| (((|List| (|DoubleFloat|)) (|Expression| (|DoubleFloat|)) (|Symbol|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{problemPoints(f,var,range)} returns a list of possible problem points by looking at the zeros of the denominator of the function if it can be retracted to \\axiomType{Polynomial DoubleFloat}.")) (|functionIsOscillatory| (((|Float|) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{functionIsOscillatory(a)} tests whether the function \\spad{a.fn} has many zeros of its derivative.")) (|gethi| (((|DoubleFloat|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{gethi(x)} gets the \\axiomType{DoubleFloat} equivalent of the second endpoint of the range \\axiom{x}")) (|getlo| (((|DoubleFloat|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{getlo(x)} gets the \\axiomType{DoubleFloat} equivalent of the first endpoint of the range \\axiom{x}")) (|functionIsContinuousAtEndPoints| (((|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{functionIsContinuousAtEndPoints(args)} uses power series limits to check for problems at the end points of the range of \\spad{args}.")) (|rangeIsFinite| (((|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{rangeIsFinite(args)} tests the endpoints of \\spad{args.range} for infinite end points."))) 
 NIL 
 NIL 
-(-187) 
+(-207) 
 ((|constructor| (NIL "\\axiomType{d01ajfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01AJF, a general numerical integration routine which can handle some singularities in the input function. The function \\axiomFun{measure} measures the usefulness of the routine D01AJF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-188) 
+(-208) 
 ((|constructor| (NIL "\\axiomType{d01akfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01AKF, a numerical integration routine which is is suitable for oscillating, non-singular functions. The function \\axiomFun{measure} measures the usefulness of the routine D01AKF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-189) 
+(-209) 
 ((|constructor| (NIL "\\axiomType{d01alfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01ALF, a general numerical integration routine which can handle a list of singularities. The function \\axiomFun{measure} measures the usefulness of the routine D01ALF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-190) 
+(-210) 
 ((|constructor| (NIL "\\axiomType{d01amfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01AMF, a general numerical integration routine which can handle infinite or semi-infinite range of the input function. The function \\axiomFun{measure} measures the usefulness of the routine D01AMF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-191) 
+(-211) 
 ((|constructor| (NIL "\\axiomType{d01anfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01ANF, a numerical integration routine which can handle weight functions of the form cos(\\omega \\spad{x)} or sin(\\omega \\spad{x).} The function \\axiomFun{measure} measures the usefulness of the routine D01ANF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-192) 
+(-212) 
 ((|constructor| (NIL "\\axiomType{d01apfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01APF, a general numerical integration routine which can handle end point singularities of the algebraico-logarithmic form w(x) = (x-a)^c * (b-x)^d. The function \\axiomFun{measure} measures the usefulness of the routine D01APF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-193) 
+(-213) 
 ((|constructor| (NIL "\\axiomType{d01aqfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01AQF, a general numerical integration routine which can solve an integral of the form /home/bjd/Axiom/anna/hypertex/bitmaps/d01aqf.xbm The function \\axiomFun{measure} measures the usefulness of the routine D01AQF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-194) 
+(-214) 
 ((|constructor| (NIL "\\axiomType{d01asfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01ASF, a numerical integration routine which can handle weight functions of the form cos(\\omega \\spad{x)} or sin(\\omega \\spad{x)} on an semi-infinite range. The function \\axiomFun{measure} measures the usefulness of the routine D01ASF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-195) 
+(-215) 
 ((|constructor| (NIL "\\axiomType{d01fcfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01FCF, a numerical integration routine which can handle multi-dimensional quadrature over a finite region. The function \\axiomFun{measure} measures the usefulness of the routine D01GBF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-196) 
+(-216) 
 ((|constructor| (NIL "\\axiomType{d01gbfAnnaType} is a domain of \\axiomType{NumericalIntegrationCategory} for the NAG routine D01GBF, a numerical integration routine which can handle multi-dimensional quadrature over a finite region. The function \\axiomFun{measure} measures the usefulness of the routine D01GBF for the given problem. The function \\axiomFun{numericalIntegration} performs the integration by using \\axiomType{NagIntegrationPackage}."))) 
 NIL 
 NIL 
-(-197) 
+(-217) 
 NIL 
 NIL 
 NIL 
-(-198) 
+(-218) 
 ((|constructor| (NIL "\\axiom{d01WeightsPackage} is a package for functions used to investigate whether a function can be divided into a simpler function and a weight function. The types of weights investigated are those giving rise to end-point singularities of the algebraico-logarithmic type, and trigonometric weights.")) (|exprHasLogarithmicWeights| (((|Integer|) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\axiom{exprHasLogarithmicWeights} looks for logarithmic weights giving rise to singularities of the function at the end-points.")) (|exprHasAlgebraicWeight| (((|Union| (|List| (|DoubleFloat|)) "failed") (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\axiom{exprHasAlgebraicWeight} looks for algebraic weights giving rise to singularities of the function at the end-points.")) (|exprHasWeightCosWXorSinWX| (((|Union| (|Record| (|:| |op| (|BasicOperator|)) (|:| |w| (|DoubleFloat|))) "failed") (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\axiom{exprHasWeightCosWXorSinWX} looks for trigonometric weights in an expression of the form \\axiom{cos \\omega \\spad{x}} or \\axiom{sin \\omega \\spad{x},} returning the value of \\omega (\\notequal 1) and the operator."))) 
 NIL 
 NIL 
-(-199) 
+(-219) 
 ((|constructor| (NIL "\\indented{1}{Author: Brian Dupee} Date Created: May 1994 Date Last Updated: January 1997 Description:")) (|intermediateResultsIF| (((|Float|) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{intermediateResultsIF(o)} returns a value corresponding to the required number of intermediate results required and, therefore, an indication of how much this would affect the step-length of the calculation. It returns a value in the range [0,1].")) (|accuracyIF| (((|Float|) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{accuracyIF(o)} returns the intensity value of the accuracy requirements of the input ODE. A request of accuracy of 10^-6 corresponds to the neutral intensity. It returns a value in the range [0,1].")) (|expenseOfEvaluationIF| (((|Float|) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{expenseOfEvaluationIF(o)} returns the intensity value of the cost of evaluating the input ODE. This is in terms of the number of ``operational units''. It returns a value in the range [0,1].\\indent{20} 400 ``operation units'' \\spad{->} 0.75 200 ``operation units'' \\spad{->} 0.5 83 ``operation units'' \\spad{->} 0.25 \\indent{15} exponentiation = 4 units ,{} function calls = 10 units.")) (|systemSizeIF| (((|Float|) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{systemSizeIF(ode)} returns the intensity value of the size of the system of ODEs. 20 equations corresponds to the neutral value. It returns a value in the range [0,1].")) (|stiffnessAndStabilityOfODEIF| (((|Record| (|:| |stiffnessFactor| (|Float|)) (|:| |stabilityFactor| (|Float|))) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{stiffnessAndStabilityOfODEIF(ode)} calculates the intensity values of stiffness of a system of first-order differential equations (by evaluating the maximum difference in the real parts of the negative eigenvalues of the jacobian of the system for which O(10) equates to mildly stiff wheras stiffness ratios of O(10^6) are not uncommon) and whether the system is likely to show any oscillations (identified by the closeness to the imaginary axis of the complex eigenvalues of the jacobian). \\blankline It returns two values in the range [0,1].")) (|stiffnessAndStabilityFactor| (((|Record| (|:| |stiffnessFactor| (|Float|)) (|:| |stabilityFactor| (|Float|))) (|Matrix| (|Expression| (|DoubleFloat|)))) "\\spad{stiffnessAndStabilityFactor(me)} calculates the stability and stiffness factor of a system of first-order differential equations (by evaluating the maximum difference in the real parts of the negative eigenvalues of the jacobian of the system for which O(10) equates to mildly stiff wheras stiffness ratios of O(10^6) are not uncommon) and whether the system is likely to show any oscillations (identified by the closeness to the imaginary axis of the complex eigenvalues of the jacobian).")) (|eval| (((|Matrix| (|Expression| (|DoubleFloat|))) (|Matrix| (|Expression| (|DoubleFloat|))) (|List| (|Symbol|)) (|Vector| (|Expression| (|DoubleFloat|)))) "\\spad{eval(mat,symbols,values)} evaluates a multivariable matrix at given \\spad{values} for each of a list of variables")) (|jacobian| (((|Matrix| (|Expression| (|DoubleFloat|))) (|Vector| (|Expression| (|DoubleFloat|))) (|List| (|Symbol|))) "\\spad{jacobian(v,w)} is a local function to make a jacobian matrix")) (|sparsityIF| (((|Float|) (|Matrix| (|Expression| (|DoubleFloat|)))) "\\spad{sparsityIF(m)} calculates the sparsity of a jacobian matrix")) (|combineFeatureCompatibility| (((|Float|) (|Float|) (|List| (|Float|))) "\\spad{combineFeatureCompatibility(C1,L)} is for interacting attributes") (((|Float|) (|Float|) (|Float|)) "\\spad{combineFeatureCompatibility(C1,C2)} is for interacting attributes"))) 
 NIL 
 NIL 
-(-200) 
+(-220) 
 ((|constructor| (NIL "\\axiomType{d02bbfAnnaType} is a domain of \\axiomType{OrdinaryDifferentialEquationsInitialValueProblemSolverCategory} for the NAG routine D02BBF, a ODE routine which uses an Runge-Kutta method to solve a system of differential equations. The function \\axiomFun{measure} measures the usefulness of the routine D02BBF for the given problem. The function \\axiomFun{ODESolve} performs the integration by using \\axiomType{NagOrdinaryDifferentialEquationsPackage}."))) 
 NIL 
 NIL 
-(-201) 
+(-221) 
 ((|constructor| (NIL "\\axiomType{d02bhfAnnaType} is a domain of \\axiomType{OrdinaryDifferentialEquationsInitialValueProblemSolverCategory} for the NAG routine D02BHF, a ODE routine which uses an Runge-Kutta method to solve a system of differential equations. The function \\axiomFun{measure} measures the usefulness of the routine D02BHF for the given problem. The function \\axiomFun{ODESolve} performs the integration by using \\axiomType{NagOrdinaryDifferentialEquationsPackage}."))) 
 NIL 
 NIL 
-(-202) 
+(-222) 
 ((|constructor| (NIL "\\axiomType{d02cjfAnnaType} is a domain of \\axiomType{OrdinaryDifferentialEquationsInitialValueProblemSolverCategory} for the NAG routine D02CJF, a ODE routine which uses an Adams-Moulton-Bashworth method to solve a system of differential equations. The function \\axiomFun{measure} measures the usefulness of the routine D02CJF for the given problem. The function \\axiomFun{ODESolve} performs the integration by using \\axiomType{NagOrdinaryDifferentialEquationsPackage}."))) 
 NIL 
 NIL 
-(-203) 
+(-223) 
 ((|constructor| (NIL "\\axiomType{d02ejfAnnaType} is a domain of \\axiomType{OrdinaryDifferentialEquationsInitialValueProblemSolverCategory} for the NAG routine D02EJF, a ODE routine which uses a backward differentiation formulae method to handle a stiff system of differential equations. The function \\axiomFun{measure} measures the usefulness of the routine D02EJF for the given problem. The function \\axiomFun{ODESolve} performs the integration by using \\axiomType{NagOrdinaryDifferentialEquationsPackage}."))) 
 NIL 
 NIL 
-(-204) 
+(-224) 
 ((|constructor| (NIL "\\axiom{d03AgentsPackage} contains a set of computational agents for use with Partial Differential Equation solvers.")) (|elliptic?| (((|Boolean|) (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) "\\spad{elliptic?(r)} \\undocumented{}")) (|central?| (((|Boolean|) (|DoubleFloat|) (|DoubleFloat|) (|List| (|Expression| (|DoubleFloat|)))) "\\spad{central?(f,g,l)} \\undocumented{}")) (|subscriptedVariables| (((|Expression| (|DoubleFloat|)) (|Expression| (|DoubleFloat|))) "\\spad{subscriptedVariables(e)} \\undocumented{}")) (|varList| (((|List| (|Symbol|)) (|Symbol|) (|NonNegativeInteger|)) "\\spad{varList(s,n)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-205) 
+(-225) 
 ((|constructor| (NIL "\\axiomType{d03eefAnnaType} is a domain of \\axiomType{PartialDifferentialEquationsSolverCategory} for the NAG routines D03EEF/D03EDF."))) 
 NIL 
 NIL 
-(-206) 
+(-226) 
 ((|constructor| (NIL "\\axiomType{d03fafAnnaType} is a domain of \\axiomType{PartialDifferentialEquationsSolverCategory} for the NAG routine D03FAF."))) 
 NIL 
 NIL 
-(-207 S) 
+(-227 S) 
 ((|constructor| (NIL "This domain implements a simple view of a database whose fields are indexed by symbols")) (|coerce| (($ (|List| |#1|)) "\\spad{coerce(l)} makes a database out of a list")) (- (($ $ $) "\\spad{db1-db2} returns the difference of databases \\spad{db1} and \\spad{db2} \\spadignore{i.e.} consisting of elements in \\spad{db1} but not in \\spad{db2}")) (+ (($ $ $) "\\spad{db1+db2} returns the merge of databases \\spad{db1} and \\spad{db2}")) (|fullDisplay| (((|Void|) $ (|PositiveInteger|) (|PositiveInteger|)) "\\spad{fullDisplay(db,start,end \\spad{)}} prints full details of entries in the range \\axiom{start..end} in \\axiom{db}.") (((|Void|) $) "\\spad{fullDisplay(db)} prints full details of each entry in \\axiom{db}.") (((|Void|) $) "\\spad{fullDisplay(x)} displays \\spad{x} in detail")) (|display| (((|Void|) $) "\\spad{display(db)} prints a summary line for each entry in \\axiom{db}.") (((|Void|) $) "\\spad{display(x)} displays \\spad{x} in some form")) (|elt| (((|DataList| (|String|)) $ (|Symbol|)) "\\spad{elt(db,s)} returns the \\axiom{s} field of each element of \\axiom{db}.") (($ $ (|QueryEquation|)) "\\spad{elt(db,q)} returns all elements of \\axiom{db} which satisfy \\axiom{q}.") (((|String|) $ (|Symbol|)) "\\spad{elt(x,s)} returns an element of \\spad{x} indexed by \\spad{s}"))) 
 NIL 
 NIL 
-(-208 -3313 UP UPUP R) 
+(-228 -3958 UP UPUP R) 
 ((|constructor| (NIL "This package provides functions for computing the residues of a function on an algebraic curve.")) (|doubleResultant| ((|#2| |#4| (|Mapping| |#2| |#2|)) "\\spad{doubleResultant(f, \\spad{')}} returns p(x) whose roots are rational multiples of the residues of \\spad{f} at all its finite poles. Argument ' is the derivation to use."))) 
 NIL 
 NIL 
-(-209 -3313 FP) 
+(-229 -3958 FP) 
 ((|constructor| (NIL "Package for the factorization of a univariate polynomial with coefficients in a finite field. The algorithm used is the \"distinct degree\" algorithm of Cantor-Zassenhaus, modified to use trace instead of the norm and a table for computing Frobenius as suggested by Naudin and Quitte .")) (|irreducible?| (((|Boolean|) |#2|) "\\spad{irreducible?(p)} tests whether the polynomial \\spad{p} is irreducible.")) (|tracePowMod| ((|#2| |#2| (|NonNegativeInteger|) |#2|) "\\spad{tracePowMod(u,k,v)} produces the sum of \\spad{u**(q**i)} for \\spad{i} running and \\spad{q=} size \\spad{F}")) (|trace2PowMod| ((|#2| |#2| (|NonNegativeInteger|) |#2|) "\\spad{trace2PowMod(u,k,v)} produces the sum of u**(2**i) for \\spad{i} running from 1 to \\spad{k} all computed modulo the polynomial \\spad{v.}")) (|exptMod| ((|#2| |#2| (|NonNegativeInteger|) |#2|) "\\spad{exptMod(u,k,v)} raises the polynomial \\spad{u} to the \\spad{k}th power modulo the polynomial \\spad{v.}")) (|separateFactors| (((|List| |#2|) (|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |prod| |#2|)))) "\\spad{separateFactors(lfact)} takes the list produced by separateDegrees and produces the complete list of factors.")) (|separateDegrees| (((|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |prod| |#2|))) |#2|) "\\spad{separateDegrees(p)} splits the square free polynomial \\spad{p} into factors each of which is a product of irreducibles of the same degree.")) (|distdfact| (((|Record| (|:| |cont| |#1|) (|:| |factors| (|List| (|Record| (|:| |irr| |#2|) (|:| |pow| (|Integer|)))))) |#2| (|Boolean|)) "\\spad{distdfact(p,sqfrflag)} produces the complete factorization of the polynomial \\spad{p} returning an internal data structure. If argument \\spad{sqfrflag} is true, the polynomial is assumed square free.")) (|factorSquareFree| (((|Factored| |#2|) |#2|) "\\spad{factorSquareFree(p)} produces the complete factorization of the square free polynomial \\spad{p.}")) (|factor| (((|Factored| |#2|) |#2|) "\\spad{factor(p)} produces the complete factorization of the polynomial \\spad{p.}"))) 
 NIL 
 NIL 
-(-210) 
+(-230) 
 ((|constructor| (NIL "This domain allows rational numbers to be presented as repeating decimal expansions.")) (|decimal| (($ (|Fraction| (|Integer|))) "\\spad{decimal(r)} converts a rational number to a decimal expansion.")) (|fractionPart| (((|Fraction| (|Integer|)) $) "\\spad{fractionPart(d)} returns the fractional part of a decimal expansion.")) (|coerce| (((|RadixExpansion| 10) $) "\\spad{coerce(d)} converts a decimal expansion to a radix expansion with base 10.") (((|Fraction| (|Integer|)) $) "\\spad{coerce(d)} converts a decimal expansion to a rational number."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-572) (QUOTE (-910))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-572) (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-151))) (|HasCategory| (-572) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-572) (QUOTE (-1028))) (|HasCategory| (-572) (QUOTE (-821))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1144))) (|HasCategory| (-572) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| (-572) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| (-572) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| (-572) (QUOTE (-227))) (|HasCategory| (-572) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-572) (LIST (QUOTE -527) (QUOTE (-1170)) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -283) (QUOTE (-572)) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-303))) (|HasCategory| (-572) (QUOTE (-554))) (|HasCategory| (-572) (QUOTE (-848))) (-1841 (|HasCategory| (-572) (QUOTE (-821))) (|HasCategory| (-572) (QUOTE (-848)))) (|HasCategory| (-572) (LIST (QUOTE -634) (QUOTE (-572)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-910)))) (|HasCategory| (-572) (QUOTE (-149))))) 
-(-211 R -3313) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-592) (QUOTE (-931))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-592) (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-171))) (|HasCategory| (-592) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-592) (QUOTE (-1049))) (|HasCategory| (-592) (QUOTE (-842))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1165))) (|HasCategory| (-592) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| (-592) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| (-592) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| (-592) (QUOTE (-247))) (|HasCategory| (-592) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-592) (LIST (QUOTE -547) (QUOTE (-1191)) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -303) (QUOTE (-592)) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-323))) (|HasCategory| (-592) (QUOTE (-574))) (|HasCategory| (-592) (QUOTE (-869))) (-3836 (|HasCategory| (-592) (QUOTE (-842))) (|HasCategory| (-592) (QUOTE (-869)))) (|HasCategory| (-592) (LIST (QUOTE -654) (QUOTE (-592)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-931)))) (|HasCategory| (-592) (QUOTE (-169))))) 
+(-231 R -3958) 
 ((|constructor| (NIL "\\spadtype{ElementaryFunctionDefiniteIntegration} provides functions to compute definite integrals of elementary functions.")) (|innerint| (((|Union| (|:| |f1| (|OrderedCompletion| |#2|)) (|:| |f2| (|List| (|OrderedCompletion| |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (|Symbol|) (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|) (|Boolean|)) "\\spad{innerint(f, \\spad{x,} a, \\spad{b,} ignore?)} should be local but conditional")) (|integrate| (((|Union| (|:| |f1| (|OrderedCompletion| |#2|)) (|:| |f2| (|List| (|OrderedCompletion| |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (|SegmentBinding| (|OrderedCompletion| |#2|)) (|String|)) "\\spad{integrate(f, \\spad{x} = a..b, \"noPole\")} returns the integral of \\spad{f(x)dx} from a to \\spad{b.} If it is not possible to check whether \\spad{f} has a pole for \\spad{x} between a and \\spad{b} (because of parameters), then this function will assume that \\spad{f} has no such pole. Error: if \\spad{f} has a pole for \\spad{x} between a and \\spad{b} or if the last argument is not \"noPole\".") (((|Union| (|:| |f1| (|OrderedCompletion| |#2|)) (|:| |f2| (|List| (|OrderedCompletion| |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (|SegmentBinding| (|OrderedCompletion| |#2|))) "\\spad{integrate(f, \\spad{x} = a..b)} returns the integral of \\spad{f(x)dx} from a to \\spad{b.} Error: if \\spad{f} has a pole for \\spad{x} between a and \\spad{b.}"))) 
 NIL 
 NIL 
-(-212 R) 
+(-232 R) 
 ((|constructor| (NIL "Definite integration of rational functions. \\spadtype{RationalFunctionDefiniteIntegration} provides functions to compute definite integrals of rational functions.")) (|integrate| (((|Union| (|:| |f1| (|OrderedCompletion| (|Expression| |#1|))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (|Fraction| (|Polynomial| |#1|)) (|SegmentBinding| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|)))) (|String|)) "\\spad{integrate(f, \\spad{x} = a..b, \"noPole\")} returns the integral of \\spad{f(x)dx} from a to \\spad{b.} If it is not possible to check whether \\spad{f} has a pole for \\spad{x} between a and \\spad{b} (because of parameters), then this function will assume that \\spad{f} has no such pole. Error: if \\spad{f} has a pole for \\spad{x} between a and \\spad{b} or if the last argument is not \"noPole\".") (((|Union| (|:| |f1| (|OrderedCompletion| (|Expression| |#1|))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (|Fraction| (|Polynomial| |#1|)) (|SegmentBinding| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|))))) "\\spad{integrate(f, \\spad{x} = a..b)} returns the integral of \\spad{f(x)dx} from a to \\spad{b.} Error: if \\spad{f} has a pole for \\spad{x} between a and \\spad{b.}") (((|Union| (|:| |f1| (|OrderedCompletion| (|Expression| |#1|))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (|Fraction| (|Polynomial| |#1|)) (|SegmentBinding| (|OrderedCompletion| (|Expression| |#1|))) (|String|)) "\\spad{integrate(f, \\spad{x} = a..b, \"noPole\")} returns the integral of \\spad{f(x)dx} from a to \\spad{b.} If it is not possible to check whether \\spad{f} has a pole for \\spad{x} between a and \\spad{b} (because of parameters), then this function will assume that \\spad{f} has no such pole. Error: if \\spad{f} has a pole for \\spad{x} between a and \\spad{b} or if the last argument is not \"noPole\".") (((|Union| (|:| |f1| (|OrderedCompletion| (|Expression| |#1|))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (|Fraction| (|Polynomial| |#1|)) (|SegmentBinding| (|OrderedCompletion| (|Expression| |#1|)))) "\\spad{integrate(f, \\spad{x} = a..b)} returns the integral of \\spad{f(x)dx} from a to \\spad{b.} Error: if \\spad{f} has a pole for \\spad{x} between a and \\spad{b.}"))) 
 NIL 
 NIL 
-(-213 R1 R2) 
+(-233 R1 R2) 
 ((|constructor| (NIL "This package has no description")) (|expand| (((|List| (|Expression| |#2|)) (|Expression| |#2|) (|PositiveInteger|)) "\\spad{expand(f,n)} \\undocumented{}")) (|reduce| (((|Record| (|:| |pol| (|SparseUnivariatePolynomial| |#1|)) (|:| |deg| (|PositiveInteger|))) (|SparseUnivariatePolynomial| |#1|)) "\\spad{reduce(p)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-214 S) 
+(-234 S) 
 ((|constructor| (NIL "Linked list implementation of a Dequeue")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} member?(3,a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} count(4,a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} count(x+->(x>2),a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} any?(x+->(x=4),a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} every?(x+->(x=4),a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} b:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} map!(x+->x+10,a) \\spad{X} a")) (|top!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} top! a \\spad{X} a")) (|reverse!| (($ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} reverse! a \\spad{X} a")) (|push!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} push! a \\spad{X} a")) (|pop!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} pop! a \\spad{X} a")) (|insertTop!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} insertTop! a \\spad{X} a")) (|insertBottom!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} insertBottom! a \\spad{X} a")) (|extractTop!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} extractTop! a \\spad{X} a")) (|extractBottom!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} extractBottom! a \\spad{X} a")) (|bottom!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} bottom! a \\spad{X} a")) (|top| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} top a")) (|height| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} height a")) (|depth| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} depth a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} map(x+->x+10,a) \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} eq?(a,b)")) (|copy| (($ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} copy a")) (|sample| (($) "\\blankline \\spad{X} sample()$Dequeue(INT)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()$(Dequeue INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} empty? a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,2,3,4,5])$Dequeue(INT)")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} size?(a,5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} more?(a,9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} less?(a,9)")) (|length| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} length a")) (|rotate!| (($ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} rotate! a")) (|back| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} back a")) (|front| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} front a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} insert! (8,a) \\spad{X} a")) (|enqueue!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} enqueue! (9,a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} extract! a \\spad{X} a")) (|dequeue!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,2,3,4,5] \\spad{X} dequeue! a \\spad{X} a")) (|dequeue| (($) "\\blankline \\spad{X} a:Dequeue INT:= dequeue \\spad{()}") (($ (|List| |#1|)) "\\indented{1}{dequeue([x,y,...,z]) creates a dequeue with first (top or front)} \\indented{1}{element \\spad{x,} second element y,...,and last (bottom or back) element \\spad{z.}} \\blankline \\spad{E} g:Dequeue INT:= dequeue [1,2,3,4,5]"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-215 |CoefRing| |listIndVar|) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-235 |CoefRing| |listIndVar|) 
 ((|constructor| (NIL "The deRham complex of Euclidean space, that is, the class of differential forms of arbitary degree over a coefficient ring. See Flanders, Harley, Differential Forms, With Applications to the Physical Sciences, New York, Academic Press, 1963.")) (|exteriorDifferential| (($ $) "\\spad{exteriorDifferential(df)} returns the exterior derivative (gradient, curl, divergence, ...) of the differential form \\spad{df.}")) (|totalDifferential| (($ (|Expression| |#1|)) "\\spad{totalDifferential(x)} returns the total differential (gradient) form for element \\spad{x.}")) (|map| (($ (|Mapping| (|Expression| |#1|) (|Expression| |#1|)) $) "\\spad{map(f,df)} replaces each coefficient \\spad{x} of differential form \\spad{df} by \\spad{f(x)}.")) (|degree| (((|Integer|) $) "\\spad{degree(df)} returns the homogeneous degree of differential form \\spad{df.}")) (|retractable?| (((|Boolean|) $) "\\spad{retractable?(df)} tests if differential form \\spad{df} is a 0-form, \\spadignore{i.e.} if degree(df) = 0.")) (|homogeneous?| (((|Boolean|) $) "\\spad{homogeneous?(df)} tests if all of the terms of differential form \\spad{df} have the same degree.")) (|generator| (($ (|NonNegativeInteger|)) "\\spad{generator(n)} returns the \\spad{n}th basis term for a differential form.")) (|coefficient| (((|Expression| |#1|) $ $) "\\spad{coefficient(df,u)}, where \\spad{df} is a differential form, returns the coefficient of \\spad{df} containing the basis term \\spad{u} if such a term exists, and 0 otherwise.")) (|reductum| (($ $) "\\spad{reductum(df)}, where \\spad{df} is a differential form, returns \\spad{df} minus the leading term of \\spad{df} if \\spad{df} has two or more terms, and 0 otherwise.")) (|leadingBasisTerm| (($ $) "\\spad{leadingBasisTerm(df)} returns the leading basis term of differential form \\spad{df.}")) (|leadingCoefficient| (((|Expression| |#1|) $) "\\spad{leadingCoefficient(df)} returns the leading coefficient of differential form \\spad{df.}"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-216 R -3313) 
+(-236 R -3958) 
 ((|constructor| (NIL "\\spadtype{DefiniteIntegrationTools} provides common tools used by the definite integration of both rational and elementary functions.")) (|checkForZero| (((|Union| (|Boolean|) "failed") (|SparseUnivariatePolynomial| |#2|) (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|) (|Boolean|)) "\\spad{checkForZero(p, a, \\spad{b,} incl?)} is \\spad{true} if \\spad{p} has a zero between a and \\spad{b,} \\spad{false} otherwise, \"failed\" if this cannot be determined. Check for a and \\spad{b} inclusive if incl? is true, exclusive otherwise.") (((|Union| (|Boolean|) "failed") (|Polynomial| |#1|) (|Symbol|) (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|) (|Boolean|)) "\\spad{checkForZero(p, \\spad{x,} a, \\spad{b,} incl?)} is \\spad{true} if \\spad{p} has a zero for \\spad{x} between a and \\spad{b,} \\spad{false} otherwise, \"failed\" if this cannot be determined. Check for a and \\spad{b} inclusive if incl? is true, exclusive otherwise.")) (|computeInt| (((|Union| (|OrderedCompletion| |#2|) "failed") (|Kernel| |#2|) |#2| (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|) (|Boolean|)) "\\spad{computeInt(x, \\spad{g,} a, \\spad{b,} eval?)} returns the integral of \\spad{f} for \\spad{x} between a and \\spad{b,} assuming that \\spad{g} is an indefinite integral of \\spad{f} and \\spad{f} has no pole between a and \\spad{b.} If \\spad{eval?} is true, then \\spad{g} can be evaluated safely at \\spad{a} and \\spad{b}, provided that they are finite values. Otherwise, limits must be computed.")) (|ignore?| (((|Boolean|) (|String|)) "\\spad{ignore?(s)} is \\spad{true} if \\spad{s} is the string that tells the integrator to assume that the function has no pole in the integration interval."))) 
 NIL 
 NIL 
-(-217) 
+(-237) 
 ((|constructor| (NIL "\\spadtype{DoubleFloat} is intended to make accessible hardware floating point arithmetic in Axiom, either native double precision, or IEEE. On most machines, there will be hardware support for the arithmetic operations: \\spad{++} \\spad{+,} \\spad{*,} / and possibly also the sqrt operation. The operations exp, log, sin, cos, atan are normally coded in software based on minimax polynomial/rational approximations. \\blankline Some general comments about the accuracy of the operations: the operations \\spad{+,} \\spad{*,} / and sqrt are expected to be fully accurate. The operations exp, log, sin, cos and atan are not expected to be fully accurate. In particular, sin and cos will lose all precision for large arguments. \\blankline The Float domain provides an alternative to the DoubleFloat domain. It provides an arbitrary precision model of floating point arithmetic. This means that accuracy problems like those above are eliminated by increasing the working precision where necessary. \\spadtype{Float} provides some special functions such as erf, the error function in addition to the elementary functions. The disadvantage of Float is that it is much more expensive than small floats when the latter can be used.")) (|integerDecode| (((|List| (|Integer|)) $) "\\spad{integerDecode(x)} returns the multiple values of the common lisp integer-decode-float function. See Steele, ISBN 0-13-152414-3 p354. This function can be used to ensure that the results are bit-exact and do not depend on the binary-to-decimal conversions. \\blankline \\spad{X} \\spad{a:DFLOAT:=-1.0/3.0} \\spad{X} integerDecode a")) (|machineFraction| (((|Fraction| (|Integer|)) $) "\\spad{machineFraction(x)} returns a bit-exact fraction of the machine floating point number using the common lisp integer-decode-float function. See Steele, ISBN 0-13-152414-3 \\spad{p354} This function can be used to print results which do not depend on binary-to-decimal conversions \\blankline \\spad{X} \\spad{a:DFLOAT:=-1.0/3.0} \\spad{X} machineFraction a")) (|rationalApproximation| (((|Fraction| (|Integer|)) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{rationalApproximation(f, \\spad{n,} \\spad{b)}} computes a rational approximation \\spad{r} to \\spad{f} with relative error \\spad{< b**(-n)} (that is, \\spad{|(r-f)/f| < b**(-n)}).") (((|Fraction| (|Integer|)) $ (|NonNegativeInteger|)) "\\spad{rationalApproximation(f, \\spad{n)}} computes a rational approximation \\spad{r} to \\spad{f} with relative error \\spad{< 10**(-n)}.")) (|doubleFloatFormat| (((|String|) (|String|)) "\\spad{doubleFloatFormat changes} the output format for doublefloats using lisp format strings")) (|Beta| (($ $ $) "\\spad{Beta(x,y)} is \\spad{Gamma(x) * Gamma(y)/Gamma(x+y)}.")) (|Gamma| (($ $) "\\spad{Gamma(x)} is the Euler Gamma function.")) (|atan| (($ $ $) "\\spad{atan(x,y)} computes the arc tangent from \\spad{x} with phase \\spad{y.}")) (|log10| (($ $) "\\spad{log10(x)} computes the logarithm with base 10 for \\spad{x.}")) (|log2| (($ $) "\\spad{log2(x)} computes the logarithm with base 2 for \\spad{x.}")) (|hash| (((|Integer|) $) "\\spad{hash(x)} returns the hash key for \\spad{x}")) (|exp1| (($) "\\spad{exp1()} returns the natural log base \\spad{2.718281828...}.")) (** (($ $ $) "\\spad{x \\spad{**} \\spad{y}} returns the \\spad{y}th power of \\spad{x} (equal to \\spad{exp(y log x)}).")) (/ (($ $ (|Integer|)) "\\spad{x / i} computes the division from \\spad{x} by an integer i."))) 
-((-3410 . T) (-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-2642 . T) (-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-218) 
+(-238) 
 ((|constructor| (NIL "This is a low-level domain which implements matrices (two dimensional arrays) of double precision floating point numbers. Indexing is 0 based, there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|) (|Integer|)) "\\indented{1}{qnew(n, \\spad{m)} creates a new uninitialized \\spad{n} by \\spad{m} matrix.} \\blankline \\spad{X} t1:DFMAT:=qnew(3,4)"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-217) (QUOTE (-1098))) (-12 (|HasCategory| (-217) (LIST (QUOTE -305) (QUOTE (-217)))) (|HasCategory| (-217) (QUOTE (-1098)))) (|HasCategory| (-217) (QUOTE (-303))) (|HasCategory| (-217) (QUOTE (-562))) (|HasAttribute| (-217) (QUOTE (-4604 "*"))) (|HasCategory| (-217) (QUOTE (-174))) (|HasCategory| (-217) (QUOTE (-368)))) 
-(-219) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-237) (QUOTE (-1119))) (-12 (|HasCategory| (-237) (LIST (QUOTE -325) (QUOTE (-237)))) (|HasCategory| (-237) (QUOTE (-1119)))) (|HasCategory| (-237) (QUOTE (-323))) (|HasCategory| (-237) (QUOTE (-582))) (|HasAttribute| (-237) (QUOTE (-4627 "*"))) (|HasCategory| (-237) (QUOTE (-194))) (|HasCategory| (-237) (QUOTE (-388)))) 
+(-239) 
 ((|constructor| (NIL "This package provides special functions for double precision real and complex floating point.")) (|fresnelC| (((|Float|) (|Float|)) "\\indented{1}{fresnelC(f) denotes the Fresnel integral \\spad{C}} \\blankline \\spad{X} fresnelC(1.5)")) (|fresnelS| (((|Float|) (|Float|)) "\\indented{1}{fresnelS(f) denotes the Fresnel integral \\spad{S}} \\blankline \\spad{X} fresnelS(1.5)")) (|hypergeometric0F1| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{hypergeometric0F1(c,z)} is the hypergeometric function \\spad{0F1(; \\spad{c;} z)}.") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{hypergeometric0F1(c,z)} is the hypergeometric function \\spad{0F1(; \\spad{c;} z)}.")) (|airyBi| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{airyBi(x)} is the Airy function \\spad{Bi(x)}. This function satisfies the differential equation: \\indented{2}{\\spad{Bi''(x) - \\spad{x} * Bi(x) = 0}.}") (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{airyBi(x)} is the Airy function \\spad{Bi(x)}. This function satisfies the differential equation: \\indented{2}{\\spad{Bi''(x) - \\spad{x} * Bi(x) = 0}.}")) (|airyAi| (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{airyAi(x)} is the Airy function \\spad{Ai(x)}. This function satisfies the differential equation: \\indented{2}{\\spad{Ai''(x) - \\spad{x} * Ai(x) = 0}.}") (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{airyAi(x)} is the Airy function \\spad{Ai(x)}. This function satisfies the differential equation: \\indented{2}{\\spad{Ai''(x) - \\spad{x} * Ai(x) = 0}.}")) (|besselK| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{besselK(v,x)} is the modified Bessel function of the second kind, \\spad{K(v,x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + \\spad{x} w'(x) - (x^2+v^2)w(x) = 0}.} Note that the default implementation uses the relation \\indented{2}{\\spad{K(v,x) = \\%pi/2*(I(-v,x) - I(v,x))/sin(v*\\%pi)}} so is not valid for integer values of \\spad{v.}") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{besselK(v,x)} is the modified Bessel function of the second kind, \\spad{K(v,x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + \\spad{x} w'(x) - (x^2+v^2)w(x) = 0}.} Note that the default implementation uses the relation \\indented{2}{\\spad{K(v,x) = \\%pi/2*(I(-v,x) - I(v,x))/sin(v*\\%pi)}.} so is not valid for integer values of \\spad{v.}")) (|besselI| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{besselI(v,x)} is the modified Bessel function of the first kind, \\spad{I(v,x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + \\spad{x} w'(x) - (x^2+v^2)w(x) = 0}.}") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{besselI(v,x)} is the modified Bessel function of the first kind, \\spad{I(v,x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + \\spad{x} w'(x) - (x^2+v^2)w(x) = 0}.}")) (|besselY| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{besselY(v,x)} is the Bessel function of the second kind, \\spad{Y(v,x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + \\spad{x} w'(x) + (x^2-v^2)w(x) = 0}.} Note that the default implementation uses the relation \\indented{2}{\\spad{Y(v,x) = (J(v,x) cos(v*\\%pi) - J(-v,x))/sin(v*\\%pi)}} so is not valid for integer values of \\spad{v.}") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{besselY(v,x)} is the Bessel function of the second kind, \\spad{Y(v,x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + \\spad{x} w'(x) + (x^2-v^2)w(x) = 0}.} Note that the default implementation uses the relation \\indented{2}{\\spad{Y(v,x) = (J(v,x) cos(v*\\%pi) - J(-v,x))/sin(v*\\%pi)}} so is not valid for integer values of \\spad{v.}")) (|besselJ| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{besselJ(v,x)} is the Bessel function of the first kind, \\spad{J(v,x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + \\spad{x} w'(x) + (x^2-v^2)w(x) = 0}.}") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{besselJ(v,x)} is the Bessel function of the first kind, \\spad{J(v,x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + \\spad{x} w'(x) + (x^2-v^2)w(x) = 0}.}")) (|polygamma| (((|Complex| (|DoubleFloat|)) (|NonNegativeInteger|) (|Complex| (|DoubleFloat|))) "\\spad{polygamma(n, \\spad{x)}} is the \\spad{n}-th derivative of \\spad{digamma(x)}.") (((|DoubleFloat|) (|NonNegativeInteger|) (|DoubleFloat|)) "\\spad{polygamma(n, \\spad{x)}} is the \\spad{n}-th derivative of \\spad{digamma(x)}.")) (|digamma| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{digamma(x)} is the function, \\spad{psi(x)}, defined by \\indented{2}{\\spad{psi(x) = Gamma'(x)/Gamma(x)}.}") (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{digamma(x)} is the function, \\spad{psi(x)}, defined by \\indented{2}{\\spad{psi(x) = Gamma'(x)/Gamma(x)}.}")) (|logGamma| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{logGamma(x)} is the natural log of \\spad{Gamma(x)}. This can often be computed even if \\spad{Gamma(x)} cannot.") (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{logGamma(x)} is the natural log of \\spad{Gamma(x)}. This can often be computed even if \\spad{Gamma(x)} cannot.")) (|Beta| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{Beta(x, \\spad{y)}} is the Euler beta function, \\spad{B(x,y)}, defined by \\indented{2}{\\spad{Beta(x,y) = integrate(t^(x-1)*(1-t)^(y-1), t=0..1)}.} This is related to \\spad{Gamma(x)} by \\indented{2}{\\spad{Beta(x,y) = Gamma(x)*Gamma(y) / Gamma(x + y)}.}") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{Beta(x, \\spad{y)}} is the Euler beta function, \\spad{B(x,y)}, defined by \\indented{2}{\\spad{Beta(x,y) = integrate(t^(x-1)*(1-t)^(y-1), t=0..1)}.} This is related to \\spad{Gamma(x)} by \\indented{2}{\\spad{Beta(x,y) = Gamma(x)*Gamma(y) / Gamma(x + y)}.}")) (|Ei6| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei6} is the first approximation of \\spad{Ei} where the result is x*\\%e^-x*Ei(x) from 32 to infinity (preserves digits)")) (|Ei5| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei5} is the first approximation of \\spad{Ei} where the result is x*\\%e^-x*Ei(x) from 12 to 32 (preserves digits)")) (|Ei4| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei4} is the first approximation of \\spad{Ei} where the result is x*\\%e^-x*Ei(x) from 4 to 12 (preserves digits)")) (|Ei3| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei3} is the first approximation of \\spad{Ei} where the result is (Ei(x)-log \\spad{|x|} - gamma)/x from \\spad{-4} to 4 (preserves digits)")) (|Ei2| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei2} is the first approximation of \\spad{Ei} where the result is x*\\%e^-x*Ei(x) from \\spad{-10} to \\spad{-4} (preserves digits)")) (|Ei1| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei1} is the first approximation of \\spad{Ei} where the result is x*\\%e^-x*Ei(x) from -infinity to \\spad{-10} (preserves digits)")) (|Ei| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei} is the Exponential Integral function This is computed using a 6 part piecewise approximation. DoubleFloat can only preserve about 16 digits but the Chebyshev approximation used can give 30 digits.")) (|En| (((|OnePointCompletion| (|DoubleFloat|)) (|Integer|) (|DoubleFloat|)) "\\spad{En(n,x)} is the \\spad{n}th Exponential Integral Function")) (E1 (((|OnePointCompletion| (|DoubleFloat|)) (|DoubleFloat|)) "\\spad{E1(x)} is the Exponential Integral function The current implementation is a piecewise approximation involving one poly from \\spad{-4..4} and a second poly for \\spad{x} > 4")) (|Gamma| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{Gamma(x)} is the Euler gamma function, \\spad{Gamma(x)}, defined by \\indented{2}{\\spad{Gamma(x) = integrate(t^(x-1)*exp(-t), t=0..\\%infinity)}.}") (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{Gamma(x)} is the Euler gamma function, \\spad{Gamma(x)}, defined by \\indented{2}{\\spad{Gamma(x) = integrate(t^(x-1)*exp(-t), t=0..\\%infinity)}.}"))) 
 NIL 
 NIL 
-(-220) 
+(-240) 
 ((|constructor| (NIL "This is a low-level domain which implements vectors (one dimensional arrays) of double precision floating point numbers. Indexing is 0 based, there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|)) "\\indented{1}{qnew(n) creates a new uninitialized vector of length \\spad{n.}} \\blankline \\spad{X} t1:DFVEC:=qnew(7)"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-217) (QUOTE (-1098))) (|HasCategory| (-217) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-217) (QUOTE (-848))) (-1841 (|HasCategory| (-217) (QUOTE (-848))) (|HasCategory| (-217) (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-217) (QUOTE (-25))) (|HasCategory| (-217) (QUOTE (-23))) (|HasCategory| (-217) (QUOTE (-21))) (|HasCategory| (-217) (QUOTE (-722))) (|HasCategory| (-217) (QUOTE (-1054))) (-12 (|HasCategory| (-217) (QUOTE (-1009))) (|HasCategory| (-217) (QUOTE (-1054)))) (-12 (|HasCategory| (-217) (LIST (QUOTE -305) (QUOTE (-217)))) (|HasCategory| (-217) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-217) (LIST (QUOTE -305) (QUOTE (-217)))) (|HasCategory| (-217) (QUOTE (-848)))) (-12 (|HasCategory| (-217) (LIST (QUOTE -305) (QUOTE (-217)))) (|HasCategory| (-217) (QUOTE (-1098)))))) 
-(-221 R) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-237) (QUOTE (-1119))) (|HasCategory| (-237) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-237) (QUOTE (-869))) (-3836 (|HasCategory| (-237) (QUOTE (-869))) (|HasCategory| (-237) (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-237) (QUOTE (-25))) (|HasCategory| (-237) (QUOTE (-23))) (|HasCategory| (-237) (QUOTE (-21))) (|HasCategory| (-237) (QUOTE (-743))) (|HasCategory| (-237) (QUOTE (-1075))) (-12 (|HasCategory| (-237) (QUOTE (-1030))) (|HasCategory| (-237) (QUOTE (-1075)))) (-12 (|HasCategory| (-237) (LIST (QUOTE -325) (QUOTE (-237)))) (|HasCategory| (-237) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-237) (LIST (QUOTE -325) (QUOTE (-237)))) (|HasCategory| (-237) (QUOTE (-869)))) (-12 (|HasCategory| (-237) (LIST (QUOTE -325) (QUOTE (-237)))) (|HasCategory| (-237) (QUOTE (-1119)))))) 
+(-241 R) 
 ((|constructor| (NIL "4x4 Matrices for coordinate transformations\\br This package contains functions to create 4x4 matrices useful for rotating and transforming coordinate systems. These matrices are useful for graphics and robotics. (Reference: Robot Manipulators Richard Paul MIT Press 1981) \\blankline A Denavit-Hartenberg Matrix is a 4x4 Matrix of the form:\\br \\tab{5}\\spad{nx ox ax px}\\br \\tab{5}\\spad{ny oy ay py}\\br \\tab{5}\\spad{nz oz az pz}\\br \\tab{5}\\spad{0 0 0 1}\\br \\spad{(n,} o, and a are the direction cosines)")) (|translate| (($ |#1| |#1| |#1|) "\\spad{translate(x,y,z)} returns a dhmatrix for translation by \\spad{x,} \\spad{y,} and \\spad{z}")) (|scale| (($ |#1| |#1| |#1|) "\\spad{scale(sx,sy,sz)} returns a dhmatrix for scaling in the \\spad{x,} \\spad{y} and \\spad{z} directions")) (|rotatez| (($ |#1|) "\\spad{rotatez(r)} returns a dhmatrix for rotation about axis \\spad{z} for \\spad{r} degrees")) (|rotatey| (($ |#1|) "\\spad{rotatey(r)} returns a dhmatrix for rotation about axis \\spad{y} for \\spad{r} degrees")) (|rotatex| (($ |#1|) "\\spad{rotatex(r)} returns a dhmatrix for rotation about axis \\spad{x} for \\spad{r} degrees")) (|identity| (($) "\\spad{identity()} create the identity dhmatrix")) (* (((|Point| |#1|) $ (|Point| |#1|)) "\\spad{t*p} applies the dhmatrix \\spad{t} to point \\spad{p}"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-562))) (|HasAttribute| |#1| (QUOTE (-4604 "*"))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-222 A S) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-582))) (|HasAttribute| |#1| (QUOTE (-4627 "*"))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-242 A S) 
 ((|constructor| (NIL "A dictionary is an aggregate in which entries can be inserted, searched for and removed. Duplicates are thrown away on insertion. This category models the usual notion of dictionary which involves large amounts of data where copying is impractical. Principal operations are thus destructive (non-copying) ones."))) 
 NIL 
 NIL 
-(-223 S) 
+(-243 S) 
 ((|constructor| (NIL "A dictionary is an aggregate in which entries can be inserted, searched for and removed. Duplicates are thrown away on insertion. This category models the usual notion of dictionary which involves large amounts of data where copying is impractical. Principal operations are thus destructive (non-copying) ones."))) 
-((-4603 . T) (-3389 . T)) 
+((-4626 . T) (-2623 . T)) 
 NIL 
-(-224 S R) 
+(-244 S R) 
 ((|constructor| (NIL "Differential extensions of a ring \\spad{R.} Given a differentiation on \\spad{R,} extend it to a differentiation on \\spad{%.}")) (D (($ $ (|Mapping| |#2| |#2|) (|NonNegativeInteger|)) "\\spad{D(x, deriv, \\spad{n)}} differentiate \\spad{x} \\spad{n} times using a derivation which extends \\spad{deriv} on \\spad{R.}") (($ $ (|Mapping| |#2| |#2|)) "\\spad{D(x, deriv)} differentiates \\spad{x} extending the derivation deriv on \\spad{R.}")) (|differentiate| (($ $ (|Mapping| |#2| |#2|) (|NonNegativeInteger|)) "\\spad{differentiate(x, deriv, \\spad{n)}} differentiate \\spad{x} \\spad{n} times using a derivation which extends \\spad{deriv} on \\spad{R.}") (($ $ (|Mapping| |#2| |#2|)) "\\spad{differentiate(x, deriv)} differentiates \\spad{x} extending the derivation deriv on \\spad{R.}"))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227)))) 
-(-225 R) 
+((|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247)))) 
+(-245 R) 
 ((|constructor| (NIL "Differential extensions of a ring \\spad{R.} Given a differentiation on \\spad{R,} extend it to a differentiation on \\spad{%.}")) (D (($ $ (|Mapping| |#1| |#1|) (|NonNegativeInteger|)) "\\spad{D(x, deriv, \\spad{n)}} differentiate \\spad{x} \\spad{n} times using a derivation which extends \\spad{deriv} on \\spad{R.}") (($ $ (|Mapping| |#1| |#1|)) "\\spad{D(x, deriv)} differentiates \\spad{x} extending the derivation deriv on \\spad{R.}")) (|differentiate| (($ $ (|Mapping| |#1| |#1|) (|NonNegativeInteger|)) "\\spad{differentiate(x, deriv, \\spad{n)}} differentiate \\spad{x} \\spad{n} times using a derivation which extends \\spad{deriv} on \\spad{R.}") (($ $ (|Mapping| |#1| |#1|)) "\\spad{differentiate(x, deriv)} differentiates \\spad{x} extending the derivation deriv on \\spad{R.}"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-226 S) 
+(-246 S) 
 ((|constructor| (NIL "An ordinary differential ring, that is, a ring with an operation \\spadfun{differentiate}. \\blankline Axioms\\br \\tab{5}\\spad{differentiate(x+y) = differentiate(x)+differentiate(y)}\\br \\tab{5}\\spad{differentiate(x*y) = x*differentiate(y) + differentiate(x)*y}")) (D (($ $ (|NonNegativeInteger|)) "\\spad{D(x, \\spad{n)}} returns the \\spad{n}-th derivative of \\spad{x.}") (($ $) "\\spad{D(x)} returns the derivative of \\spad{x.} This function is a simple differential operator where no variable needs to be specified.")) (|differentiate| (($ $ (|NonNegativeInteger|)) "\\spad{differentiate(x, \\spad{n)}} returns the \\spad{n}-th derivative of \\spad{x.}") (($ $) "\\spad{differentiate(x)} returns the derivative of \\spad{x.} This function is a simple differential operator where no variable needs to be specified."))) 
 NIL 
 NIL 
-(-227) 
+(-247) 
 ((|constructor| (NIL "An ordinary differential ring, that is, a ring with an operation \\spadfun{differentiate}. \\blankline Axioms\\br \\tab{5}\\spad{differentiate(x+y) = differentiate(x)+differentiate(y)}\\br \\tab{5}\\spad{differentiate(x*y) = x*differentiate(y) + differentiate(x)*y}")) (D (($ $ (|NonNegativeInteger|)) "\\spad{D(x, \\spad{n)}} returns the \\spad{n}-th derivative of \\spad{x.}") (($ $) "\\spad{D(x)} returns the derivative of \\spad{x.} This function is a simple differential operator where no variable needs to be specified.")) (|differentiate| (($ $ (|NonNegativeInteger|)) "\\spad{differentiate(x, \\spad{n)}} returns the \\spad{n}-th derivative of \\spad{x.}") (($ $) "\\spad{differentiate(x)} returns the derivative of \\spad{x.} This function is a simple differential operator where no variable needs to be specified."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-228 A S) 
+(-248 A S) 
 ((|constructor| (NIL "This category is a collection of operations common to both categories \\spadtype{Dictionary} and \\spadtype{MultiDictionary}")) (|select!| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{select!(p,d)} destructively changes dictionary \\spad{d} by removing all entries \\spad{x} such that \\axiom{p(x)} is not true.")) (|remove!| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{remove!(p,d)} destructively changes dictionary \\spad{d} by removeing all entries \\spad{x} such that \\axiom{p(x)} is true.") (($ |#2| $) "\\spad{remove!(x,d)} destructively changes dictionary \\spad{d} by removing all entries \\spad{y} such that \\axiom{y = \\spad{x}.}")) (|dictionary| (($ (|List| |#2|)) "\\spad{dictionary([x,y,...,z])} creates a dictionary consisting of entries \\axiom{x,y,...,z}.") (($) "\\spad{dictionary()}$D creates an empty dictionary of type \\spad{D.}"))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4602))) 
-(-229 S) 
+((|HasAttribute| |#1| (QUOTE -4625))) 
+(-249 S) 
 ((|constructor| (NIL "This category is a collection of operations common to both categories \\spadtype{Dictionary} and \\spadtype{MultiDictionary}")) (|select!| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{select!(p,d)} destructively changes dictionary \\spad{d} by removing all entries \\spad{x} such that \\axiom{p(x)} is not true.")) (|remove!| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{remove!(p,d)} destructively changes dictionary \\spad{d} by removeing all entries \\spad{x} such that \\axiom{p(x)} is true.") (($ |#1| $) "\\spad{remove!(x,d)} destructively changes dictionary \\spad{d} by removing all entries \\spad{y} such that \\axiom{y = \\spad{x}.}")) (|dictionary| (($ (|List| |#1|)) "\\spad{dictionary([x,y,...,z])} creates a dictionary consisting of entries \\axiom{x,y,...,z}.") (($) "\\spad{dictionary()}$D creates an empty dictionary of type \\spad{D.}"))) 
-((-4603 . T) (-3389 . T)) 
+((-4626 . T) (-2623 . T)) 
 NIL 
-(-230) 
+(-250) 
 ((|constructor| (NIL "Any solution of a homogeneous linear Diophantine equation can be represented as a sum of minimal solutions, which form a \"basis\" (a minimal solution cannot be represented as a nontrivial sum of solutions) in the case of an inhomogeneous linear Diophantine equation, each solution is the sum of a inhomogeneous solution and any number of homogeneous solutions therefore, it suffices to compute two sets:\\br \\tab{5}1. all minimal inhomogeneous solutions\\br \\tab{5}2. all minimal homogeneous solutions\\br the algorithm implemented is a completion procedure, which enumerates all solutions in a recursive depth-first-search it can be seen as finding monotone paths in a graph for more details see Reference")) (|dioSolve| (((|Record| (|:| |varOrder| (|List| (|Symbol|))) (|:| |inhom| (|Union| (|List| (|Vector| (|NonNegativeInteger|))) "failed")) (|:| |hom| (|List| (|Vector| (|NonNegativeInteger|))))) (|Equation| (|Polynomial| (|Integer|)))) "\\spad{dioSolve(u)} computes a basis of all minimal solutions for linear homogeneous Diophantine equation u, then all minimal solutions of inhomogeneous equation"))) 
 NIL 
 NIL 
-(-231 S -3465 R) 
+(-251 S -3832 R) 
 ((|constructor| (NIL "This category represents a finite cartesian product of a given type. Many categorical properties are preserved under this construction.")) (* (($ $ |#3|) "\\spad{y * \\spad{r}} multiplies each component of the vector \\spad{y} by the element \\spad{r.}") (($ |#3| $) "\\spad{r * \\spad{y}} multiplies the element \\spad{r} times each component of the vector \\spad{y.}")) (|dot| ((|#3| $ $) "\\spad{dot(x,y)} computes the inner product of the vectors \\spad{x} and \\spad{y.}")) (|unitVector| (($ (|PositiveInteger|)) "\\spad{unitVector(n)} produces a vector with 1 in position \\spad{n} and zero elsewhere.")) (|directProduct| (($ (|Vector| |#3|)) "\\spad{directProduct(v)} converts the vector \\spad{v} to become a direct product. Error: if the length of \\spad{v} is different from dim.")) (|finiteAggregate| ((|attribute|) "attribute to indicate an aggregate of finite size"))) 
 NIL 
-((|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-794))) (|HasCategory| |#3| (QUOTE (-846))) (|HasAttribute| |#3| (QUOTE -4599)) (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-374))) (|HasCategory| |#3| (QUOTE (-722))) (|HasCategory| |#3| (QUOTE (-138))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-1054))) (|HasCategory| |#3| (QUOTE (-1098)))) 
-(-232 -3465 R) 
+((|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-815))) (|HasCategory| |#3| (QUOTE (-867))) (|HasAttribute| |#3| (QUOTE -4622)) (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-394))) (|HasCategory| |#3| (QUOTE (-743))) (|HasCategory| |#3| (QUOTE (-158))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-1075))) (|HasCategory| |#3| (QUOTE (-1119)))) 
+(-252 -3832 R) 
 ((|constructor| (NIL "This category represents a finite cartesian product of a given type. Many categorical properties are preserved under this construction.")) (* (($ $ |#2|) "\\spad{y * \\spad{r}} multiplies each component of the vector \\spad{y} by the element \\spad{r.}") (($ |#2| $) "\\spad{r * \\spad{y}} multiplies the element \\spad{r} times each component of the vector \\spad{y.}")) (|dot| ((|#2| $ $) "\\spad{dot(x,y)} computes the inner product of the vectors \\spad{x} and \\spad{y.}")) (|unitVector| (($ (|PositiveInteger|)) "\\spad{unitVector(n)} produces a vector with 1 in position \\spad{n} and zero elsewhere.")) (|directProduct| (($ (|Vector| |#2|)) "\\spad{directProduct(v)} converts the vector \\spad{v} to become a direct product. Error: if the length of \\spad{v} is different from dim.")) (|finiteAggregate| ((|attribute|) "attribute to indicate an aggregate of finite size"))) 
-((-4596 |has| |#2| (-1054)) (-4597 |has| |#2| (-1054)) (-4599 |has| |#2| (-6 -4599)) ((-4604 "*") |has| |#2| (-174)) (-4602 . T) (-3389 . T)) 
+((-4619 |has| |#2| (-1075)) (-4620 |has| |#2| (-1075)) (-4622 |has| |#2| (-6 -4622)) ((-4627 "*") |has| |#2| (-194)) (-4625 . T) (-2623 . T)) 
 NIL 
-(-233 -3465 A B) 
+(-253 -3832 A B) 
 ((|constructor| (NIL "This package provides operations which all take as arguments direct products of elements of some type \\spad{A} and functions from \\spad{A} to another type \\spad{B.} The operations all iterate over their vector argument and either return a value of type \\spad{B} or a direct product over \\spad{B.}")) (|map| (((|DirectProduct| |#1| |#3|) (|Mapping| |#3| |#2|) (|DirectProduct| |#1| |#2|)) "\\spad{map(f, \\spad{v)}} applies the function \\spad{f} to every element of the vector \\spad{v} producing a new vector containing the values.")) (|reduce| ((|#3| (|Mapping| |#3| |#2| |#3|) (|DirectProduct| |#1| |#2|) |#3|) "\\spad{reduce(func,vec,ident)} combines the elements in \\spad{vec} using the binary function func. Argument \\spad{ident} is returned if the vector is empty.")) (|scan| (((|DirectProduct| |#1| |#3|) (|Mapping| |#3| |#2| |#3|) (|DirectProduct| |#1| |#2|) |#3|) "\\spad{scan(func,vec,ident)} creates a new vector whose elements are the result of applying reduce to the binary function func, increasing initial subsequences of the vector vec, and the element ident."))) 
 NIL 
 NIL 
-(-234 -3465 R) 
+(-254 -3832 R) 
 ((|constructor| (NIL "This type represents the finite direct or cartesian product of an underlying component type. This contrasts with simple vectors in that the members can be viewed as having constant length. Thus many categorical properties can by lifted from the underlying component type. Component extraction operations are provided but no updating operations. Thus new direct product elements can either be created by converting vector elements using the \\spadfun{directProduct} function or by taking appropriate linear combinations of basis vectors provided by the \\spad{unitVector} operation."))) 
-((-4596 |has| |#2| (-1054)) (-4597 |has| |#2| (-1054)) (-4599 |has| |#2| (-6 -4599)) ((-4604 "*") |has| |#2| (-174)) (-4602 . T)) 
-((|HasCategory| |#2| (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846))) (-1841 (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846)))) (|HasCategory| |#2| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368)))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| |#2| (QUOTE (-374))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasAttribute| |#2| (QUOTE -4599)) (|HasCategory| |#2| (QUOTE (-138))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| |#2| (QUOTE (-25))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-374))) (|HasCategory| |#2| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1098))))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))))) 
-(-235 |Coef|) 
+((-4619 |has| |#2| (-1075)) (-4620 |has| |#2| (-1075)) (-4622 |has| |#2| (-6 -4622)) ((-4627 "*") |has| |#2| (-194)) (-4625 . T)) 
+((|HasCategory| |#2| (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867))) (-3836 (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867)))) (|HasCategory| |#2| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388)))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| |#2| (QUOTE (-394))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasAttribute| |#2| (QUOTE -4622)) (|HasCategory| |#2| (QUOTE (-158))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| |#2| (QUOTE (-25))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-394))) (|HasCategory| |#2| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1119))))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))))) 
+(-255 |Coef|) 
 ((|constructor| (NIL "DirichletRing is the ring of arithmetical functions with Dirichlet convolution as multiplication")) (|additive?| (((|Boolean|) $ (|PositiveInteger|)) "\\spad{additive?(a, \\spad{n)}} returns \\spad{true} if the first \\spad{n} coefficients of a are additive")) (|multiplicative?| (((|Boolean|) $ (|PositiveInteger|)) "\\spad{multiplicative?(a, \\spad{n)}} returns \\spad{true} if the first \\spad{n} coefficients of a are multiplicative")) (|zeta| (($) "\\spad{zeta()} returns the function which is constantly one"))) 
-((-4597 |has| |#1| (-174)) (-4596 |has| |#1| (-174)) ((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-174)) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174)))) 
-(-236) 
+((-4620 |has| |#1| (-194)) (-4619 |has| |#1| (-194)) ((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-194)) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194)))) 
+(-256) 
 ((|constructor| (NIL "DisplayPackage allows one to print strings in a nice manner, including highlighting substrings.")) (|sayLength| (((|Integer|) (|List| (|String|))) "\\spad{sayLength(l)} returns the length of a list of strings \\spad{l} as an integer.") (((|Integer|) (|String|)) "\\spad{sayLength(s)} returns the length of a string \\spad{s} as an integer.")) (|say| (((|Void|) (|List| (|String|))) "\\spad{say(l)} sends a list of strings \\spad{l} to output.") (((|Void|) (|String|)) "\\spad{say(s)} sends a string \\spad{s} to output.")) (|center| (((|List| (|String|)) (|List| (|String|)) (|Integer|) (|String|)) "\\spad{center(l,i,s)} takes a list of strings \\spad{l,} and centers them within a list of strings which is \\spad{i} characters long, in which the remaining spaces are filled with strings composed of as many repetitions as possible of the last string parameter \\spad{s.}") (((|String|) (|String|) (|Integer|) (|String|)) "\\spad{center(s,i,s)} takes the first string \\spad{s,} and centers it within a string of length i, in which the other elements of the string are composed of as many replications as possible of the second indicated string, \\spad{s} which must have a length greater than that of an empty string.")) (|copies| (((|String|) (|Integer|) (|String|)) "\\spad{copies(i,s)} will take a string \\spad{s} and create a new string composed of \\spad{i} copies of \\spad{s.}")) (|newLine| (((|String|)) "\\spad{newLine()} sends a new line command to output.")) (|bright| (((|List| (|String|)) (|List| (|String|))) "\\spad{bright(l)} sets the font property of a list of strings, \\spad{l,} to bold-face type.") (((|List| (|String|)) (|String|)) "\\spad{bright(s)} sets the font property of the string \\spad{s} to bold-face type."))) 
 NIL 
 NIL 
-(-237 S) 
+(-257 S) 
 ((|constructor| (NIL "This category exports the function for domains")) (|divOfPole| (($ $) "\\spad{divOfPole(d)} returns the negative part of \\spad{d.}")) (|divOfZero| (($ $) "\\spad{divOfZero(d)} returns the positive part of \\spad{d.}")) (|suppOfPole| (((|List| |#1|) $) "suppOfZero(d) returns the elements of the support of \\spad{d} that have a negative coefficient.")) (|suppOfZero| (((|List| |#1|) $) "\\spad{suppOfZero(d)} returns the elements of the support of \\spad{d} that have a positive coefficient.")) (|supp| (((|List| |#1|) $) "\\spad{supp(d)} returns the support of the divisor \\spad{d.}")) (|effective?| (((|Boolean|) $) "\\spad{effective?(d)} returns \\spad{true} if \\spad{d} \\spad{>=} 0.")) (|concat| (($ $ $) "\\spad{concat(a,b)} concats the divisor a and \\spad{b} without collecting the duplicative points.")) (|collect| (($ $) "\\spad{collect collects} the duplicative points in the divisor.")) (|split| (((|List| $) $) "\\spad{split(d)} splits the divisor \\spad{d.} For example, split( 2 \\spad{p1} + 3p2 ) returns the list [ 2 \\spad{p1,} 3 \\spad{p2} \\spad{].}")) (|degree| (((|Integer|) $) "\\spad{degree(d)} returns the degree of the divisor \\spad{d}"))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-238 S) 
+(-258 S) 
 ((|constructor| (NIL "The following is part of the PAFF package"))) 
-((-4597 . T) (-4596 . T)) 
-((|HasCategory| (-572) (QUOTE (-793)))) 
-(-239 S) 
+((-4620 . T) (-4619 . T)) 
+((|HasCategory| (-592) (QUOTE (-814)))) 
+(-259 S) 
 ((|constructor| (NIL "A division ring (sometimes called a skew field), \\spadignore{i.e.} a not necessarily commutative ring where all non-zero elements have multiplicative inverses.")) (|inv| (($ $) "\\spad{inv \\spad{x}} returns the multiplicative inverse of \\spad{x.} Error: if \\spad{x} is 0.")) (^ (($ $ (|Integer|)) "\\spad{x^n} returns \\spad{x} raised to the integer power \\spad{n.}")) (** (($ $ (|Integer|)) "\\spad{x**n} returns \\spad{x} raised to the integer power \\spad{n.}"))) 
 NIL 
 NIL 
-(-240) 
+(-260) 
 ((|constructor| (NIL "A division ring (sometimes called a skew field), \\spadignore{i.e.} a not necessarily commutative ring where all non-zero elements have multiplicative inverses.")) (|inv| (($ $) "\\spad{inv \\spad{x}} returns the multiplicative inverse of \\spad{x.} Error: if \\spad{x} is 0.")) (^ (($ $ (|Integer|)) "\\spad{x^n} returns \\spad{x} raised to the integer power \\spad{n.}")) (** (($ $ (|Integer|)) "\\spad{x**n} returns \\spad{x} raised to the integer power \\spad{n.}"))) 
-((-4595 . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-241 S) 
+(-261 S) 
 ((|constructor| (NIL "A doubly-linked aggregate serves as a model for a doubly-linked list, that is, a list which can has links to both next and previous nodes and thus can be efficiently traversed in both directions.")) (|setnext!| (($ $ $) "\\spad{setnext!(u,v)} destructively sets the next node of doubly-linked aggregate \\spad{u} to \\spad{v,} returning \\spad{v.}")) (|setprevious!| (($ $ $) "\\spad{setprevious!(u,v)} destructively sets the previous node of doubly-linked aggregate \\spad{u} to \\spad{v,} returning \\spad{v.}")) (|concat!| (($ $ $) "\\spad{concat!(u,v)} destructively concatenates doubly-linked aggregate \\spad{v} to the end of doubly-linked aggregate u.")) (|next| (($ $) "\\spad{next(l)} returns the doubly-linked aggregate beginning with its next element. Error: if \\spad{l} has no next element. Note that \\axiom{next(l) = rest(l)} and \\axiom{previous(next(l)) = \\spad{l}.}")) (|previous| (($ $) "\\spad{previous(l)} returns the doubly-link list beginning with its previous element. Error: if \\spad{l} has no previous element. Note that \\axiom{next(previous(l)) = \\spad{l}.}")) (|tail| (($ $) "\\spad{tail(l)} returns the doubly-linked aggregate \\spad{l} starting at its second element. Error: if \\spad{l} is empty.")) (|head| (($ $) "\\spad{head(l)} returns the first element of a doubly-linked aggregate \\spad{l.} Error: if \\spad{l} is empty.")) (|last| ((|#1| $) "\\spad{last(l)} returns the last element of a doubly-linked aggregate \\spad{l.} Error: if \\spad{l} is empty."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-242 S) 
+(-262 S) 
 ((|constructor| (NIL "This domain provides some nice functions on lists")) (|elt| (((|NonNegativeInteger|) $ "count") "\\axiom{l.\"count\"} returns the number of elements in \\axiom{l}.") (($ $ "sort") "\\axiom{l.sort} returns \\axiom{l} with elements sorted. Note: \\axiom{l.sort = sort(l)}") (($ $ "unique") "\\axiom{l.unique} returns \\axiom{l} with duplicates removed. Note: \\axiom{l.unique = removeDuplicates(l)}.")) (|datalist| (($ (|List| |#1|)) "\\spad{datalist(l)} creates a datalist from \\spad{l}")) (|coerce| (((|List| |#1|) $) "\\spad{coerce(x)} returns the list of elements in \\spad{x}") (($ (|List| |#1|)) "\\spad{coerce(l)} creates a datalist from \\spad{l}"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-243 M) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-263 M) 
 ((|constructor| (NIL "DiscreteLogarithmPackage implements help functions for discrete logarithms in monoids using small cyclic groups.")) (|shanksDiscLogAlgorithm| (((|Union| (|NonNegativeInteger|) "failed") |#1| |#1| (|NonNegativeInteger|)) "\\spad{shanksDiscLogAlgorithm(b,a,p)} computes \\spad{s} with \\spad{b**s = a} for assuming that \\spad{a} and \\spad{b} are elements in a 'small' cyclic group of order \\spad{p} by Shank's algorithm. Note that this is a subroutine of the function \\spadfun{discreteLog}.")) (** ((|#1| |#1| (|Integer|)) "\\spad{x \\spad{**} \\spad{n}} returns \\spad{x} raised to the integer power \\spad{n}"))) 
 NIL 
 NIL 
-(-244 |vl| R) 
+(-264 |vl| R) 
 ((|constructor| (NIL "This type supports distributed multivariate polynomials whose variables are from a user specified list of symbols. The coefficient ring may be non commutative, but the variables are assumed to commute. The term ordering is lexicographic specified by the variable list parameter with the most significant variable first in the list.")) (|reorder| (($ $ (|List| (|Integer|))) "\\spad{reorder(p, perm)} applies the permutation perm to the variables in a polynomial and returns the new correctly ordered polynomial"))) 
-(((-4604 "*") |has| |#2| (-174)) (-4595 |has| |#2| (-562)) (-4600 |has| |#2| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-562)))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#2| (QUOTE -4600)) (|HasCategory| |#2| (QUOTE (-457))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (|HasCategory| |#2| (QUOTE (-149))))) 
-(-245 |n| R M S) 
+(((-4627 "*") |has| |#2| (-194)) (-4618 |has| |#2| (-582)) (-4623 |has| |#2| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-582)))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#2| (QUOTE -4623)) (|HasCategory| |#2| (QUOTE (-477))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (|HasCategory| |#2| (QUOTE (-169))))) 
+(-265 |n| R M S) 
 ((|constructor| (NIL "This constructor provides a direct product type with a left matrix-module view."))) 
-((-4599 -1841 (-4028 (|has| |#4| (-1054)) (|has| |#4| (-227))) (-4028 (|has| |#4| (-1054)) (|has| |#4| (-901 (-1170)))) (|has| |#4| (-6 -4599)) (-4028 (|has| |#4| (-1054)) (|has| |#4| (-634 (-572))))) (-4596 |has| |#4| (-1054)) (-4597 |has| |#4| (-1054)) ((-4604 "*") |has| |#4| (-174)) (-4602 . T)) 
-((|HasCategory| |#4| (QUOTE (-368))) (|HasCategory| |#4| (QUOTE (-1054))) (|HasCategory| |#4| (QUOTE (-794))) (|HasCategory| |#4| (QUOTE (-846))) (-1841 (|HasCategory| |#4| (QUOTE (-794))) (|HasCategory| |#4| (QUOTE (-846)))) (|HasCategory| |#4| (QUOTE (-722))) (|HasCategory| |#4| (QUOTE (-174))) (-1841 (|HasCategory| |#4| (QUOTE (-174))) (|HasCategory| |#4| (QUOTE (-368))) (|HasCategory| |#4| (QUOTE (-1054)))) (-1841 (|HasCategory| |#4| (QUOTE (-174))) (|HasCategory| |#4| (QUOTE (-368)))) (-1841 (|HasCategory| |#4| (QUOTE (-174))) (|HasCategory| |#4| (QUOTE (-1054)))) (|HasCategory| |#4| (QUOTE (-374))) (|HasCategory| |#4| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#4| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#4| (QUOTE (-227))) (-1841 (|HasCategory| |#4| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#4| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#4| (QUOTE (-174))) (|HasCategory| |#4| (QUOTE (-227))) (|HasCategory| |#4| (QUOTE (-1054)))) (|HasCategory| |#4| (QUOTE (-1098))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#4| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (QUOTE (-227))) (|HasCategory| |#4| (QUOTE (-1054)))) (-1841 (-12 (|HasCategory| |#4| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (QUOTE (-227))) (|HasCategory| |#4| (QUOTE (-1054)))) (|HasCategory| |#4| (QUOTE (-722)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#4| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-174)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-227)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-368)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-374)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-722)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-794)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-846)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-1098))))) (-1841 (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-1098)))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#4| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-174)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-227)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-368)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-374)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-722)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-794)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-846)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (QUOTE (-1098))))) (-1841 (|HasAttribute| |#4| (QUOTE -4599)) (-12 (|HasCategory| |#4| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (QUOTE (-227))) (|HasCategory| |#4| (QUOTE (-1054))))) (|HasCategory| |#4| (QUOTE (-138))) (|HasCategory| |#4| (QUOTE (-25))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (LIST (QUOTE -901) (QUOTE (-1170))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-174)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-227)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-368)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-374)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-722)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-794)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-846)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1054)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1098)))))) 
-(-246 |n| R S) 
+((-4622 -3836 (-1732 (|has| |#4| (-1075)) (|has| |#4| (-247))) (-1732 (|has| |#4| (-1075)) (|has| |#4| (-922 (-1191)))) (|has| |#4| (-6 -4622)) (-1732 (|has| |#4| (-1075)) (|has| |#4| (-654 (-592))))) (-4619 |has| |#4| (-1075)) (-4620 |has| |#4| (-1075)) ((-4627 "*") |has| |#4| (-194)) (-4625 . T)) 
+((|HasCategory| |#4| (QUOTE (-388))) (|HasCategory| |#4| (QUOTE (-1075))) (|HasCategory| |#4| (QUOTE (-815))) (|HasCategory| |#4| (QUOTE (-867))) (-3836 (|HasCategory| |#4| (QUOTE (-815))) (|HasCategory| |#4| (QUOTE (-867)))) (|HasCategory| |#4| (QUOTE (-743))) (|HasCategory| |#4| (QUOTE (-194))) (-3836 (|HasCategory| |#4| (QUOTE (-194))) (|HasCategory| |#4| (QUOTE (-388))) (|HasCategory| |#4| (QUOTE (-1075)))) (-3836 (|HasCategory| |#4| (QUOTE (-194))) (|HasCategory| |#4| (QUOTE (-388)))) (-3836 (|HasCategory| |#4| (QUOTE (-194))) (|HasCategory| |#4| (QUOTE (-1075)))) (|HasCategory| |#4| (QUOTE (-394))) (|HasCategory| |#4| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#4| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#4| (QUOTE (-247))) (-3836 (|HasCategory| |#4| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#4| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#4| (QUOTE (-194))) (|HasCategory| |#4| (QUOTE (-247))) (|HasCategory| |#4| (QUOTE (-1075)))) (|HasCategory| |#4| (QUOTE (-1119))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#4| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (QUOTE (-247))) (|HasCategory| |#4| (QUOTE (-1075)))) (-3836 (-12 (|HasCategory| |#4| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (QUOTE (-247))) (|HasCategory| |#4| (QUOTE (-1075)))) (|HasCategory| |#4| (QUOTE (-743)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#4| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-194)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-247)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-388)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-394)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-743)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-815)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-867)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-1119))))) (-3836 (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-1119)))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#4| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-194)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-247)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-388)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-394)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-743)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-815)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-867)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (QUOTE (-1119))))) (-3836 (|HasAttribute| |#4| (QUOTE -4622)) (-12 (|HasCategory| |#4| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (QUOTE (-247))) (|HasCategory| |#4| (QUOTE (-1075))))) (|HasCategory| |#4| (QUOTE (-158))) (|HasCategory| |#4| (QUOTE (-25))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (LIST (QUOTE -922) (QUOTE (-1191))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-194)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-247)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-388)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-394)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-743)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-815)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-867)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1075)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1119)))))) 
+(-266 |n| R S) 
 ((|constructor| (NIL "This constructor provides a direct product of R-modules with an R-module view."))) 
-((-4599 -1841 (-4028 (|has| |#3| (-1054)) (|has| |#3| (-227))) (-4028 (|has| |#3| (-1054)) (|has| |#3| (-901 (-1170)))) (|has| |#3| (-6 -4599)) (-4028 (|has| |#3| (-1054)) (|has| |#3| (-634 (-572))))) (-4596 |has| |#3| (-1054)) (-4597 |has| |#3| (-1054)) ((-4604 "*") |has| |#3| (-174)) (-4602 . T)) 
-((|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-1054))) (|HasCategory| |#3| (QUOTE (-794))) (|HasCategory| |#3| (QUOTE (-846))) (-1841 (|HasCategory| |#3| (QUOTE (-794))) (|HasCategory| |#3| (QUOTE (-846)))) (|HasCategory| |#3| (QUOTE (-722))) (|HasCategory| |#3| (QUOTE (-174))) (-1841 (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-1054)))) (-1841 (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-368)))) (-1841 (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-1054)))) (|HasCategory| |#3| (QUOTE (-374))) (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-227))) (-1841 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-1054)))) (|HasCategory| |#3| (QUOTE (-1098))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-1054)))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-1054)))) (|HasCategory| |#3| (QUOTE (-722)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-174)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-227)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-368)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-374)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-722)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-794)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-846)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1098))))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1098)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-174)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-227)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-368)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-374)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-722)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-794)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-846)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-1098))))) (-1841 (|HasAttribute| |#3| (QUOTE -4599)) (-12 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-1054))))) (|HasCategory| |#3| (QUOTE (-138))) (|HasCategory| |#3| (QUOTE (-25))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-174)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-227)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-368)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-374)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-722)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-794)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-846)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1098)))))) 
-(-247 A R S V E) 
+((-4622 -3836 (-1732 (|has| |#3| (-1075)) (|has| |#3| (-247))) (-1732 (|has| |#3| (-1075)) (|has| |#3| (-922 (-1191)))) (|has| |#3| (-6 -4622)) (-1732 (|has| |#3| (-1075)) (|has| |#3| (-654 (-592))))) (-4619 |has| |#3| (-1075)) (-4620 |has| |#3| (-1075)) ((-4627 "*") |has| |#3| (-194)) (-4625 . T)) 
+((|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-1075))) (|HasCategory| |#3| (QUOTE (-815))) (|HasCategory| |#3| (QUOTE (-867))) (-3836 (|HasCategory| |#3| (QUOTE (-815))) (|HasCategory| |#3| (QUOTE (-867)))) (|HasCategory| |#3| (QUOTE (-743))) (|HasCategory| |#3| (QUOTE (-194))) (-3836 (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-1075)))) (-3836 (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-388)))) (-3836 (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-1075)))) (|HasCategory| |#3| (QUOTE (-394))) (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-247))) (-3836 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-1075)))) (|HasCategory| |#3| (QUOTE (-1119))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-1075)))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-1075)))) (|HasCategory| |#3| (QUOTE (-743)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-194)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-247)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-388)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-394)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-743)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-815)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-867)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1119))))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1119)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-194)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-247)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-388)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-394)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-743)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-815)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-867)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-1119))))) (-3836 (|HasAttribute| |#3| (QUOTE -4622)) (-12 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-1075))))) (|HasCategory| |#3| (QUOTE (-158))) (|HasCategory| |#3| (QUOTE (-25))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-194)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-247)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-388)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-394)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-743)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-815)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-867)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1119)))))) 
+(-267 A R S V E) 
 ((|constructor| (NIL "\\spadtype{DifferentialPolynomialCategory} is a category constructor specifying basic functions in an ordinary differential polynomial ring with a given ordered set of differential indeterminates. In addition, it implements defaults for the basic functions. The functions \\spadfun{order} and \\spadfun{weight} are extended from the set of derivatives of differential indeterminates to the set of differential polynomials. Other operations provided on differential polynomials are \\spadfun{leader}, \\spadfun{initial}, \\spadfun{separant}, \\spadfun{differentialVariables}, and \\spadfun{isobaric?}. Furthermore, if the ground ring is a differential ring, then evaluation (substitution of differential indeterminates by elements of the ground ring or by differential polynomials) is provided by \\spadfun{eval}. A convenient way of referencing derivatives is provided by the functions \\spadfun{makeVariable}. \\blankline To construct a domain using this constructor, one needs to provide a ground ring \\spad{R,} an ordered set \\spad{S} of differential indeterminates, a ranking \\spad{V} on the set of derivatives of the differential indeterminates, and a set \\spad{E} of exponents in bijection with the set of differential monomials in the given differential indeterminates.")) (|separant| (($ $) "\\spad{separant(p)} returns the partial derivative of the differential polynomial \\spad{p} with respect to its leader.")) (|initial| (($ $) "\\spad{initial(p)} returns the leading coefficient when the differential polynomial \\spad{p} is written as a univariate polynomial in its leader.")) (|leader| ((|#4| $) "\\spad{leader(p)} returns the derivative of the highest rank appearing in the differential polynomial \\spad{p} Note that an error occurs if \\spad{p} is in the ground ring.")) (|isobaric?| (((|Boolean|) $) "\\spad{isobaric?(p)} returns \\spad{true} if every differential monomial appearing in the differential polynomial \\spad{p} has same weight, and returns \\spad{false} otherwise.")) (|weight| (((|NonNegativeInteger|) $ |#3|) "\\spad{weight(p, \\spad{s)}} returns the maximum weight of all differential monomials appearing in the differential polynomial \\spad{p} when \\spad{p} is viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.") (((|NonNegativeInteger|) $) "\\spad{weight(p)} returns the maximum weight of all differential monomials appearing in the differential polynomial \\spad{p.}")) (|weights| (((|List| (|NonNegativeInteger|)) $ |#3|) "\\spad{weights(p, \\spad{s)}} returns a list of weights of differential monomials appearing in the differential polynomial \\spad{p} when \\spad{p} is viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.") (((|List| (|NonNegativeInteger|)) $) "\\spad{weights(p)} returns a list of weights of differential monomials appearing in differential polynomial \\spad{p.}")) (|degree| (((|NonNegativeInteger|) $ |#3|) "\\spad{degree(p, \\spad{s)}} returns the maximum degree of the differential polynomial \\spad{p} viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(p)} returns the order of the differential polynomial \\spad{p,} which is the maximum number of differentiations of a differential indeterminate, among all those appearing in \\spad{p.}") (((|NonNegativeInteger|) $ |#3|) "\\spad{order(p,s)} returns the order of the differential polynomial \\spad{p} in differential indeterminate \\spad{s.}")) (|differentialVariables| (((|List| |#3|) $) "\\spad{differentialVariables(p)} returns a list of differential indeterminates occurring in a differential polynomial \\spad{p.}")) (|makeVariable| (((|Mapping| $ (|NonNegativeInteger|)) $) "\\spad{makeVariable(p)} views \\spad{p} as an element of a differential ring, in such a way that the \\spad{n}-th derivative of \\spad{p} may be simply referenced as \\spad{z.n} where \\spad{z} \\spad{:=} makeVariable(p). Note that In the interpreter, \\spad{z} is given as an internal map, which may be ignored.") (((|Mapping| $ (|NonNegativeInteger|)) |#3|) "\\spad{makeVariable(s)} views \\spad{s} as a differential indeterminate, in such a way that the \\spad{n}-th derivative of \\spad{s} may be simply referenced as \\spad{z.n} where \\spad{z} :=makeVariable(s). Note that In the interpreter, \\spad{z} is given as an internal map, which may be ignored."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-227)))) 
-(-248 R S V E) 
+((|HasCategory| |#2| (QUOTE (-247)))) 
+(-268 R S V E) 
 ((|constructor| (NIL "\\spadtype{DifferentialPolynomialCategory} is a category constructor specifying basic functions in an ordinary differential polynomial ring with a given ordered set of differential indeterminates. In addition, it implements defaults for the basic functions. The functions \\spadfun{order} and \\spadfun{weight} are extended from the set of derivatives of differential indeterminates to the set of differential polynomials. Other operations provided on differential polynomials are \\spadfun{leader}, \\spadfun{initial}, \\spadfun{separant}, \\spadfun{differentialVariables}, and \\spadfun{isobaric?}. Furthermore, if the ground ring is a differential ring, then evaluation (substitution of differential indeterminates by elements of the ground ring or by differential polynomials) is provided by \\spadfun{eval}. A convenient way of referencing derivatives is provided by the functions \\spadfun{makeVariable}. \\blankline To construct a domain using this constructor, one needs to provide a ground ring \\spad{R,} an ordered set \\spad{S} of differential indeterminates, a ranking \\spad{V} on the set of derivatives of the differential indeterminates, and a set \\spad{E} of exponents in bijection with the set of differential monomials in the given differential indeterminates.")) (|separant| (($ $) "\\spad{separant(p)} returns the partial derivative of the differential polynomial \\spad{p} with respect to its leader.")) (|initial| (($ $) "\\spad{initial(p)} returns the leading coefficient when the differential polynomial \\spad{p} is written as a univariate polynomial in its leader.")) (|leader| ((|#3| $) "\\spad{leader(p)} returns the derivative of the highest rank appearing in the differential polynomial \\spad{p} Note that an error occurs if \\spad{p} is in the ground ring.")) (|isobaric?| (((|Boolean|) $) "\\spad{isobaric?(p)} returns \\spad{true} if every differential monomial appearing in the differential polynomial \\spad{p} has same weight, and returns \\spad{false} otherwise.")) (|weight| (((|NonNegativeInteger|) $ |#2|) "\\spad{weight(p, \\spad{s)}} returns the maximum weight of all differential monomials appearing in the differential polynomial \\spad{p} when \\spad{p} is viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.") (((|NonNegativeInteger|) $) "\\spad{weight(p)} returns the maximum weight of all differential monomials appearing in the differential polynomial \\spad{p.}")) (|weights| (((|List| (|NonNegativeInteger|)) $ |#2|) "\\spad{weights(p, \\spad{s)}} returns a list of weights of differential monomials appearing in the differential polynomial \\spad{p} when \\spad{p} is viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.") (((|List| (|NonNegativeInteger|)) $) "\\spad{weights(p)} returns a list of weights of differential monomials appearing in differential polynomial \\spad{p.}")) (|degree| (((|NonNegativeInteger|) $ |#2|) "\\spad{degree(p, \\spad{s)}} returns the maximum degree of the differential polynomial \\spad{p} viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(p)} returns the order of the differential polynomial \\spad{p,} which is the maximum number of differentiations of a differential indeterminate, among all those appearing in \\spad{p.}") (((|NonNegativeInteger|) $ |#2|) "\\spad{order(p,s)} returns the order of the differential polynomial \\spad{p} in differential indeterminate \\spad{s.}")) (|differentialVariables| (((|List| |#2|) $) "\\spad{differentialVariables(p)} returns a list of differential indeterminates occurring in a differential polynomial \\spad{p.}")) (|makeVariable| (((|Mapping| $ (|NonNegativeInteger|)) $) "\\spad{makeVariable(p)} views \\spad{p} as an element of a differential ring, in such a way that the \\spad{n}-th derivative of \\spad{p} may be simply referenced as \\spad{z.n} where \\spad{z} \\spad{:=} makeVariable(p). Note that In the interpreter, \\spad{z} is given as an internal map, which may be ignored.") (((|Mapping| $ (|NonNegativeInteger|)) |#2|) "\\spad{makeVariable(s)} views \\spad{s} as a differential indeterminate, in such a way that the \\spad{n}-th derivative of \\spad{s} may be simply referenced as \\spad{z.n} where \\spad{z} :=makeVariable(s). Note that In the interpreter, \\spad{z} is given as an internal map, which may be ignored."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
 NIL 
-(-249 S) 
+(-269 S) 
 ((|constructor| (NIL "A dequeue is a doubly ended stack, that is, a bag where first items inserted are the first items extracted, at either the front or the back end of the data structure.")) (|reverse!| (($ $) "\\spad{reverse!(d)} destructively replaces \\spad{d} by its reverse dequeue, \\spadignore{i.e.} the top (front) element is now the bottom (back) element, and so on.")) (|extractBottom!| ((|#1| $) "\\spad{extractBottom!(d)} destructively extracts the bottom (back) element from the dequeue \\spad{d.} Error: if \\spad{d} is empty.")) (|extractTop!| ((|#1| $) "\\spad{extractTop!(d)} destructively extracts the top (front) element from the dequeue \\spad{d.} Error: if \\spad{d} is empty.")) (|insertBottom!| ((|#1| |#1| $) "\\spad{insertBottom!(x,d)} destructively inserts \\spad{x} into the dequeue \\spad{d} at the bottom (back) of the dequeue.")) (|insertTop!| ((|#1| |#1| $) "\\spad{insertTop!(x,d)} destructively inserts \\spad{x} into the dequeue \\spad{d,} that is, at the top (front) of the dequeue. The element previously at the top of the dequeue becomes the second in the dequeue, and so on.")) (|bottom!| ((|#1| $) "\\spad{bottom!(d)} returns the element at the bottom (back) of the dequeue.")) (|top!| ((|#1| $) "\\spad{top!(d)} returns the element at the top (front) of the dequeue.")) (|height| (((|NonNegativeInteger|) $) "\\spad{height(d)} returns the number of elements in dequeue \\spad{d.} Note that \\axiom{height(d) = \\# \\spad{d}.}")) (|dequeue| (($ (|List| |#1|)) "\\spad{dequeue([x,y,...,z])} creates a dequeue with first (top or front) element \\spad{x,} second element y,...,and last (bottom or back) element \\spad{z.}") (($) "\\spad{dequeue()}$D creates an empty dequeue of type \\spad{D.}"))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-250) 
+(-270) 
 ((|constructor| (NIL "TopLevelDrawFunctionsForCompiledFunctions provides top level functions for drawing graphics of expressions.")) (|recolor| (((|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) "\\spad{recolor()}, uninteresting to top level user; exported in order to compile package.")) (|makeObject| (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{makeObject(surface(f,g,h),a..b,c..d,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{x = f(u,v)}, \\spad{y = g(u,v)}, \\spad{z = h(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(surface(f,g,h),a..b,c..d,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{x = f(u,v)}, \\spad{y = g(u,v)}, \\spad{z = h(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{makeObject(f,a..b,c..d,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{f(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(f,a..b,c..d,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{f(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{makeObject(f,a..b,c..d)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of \\spad{z = f(x,y)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{y} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(f,a..b,c..d,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of \\spad{z = f(x,y)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{y} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|Float|))) "\\spad{makeObject(sp,curve(f,g,h),a..b)} returns the space \\spad{sp} of the domain \\spadtype{ThreeSpace} with the addition of the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t), \\spad{z} = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(curve(f,g,h),a..b,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t), \\spad{z} = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|))) "\\spad{makeObject(sp,curve(f,g,h),a..b)} returns the space \\spad{sp} of the domain \\spadtype{ThreeSpace} with the addition of the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t), \\spad{z} = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(curve(f,g,h),a..b,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t), \\spad{z} = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.")) (|draw| (((|ThreeDimensionalViewport|) (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{draw(surface(f,g,h),a..b,c..d)} draws the graph of the parametric surface \\spad{x = f(u,v)}, \\spad{y = g(u,v)}, \\spad{z = h(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}.") (((|ThreeDimensionalViewport|) (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(surface(f,g,h),a..b,c..d)} draws the graph of the parametric surface \\spad{x = f(u,v)}, \\spad{y = g(u,v)}, \\spad{z = h(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{draw(f,a..b,c..d)} draws the graph of the parametric surface \\spad{f(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)} The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f,a..b,c..d)} draws the graph of the parametric surface \\spad{f(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{draw(f,a..b,c..d)} draws the graph of \\spad{z = f(x,y)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{y} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}.") (((|ThreeDimensionalViewport|) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f,a..b,c..d,l)} draws the graph of \\spad{z = f(x,y)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{y} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}. and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|Float|))) "\\spad{draw(f,a..b,l)} draws the graph of the parametric curve \\spad{f} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}.") (((|ThreeDimensionalViewport|) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f,a..b,l)} draws the graph of the parametric curve \\spad{f} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|))) "\\spad{draw(curve(f,g,h),a..b,l)} draws the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t), \\spad{z} = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}.") (((|ThreeDimensionalViewport|) (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(curve(f,g,h),a..b,l)} draws the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t), \\spad{z} = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|TwoDimensionalViewport|) (|ParametricPlaneCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|))) "\\spad{draw(curve(f,g),a..b)} draws the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}.") (((|TwoDimensionalViewport|) (|ParametricPlaneCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(curve(f,g),a..b,l)} draws the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|TwoDimensionalViewport|) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|))) "\\spad{draw(f,a..b)} draws the graph of \\spad{y = f(x)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}.") (((|TwoDimensionalViewport|) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f,a..b,l)} draws the graph of \\spad{y = f(x)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied."))) 
 NIL 
 NIL 
-(-251 R |Ex|) 
+(-271 R |Ex|) 
 ((|constructor| (NIL "TopLevelDrawFunctionsForAlgebraicCurves provides top level functions for drawing non-singular algebraic curves.")) (|draw| (((|TwoDimensionalViewport|) (|Equation| |#2|) (|Symbol|) (|Symbol|) (|List| (|DrawOption|))) "\\spad{draw(f(x,y) = g(x,y),x,y,l)} draws the graph of a polynomial equation. The list \\spad{l} of draw options must specify a region in the plane in which the curve is to sketched."))) 
 NIL 
 NIL 
-(-252) 
+(-272) 
 ((|constructor| (NIL "\\axiomType{DrawComplex} provides some facilities for drawing complex functions.")) (|setClipValue| (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{setClipValue(x)} sets to \\spad{x} the maximum value to plot when drawing complex functions. Returns \\spad{x.}")) (|setImagSteps| (((|Integer|) (|Integer|)) "\\spad{setImagSteps(i)} sets to \\spad{i} the number of steps to use in the imaginary direction when drawing complex functions. Returns i.")) (|setRealSteps| (((|Integer|) (|Integer|)) "\\spad{setRealSteps(i)} sets to \\spad{i} the number of steps to use in the real direction when drawing complex functions. Returns i.")) (|drawComplexVectorField| (((|ThreeDimensionalViewport|) (|Mapping| (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{drawComplexVectorField(f,rRange,iRange)} draws a complex vector field using arrows on the \\spad{x--y} plane. These vector fields should be viewed from the top by pressing the \"XY\" translate button on the 3-d viewport control panel. Sample call: \\indented{3}{\\spad{f \\spad{z} \\spad{==} sin \\spad{z}}} \\indented{3}{\\spad{drawComplexVectorField(f, -2..2, -2..2)}} Parameter descriptions: \\indented{2}{f : the function to draw} \\indented{2}{rRange : the range of the real values} \\indented{2}{iRange : the range of the imaginary values} Call the functions \\axiomFunFrom{setRealSteps}{DrawComplex} and \\axiomFunFrom{setImagSteps}{DrawComplex} to change the number of steps used in each direction.")) (|drawComplex| (((|ThreeDimensionalViewport|) (|Mapping| (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Boolean|)) "\\spad{drawComplex(f,rRange,iRange,arrows?)} draws a complex function as a height field. It uses the complex norm as the height and the complex argument as the color. It will optionally draw arrows on the surface indicating the direction of the complex value. Sample call: \\indented{2}{\\spad{f \\spad{z} \\spad{==} exp(1/z)}} \\indented{2}{\\spad{drawComplex(f, 0.3..3, 0..2*%pi, false)}} Parameter descriptions: \\indented{2}{f:\\space{2}the function to draw} \\indented{2}{rRange : the range of the real values} \\indented{2}{iRange : the range of imaginary values} \\indented{2}{arrows? : a flag indicating whether to draw the phase arrows for \\spad{f}} Call the functions \\axiomFunFrom{setRealSteps}{DrawComplex} and \\axiomFunFrom{setImagSteps}{DrawComplex} to change the number of steps used in each direction."))) 
 NIL 
 NIL 
-(-253 R) 
+(-273 R) 
 ((|constructor| (NIL "Hack for the draw interface. DrawNumericHack provides a \"coercion\" from something of the form \\spad{x = a..b} where \\spad{a} and \\spad{b} are formal expressions to a binding of the form \\spad{x = c..d} where \\spad{c} and \\spad{d} are the numerical values of \\spad{a} and \\spad{b.} This \"coercion\" fails if \\spad{a} and \\spad{b} contains symbolic variables, but is meant for expressions involving \\%pi. Note that this package is meant for internal use only.")) (|coerce| (((|SegmentBinding| (|Float|)) (|SegmentBinding| (|Expression| |#1|))) "\\spad{coerce(x = a..b)} returns \\spad{x = c..d} where \\spad{c} and \\spad{d} are the numerical values of \\spad{a} and \\spad{b.}"))) 
 NIL 
 NIL 
-(-254 |Ex|) 
+(-274 |Ex|) 
 ((|constructor| (NIL "TopLevelDrawFunctions provides top level functions for drawing graphics of expressions.")) (|makeObject| (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSurface| |#1|) (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|))) "\\spad{makeObject(surface(f(u,v),g(u,v),h(u,v)),u = a..b,v = c..d)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{x = f(u,v)}, \\spad{y = g(u,v)}, \\spad{z = h(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; \\spad{h(t)} is the default title.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSurface| |#1|) (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(surface(f(u,v),g(u,v),h(u,v)),u = a..b,v = c..d,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{x = f(u,v)}, \\spad{y = g(u,v)}, \\spad{z = h(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; \\spad{h(t)} is the default title, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) |#1| (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|))) "\\spad{makeObject(f(x,y),x = a..b,y = c..d)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of \\spad{z = f(x,y)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{y} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; \\spad{f(x,y)} appears as the default title.") (((|ThreeSpace| (|DoubleFloat|)) |#1| (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(f(x,y),x = a..b,y = c..d,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of \\spad{z = f(x,y)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{y} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; \\spad{f(x,y)} is the default title, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSpaceCurve| |#1|) (|SegmentBinding| (|Float|))) "\\spad{makeObject(curve(f(t),g(t),h(t)),t = a..b)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)}, \\spad{z = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; \\spad{h(t)} is the default title.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSpaceCurve| |#1|) (|SegmentBinding| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(curve(f(t),g(t),h(t)),t = a..b,l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)}, \\spad{z = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; \\spad{h(t)} is the default title, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.")) (|draw| (((|ThreeDimensionalViewport|) (|ParametricSurface| |#1|) (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|))) "\\spad{draw(surface(f(u,v),g(u,v),h(u,v)),u = a..b,v = c..d)} draws the graph of the parametric surface \\spad{x = f(u,v)}, \\spad{y = g(u,v)}, \\spad{z = h(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; \\spad{h(t)} is the default title.") (((|ThreeDimensionalViewport|) (|ParametricSurface| |#1|) (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(surface(f(u,v),g(u,v),h(u,v)),u = a..b,v = c..d,l)} draws the graph of the parametric surface \\spad{x = f(u,v)}, \\spad{y = g(u,v)}, \\spad{z = h(u,v)} as \\spad{u} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{v} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; \\spad{h(t)} is the default title, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) |#1| (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|))) "\\spad{draw(f(x,y),x = a..b,y = c..d)} draws the graph of \\spad{z = f(x,y)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{y} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; \\spad{f(x,y)} appears in the title bar.") (((|ThreeDimensionalViewport|) |#1| (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f(x,y),x = a..b,y = c..d,l)} draws the graph of \\spad{z = f(x,y)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)} and \\spad{y} ranges from \\spad{min(c,d)} to \\spad{max(c,d)}; \\spad{f(x,y)} is the default title, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|ParametricSpaceCurve| |#1|) (|SegmentBinding| (|Float|))) "\\spad{draw(curve(f(t),g(t),h(t)),t = a..b)} draws the graph of the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)}, \\spad{z = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; \\spad{h(t)} is the default title.") (((|ThreeDimensionalViewport|) (|ParametricSpaceCurve| |#1|) (|SegmentBinding| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(curve(f(t),g(t),h(t)),t = a..b,l)} draws the graph of the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)}, \\spad{z = h(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; \\spad{h(t)} is the default title, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|TwoDimensionalViewport|) (|ParametricPlaneCurve| |#1|) (|SegmentBinding| (|Float|))) "\\spad{draw(curve(f(t),g(t)),t = a..b)} draws the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; \\spad{(f(t),g(t))} appears in the title bar.") (((|TwoDimensionalViewport|) (|ParametricPlaneCurve| |#1|) (|SegmentBinding| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(curve(f(t),g(t)),t = a..b,l)} draws the graph of the parametric curve \\spad{x = f(t), \\spad{y} = g(t)} as \\spad{t} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; \\spad{(f(t),g(t))} is the default title, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|TwoDimensionalViewport|) |#1| (|SegmentBinding| (|Float|))) "\\spad{draw(f(x),x = a..b)} draws the graph of \\spad{y = f(x)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; \\spad{f(x)} appears in the title bar.") (((|TwoDimensionalViewport|) |#1| (|SegmentBinding| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f(x),x = a..b,l)} draws the graph of \\spad{y = f(x)} as \\spad{x} ranges from \\spad{min(a,b)} to \\spad{max(a,b)}; \\spad{f(x)} is the default title, and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied."))) 
 NIL 
 NIL 
-(-255) 
+(-275) 
 ((|constructor| (NIL "TopLevelDrawFunctionsForPoints provides top level functions for drawing curves and surfaces described by sets of points.")) (|draw| (((|ThreeDimensionalViewport|) (|List| (|DoubleFloat|)) (|List| (|DoubleFloat|)) (|List| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{draw(lx,ly,lz,l)} draws the surface constructed by projecting the values in the \\axiom{lz} list onto the rectangular grid formed by the The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|List| (|DoubleFloat|)) (|List| (|DoubleFloat|)) (|List| (|DoubleFloat|))) "\\spad{draw(lx,ly,lz)} draws the surface constructed by projecting the values in the \\axiom{lz} list onto the rectangular grid formed by the \\axiom{lx \\spad{x} ly}.") (((|TwoDimensionalViewport|) (|List| (|Point| (|DoubleFloat|))) (|List| (|DrawOption|))) "\\spad{draw(lp,l)} plots the curve constructed from the list of points \\spad{lp.} The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|TwoDimensionalViewport|) (|List| (|Point| (|DoubleFloat|)))) "\\spad{draw(lp)} plots the curve constructed from the list of points \\spad{lp.}") (((|TwoDimensionalViewport|) (|List| (|DoubleFloat|)) (|List| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{draw(lx,ly,l)} plots the curve constructed of points (x,y) for \\spad{x} in \\spad{lx} for \\spad{y} in \\spad{ly}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|TwoDimensionalViewport|) (|List| (|DoubleFloat|)) (|List| (|DoubleFloat|))) "\\spad{draw(lx,ly)} plots the curve constructed of points (x,y) for \\spad{x} in \\spad{lx} for \\spad{y} in \\spad{ly}."))) 
 NIL 
 NIL 
-(-256) 
+(-276) 
 ((|constructor| (NIL "This package has no description")) (|units| (((|List| (|Float|)) (|List| (|DrawOption|)) (|List| (|Float|))) "\\spad{units(l,u)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{unit}. If the option does not exist the value, \\spad{u} is returned.")) (|coord| (((|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|))) (|List| (|DrawOption|)) (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) "\\spad{coord(l,p)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{coord}. If the option does not exist the value, \\spad{p} is returned.")) (|tubeRadius| (((|Float|) (|List| (|DrawOption|)) (|Float|)) "\\spad{tubeRadius(l,n)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{tubeRadius}. If the option does not exist the value, \\spad{n} is returned.")) (|tubePoints| (((|PositiveInteger|) (|List| (|DrawOption|)) (|PositiveInteger|)) "\\spad{tubePoints(l,n)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{tubePoints}. If the option does not exist the value, \\spad{n} is returned.")) (|space| (((|ThreeSpace| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{space(l)} takes a list of draw options, \\spad{l,} and checks to see if it contains the option \\spad{space}. If the the option doesn't exist, then an empty space is returned.")) (|var2Steps| (((|PositiveInteger|) (|List| (|DrawOption|)) (|PositiveInteger|)) "\\spad{var2Steps(l,n)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{var2Steps}. If the option does not exist the value, \\spad{n} is returned.")) (|var1Steps| (((|PositiveInteger|) (|List| (|DrawOption|)) (|PositiveInteger|)) "\\spad{var1Steps(l,n)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{var1Steps}. If the option does not exist the value, \\spad{n} is returned.")) (|ranges| (((|List| (|Segment| (|Float|))) (|List| (|DrawOption|)) (|List| (|Segment| (|Float|)))) "\\spad{ranges(l,r)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{ranges}. If the option does not exist the value, \\spad{r} is returned.")) (|curveColorPalette| (((|Palette|) (|List| (|DrawOption|)) (|Palette|)) "\\spad{curveColorPalette(l,p)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{curveColorPalette}. If the option does not exist the value, \\spad{p} is returned.")) (|pointColorPalette| (((|Palette|) (|List| (|DrawOption|)) (|Palette|)) "\\spad{pointColorPalette(l,p)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{pointColorPalette}. If the option does not exist the value, \\spad{p} is returned.")) (|toScale| (((|Boolean|) (|List| (|DrawOption|)) (|Boolean|)) "\\spad{toScale(l,b)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{toScale}. If the option does not exist the value, \\spad{b} is returned.")) (|style| (((|String|) (|List| (|DrawOption|)) (|String|)) "\\spad{style(l,s)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{style}. If the option does not exist the value, \\spad{s} is returned.")) (|title| (((|String|) (|List| (|DrawOption|)) (|String|)) "\\spad{title(l,s)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{title}. If the option does not exist the value, \\spad{s} is returned.")) (|viewpoint| (((|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|))) (|List| (|DrawOption|)) (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) "\\spad{viewpoint(l,ls)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{viewpoint}. IF the option does not exist, the value \\spad{ls} is returned.")) (|clipBoolean| (((|Boolean|) (|List| (|DrawOption|)) (|Boolean|)) "\\spad{clipBoolean(l,b)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{clipBoolean}. If the option does not exist the value, \\spad{b} is returned.")) (|adaptive| (((|Boolean|) (|List| (|DrawOption|)) (|Boolean|)) "\\spad{adaptive(l,b)} takes the list of draw options, \\spad{l,} and checks the list to see if it contains the option \\spad{adaptive}. If the option does not exist the value, \\spad{b} is returned."))) 
 NIL 
 NIL 
-(-257 S) 
+(-277 S) 
 ((|constructor| (NIL "This package has no description")) (|option| (((|Union| |#1| "failed") (|List| (|DrawOption|)) (|Symbol|)) "\\spad{option(l,s)} determines whether the indicated drawing option, \\spad{s,} is contained in the list of drawing options, \\spad{l,} which is defined by the draw command."))) 
 NIL 
 NIL 
-(-258) 
+(-278) 
 ((|constructor| (NIL "DrawOption allows the user to specify defaults for the creation and rendering of plots.")) (|option?| (((|Boolean|) (|List| $) (|Symbol|)) "\\spad{option?()} is not to be used at the top level; option? internally returns \\spad{true} for drawing options which are indicated in a draw command, or \\spad{false} for those which are not.")) (|option| (((|Union| (|Any|) "failed") (|List| $) (|Symbol|)) "\\spad{option()} is not to be used at the top level; option determines internally which drawing options are indicated in a draw command.")) (|unit| (($ (|List| (|Float|))) "\\spad{unit(lf)} will mark off the units according to the indicated list \\spad{lf.} This option is expressed in the form \\spad{unit \\spad{==} [f1,f2]}.")) (|coord| (($ (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) "\\spad{coord(p)} specifies a change of coordinates of point \\spad{p.} This option is expressed in the form \\spad{coord \\spad{==} \\spad{p}.}")) (|tubePoints| (($ (|PositiveInteger|)) "\\spad{tubePoints(n)} specifies the number of points, \\spad{n,} defining the circle which creates the tube around a 3D curve, the default is 6. This option is expressed in the form \\spad{tubePoints \\spad{==} \\spad{n}.}")) (|var2Steps| (($ (|PositiveInteger|)) "\\spad{var2Steps(n)} indicates the number of subdivisions, \\spad{n,} of the second range variable. This option is expressed in the form \\spad{var2Steps \\spad{==} \\spad{n}.}")) (|var1Steps| (($ (|PositiveInteger|)) "\\spad{var1Steps(n)} indicates the number of subdivisions, \\spad{n,} of the first range variable. This option is expressed in the form \\spad{var1Steps \\spad{==} \\spad{n}.}")) (|space| (($ (|ThreeSpace| (|DoubleFloat|))) "\\spad{space specifies} the space into which we will draw. If none is given then a new space is created.")) (|ranges| (($ (|List| (|Segment| (|Float|)))) "\\spad{ranges(l)} provides a list of user-specified ranges \\spad{l.} This option is expressed in the form \\spad{ranges \\spad{==} \\spad{l}.}")) (|range| (($ (|List| (|Segment| (|Fraction| (|Integer|))))) "\\spad{range([i])} provides a user-specified range i. This option is expressed in the form \\spad{range \\spad{==} [i]}.") (($ (|List| (|Segment| (|Float|)))) "\\spad{range([l])} provides a user-specified range \\spad{l.} This option is expressed in the form \\spad{range \\spad{==} [l]}.")) (|tubeRadius| (($ (|Float|)) "\\spad{tubeRadius(r)} specifies a radius, \\spad{r,} for a tube plot around a 3D curve; is expressed in the form \\spad{tubeRadius \\spad{==} 4}.")) (|colorFunction| (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) "\\spad{colorFunction(f(x,y,z))} specifies the color for three dimensional plots as a function of \\spad{x,} \\spad{y,} and \\spad{z} coordinates. This option is expressed in the form \\spad{colorFunction \\spad{==} f(x,y,z)}.") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) "\\spad{colorFunction(f(u,v))} specifies the color for three dimensional plots as a function based upon the two parametric variables. This option is expressed in the form \\spad{colorFunction \\spad{==} f(u,v)}.") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) "\\spad{colorFunction(f(z))} specifies the color based upon the z-component of three dimensional plots. This option is expressed in the form \\spad{colorFunction \\spad{==} f(z)}.")) (|curveColor| (($ (|Palette|)) "\\spad{curveColor(p)} specifies a color index for 2D graph curves from the spadcolors palette \\spad{p.} This option is expressed in the form \\spad{curveColor ==p}.") (($ (|Float|)) "\\spad{curveColor(v)} specifies a color, \\spad{v,} for 2D graph curves. This option is expressed in the form \\spad{curveColor \\spad{==} \\spad{v}.}")) (|pointColor| (($ (|Palette|)) "\\spad{pointColor(p)} specifies a color index for 2D graph points from the spadcolors palette \\spad{p.} This option is expressed in the form \\spad{pointColor \\spad{==} \\spad{p}.}") (($ (|Float|)) "\\spad{pointColor(v)} specifies a color, \\spad{v,} for 2D graph points. This option is expressed in the form \\spad{pointColor \\spad{==} \\spad{v}.}")) (|coordinates| (($ (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) "\\spad{coordinates(p)} specifies a change of coordinate systems of point \\spad{p.} This option is expressed in the form \\spad{coordinates \\spad{==} \\spad{p}.}")) (|toScale| (($ (|Boolean|)) "\\spad{toScale(b)} specifies whether or not a plot is to be drawn to scale; if \\spad{b} is \\spad{true} it is drawn to scale, if \\spad{b} is \\spad{false} it is not. This option is expressed in the form \\spad{toScale \\spad{==} \\spad{b}.}")) (|style| (($ (|String|)) "\\spad{style(s)} specifies the drawing style in which the graph will be plotted by the indicated string \\spad{s.} This option is expressed in the form \\spad{style \\spad{==} \\spad{s}.}")) (|title| (($ (|String|)) "\\spad{title(s)} specifies a title for a plot by the indicated string \\spad{s.} This option is expressed in the form \\spad{title \\spad{==} \\spad{s}.}")) (|viewpoint| (($ (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) "\\spad{viewpoint(vp)} creates a viewpoint data structure corresponding to the list of values. The values are interpreted as [theta, phi, scale, scaleX, scaleY, scaleZ, deltaX, deltaY]. This option is expressed in the form \\spad{viewpoint \\spad{==} ls}.")) (|clip| (($ (|List| (|Segment| (|Float|)))) "\\spad{clip([l])} provides ranges for user-defined clipping as specified in the list \\spad{l.} This option is expressed in the form \\spad{clip \\spad{==} [l]}.") (($ (|Boolean|)) "\\spad{clip(b)} turns 2D clipping on if \\spad{b} is true, or off if \\spad{b} is false. This option is expressed in the form \\spad{clip \\spad{==} \\spad{b}.}")) (|adaptive| (($ (|Boolean|)) "\\spad{adaptive(b)} turns adaptive 2D plotting on if \\spad{b} is true, or off if \\spad{b} is false. This option is expressed in the form \\spad{adaptive \\spad{==} \\spad{b}.}"))) 
 NIL 
 NIL 
-(-259 R S V) 
+(-279 R S V) 
 ((|constructor| (NIL "\\spadtype{DifferentialSparseMultivariatePolynomial} implements an ordinary differential polynomial ring by combining a domain belonging to the category \\spadtype{DifferentialVariableCategory} with the domain \\spadtype{SparseMultivariatePolynomial}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#3| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#3| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#3| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#3| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-260 S) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#3| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#3| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#3| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#3| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-280 S) 
 ((|constructor| (NIL "This category is part of the PAFF package")) (|tree| (($ (|List| |#1|)) "\\spad{tree(l)} creates a chain tree from the list \\spad{l}") (($ |#1|) "\\spad{tree(nd)} creates a tree with value \\spad{nd,} and no children") (($ |#1| (|List| $)) "\\spad{tree(nd,ls)} creates a tree with value \\spad{nd,} and children \\spad{ls.}"))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-261 S) 
+(-281 S) 
 ((|constructor| (NIL "This category is part of the PAFF package")) (|fullOutput| (((|Boolean|)) "\\spad{fullOutput returns} the value of the flag set by fullOutput(b).") (((|Boolean|) (|Boolean|)) "\\spad{fullOutput(b)} sets a flag such that when true, a coerce to OutputForm yields the full output of \\spad{tr,} otherwise encode(tr) is output (see encode function). The default is false.")) (|fullOut| (((|OutputForm|) $) "\\spad{fullOut(tr)} yields a full output of \\spad{tr} (see function fullOutput).")) (|encode| (((|String|) $) "\\spad{encode(t)} returns a string indicating the \"shape\" of the tree"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-262 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR |InfClsPoint| |DesTree| BLMET) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-282 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR |InfClsPoint| |DesTree| BLMET) 
 ((|constructor| (NIL "The following is all the categories, domains and package used for the desingularisation be means of monoidal transformation (Blowing-up)")) (|genusTreeNeg| (((|Integer|) (|NonNegativeInteger|) (|List| |#10|)) "\\spad{genusTreeNeg(n,listOfTrees)} computes the \"genus\" of a curve that may be not absolutly irreducible, where \\spad{n} is the degree of a polynomial pol defining the curve and \\spad{listOfTrees} is all the desingularisation trees at all singular points on the curve defined by pol. A \"negative\" genus means that the curve is reducible \\spad{!!.}")) (|genusTree| (((|NonNegativeInteger|) (|NonNegativeInteger|) (|List| |#10|)) "\\spad{genusTree(n,listOfTrees)} computes the genus of a curve, where \\spad{n} is the degree of a polynomial pol defining the curve and \\spad{listOfTrees} is all the desingularisation trees at all singular points on the curve defined by pol.")) (|genusNeg| (((|Integer|) |#3|) "\\spad{genusNeg(pol)} computes the \"genus\" of a curve that may be not absolutly irreducible. A \"negative\" genus means that the curve is reducible \\spad{!!.}")) (|genus| (((|NonNegativeInteger|) |#3|) "\\spad{genus(pol)} computes the genus of the curve defined by pol.")) (|initializeParamOfPlaces| (((|Void|) |#10| (|List| |#3|)) "initParLocLeaves(tr,listOfFnc) initialize the local parametrization at places corresponding to the leaves of \\spad{tr} according to the given list of functions in listOfFnc.") (((|Void|) |#10|) "initParLocLeaves(tr) initialize the local parametrization at places corresponding to the leaves of \\spad{tr.}")) (|initParLocLeaves| (((|Void|) |#10|) "\\spad{initParLocLeaves(tr)} initialize the local parametrization at simple points corresponding to the leaves of \\spad{tr.}")) (|fullParamInit| (((|Void|) |#10|) "\\spad{fullParamInit(tr)} initialize the local parametrization at all places (leaves of tr), computes the local exceptional divisor at each infinytly close points in the tree. This function is equivalent to the following called: initParLocLeaves(tr) initializeParamOfPlaces(tr) blowUpWithExcpDiv(tr)")) (|desingTree| (((|List| |#10|) |#3|) "\\spad{desingTree(pol)} returns all the desingularisation trees of all singular points on the curve defined by pol.")) (|desingTreeAtPoint| ((|#10| |#5| |#3|) "\\spad{desingTreeAtPoint(pt,pol)} computes the desingularisation tree at the point \\spad{pt} on the curve defined by pol. This function recursively compute the tree.")) (|adjunctionDivisor| ((|#8| |#10|) "\\spad{adjunctionDivisor(tr)} compute the local adjunction divisor of a desingularisation tree \\spad{tr} of a singular point.")) (|divisorAtDesingTree| ((|#8| |#3| |#10|) "\\spad{divisorAtDesingTree(f,tr)} computes the local divisor of \\spad{f} at a desingularisation tree \\spad{tr} of a singular point."))) 
 NIL 
 NIL 
-(-263 A S) 
+(-283 A S) 
 ((|constructor| (NIL "\\spadtype{DifferentialVariableCategory} constructs the set of derivatives of a given set of (ordinary) differential indeterminates. If x,...,y is an ordered set of differential indeterminates, and the prime notation is used for differentiation, then the set of derivatives (including zero-th order) of the differential indeterminates is x,\\spad{x'},\\spad{x''},..., y,\\spad{y'},\\spad{y''},... (Note that in the interpreter, the \\spad{n}-th derivative of \\spad{y} is displayed as \\spad{y} with a subscript \\spad{n.)} This set is viewed as a set of algebraic indeterminates, totally ordered in a way compatible with differentiation and the given order on the differential indeterminates. Such a total order is called a ranking of the differential indeterminates. \\blankline A domain in this category is needed to construct a differential polynomial domain. Differential polynomials are ordered by a ranking on the derivatives, and by an order (extending the ranking) on on the set of differential monomials. One may thus associate a domain in this category with a ranking of the differential indeterminates, just as one associates a domain in the category \\spadtype{OrderedAbelianMonoidSup} with an ordering of the set of monomials in a set of algebraic indeterminates. The ranking is specified through the binary relation \\spadfun{<}. For example, one may define one derivative to be less than another by lexicographically comparing first the \\spadfun{order}, then the given order of the differential indeterminates appearing in the derivatives. This is the default implementation. \\blankline The notion of weight generalizes that of degree. A polynomial domain may be made into a graded ring if a weight function is given on the set of indeterminates, Very often, a grading is the first step in ordering the set of monomials. For differential polynomial domains, this constructor provides a function \\spadfun{weight}, which allows the assignment of a non-negative number to each derivative of a differential indeterminate. For example, one may define the weight of a derivative to be simply its \\spadfun{order} (this is the default assignment). This weight function can then be extended to the set of all differential polynomials, providing a graded ring structure.")) (|coerce| (($ |#2|) "\\spad{coerce(s)} returns \\spad{s,} viewed as the zero-th order derivative of \\spad{s.}")) (|differentiate| (($ $ (|NonNegativeInteger|)) "\\spad{differentiate(v, \\spad{n)}} returns the \\spad{n}-th derivative of \\spad{v.}") (($ $) "\\spad{differentiate(v)} returns the derivative of \\spad{v.}")) (|weight| (((|NonNegativeInteger|) $) "\\spad{weight(v)} returns the weight of the derivative \\spad{v.}")) (|variable| ((|#2| $) "\\spad{variable(v)} returns \\spad{s} if \\spad{v} is any derivative of the differential indeterminate \\spad{s.}")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(v)} returns \\spad{n} if \\spad{v} is the \\spad{n}-th derivative of any differential indeterminate.")) (|makeVariable| (($ |#2| (|NonNegativeInteger|)) "\\spad{makeVariable(s, \\spad{n)}} returns the \\spad{n}-th derivative of a differential indeterminate \\spad{s} as an algebraic indeterminate."))) 
 NIL 
 NIL 
-(-264 S) 
+(-284 S) 
 ((|constructor| (NIL "\\spadtype{DifferentialVariableCategory} constructs the set of derivatives of a given set of (ordinary) differential indeterminates. If x,...,y is an ordered set of differential indeterminates, and the prime notation is used for differentiation, then the set of derivatives (including zero-th order) of the differential indeterminates is x,\\spad{x'},\\spad{x''},..., y,\\spad{y'},\\spad{y''},... (Note that in the interpreter, the \\spad{n}-th derivative of \\spad{y} is displayed as \\spad{y} with a subscript \\spad{n.)} This set is viewed as a set of algebraic indeterminates, totally ordered in a way compatible with differentiation and the given order on the differential indeterminates. Such a total order is called a ranking of the differential indeterminates. \\blankline A domain in this category is needed to construct a differential polynomial domain. Differential polynomials are ordered by a ranking on the derivatives, and by an order (extending the ranking) on on the set of differential monomials. One may thus associate a domain in this category with a ranking of the differential indeterminates, just as one associates a domain in the category \\spadtype{OrderedAbelianMonoidSup} with an ordering of the set of monomials in a set of algebraic indeterminates. The ranking is specified through the binary relation \\spadfun{<}. For example, one may define one derivative to be less than another by lexicographically comparing first the \\spadfun{order}, then the given order of the differential indeterminates appearing in the derivatives. This is the default implementation. \\blankline The notion of weight generalizes that of degree. A polynomial domain may be made into a graded ring if a weight function is given on the set of indeterminates, Very often, a grading is the first step in ordering the set of monomials. For differential polynomial domains, this constructor provides a function \\spadfun{weight}, which allows the assignment of a non-negative number to each derivative of a differential indeterminate. For example, one may define the weight of a derivative to be simply its \\spadfun{order} (this is the default assignment). This weight function can then be extended to the set of all differential polynomials, providing a graded ring structure.")) (|coerce| (($ |#1|) "\\spad{coerce(s)} returns \\spad{s,} viewed as the zero-th order derivative of \\spad{s.}")) (|differentiate| (($ $ (|NonNegativeInteger|)) "\\spad{differentiate(v, \\spad{n)}} returns the \\spad{n}-th derivative of \\spad{v.}") (($ $) "\\spad{differentiate(v)} returns the derivative of \\spad{v.}")) (|weight| (((|NonNegativeInteger|) $) "\\spad{weight(v)} returns the weight of the derivative \\spad{v.}")) (|variable| ((|#1| $) "\\spad{variable(v)} returns \\spad{s} if \\spad{v} is any derivative of the differential indeterminate \\spad{s.}")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(v)} returns \\spad{n} if \\spad{v} is the \\spad{n}-th derivative of any differential indeterminate.")) (|makeVariable| (($ |#1| (|NonNegativeInteger|)) "\\spad{makeVariable(s, \\spad{n)}} returns the \\spad{n}-th derivative of a differential indeterminate \\spad{s} as an algebraic indeterminate."))) 
 NIL 
 NIL 
-(-265) 
+(-285) 
 ((|constructor| (NIL "\\axiomType{e04AgentsPackage} is a package of numerical agents to be used to investigate attributes of an input function so as to decide the \\axiomFun{measure} of an appropriate numerical optimization routine.")) (|optAttributes| (((|List| (|String|)) (|Union| (|:| |noa| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|:| |lsa| (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))))) "\\spad{optAttributes(o)} is a function for supplying a list of attributes of an optimization problem.")) (|expenseOfEvaluation| (((|Float|) (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) "\\spad{expenseOfEvaluation(o)} returns the intensity value of the cost of evaluating the input set of functions. This is in terms of the number of ``operational units''. It returns a value in the range [0,1].")) (|changeNameToObjf| (((|Result|) (|Symbol|) (|Result|)) "\\spad{changeNameToObjf(s,r)} changes the name of item \\axiom{s} in \\axiom{r} to objf.")) (|varList| (((|List| (|Symbol|)) (|Expression| (|DoubleFloat|)) (|NonNegativeInteger|)) "\\spad{varList(e,n)} returns a list of \\axiom{n} indexed variables with name as in \\axiom{e}.")) (|variables| (((|List| (|Symbol|)) (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) "\\spad{variables(args)} returns the list of variables in \\axiom{args.lfn}")) (|quadratic?| (((|Boolean|) (|Expression| (|DoubleFloat|))) "\\spad{quadratic?(e)} tests if \\axiom{e} is a quadratic function.")) (|nonLinearPart| (((|List| (|Expression| (|DoubleFloat|))) (|List| (|Expression| (|DoubleFloat|)))) "\\spad{nonLinearPart(l)} returns the list of non-linear functions of \\spad{l.}")) (|linearPart| (((|List| (|Expression| (|DoubleFloat|))) (|List| (|Expression| (|DoubleFloat|)))) "\\spad{linearPart(l)} returns the list of linear functions of \\axiom{l}.")) (|linearMatrix| (((|Matrix| (|DoubleFloat|)) (|List| (|Expression| (|DoubleFloat|))) (|NonNegativeInteger|)) "\\spad{linearMatrix(l,n)} returns a matrix of coefficients of the linear functions in \\axiom{l}. If \\spad{l} is empty, the matrix has at least one row.")) (|linear?| (((|Boolean|) (|Expression| (|DoubleFloat|))) "\\spad{linear?(e)} tests if \\axiom{e} is a linear function.") (((|Boolean|) (|List| (|Expression| (|DoubleFloat|)))) "\\spad{linear?(l)} returns \\spad{true} if all the bounds \\spad{l} are either linear or simple.")) (|simpleBounds?| (((|Boolean|) (|List| (|Expression| (|DoubleFloat|)))) "\\spad{simpleBounds?(l)} returns \\spad{true} if the list of expressions \\spad{l} are simple.")) (|splitLinear| (((|Expression| (|DoubleFloat|)) (|Expression| (|DoubleFloat|))) "\\spad{splitLinear(f)} splits the linear part from an expression which it returns.")) (|sumOfSquares| (((|Union| (|Expression| (|DoubleFloat|)) "failed") (|Expression| (|DoubleFloat|))) "\\spad{sumOfSquares(f)} returns either an expression for which the square is the original function of \"failed\".")) (|sortConstraints| (((|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|))))) (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) "\\spad{sortConstraints(args)} uses a simple bubblesort on the list of constraints using the degree of the expression on which to sort. Of course, it must match the bounds to the constraints.")) (|finiteBound| (((|List| (|DoubleFloat|)) (|List| (|OrderedCompletion| (|DoubleFloat|))) (|DoubleFloat|)) "\\spad{finiteBound(l,b)} repaces all instances of an infinite entry in \\axiom{l} by a finite entry \\axiom{b} or \\axiom{-b}."))) 
 NIL 
 NIL 
-(-266) 
+(-286) 
 ((|constructor| (NIL "\\axiomType{e04dgfAnnaType} is a domain of \\axiomType{NumericalOptimization} for the NAG routine E04DGF, a general optimization routine which can handle some singularities in the input function. The function \\axiomFun{measure} measures the usefulness of the routine E04DGF for the given problem. The function \\axiomFun{numericalOptimization} performs the optimization by using \\axiomType{NagOptimisationPackage}."))) 
 NIL 
 NIL 
-(-267) 
+(-287) 
 ((|constructor| (NIL "\\axiomType{e04fdfAnnaType} is a domain of \\axiomType{NumericalOptimization} for the NAG routine E04FDF, a general optimization routine which can handle some singularities in the input function. The function \\axiomFun{measure} measures the usefulness of the routine E04FDF for the given problem. The function \\axiomFun{numericalOptimization} performs the optimization by using \\axiomType{NagOptimisationPackage}."))) 
 NIL 
 NIL 
-(-268) 
+(-288) 
 ((|constructor| (NIL "\\axiomType{e04gcfAnnaType} is a domain of \\axiomType{NumericalOptimization} for the NAG routine E04GCF, a general optimization routine which can handle some singularities in the input function. The function \\axiomFun{measure} measures the usefulness of the routine E04GCF for the given problem. The function \\axiomFun{numericalOptimization} performs the optimization by using \\axiomType{NagOptimisationPackage}."))) 
 NIL 
 NIL 
-(-269) 
+(-289) 
 ((|constructor| (NIL "\\axiomType{e04jafAnnaType} is a domain of \\axiomType{NumericalOptimization} for the NAG routine E04JAF, a general optimization routine which can handle some singularities in the input function. The function \\axiomFun{measure} measures the usefulness of the routine E04JAF for the given problem. The function \\axiomFun{numericalOptimization} performs the optimization by using \\axiomType{NagOptimisationPackage}."))) 
 NIL 
 NIL 
-(-270) 
+(-290) 
 ((|constructor| (NIL "\\axiomType{e04mbfAnnaType} is a domain of \\axiomType{NumericalOptimization} for the NAG routine E04MBF, an optimization routine for Linear functions. The function \\axiomFun{measure} measures the usefulness of the routine E04MBF for the given problem. The function \\axiomFun{numericalOptimization} performs the optimization by using \\axiomType{NagOptimisationPackage}."))) 
 NIL 
 NIL 
-(-271) 
+(-291) 
 ((|constructor| (NIL "\\axiomType{e04nafAnnaType} is a domain of \\axiomType{NumericalOptimization} for the NAG routine E04NAF, an optimization routine for Quadratic functions. The function \\axiomFun{measure} measures the usefulness of the routine E04NAF for the given problem. The function \\axiomFun{numericalOptimization} performs the optimization by using \\axiomType{NagOptimisationPackage}."))) 
 NIL 
 NIL 
-(-272) 
+(-292) 
 ((|constructor| (NIL "\\axiomType{e04ucfAnnaType} is a domain of \\axiomType{NumericalOptimization} for the NAG routine E04UCF, a general optimization routine which can handle some singularities in the input function. The function \\axiomFun{measure} measures the usefulness of the routine E04UCF for the given problem. The function \\axiomFun{numericalOptimization} performs the optimization by using \\axiomType{NagOptimisationPackage}."))) 
 NIL 
 NIL 
-(-273) 
+(-293) 
 ((|constructor| (NIL "A domain used in the construction of the exterior algebra on a set \\spad{X} over a ring \\spad{R.} This domain represents the set of all ordered subsets of the set \\spad{X,} assumed to be in correspondance with {1,2,3, ...}. The ordered subsets are themselves ordered lexicographically and are in bijective correspondance with an ordered basis of the exterior algebra. In this domain we are dealing strictly with the exponents of basis elements which can only be 0 or 1. \\blankline The multiplicative identity element of the exterior algebra corresponds to the empty subset of \\spad{X.} A coerce from List Integer to an ordered basis element is provided to allow the convenient input of expressions. Another exported function forgets the ordered structure and simply returns the list corresponding to an ordered subset.")) (|Nul| (($ (|NonNegativeInteger|)) "\\spad{Nul()} gives the basis element 1 for the algebra generated by \\spad{n} generators.")) (|exponents| (((|List| (|Integer|)) $) "\\spad{exponents(x)} converts a domain element into a list of zeros and ones corresponding to the exponents in the basis element that \\spad{x} represents.")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(x)} gives the numbers of 1's in \\spad{x,} \\spadignore{i.e.} the number of non-zero exponents in the basis element that \\spad{x} represents.")) (|coerce| (($ (|List| (|Integer|))) "\\spad{coerce(l)} converts a list of 0's and 1's into a basis element, where 1 (respectively 0) designates that the variable of the corresponding index of \\spad{l} is (respectively, is not) present. Error: if an element of \\spad{l} is not 0 or 1."))) 
 NIL 
 NIL 
-(-274 R -3313) 
+(-294 R -3958) 
 ((|constructor| (NIL "Provides elementary functions over an integral domain.")) (|localReal?| (((|Boolean|) |#2|) "\\spad{localReal?(x)} should be local but conditional")) (|specialTrigs| (((|Union| |#2| "failed") |#2| (|List| (|Record| (|:| |func| |#2|) (|:| |pole| (|Boolean|))))) "\\spad{specialTrigs(x,l)} should be local but conditional")) (|iiacsch| ((|#2| |#2|) "\\spad{iiacsch(x)} should be local but conditional")) (|iiasech| ((|#2| |#2|) "\\spad{iiasech(x)} should be local but conditional")) (|iiacoth| ((|#2| |#2|) "\\spad{iiacoth(x)} should be local but conditional")) (|iiatanh| ((|#2| |#2|) "\\spad{iiatanh(x)} should be local but conditional")) (|iiacosh| ((|#2| |#2|) "\\spad{iiacosh(x)} should be local but conditional")) (|iiasinh| ((|#2| |#2|) "\\spad{iiasinh(x)} should be local but conditional")) (|iicsch| ((|#2| |#2|) "\\spad{iicsch(x)} should be local but conditional")) (|iisech| ((|#2| |#2|) "\\spad{iisech(x)} should be local but conditional")) (|iicoth| ((|#2| |#2|) "\\spad{iicoth(x)} should be local but conditional")) (|iitanh| ((|#2| |#2|) "\\spad{iitanh(x)} should be local but conditional")) (|iicosh| ((|#2| |#2|) "\\spad{iicosh(x)} should be local but conditional")) (|iisinh| ((|#2| |#2|) "\\spad{iisinh(x)} should be local but conditional")) (|iiacsc| ((|#2| |#2|) "\\spad{iiacsc(x)} should be local but conditional")) (|iiasec| ((|#2| |#2|) "\\spad{iiasec(x)} should be local but conditional")) (|iiacot| ((|#2| |#2|) "\\spad{iiacot(x)} should be local but conditional")) (|iiatan| ((|#2| |#2|) "\\spad{iiatan(x)} should be local but conditional")) (|iiacos| ((|#2| |#2|) "\\spad{iiacos(x)} should be local but conditional")) (|iiasin| ((|#2| |#2|) "\\spad{iiasin(x)} should be local but conditional")) (|iicsc| ((|#2| |#2|) "\\spad{iicsc(x)} should be local but conditional")) (|iisec| ((|#2| |#2|) "\\spad{iisec(x)} should be local but conditional")) (|iicot| ((|#2| |#2|) "\\spad{iicot(x)} should be local but conditional")) (|iitan| ((|#2| |#2|) "\\spad{iitan(x)} should be local but conditional")) (|iicos| ((|#2| |#2|) "\\spad{iicos(x)} should be local but conditional")) (|iisin| ((|#2| |#2|) "\\spad{iisin(x)} should be local but conditional")) (|iilog| ((|#2| |#2|) "\\spad{iilog(x)} should be local but conditional")) (|iiexp| ((|#2| |#2|) "\\spad{iiexp(x)} should be local but conditional")) (|iisqrt3| ((|#2|) "\\spad{iisqrt3()} should be local but conditional")) (|iisqrt2| ((|#2|) "\\spad{iisqrt2()} should be local but conditional")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(p)} returns an elementary operator with the same symbol as \\spad{p}")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(p)} returns \\spad{true} if operator \\spad{p} is elementary")) (|pi| ((|#2|) "\\spad{pi()} returns the \\spad{pi} operator")) (|acsch| ((|#2| |#2|) "\\spad{acsch(x)} applies the inverse hyperbolic cosecant operator to \\spad{x}")) (|asech| ((|#2| |#2|) "\\spad{asech(x)} applies the inverse hyperbolic secant operator to \\spad{x}")) (|acoth| ((|#2| |#2|) "\\spad{acoth(x)} applies the inverse hyperbolic cotangent operator to \\spad{x}")) (|atanh| ((|#2| |#2|) "\\spad{atanh(x)} applies the inverse hyperbolic tangent operator to \\spad{x}")) (|acosh| ((|#2| |#2|) "\\spad{acosh(x)} applies the inverse hyperbolic cosine operator to \\spad{x}")) (|asinh| ((|#2| |#2|) "\\spad{asinh(x)} applies the inverse hyperbolic sine operator to \\spad{x}")) (|csch| ((|#2| |#2|) "\\spad{csch(x)} applies the hyperbolic cosecant operator to \\spad{x}")) (|sech| ((|#2| |#2|) "\\spad{sech(x)} applies the hyperbolic secant operator to \\spad{x}")) (|coth| ((|#2| |#2|) "\\spad{coth(x)} applies the hyperbolic cotangent operator to \\spad{x}")) (|tanh| ((|#2| |#2|) "\\spad{tanh(x)} applies the hyperbolic tangent operator to \\spad{x}")) (|cosh| ((|#2| |#2|) "\\spad{cosh(x)} applies the hyperbolic cosine operator to \\spad{x}")) (|sinh| ((|#2| |#2|) "\\spad{sinh(x)} applies the hyperbolic sine operator to \\spad{x}")) (|acsc| ((|#2| |#2|) "\\spad{acsc(x)} applies the inverse cosecant operator to \\spad{x}")) (|asec| ((|#2| |#2|) "\\spad{asec(x)} applies the inverse secant operator to \\spad{x}")) (|acot| ((|#2| |#2|) "\\spad{acot(x)} applies the inverse cotangent operator to \\spad{x}")) (|atan| ((|#2| |#2|) "\\spad{atan(x)} applies the inverse tangent operator to \\spad{x}")) (|acos| ((|#2| |#2|) "\\spad{acos(x)} applies the inverse cosine operator to \\spad{x}")) (|asin| ((|#2| |#2|) "\\spad{asin(x)} applies the inverse sine operator to \\spad{x}")) (|csc| ((|#2| |#2|) "\\spad{csc(x)} applies the cosecant operator to \\spad{x}")) (|sec| ((|#2| |#2|) "\\spad{sec(x)} applies the secant operator to \\spad{x}")) (|cot| ((|#2| |#2|) "\\spad{cot(x)} applies the cotangent operator to \\spad{x}")) (|tan| ((|#2| |#2|) "\\spad{tan(x)} applies the tangent operator to \\spad{x}")) (|cos| ((|#2| |#2|) "\\spad{cos(x)} applies the cosine operator to \\spad{x}")) (|sin| ((|#2| |#2|) "\\spad{sin(x)} applies the sine operator to \\spad{x}")) (|log| ((|#2| |#2|) "\\spad{log(x)} applies the logarithm operator to \\spad{x}")) (|exp| ((|#2| |#2|) "\\spad{exp(x)} applies the exponential operator to \\spad{x}"))) 
 NIL 
 NIL 
-(-275 R -3313) 
+(-295 R -3958) 
 ((|constructor| (NIL "ElementaryFunctionStructurePackage provides functions to test the algebraic independence of various elementary functions, using the Risch structure theorem (real and complex versions). It also provides transformations on elementary functions which are not considered simplifications.")) (|tanQ| ((|#2| (|Fraction| (|Integer|)) |#2|) "\\spad{tanQ(q,a)} is a local function with a conditional implementation.")) (|rootNormalize| ((|#2| |#2| (|Kernel| |#2|)) "\\spad{rootNormalize(f, \\spad{k)}} returns \\spad{f} rewriting either \\spad{k} which must be an nth-root in terms of radicals already in \\spad{f}, or some radicals in \\spad{f} in terms of \\spad{k}.")) (|validExponential| (((|Union| |#2| "failed") (|List| (|Kernel| |#2|)) |#2| (|Symbol|)) "\\spad{validExponential([k1,...,kn],f,x)} returns \\spad{g} if \\spad{exp(f)=g} and \\spad{g} involves only \\spad{k1...kn}, and \"failed\" otherwise.")) (|realElementary| ((|#2| |#2| (|Symbol|)) "\\spad{realElementary(f,x)} rewrites the kernels of \\spad{f} involving \\spad{x} in terms of the 4 fundamental real transcendental elementary functions: \\spad{log, exp, tan, atan}.") ((|#2| |#2|) "\\spad{realElementary(f)} rewrites \\spad{f} in terms of the 4 fundamental real transcendental elementary functions: \\spad{log, exp, tan, atan}.")) (|rischNormalize| (((|Record| (|:| |func| |#2|) (|:| |kers| (|List| (|Kernel| |#2|))) (|:| |vals| (|List| |#2|))) |#2| (|Symbol|)) "\\spad{rischNormalize(f, \\spad{x)}} returns \\spad{[g, [k1,...,kn], [h1,...,hn]]} such that \\spad{g = normalize(f, \\spad{x)}} and each \\spad{ki} was rewritten as \\spad{hi} during the normalization.")) (|normalize| ((|#2| |#2| (|Symbol|)) "\\spad{normalize(f, \\spad{x)}} rewrites \\spad{f} using the least possible number of real algebraically independent kernels involving \\spad{x}.") ((|#2| |#2|) "\\spad{normalize(f)} rewrites \\spad{f} using the least possible number of real algebraically independent kernels."))) 
 NIL 
 NIL 
-(-276 |Coef| UTS ULS) 
+(-296 |Coef| UTS ULS) 
 ((|constructor| (NIL "This domain provides elementary functions on any Laurent series domain over a field which was constructed from a Taylor series domain. These functions are implemented by calling the corresponding functions on the Taylor series domain. We also provide 'partial functions' which compute transcendental functions of Laurent series when possible and return \"failed\" when this is not possible.")) (|acsch| ((|#3| |#3|) "\\spad{acsch(z)} returns the inverse hyperbolic cosecant of Laurent series \\spad{z.}")) (|asech| ((|#3| |#3|) "\\spad{asech(z)} returns the inverse hyperbolic secant of Laurent series \\spad{z.}")) (|acoth| ((|#3| |#3|) "\\spad{acoth(z)} returns the inverse hyperbolic cotangent of Laurent series \\spad{z.}")) (|atanh| ((|#3| |#3|) "\\spad{atanh(z)} returns the inverse hyperbolic tangent of Laurent series \\spad{z.}")) (|acosh| ((|#3| |#3|) "\\spad{acosh(z)} returns the inverse hyperbolic cosine of Laurent series \\spad{z.}")) (|asinh| ((|#3| |#3|) "\\spad{asinh(z)} returns the inverse hyperbolic sine of Laurent series \\spad{z.}")) (|csch| ((|#3| |#3|) "\\spad{csch(z)} returns the hyperbolic cosecant of Laurent series \\spad{z.}")) (|sech| ((|#3| |#3|) "\\spad{sech(z)} returns the hyperbolic secant of Laurent series \\spad{z.}")) (|coth| ((|#3| |#3|) "\\spad{coth(z)} returns the hyperbolic cotangent of Laurent series \\spad{z.}")) (|tanh| ((|#3| |#3|) "\\spad{tanh(z)} returns the hyperbolic tangent of Laurent series \\spad{z.}")) (|cosh| ((|#3| |#3|) "\\spad{cosh(z)} returns the hyperbolic cosine of Laurent series \\spad{z.}")) (|sinh| ((|#3| |#3|) "\\spad{sinh(z)} returns the hyperbolic sine of Laurent series \\spad{z.}")) (|acsc| ((|#3| |#3|) "\\spad{acsc(z)} returns the arc-cosecant of Laurent series \\spad{z.}")) (|asec| ((|#3| |#3|) "\\spad{asec(z)} returns the arc-secant of Laurent series \\spad{z.}")) (|acot| ((|#3| |#3|) "\\spad{acot(z)} returns the arc-cotangent of Laurent series \\spad{z.}")) (|atan| ((|#3| |#3|) "\\spad{atan(z)} returns the arc-tangent of Laurent series \\spad{z.}")) (|acos| ((|#3| |#3|) "\\spad{acos(z)} returns the arc-cosine of Laurent series \\spad{z.}")) (|asin| ((|#3| |#3|) "\\spad{asin(z)} returns the arc-sine of Laurent series \\spad{z.}")) (|csc| ((|#3| |#3|) "\\spad{csc(z)} returns the cosecant of Laurent series \\spad{z.}")) (|sec| ((|#3| |#3|) "\\spad{sec(z)} returns the secant of Laurent series \\spad{z.}")) (|cot| ((|#3| |#3|) "\\spad{cot(z)} returns the cotangent of Laurent series \\spad{z.}")) (|tan| ((|#3| |#3|) "\\spad{tan(z)} returns the tangent of Laurent series \\spad{z.}")) (|cos| ((|#3| |#3|) "\\spad{cos(z)} returns the cosine of Laurent series \\spad{z.}")) (|sin| ((|#3| |#3|) "\\spad{sin(z)} returns the sine of Laurent series \\spad{z.}")) (|log| ((|#3| |#3|) "\\spad{log(z)} returns the logarithm of Laurent series \\spad{z.}")) (|exp| ((|#3| |#3|) "\\spad{exp(z)} returns the exponential of Laurent series \\spad{z.}")) (** ((|#3| |#3| (|Fraction| (|Integer|))) "\\spad{s \\spad{**} \\spad{r}} raises a Laurent series \\spad{s} to a rational power \\spad{r}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368)))) 
-(-277 |Coef| ULS UPXS EFULS) 
+((|HasCategory| |#1| (QUOTE (-388)))) 
+(-297 |Coef| ULS UPXS EFULS) 
 ((|constructor| (NIL "This package provides elementary functions on any Laurent series domain over a field which was constructed from a Taylor series domain. These functions are implemented by calling the corresponding functions on the Taylor series domain. We also provide 'partial functions' which compute transcendental functions of Laurent series when possible and return \"failed\" when this is not possible.")) (|acsch| ((|#3| |#3|) "\\spad{acsch(z)} returns the inverse hyperbolic cosecant of a Puiseux series \\spad{z.}")) (|asech| ((|#3| |#3|) "\\spad{asech(z)} returns the inverse hyperbolic secant of a Puiseux series \\spad{z.}")) (|acoth| ((|#3| |#3|) "\\spad{acoth(z)} returns the inverse hyperbolic cotangent of a Puiseux series \\spad{z.}")) (|atanh| ((|#3| |#3|) "\\spad{atanh(z)} returns the inverse hyperbolic tangent of a Puiseux series \\spad{z.}")) (|acosh| ((|#3| |#3|) "\\spad{acosh(z)} returns the inverse hyperbolic cosine of a Puiseux series \\spad{z.}")) (|asinh| ((|#3| |#3|) "\\spad{asinh(z)} returns the inverse hyperbolic sine of a Puiseux series \\spad{z.}")) (|csch| ((|#3| |#3|) "\\spad{csch(z)} returns the hyperbolic cosecant of a Puiseux series \\spad{z.}")) (|sech| ((|#3| |#3|) "\\spad{sech(z)} returns the hyperbolic secant of a Puiseux series \\spad{z.}")) (|coth| ((|#3| |#3|) "\\spad{coth(z)} returns the hyperbolic cotangent of a Puiseux series \\spad{z.}")) (|tanh| ((|#3| |#3|) "\\spad{tanh(z)} returns the hyperbolic tangent of a Puiseux series \\spad{z.}")) (|cosh| ((|#3| |#3|) "\\spad{cosh(z)} returns the hyperbolic cosine of a Puiseux series \\spad{z.}")) (|sinh| ((|#3| |#3|) "\\spad{sinh(z)} returns the hyperbolic sine of a Puiseux series \\spad{z.}")) (|acsc| ((|#3| |#3|) "\\spad{acsc(z)} returns the arc-cosecant of a Puiseux series \\spad{z.}")) (|asec| ((|#3| |#3|) "\\spad{asec(z)} returns the arc-secant of a Puiseux series \\spad{z.}")) (|acot| ((|#3| |#3|) "\\spad{acot(z)} returns the arc-cotangent of a Puiseux series \\spad{z.}")) (|atan| ((|#3| |#3|) "\\spad{atan(z)} returns the arc-tangent of a Puiseux series \\spad{z.}")) (|acos| ((|#3| |#3|) "\\spad{acos(z)} returns the arc-cosine of a Puiseux series \\spad{z.}")) (|asin| ((|#3| |#3|) "\\spad{asin(z)} returns the arc-sine of a Puiseux series \\spad{z.}")) (|csc| ((|#3| |#3|) "\\spad{csc(z)} returns the cosecant of a Puiseux series \\spad{z.}")) (|sec| ((|#3| |#3|) "\\spad{sec(z)} returns the secant of a Puiseux series \\spad{z.}")) (|cot| ((|#3| |#3|) "\\spad{cot(z)} returns the cotangent of a Puiseux series \\spad{z.}")) (|tan| ((|#3| |#3|) "\\spad{tan(z)} returns the tangent of a Puiseux series \\spad{z.}")) (|cos| ((|#3| |#3|) "\\spad{cos(z)} returns the cosine of a Puiseux series \\spad{z.}")) (|sin| ((|#3| |#3|) "\\spad{sin(z)} returns the sine of a Puiseux series \\spad{z.}")) (|log| ((|#3| |#3|) "\\spad{log(z)} returns the logarithm of a Puiseux series \\spad{z.}")) (|exp| ((|#3| |#3|) "\\spad{exp(z)} returns the exponential of a Puiseux series \\spad{z.}")) (** ((|#3| |#3| (|Fraction| (|Integer|))) "\\spad{z \\spad{**} \\spad{r}} raises a Puiseaux series \\spad{z} to a rational power \\spad{r}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368)))) 
-(-278 A S) 
+((|HasCategory| |#1| (QUOTE (-388)))) 
+(-298 A S) 
 ((|constructor| (NIL "An extensible aggregate is one which allows insertion and deletion of entries. These aggregates are models of lists and streams which are represented by linked structures so as to make insertion, deletion, and concatenation efficient. However, access to elements of these extensible aggregates is generally slow since access is made from the end. See \\spadtype{FlexibleArray} for an exception.")) (|removeDuplicates!| (($ $) "\\spad{removeDuplicates!(u)} destructively removes duplicates from u.")) (|select!| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{select!(p,u)} destructively changes \\spad{u} by keeping only values \\spad{x} such that \\axiom{p(x)}.")) (|merge!| (($ $ $) "\\spad{merge!(u,v)} destructively merges \\spad{u} and \\spad{v} in ascending order.") (($ (|Mapping| (|Boolean|) |#2| |#2|) $ $) "\\spad{merge!(p,u,v)} destructively merges \\spad{u} and \\spad{v} using predicate \\spad{p.}")) (|insert!| (($ $ $ (|Integer|)) "\\spad{insert!(v,u,i)} destructively inserts aggregate \\spad{v} into \\spad{u} at position i.") (($ |#2| $ (|Integer|)) "\\spad{insert!(x,u,i)} destructively inserts \\spad{x} into \\spad{u} at position i.")) (|remove!| (($ |#2| $) "\\spad{remove!(x,u)} destructively removes all values \\spad{x} from u.") (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{remove!(p,u)} destructively removes all elements \\spad{x} of \\spad{u} such that \\axiom{p(x)} is true.")) (|delete!| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{delete!(u,i..j)} destructively deletes elements u.i through u.j.") (($ $ (|Integer|)) "\\indented{1}{delete!(u,i) destructively deletes the \\axiom{i}th element of u.} \\blankline \\spad{E} Data:=Record(age:Integer,gender:String) \\spad{E} a1:AssociationList(String,Data):=table() \\spad{E} a1.\"tim\":=[55,\"male\"]$Data \\spad{E} delete!(a1,1)")) (|concat!| (($ $ $) "\\spad{concat!(u,v)} destructively appends \\spad{v} to the end of u. \\spad{v} is unchanged") (($ $ |#2|) "\\spad{concat!(u,x)} destructively adds element \\spad{x} to the end of u."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098)))) 
-(-279 S) 
+((|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119)))) 
+(-299 S) 
 ((|constructor| (NIL "An extensible aggregate is one which allows insertion and deletion of entries. These aggregates are models of lists and streams which are represented by linked structures so as to make insertion, deletion, and concatenation efficient. However, access to elements of these extensible aggregates is generally slow since access is made from the end. See \\spadtype{FlexibleArray} for an exception.")) (|removeDuplicates!| (($ $) "\\spad{removeDuplicates!(u)} destructively removes duplicates from u.")) (|select!| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{select!(p,u)} destructively changes \\spad{u} by keeping only values \\spad{x} such that \\axiom{p(x)}.")) (|merge!| (($ $ $) "\\spad{merge!(u,v)} destructively merges \\spad{u} and \\spad{v} in ascending order.") (($ (|Mapping| (|Boolean|) |#1| |#1|) $ $) "\\spad{merge!(p,u,v)} destructively merges \\spad{u} and \\spad{v} using predicate \\spad{p.}")) (|insert!| (($ $ $ (|Integer|)) "\\spad{insert!(v,u,i)} destructively inserts aggregate \\spad{v} into \\spad{u} at position i.") (($ |#1| $ (|Integer|)) "\\spad{insert!(x,u,i)} destructively inserts \\spad{x} into \\spad{u} at position i.")) (|remove!| (($ |#1| $) "\\spad{remove!(x,u)} destructively removes all values \\spad{x} from u.") (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{remove!(p,u)} destructively removes all elements \\spad{x} of \\spad{u} such that \\axiom{p(x)} is true.")) (|delete!| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{delete!(u,i..j)} destructively deletes elements u.i through u.j.") (($ $ (|Integer|)) "\\indented{1}{delete!(u,i) destructively deletes the \\axiom{i}th element of u.} \\blankline \\spad{E} Data:=Record(age:Integer,gender:String) \\spad{E} a1:AssociationList(String,Data):=table() \\spad{E} a1.\"tim\":=[55,\"male\"]$Data \\spad{E} delete!(a1,1)")) (|concat!| (($ $ $) "\\spad{concat!(u,v)} destructively appends \\spad{v} to the end of u. \\spad{v} is unchanged") (($ $ |#1|) "\\spad{concat!(u,x)} destructively adds element \\spad{x} to the end of u."))) 
-((-4603 . T) (-3389 . T)) 
+((-4626 . T) (-2623 . T)) 
 NIL 
-(-280 S) 
+(-300 S) 
 ((|constructor| (NIL "Category for the elementary functions.")) (** (($ $ $) "\\spad{x**y} returns \\spad{x} to the power \\spad{y.}")) (|exp| (($ $) "\\spad{exp(x)} returns \\%e to the power \\spad{x.}")) (|log| (($ $) "\\spad{log(x)} returns the natural logarithm of \\spad{x.}"))) 
 NIL 
 NIL 
-(-281) 
+(-301) 
 ((|constructor| (NIL "Category for the elementary functions.")) (** (($ $ $) "\\spad{x**y} returns \\spad{x} to the power \\spad{y.}")) (|exp| (($ $) "\\spad{exp(x)} returns \\%e to the power \\spad{x.}")) (|log| (($ $) "\\spad{log(x)} returns the natural logarithm of \\spad{x.}"))) 
 NIL 
 NIL 
-(-282 |Coef| UTS) 
+(-302 |Coef| UTS) 
 ((|constructor| (NIL "The elliptic functions \\spad{sn,} \\spad{sc} and \\spad{dn} are expanded as Taylor series.")) (|sncndn| (((|List| (|Stream| |#1|)) (|Stream| |#1|) |#1|) "\\spad{sncndn(s,c)} is used internally.")) (|dn| ((|#2| |#2| |#1|) "\\spad{dn(x,k)} expands the elliptic function \\spad{dn} as a Taylor \\indented{1}{series.}")) (|cn| ((|#2| |#2| |#1|) "\\spad{cn(x,k)} expands the elliptic function \\spad{cn} as a Taylor \\indented{1}{series.}")) (|sn| ((|#2| |#2| |#1|) "\\spad{sn(x,k)} expands the elliptic function \\spad{sn} as a Taylor \\indented{1}{series.}"))) 
 NIL 
 NIL 
-(-283 S |Index|) 
+(-303 S |Index|) 
 ((|constructor| (NIL "An eltable over domains \\spad{D} and \\spad{I} is a structure which can be viewed as a function from \\spad{D} to I. Examples of eltable structures range from data structures, For example, those of type List, to algebraic structures like Polynomial.")) (|elt| ((|#2| $ |#1|) "\\spad{elt(u,i)} (also written: \\spad{u} . i) returns the element of \\spad{u} indexed by i. Error: if \\spad{i} is not an index of u."))) 
 NIL 
 NIL 
-(-284 S |Dom| |Im|) 
+(-304 S |Dom| |Im|) 
 ((|constructor| (NIL "An eltable aggregate is one which can be viewed as a function. For example, the list [1,7,4] can applied to 0,1, and 2 respectively will return the integers 1, 7, and 4; thus this list may be viewed as mapping 0 to 1, 1 to 7 and 2 to 4. In general, an aggregate can map members of a domain Dom to an image domain Im.")) (|qsetelt!| ((|#3| $ |#2| |#3|) "\\spad{qsetelt!(u,x,y)} sets the image of \\axiom{x} to be \\axiom{y} under \\axiom{u}, without checking that \\axiom{x} is in the domain of \\axiom{u}. If such a check is required use the function \\axiom{setelt}.")) (|setelt| ((|#3| $ |#2| |#3|) "\\spad{setelt(u,x,y)} sets the image of \\spad{x} to be \\spad{y} under u, assuming \\spad{x} is in the domain of u. Error: if \\spad{x} is not in the domain of u.")) (|qelt| ((|#3| $ |#2|) "\\spad{qelt(u, \\spad{x)}} applies \\axiom{u} to \\axiom{x} without checking whether \\axiom{x} is in the domain of \\axiom{u}. If \\axiom{x} is not in the domain of \\axiom{u} a memory-access violation may occur. If a check on whether \\axiom{x} is in the domain of \\axiom{u} is required, use the function \\axiom{elt}.")) (|elt| ((|#3| $ |#2| |#3|) "\\spad{elt(u, \\spad{x,} \\spad{y)}} applies \\spad{u} to \\spad{x} if \\spad{x} is in the domain of u, and returns \\spad{y} otherwise. For example, if \\spad{u} is a polynomial in \\axiom{x} over the rationals, \\axiom{elt(u,n,0)} may define the coefficient of \\axiom{x} to the power \\spad{n,} returning 0 when \\spad{n} is out of range."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4603))) 
-(-285 |Dom| |Im|) 
+((|HasAttribute| |#1| (QUOTE -4626))) 
+(-305 |Dom| |Im|) 
 ((|constructor| (NIL "An eltable aggregate is one which can be viewed as a function. For example, the list [1,7,4] can applied to 0,1, and 2 respectively will return the integers 1, 7, and 4; thus this list may be viewed as mapping 0 to 1, 1 to 7 and 2 to 4. In general, an aggregate can map members of a domain Dom to an image domain Im.")) (|qsetelt!| ((|#2| $ |#1| |#2|) "\\spad{qsetelt!(u,x,y)} sets the image of \\axiom{x} to be \\axiom{y} under \\axiom{u}, without checking that \\axiom{x} is in the domain of \\axiom{u}. If such a check is required use the function \\axiom{setelt}.")) (|setelt| ((|#2| $ |#1| |#2|) "\\spad{setelt(u,x,y)} sets the image of \\spad{x} to be \\spad{y} under u, assuming \\spad{x} is in the domain of u. Error: if \\spad{x} is not in the domain of u.")) (|qelt| ((|#2| $ |#1|) "\\spad{qelt(u, \\spad{x)}} applies \\axiom{u} to \\axiom{x} without checking whether \\axiom{x} is in the domain of \\axiom{u}. If \\axiom{x} is not in the domain of \\axiom{u} a memory-access violation may occur. If a check on whether \\axiom{x} is in the domain of \\axiom{u} is required, use the function \\axiom{elt}.")) (|elt| ((|#2| $ |#1| |#2|) "\\spad{elt(u, \\spad{x,} \\spad{y)}} applies \\spad{u} to \\spad{x} if \\spad{x} is in the domain of u, and returns \\spad{y} otherwise. For example, if \\spad{u} is a polynomial in \\axiom{x} over the rationals, \\axiom{elt(u,n,0)} may define the coefficient of \\axiom{x} to the power \\spad{n,} returning 0 when \\spad{n} is out of range."))) 
 NIL 
 NIL 
-(-286 S R |Mod| -4007 -4475 |exactQuo|) 
+(-306 S R |Mod| -3674 -4491 |exactQuo|) 
 ((|constructor| (NIL "These domains are used for the factorization and gcds of univariate polynomials over the integers in order to work modulo different primes. See \\spadtype{ModularRing}, \\spadtype{ModularField}")) (|elt| ((|#2| $ |#2|) "\\spad{elt(x,r)} or \\spad{x.r} is not documented")) (|inv| (($ $) "\\spad{inv(x)} is not documented")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} is not documented")) (|exQuo| (((|Union| $ "failed") $ $) "\\spad{exQuo(x,y)} is not documented")) (|reduce| (($ |#2| |#3|) "\\spad{reduce(r,m)} is not documented")) (|coerce| ((|#2| $) "\\spad{coerce(x)} is not documented")) (|modulus| ((|#3| $) "\\spad{modulus(x)} is not documented"))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-287) 
+(-307) 
 ((|constructor| (NIL "Entire Rings (non-commutative Integral Domains), \\spadignore{i.e.} a ring not necessarily commutative which has no zero divisors. \\blankline Axioms\\br \\tab{5}\\spad{ab=0 \\spad{=>} \\spad{a=0} or b=0} \\spad{--} known as noZeroDivisors\\br \\tab{5}\\spad{not(1=0)}")) (|noZeroDivisors| ((|attribute|) "if a product is zero then one of the factors must be zero."))) 
-((-4595 . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-288 R) 
+(-308 R) 
 ((|constructor| (NIL "This is a package for the exact computation of eigenvalues and eigenvectors. This package can be made to work for matrices with coefficients which are rational functions over a ring where we can factor polynomials. Rational eigenvalues are always explicitly computed while the non-rational ones are expressed in terms of their minimal polynomial.")) (|eigenvectors| (((|List| (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|)))) (|:| |eigmult| (|NonNegativeInteger|)) (|:| |eigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| |#1|))))))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{eigenvectors(m)} returns the eigenvalues and eigenvectors for the matrix \\spad{m.} The rational eigenvalues and the correspondent eigenvectors are explicitely computed, while the non rational ones are given via their minimal polynomial and the corresponding eigenvectors are expressed in terms of a \"generic\" root of such a polynomial.")) (|generalizedEigenvectors| (((|List| (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|)))) (|:| |geneigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| |#1|))))))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{generalizedEigenvectors(m)} returns the generalized eigenvectors of the matrix \\spad{m.}")) (|generalizedEigenvector| (((|List| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|)))) (|:| |eigmult| (|NonNegativeInteger|)) (|:| |eigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| |#1|)))))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{generalizedEigenvector(eigen,m)} returns the generalized eigenvectors of the matrix relative to the eigenvalue eigen, as returned by the function eigenvectors.") (((|List| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|))) (|Matrix| (|Fraction| (|Polynomial| |#1|))) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{generalizedEigenvector(alpha,m,k,g)} returns the generalized eigenvectors of the matrix relative to the eigenvalue alpha. The integers \\spad{k} and \\spad{g} are respectively the algebraic and the geometric multiplicity of tye eigenvalue alpha. \\spad{alpha} can be either rational or not. In the seconda case apha is the minimal polynomial of the eigenvalue.")) (|eigenvector| (((|List| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{eigenvector(eigval,m)} returns the eigenvectors belonging to the eigenvalue \\spad{eigval} for the matrix \\spad{m.}")) (|eigenvalues| (((|List| (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|)))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{eigenvalues(m)} returns the eigenvalues of the matrix \\spad{m} which are expressible as rational functions over the rational numbers.")) (|characteristicPolynomial| (((|Polynomial| |#1|) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{characteristicPolynomial(m)} returns the characteristicPolynomial of the matrix \\spad{m} using a new generated symbol symbol as the main variable.") (((|Polynomial| |#1|) (|Matrix| (|Fraction| (|Polynomial| |#1|))) (|Symbol|)) "\\spad{characteristicPolynomial(m,var)} returns the characteristicPolynomial of the matrix \\spad{m} using the symbol \\spad{var} as the main variable."))) 
 NIL 
 NIL 
-(-289 S R) 
+(-309 S R) 
 ((|constructor| (NIL "This package provides operations for mapping the sides of equations.")) (|map| (((|Equation| |#2|) (|Mapping| |#2| |#1|) (|Equation| |#1|)) "\\spad{map(f,eq)} returns an equation where \\spad{f} is applied to the sides of \\spad{eq}"))) 
 NIL 
 NIL 
-(-290 S) 
+(-310 S) 
 ((|constructor| (NIL "Equations as mathematical objects. All properties of the basis domain, \\spadignore{e.g.} being an abelian group are carried over the equation domain, by performing the structural operations on the left and on the right hand side.")) (|subst| (($ $ $) "\\spad{subst(eq1,eq2)} substitutes \\spad{eq2} into both sides of \\spad{eq1} the \\spad{lhs} of \\spad{eq2} should be a kernel")) (|inv| (($ $) "\\spad{inv(x)} returns the multiplicative inverse of \\spad{x.}")) (/ (($ $ $) "\\spad{e1/e2} produces a new equation by dividing the left and right hand sides of equations \\spad{e1} and e2.")) (|factorAndSplit| (((|List| $) $) "\\spad{factorAndSplit(eq)} make the right hand side 0 and factors the new left hand side. Each factor is equated to 0 and put into the resulting list without repetitions.")) (|rightOne| (((|Union| $ "failed") $) "\\spad{rightOne(eq)} divides by the right hand side.") (((|Union| $ "failed") $) "\\spad{rightOne(eq)} divides by the right hand side, if possible.")) (|leftOne| (((|Union| $ "failed") $) "\\spad{leftOne(eq)} divides by the left hand side.") (((|Union| $ "failed") $) "\\spad{leftOne(eq)} divides by the left hand side, if possible.")) (* (($ $ |#1|) "\\spad{eqn*x} produces a new equation by multiplying both sides of equation eqn by \\spad{x.}") (($ |#1| $) "\\spad{x*eqn} produces a new equation by multiplying both sides of equation eqn by \\spad{x.}")) (- (($ $ |#1|) "\\spad{eqn-x} produces a new equation by subtracting \\spad{x} from both sides of equation eqn.") (($ |#1| $) "\\spad{x-eqn} produces a new equation by subtracting both sides of equation eqn from \\spad{x.}")) (|rightZero| (($ $) "\\spad{rightZero(eq)} subtracts the right hand side.")) (|leftZero| (($ $) "\\spad{leftZero(eq)} subtracts the left hand side.")) (+ (($ $ |#1|) "\\spad{eqn+x} produces a new equation by adding \\spad{x} to both sides of equation eqn.") (($ |#1| $) "\\spad{x+eqn} produces a new equation by adding \\spad{x} to both sides of equation eqn.")) (|eval| (($ $ (|List| $)) "\\spad{eval(eqn, [x1=v1, \\spad{...} xn=vn])} replaces \\spad{xi} by \\spad{vi} in equation eqn.") (($ $ $) "\\spad{eval(eqn, x=f)} replaces \\spad{x} by \\spad{f} in equation eqn.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f,eqn)} constructs a new equation by applying \\spad{f} to both sides of eqn.")) (|rhs| ((|#1| $) "\\spad{rhs(eqn)} returns the right hand side of equation eqn.")) (|lhs| ((|#1| $) "\\spad{lhs(eqn)} returns the left hand side of equation eqn.")) (|swap| (($ $) "\\spad{swap(eq)} interchanges left and right hand side of equation eq.")) (|equation| (($ |#1| |#1|) "\\spad{equation(a,b)} creates an equation.")) (= (($ |#1| |#1|) "\\spad{a=b} creates an equation."))) 
-((-4599 -1841 (|has| |#1| (-1054)) (|has| |#1| (-482))) (-4596 |has| |#1| (-1054)) (-4597 |has| |#1| (-1054))) 
-((|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (QUOTE (-1054))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-1054)))) (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-298))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-482)))) (-1841 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (QUOTE (-1054)))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-1054)))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-722))) (-1841 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (QUOTE (-722)))) (|HasCategory| |#1| (QUOTE (-1110))) (-1841 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (QUOTE (-722))) (|HasCategory| |#1| (QUOTE (-1110)))) (|HasCategory| |#1| (QUOTE (-21))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-1054)))) (-1841 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-722)))) (|HasCategory| |#1| (QUOTE (-25))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-1054)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (QUOTE (-722))) (|HasCategory| |#1| (QUOTE (-1054))) (|HasCategory| |#1| (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-291 |Key| |Entry|) 
+((-4622 -3836 (|has| |#1| (-1075)) (|has| |#1| (-502))) (-4619 |has| |#1| (-1075)) (-4620 |has| |#1| (-1075))) 
+((|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (QUOTE (-1075))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-1075)))) (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-318))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-502)))) (-3836 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (QUOTE (-1075)))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-1075)))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-743))) (-3836 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (QUOTE (-743)))) (|HasCategory| |#1| (QUOTE (-1131))) (-3836 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (QUOTE (-743))) (|HasCategory| |#1| (QUOTE (-1131)))) (|HasCategory| |#1| (QUOTE (-21))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-1075)))) (-3836 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-743)))) (|HasCategory| |#1| (QUOTE (-25))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-1075)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (QUOTE (-743))) (|HasCategory| |#1| (QUOTE (-1075))) (|HasCategory| |#1| (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-311 |Key| |Entry|) 
 ((|constructor| (NIL "This domain provides tables where the keys are compared using \\spadfun{eq?}. Thus keys are considered equal only if they are the same instance of a structure."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098))) (-1841 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-1098)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098))))) 
-(-292) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119))) (-3836 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-1119)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119))))) 
+(-312) 
 ((|constructor| (NIL "ErrorFunctions implements error functions callable from the system interpreter. Typically, these functions would be called in user functions. The simple forms of the functions take one argument which is either a string (an error message) or a list of strings which all together make up a message. The list can contain formatting codes (see below). The more sophisticated versions takes two arguments where the first argument is the name of the function from which the error was invoked and the second argument is either a string or a list of strings, as above. When you use the one argument version in an interpreter function, the system will automatically insert the name of the function as the new first argument. Thus in the user interpreter function\\br \\tab{5}\\spad{f \\spad{x} \\spad{==} if \\spad{x} < 0 then error \"negative argument\" else x}\\br the call to error will actually be of the form\\br \\tab{5}\\spad{error(\"f\",\"negative argument\")}\\br because the interpreter will have created a new first argument. \\blankline Formatting codes: error messages may contain the following formatting codes (they should either start or end a string or else have blanks around them):\\br \\spad{\\%l}\\tab{6}start a new line\\br \\spad{\\%b}\\tab{6}start printing in a bold font (where available)\\br \\spad{\\%d}\\tab{6}stop printing in a bold font (where available)\\br \\spad{\\%ceon}\\tab{3}start centering message lines\\br \\spad{\\%ceoff}\\tab{2}stop centering message lines\\br \\spad{\\%rjon}\\tab{3}start displaying lines \"ragged left\"\\br \\spad{\\%rjoff}\\tab{2}stop displaying lines \"ragged left\"\\br \\spad{\\%i}\\tab{6}indent following lines 3 additional spaces\\br \\spad{\\%u}\\tab{6}unindent following lines 3 additional spaces\\br \\spad{\\%xN}\\tab{5}insert \\spad{N} blanks (eg, \\spad{\\%x10} inserts 10 blanks) \\blankline")) (|error| (((|Exit|) (|String|) (|List| (|String|))) "\\spad{error(nam,lmsg)} displays error messages \\spad{lmsg} preceded by a message containing the name \\spad{nam} of the function in which the error is contained.") (((|Exit|) (|String|) (|String|)) "\\spad{error(nam,msg)} displays error message \\spad{msg} preceded by a message containing the name \\spad{nam} of the function in which the error is contained.") (((|Exit|) (|List| (|String|))) "\\spad{error(lmsg)} displays error message \\spad{lmsg} and terminates.") (((|Exit|) (|String|)) "\\spad{error(msg)} displays error message \\spad{msg} and terminates."))) 
 NIL 
 NIL 
-(-293 -3313 S) 
+(-313 -3958 S) 
 ((|constructor| (NIL "This package allows a map from any expression space into any object to be lifted to a kernel over the expression set, using a given property of the operator of the kernel.")) (|map| ((|#2| (|Mapping| |#2| |#1|) (|String|) (|Kernel| |#1|)) "\\spad{map(f, \\spad{p,} \\spad{k)}} uses the property \\spad{p} of the operator of \\spad{k,} in order to lift \\spad{f} and apply it to \\spad{k.}"))) 
 NIL 
 NIL 
-(-294 E -3313) 
+(-314 E -3958) 
 ((|constructor| (NIL "This package allows a mapping \\spad{E} \\spad{->} \\spad{F} to be lifted to a kernel over E; This lifting can fail if the operator of the kernel cannot be applied in \\spad{F;} Do not use this package with \\spad{E} = \\spad{F,} since this may drop some properties of the operators.")) (|map| ((|#2| (|Mapping| |#2| |#1|) (|Kernel| |#1|)) "\\spad{map(f, \\spad{k)}} returns \\spad{g = op(f(a1),...,f(an))} where \\spad{k = op(a1,...,an)}."))) 
 NIL 
 NIL 
-(-295 A B) 
+(-315 A B) 
 ((|constructor| (NIL "\\spad{ExpertSystemContinuityPackage1} exports a function to check range inclusion")) (|in?| (((|Boolean|) (|DoubleFloat|)) "\\spad{in?(p)} tests whether point \\spad{p} is internal to the range [\\spad{A..B}]"))) 
 NIL 
 NIL 
-(-296) 
+(-316) 
 ((|constructor| (NIL "ExpertSystemContinuityPackage is a package of functions for the use of domains belonging to the category \\axiomType{NumericalIntegration}.")) (|sdf2lst| (((|List| (|String|)) (|Stream| (|DoubleFloat|))) "\\spad{sdf2lst(ln)} coerces a Stream of \\axiomType{DoubleFloat} to \\axiomType{List}(\\axiomType{String})")) (|ldf2lst| (((|List| (|String|)) (|List| (|DoubleFloat|))) "\\spad{ldf2lst(ln)} coerces a List of \\axiomType{DoubleFloat} to \\axiomType{List}(\\axiomType{String})")) (|df2st| (((|String|) (|DoubleFloat|)) "\\spad{df2st(n)} coerces a \\axiomType{DoubleFloat} to \\axiomType{String}")) (|polynomialZeros| (((|List| (|DoubleFloat|)) (|Polynomial| (|Fraction| (|Integer|))) (|Symbol|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{polynomialZeros(fn,var,range)} calculates the real zeros of the polynomial which are contained in the given interval. It returns a list of points (\\axiomType{Doublefloat}) for which the univariate polynomial \\spad{fn} is zero.")) (|singularitiesOf| (((|Stream| (|DoubleFloat|)) (|Vector| (|Expression| (|DoubleFloat|))) (|List| (|Symbol|)) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{singularitiesOf(v,vars,range)} returns a list of points (\\axiomType{Doublefloat}) at which a NAG fortran version of \\spad{v} will most likely produce an error. This includes those points which evaluate to 0/0.") (((|Stream| (|DoubleFloat|)) (|Expression| (|DoubleFloat|)) (|List| (|Symbol|)) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{singularitiesOf(e,vars,range)} returns a list of points (\\axiomType{Doublefloat}) at which a NAG fortran version of \\spad{e} will most likely produce an error. This includes those points which evaluate to 0/0.")) (|zerosOf| (((|Stream| (|DoubleFloat|)) (|Expression| (|DoubleFloat|)) (|List| (|Symbol|)) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{zerosOf(e,vars,range)} returns a list of points (\\axiomType{Doublefloat}) at which a NAG fortran version of \\spad{e} will most likely produce an error.")) (|problemPoints| (((|List| (|DoubleFloat|)) (|Expression| (|DoubleFloat|)) (|Symbol|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{problemPoints(f,var,range)} returns a list of possible problem points by looking at the zeros of the denominator of the function \\spad{f} if it can be retracted to \\axiomType{Polynomial(DoubleFloat)}.")) (|functionIsFracPolynomial?| (((|Boolean|) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{functionIsFracPolynomial?(args)} tests whether the function can be retracted to \\axiomType{Fraction(Polynomial(DoubleFloat))}")) (|gethi| (((|DoubleFloat|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{gethi(u)} gets the \\axiomType{DoubleFloat} equivalent of the second endpoint of the range \\axiom{u}")) (|getlo| (((|DoubleFloat|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{getlo(u)} gets the \\axiomType{DoubleFloat} equivalent of the first endpoint of the range \\axiom{u}"))) 
 NIL 
 NIL 
-(-297 S) 
+(-317 S) 
 ((|constructor| (NIL "An expression space is a set which is closed under certain operators.")) (|odd?| (((|Boolean|) $) "\\spad{odd? \\spad{x}} is \\spad{true} if \\spad{x} is an odd integer.")) (|even?| (((|Boolean|) $) "\\spad{even? \\spad{x}} is \\spad{true} if \\spad{x} is an even integer.")) (|definingPolynomial| (($ $) "\\spad{definingPolynomial(x)} returns an expression \\spad{p} such that \\spad{p(x) = 0}.")) (|minPoly| (((|SparseUnivariatePolynomial| $) (|Kernel| $)) "\\spad{minPoly(k)} returns \\spad{p} such that \\spad{p(k) = 0}.")) (|eval| (($ $ (|BasicOperator|) (|Mapping| $ $)) "\\spad{eval(x, \\spad{s,} \\spad{f)}} replaces every \\spad{s(a)} in \\spad{x} by \\spad{f(a)} for any \\spad{a}.") (($ $ (|BasicOperator|) (|Mapping| $ (|List| $))) "\\spad{eval(x, \\spad{s,} \\spad{f)}} replaces every \\spad{s(a1,..,am)} in \\spad{x} by \\spad{f(a1,..,am)} for any \\spad{a1},...,\\spad{am}.") (($ $ (|List| (|BasicOperator|)) (|List| (|Mapping| $ (|List| $)))) "\\spad{eval(x, [s1,...,sm], [f1,...,fm])} replaces every \\spad{si(a1,...,an)} in \\spad{x} by \\spad{fi(a1,...,an)} for any \\spad{a1},...,\\spad{an}.") (($ $ (|List| (|BasicOperator|)) (|List| (|Mapping| $ $))) "\\spad{eval(x, [s1,...,sm], [f1,...,fm])} replaces every \\spad{si(a)} in \\spad{x} by \\spad{fi(a)} for any \\spad{a}.") (($ $ (|Symbol|) (|Mapping| $ $)) "\\spad{eval(x, \\spad{s,} \\spad{f)}} replaces every \\spad{s(a)} in \\spad{x} by \\spad{f(a)} for any \\spad{a}.") (($ $ (|Symbol|) (|Mapping| $ (|List| $))) "\\spad{eval(x, \\spad{s,} \\spad{f)}} replaces every \\spad{s(a1,..,am)} in \\spad{x} by \\spad{f(a1,..,am)} for any \\spad{a1},...,\\spad{am}.") (($ $ (|List| (|Symbol|)) (|List| (|Mapping| $ (|List| $)))) "\\spad{eval(x, [s1,...,sm], [f1,...,fm])} replaces every \\spad{si(a1,...,an)} in \\spad{x} by \\spad{fi(a1,...,an)} for any \\spad{a1},...,\\spad{an}.") (($ $ (|List| (|Symbol|)) (|List| (|Mapping| $ $))) "\\spad{eval(x, [s1,...,sm], [f1,...,fm])} replaces every \\spad{si(a)} in \\spad{x} by \\spad{fi(a)} for any \\spad{a}.")) (|freeOf?| (((|Boolean|) $ (|Symbol|)) "\\spad{freeOf?(x, \\spad{s)}} tests if \\spad{x} does not contain any operator whose name is \\spad{s.}") (((|Boolean|) $ $) "\\spad{freeOf?(x, \\spad{y)}} tests if \\spad{x} does not contain any occurrence of \\spad{y,} where \\spad{y} is a single kernel.")) (|map| (($ (|Mapping| $ $) (|Kernel| $)) "\\spad{map(f, \\spad{k)}} returns \\spad{op(f(x1),...,f(xn))} where \\spad{k = op(x1,...,xn)}.")) (|kernel| (($ (|BasicOperator|) (|List| $)) "\\spad{kernel(op, [f1,...,fn])} constructs \\spad{op(f1,...,fn)} without evaluating it.") (($ (|BasicOperator|) $) "\\spad{kernel(op, \\spad{x)}} constructs op(x) without evaluating it.")) (|is?| (((|Boolean|) $ (|Symbol|)) "\\spad{is?(x, \\spad{s)}} tests if \\spad{x} is a kernel and is the name of its operator is \\spad{s.}") (((|Boolean|) $ (|BasicOperator|)) "\\spad{is?(x, op)} tests if \\spad{x} is a kernel and is its operator is op.")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} tests if \\% accepts \\spad{op} as applicable to its elements.")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns a copy of \\spad{op} with the domain-dependent properties appropriate for \\spad{%.}")) (|operators| (((|List| (|BasicOperator|)) $) "\\spad{operators(f)} returns all the basic operators appearing in \\spad{f,} no matter what their levels are.")) (|tower| (((|List| (|Kernel| $)) $) "\\spad{tower(f)} returns all the kernels appearing in \\spad{f,} no matter what their levels are.")) (|kernels| (((|List| (|Kernel| $)) $) "\\spad{kernels(f)} returns the list of all the top-level kernels appearing in \\spad{f,} but not the ones appearing in the arguments of the top-level kernels.")) (|mainKernel| (((|Union| (|Kernel| $) "failed") $) "\\spad{mainKernel(f)} returns a kernel of \\spad{f} with maximum nesting level, or if \\spad{f} has no kernels (\\spadignore{i.e.} \\spad{f} is a constant).")) (|height| (((|NonNegativeInteger|) $) "\\spad{height(f)} returns the highest nesting level appearing in \\spad{f.} Constants have height 0. Symbols have height 1. For any operator op and expressions f1,...,fn, \\spad{op(f1,...,fn)} has height equal to \\spad{1 + max(height(f1),...,height(fn))}.")) (|distribute| (($ $ $) "\\spad{distribute(f, \\spad{g)}} expands all the kernels in \\spad{f} that contain \\spad{g} in their arguments and that are formally enclosed by a \\spadfunFrom{box}{ExpressionSpace} or a \\spadfunFrom{paren}{ExpressionSpace} expression.") (($ $) "\\spad{distribute(f)} expands all the kernels in \\spad{f} that are formally enclosed by a \\spadfunFrom{box}{ExpressionSpace} or \\spadfunFrom{paren}{ExpressionSpace} expression.")) (|paren| (($ (|List| $)) "\\spad{paren([f1,...,fn])} returns \\spad{(f1,...,fn)}. This prevents the \\spad{fi} from being evaluated when operators are applied to them, and makes them applicable to a unary operator. For example, \\spad{atan(paren \\spad{[x,} 2])} returns the formal kernel \\spad{atan((x, 2))}.") (($ $) "\\spad{paren(f)} returns (f). This prevents \\spad{f} from being evaluated when operators are applied to it. For example, \\spad{log(1)} returns 0, but \\spad{log(paren 1)} returns the formal kernel log((1)).")) (|box| (($ (|List| $)) "\\spad{box([f1,...,fn])} returns \\spad{(f1,...,fn)} with a 'box' around them that prevents the \\spad{fi} from being evaluated when operators are applied to them, and makes them applicable to a unary operator. For example, \\spad{atan(box \\spad{[x,} 2])} returns the formal kernel \\spad{atan(x, 2)}.") (($ $) "\\spad{box(f)} returns \\spad{f} with a 'box' around it that prevents \\spad{f} from being evaluated when operators are applied to it. For example, \\spad{log(1)} returns 0, but \\spad{log(box 1)} returns the formal kernel log(1).")) (|subst| (($ $ (|List| (|Kernel| $)) (|List| $)) "\\spad{subst(f, [k1...,kn], [g1,...,gn])} replaces the kernels k1,...,kn by g1,...,gn formally in \\spad{f.}") (($ $ (|List| (|Equation| $))) "\\spad{subst(f, \\spad{[k1} = g1,...,kn = gn])} replaces the kernels k1,...,kn by g1,...,gn formally in \\spad{f.}") (($ $ (|Equation| $)) "\\spad{subst(f, \\spad{k} = \\spad{g)}} replaces the kernel \\spad{k} by \\spad{g} formally in \\spad{f.}")) (|elt| (($ (|BasicOperator|) (|List| $)) "\\spad{elt(op,[x1,...,xn])} or op([x1,...,xn]) applies the n-ary operator \\spad{op} to x1,...,xn.") (($ (|BasicOperator|) $ $ $ $) "\\spad{elt(op,x,y,z,t)} or op(x, \\spad{y,} \\spad{z,} \\spad{t)} applies the 4-ary operator \\spad{op} to \\spad{x,} \\spad{y,} \\spad{z} and \\spad{t.}") (($ (|BasicOperator|) $ $ $) "\\spad{elt(op,x,y,z)} or op(x, \\spad{y,} \\spad{z)} applies the ternary operator \\spad{op} to \\spad{x,} \\spad{y} and \\spad{z.}") (($ (|BasicOperator|) $ $) "\\spad{elt(op,x,y)} or op(x, \\spad{y)} applies the binary operator \\spad{op} to \\spad{x} and \\spad{y.}") (($ (|BasicOperator|) $) "\\spad{elt(op,x)} or op(x) applies the unary operator \\spad{op} to \\spad{x.}"))) 
 NIL 
-((|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-1054)))) 
-(-298) 
+((|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-1075)))) 
+(-318) 
 ((|constructor| (NIL "An expression space is a set which is closed under certain operators.")) (|odd?| (((|Boolean|) $) "\\spad{odd? \\spad{x}} is \\spad{true} if \\spad{x} is an odd integer.")) (|even?| (((|Boolean|) $) "\\spad{even? \\spad{x}} is \\spad{true} if \\spad{x} is an even integer.")) (|definingPolynomial| (($ $) "\\spad{definingPolynomial(x)} returns an expression \\spad{p} such that \\spad{p(x) = 0}.")) (|minPoly| (((|SparseUnivariatePolynomial| $) (|Kernel| $)) "\\spad{minPoly(k)} returns \\spad{p} such that \\spad{p(k) = 0}.")) (|eval| (($ $ (|BasicOperator|) (|Mapping| $ $)) "\\spad{eval(x, \\spad{s,} \\spad{f)}} replaces every \\spad{s(a)} in \\spad{x} by \\spad{f(a)} for any \\spad{a}.") (($ $ (|BasicOperator|) (|Mapping| $ (|List| $))) "\\spad{eval(x, \\spad{s,} \\spad{f)}} replaces every \\spad{s(a1,..,am)} in \\spad{x} by \\spad{f(a1,..,am)} for any \\spad{a1},...,\\spad{am}.") (($ $ (|List| (|BasicOperator|)) (|List| (|Mapping| $ (|List| $)))) "\\spad{eval(x, [s1,...,sm], [f1,...,fm])} replaces every \\spad{si(a1,...,an)} in \\spad{x} by \\spad{fi(a1,...,an)} for any \\spad{a1},...,\\spad{an}.") (($ $ (|List| (|BasicOperator|)) (|List| (|Mapping| $ $))) "\\spad{eval(x, [s1,...,sm], [f1,...,fm])} replaces every \\spad{si(a)} in \\spad{x} by \\spad{fi(a)} for any \\spad{a}.") (($ $ (|Symbol|) (|Mapping| $ $)) "\\spad{eval(x, \\spad{s,} \\spad{f)}} replaces every \\spad{s(a)} in \\spad{x} by \\spad{f(a)} for any \\spad{a}.") (($ $ (|Symbol|) (|Mapping| $ (|List| $))) "\\spad{eval(x, \\spad{s,} \\spad{f)}} replaces every \\spad{s(a1,..,am)} in \\spad{x} by \\spad{f(a1,..,am)} for any \\spad{a1},...,\\spad{am}.") (($ $ (|List| (|Symbol|)) (|List| (|Mapping| $ (|List| $)))) "\\spad{eval(x, [s1,...,sm], [f1,...,fm])} replaces every \\spad{si(a1,...,an)} in \\spad{x} by \\spad{fi(a1,...,an)} for any \\spad{a1},...,\\spad{an}.") (($ $ (|List| (|Symbol|)) (|List| (|Mapping| $ $))) "\\spad{eval(x, [s1,...,sm], [f1,...,fm])} replaces every \\spad{si(a)} in \\spad{x} by \\spad{fi(a)} for any \\spad{a}.")) (|freeOf?| (((|Boolean|) $ (|Symbol|)) "\\spad{freeOf?(x, \\spad{s)}} tests if \\spad{x} does not contain any operator whose name is \\spad{s.}") (((|Boolean|) $ $) "\\spad{freeOf?(x, \\spad{y)}} tests if \\spad{x} does not contain any occurrence of \\spad{y,} where \\spad{y} is a single kernel.")) (|map| (($ (|Mapping| $ $) (|Kernel| $)) "\\spad{map(f, \\spad{k)}} returns \\spad{op(f(x1),...,f(xn))} where \\spad{k = op(x1,...,xn)}.")) (|kernel| (($ (|BasicOperator|) (|List| $)) "\\spad{kernel(op, [f1,...,fn])} constructs \\spad{op(f1,...,fn)} without evaluating it.") (($ (|BasicOperator|) $) "\\spad{kernel(op, \\spad{x)}} constructs op(x) without evaluating it.")) (|is?| (((|Boolean|) $ (|Symbol|)) "\\spad{is?(x, \\spad{s)}} tests if \\spad{x} is a kernel and is the name of its operator is \\spad{s.}") (((|Boolean|) $ (|BasicOperator|)) "\\spad{is?(x, op)} tests if \\spad{x} is a kernel and is its operator is op.")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} tests if \\% accepts \\spad{op} as applicable to its elements.")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns a copy of \\spad{op} with the domain-dependent properties appropriate for \\spad{%.}")) (|operators| (((|List| (|BasicOperator|)) $) "\\spad{operators(f)} returns all the basic operators appearing in \\spad{f,} no matter what their levels are.")) (|tower| (((|List| (|Kernel| $)) $) "\\spad{tower(f)} returns all the kernels appearing in \\spad{f,} no matter what their levels are.")) (|kernels| (((|List| (|Kernel| $)) $) "\\spad{kernels(f)} returns the list of all the top-level kernels appearing in \\spad{f,} but not the ones appearing in the arguments of the top-level kernels.")) (|mainKernel| (((|Union| (|Kernel| $) "failed") $) "\\spad{mainKernel(f)} returns a kernel of \\spad{f} with maximum nesting level, or if \\spad{f} has no kernels (\\spadignore{i.e.} \\spad{f} is a constant).")) (|height| (((|NonNegativeInteger|) $) "\\spad{height(f)} returns the highest nesting level appearing in \\spad{f.} Constants have height 0. Symbols have height 1. For any operator op and expressions f1,...,fn, \\spad{op(f1,...,fn)} has height equal to \\spad{1 + max(height(f1),...,height(fn))}.")) (|distribute| (($ $ $) "\\spad{distribute(f, \\spad{g)}} expands all the kernels in \\spad{f} that contain \\spad{g} in their arguments and that are formally enclosed by a \\spadfunFrom{box}{ExpressionSpace} or a \\spadfunFrom{paren}{ExpressionSpace} expression.") (($ $) "\\spad{distribute(f)} expands all the kernels in \\spad{f} that are formally enclosed by a \\spadfunFrom{box}{ExpressionSpace} or \\spadfunFrom{paren}{ExpressionSpace} expression.")) (|paren| (($ (|List| $)) "\\spad{paren([f1,...,fn])} returns \\spad{(f1,...,fn)}. This prevents the \\spad{fi} from being evaluated when operators are applied to them, and makes them applicable to a unary operator. For example, \\spad{atan(paren \\spad{[x,} 2])} returns the formal kernel \\spad{atan((x, 2))}.") (($ $) "\\spad{paren(f)} returns (f). This prevents \\spad{f} from being evaluated when operators are applied to it. For example, \\spad{log(1)} returns 0, but \\spad{log(paren 1)} returns the formal kernel log((1)).")) (|box| (($ (|List| $)) "\\spad{box([f1,...,fn])} returns \\spad{(f1,...,fn)} with a 'box' around them that prevents the \\spad{fi} from being evaluated when operators are applied to them, and makes them applicable to a unary operator. For example, \\spad{atan(box \\spad{[x,} 2])} returns the formal kernel \\spad{atan(x, 2)}.") (($ $) "\\spad{box(f)} returns \\spad{f} with a 'box' around it that prevents \\spad{f} from being evaluated when operators are applied to it. For example, \\spad{log(1)} returns 0, but \\spad{log(box 1)} returns the formal kernel log(1).")) (|subst| (($ $ (|List| (|Kernel| $)) (|List| $)) "\\spad{subst(f, [k1...,kn], [g1,...,gn])} replaces the kernels k1,...,kn by g1,...,gn formally in \\spad{f.}") (($ $ (|List| (|Equation| $))) "\\spad{subst(f, \\spad{[k1} = g1,...,kn = gn])} replaces the kernels k1,...,kn by g1,...,gn formally in \\spad{f.}") (($ $ (|Equation| $)) "\\spad{subst(f, \\spad{k} = \\spad{g)}} replaces the kernel \\spad{k} by \\spad{g} formally in \\spad{f.}")) (|elt| (($ (|BasicOperator|) (|List| $)) "\\spad{elt(op,[x1,...,xn])} or op([x1,...,xn]) applies the n-ary operator \\spad{op} to x1,...,xn.") (($ (|BasicOperator|) $ $ $ $) "\\spad{elt(op,x,y,z,t)} or op(x, \\spad{y,} \\spad{z,} \\spad{t)} applies the 4-ary operator \\spad{op} to \\spad{x,} \\spad{y,} \\spad{z} and \\spad{t.}") (($ (|BasicOperator|) $ $ $) "\\spad{elt(op,x,y,z)} or op(x, \\spad{y,} \\spad{z)} applies the ternary operator \\spad{op} to \\spad{x,} \\spad{y} and \\spad{z.}") (($ (|BasicOperator|) $ $) "\\spad{elt(op,x,y)} or op(x, \\spad{y)} applies the binary operator \\spad{op} to \\spad{x} and \\spad{y.}") (($ (|BasicOperator|) $) "\\spad{elt(op,x)} or op(x) applies the unary operator \\spad{op} to \\spad{x.}"))) 
 NIL 
 NIL 
-(-299 R1) 
+(-319 R1) 
 ((|constructor| (NIL "\\axiom{ExpertSystemToolsPackage1} contains some useful functions for use by the computational agents of Ordinary Differential Equation solvers.")) (|neglist| (((|List| |#1|) (|List| |#1|)) "\\spad{neglist(l)} returns only the negative elements of the list \\spad{l}"))) 
 NIL 
 NIL 
-(-300 R1 R2) 
+(-320 R1 R2) 
 ((|constructor| (NIL "\\axiom{ExpertSystemToolsPackage2} contains some useful functions for use by the computational agents of Ordinary Differential Equation solvers.")) (|map| (((|Matrix| |#2|) (|Mapping| |#2| |#1|) (|Matrix| |#1|)) "\\spad{map(f,m)} applies a mapping \\spad{f:R1} \\spad{->} \\spad{R2} onto a matrix \\spad{m} in \\spad{R1} returning a matrix in \\spad{R2}"))) 
 NIL 
 NIL 
-(-301) 
+(-321) 
 ((|constructor| (NIL "\\axiom{ExpertSystemToolsPackage} contains some useful functions for use by the computational agents of numerical solvers.")) (|mat| (((|Matrix| (|DoubleFloat|)) (|List| (|DoubleFloat|)) (|NonNegativeInteger|)) "\\spad{mat(a,n)} constructs a one-dimensional matrix of a.")) (|fi2df| (((|DoubleFloat|) (|Fraction| (|Integer|))) "\\spad{fi2df(f)} coerces a \\axiomType{Fraction Integer} to \\axiomType{DoubleFloat}")) (|df2ef| (((|Expression| (|Float|)) (|DoubleFloat|)) "\\spad{df2ef(a)} coerces a \\axiomType{DoubleFloat} to \\axiomType{Expression Float}")) (|pdf2df| (((|DoubleFloat|) (|Polynomial| (|DoubleFloat|))) "\\spad{pdf2df(p)} coerces a \\axiomType{Polynomial DoubleFloat} to \\axiomType{DoubleFloat}. It is an error if \\axiom{p} is not retractable to DoubleFloat.")) (|pdf2ef| (((|Expression| (|Float|)) (|Polynomial| (|DoubleFloat|))) "\\spad{pdf2ef(p)} coerces a \\axiomType{Polynomial DoubleFloat} to \\axiomType{Expression Float}")) (|iflist2Result| (((|Result|) (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|)))) "\\spad{iflist2Result(m)} converts a attributes record into a \\axiomType{Result}")) (|att2Result| (((|Result|) (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) "\\spad{att2Result(m)} converts a attributes record into a \\axiomType{Result}")) (|measure2Result| (((|Result|) (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|)))) "\\spad{measure2Result(m)} converts a measure record into a \\axiomType{Result}") (((|Result|) (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) "\\spad{measure2Result(m)} converts a measure record into a \\axiomType{Result}")) (|outputMeasure| (((|String|) (|Float|)) "\\spad{outputMeasure(n)} rounds \\spad{n} to 3 decimal places and outputs it as a string")) (|concat| (((|Result|) (|List| (|Result|))) "\\spad{concat(l)} concatenates a list of aggregates of type \\axiomType{Result}") (((|Result|) (|Result|) (|Result|)) "\\spad{concat(a,b)} adds two aggregates of type \\axiomType{Result}.")) (|gethi| (((|DoubleFloat|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{gethi(u)} gets the \\axiomType{DoubleFloat} equivalent of the second endpoint of the range \\spad{u}")) (|getlo| (((|DoubleFloat|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{getlo(u)} gets the \\axiomType{DoubleFloat} equivalent of the first endpoint of the range \\spad{u}")) (|sdf2lst| (((|List| (|String|)) (|Stream| (|DoubleFloat|))) "\\spad{sdf2lst(ln)} coerces a \\axiomType{Stream DoubleFloat} to \\axiomType{String}")) (|ldf2lst| (((|List| (|String|)) (|List| (|DoubleFloat|))) "\\spad{ldf2lst(ln)} coerces a \\axiomType{List DoubleFloat} to \\axiomType{List String}")) (|f2st| (((|String|) (|Float|)) "\\spad{f2st(n)} coerces a \\axiomType{Float} to \\axiomType{String}")) (|df2st| (((|String|) (|DoubleFloat|)) "\\spad{df2st(n)} coerces a \\axiomType{DoubleFloat} to \\axiomType{String}")) (|in?| (((|Boolean|) (|DoubleFloat|) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{in?(p,range)} tests whether point \\spad{p} is internal to the \\spad{range} \\spad{range}")) (|vedf2vef| (((|Vector| (|Expression| (|Float|))) (|Vector| (|Expression| (|DoubleFloat|)))) "\\spad{vedf2vef(v)} maps \\axiomType{Vector Expression DoubleFloat} to \\axiomType{Vector Expression Float}")) (|edf2ef| (((|Expression| (|Float|)) (|Expression| (|DoubleFloat|))) "\\spad{edf2ef(e)} maps \\axiomType{Expression DoubleFloat} to \\axiomType{Expression Float}")) (|ldf2vmf| (((|Vector| (|MachineFloat|)) (|List| (|DoubleFloat|))) "\\spad{ldf2vmf(l)} coerces a \\axiomType{List DoubleFloat} to \\axiomType{List MachineFloat}")) (|df2mf| (((|MachineFloat|) (|DoubleFloat|)) "\\spad{df2mf(n)} coerces a \\axiomType{DoubleFloat} to \\axiomType{MachineFloat}")) (|dflist| (((|List| (|DoubleFloat|)) (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) "\\spad{dflist(l)} returns a list of \\axiomType{DoubleFloat} equivalents of list \\spad{l}")) (|dfRange| (((|Segment| (|OrderedCompletion| (|DoubleFloat|))) (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) "\\spad{dfRange(r)} converts a range including \\inputbitmap{\\htbmdir{}/plusminus.bitmap} \\infty to \\axiomType{DoubleFloat} equavalents.")) (|edf2efi| (((|Expression| (|Fraction| (|Integer|))) (|Expression| (|DoubleFloat|))) "\\spad{edf2efi(e)} coerces \\axiomType{Expression DoubleFloat} into \\axiomType{Expression Fraction Integer}")) (|numberOfOperations| (((|Record| (|:| |additions| (|Integer|)) (|:| |multiplications| (|Integer|)) (|:| |exponentiations| (|Integer|)) (|:| |functionCalls| (|Integer|))) (|Vector| (|Expression| (|DoubleFloat|)))) "\\spad{numberOfOperations(ode)} counts additions, multiplications, exponentiations and function calls in the input set of expressions.")) (|expenseOfEvaluation| (((|Float|) (|Vector| (|Expression| (|DoubleFloat|)))) "\\spad{expenseOfEvaluation(o)} gives an approximation of the cost of evaluating a list of expressions in terms of the number of basic operations. < 0.3 inexpensive ; 0.5 neutral ; > 0.7 very expensive 400 `operation units' \\spad{->} 0.75 200 `operation units' \\spad{->} 0.5 83 `operation units' \\spad{->} 0.25 \\spad{**} = 4 units ,{} function calls = 10 units.")) (|isQuotient| (((|Union| (|Expression| (|DoubleFloat|)) "failed") (|Expression| (|DoubleFloat|))) "\\spad{isQuotient(expr)} returns the quotient part of the input expression or \\spad{\"failed\"} if the expression is not of that form.")) (|edf2df| (((|DoubleFloat|) (|Expression| (|DoubleFloat|))) "\\spad{edf2df(n)} maps \\axiomType{Expression DoubleFloat} to \\axiomType{DoubleFloat} It is an error if \\spad{n} is not coercible to DoubleFloat")) (|edf2fi| (((|Fraction| (|Integer|)) (|Expression| (|DoubleFloat|))) "\\spad{edf2fi(n)} maps \\axiomType{Expression DoubleFloat} to \\axiomType{Fraction Integer} It is an error if \\spad{n} is not coercible to Fraction Integer")) (|df2fi| (((|Fraction| (|Integer|)) (|DoubleFloat|)) "\\spad{df2fi(n)} is a function to convert a \\axiomType{DoubleFloat} to a \\axiomType{Fraction Integer}")) (|convert| (((|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|List| (|Segment| (|OrderedCompletion| (|Float|))))) "\\spad{convert(l)} is a function to convert a \\axiomType{Segment OrderedCompletion Float} to a \\axiomType{Segment OrderedCompletion DoubleFloat}")) (|socf2socdf| (((|Segment| (|OrderedCompletion| (|DoubleFloat|))) (|Segment| (|OrderedCompletion| (|Float|)))) "\\spad{socf2socdf(a)} is a function to convert a \\axiomType{Segment OrderedCompletion Float} to a \\axiomType{Segment OrderedCompletion DoubleFloat}")) (|ocf2ocdf| (((|OrderedCompletion| (|DoubleFloat|)) (|OrderedCompletion| (|Float|))) "\\spad{ocf2ocdf(a)} is a function to convert an \\axiomType{OrderedCompletion Float} to an \\axiomType{OrderedCompletion DoubleFloat}")) (|ef2edf| (((|Expression| (|DoubleFloat|)) (|Expression| (|Float|))) "\\spad{ef2edf(f)} is a function to convert an \\axiomType{Expression Float} to an \\axiomType{Expression DoubleFloat}")) (|f2df| (((|DoubleFloat|) (|Float|)) "\\spad{f2df(f)} is a function to convert a \\axiomType{Float} to a \\axiomType{DoubleFloat}"))) 
 NIL 
 NIL 
-(-302 S) 
+(-322 S) 
 ((|constructor| (NIL "A constructive euclidean domain, \\spadignore{i.e.} one can divide producing a quotient and a remainder where the remainder is either zero or is smaller (\\spadfun{euclideanSize}) than the divisor. \\blankline Conditional attributes\\br \\tab{5}multiplicativeValuation\\tab{5}Size(a*b)=Size(a)*Size(b)\\br \\tab{5}additiveValuation\\tab{11}Size(a*b)=Size(a)+Size(b)")) (|multiEuclidean| (((|Union| (|List| $) "failed") (|List| $) $) "\\spad{multiEuclidean([f1,...,fn],z)} returns a list of coefficients \\spad{[a1, ..., an]} such that \\spad{ \\spad{z} / prod \\spad{fi} = sum aj/fj}. If no such list of coefficients exists, \"failed\" is returned.")) (|extendedEuclidean| (((|Union| (|Record| (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) "\\spad{extendedEuclidean(x,y,z)} either returns a record rec where \\spad{rec.coef1*x+rec.coef2*y=z} or returns \"failed\" if \\spad{z} cannot be expressed as a linear combination of \\spad{x} and \\spad{y.}") (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{extendedEuclidean(x,y)} returns a record rec where \\spad{rec.coef1*x+rec.coef2*y = rec.generator} and rec.generator is a \\spad{gcd} of \\spad{x} and \\spad{y.} The \\spad{gcd} is unique only up to associates if \\spadatt{canonicalUnitNormal} is not asserted. \\spadfun{principalIdeal} provides a version of this operation which accepts an arbitrary length list of arguments.")) (|rem| (($ $ $) "\\spad{x rem \\spad{y}} is the same as \\spad{divide(x,y).remainder}. See \\spadfunFrom{divide}{EuclideanDomain}.")) (|quo| (($ $ $) "\\spad{x quo \\spad{y}} is the same as \\spad{divide(x,y).quotient}. See \\spadfunFrom{divide}{EuclideanDomain}.")) (|divide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{divide(x,y)} divides \\spad{x} by \\spad{y} producing a record containing a \\spad{quotient} and \\spad{remainder}, where the remainder is smaller (see \\spadfunFrom{sizeLess?}{EuclideanDomain}) than the divisor \\spad{y.}")) (|euclideanSize| (((|NonNegativeInteger|) $) "\\spad{euclideanSize(x)} returns the euclidean size of the element \\spad{x.} Error: if \\spad{x} is zero.")) (|sizeLess?| (((|Boolean|) $ $) "\\spad{sizeLess?(x,y)} tests whether \\spad{x} is strictly smaller than \\spad{y} with respect to the \\spadfunFrom{euclideanSize}{EuclideanDomain}."))) 
 NIL 
 NIL 
-(-303) 
+(-323) 
 ((|constructor| (NIL "A constructive euclidean domain, \\spadignore{i.e.} one can divide producing a quotient and a remainder where the remainder is either zero or is smaller (\\spadfun{euclideanSize}) than the divisor. \\blankline Conditional attributes\\br \\tab{5}multiplicativeValuation\\tab{5}Size(a*b)=Size(a)*Size(b)\\br \\tab{5}additiveValuation\\tab{11}Size(a*b)=Size(a)+Size(b)")) (|multiEuclidean| (((|Union| (|List| $) "failed") (|List| $) $) "\\spad{multiEuclidean([f1,...,fn],z)} returns a list of coefficients \\spad{[a1, ..., an]} such that \\spad{ \\spad{z} / prod \\spad{fi} = sum aj/fj}. If no such list of coefficients exists, \"failed\" is returned.")) (|extendedEuclidean| (((|Union| (|Record| (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) "\\spad{extendedEuclidean(x,y,z)} either returns a record rec where \\spad{rec.coef1*x+rec.coef2*y=z} or returns \"failed\" if \\spad{z} cannot be expressed as a linear combination of \\spad{x} and \\spad{y.}") (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{extendedEuclidean(x,y)} returns a record rec where \\spad{rec.coef1*x+rec.coef2*y = rec.generator} and rec.generator is a \\spad{gcd} of \\spad{x} and \\spad{y.} The \\spad{gcd} is unique only up to associates if \\spadatt{canonicalUnitNormal} is not asserted. \\spadfun{principalIdeal} provides a version of this operation which accepts an arbitrary length list of arguments.")) (|rem| (($ $ $) "\\spad{x rem \\spad{y}} is the same as \\spad{divide(x,y).remainder}. See \\spadfunFrom{divide}{EuclideanDomain}.")) (|quo| (($ $ $) "\\spad{x quo \\spad{y}} is the same as \\spad{divide(x,y).quotient}. See \\spadfunFrom{divide}{EuclideanDomain}.")) (|divide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{divide(x,y)} divides \\spad{x} by \\spad{y} producing a record containing a \\spad{quotient} and \\spad{remainder}, where the remainder is smaller (see \\spadfunFrom{sizeLess?}{EuclideanDomain}) than the divisor \\spad{y.}")) (|euclideanSize| (((|NonNegativeInteger|) $) "\\spad{euclideanSize(x)} returns the euclidean size of the element \\spad{x.} Error: if \\spad{x} is zero.")) (|sizeLess?| (((|Boolean|) $ $) "\\spad{sizeLess?(x,y)} tests whether \\spad{x} is strictly smaller than \\spad{y} with respect to the \\spadfunFrom{euclideanSize}{EuclideanDomain}."))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-304 S R) 
+(-324 S R) 
 ((|constructor| (NIL "This category provides \\spadfun{eval} operations. A domain may belong to this category if it is possible to make ``evaluation'' substitutions.")) (|eval| (($ $ (|List| (|Equation| |#2|))) "\\spad{eval(f, \\spad{[x1} = v1,...,xn = vn])} replaces \\spad{xi} by \\spad{vi} in \\spad{f.}") (($ $ (|Equation| |#2|)) "\\spad{eval(f,x = \\spad{v)}} replaces \\spad{x} by \\spad{v} in \\spad{f.}"))) 
 NIL 
 NIL 
-(-305 R) 
+(-325 R) 
 ((|constructor| (NIL "This category provides \\spadfun{eval} operations. A domain may belong to this category if it is possible to make ``evaluation'' substitutions.")) (|eval| (($ $ (|List| (|Equation| |#1|))) "\\spad{eval(f, \\spad{[x1} = v1,...,xn = vn])} replaces \\spad{xi} by \\spad{vi} in \\spad{f.}") (($ $ (|Equation| |#1|)) "\\spad{eval(f,x = \\spad{v)}} replaces \\spad{x} by \\spad{v} in \\spad{f.}"))) 
 NIL 
 NIL 
-(-306 -3313) 
+(-326 -3958) 
 ((|constructor| (NIL "This package is to be used in conjuction with the CycleIndicators package. It provides an evaluation function for SymmetricPolynomials.")) (|eval| ((|#1| (|Mapping| |#1| (|Integer|)) (|SymmetricPolynomial| (|Fraction| (|Integer|)))) "\\spad{eval(f,s)} evaluates the cycle index \\spad{s} by applying \\indented{1}{the function \\spad{f} to each integer in a monomial partition,} \\indented{1}{forms their product and sums the results over all monomials.}"))) 
 NIL 
 NIL 
-(-307) 
+(-327) 
 ((|constructor| (NIL "A function which does not return directly to its caller should have Exit as its return type. \\blankline Note that It is convenient to have a formal \\spad{coerce} into each type from type Exit. This allows, for example, errors to be raised in one half of a type-balanced \\spad{if}."))) 
 NIL 
 NIL 
-(-308) 
+(-328) 
 ((|writeObj| (((|Void|) (|SubSpace| 3 (|DoubleFloat|)) (|String|)) "writes 3D SubSpace to a file in Wavefront (.OBJ) format"))) 
 NIL 
 NIL 
-(-309 R FE |var| |cen|) 
+(-329 R FE |var| |cen|) 
 ((|constructor| (NIL "UnivariatePuiseuxSeriesWithExponentialSingularity is a domain used to represent essential singularities of functions. Objects in this domain are quotients of sums, where each term in the sum is a univariate Puiseux series times the exponential of a univariate Puiseux series.")) (|coerce| (($ (|UnivariatePuiseuxSeries| |#2| |#3| |#4|)) "\\spad{coerce(f)} converts a \\spadtype{UnivariatePuiseuxSeries} to an \\spadtype{ExponentialExpansion}.")) (|limitPlus| (((|Union| (|OrderedCompletion| |#2|) "failed") $) "\\spad{limitPlus(f(var))} returns \\spad{limit(var \\spad{->} a+,f(var))}."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-910))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-149))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-151))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-1028))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-821))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-1144))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-227))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -527) (QUOTE (-1170)) (LIST (QUOTE -1244) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -305) (LIST (QUOTE -1244) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (LIST (QUOTE -283) (LIST (QUOTE -1244) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)) (LIST (QUOTE -1244) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-303))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-554))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-848))) (-1841 (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-821))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-848)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-910)))) (|HasCategory| (-1244 |#1| |#2| |#3| |#4|) (QUOTE (-149))))) 
-(-310 R S) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-931))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-169))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-171))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-1049))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-842))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-1165))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-247))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -547) (QUOTE (-1191)) (LIST (QUOTE -1265) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -325) (LIST (QUOTE -1265) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (LIST (QUOTE -303) (LIST (QUOTE -1265) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)) (LIST (QUOTE -1265) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-323))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-574))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-869))) (-3836 (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-842))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-869)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-931)))) (|HasCategory| (-1265 |#1| |#2| |#3| |#4|) (QUOTE (-169))))) 
+(-330 R S) 
 ((|constructor| (NIL "Lifting of maps to Expressions.")) (|map| (((|Expression| |#2|) (|Mapping| |#2| |#1|) (|Expression| |#1|)) "\\spad{map(f, e)} applies \\spad{f} to all the constants appearing in e."))) 
 NIL 
 NIL 
-(-311 R FE) 
+(-331 R FE) 
 ((|constructor| (NIL "This package provides functions to convert functional expressions to power series.")) (|series| (((|Any|) |#2| (|Equation| |#2|) (|Fraction| (|Integer|))) "\\spad{series(f,x = a,n)} expands the expression \\spad{f} as a series in powers of \\spad{(x} - a); terms will be computed up to order at least \\spad{n.}") (((|Any|) |#2| (|Equation| |#2|)) "\\spad{series(f,x = a)} expands the expression \\spad{f} as a series in powers of \\spad{(x} - a).") (((|Any|) |#2| (|Fraction| (|Integer|))) "\\spad{series(f,n)} returns a series expansion of the expression \\spad{f.} Note that \\spad{f} should have only one variable; the series will be expanded in powers of that variable and terms will be computed up to order at least \\spad{n.}") (((|Any|) |#2|) "\\spad{series(f)} returns a series expansion of the expression \\spad{f.} Note that \\spad{f} should have only one variable; the series will be expanded in powers of that variable.") (((|Any|) (|Symbol|)) "\\spad{series(x)} returns \\spad{x} viewed as a series.")) (|puiseux| (((|Any|) |#2| (|Equation| |#2|) (|Fraction| (|Integer|))) "\\spad{puiseux(f,x = a,n)} expands the expression \\spad{f} as a Puiseux series in powers of \\spad{(x - a)}; terms will be computed up to order at least \\spad{n.}") (((|Any|) |#2| (|Equation| |#2|)) "\\spad{puiseux(f,x = a)} expands the expression \\spad{f} as a Puiseux series in powers of \\spad{(x - a)}.") (((|Any|) |#2| (|Fraction| (|Integer|))) "\\spad{puiseux(f,n)} returns a Puiseux expansion of the expression \\spad{f.} Note that \\spad{f} should have only one variable; the series will be expanded in powers of that variable and terms will be computed up to order at least \\spad{n.}") (((|Any|) |#2|) "\\spad{puiseux(f)} returns a Puiseux expansion of the expression \\spad{f.} Note that \\spad{f} should have only one variable; the series will be expanded in powers of that variable.") (((|Any|) (|Symbol|)) "\\spad{puiseux(x)} returns \\spad{x} viewed as a Puiseux series.")) (|laurent| (((|Any|) |#2| (|Equation| |#2|) (|Integer|)) "\\spad{laurent(f,x = a,n)} expands the expression \\spad{f} as a Laurent series in powers of \\spad{(x - a)}; terms will be computed up to order at least \\spad{n.}") (((|Any|) |#2| (|Equation| |#2|)) "\\spad{laurent(f,x = a)} expands the expression \\spad{f} as a Laurent series in powers of \\spad{(x - a)}.") (((|Any|) |#2| (|Integer|)) "\\spad{laurent(f,n)} returns a Laurent expansion of the expression \\spad{f.} Note that \\spad{f} should have only one variable; the series will be expanded in powers of that variable and terms will be computed up to order at least \\spad{n.}") (((|Any|) |#2|) "\\spad{laurent(f)} returns a Laurent expansion of the expression \\spad{f.} Note that \\spad{f} should have only one variable; the series will be expanded in powers of that variable.") (((|Any|) (|Symbol|)) "\\spad{laurent(x)} returns \\spad{x} viewed as a Laurent series.")) (|taylor| (((|Any|) |#2| (|Equation| |#2|) (|NonNegativeInteger|)) "\\spad{taylor(f,x = a)} expands the expression \\spad{f} as a Taylor series in powers of \\spad{(x - a)}; terms will be computed up to order at least \\spad{n.}") (((|Any|) |#2| (|Equation| |#2|)) "\\spad{taylor(f,x = a)} expands the expression \\spad{f} as a Taylor series in powers of \\spad{(x - a)}.") (((|Any|) |#2| (|NonNegativeInteger|)) "\\spad{taylor(f,n)} returns a Taylor expansion of the expression \\spad{f.} Note that \\spad{f} should have only one variable; the series will be expanded in powers of that variable and terms will be computed up to order at least \\spad{n.}") (((|Any|) |#2|) "\\spad{taylor(f)} returns a Taylor expansion of the expression \\spad{f.} Note that \\spad{f} should have only one variable; the series will be expanded in powers of that variable.") (((|Any|) (|Symbol|)) "\\spad{taylor(x)} returns \\spad{x} viewed as a Taylor series."))) 
 NIL 
 NIL 
-(-312 R) 
+(-332 R) 
 ((|constructor| (NIL "Top-level mathematical expressions involving symbolic functions.")) (|squareFreePolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{squareFreePolynomial(p)} is not documented")) (|factorPolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{factorPolynomial(p)} is not documented")) (|simplifyPower| (($ $ (|Integer|)) "simplifyPower?(f,n) is not documented")) (|number?| (((|Boolean|) $) "\\spad{number?(f)} tests if \\spad{f} is rational")) (|reduce| (($ $) "\\spad{reduce(f)} simplifies all the unreduced algebraic quantities present in \\spad{f} by applying their defining relations."))) 
-((-4599 -1841 (-4028 (|has| |#1| (-1054)) (|has| |#1| (-634 (-572)))) (-12 (|has| |#1| (-562)) (-1841 (-4028 (|has| |#1| (-1054)) (|has| |#1| (-634 (-572)))) (|has| |#1| (-1054)) (|has| |#1| (-482)))) (|has| |#1| (-1054)) (|has| |#1| (-482))) (-4597 |has| |#1| (-174)) (-4596 |has| |#1| (-174)) ((-4604 "*") |has| |#1| (-562)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-562)) (-4594 |has| |#1| (-562))) 
-((|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-1054))) (-1841 (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-1054)))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-1054)))) (-12 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-1054)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-1054)))) (-1841 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (QUOTE (-1054)))) (|HasCategory| |#1| (QUOTE (-21))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-1054)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-1054)))) (|HasCategory| |#1| (QUOTE (-21)))) (|HasCategory| |#1| (QUOTE (-25))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-1054)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-1054)))) (|HasCategory| |#1| (QUOTE (-25)))) (|HasCategory| |#1| (QUOTE (-1110))) (-1841 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#1| (QUOTE (-1110)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-1054)))) (|HasCategory| |#1| (QUOTE (-1110)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-1054)))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-1110)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-562))))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-562))))) (|HasCategory| $ (QUOTE (-1054))) (|HasCategory| $ (LIST (QUOTE -1044) (QUOTE (-572))))) 
-(-313 R -3313) 
+((-4622 -3836 (-1732 (|has| |#1| (-1075)) (|has| |#1| (-654 (-592)))) (-12 (|has| |#1| (-582)) (-3836 (-1732 (|has| |#1| (-1075)) (|has| |#1| (-654 (-592)))) (|has| |#1| (-1075)) (|has| |#1| (-502)))) (|has| |#1| (-1075)) (|has| |#1| (-502))) (-4620 |has| |#1| (-194)) (-4619 |has| |#1| (-194)) ((-4627 "*") |has| |#1| (-582)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-582)) (-4617 |has| |#1| (-582))) 
+((|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-1075))) (-3836 (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-1075)))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-1075)))) (-12 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-1075)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-1075)))) (-3836 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (QUOTE (-1075)))) (|HasCategory| |#1| (QUOTE (-21))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-1075)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-1075)))) (|HasCategory| |#1| (QUOTE (-21)))) (|HasCategory| |#1| (QUOTE (-25))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-1075)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-1075)))) (|HasCategory| |#1| (QUOTE (-25)))) (|HasCategory| |#1| (QUOTE (-1131))) (-3836 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#1| (QUOTE (-1131)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-1075)))) (|HasCategory| |#1| (QUOTE (-1131)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-1075)))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-1131)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-582))))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-582))))) (|HasCategory| $ (QUOTE (-1075))) (|HasCategory| $ (LIST (QUOTE -1065) (QUOTE (-592))))) 
+(-333 R -3958) 
 ((|constructor| (NIL "Taylor series solutions of explicit ODE's.")) (|seriesSolve| (((|Any|) |#2| (|BasicOperator|) (|Equation| |#2|) (|List| |#2|)) "\\spad{seriesSolve(eq, \\spad{y,} \\spad{x} = a, [b0,...,bn])} is equivalent to \\spad{seriesSolve(eq = 0, \\spad{y,} \\spad{x} = a, [b0,...,b(n-1)])}.") (((|Any|) |#2| (|BasicOperator|) (|Equation| |#2|) (|Equation| |#2|)) "\\spad{seriesSolve(eq, \\spad{y,} \\spad{x} = a, \\spad{y} a = \\spad{b)}} is equivalent to \\spad{seriesSolve(eq=0, \\spad{y,} x=a, \\spad{y} a = b)}.") (((|Any|) |#2| (|BasicOperator|) (|Equation| |#2|) |#2|) "\\spad{seriesSolve(eq, \\spad{y,} \\spad{x} = a, \\spad{b)}} is equivalent to \\spad{seriesSolve(eq = 0, \\spad{y,} \\spad{x} = a, \\spad{y} a = b)}.") (((|Any|) (|Equation| |#2|) (|BasicOperator|) (|Equation| |#2|) |#2|) "\\spad{seriesSolve(eq,y, x=a, \\spad{b)}} is equivalent to \\spad{seriesSolve(eq, \\spad{y,} x=a, \\spad{y} a = b)}.") (((|Any|) (|List| |#2|) (|List| (|BasicOperator|)) (|Equation| |#2|) (|List| (|Equation| |#2|))) "seriesSolve([eq1,...,eqn], [y1,...,yn], \\spad{x} = \\spad{a,[y1} a = b1,..., \\spad{yn} a = bn]) is equivalent to \\spad{seriesSolve([eq1=0,...,eqn=0], [y1,...,yn], \\spad{x} = a, \\spad{[y1} a = b1,..., \\spad{yn} a = bn])}.") (((|Any|) (|List| |#2|) (|List| (|BasicOperator|)) (|Equation| |#2|) (|List| |#2|)) "\\spad{seriesSolve([eq1,...,eqn], [y1,...,yn], x=a, [b1,...,bn])} is equivalent to \\spad{seriesSolve([eq1=0,...,eqn=0], [y1,...,yn], x=a, [b1,...,bn])}.") (((|Any|) (|List| (|Equation| |#2|)) (|List| (|BasicOperator|)) (|Equation| |#2|) (|List| |#2|)) "\\spad{seriesSolve([eq1,...,eqn], [y1,...,yn], x=a, [b1,...,bn])} is equivalent to \\spad{seriesSolve([eq1,...,eqn], [y1,...,yn], \\spad{x} = a, \\spad{[y1} a = b1,..., \\spad{yn} a = bn])}.") (((|Any|) (|List| (|Equation| |#2|)) (|List| (|BasicOperator|)) (|Equation| |#2|) (|List| (|Equation| |#2|))) "\\spad{seriesSolve([eq1,...,eqn],[y1,...,yn],x = \\spad{a,[y1} a = b1,...,yn a = bn])} returns a taylor series solution of \\spad{[eq1,...,eqn]} around \\spad{x = a} with initial conditions \\spad{yi(a) = bi}. Note that eqi must be of the form \\spad{fi(x, \\spad{y1} \\spad{x,} \\spad{y2} x,..., \\spad{yn} \\spad{x)} y1'(x) + gi(x, \\spad{y1} \\spad{x,} \\spad{y2} x,..., \\spad{yn} \\spad{x)} = h(x, \\spad{y1} \\spad{x,} \\spad{y2} x,..., \\spad{yn} x)}.") (((|Any|) (|Equation| |#2|) (|BasicOperator|) (|Equation| |#2|) (|List| |#2|)) "\\spad{seriesSolve(eq,y,x=a,[b0,...,b(n-1)])} returns a Taylor series solution of \\spad{eq} around \\spad{x = a} with initial conditions \\spad{y(a) = b0}, \\spad{y'(a) = b1}, \\spad{y''(a) = b2}, ...,\\spad{y(n-1)(a) = b(n-1)} \\spad{eq} must be of the form \\spad{f(x, \\spad{y} \\spad{x,} y'(x),..., y(n-1)(x)) y(n)(x) + g(x,y x,y'(x),...,y(n-1)(x)) = h(x,y \\spad{x,} y'(x),..., y(n-1)(x))}.") (((|Any|) (|Equation| |#2|) (|BasicOperator|) (|Equation| |#2|) (|Equation| |#2|)) "\\spad{seriesSolve(eq,y,x=a, \\spad{y} a = \\spad{b)}} returns a Taylor series solution of \\spad{eq} around \\spad{x} = a with initial condition \\spad{y(a) = \\spad{b}.} Note that \\spad{eq} must be of the form \\spad{f(x, \\spad{y} \\spad{x)} y'(x) + g(x, \\spad{y} \\spad{x)} = h(x, \\spad{y} x)}."))) 
 NIL 
 NIL 
-(-314 R -3313 UTSF UTSSUPF) 
+(-334 R -3958 UTSF UTSSUPF) 
 ((|constructor| (NIL "This package has no description"))) 
 NIL 
 NIL 
-(-315) 
+(-335) 
 ((|constructor| (NIL "Package for constructing tubes around 3-dimensional parametric curves.")) (|tubePlot| (((|TubePlot| (|Plot3D|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|String|)) "\\spad{tubePlot(f,g,h,colorFcn,a..b,r,n,s)} puts a tube of radius \\spad{r} with \\spad{n} points on each circle about the curve \\spad{x = f(t)}, \\spad{y = g(t)}, \\spad{z = h(t)} for \\spad{t} in \\spad{[a,b]}. If \\spad{s} = \"closed\", the tube is considered to be closed; if \\spad{s} = \"open\", the tube is considered to be open.") (((|TubePlot| (|Plot3D|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|)) "\\spad{tubePlot(f,g,h,colorFcn,a..b,r,n)} puts a tube of radius \\spad{r} with \\spad{n} points on each circle about the curve \\spad{x = f(t)}, \\spad{y = g(t)}, \\spad{z = h(t)} for \\spad{t} in \\spad{[a,b]}. The tube is considered to be open.") (((|TubePlot| (|Plot3D|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Integer|) (|String|)) "\\spad{tubePlot(f,g,h,colorFcn,a..b,r,n,s)} puts a tube of radius \\spad{r(t)} with \\spad{n} points on each circle about the curve \\spad{x = f(t)}, \\spad{y = g(t)}, \\spad{z = h(t)} for \\spad{t} in \\spad{[a,b]}. If \\spad{s} = \"closed\", the tube is considered to be closed; if \\spad{s} = \"open\", the tube is considered to be open.") (((|TubePlot| (|Plot3D|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Integer|)) "\\spad{tubePlot(f,g,h,colorFcn,a..b,r,n)} puts a tube of radius r(t) with \\spad{n} points on each circle about the curve \\spad{x = f(t)}, \\spad{y = g(t)}, \\spad{z = h(t)} for \\spad{t} in \\spad{[a,b]}. The tube is considered to be open.")) (|constantToUnaryFunction| (((|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|DoubleFloat|)) "\\spad{constantToUnaryFunction(s)} is a local function which takes the value of \\spad{s,} which may be a function of a constant, and returns a function which always returns the value \\spadtype{DoubleFloat} \\spad{s.}"))) 
 NIL 
 NIL 
-(-316 FE |var| |cen|) 
+(-336 FE |var| |cen|) 
 ((|constructor| (NIL "ExponentialOfUnivariatePuiseuxSeries is a domain used to represent essential singularities of functions. An object in this domain is a function of the form \\spad{exp(f(x))}, where \\spad{f(x)} is a Puiseux series with no terms of non-negative degree. Objects are ordered according to order of singularity, with functions which tend more rapidly to zero or infinity considered to be larger. Thus, if \\spad{order(f(x)) < order(g(x))}, \\spadignore{i.e.} the first non-zero term of \\spad{f(x)} has lower degree than the first non-zero term of \\spad{g(x)}, then \\spad{exp(f(x)) > exp(g(x))}. If \\spad{order(f(x)) = order(g(x))}, then the ordering is essentially random. This domain is used in computing limits involving functions with essential singularities.")) (|exponentialOrder| (((|Fraction| (|Integer|)) $) "\\spad{exponentialOrder(exp(c * \\spad{x} **(-n) + ...))} returns \\spad{-n}. exponentialOrder(0) returns \\spad{0}.")) (|exponent| (((|UnivariatePuiseuxSeries| |#1| |#2| |#3|) $) "\\spad{exponent(exp(f(x)))} returns \\spad{f(x)}")) (|exponential| (($ (|UnivariatePuiseuxSeries| |#1| |#2| |#3|)) "\\spad{exponential(f(x))} returns \\spad{exp(f(x))}. Note: the function does NOT check that \\spad{f(x)} has no non-negative terms."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|))))) (|HasCategory| (-413 (-572)) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-317 K) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|))))) (|HasCategory| (-433 (-592)) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-337 K) 
 ((|constructor| (NIL "Part of the Package for Algebraic Function Fields in one variable PAFF"))) 
 NIL 
 NIL 
-(-318 M) 
+(-338 M) 
 ((|constructor| (NIL "computes various functions on factored arguments.")) (|log| (((|List| (|Record| (|:| |coef| (|NonNegativeInteger|)) (|:| |logand| |#1|))) (|Factored| |#1|)) "\\spad{log(f)} returns \\spad{[(a1,b1),...,(am,bm)]} such that the logarithm of \\spad{f} is equal to \\spad{a1*log(b1) + \\spad{...} + am*log(bm)}.")) (|nthRoot| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#1|) (|:| |radicand| (|List| |#1|))) (|Factored| |#1|) (|NonNegativeInteger|)) "\\spad{nthRoot(f, \\spad{n)}} returns \\spad{(p, \\spad{r,} [r1,...,rm])} such that the nth-root of \\spad{f} is equal to \\spad{r * \\spad{pth-root(r1} * \\spad{...} * rm)}, where r1,...,rm are distinct factors of \\spad{f,} each of which has an exponent smaller than \\spad{p} in \\spad{f.}"))) 
 NIL 
 NIL 
-(-319 K) 
+(-339 K) 
 ((|constructor| (NIL "Part of the Package for Algebraic Function Fields in one variable PAFF"))) 
 NIL 
 NIL 
-(-320 E OV R P) 
+(-340 E OV R P) 
 ((|constructor| (NIL "This package provides utilities used by the factorizers which operate on polynomials represented as univariate polynomials with multivariate coefficients.")) (|ran| ((|#3| (|Integer|)) "\\spad{ran(k)} computes a random integer between \\spad{-k} and \\spad{k} as a member of \\spad{R.}")) (|normalDeriv| (((|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|) (|Integer|)) "\\spad{normalDeriv(poly,i)} computes the \\spad{i}th derivative of \\spad{poly} divided by i!.")) (|raisePolynomial| (((|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#3|)) "\\spad{raisePolynomial(rpoly)} converts \\spad{rpoly} from a univariate polynomial over \\spad{r} to be a univariate polynomial with polynomial coefficients.")) (|lowerPolynomial| (((|SparseUnivariatePolynomial| |#3|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{lowerPolynomial(upoly)} converts \\spad{upoly} to be a univariate polynomial over \\spad{R.} An error if the coefficients contain variables.")) (|variables| (((|List| |#2|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{variables(upoly)} returns the list of variables for the coefficients of upoly.")) (|degree| (((|List| (|NonNegativeInteger|)) (|SparseUnivariatePolynomial| |#4|) (|List| |#2|)) "\\spad{degree(upoly, lvar)} returns a list containing the maximum degree for each variable in lvar.")) (|completeEval| (((|SparseUnivariatePolynomial| |#3|) (|SparseUnivariatePolynomial| |#4|) (|List| |#2|) (|List| |#3|)) "\\spad{completeEval(upoly, lvar, lval)} evaluates the polynomial \\spad{upoly} with each variable in \\spad{lvar} replaced by the corresponding value in lval. Substitutions are done for all variables in \\spad{upoly} producing a univariate polynomial over \\spad{R.}"))) 
 NIL 
 NIL 
-(-321 S) 
+(-341 S) 
 ((|constructor| (NIL "Free abelian group on any set of generators The free abelian group on a set \\spad{S} is the monoid of finite sums of the form \\spad{reduce(+,[ni * si])} where the si's are in \\spad{S,} and the ni's are integers. The operation is commutative."))) 
-((-4597 . T) (-4596 . T)) 
-((|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| (-572) (QUOTE (-793)))) 
-(-322 S E) 
+((-4620 . T) (-4619 . T)) 
+((|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| (-592) (QUOTE (-814)))) 
+(-342 S E) 
 ((|constructor| (NIL "A free abelian monoid on a set \\spad{S} is the monoid of finite sums of the form \\spad{reduce(+,[ni * si])} where the si's are in \\spad{S,} and the ni's are in a given abelian monoid. The operation is commutative.")) (|highCommonTerms| (($ $ $) "\\spad{highCommonTerms(e1 \\spad{a1} + \\spad{...} + en an, \\spad{f1} \\spad{b1} + \\spad{...} + \\spad{fm} bm)} returns \\spad{reduce(+,[max(ei, fi) ci])} where \\spad{ci} ranges in the intersection of \\spad{{a1,...,an}} and \\spad{{b1,...,bm}}.")) (|mapGen| (($ (|Mapping| |#1| |#1|) $) "\\spad{mapGen(f, \\spad{e1} \\spad{a1} +...+ en an)} returns \\spad{e1 f(a1) +...+ en f(an)}.")) (|mapCoef| (($ (|Mapping| |#2| |#2|) $) "\\spad{mapCoef(f, \\spad{e1} \\spad{a1} +...+ en an)} returns \\spad{f(e1) \\spad{a1} +...+ f(en) an}.")) (|coefficient| ((|#2| |#1| $) "\\spad{coefficient(s, \\spad{e1} \\spad{a1} + \\spad{...} + en an)} returns \\spad{ei} such that \\spad{ai} = \\spad{s,} or 0 if \\spad{s} is not one of the ai's.")) (|nthFactor| ((|#1| $ (|Integer|)) "\\spad{nthFactor(x, \\spad{n)}} returns the factor of the n^th term of \\spad{x.}")) (|nthCoef| ((|#2| $ (|Integer|)) "\\spad{nthCoef(x, \\spad{n)}} returns the coefficient of the n^th term of \\spad{x.}")) (|terms| (((|List| (|Record| (|:| |gen| |#1|) (|:| |exp| |#2|))) $) "\\spad{terms(e1 \\spad{a1} + \\spad{...} + en an)} returns \\spad{[[a1, e1],...,[an, en]]}.")) (|size| (((|NonNegativeInteger|) $) "\\indented{1}{size(x) returns the number of terms in \\spad{x.}} \\indented{1}{mapGen(f, \\spad{a1\\^e1} \\spad{...} an\\^en) returns} \\spad{f(a1)\\^e1 \\spad{...} f(an)\\^en}.")) (* (($ |#2| |#1|) "\\spad{e * \\spad{s}} returns \\spad{e} times \\spad{s.}")) (+ (($ |#1| $) "\\spad{s + \\spad{x}} returns the sum of \\spad{s} and \\spad{x.}"))) 
 NIL 
 NIL 
-(-323 S) 
+(-343 S) 
 ((|constructor| (NIL "Free abelian monoid on any set of generators The free abelian monoid on a set \\spad{S} is the monoid of finite sums of the form \\spad{reduce(+,[ni * si])} where the si's are in \\spad{S,} and the ni's are non-negative integers. The operation is commutative."))) 
 NIL 
-((|HasCategory| (-769) (QUOTE (-793)))) 
-(-324 E R1 A1 R2 A2) 
+((|HasCategory| (-790) (QUOTE (-814)))) 
+(-344 E R1 A1 R2 A2) 
 ((|constructor| (NIL "This package provides a mapping function for \\spadtype{FiniteAbelianMonoidRing} The packages defined in this file provide fast fraction free rational interpolation algorithms. (see FAMR2, FFFG, FFFGF, NEWTON)")) (|map| ((|#5| (|Mapping| |#4| |#2|) |#3|) "\\spad{map}(f, a) applies the map \\spad{f} to each coefficient in a. It is assumed that \\spad{f} maps 0 to 0"))) 
 NIL 
 NIL 
-(-325 S R E) 
+(-345 S R E) 
 ((|constructor| (NIL "This category is similar to AbelianMonoidRing, except that the sum is assumed to be finite. It is a useful model for polynomials, but is somewhat more general.")) (|primitivePart| (($ $) "\\spad{primitivePart(p)} returns the unit normalized form of polynomial \\spad{p} divided by the content of \\spad{p.}")) (|content| ((|#2| $) "\\spad{content(p)} gives the \\spad{gcd} of the coefficients of polynomial \\spad{p.}")) (|exquo| (((|Union| $ "failed") $ |#2|) "\\spad{exquo(p,r)} returns the exact quotient of polynomial \\spad{p} by \\spad{r,} or \"failed\" if none exists.")) (|binomThmExpt| (($ $ $ (|NonNegativeInteger|)) "\\spad{binomThmExpt(p,q,n)} returns \\spad{(x+y)^n} by means of the binomial theorem trick.")) (|pomopo!| (($ $ |#2| |#3| $) "\\spad{pomopo!(p1,r,e,p2)} returns \\spad{p1 + monomial(e,r) * \\spad{p2}} and may use \\spad{p1} as workspace. The constaant \\spad{r} is assumed to be nonzero.")) (|mapExponents| (($ (|Mapping| |#3| |#3|) $) "\\spad{mapExponents(fn,u)} maps function \\spad{fn} onto the exponents of the non-zero monomials of polynomial u.")) (|minimumDegree| ((|#3| $) "\\spad{minimumDegree(p)} gives the least exponent of a non-zero term of polynomial \\spad{p.} Error: if applied to 0.")) (|numberOfMonomials| (((|NonNegativeInteger|) $) "\\spad{numberOfMonomials(p)} gives the number of non-zero monomials in polynomial \\spad{p.}")) (|coefficients| (((|List| |#2|) $) "\\spad{coefficients(p)} gives the list of non-zero coefficients of polynomial \\spad{p.}")) (|ground| ((|#2| $) "\\spad{ground(p)} retracts polynomial \\spad{p} to the coefficient ring.")) (|ground?| (((|Boolean|) $) "\\spad{ground?(p)} tests if polynomial \\spad{p} is a member of the coefficient ring."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174)))) 
-(-326 R E) 
+((|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194)))) 
+(-346 R E) 
 ((|constructor| (NIL "This category is similar to AbelianMonoidRing, except that the sum is assumed to be finite. It is a useful model for polynomials, but is somewhat more general.")) (|primitivePart| (($ $) "\\spad{primitivePart(p)} returns the unit normalized form of polynomial \\spad{p} divided by the content of \\spad{p.}")) (|content| ((|#1| $) "\\spad{content(p)} gives the \\spad{gcd} of the coefficients of polynomial \\spad{p.}")) (|exquo| (((|Union| $ "failed") $ |#1|) "\\spad{exquo(p,r)} returns the exact quotient of polynomial \\spad{p} by \\spad{r,} or \"failed\" if none exists.")) (|binomThmExpt| (($ $ $ (|NonNegativeInteger|)) "\\spad{binomThmExpt(p,q,n)} returns \\spad{(x+y)^n} by means of the binomial theorem trick.")) (|pomopo!| (($ $ |#1| |#2| $) "\\spad{pomopo!(p1,r,e,p2)} returns \\spad{p1 + monomial(e,r) * \\spad{p2}} and may use \\spad{p1} as workspace. The constaant \\spad{r} is assumed to be nonzero.")) (|mapExponents| (($ (|Mapping| |#2| |#2|) $) "\\spad{mapExponents(fn,u)} maps function \\spad{fn} onto the exponents of the non-zero monomials of polynomial u.")) (|minimumDegree| ((|#2| $) "\\spad{minimumDegree(p)} gives the least exponent of a non-zero term of polynomial \\spad{p.} Error: if applied to 0.")) (|numberOfMonomials| (((|NonNegativeInteger|) $) "\\spad{numberOfMonomials(p)} gives the number of non-zero monomials in polynomial \\spad{p.}")) (|coefficients| (((|List| |#1|) $) "\\spad{coefficients(p)} gives the list of non-zero coefficients of polynomial \\spad{p.}")) (|ground| ((|#1| $) "\\spad{ground(p)} retracts polynomial \\spad{p} to the coefficient ring.")) (|ground?| (((|Boolean|) $) "\\spad{ground?(p)} tests if polynomial \\spad{p} is a member of the coefficient ring."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-327 S) 
+(-347 S) 
 ((|constructor| (NIL "A FlexibleArray is the notion of an array intended to allow for growth at the end only. Hence the following efficient operations \\spad{append(x,a)} meaning append item \\spad{x} at the end of the array \\spad{a} \\spad{delete(a,n)} meaning delete the last item from the array \\spad{a} Flexible arrays support the other operations inherited from \\spadtype{ExtensibleLinearAggregate}. However, these are not efficient. Flexible arrays combine the \\spad{O(1)} access time property of arrays with growing and shrinking at the end in \\spad{O(1)} (average) time. This is done by using an ordinary array which may have zero or more empty slots at the end. When the array becomes full it is copied into a new larger (50% larger) array. Conversely, when the array becomes less than 1/2 full, it is copied into a smaller array. Flexible arrays provide for an efficient implementation of many data structures in particular heaps, stacks and sets."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-328 S -3313) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-348 S -3958) 
 ((|constructor| (NIL "FiniteAlgebraicExtensionField \\spad{F} is the category of fields which are finite algebraic extensions of the field \\spad{F.} If \\spad{F} is finite then any finite algebraic extension of \\spad{F} is finite, too. Let \\spad{K} be a finite algebraic extension of the finite field \\spad{F.} The exponentiation of elements of \\spad{K} defines a Z-module structure on the multiplicative group of \\spad{K.} The additive group of \\spad{K} becomes a module over the ring of polynomials over \\spad{F} via the operation \\spadfun{linearAssociatedExp}(a:K,f:SparseUnivariatePolynomial \\spad{F)} which is linear over \\spad{F,} that is, for elements a from \\spad{K,} \\spad{c,d} from \\spad{F} and \\spad{f,g} univariate polynomials over \\spad{F} we have \\spadfun{linearAssociatedExp}(a,cf+dg) equals \\spad{c} times \\spadfun{linearAssociatedExp}(a,f) plus \\spad{d} times \\spadfun{linearAssociatedExp}(a,g). Therefore \\spadfun{linearAssociatedExp} is defined completely by its action on monomials from F[X]: \\spadfun{linearAssociatedExp}(a,monomial(1,k)\\$SUP(F)) is defined to be \\spadfun{Frobenius}(a,k) which is a**(q**k) where q=size()\\$F. The operations order and discreteLog associated with the multiplicative exponentiation have additive analogues associated to the operation \\spadfun{linearAssociatedExp}. These are the functions \\spadfun{linearAssociatedOrder} and \\spadfun{linearAssociatedLog}, respectively.")) (|linearAssociatedLog| (((|Union| (|SparseUnivariatePolynomial| |#2|) "failed") $ $) "\\spad{linearAssociatedLog(b,a)} returns a polynomial \\spad{g,} such that the \\spadfun{linearAssociatedExp}(b,g) equals a. If there is no such polynomial \\spad{g,} then \\spadfun{linearAssociatedLog} fails.") (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{linearAssociatedLog(a)} returns a polynomial \\spad{g,} such that \\spadfun{linearAssociatedExp}(normalElement(),g) equals a.")) (|linearAssociatedOrder| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{linearAssociatedOrder(a)} retruns the monic polynomial \\spad{g} of least degree, such that \\spadfun{linearAssociatedExp}(a,g) is 0.")) (|linearAssociatedExp| (($ $ (|SparseUnivariatePolynomial| |#2|)) "\\spad{linearAssociatedExp(a,f)} is linear over \\spad{F,} that is, for elements a from \\spad{\\$,} \\spad{c,d} form \\spad{F} and \\spad{f,g} univariate polynomials over \\spad{F} we have \\spadfun{linearAssociatedExp}(a,cf+dg) equals \\spad{c} times \\spadfun{linearAssociatedExp}(a,f) plus \\spad{d} times \\spadfun{linearAssociatedExp}(a,g). Therefore \\spadfun{linearAssociatedExp} is defined completely by its action on monomials from F[X]: \\spadfun{linearAssociatedExp}(a,monomial(1,k)\\$SUP(F)) is defined to be \\spadfun{Frobenius}(a,k) which is a**(q**k), where q=size()\\$F.")) (|generator| (($) "\\spad{generator()} returns a root of the defining polynomial. This element generates the field as an algebra over the ground field.")) (|normal?| (((|Boolean|) $) "\\spad{normal?(a)} tests whether the element \\spad{a} is normal over the ground field \\spad{F,} that is, \\spad{a**(q**i), 0 \\spad{<=} \\spad{i} \\spad{<=} extensionDegree()-1} is an F-basis, where \\spad{q = size()\\$F}. Implementation according to Lidl/Niederreiter: Theorem 2.39.")) (|normalElement| (($) "\\spad{normalElement()} returns a element, normal over the ground field \\spad{F,} thus \\spad{a**(q**i), 0 \\spad{<=} \\spad{i} < extensionDegree()} is an F-basis, where \\spad{q = size()\\$F}. At the first call, the element is computed by \\spadfunFrom{createNormalElement}{FiniteAlgebraicExtensionField} then cached in a global variable. On subsequent calls, the element is retrieved by referencing the global variable.")) (|createNormalElement| (($) "\\spad{createNormalElement()} computes a normal element over the ground field \\spad{F,} that is, \\spad{a**(q**i), 0 \\spad{<=} \\spad{i} < extensionDegree()} is an F-basis, where \\spad{q = size()\\$F}. Reference: Such an element exists Lidl/Niederreiter: Theorem 2.35.")) (|trace| (($ $ (|PositiveInteger|)) "\\spad{trace(a,d)} computes the trace of \\spad{a} with respect to the field of extension degree \\spad{d} over the ground field of size \\spad{q.} Error: if \\spad{d} does not divide the extension degree of \\spad{a}. Note that \\spad{trace(a,d)=reduce(+,[a**(q**(d*i)) for \\spad{i} in 0..n/d])}.") ((|#2| $) "\\spad{trace(a)} computes the trace of \\spad{a} with respect to the field considered as an algebra with 1 over the ground field \\spad{F.}")) (|norm| (($ $ (|PositiveInteger|)) "\\spad{norm(a,d)} computes the norm of \\spad{a} with respect to the field of extension degree \\spad{d} over the ground field of size. Error: if \\spad{d} does not divide the extension degree of \\spad{a}. Note that norm(a,d) = reduce(*,[a**(q**(d*i)) for \\spad{i} in 0..n/d])") ((|#2| $) "\\spad{norm(a)} computes the norm of \\spad{a} with respect to the field considered as an algebra with 1 over the ground field \\spad{F.}")) (|degree| (((|PositiveInteger|) $) "\\spad{degree(a)} returns the degree of the minimal polynomial of an element \\spad{a} over the ground field \\spad{F.}")) (|extensionDegree| (((|PositiveInteger|)) "\\spad{extensionDegree()} returns the degree of field extension.")) (|definingPolynomial| (((|SparseUnivariatePolynomial| |#2|)) "\\spad{definingPolynomial()} returns the polynomial used to define the field extension.")) (|minimalPolynomial| (((|SparseUnivariatePolynomial| $) $ (|PositiveInteger|)) "\\spad{minimalPolynomial(x,n)} computes the minimal polynomial of \\spad{x} over the field of extension degree \\spad{n} over the ground field \\spad{F.}") (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{minimalPolynomial(a)} returns the minimal polynomial of an element \\spad{a} over the ground field \\spad{F.}")) (|represents| (($ (|Vector| |#2|)) "\\spad{represents([a1,..,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where v1,...,vn are the elements of the fixed basis.")) (|coordinates| (((|Matrix| |#2|) (|Vector| $)) "\\spad{coordinates([v1,...,vm])} returns the coordinates of the vi's with to the fixed basis. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#2|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{F}-vectorspace basis.")) (|basis| (((|Vector| $) (|PositiveInteger|)) "\\spad{basis(n)} returns a fixed basis of a subfield of \\spad{\\$} as \\spad{F}-vectorspace.") (((|Vector| $)) "\\spad{basis()} returns a fixed basis of \\spad{\\$} as \\spad{F}-vectorspace."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-374)))) 
-(-329 -3313) 
+((|HasCategory| |#2| (QUOTE (-394)))) 
+(-349 -3958) 
 ((|constructor| (NIL "FiniteAlgebraicExtensionField \\spad{F} is the category of fields which are finite algebraic extensions of the field \\spad{F.} If \\spad{F} is finite then any finite algebraic extension of \\spad{F} is finite, too. Let \\spad{K} be a finite algebraic extension of the finite field \\spad{F.} The exponentiation of elements of \\spad{K} defines a Z-module structure on the multiplicative group of \\spad{K.} The additive group of \\spad{K} becomes a module over the ring of polynomials over \\spad{F} via the operation \\spadfun{linearAssociatedExp}(a:K,f:SparseUnivariatePolynomial \\spad{F)} which is linear over \\spad{F,} that is, for elements a from \\spad{K,} \\spad{c,d} from \\spad{F} and \\spad{f,g} univariate polynomials over \\spad{F} we have \\spadfun{linearAssociatedExp}(a,cf+dg) equals \\spad{c} times \\spadfun{linearAssociatedExp}(a,f) plus \\spad{d} times \\spadfun{linearAssociatedExp}(a,g). Therefore \\spadfun{linearAssociatedExp} is defined completely by its action on monomials from F[X]: \\spadfun{linearAssociatedExp}(a,monomial(1,k)\\$SUP(F)) is defined to be \\spadfun{Frobenius}(a,k) which is a**(q**k) where q=size()\\$F. The operations order and discreteLog associated with the multiplicative exponentiation have additive analogues associated to the operation \\spadfun{linearAssociatedExp}. These are the functions \\spadfun{linearAssociatedOrder} and \\spadfun{linearAssociatedLog}, respectively.")) (|linearAssociatedLog| (((|Union| (|SparseUnivariatePolynomial| |#1|) "failed") $ $) "\\spad{linearAssociatedLog(b,a)} returns a polynomial \\spad{g,} such that the \\spadfun{linearAssociatedExp}(b,g) equals a. If there is no such polynomial \\spad{g,} then \\spadfun{linearAssociatedLog} fails.") (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{linearAssociatedLog(a)} returns a polynomial \\spad{g,} such that \\spadfun{linearAssociatedExp}(normalElement(),g) equals a.")) (|linearAssociatedOrder| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{linearAssociatedOrder(a)} retruns the monic polynomial \\spad{g} of least degree, such that \\spadfun{linearAssociatedExp}(a,g) is 0.")) (|linearAssociatedExp| (($ $ (|SparseUnivariatePolynomial| |#1|)) "\\spad{linearAssociatedExp(a,f)} is linear over \\spad{F,} that is, for elements a from \\spad{\\$,} \\spad{c,d} form \\spad{F} and \\spad{f,g} univariate polynomials over \\spad{F} we have \\spadfun{linearAssociatedExp}(a,cf+dg) equals \\spad{c} times \\spadfun{linearAssociatedExp}(a,f) plus \\spad{d} times \\spadfun{linearAssociatedExp}(a,g). Therefore \\spadfun{linearAssociatedExp} is defined completely by its action on monomials from F[X]: \\spadfun{linearAssociatedExp}(a,monomial(1,k)\\$SUP(F)) is defined to be \\spadfun{Frobenius}(a,k) which is a**(q**k), where q=size()\\$F.")) (|generator| (($) "\\spad{generator()} returns a root of the defining polynomial. This element generates the field as an algebra over the ground field.")) (|normal?| (((|Boolean|) $) "\\spad{normal?(a)} tests whether the element \\spad{a} is normal over the ground field \\spad{F,} that is, \\spad{a**(q**i), 0 \\spad{<=} \\spad{i} \\spad{<=} extensionDegree()-1} is an F-basis, where \\spad{q = size()\\$F}. Implementation according to Lidl/Niederreiter: Theorem 2.39.")) (|normalElement| (($) "\\spad{normalElement()} returns a element, normal over the ground field \\spad{F,} thus \\spad{a**(q**i), 0 \\spad{<=} \\spad{i} < extensionDegree()} is an F-basis, where \\spad{q = size()\\$F}. At the first call, the element is computed by \\spadfunFrom{createNormalElement}{FiniteAlgebraicExtensionField} then cached in a global variable. On subsequent calls, the element is retrieved by referencing the global variable.")) (|createNormalElement| (($) "\\spad{createNormalElement()} computes a normal element over the ground field \\spad{F,} that is, \\spad{a**(q**i), 0 \\spad{<=} \\spad{i} < extensionDegree()} is an F-basis, where \\spad{q = size()\\$F}. Reference: Such an element exists Lidl/Niederreiter: Theorem 2.35.")) (|trace| (($ $ (|PositiveInteger|)) "\\spad{trace(a,d)} computes the trace of \\spad{a} with respect to the field of extension degree \\spad{d} over the ground field of size \\spad{q.} Error: if \\spad{d} does not divide the extension degree of \\spad{a}. Note that \\spad{trace(a,d)=reduce(+,[a**(q**(d*i)) for \\spad{i} in 0..n/d])}.") ((|#1| $) "\\spad{trace(a)} computes the trace of \\spad{a} with respect to the field considered as an algebra with 1 over the ground field \\spad{F.}")) (|norm| (($ $ (|PositiveInteger|)) "\\spad{norm(a,d)} computes the norm of \\spad{a} with respect to the field of extension degree \\spad{d} over the ground field of size. Error: if \\spad{d} does not divide the extension degree of \\spad{a}. Note that norm(a,d) = reduce(*,[a**(q**(d*i)) for \\spad{i} in 0..n/d])") ((|#1| $) "\\spad{norm(a)} computes the norm of \\spad{a} with respect to the field considered as an algebra with 1 over the ground field \\spad{F.}")) (|degree| (((|PositiveInteger|) $) "\\spad{degree(a)} returns the degree of the minimal polynomial of an element \\spad{a} over the ground field \\spad{F.}")) (|extensionDegree| (((|PositiveInteger|)) "\\spad{extensionDegree()} returns the degree of field extension.")) (|definingPolynomial| (((|SparseUnivariatePolynomial| |#1|)) "\\spad{definingPolynomial()} returns the polynomial used to define the field extension.")) (|minimalPolynomial| (((|SparseUnivariatePolynomial| $) $ (|PositiveInteger|)) "\\spad{minimalPolynomial(x,n)} computes the minimal polynomial of \\spad{x} over the field of extension degree \\spad{n} over the ground field \\spad{F.}") (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{minimalPolynomial(a)} returns the minimal polynomial of an element \\spad{a} over the ground field \\spad{F.}")) (|represents| (($ (|Vector| |#1|)) "\\spad{represents([a1,..,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where v1,...,vn are the elements of the fixed basis.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $)) "\\spad{coordinates([v1,...,vm])} returns the coordinates of the vi's with to the fixed basis. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#1|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{F}-vectorspace basis.")) (|basis| (((|Vector| $) (|PositiveInteger|)) "\\spad{basis(n)} returns a fixed basis of a subfield of \\spad{\\$} as \\spad{F}-vectorspace.") (((|Vector| $)) "\\spad{basis()} returns a fixed basis of \\spad{\\$} as \\spad{F}-vectorspace."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-330) 
+(-350) 
 ((|constructor| (NIL "This domain builds representations of program code segments for use with the FortranProgram domain.")) (|setLabelValue| (((|SingleInteger|) (|SingleInteger|)) "\\spad{setLabelValue(i)} resets the counter which produces labels to \\spad{i}")) (|getCode| (((|SExpression|) $) "\\spad{getCode(f)} returns a Lisp list of strings representing \\spad{f} in Fortran notation. This is used by the FortranProgram domain.")) (|printCode| (((|Void|) $) "\\spad{printCode(f)} prints out \\spad{f} in FORTRAN notation.")) (|code| (((|Union| (|:| |nullBranch| "null") (|:| |assignmentBranch| (|Record| (|:| |var| (|Symbol|)) (|:| |arrayIndex| (|List| (|Polynomial| (|Integer|)))) (|:| |rand| (|Record| (|:| |ints2Floats?| (|Boolean|)) (|:| |expr| (|OutputForm|)))))) (|:| |arrayAssignmentBranch| (|Record| (|:| |var| (|Symbol|)) (|:| |rand| (|OutputForm|)) (|:| |ints2Floats?| (|Boolean|)))) (|:| |conditionalBranch| (|Record| (|:| |switch| (|Switch|)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (|Record| (|:| |empty?| (|Boolean|)) (|:| |value| (|Record| (|:| |ints2Floats?| (|Boolean|)) (|:| |expr| (|OutputForm|)))))) (|:| |blockBranch| (|List| $)) (|:| |commentBranch| (|List| (|String|))) (|:| |callBranch| (|String|)) (|:| |forBranch| (|Record| (|:| |range| (|SegmentBinding| (|Polynomial| (|Integer|)))) (|:| |span| (|Polynomial| (|Integer|))) (|:| |body| $))) (|:| |labelBranch| (|SingleInteger|)) (|:| |loopBranch| (|Record| (|:| |switch| (|Switch|)) (|:| |body| $))) (|:| |commonBranch| (|Record| (|:| |name| (|Symbol|)) (|:| |contents| (|List| (|Symbol|))))) (|:| |printBranch| (|List| (|OutputForm|)))) $) "\\spad{code(f)} returns the internal representation of the object represented by \\spad{f}.")) (|operation| (((|Union| (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $) "\\spad{operation(f)} returns the name of the operation represented by \\spad{f}.")) (|common| (($ (|Symbol|) (|List| (|Symbol|))) "\\spad{common(name,contents)} creates a representation a named common block.")) (|printStatement| (($ (|List| (|OutputForm|))) "\\spad{printStatement(l)} creates a representation of a PRINT statement.")) (|save| (($) "\\spad{save()} creates a representation of a SAVE statement.")) (|stop| (($) "\\spad{stop()} creates a representation of a STOP statement.")) (|block| (($ (|List| $)) "\\spad{block(l)} creates a representation of the statements in \\spad{l} as a block.")) (|assign| (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|Complex| (|Float|)))) "\\spad{assign(x,l,y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}'th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|Float|))) "\\spad{assign(x,l,y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}'th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|Integer|))) "\\spad{assign(x,l,y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}'th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|Vector| (|Expression| (|Complex| (|Float|))))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|Expression| (|Float|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|Expression| (|Integer|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|Complex| (|Float|))))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|Float|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|Integer|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|Complex| (|Float|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|Float|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|Integer|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|MachineComplex|))) "\\spad{assign(x,l,y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}'th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|MachineFloat|))) "\\spad{assign(x,l,y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}'th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|MachineInteger|))) "\\spad{assign(x,l,y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}'th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|Vector| (|Expression| (|MachineComplex|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|Expression| (|MachineFloat|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|Expression| (|MachineInteger|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|MachineComplex|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|MachineFloat|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|MachineInteger|)))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|MachineComplex|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|MachineFloat|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|MachineInteger|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|MachineComplex|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|MachineFloat|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|MachineInteger|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|MachineComplex|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|MachineFloat|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|MachineInteger|))) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|String|)) "\\spad{assign(x,y)} creates a representation of the FORTRAN expression x=y.")) (|cond| (($ (|Switch|) $ $) "\\spad{cond(s,e,f)} creates a representation of the FORTRAN expression IF \\spad{(s)} THEN \\spad{e} ELSE \\spad{f.}") (($ (|Switch|) $) "\\spad{cond(s,e)} creates a representation of the FORTRAN expression IF \\spad{(s)} THEN e.")) (|returns| (($ (|Expression| (|Complex| (|Float|)))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|Integer|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|Float|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|MachineComplex|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|MachineInteger|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|MachineFloat|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($) "\\spad{returns()} creates a representation of a FORTRAN RETURN statement.")) (|call| (($ (|String|)) "\\spad{call(s)} creates a representation of a FORTRAN CALL statement")) (|comment| (($ (|List| (|String|))) "\\spad{comment(s)} creates a representation of the Strings \\spad{s} as a multi-line FORTRAN comment.") (($ (|String|)) "\\spad{comment(s)} creates a representation of the String \\spad{s} as a single FORTRAN comment.")) (|continue| (($ (|SingleInteger|)) "\\spad{continue(l)} creates a representation of a FORTRAN CONTINUE labelled with \\spad{l}")) (|goto| (($ (|SingleInteger|)) "\\spad{goto(l)} creates a representation of a FORTRAN GOTO statement")) (|repeatUntilLoop| (($ (|Switch|) $) "\\spad{repeatUntilLoop(s,c)} creates a repeat \\spad{...} until loop in FORTRAN.")) (|whileLoop| (($ (|Switch|) $) "\\spad{whileLoop(s,c)} creates a while loop in FORTRAN.")) (|forLoop| (($ (|SegmentBinding| (|Polynomial| (|Integer|))) (|Polynomial| (|Integer|)) $) "\\spad{forLoop(i=1..10,n,c)} creates a representation of a FORTRAN DO loop with \\spad{i} ranging over the values 1 to 10 by \\spad{n.}") (($ (|SegmentBinding| (|Polynomial| (|Integer|))) $) "\\spad{forLoop(i=1..10,c)} creates a representation of a FORTRAN DO loop with \\spad{i} ranging over the values 1 to 10.")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(f)} returns an object of type OutputForm."))) 
 NIL 
 NIL 
-(-331 E) 
+(-351 E) 
 ((|constructor| (NIL "This domain creates kernels for use in Fourier series")) (|argument| ((|#1| $) "\\spad{argument(x)} returns the argument of a given sin/cos expressions")) (|sin?| (((|Boolean|) $) "\\spad{sin?(x)} returns \\spad{true} if term is a sin, otherwise \\spad{false}")) (|cos| (($ |#1|) "\\spad{cos(x)} makes a cos kernel for use in Fourier series")) (|sin| (($ |#1|) "\\spad{sin(x)} makes a sin kernel for use in Fourier series"))) 
 NIL 
 NIL 
-(-332) 
+(-352) 
 ((|constructor| (NIL "\\spadtype{FortranCodePackage1} provides some utilities for producing useful objects in FortranCode domain. The Package may be used with the FortranCode domain and its \\spad{printCode} or possibly via an outputAsFortran. (The package provides items of use in connection with ASPs in the AXIOM-NAG link and, where appropriate, naming accords with that in IRENA.) The easy-to-use functions use Fortran loop variables I1, I2, and it is users' responsibility to check that this is sensible. The advanced functions use SegmentBinding to allow users control over Fortran loop variable names.")) (|identitySquareMatrix| (((|FortranCode|) (|Symbol|) (|Polynomial| (|Integer|))) "\\spad{identitySquareMatrix(s,p)} \\undocumented{}")) (|zeroSquareMatrix| (((|FortranCode|) (|Symbol|) (|Polynomial| (|Integer|))) "\\spad{zeroSquareMatrix(s,p)} \\undocumented{}")) (|zeroMatrix| (((|FortranCode|) (|Symbol|) (|SegmentBinding| (|Polynomial| (|Integer|))) (|SegmentBinding| (|Polynomial| (|Integer|)))) "\\spad{zeroMatrix(s,b,d)} in this version gives the user control over names of Fortran variables used in loops.") (((|FortranCode|) (|Symbol|) (|Polynomial| (|Integer|)) (|Polynomial| (|Integer|))) "\\spad{zeroMatrix(s,p,q)} uses loop variables in the Fortran, \\spad{I1} and \\spad{I2}")) (|zeroVector| (((|FortranCode|) (|Symbol|) (|Polynomial| (|Integer|))) "\\spad{zeroVector(s,p)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-333 R1 UP1 UPUP1 F1 R2 UP2 UPUP2 F2) 
+(-353 R1 UP1 UPUP1 F1 R2 UP2 UPUP2 F2) 
 ((|constructor| (NIL "Lift a map to finite divisors.")) (|map| (((|FiniteDivisor| |#5| |#6| |#7| |#8|) (|Mapping| |#5| |#1|) (|FiniteDivisor| |#1| |#2| |#3| |#4|)) "\\spad{map(f,d)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-334 S -3313 UP UPUP R) 
+(-354 S -3958 UP UPUP R) 
 ((|constructor| (NIL "This category describes finite rational divisors on a curve, that is finite formal sums SUM(n * \\spad{P)} where the \\spad{n's} are integers and the \\spad{P's} are finite rational points on the curve.")) (|generator| (((|Union| |#5| "failed") $) "\\spad{generator(d)} returns \\spad{f} if \\spad{(f) = \\spad{d},} \"failed\" if \\spad{d} is not principal.")) (|principal?| (((|Boolean|) $) "\\spad{principal?(D)} tests if the argument is the divisor of a function.")) (|reduce| (($ $) "\\spad{reduce(D)} converts \\spad{D} to some reduced form (the reduced forms can be differents in different implementations).")) (|decompose| (((|Record| (|:| |id| (|FractionalIdeal| |#3| (|Fraction| |#3|) |#4| |#5|)) (|:| |principalPart| |#5|)) $) "\\spad{decompose(d)} returns \\spad{[id, \\spad{f]}} where \\spad{d = (id) + div(f)}.")) (|divisor| (($ |#5| |#3| |#3| |#3| |#2|) "\\spad{divisor(h, \\spad{d,} \\spad{d',} \\spad{g,} \\spad{r)}} returns the sum of all the finite points where \\spad{h/d} has residue \\spad{r}. \\spad{h} must be integral. \\spad{d} must be squarefree. \\spad{d'} is some derivative of \\spad{d} (not necessarily dd/dx). \\spad{g = gcd(d,discriminant)} contains the ramified zeros of \\spad{d}") (($ |#2| |#2| (|Integer|)) "\\spad{divisor(a, \\spad{b,} \\spad{n)}} makes the divisor \\spad{nP} where \\spad{P:} \\spad{(x = a, \\spad{y} = b)}. \\spad{P} is allowed to be singular if \\spad{n} is a multiple of the rank.") (($ |#2| |#2|) "\\spad{divisor(a, \\spad{b)}} makes the divisor \\spad{P:} \\spad{(x = a, \\spad{y} = b)}. Error: if \\spad{P} is singular.") (($ |#5|) "\\spad{divisor(g)} returns the divisor of the function \\spad{g.}") (($ (|FractionalIdeal| |#3| (|Fraction| |#3|) |#4| |#5|)) "\\spad{divisor(I)} makes a divisor \\spad{D} from an ideal I.")) (|ideal| (((|FractionalIdeal| |#3| (|Fraction| |#3|) |#4| |#5|) $) "\\spad{ideal(D)} returns the ideal corresponding to a divisor \\spad{D.}"))) 
 NIL 
 NIL 
-(-335 -3313 UP UPUP R) 
+(-355 -3958 UP UPUP R) 
 ((|constructor| (NIL "This category describes finite rational divisors on a curve, that is finite formal sums SUM(n * \\spad{P)} where the \\spad{n's} are integers and the \\spad{P's} are finite rational points on the curve.")) (|generator| (((|Union| |#4| "failed") $) "\\spad{generator(d)} returns \\spad{f} if \\spad{(f) = \\spad{d},} \"failed\" if \\spad{d} is not principal.")) (|principal?| (((|Boolean|) $) "\\spad{principal?(D)} tests if the argument is the divisor of a function.")) (|reduce| (($ $) "\\spad{reduce(D)} converts \\spad{D} to some reduced form (the reduced forms can be differents in different implementations).")) (|decompose| (((|Record| (|:| |id| (|FractionalIdeal| |#2| (|Fraction| |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) "\\spad{decompose(d)} returns \\spad{[id, \\spad{f]}} where \\spad{d = (id) + div(f)}.")) (|divisor| (($ |#4| |#2| |#2| |#2| |#1|) "\\spad{divisor(h, \\spad{d,} \\spad{d',} \\spad{g,} \\spad{r)}} returns the sum of all the finite points where \\spad{h/d} has residue \\spad{r}. \\spad{h} must be integral. \\spad{d} must be squarefree. \\spad{d'} is some derivative of \\spad{d} (not necessarily dd/dx). \\spad{g = gcd(d,discriminant)} contains the ramified zeros of \\spad{d}") (($ |#1| |#1| (|Integer|)) "\\spad{divisor(a, \\spad{b,} \\spad{n)}} makes the divisor \\spad{nP} where \\spad{P:} \\spad{(x = a, \\spad{y} = b)}. \\spad{P} is allowed to be singular if \\spad{n} is a multiple of the rank.") (($ |#1| |#1|) "\\spad{divisor(a, \\spad{b)}} makes the divisor \\spad{P:} \\spad{(x = a, \\spad{y} = b)}. Error: if \\spad{P} is singular.") (($ |#4|) "\\spad{divisor(g)} returns the divisor of the function \\spad{g.}") (($ (|FractionalIdeal| |#2| (|Fraction| |#2|) |#3| |#4|)) "\\spad{divisor(I)} makes a divisor \\spad{D} from an ideal I.")) (|ideal| (((|FractionalIdeal| |#2| (|Fraction| |#2|) |#3| |#4|) $) "\\spad{ideal(D)} returns the ideal corresponding to a divisor \\spad{D.}"))) 
 NIL 
 NIL 
-(-336 -3313 UP UPUP R) 
+(-356 -3958 UP UPUP R) 
 ((|constructor| (NIL "This domains implements finite rational divisors on a curve, that is finite formal sums SUM(n * \\spad{P)} where the \\spad{n's} are integers and the \\spad{P's} are finite rational points on the curve.")) (|lSpaceBasis| (((|Vector| |#4|) $) "\\spad{lSpaceBasis(d)} returns a basis for \\spad{L(d) = \\spad{{f} | \\spad{(f)} \\spad{>=} -d}} as a module over \\spad{K[x]}.")) (|finiteBasis| (((|Vector| |#4|) $) "\\spad{finiteBasis(d)} returns a basis for \\spad{d} as a module over K[x]."))) 
 NIL 
 NIL 
-(-337 S R) 
+(-357 S R) 
 ((|constructor| (NIL "This category provides a selection of evaluation operations depending on what the argument type \\spad{R} provides.")) (|map| (($ (|Mapping| |#2| |#2|) $) "\\spad{map(f, ex)} evaluates ex, applying \\spad{f} to values of type \\spad{R} in ex."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -283) (|devaluate| |#2|) (|devaluate| |#2|)))) 
-(-338 R) 
+((|HasCategory| |#2| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|) (|devaluate| |#2|)))) 
+(-358 R) 
 ((|constructor| (NIL "This category provides a selection of evaluation operations depending on what the argument type \\spad{R} provides.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f, ex)} evaluates ex, applying \\spad{f} to values of type \\spad{R} in ex."))) 
 NIL 
 NIL 
-(-339 |basicSymbols| |subscriptedSymbols| R) 
+(-359 |basicSymbols| |subscriptedSymbols| R) 
 ((|constructor| (NIL "A domain of expressions involving functions which can be translated into standard Fortran-77, with some extra extensions from the NAG Fortran Library.")) (|useNagFunctions| (((|Boolean|) (|Boolean|)) "\\spad{useNagFunctions(v)} sets the flag which controls whether NAG functions \\indented{1}{are being used for mathematical and machine constants.\\space{2}The previous} \\indented{1}{value is returned.}") (((|Boolean|)) "\\spad{useNagFunctions()} indicates whether NAG functions are being used \\indented{1}{for mathematical and machine constants.}")) (|variables| (((|List| (|Symbol|)) $) "\\spad{variables(e)} return a list of all the variables in \\spad{e}.")) (|pi| (($) "\\spad{pi(x)} represents the NAG Library function X01AAF which returns \\indented{1}{an approximation to the value of pi}")) (|tanh| (($ $) "\\spad{tanh(x)} represents the Fortran intrinsic function TANH")) (|cosh| (($ $) "\\spad{cosh(x)} represents the Fortran intrinsic function COSH")) (|sinh| (($ $) "\\spad{sinh(x)} represents the Fortran intrinsic function SINH")) (|atan| (($ $) "\\spad{atan(x)} represents the Fortran intrinsic function ATAN")) (|acos| (($ $) "\\spad{acos(x)} represents the Fortran intrinsic function ACOS")) (|asin| (($ $) "\\spad{asin(x)} represents the Fortran intrinsic function ASIN")) (|tan| (($ $) "\\spad{tan(x)} represents the Fortran intrinsic function TAN")) (|cos| (($ $) "\\spad{cos(x)} represents the Fortran intrinsic function COS")) (|sin| (($ $) "\\spad{sin(x)} represents the Fortran intrinsic function SIN")) (|log10| (($ $) "\\spad{log10(x)} represents the Fortran intrinsic function \\spad{LOG10}")) (|log| (($ $) "\\spad{log(x)} represents the Fortran intrinsic function LOG")) (|exp| (($ $) "\\spad{exp(x)} represents the Fortran intrinsic function EXP")) (|sqrt| (($ $) "\\spad{sqrt(x)} represents the Fortran intrinsic function SQRT")) (|abs| (($ $) "\\spad{abs(x)} represents the Fortran intrinsic function ABS")) (|coerce| (((|Expression| |#3|) $) "\\spad{coerce(x)} is not documented")) (|retractIfCan| (((|Union| $ "failed") (|Polynomial| (|Float|))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Fraction| (|Polynomial| (|Float|)))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Expression| (|Float|))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Fraction| (|Polynomial| (|Integer|)))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Expression| (|Integer|))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Symbol|)) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it is one of the given basic symbols or subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Expression| |#3|)) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.")) (|retract| (($ (|Polynomial| (|Float|))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Fraction| (|Polynomial| (|Float|)))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Expression| (|Float|))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Polynomial| (|Integer|))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Fraction| (|Polynomial| (|Integer|)))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Expression| (|Integer|))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Symbol|)) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it is one of the given basic symbols or subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Expression| |#3|)) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions, and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-385)))) (|HasCategory| $ (QUOTE (-1054))) (|HasCategory| $ (LIST (QUOTE -1044) (QUOTE (-572))))) 
-(-340 R1 UP1 UPUP1 F1 R2 UP2 UPUP2 F2) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-405)))) (|HasCategory| $ (QUOTE (-1075))) (|HasCategory| $ (LIST (QUOTE -1065) (QUOTE (-592))))) 
+(-360 R1 UP1 UPUP1 F1 R2 UP2 UPUP2 F2) 
 ((|constructor| (NIL "Lifts a map from rings to function fields over them.")) (|map| ((|#8| (|Mapping| |#5| |#1|) |#4|) "\\spad{map(f, \\spad{p)}} lifts \\spad{f} to \\spad{F1} and applies it to \\spad{p.}"))) 
 NIL 
 NIL 
-(-341 S -3313 UP UPUP) 
+(-361 S -3958 UP UPUP) 
 ((|constructor| (NIL "Function field of a curve This category is a model for the function field of a plane algebraic curve.")) (|rationalPoints| (((|List| (|List| |#2|))) "\\spad{rationalPoints()} returns the list of all the affine rational points.")) (|nonSingularModel| (((|List| (|Polynomial| |#2|)) (|Symbol|)) "\\spad{nonSingularModel(u)} returns the equations in u1,...,un of \\indented{1}{an affine non-singular model for the curve.}")) (|algSplitSimple| (((|Record| (|:| |num| $) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) $ (|Mapping| |#3| |#3|)) "\\spad{algSplitSimple(f, \\spad{D)}} returns \\spad{[h,d,d',g]} such that \\indented{1}{\\spad{f=h/d},} \\indented{1}{\\spad{h} is integral at all the normal places w.r.t. \\spad{D},} \\indented{1}{\\spad{d' = Dd}, \\spad{g = gcd(d, discriminant())} and \\spad{D}} \\indented{1}{is the derivation to use. \\spad{f} must have at most simple finite} \\indented{1}{poles.}")) (|hyperelliptic| (((|Union| |#3| "failed")) "\\spad{hyperelliptic()} returns \\spad{p(x)} if the curve is the \\indented{1}{hyperelliptic} \\indented{1}{defined by \\spad{y**2 = p(x)}, \"failed\" otherwise.}")) (|elliptic| (((|Union| |#3| "failed")) "\\spad{elliptic()} returns \\spad{p(x)} if the curve is the elliptic \\indented{1}{defined by \\spad{y**2 = p(x)}, \"failed\" otherwise.}")) (|elt| ((|#2| $ |#2| |#2|) "\\spad{elt(f,a,b)} or f(a, \\spad{b)} returns the value of \\spad{f} \\indented{1}{at the point \\spad{(x = a, \\spad{y} = b)}} \\indented{1}{if it is not singular.}")) (|primitivePart| (($ $) "\\spad{primitivePart(f)} removes the content of the denominator and \\indented{1}{the common content of the numerator of \\spad{f.}}")) (|differentiate| (($ $ (|Mapping| |#3| |#3|)) "\\spad{differentiate(x, \\spad{d)}} extends the derivation \\spad{d} from UP to \\$ and \\indented{1}{applies it to \\spad{x.}}")) (|integralDerivationMatrix| (((|Record| (|:| |num| (|Matrix| |#3|)) (|:| |den| |#3|)) (|Mapping| |#3| |#3|)) "\\spad{integralDerivationMatrix(d)} extends the derivation \\spad{d} from UP to \\$ \\indented{1}{and returns \\spad{(M,} \\spad{Q)} such that the i^th row of \\spad{M} divided by \\spad{Q} form} \\indented{1}{the coordinates of \\spad{d(wi)} with respect to \\spad{(w1,...,wn)}} \\indented{1}{where \\spad{(w1,...,wn)} is the integral basis returned} \\indented{1}{by integralBasis().}")) (|integralRepresents| (($ (|Vector| |#3|) |#3|) "\\spad{integralRepresents([A1,...,An], \\spad{D)}} returns \\indented{1}{\\spad{(A1 w1+...+An wn)/D}} \\indented{1}{where \\spad{(w1,...,wn)} is the integral} \\indented{1}{basis of \\spad{integralBasis()}.}")) (|integralCoordinates| (((|Record| (|:| |num| (|Vector| |#3|)) (|:| |den| |#3|)) $) "\\spad{integralCoordinates(f)} returns \\spad{[[A1,...,An], \\spad{D]}} such that \\indented{1}{\\spad{f = \\spad{(A1} \\spad{w1} +...+ An \\spad{wn)} / D}\\space{2}where \\spad{(w1,...,wn)} is the} \\indented{1}{integral basis returned by \\spad{integralBasis()}.}")) (|represents| (($ (|Vector| |#3|) |#3|) "\\spad{represents([A0,...,A(n-1)],D)} returns \\indented{1}{\\spad{(A0 + \\spad{A1} \\spad{y} +...+ A(n-1)*y**(n-1))/D}.}") (($ (|Vector| |#3|) |#3|) "\\spad{represents([A0,...,A(n-1)],D)} returns \\indented{1}{\\spad{(A0 + \\spad{A1} \\spad{y} +...+ A(n-1)*y**(n-1))/D}.}")) (|yCoordinates| (((|Record| (|:| |num| (|Vector| |#3|)) (|:| |den| |#3|)) $) "\\spad{yCoordinates(f)} returns \\spad{[[A1,...,An], \\spad{D]}} such that \\indented{1}{\\spad{f = \\spad{(A1} + \\spad{A2} \\spad{y} +...+ An y**(n-1)) / D}.}")) (|inverseIntegralMatrixAtInfinity| (((|Matrix| (|Fraction| |#3|))) "\\spad{inverseIntegralMatrixAtInfinity()} returns \\spad{M} such \\indented{1}{that \\spad{M (v1,...,vn) = \\spad{(1,} \\spad{y,} ..., y**(n-1))}} \\indented{1}{where \\spad{(v1,...,vn)} is the local integral basis at infinity} \\indented{1}{returned by \\spad{infIntBasis()}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} inverseIntegralMatrixAtInfinity()$R")) (|integralMatrixAtInfinity| (((|Matrix| (|Fraction| |#3|))) "\\spad{integralMatrixAtInfinity()} returns \\spad{M} such that \\indented{1}{\\spad{(v1,...,vn) = \\spad{M} \\spad{(1,} \\spad{y,} ..., y**(n-1))}} \\indented{1}{where \\spad{(v1,...,vn)} is the local integral basis at infinity} \\indented{1}{returned by \\spad{infIntBasis()}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} integralMatrixAtInfinity()$R")) (|inverseIntegralMatrix| (((|Matrix| (|Fraction| |#3|))) "\\spad{inverseIntegralMatrix()} returns \\spad{M} such that \\indented{1}{\\spad{M (w1,...,wn) = \\spad{(1,} \\spad{y,} ..., y**(n-1))}} \\indented{1}{where \\spad{(w1,...,wn)} is the integral basis of} \\indented{1}{\\spadfunFrom{integralBasis}{FunctionFieldCategory}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} inverseIntegralMatrix()$R")) (|integralMatrix| (((|Matrix| (|Fraction| |#3|))) "\\spad{integralMatrix()} returns \\spad{M} such that \\indented{1}{\\spad{(w1,...,wn) = \\spad{M} \\spad{(1,} \\spad{y,} ..., y**(n-1))},} \\indented{1}{where \\spad{(w1,...,wn)} is the integral basis of} \\indented{1}{\\spadfunFrom{integralBasis}{FunctionFieldCategory}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} integralMatrix()$R")) (|reduceBasisAtInfinity| (((|Vector| $) (|Vector| $)) "\\spad{reduceBasisAtInfinity(b1,...,bn)} returns \\spad{(x**i * bj)} \\indented{1}{for all i,j such that \\spad{x**i*bj} is locally integral} \\indented{1}{at infinity.}")) (|normalizeAtInfinity| (((|Vector| $) (|Vector| $)) "\\spad{normalizeAtInfinity(v)} makes \\spad{v} normal at infinity.")) (|complementaryBasis| (((|Vector| $) (|Vector| $)) "\\spad{complementaryBasis(b1,...,bn)} returns the complementary basis \\indented{1}{\\spad{(b1',...,bn')} of \\spad{(b1,...,bn)}.}")) (|integral?| (((|Boolean|) $ |#3|) "\\spad{integral?(f, \\spad{p)}} tests whether \\spad{f} is locally integral at \\indented{1}{\\spad{p(x) = 0}}") (((|Boolean|) $ |#2|) "\\spad{integral?(f, a)} tests whether \\spad{f} is locally integral at \\spad{x = a}.") (((|Boolean|) $) "\\spad{integral?()} tests if \\spad{f} is integral over \\spad{k[x]}.")) (|integralAtInfinity?| (((|Boolean|) $) "\\spad{integralAtInfinity?()} tests if \\spad{f} is locally integral at infinity.")) (|integralBasisAtInfinity| (((|Vector| $)) "\\spad{integralBasisAtInfinity()} returns the local integral basis \\indented{1}{at infinity} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} integralBasisAtInfinity()$R")) (|integralBasis| (((|Vector| $)) "\\spad{integralBasis()} returns the integral basis for the curve. \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} integralBasis()$R")) (|ramified?| (((|Boolean|) |#3|) "\\spad{ramified?(p)} tests whether \\spad{p(x) = 0} is ramified.") (((|Boolean|) |#2|) "\\spad{ramified?(a)} tests whether \\spad{x = a} is ramified.")) (|ramifiedAtInfinity?| (((|Boolean|)) "\\spad{ramifiedAtInfinity?()} tests if infinity is ramified.")) (|singular?| (((|Boolean|) |#3|) "\\spad{singular?(p)} tests whether \\spad{p(x) = 0} is singular.") (((|Boolean|) |#2|) "\\spad{singular?(a)} tests whether \\spad{x = a} is singular.")) (|singularAtInfinity?| (((|Boolean|)) "\\spad{singularAtInfinity?()} tests if there is a singularity at infinity.")) (|branchPoint?| (((|Boolean|) |#3|) "\\spad{branchPoint?(p)} tests whether \\spad{p(x) = 0} is a branch point.") (((|Boolean|) |#2|) "\\spad{branchPoint?(a)} tests whether \\spad{x = a} is a branch point.")) (|branchPointAtInfinity?| (((|Boolean|)) "\\spad{branchPointAtInfinity?()} tests if there is a branch point \\indented{1}{at infinity.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} branchPointAtInfinity?()$R \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 2 * x**2, 4) \\spad{X} branchPointAtInfinity?()$R")) (|rationalPoint?| (((|Boolean|) |#2| |#2|) "\\spad{rationalPoint?(a, \\spad{b)}} tests if \\spad{(x=a,y=b)} is on the curve. \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} rationalPoint?(0,0)$R \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 2 * x**2, 4) \\spad{X} \\spad{rationalPoint?(0,0)$R2}")) (|absolutelyIrreducible?| (((|Boolean|)) "\\spad{absolutelyIrreducible?()} tests if the curve absolutely irreducible? \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 2 * x**2, 4) \\spad{X} \\spad{absolutelyIrreducible?()$R2}")) (|genus| (((|NonNegativeInteger|)) "\\spad{genus()} returns the genus of one absolutely irreducible component \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} genus()$R")) (|numberOfComponents| (((|NonNegativeInteger|)) "\\spad{numberOfComponents()} returns the number of absolutely irreducible \\indented{1}{components.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} numberOfComponents()$R"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-374))) (|HasCategory| |#2| (QUOTE (-368)))) 
-(-342 -3313 UP UPUP) 
+((|HasCategory| |#2| (QUOTE (-394))) (|HasCategory| |#2| (QUOTE (-388)))) 
+(-362 -3958 UP UPUP) 
 ((|constructor| (NIL "Function field of a curve This category is a model for the function field of a plane algebraic curve.")) (|rationalPoints| (((|List| (|List| |#1|))) "\\spad{rationalPoints()} returns the list of all the affine rational points.")) (|nonSingularModel| (((|List| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{nonSingularModel(u)} returns the equations in u1,...,un of \\indented{1}{an affine non-singular model for the curve.}")) (|algSplitSimple| (((|Record| (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (|Mapping| |#2| |#2|)) "\\spad{algSplitSimple(f, \\spad{D)}} returns \\spad{[h,d,d',g]} such that \\indented{1}{\\spad{f=h/d},} \\indented{1}{\\spad{h} is integral at all the normal places w.r.t. \\spad{D},} \\indented{1}{\\spad{d' = Dd}, \\spad{g = gcd(d, discriminant())} and \\spad{D}} \\indented{1}{is the derivation to use. \\spad{f} must have at most simple finite} \\indented{1}{poles.}")) (|hyperelliptic| (((|Union| |#2| "failed")) "\\spad{hyperelliptic()} returns \\spad{p(x)} if the curve is the \\indented{1}{hyperelliptic} \\indented{1}{defined by \\spad{y**2 = p(x)}, \"failed\" otherwise.}")) (|elliptic| (((|Union| |#2| "failed")) "\\spad{elliptic()} returns \\spad{p(x)} if the curve is the elliptic \\indented{1}{defined by \\spad{y**2 = p(x)}, \"failed\" otherwise.}")) (|elt| ((|#1| $ |#1| |#1|) "\\spad{elt(f,a,b)} or f(a, \\spad{b)} returns the value of \\spad{f} \\indented{1}{at the point \\spad{(x = a, \\spad{y} = b)}} \\indented{1}{if it is not singular.}")) (|primitivePart| (($ $) "\\spad{primitivePart(f)} removes the content of the denominator and \\indented{1}{the common content of the numerator of \\spad{f.}}")) (|differentiate| (($ $ (|Mapping| |#2| |#2|)) "\\spad{differentiate(x, \\spad{d)}} extends the derivation \\spad{d} from UP to \\$ and \\indented{1}{applies it to \\spad{x.}}")) (|integralDerivationMatrix| (((|Record| (|:| |num| (|Matrix| |#2|)) (|:| |den| |#2|)) (|Mapping| |#2| |#2|)) "\\spad{integralDerivationMatrix(d)} extends the derivation \\spad{d} from UP to \\$ \\indented{1}{and returns \\spad{(M,} \\spad{Q)} such that the i^th row of \\spad{M} divided by \\spad{Q} form} \\indented{1}{the coordinates of \\spad{d(wi)} with respect to \\spad{(w1,...,wn)}} \\indented{1}{where \\spad{(w1,...,wn)} is the integral basis returned} \\indented{1}{by integralBasis().}")) (|integralRepresents| (($ (|Vector| |#2|) |#2|) "\\spad{integralRepresents([A1,...,An], \\spad{D)}} returns \\indented{1}{\\spad{(A1 w1+...+An wn)/D}} \\indented{1}{where \\spad{(w1,...,wn)} is the integral} \\indented{1}{basis of \\spad{integralBasis()}.}")) (|integralCoordinates| (((|Record| (|:| |num| (|Vector| |#2|)) (|:| |den| |#2|)) $) "\\spad{integralCoordinates(f)} returns \\spad{[[A1,...,An], \\spad{D]}} such that \\indented{1}{\\spad{f = \\spad{(A1} \\spad{w1} +...+ An \\spad{wn)} / D}\\space{2}where \\spad{(w1,...,wn)} is the} \\indented{1}{integral basis returned by \\spad{integralBasis()}.}")) (|represents| (($ (|Vector| |#2|) |#2|) "\\spad{represents([A0,...,A(n-1)],D)} returns \\indented{1}{\\spad{(A0 + \\spad{A1} \\spad{y} +...+ A(n-1)*y**(n-1))/D}.}") (($ (|Vector| |#2|) |#2|) "\\spad{represents([A0,...,A(n-1)],D)} returns \\indented{1}{\\spad{(A0 + \\spad{A1} \\spad{y} +...+ A(n-1)*y**(n-1))/D}.}")) (|yCoordinates| (((|Record| (|:| |num| (|Vector| |#2|)) (|:| |den| |#2|)) $) "\\spad{yCoordinates(f)} returns \\spad{[[A1,...,An], \\spad{D]}} such that \\indented{1}{\\spad{f = \\spad{(A1} + \\spad{A2} \\spad{y} +...+ An y**(n-1)) / D}.}")) (|inverseIntegralMatrixAtInfinity| (((|Matrix| (|Fraction| |#2|))) "\\spad{inverseIntegralMatrixAtInfinity()} returns \\spad{M} such \\indented{1}{that \\spad{M (v1,...,vn) = \\spad{(1,} \\spad{y,} ..., y**(n-1))}} \\indented{1}{where \\spad{(v1,...,vn)} is the local integral basis at infinity} \\indented{1}{returned by \\spad{infIntBasis()}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} inverseIntegralMatrixAtInfinity()$R")) (|integralMatrixAtInfinity| (((|Matrix| (|Fraction| |#2|))) "\\spad{integralMatrixAtInfinity()} returns \\spad{M} such that \\indented{1}{\\spad{(v1,...,vn) = \\spad{M} \\spad{(1,} \\spad{y,} ..., y**(n-1))}} \\indented{1}{where \\spad{(v1,...,vn)} is the local integral basis at infinity} \\indented{1}{returned by \\spad{infIntBasis()}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} integralMatrixAtInfinity()$R")) (|inverseIntegralMatrix| (((|Matrix| (|Fraction| |#2|))) "\\spad{inverseIntegralMatrix()} returns \\spad{M} such that \\indented{1}{\\spad{M (w1,...,wn) = \\spad{(1,} \\spad{y,} ..., y**(n-1))}} \\indented{1}{where \\spad{(w1,...,wn)} is the integral basis of} \\indented{1}{\\spadfunFrom{integralBasis}{FunctionFieldCategory}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} inverseIntegralMatrix()$R")) (|integralMatrix| (((|Matrix| (|Fraction| |#2|))) "\\spad{integralMatrix()} returns \\spad{M} such that \\indented{1}{\\spad{(w1,...,wn) = \\spad{M} \\spad{(1,} \\spad{y,} ..., y**(n-1))},} \\indented{1}{where \\spad{(w1,...,wn)} is the integral basis of} \\indented{1}{\\spadfunFrom{integralBasis}{FunctionFieldCategory}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} integralMatrix()$R")) (|reduceBasisAtInfinity| (((|Vector| $) (|Vector| $)) "\\spad{reduceBasisAtInfinity(b1,...,bn)} returns \\spad{(x**i * bj)} \\indented{1}{for all i,j such that \\spad{x**i*bj} is locally integral} \\indented{1}{at infinity.}")) (|normalizeAtInfinity| (((|Vector| $) (|Vector| $)) "\\spad{normalizeAtInfinity(v)} makes \\spad{v} normal at infinity.")) (|complementaryBasis| (((|Vector| $) (|Vector| $)) "\\spad{complementaryBasis(b1,...,bn)} returns the complementary basis \\indented{1}{\\spad{(b1',...,bn')} of \\spad{(b1,...,bn)}.}")) (|integral?| (((|Boolean|) $ |#2|) "\\spad{integral?(f, \\spad{p)}} tests whether \\spad{f} is locally integral at \\indented{1}{\\spad{p(x) = 0}}") (((|Boolean|) $ |#1|) "\\spad{integral?(f, a)} tests whether \\spad{f} is locally integral at \\spad{x = a}.") (((|Boolean|) $) "\\spad{integral?()} tests if \\spad{f} is integral over \\spad{k[x]}.")) (|integralAtInfinity?| (((|Boolean|) $) "\\spad{integralAtInfinity?()} tests if \\spad{f} is locally integral at infinity.")) (|integralBasisAtInfinity| (((|Vector| $)) "\\spad{integralBasisAtInfinity()} returns the local integral basis \\indented{1}{at infinity} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} integralBasisAtInfinity()$R")) (|integralBasis| (((|Vector| $)) "\\spad{integralBasis()} returns the integral basis for the curve. \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} integralBasis()$R")) (|ramified?| (((|Boolean|) |#2|) "\\spad{ramified?(p)} tests whether \\spad{p(x) = 0} is ramified.") (((|Boolean|) |#1|) "\\spad{ramified?(a)} tests whether \\spad{x = a} is ramified.")) (|ramifiedAtInfinity?| (((|Boolean|)) "\\spad{ramifiedAtInfinity?()} tests if infinity is ramified.")) (|singular?| (((|Boolean|) |#2|) "\\spad{singular?(p)} tests whether \\spad{p(x) = 0} is singular.") (((|Boolean|) |#1|) "\\spad{singular?(a)} tests whether \\spad{x = a} is singular.")) (|singularAtInfinity?| (((|Boolean|)) "\\spad{singularAtInfinity?()} tests if there is a singularity at infinity.")) (|branchPoint?| (((|Boolean|) |#2|) "\\spad{branchPoint?(p)} tests whether \\spad{p(x) = 0} is a branch point.") (((|Boolean|) |#1|) "\\spad{branchPoint?(a)} tests whether \\spad{x = a} is a branch point.")) (|branchPointAtInfinity?| (((|Boolean|)) "\\spad{branchPointAtInfinity?()} tests if there is a branch point \\indented{1}{at infinity.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} branchPointAtInfinity?()$R \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 2 * x**2, 4) \\spad{X} branchPointAtInfinity?()$R")) (|rationalPoint?| (((|Boolean|) |#1| |#1|) "\\spad{rationalPoint?(a, \\spad{b)}} tests if \\spad{(x=a,y=b)} is on the curve. \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} rationalPoint?(0,0)$R \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 2 * x**2, 4) \\spad{X} \\spad{rationalPoint?(0,0)$R2}")) (|absolutelyIrreducible?| (((|Boolean|)) "\\spad{absolutelyIrreducible?()} tests if the curve absolutely irreducible? \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 2 * x**2, 4) \\spad{X} \\spad{absolutelyIrreducible?()$R2}")) (|genus| (((|NonNegativeInteger|)) "\\spad{genus()} returns the genus of one absolutely irreducible component \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} genus()$R")) (|numberOfComponents| (((|NonNegativeInteger|)) "\\spad{numberOfComponents()} returns the number of absolutely irreducible \\indented{1}{components.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(x, Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(y, Fraction \\spad{P0)} \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT, \\spad{P0,} \\spad{P1,} 1 - x**20, 20) \\spad{X} numberOfComponents()$R"))) 
-((-4595 |has| (-413 |#2|) (-368)) (-4600 |has| (-413 |#2|) (-368)) (-4594 |has| (-413 |#2|) (-368)) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 |has| (-433 |#2|) (-388)) (-4623 |has| (-433 |#2|) (-388)) (-4617 |has| (-433 |#2|) (-388)) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-343 |p| |extdeg|) 
+(-363 |p| |extdeg|) 
 ((|constructor| (NIL "FiniteFieldCyclicGroup(p,n) implements a finite field extension of degee \\spad{n} over the prime field with \\spad{p} elements. Its elements are represented by powers of a primitive element, \\spadignore{i.e.} a generator of the multiplicative (cyclic) group. As primitive element we choose the root of the extension polynomial, which is created by createPrimitivePoly from \\spadtype{FiniteFieldPolynomialPackage}. The Zech logarithms are stored in a table of size half of the field size, and use \\spadtype{SingleInteger} for representing field elements, hence, there are restrictions on the size of the field.")) (|getZechTable| (((|PrimitiveArray| (|SingleInteger|))) "\\spad{getZechTable()} returns the zech logarithm table of the field. This table is used to perform additions in the field quickly."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-911 |#1|) (QUOTE (-151))) (|HasCategory| (-911 |#1|) (QUOTE (-374))) (|HasCategory| (-911 |#1|) (QUOTE (-149))) (-1841 (|HasCategory| (-911 |#1|) (QUOTE (-149))) (|HasCategory| (-911 |#1|) (QUOTE (-374))))) 
-(-344 GF |defpol|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-932 |#1|) (QUOTE (-171))) (|HasCategory| (-932 |#1|) (QUOTE (-394))) (|HasCategory| (-932 |#1|) (QUOTE (-169))) (-3836 (|HasCategory| (-932 |#1|) (QUOTE (-169))) (|HasCategory| (-932 |#1|) (QUOTE (-394))))) 
+(-364 GF |defpol|) 
 ((|constructor| (NIL "FiniteFieldCyclicGroupExtensionByPolynomial(GF,defpol) implements a finite extension field of the ground field \\spad{GF.} Its elements are represented by powers of a primitive element, \\spadignore{i.e.} a generator of the multiplicative (cyclic) group. As primitive element we choose the root of the extension polynomial defpol, which MUST be primitive (user responsibility). Zech logarithms are stored in a table of size half of the field size, and use \\spadtype{SingleInteger} for representing field elements, hence, there are restrictions on the size of the field.")) (|getZechTable| (((|PrimitiveArray| (|SingleInteger|))) "\\spad{getZechTable()} returns the zech logarithm table of the field it is used to perform additions in the field quickly."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-149))) (-1841 (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-374))))) 
-(-345 GF |extdeg|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-169))) (-3836 (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-394))))) 
+(-365 GF |extdeg|) 
 ((|constructor| (NIL "FiniteFieldCyclicGroupExtension(GF,n) implements a extension of degree \\spad{n} over the ground field \\spad{GF.} Its elements are represented by powers of a primitive element, \\spadignore{i.e.} a generator of the multiplicative (cyclic) group. As primitive element we choose the root of the extension polynomial, which is created by createPrimitivePoly from \\spadtype{FiniteFieldPolynomialPackage}. Zech logarithms are stored in a table of size half of the field size, and use \\spadtype{SingleInteger} for representing field elements, hence, there are restrictions on the size of the field.")) (|getZechTable| (((|PrimitiveArray| (|SingleInteger|))) "\\spad{getZechTable()} returns the zech logarithm table of the field. This table is used to perform additions in the field quickly."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-149))) (-1841 (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-374))))) 
-(-346 K |PolK|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-169))) (-3836 (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-394))))) 
+(-366 K |PolK|) 
 ((|constructor| (NIL "Part of the PAFF package"))) 
 NIL 
 NIL 
-(-347 K |PolK|) 
+(-367 K |PolK|) 
 ((|constructor| (NIL "Part of the package for Algebraic Function Fields in one variable (PAFF) It has been modified (very slitely) so that each time the \"factor\" function is used, the variable related to the size of the field over which the polynomial is factorized is reset. This is done in order to be used with a \"dynamic extension field\" which size is not fixed but set before calling the \"factor\" function and which is parse by side effect to this package via the function \"size\". See the local function \"initialize\" of this package."))) 
 NIL 
 NIL 
-(-348 -1557 V VF) 
+(-368 -1940 V VF) 
 ((|constructor| (NIL "This package lifts the interpolation functions from \\spadtype{FractionFreeFastGaussian} to fractions. The packages defined in this file provide fast fraction free rational interpolation algorithms. (see FAMR2, FFFG, FFFGF, NEWTON)")) (|generalInterpolation| (((|Stream| (|Matrix| (|SparseUnivariatePolynomial| |#1|))) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#3|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{generalInterpolation(l, CA, \\spad{f,} sumEta, maxEta)} applies generalInterpolation(l, CA, \\spad{f,} eta) for all possible eta with maximal entry maxEta and sum of entries \\spad{sumEta}") (((|Matrix| (|SparseUnivariatePolynomial| |#1|)) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#3|) (|List| (|NonNegativeInteger|))) "\\spad{generalInterpolation(l, CA, \\spad{f,} eta)} performs Hermite-Pade approximation using the given action \\spad{CA} of polynomials on the elements of \\spad{f.} The result is guaranteed to be correct up to order |eta|-1. Given that eta is a \"normal\" point, the degrees on the diagonal are given by eta. The degrees of column \\spad{i} are in this case eta + e.i - [1,1,...,1], where the degree of zero is \\spad{-1.}"))) 
 NIL 
 NIL 
-(-349 -1557 V) 
+(-369 -1940 V) 
 ((|constructor| (NIL "This package implements the interpolation algorithm proposed in Beckermann, Bernhard and Labahn, George, Fraction-free computation of matrix rational interpolants and matrix GCDs, SIAM Journal on Matrix Analysis and Applications 22. The packages defined in this file provide fast fraction free rational interpolation algorithms. (see FAMR2, FFFG, FFFGF, NEWTON)")) (|qShiftC| (((|List| |#1|) |#1| (|NonNegativeInteger|)) "\\spad{qShiftC} gives the coefficients c_{k,k} in the expansion <x^k> \\spad{z} g(x) = sum_{i=0}^k c_{k,i} <x^i> g(x), where \\spad{z} acts on g(x) by shifting. In fact, the result is [1,q,q^2,...]")) (|qShiftAction| ((|#1| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) "\\spad{qShiftAction(q, \\spad{k,} \\spad{l,} \\spad{g)}} gives the coefficient of \\spad{x^k} in \\spad{z^l} g(x), where z*(a+b*x+c*x^2+d*x^3+...) = (a+q*b*x+q^2*c*x^2+q^3*d*x^3+...). In terms of sequences, z*u(n)=q^n*u(n).")) (|DiffC| (((|List| |#1|) (|NonNegativeInteger|)) "\\spad{DiffC} gives the coefficients c_{k,k} in the expansion <x^k> \\spad{z} g(x) = sum_{i=0}^k c_{k,i} <x^i> g(x), where \\spad{z} acts on g(x) by shifting. In fact, the result is [0,0,0,...]")) (|DiffAction| ((|#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) "\\spad{DiffAction(k, \\spad{l,} \\spad{g)}} gives the coefficient of \\spad{x^k} in \\spad{z^l} g(x), where z*(a+b*x+c*x^2+d*x^3+...) = (a*x+b*x^2+c*x^3+...), \\spadignore{i.e.} multiplication with \\spad{x.}")) (|ShiftC| (((|List| |#1|) (|NonNegativeInteger|)) "\\spad{ShiftC} gives the coefficients c_{k,k} in the expansion <x^k> \\spad{z} g(x) = sum_{i=0}^k c_{k,i} <x^i> g(x), where \\spad{z} acts on g(x) by shifting. In fact, the result is [0,1,2,...]")) (|ShiftAction| ((|#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) "\\spad{ShiftAction(k, \\spad{l,} \\spad{g)}} gives the coefficient of \\spad{x^k} in \\spad{z^l} g(x), where \\spad{z*(a+b*x+c*x^2+d*x^3+...) = (b*x+2*c*x^2+3*d*x^3+...)}. In terms of sequences, z*u(n)=n*u(n).")) (|generalCoefficient| ((|#1| (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#2|) (|NonNegativeInteger|) (|Vector| (|SparseUnivariatePolynomial| |#1|))) "\\spad{generalCoefficient(action, \\spad{f,} \\spad{k,} \\spad{p)}} gives the coefficient of \\spad{x^k} in p(z)\\dot f(x), where the \\spad{action} of \\spad{z^l} on a polynomial in \\spad{x} is given by action, \\spadignore{i.e.} action(k, \\spad{l,} \\spad{f)} should return the coefficient of \\spad{x^k} in \\spad{z^l} f(x).")) (|generalInterpolation| (((|Stream| (|Matrix| (|SparseUnivariatePolynomial| |#1|))) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#2|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{generalInterpolation(C, CA, \\spad{f,} sumEta, maxEta)} applies \\spad{generalInterpolation(C, CA, \\spad{f,} eta)} for all possible \\spad{eta} with maximal entry \\spad{maxEta} and sum of entries at most \\spad{sumEta}. \\blankline The first argument \\spad{C} is the list of coefficients c_{k,k} in the expansion <x^k> \\spad{z} g(x) = sum_{i=0}^k c_{k,i} <x^i> g(x). \\blankline The second argument, CA(k, \\spad{l,} \\spad{f),} should return the coefficient of \\spad{x^k} in \\spad{z^l} f(x).") (((|Matrix| (|SparseUnivariatePolynomial| |#1|)) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#2|) (|List| (|NonNegativeInteger|))) "\\spad{generalInterpolation(C, CA, \\spad{f,} eta)} performs Hermite-Pade approximation using the given action \\spad{CA} of polynomials on the elements of \\spad{f.} The result is guaranteed to be correct up to order |eta|-1. Given that eta is a \"normal\" point, the degrees on the diagonal are given by eta. The degrees of column \\spad{i} are in this case eta + e.i - [1,1,...,1], where the degree of zero is \\spad{-1.} \\blankline The first argument \\spad{C} is the list of coefficients c_{k,k} in the expansion <x^k> \\spad{z} g(x) = sum_{i=0}^k c_{k,i} <x^i> g(x). \\blankline The second argument, CA(k, \\spad{l,} \\spad{f),} should return the coefficient of \\spad{x^k} in \\spad{z^l} f(x).")) (|interpolate| (((|Fraction| (|SparseUnivariatePolynomial| |#1|)) (|List| (|Fraction| |#1|)) (|List| (|Fraction| |#1|)) (|NonNegativeInteger|)) "\\spad{interpolate(xlist, ylist, deg} returns the rational function with numerator degree \\spad{deg} that interpolates the given points using fraction free arithmetic.") (((|Fraction| (|SparseUnivariatePolynomial| |#1|)) (|List| |#1|) (|List| |#1|) (|NonNegativeInteger|)) "\\spad{interpolate(xlist, ylist, deg} returns the rational function with numerator degree at most \\spad{deg} and denominator degree at most \\spad{\\#xlist-deg-1} that interpolates the given points using fraction free arithmetic. Note that rational interpolation does not guarantee that all given points are interpolated correctly: unattainable points may make this impossible.")) (|fffg| (((|Matrix| (|SparseUnivariatePolynomial| |#1|)) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|Vector| (|SparseUnivariatePolynomial| |#1|))) (|List| (|NonNegativeInteger|))) "\\spad{fffg} is the general algorithm as proposed by Beckermann and Labahn. \\blankline The first argument is the list of c_{i,i}. These are the only values of \\spad{C} explicitely needed in \\spad{fffg}. \\blankline The second argument \\spad{c,} computes c_k(M), \\spadignore{i.e.} c_k(.) is the dual basis of the vector space \\spad{V,} but also knows about the special multiplication rule as descibed in Equation (2). Note that the information about \\spad{f} is therefore encoded in \\spad{c.} \\blankline The third argument is the vector of degree bounds \\spad{n,} as introduced in Definition 2.1. In particular, the sum of the entries is the order of the Mahler system computed."))) 
 NIL 
 NIL 
-(-350 GF) 
+(-370 GF) 
 ((|constructor| (NIL "FiniteFieldFunctions(GF) is a package with functions concerning finite extension fields of the finite ground field \\spad{GF,} \\spadignore{e.g.} Zech logarithms.")) (|createLowComplexityNormalBasis| (((|Union| (|SparseUnivariatePolynomial| |#1|) (|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|)))))) (|PositiveInteger|)) "\\spad{createLowComplexityNormalBasis(n)} tries to find a a low complexity normal basis of degree \\spad{n} over \\spad{GF} and returns its multiplication matrix If no low complexity basis is found it calls \\axiomFunFrom{createNormalPoly}{FiniteFieldPolynomialPackage}(n) to produce a normal polynomial of degree \\spad{n} over \\spad{GF}")) (|createLowComplexityTable| (((|Union| (|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|))))) "failed") (|PositiveInteger|)) "\\spad{createLowComplexityTable(n)} tries to find a low complexity normal basis of degree \\spad{n} over \\spad{GF} and returns its multiplication matrix Fails, if it does not find a low complexity basis")) (|sizeMultiplication| (((|NonNegativeInteger|) (|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|)))))) "\\spad{sizeMultiplication(m)} returns the number of entries of the multiplication table \\spad{m.}")) (|createMultiplicationMatrix| (((|Matrix| |#1|) (|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|)))))) "\\spad{createMultiplicationMatrix(m)} forms the multiplication table \\spad{m} into a matrix over the ground field.")) (|createMultiplicationTable| (((|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|))))) (|SparseUnivariatePolynomial| |#1|)) "\\spad{createMultiplicationTable(f)} generates a multiplication table for the normal basis of the field extension determined by \\spad{f.} This is needed to perform multiplications between elements represented as coordinate vectors to this basis. See \\spadtype{FFNBP}, \\spadtype{FFNBX}.")) (|createZechTable| (((|PrimitiveArray| (|SingleInteger|)) (|SparseUnivariatePolynomial| |#1|)) "\\spad{createZechTable(f)} generates a Zech logarithm table for the cyclic group representation of a extension of the ground field by the primitive polynomial f(x), \\spadignore{i.e.} \\spad{Z(i)}, defined by x**Z(i) = 1+x**i is stored at index i. This is needed in particular to perform addition of field elements in finite fields represented in this way. See \\spadtype{FFCGP}, \\spadtype{FFCGX}."))) 
 NIL 
 NIL 
-(-351 F1 GF F2) 
+(-371 F1 GF F2) 
 ((|constructor| (NIL "FiniteFieldHomomorphisms(F1,GF,F2) exports coercion functions of elements between the fields \\spad{F1} and \\spad{F2,} which both must be finite simple algebraic extensions of the finite ground field \\spad{GF.}")) (|coerce| ((|#1| |#3|) "\\spad{coerce(x)} is the homomorphic image of \\spad{x} from \\spad{F2} in \\spad{F1,} where coerce is a field homomorphism between the fields extensions \\spad{F2} and \\spad{F1} both over ground field \\spad{GF} (the second argument to the package). Error: if the extension degree of \\spad{F2} doesn't divide the extension degree of \\spad{F1.} Note that the other coercion function in the \\spadtype{FiniteFieldHomomorphisms} is a left inverse.") ((|#3| |#1|) "\\spad{coerce(x)} is the homomorphic image of \\spad{x} from \\spad{F1} in \\spad{F2.} Thus coerce is a field homomorphism between the fields extensions \\spad{F1} and \\spad{F2} both over ground field \\spad{GF} (the second argument to the package). Error: if the extension degree of \\spad{F1} doesn't divide the extension degree of \\spad{F2.} Note that the other coercion function in the \\spadtype{FiniteFieldHomomorphisms} is a left inverse."))) 
 NIL 
 NIL 
-(-352 S) 
+(-372 S) 
 ((|constructor| (NIL "FiniteFieldCategory is the category of finite fields")) (|representationType| (((|Union| "prime" "polynomial" "normal" "cyclic")) "\\spad{representationType()} returns the type of the representation, one of: \\spad{prime}, \\spad{polynomial}, \\spad{normal}, or \\spad{cyclic}.")) (|order| (((|PositiveInteger|) $) "\\spad{order(b)} computes the order of an element \\spad{b} in the multiplicative group of the field. Error: if \\spad{b} equals 0.")) (|discreteLog| (((|NonNegativeInteger|) $) "\\spad{discreteLog(a)} computes the discrete logarithm of \\spad{a} with respect to \\spad{primitiveElement()} of the field.")) (|primitive?| (((|Boolean|) $) "\\spad{primitive?(b)} tests whether the element \\spad{b} is a generator of the (cyclic) multiplicative group of the field, \\spadignore{i.e.} is a primitive element. Implementation Note that see ch.IX.1.3, \\spad{th.2} in \\spad{D.} Lipson.")) (|primitiveElement| (($) "\\spad{primitiveElement()} returns a primitive element stored in a global variable in the domain. At first call, the primitive element is computed by calling \\spadfun{createPrimitiveElement}.")) (|createPrimitiveElement| (($) "\\spad{createPrimitiveElement()} computes a generator of the (cyclic) multiplicative group of the field.")) (|tableForDiscreteLogarithm| (((|Table| (|PositiveInteger|) (|NonNegativeInteger|)) (|Integer|)) "\\spad{tableForDiscreteLogarithm(a,n)} returns a table of the discrete logarithms of \\spad{a**0} up to \\spad{a**(n-1)} which, called with key \\spad{lookup(a**i)} returns \\spad{i} for \\spad{i} in \\spad{0..n-1}. Error: if not called for prime divisors of order of \\indented{7}{multiplicative group.}")) (|factorsOfCyclicGroupSize| (((|List| (|Record| (|:| |factor| (|Integer|)) (|:| |exponent| (|Integer|))))) "\\spad{factorsOfCyclicGroupSize()} returns the factorization of \\spad{size()-1}")) (|conditionP| (((|Union| (|Vector| $) "failed") (|Matrix| $)) "\\spad{conditionP(mat)}, given a matrix representing a homogeneous system of equations, returns a vector whose characteristic'th powers is a non-trivial solution, or \"failed\" if no such vector exists.")) (|charthRoot| (($ $) "\\spad{charthRoot(a)} takes the characteristic'th root of a. Note that such a root is alway defined in finite fields."))) 
 NIL 
 NIL 
-(-353) 
+(-373) 
 ((|constructor| (NIL "FiniteFieldCategory is the category of finite fields")) (|representationType| (((|Union| "prime" "polynomial" "normal" "cyclic")) "\\spad{representationType()} returns the type of the representation, one of: \\spad{prime}, \\spad{polynomial}, \\spad{normal}, or \\spad{cyclic}.")) (|order| (((|PositiveInteger|) $) "\\spad{order(b)} computes the order of an element \\spad{b} in the multiplicative group of the field. Error: if \\spad{b} equals 0.")) (|discreteLog| (((|NonNegativeInteger|) $) "\\spad{discreteLog(a)} computes the discrete logarithm of \\spad{a} with respect to \\spad{primitiveElement()} of the field.")) (|primitive?| (((|Boolean|) $) "\\spad{primitive?(b)} tests whether the element \\spad{b} is a generator of the (cyclic) multiplicative group of the field, \\spadignore{i.e.} is a primitive element. Implementation Note that see ch.IX.1.3, \\spad{th.2} in \\spad{D.} Lipson.")) (|primitiveElement| (($) "\\spad{primitiveElement()} returns a primitive element stored in a global variable in the domain. At first call, the primitive element is computed by calling \\spadfun{createPrimitiveElement}.")) (|createPrimitiveElement| (($) "\\spad{createPrimitiveElement()} computes a generator of the (cyclic) multiplicative group of the field.")) (|tableForDiscreteLogarithm| (((|Table| (|PositiveInteger|) (|NonNegativeInteger|)) (|Integer|)) "\\spad{tableForDiscreteLogarithm(a,n)} returns a table of the discrete logarithms of \\spad{a**0} up to \\spad{a**(n-1)} which, called with key \\spad{lookup(a**i)} returns \\spad{i} for \\spad{i} in \\spad{0..n-1}. Error: if not called for prime divisors of order of \\indented{7}{multiplicative group.}")) (|factorsOfCyclicGroupSize| (((|List| (|Record| (|:| |factor| (|Integer|)) (|:| |exponent| (|Integer|))))) "\\spad{factorsOfCyclicGroupSize()} returns the factorization of \\spad{size()-1}")) (|conditionP| (((|Union| (|Vector| $) "failed") (|Matrix| $)) "\\spad{conditionP(mat)}, given a matrix representing a homogeneous system of equations, returns a vector whose characteristic'th powers is a non-trivial solution, or \"failed\" if no such vector exists.")) (|charthRoot| (($ $) "\\spad{charthRoot(a)} takes the characteristic'th root of a. Note that such a root is alway defined in finite fields."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-354 R UP -3313) 
+(-374 R UP -3958) 
 ((|constructor| (NIL "Integral bases for function fields of dimension one In this package \\spad{R} is a Euclidean domain and \\spad{F} is a framed algebra over \\spad{R.} The package provides functions to compute the integral closure of \\spad{R} in the quotient field of \\spad{F.} It is assumed that \\spad{char(R/P) = char(R)} for any prime \\spad{P} of \\spad{R.} A typical instance of this is when \\spad{R = K[x]} and \\spad{F} is a function field over \\spad{R.}")) (|localIntegralBasis| (((|Record| (|:| |basis| (|Matrix| |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (|Matrix| |#1|))) |#1|) "\\spad{integralBasis(p)} returns a record \\spad{[basis,basisDen,basisInv]} containing information regarding the local integral closure of \\spad{R} at the prime \\spad{p} in the quotient field of \\spad{F,} where \\spad{F} is a framed algebra with R-module basis \\spad{w1,w2,...,wn}. If \\spad{basis} is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then the \\spad{i}th element of the local integral basis is \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of \\spad{basis} contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if \\spad{basisInv} is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}.")) (|integralBasis| (((|Record| (|:| |basis| (|Matrix| |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (|Matrix| |#1|)))) "\\spad{integralBasis()} returns a record \\spad{[basis,basisDen,basisInv]} containing information regarding the integral closure of \\spad{R} in the quotient field of \\spad{F,} where \\spad{F} is a framed algebra with R-module basis \\spad{w1,w2,...,wn}. If \\spad{basis} is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then the \\spad{i}th element of the integral basis is \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of \\spad{basis} contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if \\spad{basisInv} is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(x)} returns a square-free factorisation of \\spad{x}"))) 
 NIL 
 NIL 
-(-355 |p| |extdeg|) 
+(-375 |p| |extdeg|) 
 ((|constructor| (NIL "FiniteFieldNormalBasis(p,n) implements a finite extension field of degree \\spad{n} over the prime field with \\spad{p} elements. The elements are represented by coordinate vectors with respect to a normal basis, \\spadignore{i.e.} a basis consisting of the conjugates (q-powers) of an element, in this case called normal element. This is chosen as a root of the extension polynomial created by createNormalPoly")) (|sizeMultiplication| (((|NonNegativeInteger|)) "\\spad{sizeMultiplication()} returns the number of entries in the multiplication table of the field. Note: The time of multiplication of field elements depends on this size.")) (|getMultiplicationMatrix| (((|Matrix| (|PrimeField| |#1|))) "\\spad{getMultiplicationMatrix()} returns the multiplication table in form of a matrix.")) (|getMultiplicationTable| (((|Vector| (|List| (|Record| (|:| |value| (|PrimeField| |#1|)) (|:| |index| (|SingleInteger|)))))) "\\spad{getMultiplicationTable()} returns the multiplication table for the normal basis of the field. This table is used to perform multiplications between field elements."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-911 |#1|) (QUOTE (-151))) (|HasCategory| (-911 |#1|) (QUOTE (-374))) (|HasCategory| (-911 |#1|) (QUOTE (-149))) (-1841 (|HasCategory| (-911 |#1|) (QUOTE (-149))) (|HasCategory| (-911 |#1|) (QUOTE (-374))))) 
-(-356 GF |uni|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-932 |#1|) (QUOTE (-171))) (|HasCategory| (-932 |#1|) (QUOTE (-394))) (|HasCategory| (-932 |#1|) (QUOTE (-169))) (-3836 (|HasCategory| (-932 |#1|) (QUOTE (-169))) (|HasCategory| (-932 |#1|) (QUOTE (-394))))) 
+(-376 GF |uni|) 
 ((|constructor| (NIL "FiniteFieldNormalBasisExtensionByPolynomial(GF,uni) implements a finite extension of the ground field \\spad{GF.} The elements are represented by coordinate vectors with respect to. a normal basis, \\spadignore{i.e.} a basis consisting of the conjugates (q-powers) of an element, in this case called normal element, where \\spad{q} is the size of \\spad{GF.} The normal element is chosen as a root of the extension polynomial, which MUST be normal over \\spad{GF} (user responsibility)")) (|sizeMultiplication| (((|NonNegativeInteger|)) "\\spad{sizeMultiplication()} returns the number of entries in the multiplication table of the field. Note: the time of multiplication of field elements depends on this size.")) (|getMultiplicationMatrix| (((|Matrix| |#1|)) "\\spad{getMultiplicationMatrix()} returns the multiplication table in form of a matrix.")) (|getMultiplicationTable| (((|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|)))))) "\\spad{getMultiplicationTable()} returns the multiplication table for the normal basis of the field. This table is used to perform multiplications between field elements."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-149))) (-1841 (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-374))))) 
-(-357 GF |extdeg|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-169))) (-3836 (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-394))))) 
+(-377 GF |extdeg|) 
 ((|constructor| (NIL "FiniteFieldNormalBasisExtensionByPolynomial(GF,n) implements a finite extension field of degree \\spad{n} over the ground field \\spad{GF.} The elements are represented by coordinate vectors with respect to a normal basis, \\spadignore{i.e.} a basis consisting of the conjugates (q-powers) of an element, in this case called normal element. This is chosen as a root of the extension polynomial, created by createNormalPoly from \\spadtype{FiniteFieldPolynomialPackage}")) (|sizeMultiplication| (((|NonNegativeInteger|)) "\\spad{sizeMultiplication()} returns the number of entries in the multiplication table of the field. Note: the time of multiplication of field elements depends on this size.")) (|getMultiplicationMatrix| (((|Matrix| |#1|)) "\\spad{getMultiplicationMatrix()} returns the multiplication table in form of a matrix.")) (|getMultiplicationTable| (((|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|)))))) "\\spad{getMultiplicationTable()} returns the multiplication table for the normal basis of the field. This table is used to perform multiplications between field elements."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-149))) (-1841 (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-374))))) 
-(-358 |p| |n|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-169))) (-3836 (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-394))))) 
+(-378 |p| |n|) 
 ((|constructor| (NIL "FiniteField(p,n) implements finite fields with p**n elements. This packages checks that \\spad{p} is prime. For a non-checking version, see \\spadtype{InnerFiniteField}."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-911 |#1|) (QUOTE (-151))) (|HasCategory| (-911 |#1|) (QUOTE (-374))) (|HasCategory| (-911 |#1|) (QUOTE (-149))) (-1841 (|HasCategory| (-911 |#1|) (QUOTE (-149))) (|HasCategory| (-911 |#1|) (QUOTE (-374))))) 
-(-359 GF |defpol|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-932 |#1|) (QUOTE (-171))) (|HasCategory| (-932 |#1|) (QUOTE (-394))) (|HasCategory| (-932 |#1|) (QUOTE (-169))) (-3836 (|HasCategory| (-932 |#1|) (QUOTE (-169))) (|HasCategory| (-932 |#1|) (QUOTE (-394))))) 
+(-379 GF |defpol|) 
 ((|constructor| (NIL "FiniteFieldExtensionByPolynomial(GF, defpol) implements the extension of the finite field \\spad{GF} generated by the extension polynomial defpol which MUST be irreducible."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-149))) (-1841 (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-374))))) 
-(-360 -3313 GF) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-169))) (-3836 (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-394))))) 
+(-380 -3958 GF) 
 ((|constructor| (NIL "FiniteFieldPolynomialPackage2(F,GF) exports some functions concerning finite fields, which depend on a finite field \\spad{GF} and an algebraic extension \\spad{F} of \\spad{GF,} \\spadignore{e.g.} a zero of a polynomial over \\spad{GF} in \\spad{F.}")) (|rootOfIrreduciblePoly| ((|#1| (|SparseUnivariatePolynomial| |#2|)) "\\spad{rootOfIrreduciblePoly(f)} computes one root of the monic, irreducible polynomial \\spad{f,} which degree must divide the extension degree of \\spad{F} over \\spad{GF,} \\spadignore{i.e.} \\spad{f} splits into linear factors over \\spad{F.}")) (|Frobenius| ((|#1| |#1|) "\\spad{Frobenius(x)} \\undocumented{}")) (|basis| (((|Vector| |#1|) (|PositiveInteger|)) "\\spad{basis(n)} \\undocumented{}")) (|lookup| (((|PositiveInteger|) |#1|) "\\spad{lookup(x)} \\undocumented{}")) (|coerce| ((|#1| |#2|) "\\spad{coerce(x)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-361 GF) 
+(-381 GF) 
 ((|constructor| (NIL "This package provides a number of functions for generating, counting and testing irreducible, normal, primitive, random polynomials over finite fields.")) (|reducedQPowers| (((|PrimitiveArray| (|SparseUnivariatePolynomial| |#1|)) (|SparseUnivariatePolynomial| |#1|)) "\\spad{reducedQPowers(f)} generates \\spad{[x,x**q,x**(q**2),...,x**(q**(n-1))]} reduced modulo \\spad{f} where \\spad{q = size()$GF} and \\spad{n = degree \\spad{f}.}")) (|leastAffineMultiple| (((|SparseUnivariatePolynomial| |#1|) (|SparseUnivariatePolynomial| |#1|)) "\\spad{leastAffineMultiple(f)} computes the least affine polynomial which is divisible by the polynomial \\spad{f} over the finite field \\spad{GF,} \\spadignore{i.e.} a polynomial whose exponents are 0 or a power of \\spad{q,} the size of \\spad{GF.}")) (|random| (((|SparseUnivariatePolynomial| |#1|) (|PositiveInteger|) (|PositiveInteger|)) "\\spad{random(m,n)}$FFPOLY(GF) generates a random monic polynomial of degree \\spad{d} over the finite field \\spad{GF,} \\spad{d} between \\spad{m} and \\spad{n.}") (((|SparseUnivariatePolynomial| |#1|) (|PositiveInteger|)) "\\spad{random(n)}$FFPOLY(GF) generates a random monic polynomial of degree \\spad{n} over the finite field \\spad{GF.}")) (|nextPrimitiveNormalPoly| (((|Union| (|SparseUnivariatePolynomial| |#1|) "failed") (|SparseUnivariatePolynomial| |#1|)) "\\spad{nextPrimitiveNormalPoly(f)} yields the next primitive normal polynomial over a finite field \\spad{GF} of the same degree as \\spad{f} in the following order, or \"failed\" if there are no greater ones. Error: if \\spad{f} has degree 0. Note that the input polynomial \\spad{f} is made monic. Also, \\spad{f < \\spad{g}} if the lookup of the constant term of \\spad{f} is less than this number for \\spad{g} or, in case these numbers are equal, if the lookup of the coefficient of the term of degree \\spad{n-1} of \\spad{f} is less than this number for \\spad{g.} If these numbers are equals, \\spad{f < \\spad{g}} if the number of monomials of \\spad{f} is less than that for \\spad{g,} or if the lists of exponents for \\spad{f} are lexicographically less than those for \\spad{g.} If these lists are also equal, the lists of coefficients are coefficients according to the lexicographic ordering induced by the ordering of the elements of \\spad{GF} given by lookup. This operation is equivalent to nextNormalPrimitivePoly(f).")) (|nextNormalPrimitivePoly| (((|Union| (|SparseUnivariatePolynomial| |#1|) "failed") (|SparseUnivariatePolynomial| |#1|)) "\\spad{nextNormalPrimitivePoly(f)} yields the next normal primitive polynomial over a finite field \\spad{GF} of the same degree as \\spad{f} in the following order, or \"failed\" if there are no greater ones. Error: if \\spad{f} has degree 0. Note that the input polynomial \\spad{f} is made monic. Also, \\spad{f < \\spad{g}} if the lookup of the constant term of \\spad{f} is less than this number for \\spad{g} or if lookup of the coefficient of the term of degree \\spad{n-1} of \\spad{f} is less than this number for \\spad{g.} Otherwise, \\spad{f < \\spad{g}} if the number of monomials of \\spad{f} is less than that for \\spad{g} or if the lists of exponents for \\spad{f} are lexicographically less than those for \\spad{g.} If these lists are also equal, the lists of coefficients are compared according to the lexicographic ordering induced by the ordering of the elements of \\spad{GF} given by lookup. This operation is equivalent to nextPrimitiveNormalPoly(f).")) (|nextNormalPoly| (((|Union| (|SparseUnivariatePolynomial| |#1|) "failed") (|SparseUnivariatePolynomial| |#1|)) "\\spad{nextNormalPoly(f)} yields the next normal polynomial over a finite field \\spad{GF} of the same degree as \\spad{f} in the following order, or \"failed\" if there are no greater ones. Error: if \\spad{f} has degree 0. Note that the input polynomial \\spad{f} is made monic. Also, \\spad{f < \\spad{g}} if the lookup of the coefficient of the term of degree \\spad{n-1} of \\spad{f} is less than that for \\spad{g.} In case these numbers are equal, \\spad{f < \\spad{g}} if if the number of monomials of \\spad{f} is less that for \\spad{g} or if the list of exponents of \\spad{f} are lexicographically less than the corresponding list for \\spad{g.} If these lists are also equal, the lists of coefficients are compared according to the lexicographic ordering induced by the ordering of the elements of \\spad{GF} given by lookup.")) (|nextPrimitivePoly| (((|Union| (|SparseUnivariatePolynomial| |#1|) "failed") (|SparseUnivariatePolynomial| |#1|)) "\\spad{nextPrimitivePoly(f)} yields the next primitive polynomial over a finite field \\spad{GF} of the same degree as \\spad{f} in the following order, or \"failed\" if there are no greater ones. Error: if \\spad{f} has degree 0. Note that the input polynomial \\spad{f} is made monic. Also, \\spad{f < \\spad{g}} if the lookup of the constant term of \\spad{f} is less than this number for \\spad{g.} If these values are equal, then \\spad{f < \\spad{g}} if if the number of monomials of \\spad{f} is less than that for \\spad{g} or if the lists of exponents of \\spad{f} are lexicographically less than the corresponding list for \\spad{g.} If these lists are also equal, the lists of coefficients are compared according to the lexicographic ordering induced by the ordering of the elements of \\spad{GF} given by lookup.")) (|nextIrreduciblePoly| (((|Union| (|SparseUnivariatePolynomial| |#1|) "failed") (|SparseUnivariatePolynomial| |#1|)) "\\spad{nextIrreduciblePoly(f)} yields the next monic irreducible polynomial over a finite field \\spad{GF} of the same degree as \\spad{f} in the following order, or \"failed\" if there are no greater ones. Error: if \\spad{f} has degree 0. Note that the input polynomial \\spad{f} is made monic. Also, \\spad{f < \\spad{g}} if the number of monomials of \\spad{f} is less than this number for \\spad{g.} If \\spad{f} and \\spad{g} have the same number of monomials, the lists of exponents are compared lexicographically. If these lists are also equal, the lists of coefficients are compared according to the lexicographic ordering induced by the ordering of the elements of \\spad{GF} given by lookup.")) (|createPrimitiveNormalPoly| (((|SparseUnivariatePolynomial| |#1|) (|PositiveInteger|)) "\\spad{createPrimitiveNormalPoly(n)}$FFPOLY(GF) generates a normal and primitive polynomial of degree \\spad{n} over the field \\spad{GF.} polynomial of degree \\spad{n} over the field \\spad{GF.}")) (|createNormalPrimitivePoly| (((|SparseUnivariatePolynomial| |#1|) (|PositiveInteger|)) "\\spad{createNormalPrimitivePoly(n)}$FFPOLY(GF) generates a normal and primitive polynomial of degree \\spad{n} over the field \\spad{GF.} Note that this function is equivalent to createPrimitiveNormalPoly(n)")) (|createNormalPoly| (((|SparseUnivariatePolynomial| |#1|) (|PositiveInteger|)) "\\spad{createNormalPoly(n)}$FFPOLY(GF) generates a normal polynomial of degree \\spad{n} over the finite field \\spad{GF.}")) (|createPrimitivePoly| (((|SparseUnivariatePolynomial| |#1|) (|PositiveInteger|)) "\\spad{createPrimitivePoly(n)}$FFPOLY(GF) generates a primitive polynomial of degree \\spad{n} over the finite field \\spad{GF.}")) (|createIrreduciblePoly| (((|SparseUnivariatePolynomial| |#1|) (|PositiveInteger|)) "\\spad{createIrreduciblePoly(n)}$FFPOLY(GF) generates a monic irreducible univariate polynomial of degree \\spad{n} over the finite field \\spad{GF.}")) (|numberOfNormalPoly| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{numberOfNormalPoly(n)}$FFPOLY(GF) yields the number of normal polynomials of degree \\spad{n} over the finite field \\spad{GF.}")) (|numberOfPrimitivePoly| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{numberOfPrimitivePoly(n)}$FFPOLY(GF) yields the number of primitive polynomials of degree \\spad{n} over the finite field \\spad{GF.}")) (|numberOfIrreduciblePoly| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{numberOfIrreduciblePoly(n)}$FFPOLY(GF) yields the number of monic irreducible univariate polynomials of degree \\spad{n} over the finite field \\spad{GF.}")) (|normal?| (((|Boolean|) (|SparseUnivariatePolynomial| |#1|)) "\\spad{normal?(f)} tests whether the polynomial \\spad{f} over a finite field is normal, \\spadignore{i.e.} its roots are linearly independent over the field.")) (|primitive?| (((|Boolean|) (|SparseUnivariatePolynomial| |#1|)) "\\spad{primitive?(f)} tests whether the polynomial \\spad{f} over a finite field is primitive, \\spadignore{i.e.} all its roots are primitive."))) 
 NIL 
 NIL 
-(-362 -3313 FP FPP) 
+(-382 -3958 FP FPP) 
 ((|constructor| (NIL "This package solves linear diophantine equations for Bivariate polynomials over finite fields")) (|solveLinearPolynomialEquation| (((|Union| (|List| |#3|) "failed") (|List| |#3|) |#3|) "\\spad{solveLinearPolynomialEquation([f1, ..., fn], \\spad{g)}} (where the \\spad{fi} are relatively prime to each other) returns a list of \\spad{ai} such that \\spad{g/prod \\spad{fi} = sum ai/fi} or returns \"failed\" if no such list of ai's exists."))) 
 NIL 
 NIL 
-(-363 K |PolK|) 
+(-383 K |PolK|) 
 ((|constructor| (NIL "Part of the package for Algebraic Function Fields in one variable (PAFF)"))) 
 NIL 
 NIL 
-(-364 GF |n|) 
+(-384 GF |n|) 
 ((|constructor| (NIL "FiniteFieldExtensionByPolynomial(GF, \\spad{n)} implements an extension of the finite field \\spad{GF} of degree \\spad{n} generated by the extension polynomial constructed by createIrreduciblePoly from \\spadtype{FiniteFieldPolynomialPackage}."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-149))) (-1841 (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-374))))) 
-(-365 R |ls|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-169))) (-3836 (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-394))))) 
+(-385 R |ls|) 
 ((|constructor| (NIL "This is just an interface between several packages and domains. The goal is to compute lexicographical Groebner bases of sets of polynomial with type \\spadtype{Polynomial \\spad{R}} by the FGLM algorithm if this is possible (\\spadignore{i.e.} if the input system generates a zero-dimensional ideal).")) (|groebner| (((|List| (|Polynomial| |#1|)) (|List| (|Polynomial| |#1|))) "\\axiom{groebner(lq1)} returns the lexicographical Groebner basis of \\axiom{lq1}. If \\axiom{lq1} generates a zero-dimensional ideal then the FGLM strategy is used, otherwise the Sugar strategy is used.")) (|fglmIfCan| (((|Union| (|List| (|Polynomial| |#1|)) "failed") (|List| (|Polynomial| |#1|))) "\\axiom{fglmIfCan(lq1)} returns the lexicographical Groebner basis of \\axiom{lq1} by using the FGLM strategy, if \\axiom{zeroDimensional?(lq1)} holds.")) (|zeroDimensional?| (((|Boolean|) (|List| (|Polynomial| |#1|))) "\\axiom{zeroDimensional?(lq1)} returns \\spad{true} iff \\axiom{lq1} generates a zero-dimensional ideal w.r.t. the variables of \\axiom{ls}."))) 
 NIL 
 NIL 
-(-366 S) 
+(-386 S) 
 ((|constructor| (NIL "Free group on any set of generators The free group on a set \\spad{S} is the group of finite products of the form \\spad{reduce(*,[si \\spad{**} ni])} where the si's are in \\spad{S,} and the ni's are integers. The multiplication is not commutative.")) (|factors| (((|List| (|Record| (|:| |gen| |#1|) (|:| |exp| (|Integer|)))) $) "\\spad{factors(a1\\^e1,...,an\\^en)} returns \\spad{[[a1, e1],...,[an, en]]}.")) (|mapGen| (($ (|Mapping| |#1| |#1|) $) "\\spad{mapGen(f, \\spad{a1\\^e1} \\spad{...} an\\^en)} returns \\spad{f(a1)\\^e1 \\spad{...} f(an)\\^en}.")) (|mapExpon| (($ (|Mapping| (|Integer|) (|Integer|)) $) "\\spad{mapExpon(f, \\spad{a1\\^e1} \\spad{...} an\\^en)} returns \\spad{a1\\^f(e1) \\spad{...} an\\^f(en)}.")) (|nthFactor| ((|#1| $ (|Integer|)) "\\spad{nthFactor(x, \\spad{n)}} returns the factor of the n^th monomial of \\spad{x.}")) (|nthExpon| (((|Integer|) $ (|Integer|)) "\\spad{nthExpon(x, \\spad{n)}} returns the exponent of the n^th monomial of \\spad{x.}")) (|size| (((|NonNegativeInteger|) $) "\\spad{size(x)} returns the number of monomials in \\spad{x.}")) (** (($ |#1| (|Integer|)) "\\spad{s \\spad{**} \\spad{n}} returns the product of \\spad{s} by itself \\spad{n} times.")) (* (($ $ |#1|) "\\spad{x * \\spad{s}} returns the product of \\spad{x} by \\spad{s} on the right.") (($ |#1| $) "\\spad{s * \\spad{x}} returns the product of \\spad{x} by \\spad{s} on the left."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-367 S) 
+(-387 S) 
 ((|constructor| (NIL "The category of commutative fields, \\spadignore{i.e.} commutative rings where all non-zero elements have multiplicative inverses. The \\spadfun{factor} operation while trivial is useful to have defined. \\blankline Axioms\\br \\tab{5}\\spad{a*(b/a) = b}\\br \\tab{5}\\spad{inv(a) = 1/a}")) (|canonicalsClosed| ((|attribute|) "since \\spad{0*0=0}, \\spad{1*1=1}")) (|canonicalUnitNormal| ((|attribute|) "either 0 or 1.")) (/ (($ $ $) "\\spad{x/y} divides the element \\spad{x} by the element \\spad{y.} Error: if \\spad{y} is 0."))) 
 NIL 
 NIL 
-(-368) 
+(-388) 
 ((|constructor| (NIL "The category of commutative fields, \\spadignore{i.e.} commutative rings where all non-zero elements have multiplicative inverses. The \\spadfun{factor} operation while trivial is useful to have defined. \\blankline Axioms\\br \\tab{5}\\spad{a*(b/a) = b}\\br \\tab{5}\\spad{inv(a) = 1/a}")) (|canonicalsClosed| ((|attribute|) "since \\spad{0*0=0}, \\spad{1*1=1}")) (|canonicalUnitNormal| ((|attribute|) "either 0 or 1.")) (/ (($ $ $) "\\spad{x/y} divides the element \\spad{x} by the element \\spad{y.} Error: if \\spad{y} is 0."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-369 |Name| S) 
+(-389 |Name| S) 
 ((|constructor| (NIL "This category provides an interface to operate on files in the computer's file system. The precise method of naming files is determined by the Name parameter. The type of the contents of the file is determined by \\spad{S.}")) (|flush| (((|Void|) $) "\\spad{flush(f)} makes sure that buffered data is written out")) (|write!| ((|#2| $ |#2|) "\\spad{write!(f,s)} puts the value \\spad{s} into the file \\spad{f.} The state of \\spad{f} is modified so subsequents call to \\spad{write!} will append one after another.")) (|read!| ((|#2| $) "\\spad{read!(f)} extracts a value from file \\spad{f.} The state of \\spad{f} is modified so a subsequent call to \\spadfun{read!} will return the next element.")) (|iomode| (((|String|) $) "\\spad{iomode(f)} returns the status of the file \\spad{f.} The input/output status of \\spad{f} may be \"input\", \"output\" or \"closed\" mode.")) (|name| ((|#1| $) "\\spad{name(f)} returns the external name of the file \\spad{f.}")) (|close!| (($ $) "\\spad{close!(f)} returns the file \\spad{f} closed to input and output.")) (|reopen!| (($ $ (|String|)) "\\spad{reopen!(f,mode)} returns a file \\spad{f} reopened for operation in the indicated mode: \"input\" or \"output\". \\spad{reopen!(f,\"input\")} will reopen the file \\spad{f} for input.")) (|open| (($ |#1| (|String|)) "\\spad{open(s,mode)} returns a file \\spad{s} open for operation in the indicated mode: \"input\" or \"output\".") (($ |#1|) "\\spad{open(s)} returns the file \\spad{s} open for input."))) 
 NIL 
 NIL 
-(-370 S) 
+(-390 S) 
 ((|constructor| (NIL "This domain provides a basic model of files to save arbitrary values. The operations provide sequential access to the contents.")) (|readIfCan!| (((|Union| |#1| "failed") $) "\\spad{readIfCan!(f)} returns a value from the file \\spad{f,} if possible. If \\spad{f} is not open for reading, or if \\spad{f} is at the end of file then \\spad{\"failed\"} is the result."))) 
 NIL 
 NIL 
-(-371 S R) 
+(-391 S R) 
 ((|constructor| (NIL "A FiniteRankNonAssociativeAlgebra is a non associative algebra over a commutative ring \\spad{R} which is a free \\spad{R}-module of finite rank.")) (|unitsKnown| ((|attribute|) "unitsKnown means that \\spadfun{recip} truly yields reciprocal or \\spad{\"failed\"} if not a unit, similarly for \\spadfun{leftRecip} and \\spadfun{rightRecip}. The reason is that we use left, respectively right, minimal polynomials to decide this question.")) (|unit| (((|Union| $ "failed")) "\\spad{unit()} returns a unit of the algebra (necessarily unique), or \\spad{\"failed\"} if there is none.")) (|rightUnit| (((|Union| $ "failed")) "\\spad{rightUnit()} returns a right unit of the algebra (not necessarily unique), or \\spad{\"failed\"} if there is none.")) (|leftUnit| (((|Union| $ "failed")) "\\spad{leftUnit()} returns a left unit of the algebra (not necessarily unique), or \\spad{\"failed\"} if there is none.")) (|rightUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{rightUnits()} returns the affine space of all right units of the algebra, or \\spad{\"failed\"} if there is none.")) (|leftUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{leftUnits()} returns the affine space of all left units of the algebra, or \\spad{\"failed\"} if there is none.")) (|rightMinimalPolynomial| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{rightMinimalPolynomial(a)} returns the polynomial determined by the smallest non-trivial linear combination of right powers of \\spad{a}. Note that the polynomial never has a constant term as in general the algebra has no unit.")) (|leftMinimalPolynomial| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{leftMinimalPolynomial(a)} returns the polynomial determined by the smallest non-trivial linear combination of left powers of \\spad{a}. Note that the polynomial never has a constant term as in general the algebra has no unit.")) (|associatorDependence| (((|List| (|Vector| |#2|))) "\\spad{associatorDependence()} looks for the associator identities, that is, finds a basis of the solutions of the linear combinations of the six permutations of \\spad{associator(a,b,c)} which yield 0, for all \\spad{a},b,c in the algebra. The order of the permutations is \\spad{123 231 312 132 321 213}.")) (|rightRecip| (((|Union| $ "failed") $) "\\spad{rightRecip(a)} returns an element, which is a right inverse of \\spad{a}, or \\spad{\"failed\"} if there is no unit element, if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|leftRecip| (((|Union| $ "failed") $) "\\spad{leftRecip(a)} returns an element, which is a left inverse of \\spad{a}, or \\spad{\"failed\"} if there is no unit element, if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(a)} returns an element, which is both a left and a right inverse of \\spad{a}, or \\spad{\"failed\"} if there is no unit element, if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|lieAlgebra?| (((|Boolean|)) "\\spad{lieAlgebra?()} tests if the algebra is anticommutative and \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} for all \\spad{a},b,c in the algebra (Jacobi identity). Example: for every associative algebra \\spad{(A,+,@)} we can construct a Lie algebra \\spad{(A,+,*)}, where \\spad{a*b \\spad{:=} a@b-b@a}.")) (|jordanAlgebra?| (((|Boolean|)) "\\spad{jordanAlgebra?()} tests if the algebra is commutative, characteristic is not 2, and \\spad{(a*b)*a**2 - a*(b*a**2) = 0} for all \\spad{a},b,c in the algebra (Jordan identity). Example: for every associative algebra \\spad{(A,+,@)} we can construct a Jordan algebra \\spad{(A,+,*)}, where \\spad{a*b \\spad{:=} (a@b+b@a)/2}.")) (|noncommutativeJordanAlgebra?| (((|Boolean|)) "\\spad{noncommutativeJordanAlgebra?()} tests if the algebra is flexible and Jordan admissible.")) (|jordanAdmissible?| (((|Boolean|)) "\\spad{jordanAdmissible?()} tests if 2 is invertible in the coefficient domain and the multiplication defined by \\spad{(1/2)(a*b+b*a)} determines a Jordan algebra, that is, satisfies the Jordan identity. The property of \\spadatt{commutative(\"*\")} follows from by definition.")) (|lieAdmissible?| (((|Boolean|)) "\\spad{lieAdmissible?()} tests if the algebra defined by the commutators is a Lie algebra, that is, satisfies the Jacobi identity. The property of anticommutativity follows from definition.")) (|jacobiIdentity?| (((|Boolean|)) "\\spad{jacobiIdentity?()} tests if \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} for all \\spad{a},b,c in the algebra. For example, this holds for crossed products of 3-dimensional vectors.")) (|powerAssociative?| (((|Boolean|)) "\\spad{powerAssociative?()} tests if all subalgebras generated by a single element are associative.")) (|alternative?| (((|Boolean|)) "\\spad{alternative?()} tests if \\spad{2*associator(a,a,b) = 0 = 2*associator(a,b,b)} for all \\spad{a}, \\spad{b} in the algebra. Note that we only can test this; in general we don't know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|flexible?| (((|Boolean|)) "\\spad{flexible?()} tests if \\spad{2*associator(a,b,a) = 0} for all \\spad{a}, \\spad{b} in the algebra. Note that we only can test this; in general we don't know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|rightAlternative?| (((|Boolean|)) "\\spad{rightAlternative?()} tests if \\spad{2*associator(a,b,b) = 0} for all \\spad{a}, \\spad{b} in the algebra. Note that we only can test this; in general we don't know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|leftAlternative?| (((|Boolean|)) "\\spad{leftAlternative?()} tests if \\spad{2*associator(a,a,b) = 0} for all \\spad{a}, \\spad{b} in the algebra. Note that we only can test this; in general we don't know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|antiAssociative?| (((|Boolean|)) "\\spad{antiAssociative?()} tests if multiplication in algebra is anti-associative, that is, \\spad{(a*b)*c + a*(b*c) = 0} for all \\spad{a},b,c in the algebra.")) (|associative?| (((|Boolean|)) "\\spad{associative?()} tests if multiplication in algebra is associative.")) (|antiCommutative?| (((|Boolean|)) "\\spad{antiCommutative?()} tests if \\spad{a*a = 0} for all \\spad{a} in the algebra. Note that this implies \\spad{a*b + b*a = 0} for all \\spad{a} and \\spad{b}.")) (|commutative?| (((|Boolean|)) "\\spad{commutative?()} tests if multiplication in the algebra is commutative.")) (|rightCharacteristicPolynomial| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{rightCharacteristicPolynomial(a)} returns the characteristic polynomial of the right regular representation of \\spad{a} with respect to any basis.")) (|leftCharacteristicPolynomial| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{leftCharacteristicPolynomial(a)} returns the characteristic polynomial of the left regular representation of \\spad{a} with respect to any basis.")) (|rightTraceMatrix| (((|Matrix| |#2|) (|Vector| $)) "\\spad{rightTraceMatrix([v1,...,vn])} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the right trace of the product \\spad{vi*vj}.")) (|leftTraceMatrix| (((|Matrix| |#2|) (|Vector| $)) "\\spad{leftTraceMatrix([v1,...,vn])} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the left trace of the product \\spad{vi*vj}.")) (|rightDiscriminant| ((|#2| (|Vector| $)) "\\spad{rightDiscriminant([v1,...,vn])} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the right trace of the product \\spad{vi*vj}. Note that this is the same as \\spad{determinant(rightTraceMatrix([v1,...,vn]))}.")) (|leftDiscriminant| ((|#2| (|Vector| $)) "\\spad{leftDiscriminant([v1,...,vn])} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the left trace of the product \\spad{vi*vj}. Note that this is the same as \\spad{determinant(leftTraceMatrix([v1,...,vn]))}.")) (|represents| (($ (|Vector| |#2|) (|Vector| $)) "\\spad{represents([a1,...,am],[v1,...,vm])} returns the linear combination \\spad{a1*vm + \\spad{...} + an*vm}.")) (|coordinates| (((|Matrix| |#2|) (|Vector| $) (|Vector| $)) "\\spad{coordinates([a1,...,am],[v1,...,vn])} returns a matrix whose \\spad{i}-th row is formed by the coordinates of \\spad{ai} with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}.") (((|Vector| |#2|) $ (|Vector| $)) "\\spad{coordinates(a,[v1,...,vn])} returns the coordinates of \\spad{a} with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}.")) (|rightNorm| ((|#2| $) "\\spad{rightNorm(a)} returns the determinant of the right regular representation of \\spad{a}.")) (|leftNorm| ((|#2| $) "\\spad{leftNorm(a)} returns the determinant of the left regular representation of \\spad{a}.")) (|rightTrace| ((|#2| $) "\\spad{rightTrace(a)} returns the trace of the right regular representation of \\spad{a}.")) (|leftTrace| ((|#2| $) "\\spad{leftTrace(a)} returns the trace of the left regular representation of \\spad{a}.")) (|rightRegularRepresentation| (((|Matrix| |#2|) $ (|Vector| $)) "\\spad{rightRegularRepresentation(a,[v1,...,vn])} returns the matrix of the linear map defined by right multiplication by \\spad{a} with respect to the \\spad{R}-module basis \\spad{[v1,...,vn]}.")) (|leftRegularRepresentation| (((|Matrix| |#2|) $ (|Vector| $)) "\\spad{leftRegularRepresentation(a,[v1,...,vn])} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the \\spad{R}-module basis \\spad{[v1,...,vn]}.")) (|structuralConstants| (((|Vector| (|Matrix| |#2|)) (|Vector| $)) "\\spad{structuralConstants([v1,v2,...,vm])} calculates the structural constants \\spad{[(gammaijk) for \\spad{k} in 1..m]} defined by \\spad{vi * \\spad{vj} = \\spad{gammaij1} * \\spad{v1} + \\spad{...} + gammaijm * vm}, where \\spad{[v1,...,vm]} is an \\spad{R}-module basis of a subalgebra.")) (|conditionsForIdempotents| (((|List| (|Polynomial| |#2|)) (|Vector| $)) "\\spad{conditionsForIdempotents([v1,...,vn])} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}.")) (|rank| (((|PositiveInteger|)) "\\spad{rank()} returns the rank of the algebra as \\spad{R}-module.")) (|someBasis| (((|Vector| $)) "\\spad{someBasis()} returns some \\spad{R}-module basis."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-562)))) 
-(-372 R) 
+((|HasCategory| |#2| (QUOTE (-582)))) 
+(-392 R) 
 ((|constructor| (NIL "A FiniteRankNonAssociativeAlgebra is a non associative algebra over a commutative ring \\spad{R} which is a free \\spad{R}-module of finite rank.")) (|unitsKnown| ((|attribute|) "unitsKnown means that \\spadfun{recip} truly yields reciprocal or \\spad{\"failed\"} if not a unit, similarly for \\spadfun{leftRecip} and \\spadfun{rightRecip}. The reason is that we use left, respectively right, minimal polynomials to decide this question.")) (|unit| (((|Union| $ "failed")) "\\spad{unit()} returns a unit of the algebra (necessarily unique), or \\spad{\"failed\"} if there is none.")) (|rightUnit| (((|Union| $ "failed")) "\\spad{rightUnit()} returns a right unit of the algebra (not necessarily unique), or \\spad{\"failed\"} if there is none.")) (|leftUnit| (((|Union| $ "failed")) "\\spad{leftUnit()} returns a left unit of the algebra (not necessarily unique), or \\spad{\"failed\"} if there is none.")) (|rightUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{rightUnits()} returns the affine space of all right units of the algebra, or \\spad{\"failed\"} if there is none.")) (|leftUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{leftUnits()} returns the affine space of all left units of the algebra, or \\spad{\"failed\"} if there is none.")) (|rightMinimalPolynomial| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{rightMinimalPolynomial(a)} returns the polynomial determined by the smallest non-trivial linear combination of right powers of \\spad{a}. Note that the polynomial never has a constant term as in general the algebra has no unit.")) (|leftMinimalPolynomial| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{leftMinimalPolynomial(a)} returns the polynomial determined by the smallest non-trivial linear combination of left powers of \\spad{a}. Note that the polynomial never has a constant term as in general the algebra has no unit.")) (|associatorDependence| (((|List| (|Vector| |#1|))) "\\spad{associatorDependence()} looks for the associator identities, that is, finds a basis of the solutions of the linear combinations of the six permutations of \\spad{associator(a,b,c)} which yield 0, for all \\spad{a},b,c in the algebra. The order of the permutations is \\spad{123 231 312 132 321 213}.")) (|rightRecip| (((|Union| $ "failed") $) "\\spad{rightRecip(a)} returns an element, which is a right inverse of \\spad{a}, or \\spad{\"failed\"} if there is no unit element, if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|leftRecip| (((|Union| $ "failed") $) "\\spad{leftRecip(a)} returns an element, which is a left inverse of \\spad{a}, or \\spad{\"failed\"} if there is no unit element, if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(a)} returns an element, which is both a left and a right inverse of \\spad{a}, or \\spad{\"failed\"} if there is no unit element, if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|lieAlgebra?| (((|Boolean|)) "\\spad{lieAlgebra?()} tests if the algebra is anticommutative and \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} for all \\spad{a},b,c in the algebra (Jacobi identity). Example: for every associative algebra \\spad{(A,+,@)} we can construct a Lie algebra \\spad{(A,+,*)}, where \\spad{a*b \\spad{:=} a@b-b@a}.")) (|jordanAlgebra?| (((|Boolean|)) "\\spad{jordanAlgebra?()} tests if the algebra is commutative, characteristic is not 2, and \\spad{(a*b)*a**2 - a*(b*a**2) = 0} for all \\spad{a},b,c in the algebra (Jordan identity). Example: for every associative algebra \\spad{(A,+,@)} we can construct a Jordan algebra \\spad{(A,+,*)}, where \\spad{a*b \\spad{:=} (a@b+b@a)/2}.")) (|noncommutativeJordanAlgebra?| (((|Boolean|)) "\\spad{noncommutativeJordanAlgebra?()} tests if the algebra is flexible and Jordan admissible.")) (|jordanAdmissible?| (((|Boolean|)) "\\spad{jordanAdmissible?()} tests if 2 is invertible in the coefficient domain and the multiplication defined by \\spad{(1/2)(a*b+b*a)} determines a Jordan algebra, that is, satisfies the Jordan identity. The property of \\spadatt{commutative(\"*\")} follows from by definition.")) (|lieAdmissible?| (((|Boolean|)) "\\spad{lieAdmissible?()} tests if the algebra defined by the commutators is a Lie algebra, that is, satisfies the Jacobi identity. The property of anticommutativity follows from definition.")) (|jacobiIdentity?| (((|Boolean|)) "\\spad{jacobiIdentity?()} tests if \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} for all \\spad{a},b,c in the algebra. For example, this holds for crossed products of 3-dimensional vectors.")) (|powerAssociative?| (((|Boolean|)) "\\spad{powerAssociative?()} tests if all subalgebras generated by a single element are associative.")) (|alternative?| (((|Boolean|)) "\\spad{alternative?()} tests if \\spad{2*associator(a,a,b) = 0 = 2*associator(a,b,b)} for all \\spad{a}, \\spad{b} in the algebra. Note that we only can test this; in general we don't know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|flexible?| (((|Boolean|)) "\\spad{flexible?()} tests if \\spad{2*associator(a,b,a) = 0} for all \\spad{a}, \\spad{b} in the algebra. Note that we only can test this; in general we don't know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|rightAlternative?| (((|Boolean|)) "\\spad{rightAlternative?()} tests if \\spad{2*associator(a,b,b) = 0} for all \\spad{a}, \\spad{b} in the algebra. Note that we only can test this; in general we don't know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|leftAlternative?| (((|Boolean|)) "\\spad{leftAlternative?()} tests if \\spad{2*associator(a,a,b) = 0} for all \\spad{a}, \\spad{b} in the algebra. Note that we only can test this; in general we don't know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|antiAssociative?| (((|Boolean|)) "\\spad{antiAssociative?()} tests if multiplication in algebra is anti-associative, that is, \\spad{(a*b)*c + a*(b*c) = 0} for all \\spad{a},b,c in the algebra.")) (|associative?| (((|Boolean|)) "\\spad{associative?()} tests if multiplication in algebra is associative.")) (|antiCommutative?| (((|Boolean|)) "\\spad{antiCommutative?()} tests if \\spad{a*a = 0} for all \\spad{a} in the algebra. Note that this implies \\spad{a*b + b*a = 0} for all \\spad{a} and \\spad{b}.")) (|commutative?| (((|Boolean|)) "\\spad{commutative?()} tests if multiplication in the algebra is commutative.")) (|rightCharacteristicPolynomial| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{rightCharacteristicPolynomial(a)} returns the characteristic polynomial of the right regular representation of \\spad{a} with respect to any basis.")) (|leftCharacteristicPolynomial| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{leftCharacteristicPolynomial(a)} returns the characteristic polynomial of the left regular representation of \\spad{a} with respect to any basis.")) (|rightTraceMatrix| (((|Matrix| |#1|) (|Vector| $)) "\\spad{rightTraceMatrix([v1,...,vn])} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the right trace of the product \\spad{vi*vj}.")) (|leftTraceMatrix| (((|Matrix| |#1|) (|Vector| $)) "\\spad{leftTraceMatrix([v1,...,vn])} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the left trace of the product \\spad{vi*vj}.")) (|rightDiscriminant| ((|#1| (|Vector| $)) "\\spad{rightDiscriminant([v1,...,vn])} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the right trace of the product \\spad{vi*vj}. Note that this is the same as \\spad{determinant(rightTraceMatrix([v1,...,vn]))}.")) (|leftDiscriminant| ((|#1| (|Vector| $)) "\\spad{leftDiscriminant([v1,...,vn])} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the left trace of the product \\spad{vi*vj}. Note that this is the same as \\spad{determinant(leftTraceMatrix([v1,...,vn]))}.")) (|represents| (($ (|Vector| |#1|) (|Vector| $)) "\\spad{represents([a1,...,am],[v1,...,vm])} returns the linear combination \\spad{a1*vm + \\spad{...} + an*vm}.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $) (|Vector| $)) "\\spad{coordinates([a1,...,am],[v1,...,vn])} returns a matrix whose \\spad{i}-th row is formed by the coordinates of \\spad{ai} with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}.") (((|Vector| |#1|) $ (|Vector| $)) "\\spad{coordinates(a,[v1,...,vn])} returns the coordinates of \\spad{a} with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}.")) (|rightNorm| ((|#1| $) "\\spad{rightNorm(a)} returns the determinant of the right regular representation of \\spad{a}.")) (|leftNorm| ((|#1| $) "\\spad{leftNorm(a)} returns the determinant of the left regular representation of \\spad{a}.")) (|rightTrace| ((|#1| $) "\\spad{rightTrace(a)} returns the trace of the right regular representation of \\spad{a}.")) (|leftTrace| ((|#1| $) "\\spad{leftTrace(a)} returns the trace of the left regular representation of \\spad{a}.")) (|rightRegularRepresentation| (((|Matrix| |#1|) $ (|Vector| $)) "\\spad{rightRegularRepresentation(a,[v1,...,vn])} returns the matrix of the linear map defined by right multiplication by \\spad{a} with respect to the \\spad{R}-module basis \\spad{[v1,...,vn]}.")) (|leftRegularRepresentation| (((|Matrix| |#1|) $ (|Vector| $)) "\\spad{leftRegularRepresentation(a,[v1,...,vn])} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the \\spad{R}-module basis \\spad{[v1,...,vn]}.")) (|structuralConstants| (((|Vector| (|Matrix| |#1|)) (|Vector| $)) "\\spad{structuralConstants([v1,v2,...,vm])} calculates the structural constants \\spad{[(gammaijk) for \\spad{k} in 1..m]} defined by \\spad{vi * \\spad{vj} = \\spad{gammaij1} * \\spad{v1} + \\spad{...} + gammaijm * vm}, where \\spad{[v1,...,vm]} is an \\spad{R}-module basis of a subalgebra.")) (|conditionsForIdempotents| (((|List| (|Polynomial| |#1|)) (|Vector| $)) "\\spad{conditionsForIdempotents([v1,...,vn])} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}.")) (|rank| (((|PositiveInteger|)) "\\spad{rank()} returns the rank of the algebra as \\spad{R}-module.")) (|someBasis| (((|Vector| $)) "\\spad{someBasis()} returns some \\spad{R}-module basis."))) 
-((-4599 |has| |#1| (-562)) (-4597 . T) (-4596 . T)) 
+((-4622 |has| |#1| (-582)) (-4620 . T) (-4619 . T)) 
 NIL 
-(-373 S) 
+(-393 S) 
 ((|constructor| (NIL "The category of domains composed of a finite set of elements. We include the functions \\spadfun{lookup} and \\spadfun{index} to give a bijection between the finite set and an initial segment of positive integers. \\blankline")) (|enumerate| (((|List| $)) "\\indented{1}{enumerate() returns a list of elements of the set} \\blankline \\spad{X} enumerate()$OrderedVariableList([p,q])")) (|random| (($) "\\spad{random()} returns a random element from the set.")) (|lookup| (((|PositiveInteger|) $) "\\spad{lookup(x)} returns a positive integer such that \\spad{x = index lookup \\spad{x}.}")) (|index| (($ (|PositiveInteger|)) "\\spad{index(i)} takes a positive integer \\spad{i} less than or equal to \\spad{size()} and returns the \\spad{i}-th element of the set. This operation establishs a bijection between the elements of the finite set and \\spad{1..size()}.")) (|size| (((|NonNegativeInteger|)) "\\spad{size()} returns the number of elements in the set."))) 
 NIL 
 NIL 
-(-374) 
+(-394) 
 ((|constructor| (NIL "The category of domains composed of a finite set of elements. We include the functions \\spadfun{lookup} and \\spadfun{index} to give a bijection between the finite set and an initial segment of positive integers. \\blankline")) (|enumerate| (((|List| $)) "\\indented{1}{enumerate() returns a list of elements of the set} \\blankline \\spad{X} enumerate()$OrderedVariableList([p,q])")) (|random| (($) "\\spad{random()} returns a random element from the set.")) (|lookup| (((|PositiveInteger|) $) "\\spad{lookup(x)} returns a positive integer such that \\spad{x = index lookup \\spad{x}.}")) (|index| (($ (|PositiveInteger|)) "\\spad{index(i)} takes a positive integer \\spad{i} less than or equal to \\spad{size()} and returns the \\spad{i}-th element of the set. This operation establishs a bijection between the elements of the finite set and \\spad{1..size()}.")) (|size| (((|NonNegativeInteger|)) "\\spad{size()} returns the number of elements in the set."))) 
 NIL 
 NIL 
-(-375 S R UP) 
+(-395 S R UP) 
 ((|constructor| (NIL "A FiniteRankAlgebra is an algebra over a commutative ring \\spad{R} which is a free R-module of finite rank.")) (|minimalPolynomial| ((|#3| $) "\\spad{minimalPolynomial(a)} returns the minimal polynomial of \\spad{a}.")) (|characteristicPolynomial| ((|#3| $) "\\spad{characteristicPolynomial(a)} returns the characteristic polynomial of the regular representation of \\spad{a} with respect to any basis.")) (|traceMatrix| (((|Matrix| |#2|) (|Vector| $)) "\\spad{traceMatrix([v1,..,vn])} is the n-by-n matrix ( Tr(vi * \\spad{vj)} )")) (|discriminant| ((|#2| (|Vector| $)) "\\spad{discriminant([v1,..,vn])} returns \\spad{determinant(traceMatrix([v1,..,vn]))}.")) (|represents| (($ (|Vector| |#2|) (|Vector| $)) "\\spad{represents([a1,..,an],[v1,..,vn])} returns \\spad{a1*v1+...+an*vn}.")) (|coordinates| (((|Matrix| |#2|) (|Vector| $) (|Vector| $)) "\\spad{coordinates([v1,...,vm], basis)} returns the coordinates of the vi's with to the basis \\spad{basis}. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#2|) $ (|Vector| $)) "\\spad{coordinates(a,basis)} returns the coordinates of \\spad{a} with respect to the \\spad{basis} \\spad{basis}.")) (|norm| ((|#2| $) "\\spad{norm(a)} returns the determinant of the regular representation of \\spad{a} with respect to any basis.")) (|trace| ((|#2| $) "\\spad{trace(a)} returns the trace of the regular representation of \\spad{a} with respect to any basis.")) (|regularRepresentation| (((|Matrix| |#2|) $ (|Vector| $)) "\\spad{regularRepresentation(a,basis)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the \\spad{basis} \\spad{basis}.")) (|rank| (((|PositiveInteger|)) "\\spad{rank()} returns the rank of the algebra."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-368)))) 
-(-376 R UP) 
+((|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-388)))) 
+(-396 R UP) 
 ((|constructor| (NIL "A FiniteRankAlgebra is an algebra over a commutative ring \\spad{R} which is a free R-module of finite rank.")) (|minimalPolynomial| ((|#2| $) "\\spad{minimalPolynomial(a)} returns the minimal polynomial of \\spad{a}.")) (|characteristicPolynomial| ((|#2| $) "\\spad{characteristicPolynomial(a)} returns the characteristic polynomial of the regular representation of \\spad{a} with respect to any basis.")) (|traceMatrix| (((|Matrix| |#1|) (|Vector| $)) "\\spad{traceMatrix([v1,..,vn])} is the n-by-n matrix ( Tr(vi * \\spad{vj)} )")) (|discriminant| ((|#1| (|Vector| $)) "\\spad{discriminant([v1,..,vn])} returns \\spad{determinant(traceMatrix([v1,..,vn]))}.")) (|represents| (($ (|Vector| |#1|) (|Vector| $)) "\\spad{represents([a1,..,an],[v1,..,vn])} returns \\spad{a1*v1+...+an*vn}.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $) (|Vector| $)) "\\spad{coordinates([v1,...,vm], basis)} returns the coordinates of the vi's with to the basis \\spad{basis}. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#1|) $ (|Vector| $)) "\\spad{coordinates(a,basis)} returns the coordinates of \\spad{a} with respect to the \\spad{basis} \\spad{basis}.")) (|norm| ((|#1| $) "\\spad{norm(a)} returns the determinant of the regular representation of \\spad{a} with respect to any basis.")) (|trace| ((|#1| $) "\\spad{trace(a)} returns the trace of the regular representation of \\spad{a} with respect to any basis.")) (|regularRepresentation| (((|Matrix| |#1|) $ (|Vector| $)) "\\spad{regularRepresentation(a,basis)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the \\spad{basis} \\spad{basis}.")) (|rank| (((|PositiveInteger|)) "\\spad{rank()} returns the rank of the algebra."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-377 S A R B) 
+(-397 S A R B) 
 ((|constructor| (NIL "\\spad{FiniteLinearAggregateFunctions2} provides functions involving two FiniteLinearAggregates where the underlying domains might be different. An example of this might be creating a list of rational numbers by mapping a function across a list of integers where the function divides each integer by 1000.")) (|scan| ((|#4| (|Mapping| |#3| |#1| |#3|) |#2| |#3|) "\\spad{scan(f,a,r)} successively applies \\spad{reduce(f,x,r)} to more and more leading sub-aggregates \\spad{x} of aggregrate \\spad{a}. More precisely, if \\spad{a} is \\spad{[a1,a2,...]}, then \\spad{scan(f,a,r)} returns \\spad{[reduce(f,[a1],r),reduce(f,[a1,a2],r),...]}.")) (|reduce| ((|#3| (|Mapping| |#3| |#1| |#3|) |#2| |#3|) "\\spad{reduce(f,a,r)} applies function \\spad{f} to each successive element of the aggregate \\spad{a} and an accumulant initialized to \\spad{r.} For example, \\spad{reduce(_+$Integer,[1,2,3],0)} does \\spad{3+(2+(1+0))}. Note that third argument \\spad{r} may be regarded as the identity element for the function \\spad{f.}")) (|map| ((|#4| (|Mapping| |#3| |#1|) |#2|) "\\spad{map(f,a)} applies function \\spad{f} to each member of aggregate \\spad{a} resulting in a new aggregate over a possibly different underlying domain."))) 
 NIL 
 NIL 
-(-378 A S) 
+(-398 A S) 
 ((|constructor| (NIL "A finite linear aggregate is a linear aggregate of finite length. The finite property of the aggregate adds several exports to the list of exports from \\spadtype{LinearAggregate} such as \\spadfun{reverse}, \\spadfun{sort}, and so on.")) (|sort!| (($ $) "\\spad{sort!(u)} returns \\spad{u} with its elements in ascending order.") (($ (|Mapping| (|Boolean|) |#2| |#2|) $) "\\spad{sort!(p,u)} returns \\spad{u} with its elements ordered by \\spad{p.}")) (|reverse!| (($ $) "\\spad{reverse!(u)} returns \\spad{u} with its elements in reverse order.")) (|copyInto!| (($ $ $ (|Integer|)) "\\spad{copyInto!(u,v,i)} returns aggregate \\spad{u} containing a copy of \\spad{v} inserted at element i.")) (|position| (((|Integer|) |#2| $ (|Integer|)) "\\spad{position(x,a,n)} returns the index \\spad{i} of the first occurrence of \\spad{x} in \\axiom{a} where \\axiom{i \\spad{>=} \\spad{n},} and \\axiom{minIndex(a) - 1} if no such \\spad{x} is found.") (((|Integer|) |#2| $) "\\spad{position(x,a)} returns the index \\spad{i} of the first occurrence of \\spad{x} in a, and \\axiom{minIndex(a) - 1} if there is no such \\spad{x.}") (((|Integer|) (|Mapping| (|Boolean|) |#2|) $) "\\spad{position(p,a)} returns the index \\spad{i} of the first \\spad{x} in \\axiom{a} such that \\axiom{p(x)} is true, and \\axiom{minIndex(a) - 1} if there is no such \\spad{x.}")) (|sorted?| (((|Boolean|) $) "\\spad{sorted?(u)} tests if the elements of \\spad{u} are in ascending order.") (((|Boolean|) (|Mapping| (|Boolean|) |#2| |#2|) $) "\\spad{sorted?(p,a)} tests if \\axiom{a} is sorted according to predicate \\spad{p.}")) (|sort| (($ $) "\\spad{sort(u)} returns an \\spad{u} with elements in ascending order. Note that \\axiom{sort(u) = sort(<=,u)}.") (($ (|Mapping| (|Boolean|) |#2| |#2|) $) "\\spad{sort(p,a)} returns a copy of \\axiom{a} sorted using total ordering predicate \\spad{p.}")) (|reverse| (($ $) "\\spad{reverse(a)} returns a copy of \\axiom{a} with elements in reverse order.")) (|merge| (($ $ $) "\\spad{merge(u,v)} merges \\spad{u} and \\spad{v} in ascending order. Note that \\axiom{merge(u,v) = merge(<=,u,v)}.") (($ (|Mapping| (|Boolean|) |#2| |#2|) $ $) "\\spad{merge(p,a,b)} returns an aggregate \\spad{c} which merges \\axiom{a} and \\spad{b.} The result is produced by examining each element \\spad{x} of \\axiom{a} and \\spad{y} of \\spad{b} successively. If \\axiom{p(x,y)} is true, then \\spad{x} is inserted into the result; otherwise \\spad{y} is inserted. If \\spad{x} is chosen, the next element of \\axiom{a} is examined, and so on. When all the elements of one aggregate are examined, the remaining elements of the other are appended. For example, \\axiom{merge(<,[1,3],[2,7,5])} returns \\axiom{[1,2,3,7,5]}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4603)) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098)))) 
-(-379 S) 
+((|HasAttribute| |#1| (QUOTE -4626)) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119)))) 
+(-399 S) 
 ((|constructor| (NIL "A finite linear aggregate is a linear aggregate of finite length. The finite property of the aggregate adds several exports to the list of exports from \\spadtype{LinearAggregate} such as \\spadfun{reverse}, \\spadfun{sort}, and so on.")) (|sort!| (($ $) "\\spad{sort!(u)} returns \\spad{u} with its elements in ascending order.") (($ (|Mapping| (|Boolean|) |#1| |#1|) $) "\\spad{sort!(p,u)} returns \\spad{u} with its elements ordered by \\spad{p.}")) (|reverse!| (($ $) "\\spad{reverse!(u)} returns \\spad{u} with its elements in reverse order.")) (|copyInto!| (($ $ $ (|Integer|)) "\\spad{copyInto!(u,v,i)} returns aggregate \\spad{u} containing a copy of \\spad{v} inserted at element i.")) (|position| (((|Integer|) |#1| $ (|Integer|)) "\\spad{position(x,a,n)} returns the index \\spad{i} of the first occurrence of \\spad{x} in \\axiom{a} where \\axiom{i \\spad{>=} \\spad{n},} and \\axiom{minIndex(a) - 1} if no such \\spad{x} is found.") (((|Integer|) |#1| $) "\\spad{position(x,a)} returns the index \\spad{i} of the first occurrence of \\spad{x} in a, and \\axiom{minIndex(a) - 1} if there is no such \\spad{x.}") (((|Integer|) (|Mapping| (|Boolean|) |#1|) $) "\\spad{position(p,a)} returns the index \\spad{i} of the first \\spad{x} in \\axiom{a} such that \\axiom{p(x)} is true, and \\axiom{minIndex(a) - 1} if there is no such \\spad{x.}")) (|sorted?| (((|Boolean|) $) "\\spad{sorted?(u)} tests if the elements of \\spad{u} are in ascending order.") (((|Boolean|) (|Mapping| (|Boolean|) |#1| |#1|) $) "\\spad{sorted?(p,a)} tests if \\axiom{a} is sorted according to predicate \\spad{p.}")) (|sort| (($ $) "\\spad{sort(u)} returns an \\spad{u} with elements in ascending order. Note that \\axiom{sort(u) = sort(<=,u)}.") (($ (|Mapping| (|Boolean|) |#1| |#1|) $) "\\spad{sort(p,a)} returns a copy of \\axiom{a} sorted using total ordering predicate \\spad{p.}")) (|reverse| (($ $) "\\spad{reverse(a)} returns a copy of \\axiom{a} with elements in reverse order.")) (|merge| (($ $ $) "\\spad{merge(u,v)} merges \\spad{u} and \\spad{v} in ascending order. Note that \\axiom{merge(u,v) = merge(<=,u,v)}.") (($ (|Mapping| (|Boolean|) |#1| |#1|) $ $) "\\spad{merge(p,a,b)} returns an aggregate \\spad{c} which merges \\axiom{a} and \\spad{b.} The result is produced by examining each element \\spad{x} of \\axiom{a} and \\spad{y} of \\spad{b} successively. If \\axiom{p(x,y)} is true, then \\spad{x} is inserted into the result; otherwise \\spad{y} is inserted. If \\spad{x} is chosen, the next element of \\axiom{a} is examined, and so on. When all the elements of one aggregate are examined, the remaining elements of the other are appended. For example, \\axiom{merge(<,[1,3],[2,7,5])} returns \\axiom{[1,2,3,7,5]}."))) 
-((-4602 . T) (-3389 . T)) 
+((-4625 . T) (-2623 . T)) 
 NIL 
-(-380 |VarSet| R) 
+(-400 |VarSet| R) 
 ((|constructor| (NIL "The category of free Lie algebras. It is used by domains of non-commutative algebra: \\spadtype{LiePolynomial} and \\spadtype{XPBWPolynomial}.")) (|eval| (($ $ (|List| |#1|) (|List| $)) "\\axiom{eval(p, [x1,...,xn], [v1,...,vn])} replaces \\axiom{xi} by \\axiom{vi} in \\axiom{p}.") (($ $ |#1| $) "\\axiom{eval(p, \\spad{x,} \\spad{v)}} replaces \\axiom{x} by \\axiom{v} in \\axiom{p}.")) (|varList| (((|List| |#1|) $) "\\axiom{varList(x)} returns the list of distinct entries of \\axiom{x}.")) (|trunc| (($ $ (|NonNegativeInteger|)) "\\axiom{trunc(p,n)} returns the polynomial \\axiom{p} truncated at order \\axiom{n}.")) (|mirror| (($ $) "\\axiom{mirror(x)} returns \\axiom{Sum(r_i mirror(w_i))} if \\axiom{x} is \\axiom{Sum(r_i w_i)}.")) (|LiePoly| (($ (|LyndonWord| |#1|)) "\\axiom{LiePoly(l)} returns the bracketed form of \\axiom{l} as a Lie polynomial.")) (|rquo| (((|XRecursivePolynomial| |#1| |#2|) (|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{rquo(x,y)} returns the right simplification of \\axiom{x} by \\axiom{y}.")) (|lquo| (((|XRecursivePolynomial| |#1| |#2|) (|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{lquo(x,y)} returns the left simplification of \\axiom{x} by \\axiom{y}.")) (|degree| (((|NonNegativeInteger|) $) "\\axiom{degree(x)} returns the greatest length of a word in the support of \\axiom{x}.")) (|coerce| (((|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{coerce(x)} returns \\axiom{x} as a recursive polynomial.") (((|XDistributedPolynomial| |#1| |#2|) $) "\\axiom{coerce(x)} returns \\axiom{x} as distributed polynomial.") (($ |#1|) "\\axiom{coerce(x)} returns \\axiom{x} as a Lie polynomial.")) (|coef| ((|#2| (|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{coef(x,y)} returns the scalar product of \\axiom{x} by \\axiom{y}, the set of words being regarded as an orthogonal basis."))) 
-((|JacobiIdentity| . T) (|NullSquare| . T) (-4597 . T) (-4596 . T)) 
+((|JacobiIdentity| . T) (|NullSquare| . T) (-4620 . T) (-4619 . T)) 
 NIL 
-(-381 S V) 
+(-401 S V) 
 ((|constructor| (NIL "This package exports 3 sorting algorithms which work over FiniteLinearAggregates. Sort package (in-place) for shallowlyMutable Finite Linear Aggregates")) (|shellSort| ((|#2| (|Mapping| (|Boolean|) |#1| |#1|) |#2|) "\\spad{shellSort(f, agg)} sorts the aggregate agg with the ordering function \\spad{f} using the shellSort algorithm.")) (|heapSort| ((|#2| (|Mapping| (|Boolean|) |#1| |#1|) |#2|) "\\spad{heapSort(f, agg)} sorts the aggregate agg with the ordering function \\spad{f} using the heapsort algorithm.")) (|quickSort| ((|#2| (|Mapping| (|Boolean|) |#1| |#1|) |#2|) "\\spad{quickSort(f, agg)} sorts the aggregate agg with the ordering function \\spad{f} using the quicksort algorithm."))) 
 NIL 
 NIL 
-(-382 S R) 
+(-402 S R) 
 ((|constructor| (NIL "\\spad{S} is \\spadtype{FullyLinearlyExplicitRingOver \\spad{R}} means that \\spad{S} is a \\spadtype{LinearlyExplicitRingOver \\spad{R}} and, in addition, if \\spad{R} is a \\spadtype{LinearlyExplicitRingOver Integer}, then so is \\spad{S}"))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572))))) 
-(-383 R) 
+((|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592))))) 
+(-403 R) 
 ((|constructor| (NIL "\\spad{S} is \\spadtype{FullyLinearlyExplicitRingOver \\spad{R}} means that \\spad{S} is a \\spadtype{LinearlyExplicitRingOver \\spad{R}} and, in addition, if \\spad{R} is a \\spadtype{LinearlyExplicitRingOver Integer}, then so is \\spad{S}"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-384 |Par|) 
+(-404 |Par|) 
 ((|constructor| (NIL "This is a package for the approximation of complex solutions for systems of equations of rational functions with complex rational coefficients. The results are expressed as either complex rational numbers or complex floats depending on the type of the precision parameter which can be either a rational number or a floating point number.")) (|complexRoots| (((|List| (|List| (|Complex| |#1|))) (|List| (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) (|List| (|Symbol|)) |#1|) "\\spad{complexRoots(lrf, \\spad{lv,} eps)} finds all the complex solutions of a list of rational functions with rational number coefficients with respect the the variables appearing in \\spad{lv.} Each solution is computed to precision eps and returned as list corresponding to the order of variables in \\spad{lv.}") (((|List| (|Complex| |#1|)) (|Fraction| (|Polynomial| (|Complex| (|Integer|)))) |#1|) "\\spad{complexRoots(rf, eps)} finds all the complex solutions of a univariate rational function with rational number coefficients. The solutions are computed to precision eps.")) (|complexSolve| (((|List| (|Equation| (|Polynomial| (|Complex| |#1|)))) (|Equation| (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) |#1|) "\\spad{complexSolve(eq,eps)} finds all the complex solutions of the equation \\spad{eq} of rational functions with rational rational coefficients with respect to all the variables appearing in eq, with precision eps.") (((|List| (|Equation| (|Polynomial| (|Complex| |#1|)))) (|Fraction| (|Polynomial| (|Complex| (|Integer|)))) |#1|) "\\spad{complexSolve(p,eps)} find all the complex solutions of the rational function \\spad{p} with complex rational coefficients with respect to all the variables appearing in \\spad{p,} with precision eps.") (((|List| (|List| (|Equation| (|Polynomial| (|Complex| |#1|))))) (|List| (|Equation| (|Fraction| (|Polynomial| (|Complex| (|Integer|)))))) |#1|) "\\spad{complexSolve(leq,eps)} finds all the complex solutions to precision \\spad{eps} of the system \\spad{leq} of equations of rational functions over complex rationals with respect to all the variables appearing in \\spad{lp.}") (((|List| (|List| (|Equation| (|Polynomial| (|Complex| |#1|))))) (|List| (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) |#1|) "\\spad{complexSolve(lp,eps)} finds all the complex solutions to precision \\spad{eps} of the system \\spad{lp} of rational functions over the complex rationals with respect to all the variables appearing in \\spad{lp.}"))) 
 NIL 
 NIL 
-(-385) 
+(-405) 
 ((|outputSpacing| (((|Void|) (|NonNegativeInteger|)) "\\spad{outputSpacing(n)} inserts a space after \\spad{n} (default 10) digits on output; outputSpacing(0) means no spaces are inserted.")) (|outputGeneral| (((|Void|) (|NonNegativeInteger|)) "\\spad{outputGeneral(n)} sets the output mode to general notation with \\spad{n} significant digits displayed.") (((|Void|)) "\\spad{outputGeneral()} sets the output mode (default mode) to general notation; numbers will be displayed in either fixed or floating (scientific) notation depending on the magnitude.")) (|outputFixed| (((|Void|) (|NonNegativeInteger|)) "\\spad{outputFixed(n)} sets the output mode to fixed point notation, with \\spad{n} digits displayed after the decimal point.") (((|Void|)) "\\spad{outputFixed()} sets the output mode to fixed point notation; the output will contain a decimal point.")) (|outputFloating| (((|Void|) (|NonNegativeInteger|)) "\\spad{outputFloating(n)} sets the output mode to floating (scientific) notation with \\spad{n} significant digits displayed after the decimal point.") (((|Void|)) "\\spad{outputFloating()} sets the output mode to floating (scientific) notation, \\spadignore{i.e.} \\spad{mantissa * 10 exponent} is displayed as \\spad{0.mantissa \\spad{E} exponent}.")) (|convert| (($ (|DoubleFloat|)) "\\spad{convert(x)} converts a \\spadtype{DoubleFloat} \\spad{x} to a \\spadtype{Float}.")) (|atan| (($ $ $) "\\spad{atan(x,y)} computes the arc tangent from \\spad{x} with phase \\spad{y.}")) (|exp1| (($) "\\spad{exp1()} returns exp 1: \\spad{2.7182818284...}.")) (|log10| (($ $) "\\spad{log10(x)} computes the logarithm for \\spad{x} to base 10.") (($) "\\spad{log10()} returns \\spad{ln 10}: \\spad{2.3025809299...}.")) (|log2| (($ $) "\\spad{log2(x)} computes the logarithm for \\spad{x} to base 2.") (($) "\\spad{log2()} returns \\spad{ln 2}, \\spadignore{i.e.} \\spad{0.6931471805...}.")) (|rationalApproximation| (((|Fraction| (|Integer|)) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{rationalApproximation(f, \\spad{n,} \\spad{b)}} computes a rational approximation \\spad{r} to \\spad{f} with relative error \\spad{< b**(-n)}, that is \\spad{|(r-f)/f| < b**(-n)}.") (((|Fraction| (|Integer|)) $ (|NonNegativeInteger|)) "\\spad{rationalApproximation(f, \\spad{n)}} computes a rational approximation \\spad{r} to \\spad{f} with relative error \\spad{< 10**(-n)}.")) (|shift| (($ $ (|Integer|)) "\\spad{shift(x,n)} adds \\spad{n} to the exponent of float \\spad{x.}")) (|relerror| (((|Integer|) $ $) "\\spad{relerror(x,y)} computes the absolute value of \\spad{x - \\spad{y}} divided by \\spad{y,} when \\spad{y \\spad{\\^=} 0}.")) (|normalize| (($ $) "\\spad{normalize(x)} normalizes \\spad{x} at current precision.")) (** (($ $ $) "\\spad{x \\spad{**} \\spad{y}} computes \\spad{exp(y log \\spad{x)}} where \\spad{x \\spad{>=} 0}.")) (/ (($ $ (|Integer|)) "\\spad{x / i} computes the division from \\spad{x} by an integer i."))) 
-((-4585 . T) (-4593 . T) (-3410 . T) (-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4608 . T) (-4616 . T) (-2642 . T) (-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-386 |Par|) 
+(-406 |Par|) 
 ((|constructor| (NIL "This is a package for the approximation of real solutions for systems of polynomial equations over the rational numbers. The results are expressed as either rational numbers or floats depending on the type of the precision parameter which can be either a rational number or a floating point number.")) (|realRoots| (((|List| |#1|) (|Fraction| (|Polynomial| (|Integer|))) |#1|) "\\spad{realRoots(rf, eps)} finds the real zeros of a univariate rational function with precision given by eps.") (((|List| (|List| |#1|)) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|Symbol|)) |#1|) "\\spad{realRoots(lp,lv,eps)} computes the list of the real solutions of the list \\spad{lp} of rational functions with rational coefficients with respect to the variables in \\spad{lv,} with precision eps. Each solution is expressed as a list of numbers in order corresponding to the variables in \\spad{lv.}")) (|solve| (((|List| (|Equation| (|Polynomial| |#1|))) (|Equation| (|Fraction| (|Polynomial| (|Integer|)))) |#1|) "\\spad{solve(eq,eps)} finds all of the real solutions of the univariate equation \\spad{eq} of rational functions with respect to the unique variables appearing in eq, with precision eps.") (((|List| (|Equation| (|Polynomial| |#1|))) (|Fraction| (|Polynomial| (|Integer|))) |#1|) "\\spad{solve(p,eps)} finds all of the real solutions of the univariate rational function \\spad{p} with rational coefficients with respect to the unique variable appearing in \\spad{p,} with precision eps.") (((|List| (|List| (|Equation| (|Polynomial| |#1|)))) (|List| (|Equation| (|Fraction| (|Polynomial| (|Integer|))))) |#1|) "\\spad{solve(leq,eps)} finds all of the real solutions of the system \\spad{leq} of equationas of rational functions with respect to all the variables appearing in \\spad{lp,} with precision eps.") (((|List| (|List| (|Equation| (|Polynomial| |#1|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) |#1|) "\\spad{solve(lp,eps)} finds all of the real solutions of the system \\spad{lp} of rational functions over the rational numbers with respect to all the variables appearing in \\spad{lp,} with precision eps."))) 
 NIL 
 NIL 
-(-387 R S) 
+(-407 R S) 
 ((|constructor| (NIL "This domain implements linear combinations of elements from the domain \\spad{S} with coefficients in the domain \\spad{R} where \\spad{S} is an ordered set and \\spad{R} is a ring (which may be non-commutative). This domain is used by domains of non-commutative algebra such as: XDistributedPolynomial, XRecursivePolynomial.")) (* (($ |#2| |#1|) "\\spad{s*r} returns the product \\spad{r*s} used by \\spadtype{XRecursivePolynomial}"))) 
-((-4597 . T) (-4596 . T)) 
-((|HasCategory| |#1| (QUOTE (-174)))) 
-(-388 R |Basis|) 
+((-4620 . T) (-4619 . T)) 
+((|HasCategory| |#1| (QUOTE (-194)))) 
+(-408 R |Basis|) 
 ((|constructor| (NIL "A domain of this category implements formal linear combinations of elements from a domain \\spad{Basis} with coefficients in a domain \\spad{R}. The domain \\spad{Basis} needs only to belong to the category \\spadtype{SetCategory} and \\spad{R} to the category \\spadtype{Ring}. Thus the coefficient ring may be non-commutative. See the \\spadtype{XDistributedPolynomial} constructor for examples of domains built with the \\spadtype{FreeModuleCat} category constructor.")) (|reductum| (($ $) "\\spad{reductum(x)} returns \\spad{x} minus its leading term.")) (|leadingTerm| (((|Record| (|:| |k| |#2|) (|:| |c| |#1|)) $) "\\spad{leadingTerm(x)} returns the first term which appears in \\spad{listOfTerms(x)}.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(x)} returns the first coefficient which appears in \\spad{listOfTerms(x)}.")) (|leadingMonomial| ((|#2| $) "\\spad{leadingMonomial(x)} returns the first element from \\spad{Basis} which appears in \\spad{listOfTerms(x)}.")) (|numberOfMonomials| (((|NonNegativeInteger|) $) "\\spad{numberOfMonomials(x)} returns the number of monomials of \\spad{x}.")) (|monomials| (((|List| $) $) "\\spad{monomials(x)} returns the list of \\spad{r_i*b_i} whose sum is \\spad{x}.")) (|coefficients| (((|List| |#1|) $) "\\spad{coefficients(x)} returns the list of coefficients of \\spad{x}")) (|listOfTerms| (((|List| (|Record| (|:| |k| |#2|) (|:| |c| |#1|))) $) "\\spad{listOfTerms(x)} returns a list \\spad{lt} of terms with type \\spad{Record(k: Basis, \\spad{c:} \\spad{R)}} such that \\spad{x} equals \\spad{reduce(+, map(x \\spad{+->} monom(x.k, x.c), lt))}.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(x)} returns \\spad{true} if \\spad{x} contains a single monomial.")) (|monom| (($ |#2| |#1|) "\\spad{monom(b,r)} returns the element with the single monomial \\indented{1}{\\spad{b} and coefficient \\spad{r}.}")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(fn,u)} maps function \\spad{fn} onto the coefficients \\indented{1}{of the non-zero monomials of \\spad{u}.}")) (|coefficient| ((|#1| $ |#2|) "\\spad{coefficient(x,b)} returns the coefficient of \\spad{b} in \\spad{x}.")) (* (($ |#1| |#2|) "\\spad{r*b} returns the product of \\spad{r} by \\spad{b}."))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-389) 
+(-409) 
 ((|constructor| (NIL "\\axiomType{FortranMatrixCategory} provides support for producing Functions and Subroutines when the input to these is an AXIOM object of type \\axiomType{Matrix} or in domains involving \\axiomType{FortranCode}.")) (|coerce| (($ (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) "\\spad{coerce(e)} takes the component of \\spad{e} from \\spadtype{List FortranCode} and uses it as the body of the ASP, making the declarations in the \\spadtype{SymbolTable} component.") (($ (|FortranCode|)) "\\spad{coerce(e)} takes an object from \\spadtype{FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|List| (|FortranCode|))) "\\spad{coerce(e)} takes an object from \\spadtype{List FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|Matrix| (|MachineFloat|))) "\\spad{coerce(v)} produces an ASP which returns the value of \\spad{v}."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-390) 
+(-410) 
 ((|constructor| (NIL "\\axiomType{FortranMatrixFunctionCategory} provides support for producing Functions and Subroutines representing matrices of expressions.")) (|retractIfCan| (((|Union| $ "failed") (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Matrix| (|Fraction| (|Polynomial| (|Float|))))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Matrix| (|Polynomial| (|Integer|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Matrix| (|Polynomial| (|Float|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Matrix| (|Expression| (|Integer|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Matrix| (|Expression| (|Float|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}")) (|retract| (($ (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Matrix| (|Fraction| (|Polynomial| (|Float|))))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Matrix| (|Polynomial| (|Integer|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Matrix| (|Polynomial| (|Float|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Matrix| (|Expression| (|Integer|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Matrix| (|Expression| (|Float|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}")) (|coerce| (($ (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) "\\spad{coerce(e)} takes the component of \\spad{e} from \\spadtype{List FortranCode} and uses it as the body of the ASP, making the declarations in the \\spadtype{SymbolTable} component.") (($ (|FortranCode|)) "\\spad{coerce(e)} takes an object from \\spadtype{FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|List| (|FortranCode|))) "\\spad{coerce(e)} takes an object from \\spadtype{List FortranCode} and \\indented{1}{uses it as the body of an ASP.}"))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-391 R S) 
+(-411 R S) 
 ((|constructor| (NIL "A bi-module is a free module over a ring with generators indexed by an ordered set. Each element can be expressed as a finite linear combination of generators. Only non-zero terms are stored."))) 
-((-4597 . T) (-4596 . T)) 
-((|HasCategory| |#1| (QUOTE (-174)))) 
-(-392 S) 
+((-4620 . T) (-4619 . T)) 
+((|HasCategory| |#1| (QUOTE (-194)))) 
+(-412 S) 
 ((|constructor| (NIL "Free monoid on any set of generators The free monoid on a set \\spad{S} is the monoid of finite products of the form \\spad{reduce(*,[si \\spad{**} ni])} where the si's are in \\spad{S,} and the ni's are nonnegative integers. The multiplication is not commutative.")) (|mapGen| (($ (|Mapping| |#1| |#1|) $) "\\spad{mapGen(f, \\spad{a1\\^e1} \\spad{...} an\\^en)} returns \\spad{f(a1)\\^e1 \\spad{...} f(an)\\^en}.")) (|mapExpon| (($ (|Mapping| (|NonNegativeInteger|) (|NonNegativeInteger|)) $) "\\spad{mapExpon(f, \\spad{a1\\^e1} \\spad{...} an\\^en)} returns \\spad{a1\\^f(e1) \\spad{...} an\\^f(en)}.")) (|nthFactor| ((|#1| $ (|Integer|)) "\\spad{nthFactor(x, \\spad{n)}} returns the factor of the n^th monomial of \\spad{x.}")) (|nthExpon| (((|NonNegativeInteger|) $ (|Integer|)) "\\spad{nthExpon(x, \\spad{n)}} returns the exponent of the n^th monomial of \\spad{x.}")) (|factors| (((|List| (|Record| (|:| |gen| |#1|) (|:| |exp| (|NonNegativeInteger|)))) $) "\\spad{factors(a1\\^e1,...,an\\^en)} returns \\spad{[[a1, e1],...,[an, en]]}.")) (|size| (((|NonNegativeInteger|) $) "\\spad{size(x)} returns the number of monomials in \\spad{x.}")) (|overlap| (((|Record| (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) "\\spad{overlap(x, \\spad{y)}} returns \\spad{[l, \\spad{m,} \\spad{r]}} such that \\spad{x = \\spad{l} * \\spad{m},} \\spad{y = \\spad{m} * \\spad{r}} and \\spad{l} and \\spad{r} have no overlap, \\spadignore{i.e.} \\spad{overlap(l, \\spad{r)} = \\spad{[l,} 1, r]}.")) (|divide| (((|Union| (|Record| (|:| |lm| $) (|:| |rm| $)) "failed") $ $) "\\spad{divide(x, \\spad{y)}} returns the left and right exact quotients of \\spad{x} by \\spad{y,} \\spadignore{i.e.} \\spad{[l, \\spad{r]}} such that \\spad{x = \\spad{l} * \\spad{y} * \\spad{r},} \"failed\" if \\spad{x} is not of the form \\spad{l * \\spad{y} * \\spad{r}.}")) (|rquo| (((|Union| $ "failed") $ $) "\\spad{rquo(x, \\spad{y)}} returns the exact right quotient of \\spad{x} by \\spad{y} \\spadignore{i.e.} \\spad{q} such that \\spad{x = \\spad{q} * \\spad{y},} \"failed\" if \\spad{x} is not of the form \\spad{q * \\spad{y}.}")) (|lquo| (((|Union| $ "failed") $ $) "\\spad{lquo(x, \\spad{y)}} returns the exact left quotient of \\spad{x} by \\spad{y} \\spadignore{i.e.} \\spad{q} such that \\spad{x = \\spad{y} * \\spad{q},} \"failed\" if \\spad{x} is not of the form \\spad{y * \\spad{q}.}")) (|hcrf| (($ $ $) "\\spad{hcrf(x, \\spad{y)}} returns the highest common right factor of \\spad{x} and \\spad{y,} \\spadignore{i.e.} the largest \\spad{d} such that \\spad{x = a \\spad{d}} and \\spad{y = \\spad{b} \\spad{d}.}")) (|hclf| (($ $ $) "\\spad{hclf(x, \\spad{y)}} returns the highest common left factor of \\spad{x} and \\spad{y,} \\spadignore{i.e.} the largest \\spad{d} such that \\spad{x = \\spad{d} a} and \\spad{y = \\spad{d} \\spad{b}.}")) (** (($ |#1| (|NonNegativeInteger|)) "\\spad{s \\spad{**} \\spad{n}} returns the product of \\spad{s} by itself \\spad{n} times.")) (* (($ $ |#1|) "\\spad{x * \\spad{s}} returns the product of \\spad{x} by \\spad{s} on the right.") (($ |#1| $) "\\spad{s * \\spad{x}} returns the product of \\spad{x} by \\spad{s} on the left."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-848)))) 
-(-393) 
+((|HasCategory| |#1| (QUOTE (-869)))) 
+(-413) 
 ((|constructor| (NIL "A category of domains which model machine arithmetic used by machines in the AXIOM-NAG link."))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-394) 
+(-414) 
 ((|constructor| (NIL "This domain provides an interface to names in the file system."))) 
 NIL 
 NIL 
-(-395) 
+(-415) 
 ((|constructor| (NIL "This category provides an interface to names in the file system.")) (|new| (($ (|String|) (|String|) (|String|)) "\\spad{new(d,pref,e)} constructs the name of a new writable file with \\spad{d} as its directory, \\spad{pref} as a prefix of its name and \\spad{e} as its extension. When \\spad{d} or \\spad{t} is the empty string, a default is used. An error occurs if a new file cannot be written in the given directory.")) (|writable?| (((|Boolean|) $) "\\spad{writable?(f)} tests if the named file be opened for writing. The named file need not already exist.")) (|readable?| (((|Boolean|) $) "\\spad{readable?(f)} tests if the named file exist and can it be opened for reading.")) (|exists?| (((|Boolean|) $) "\\spad{exists?(f)} tests if the file exists in the file system.")) (|extension| (((|String|) $) "\\spad{extension(f)} returns the type part of the file name.")) (|name| (((|String|) $) "\\spad{name(f)} returns the name part of the file name.")) (|directory| (((|String|) $) "\\spad{directory(f)} returns the directory part of the file name.")) (|filename| (($ (|String|) (|String|) (|String|)) "\\spad{filename(d,n,e)} creates a file name with \\spad{d} as its directory, \\spad{n} as its name and \\spad{e} as its extension. This is a portable way to create file names. When \\spad{d} or \\spad{t} is the empty string, a default is used.")) (|coerce| (((|String|) $) "\\spad{coerce(fn)} produces a string for a file name according to operating system-dependent conventions.") (($ (|String|)) "\\spad{coerce(s)} converts a string to a file name according to operating system-dependent conventions."))) 
 NIL 
 NIL 
-(-396 |n| |class| R) 
+(-416 |n| |class| R) 
 ((|constructor| (NIL "Generate the Free Lie Algebra over a ring \\spad{R} with identity; A \\spad{P.} Hall basis is generated by a package call to HallBasis.")) (|generator| (($ (|NonNegativeInteger|)) "\\spad{generator(i)} is the \\spad{i}th Hall Basis element")) (|shallowExpand| (((|OutputForm|) $) "\\spad{shallowExpand(x)} is not documented")) (|deepExpand| (((|OutputForm|) $) "\\spad{deepExpand(x)} is not documented")) (|dimension| (((|NonNegativeInteger|)) "\\spad{dimension()} is the rank of this Lie algebra"))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-397) 
+(-417) 
 ((|constructor| (NIL "Code to manipulate Fortran Output Stack")) (|topFortranOutputStack| (((|String|)) "\\spad{topFortranOutputStack()} returns the top element of the Fortran output stack")) (|pushFortranOutputStack| (((|Void|) (|String|)) "\\spad{pushFortranOutputStack(f)} pushes \\spad{f} onto the Fortran output stack") (((|Void|) (|FileName|)) "\\spad{pushFortranOutputStack(f)} pushes \\spad{f} onto the Fortran output stack")) (|popFortranOutputStack| (((|Void|)) "\\spad{popFortranOutputStack()} pops the Fortran output stack")) (|showFortranOutputStack| (((|Stack| (|String|))) "\\spad{showFortranOutputStack()} returns the Fortran output stack")) (|clearFortranOutputStack| (((|Stack| (|String|))) "\\spad{clearFortranOutputStack()} clears the Fortran output stack"))) 
 NIL 
 NIL 
-(-398 -3313 UP UPUP R) 
+(-418 -3958 UP UPUP R) 
 ((|constructor| (NIL "Finds the order of a divisor over a finite field")) (|order| (((|NonNegativeInteger|) (|FiniteDivisor| |#1| |#2| |#3| |#4|)) "\\spad{order(x)} \\undocumented"))) 
 NIL 
 NIL 
-(-399 S) 
+(-419 S) 
 ((|constructor| (NIL "\\spadtype{ScriptFormulaFormat1} provides a utility coercion for changing to SCRIPT formula format anything that has a coercion to the standard output format.")) (|coerce| (((|ScriptFormulaFormat|) |#1|) "\\spad{coerce(s)} provides a direct coercion from an expression \\spad{s} of domain \\spad{S} to SCRIPT formula format. This allows the user to skip the step of first manually coercing the object to standard output format before it is coerced to SCRIPT formula format."))) 
 NIL 
 NIL 
-(-400) 
+(-420) 
 ((|constructor| (NIL "\\spadtype{ScriptFormulaFormat} provides a coercion from \\spadtype{OutputForm} to IBM SCRIPT/VS Mathematical Formula Format. The basic SCRIPT formula format object consists of three parts: a prologue, a formula part and an epilogue. The functions \\spadfun{prologue}, \\spadfun{formula} and \\spadfun{epilogue} extract these parts, respectively. The central parts of the expression go into the formula part. The other parts can be set (\\spadfun{setPrologue!}, \\spadfun{setEpilogue!}) so that contain the appropriate tags for printing. For example, the prologue and epilogue might simply contain \":df.\" and \":edf.\" so that the formula section will be printed in display math mode.")) (|setPrologue!| (((|List| (|String|)) $ (|List| (|String|))) "\\spad{setPrologue!(t,strings)} sets the prologue section of a formatted object \\spad{t} to strings.")) (|setFormula!| (((|List| (|String|)) $ (|List| (|String|))) "\\spad{setFormula!(t,strings)} sets the formula section of a formatted object \\spad{t} to strings.")) (|setEpilogue!| (((|List| (|String|)) $ (|List| (|String|))) "\\spad{setEpilogue!(t,strings)} sets the epilogue section of a formatted object \\spad{t} to strings.")) (|prologue| (((|List| (|String|)) $) "\\spad{prologue(t)} extracts the prologue section of a formatted object \\spad{t.}")) (|new| (($) "\\spad{new()} create a new, empty object. Use \\spadfun{setPrologue!}, \\spadfun{setFormula!} and \\spadfun{setEpilogue!} to set the various components of this object.")) (|formula| (((|List| (|String|)) $) "\\spad{formula(t)} extracts the formula section of a formatted object \\spad{t.}")) (|epilogue| (((|List| (|String|)) $) "\\spad{epilogue(t)} extracts the epilogue section of a formatted object \\spad{t.}")) (|display| (((|Void|) $) "\\spad{display(t)} outputs the formatted code \\spad{t} so that each line has length less than or equal to the value set by the system command \\spadsyscom{set output length}.") (((|Void|) $ (|Integer|)) "\\spad{display(t,width)} outputs the formatted code \\spad{t} so that each line has length less than or equal to \\spadvar{width}.")) (|convert| (($ (|OutputForm|) (|Integer|)) "\\spad{convert(o,step)} changes \\spad{o} in standard output format to SCRIPT formula format and also adds the given \\spad{step} number. This is useful if you want to create equations with given numbers or have the equation numbers correspond to the interpreter \\spad{step} numbers.")) (|coerce| (($ (|OutputForm|)) "\\spad{coerce(o)} changes \\spad{o} in the standard output format to SCRIPT formula format."))) 
 NIL 
 NIL 
-(-401) 
+(-421) 
 ((|constructor| (NIL "FortranProgramCategory provides various models of FORTRAN subprograms. These can be transformed into actual FORTRAN code.")) (|outputAsFortran| (((|Void|) $) "\\axiom{outputAsFortran(u)} translates \\axiom{u} into a legal FORTRAN subprogram."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-402) 
+(-422) 
 ((|constructor| (NIL "\\axiomType{FortranFunctionCategory} is the category of arguments to NAG Library routines which return (sets of) function values.")) (|retractIfCan| (((|Union| $ "failed") (|Fraction| (|Polynomial| (|Integer|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Fraction| (|Polynomial| (|Float|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Polynomial| (|Float|))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Expression| (|Integer|))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Expression| (|Float|))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}")) (|retract| (($ (|Fraction| (|Polynomial| (|Integer|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Fraction| (|Polynomial| (|Float|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Polynomial| (|Integer|))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Polynomial| (|Float|))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Expression| (|Integer|))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Expression| (|Float|))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}")) (|coerce| (($ (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) "\\spad{coerce(e)} takes the component of \\spad{e} from \\spadtype{List FortranCode} and uses it as the body of the ASP, making the declarations in the \\spadtype{SymbolTable} component.") (($ (|FortranCode|)) "\\spad{coerce(e)} takes an object from \\spadtype{FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|List| (|FortranCode|))) "\\spad{coerce(e)} takes an object from \\spadtype{List FortranCode} and \\indented{1}{uses it as the body of an ASP.}"))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-403) 
+(-423) 
 ((|constructor| (NIL "provides an interface to the boot code for calling Fortran")) (|setLegalFortranSourceExtensions| (((|List| (|String|)) (|List| (|String|))) "\\spad{setLegalFortranSourceExtensions(l)} \\undocumented{}")) (|outputAsFortran| (((|Void|) (|FileName|)) "\\spad{outputAsFortran(fn)} \\undocumented{}")) (|linkToFortran| (((|SExpression|) (|Symbol|) (|List| (|Symbol|)) (|TheSymbolTable|) (|List| (|Symbol|))) "\\spad{linkToFortran(s,l,t,lv)} \\undocumented{}") (((|SExpression|) (|Symbol|) (|List| (|Union| (|:| |array| (|List| (|Symbol|))) (|:| |scalar| (|Symbol|)))) (|List| (|List| (|Union| (|:| |array| (|List| (|Symbol|))) (|:| |scalar| (|Symbol|))))) (|List| (|Symbol|)) (|Symbol|)) "\\spad{linkToFortran(s,l,ll,lv,t)} \\undocumented{}") (((|SExpression|) (|Symbol|) (|List| (|Union| (|:| |array| (|List| (|Symbol|))) (|:| |scalar| (|Symbol|)))) (|List| (|List| (|Union| (|:| |array| (|List| (|Symbol|))) (|:| |scalar| (|Symbol|))))) (|List| (|Symbol|))) "\\spad{linkToFortran(s,l,ll,lv)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-404 -3201 |returnType| |arguments| |symbols|) 
+(-424 -4095 |returnType| |arguments| |symbols|) 
 ((|constructor| (NIL "\\axiomType{FortranProgram} allows the user to build and manipulate simple models of FORTRAN subprograms. These can then be transformed into actual FORTRAN notation.")) (|coerce| (($ (|Equation| (|Expression| (|Complex| (|Float|))))) "\\spad{coerce(eq)} is not documented") (($ (|Equation| (|Expression| (|Float|)))) "\\spad{coerce(eq)} is not documented") (($ (|Equation| (|Expression| (|Integer|)))) "\\spad{coerce(eq)} is not documented") (($ (|Expression| (|Complex| (|Float|)))) "\\spad{coerce(e)} is not documented") (($ (|Expression| (|Float|))) "\\spad{coerce(e)} is not documented") (($ (|Expression| (|Integer|))) "\\spad{coerce(e)} is not documented") (($ (|Equation| (|Expression| (|MachineComplex|)))) "\\spad{coerce(eq)} is not documented") (($ (|Equation| (|Expression| (|MachineFloat|)))) "\\spad{coerce(eq)} is not documented") (($ (|Equation| (|Expression| (|MachineInteger|)))) "\\spad{coerce(eq)} is not documented") (($ (|Expression| (|MachineComplex|))) "\\spad{coerce(e)} is not documented") (($ (|Expression| (|MachineFloat|))) "\\spad{coerce(e)} is not documented") (($ (|Expression| (|MachineInteger|))) "\\spad{coerce(e)} is not documented") (($ (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) "\\spad{coerce(r)} is not documented") (($ (|List| (|FortranCode|))) "\\spad{coerce(lfc)} is not documented") (($ (|FortranCode|)) "\\spad{coerce(fc)} is not documented"))) 
 NIL 
 NIL 
-(-405 -3313 UP) 
+(-425 -3958 UP) 
 ((|constructor| (NIL "Full partial fraction expansion of rational functions")) (D (($ $ (|NonNegativeInteger|)) "\\spad{D(f, \\spad{n)}} returns the \\spad{n}-th derivative of \\spad{f.}") (($ $) "\\spad{D(f)} returns the derivative of \\spad{f.}")) (|differentiate| (($ $ (|NonNegativeInteger|)) "\\spad{differentiate(f, \\spad{n)}} returns the \\spad{n}-th derivative of \\spad{f.}") (($ $) "\\spad{differentiate(f)} returns the derivative of \\spad{f.}")) (|construct| (($ (|List| (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |center| |#2|) (|:| |num| |#2|)))) "\\spad{construct(l)} is the inverse of fracPart.")) (|fracPart| (((|List| (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |center| |#2|) (|:| |num| |#2|))) $) "\\spad{fracPart(f)} returns the list of summands of the fractional part of \\spad{f.}")) (|polyPart| ((|#2| $) "\\spad{polyPart(f)} returns the polynomial part of \\spad{f.}")) (|fullPartialFraction| (($ (|Fraction| |#2|)) "\\spad{fullPartialFraction(f)} returns \\spad{[p, [[j, \\spad{Dj,} Hj]...]]} such that \\spad{f = p(x) + sum_{[j,Dj,Hj] in \\spad{l}} sum_{Dj(a)=0} Hj(a)/(x - a)\\^j}.")) (+ (($ |#2| $) "\\spad{p + \\spad{x}} returns the sum of \\spad{p} and \\spad{x}"))) 
 NIL 
 NIL 
-(-406 R) 
+(-426 R) 
 ((|constructor| (NIL "A set \\spad{S} is PatternMatchable over \\spad{R} if \\spad{S} can lift the pattern-matching functions of \\spad{S} over the integers and float to itself (necessary for matching in towers)."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-407 S) 
+(-427 S) 
 ((|constructor| (NIL "FieldOfPrimeCharacteristic is the category of fields of prime characteristic, \\spadignore{e.g.} finite fields, algebraic closures of fields of prime characteristic, transcendental extensions of of fields of prime characteristic.")) (|primeFrobenius| (($ $ (|NonNegativeInteger|)) "\\spad{primeFrobenius(a,s)} returns \\spad{a**(p**s)} where \\spad{p} is the characteristic.") (($ $) "\\spad{primeFrobenius(a)} returns \\spad{a**p} where \\spad{p} is the characteristic.")) (|discreteLog| (((|Union| (|NonNegativeInteger|) "failed") $ $) "\\spad{discreteLog(b,a)} computes \\spad{s} with \\spad{b**s = a} if such an \\spad{s} exists.")) (|order| (((|OnePointCompletion| (|PositiveInteger|)) $) "\\spad{order(a)} computes the order of an element in the multiplicative group of the field. Error: if \\spad{a} is 0."))) 
 NIL 
 NIL 
-(-408) 
+(-428) 
 ((|constructor| (NIL "FieldOfPrimeCharacteristic is the category of fields of prime characteristic, \\spadignore{e.g.} finite fields, algebraic closures of fields of prime characteristic, transcendental extensions of of fields of prime characteristic.")) (|primeFrobenius| (($ $ (|NonNegativeInteger|)) "\\spad{primeFrobenius(a,s)} returns \\spad{a**(p**s)} where \\spad{p} is the characteristic.") (($ $) "\\spad{primeFrobenius(a)} returns \\spad{a**p} where \\spad{p} is the characteristic.")) (|discreteLog| (((|Union| (|NonNegativeInteger|) "failed") $ $) "\\spad{discreteLog(b,a)} computes \\spad{s} with \\spad{b**s = a} if such an \\spad{s} exists.")) (|order| (((|OnePointCompletion| (|PositiveInteger|)) $) "\\spad{order(a)} computes the order of an element in the multiplicative group of the field. Error: if \\spad{a} is 0."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-409 S) 
+(-429 S) 
 ((|constructor| (NIL "This category is intended as a model for floating point systems. A floating point system is a model for the real numbers. In fact, it is an approximation in the sense that not all real numbers are exactly representable by floating point numbers. A floating point system is characterized by the following: \\blankline 1: base of the exponent where the actual implemenations are usually binary or decimal)\\br 2: precision of the mantissa (arbitrary or fixed)\\br 3: rounding error for operations \\blankline Because a Float is an approximation to the real numbers, even though it is defined to be a join of a Field and OrderedRing, some of the attributes do not hold. In particular associative(\"+\") does not hold. Algorithms defined over a field need special considerations when the field is a floating point system.")) (|max| (($) "\\spad{max()} returns the maximum floating point number.")) (|min| (($) "\\spad{min()} returns the minimum floating point number.")) (|decreasePrecision| (((|PositiveInteger|) (|Integer|)) "\\spad{decreasePrecision(n)} decreases the current \\spadfunFrom{precision}{FloatingPointSystem} precision by \\spad{n} decimal digits.")) (|increasePrecision| (((|PositiveInteger|) (|Integer|)) "\\spad{increasePrecision(n)} increases the current \\spadfunFrom{precision}{FloatingPointSystem} by \\spad{n} decimal digits.")) (|precision| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{precision(n)} set the precision in the base to \\spad{n} decimal digits.") (((|PositiveInteger|)) "\\spad{precision()} returns the precision in digits base.")) (|digits| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{digits(d)} set the \\spadfunFrom{precision}{FloatingPointSystem} to \\spad{d} digits.") (((|PositiveInteger|)) "\\spad{digits()} returns ceiling's precision in decimal digits.")) (|bits| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{bits(n)} set the \\spadfunFrom{precision}{FloatingPointSystem} to \\spad{n} bits.") (((|PositiveInteger|)) "\\spad{bits()} returns ceiling's precision in bits.")) (|mantissa| (((|Integer|) $) "\\spad{mantissa(x)} returns the mantissa part of \\spad{x.}")) (|exponent| (((|Integer|) $) "\\spad{exponent(x)} returns the \\spadfunFrom{exponent}{FloatingPointSystem} part of \\spad{x.}")) (|base| (((|PositiveInteger|)) "\\spad{base()} returns the base of the \\spadfunFrom{exponent}{FloatingPointSystem}.")) (|order| (((|Integer|) $) "\\spad{order \\spad{x}} is the order of magnitude of \\spad{x.} Note that \\spad{base \\spad{**} order \\spad{x} \\spad{<=} \\spad{|x|} < base \\spad{**} \\spad{(1} + order x)}.")) (|float| (($ (|Integer|) (|Integer|) (|PositiveInteger|)) "\\spad{float(a,e,b)} returns \\spad{a * \\spad{b} \\spad{**} e}.") (($ (|Integer|) (|Integer|)) "\\spad{float(a,e)} returns \\spad{a * base() \\spad{**} e}.")) (|approximate| ((|attribute|) "\\spad{approximate} means \"is an approximation to the real numbers\"."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4585)) (|HasAttribute| |#1| (QUOTE -4593))) 
-(-410) 
+((|HasAttribute| |#1| (QUOTE -4608)) (|HasAttribute| |#1| (QUOTE -4616))) 
+(-430) 
 ((|constructor| (NIL "This category is intended as a model for floating point systems. A floating point system is a model for the real numbers. In fact, it is an approximation in the sense that not all real numbers are exactly representable by floating point numbers. A floating point system is characterized by the following: \\blankline 1: base of the exponent where the actual implemenations are usually binary or decimal)\\br 2: precision of the mantissa (arbitrary or fixed)\\br 3: rounding error for operations \\blankline Because a Float is an approximation to the real numbers, even though it is defined to be a join of a Field and OrderedRing, some of the attributes do not hold. In particular associative(\"+\") does not hold. Algorithms defined over a field need special considerations when the field is a floating point system.")) (|max| (($) "\\spad{max()} returns the maximum floating point number.")) (|min| (($) "\\spad{min()} returns the minimum floating point number.")) (|decreasePrecision| (((|PositiveInteger|) (|Integer|)) "\\spad{decreasePrecision(n)} decreases the current \\spadfunFrom{precision}{FloatingPointSystem} precision by \\spad{n} decimal digits.")) (|increasePrecision| (((|PositiveInteger|) (|Integer|)) "\\spad{increasePrecision(n)} increases the current \\spadfunFrom{precision}{FloatingPointSystem} by \\spad{n} decimal digits.")) (|precision| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{precision(n)} set the precision in the base to \\spad{n} decimal digits.") (((|PositiveInteger|)) "\\spad{precision()} returns the precision in digits base.")) (|digits| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{digits(d)} set the \\spadfunFrom{precision}{FloatingPointSystem} to \\spad{d} digits.") (((|PositiveInteger|)) "\\spad{digits()} returns ceiling's precision in decimal digits.")) (|bits| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{bits(n)} set the \\spadfunFrom{precision}{FloatingPointSystem} to \\spad{n} bits.") (((|PositiveInteger|)) "\\spad{bits()} returns ceiling's precision in bits.")) (|mantissa| (((|Integer|) $) "\\spad{mantissa(x)} returns the mantissa part of \\spad{x.}")) (|exponent| (((|Integer|) $) "\\spad{exponent(x)} returns the \\spadfunFrom{exponent}{FloatingPointSystem} part of \\spad{x.}")) (|base| (((|PositiveInteger|)) "\\spad{base()} returns the base of the \\spadfunFrom{exponent}{FloatingPointSystem}.")) (|order| (((|Integer|) $) "\\spad{order \\spad{x}} is the order of magnitude of \\spad{x.} Note that \\spad{base \\spad{**} order \\spad{x} \\spad{<=} \\spad{|x|} < base \\spad{**} \\spad{(1} + order x)}.")) (|float| (($ (|Integer|) (|Integer|) (|PositiveInteger|)) "\\spad{float(a,e,b)} returns \\spad{a * \\spad{b} \\spad{**} e}.") (($ (|Integer|) (|Integer|)) "\\spad{float(a,e)} returns \\spad{a * base() \\spad{**} e}.")) (|approximate| ((|attribute|) "\\spad{approximate} means \"is an approximation to the real numbers\"."))) 
-((-3410 . T) (-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-2642 . T) (-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-411 R S) 
+(-431 R S) 
 ((|constructor| (NIL "\\spadtype{FactoredFunctions2} contains functions that involve factored objects whose underlying domains may not be the same. For example, \\spadfun{map} might be used to coerce an object of type \\spadtype{Factored(Integer)} to \\spadtype{Factored(Complex(Integer))}.")) (|map| (((|Factored| |#2|) (|Mapping| |#2| |#1|) (|Factored| |#1|)) "\\spad{map(fn,u)} is used to apply the function \\userfun{fn} to every factor of \\spadvar{u}. The new factored object will have all its information flags set to \"nil\". This function is used, for example, to coerce every factor base to another type."))) 
 NIL 
 NIL 
-(-412 A B) 
+(-432 A B) 
 ((|constructor| (NIL "This package extends a map between integral domains to a map between Fractions over those domains by applying the map to the numerators and denominators.")) (|map| (((|Fraction| |#2|) (|Mapping| |#2| |#1|) (|Fraction| |#1|)) "\\spad{map(func,frac)} applies the function \\spad{func} to the numerator and denominator of the fraction frac."))) 
 NIL 
 NIL 
-(-413 S) 
+(-433 S) 
 ((|constructor| (NIL "Fraction takes an IntegralDomain \\spad{S} and produces the domain of Fractions with numerators and denominators from \\spad{S.} If \\spad{S} is also a GcdDomain, then gcd's between numerator and denominator will be cancelled during all operations.")) (|canonical| ((|attribute|) "\\spad{canonical} means that equal elements are in fact identical."))) 
-((-4589 -12 (|has| |#1| (-6 -4600)) (|has| |#1| (-457)) (|has| |#1| (-6 -4589))) (-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-1028))) (|HasCategory| |#1| (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-1144))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -283) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-554))) (-12 (|HasCategory| |#1| (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-829)))) (-12 (|HasAttribute| |#1| (QUOTE -4600)) (|HasAttribute| |#1| (QUOTE -4589)) (|HasCategory| |#1| (QUOTE (-457)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (-12 (|HasCategory| |#1| (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-829))))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-848)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (-12 (|HasCategory| |#1| (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-829))))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (-12 (|HasCategory| |#1| (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-829))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-829))))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (-12 (|HasCategory| |#1| (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-829))))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-414 S R UP) 
+((-4612 -12 (|has| |#1| (-6 -4623)) (|has| |#1| (-477)) (|has| |#1| (-6 -4612))) (-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-1049))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1165))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-574))) (-12 (|HasCategory| |#1| (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-850)))) (-12 (|HasAttribute| |#1| (QUOTE -4623)) (|HasAttribute| |#1| (QUOTE -4612)) (|HasCategory| |#1| (QUOTE (-477)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (-12 (|HasCategory| |#1| (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-850))))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-869)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (-12 (|HasCategory| |#1| (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-850))))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (-12 (|HasCategory| |#1| (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-850))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-850))))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (-12 (|HasCategory| |#1| (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-850))))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-434 S R UP) 
 ((|constructor| (NIL "A \\spadtype{FramedAlgebra} is a \\spadtype{FiniteRankAlgebra} together with a fixed R-module basis.")) (|regularRepresentation| (((|Matrix| |#2|) $) "\\spad{regularRepresentation(a)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the fixed basis.")) (|discriminant| ((|#2|) "\\spad{discriminant()} = determinant(traceMatrix()).")) (|traceMatrix| (((|Matrix| |#2|)) "\\spad{traceMatrix()} is the n-by-n matrix ( \\spad{Tr(vi * vj)} \\spad{),} where \\spad{v1,} ..., \\spad{vn} are the elements of the fixed basis.")) (|convert| (($ (|Vector| |#2|)) "\\spad{convert([a1,..,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where \\spad{v1,} ..., \\spad{vn} are the elements of the fixed basis.") (((|Vector| |#2|) $) "\\spad{convert(a)} returns the coordinates of \\spad{a} with respect to the fixed R-module basis.")) (|represents| (($ (|Vector| |#2|)) "\\spad{represents([a1,..,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where \\spad{v1,} ..., \\spad{vn} are the elements of the fixed basis.")) (|coordinates| (((|Matrix| |#2|) (|Vector| $)) "\\spad{coordinates([v1,...,vm])} returns the coordinates of the vi's with to the fixed basis. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#2|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed R-module basis.")) (|basis| (((|Vector| $)) "\\spad{basis()} returns the fixed R-module basis."))) 
 NIL 
 NIL 
-(-415 R UP) 
+(-435 R UP) 
 ((|constructor| (NIL "A \\spadtype{FramedAlgebra} is a \\spadtype{FiniteRankAlgebra} together with a fixed R-module basis.")) (|regularRepresentation| (((|Matrix| |#1|) $) "\\spad{regularRepresentation(a)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the fixed basis.")) (|discriminant| ((|#1|) "\\spad{discriminant()} = determinant(traceMatrix()).")) (|traceMatrix| (((|Matrix| |#1|)) "\\spad{traceMatrix()} is the n-by-n matrix ( \\spad{Tr(vi * vj)} \\spad{),} where \\spad{v1,} ..., \\spad{vn} are the elements of the fixed basis.")) (|convert| (($ (|Vector| |#1|)) "\\spad{convert([a1,..,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where \\spad{v1,} ..., \\spad{vn} are the elements of the fixed basis.") (((|Vector| |#1|) $) "\\spad{convert(a)} returns the coordinates of \\spad{a} with respect to the fixed R-module basis.")) (|represents| (($ (|Vector| |#1|)) "\\spad{represents([a1,..,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where \\spad{v1,} ..., \\spad{vn} are the elements of the fixed basis.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $)) "\\spad{coordinates([v1,...,vm])} returns the coordinates of the vi's with to the fixed basis. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#1|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed R-module basis.")) (|basis| (((|Vector| $)) "\\spad{basis()} returns the fixed R-module basis."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-416 A S) 
+(-436 A S) 
 ((|constructor| (NIL "A is fully retractable to \\spad{B} means that A is retractable to \\spad{B} and if \\spad{B} is retractable to the integers or rational numbers then so is A. In particular, what we are asserting is that there are no integers (rationals) in A which don't retract into \\spad{B.}"))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) 
-(-417 S) 
+((|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) 
+(-437 S) 
 ((|constructor| (NIL "A is fully retractable to \\spad{B} means that A is retractable to \\spad{B} and if \\spad{B} is retractable to the integers or rational numbers then so is A. In particular, what we are asserting is that there are no integers (rationals) in A which don't retract into \\spad{B.}"))) 
 NIL 
 NIL 
-(-418 R1 F1 U1 A1 R2 F2 U2 A2) 
+(-438 R1 F1 U1 A1 R2 F2 U2 A2) 
 ((|constructor| (NIL "Lifting of morphisms to fractional ideals.")) (|map| (((|FractionalIdeal| |#5| |#6| |#7| |#8|) (|Mapping| |#5| |#1|) (|FractionalIdeal| |#1| |#2| |#3| |#4|)) "\\spad{map(f,i)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-419 R -3313 UP A) 
+(-439 R -3958 UP A) 
 ((|constructor| (NIL "Fractional ideals in a framed algebra.")) (|randomLC| ((|#4| (|NonNegativeInteger|) (|Vector| |#4|)) "\\spad{randomLC(n,x)} should be local but conditional.")) (|minimize| (($ $) "\\spad{minimize(I)} returns a reduced set of generators for \\spad{I}.")) (|denom| ((|#1| $) "\\spad{denom(1/d * (f1,...,fn))} returns \\spad{d.}")) (|numer| (((|Vector| |#4|) $) "\\spad{numer(1/d * (f1,...,fn))} = the vector \\spad{[f1,...,fn]}.")) (|norm| ((|#2| $) "\\spad{norm(I)} returns the norm of the ideal I.")) (|basis| (((|Vector| |#4|) $) "\\spad{basis((f1,...,fn))} returns the vector \\spad{[f1,...,fn]}.")) (|ideal| (($ (|Vector| |#4|)) "\\spad{ideal([f1,...,fn])} returns the ideal \\spad{(f1,...,fn)}."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-420 R -3313 UP A |ibasis|) 
+(-440 R -3958 UP A |ibasis|) 
 ((|constructor| (NIL "Module representation of fractional ideals.")) (|module| (($ (|FractionalIdeal| |#1| |#2| |#3| |#4|)) "\\spad{module(I)} returns \\spad{I} viewed has a module over \\spad{R.}") (($ (|Vector| |#4|)) "\\spad{module([f1,...,fn])} = the module generated by \\spad{(f1,...,fn)} over \\spad{R.}")) (|norm| ((|#2| $) "\\spad{norm(f)} returns the norm of the module \\spad{f.}")) (|basis| (((|Vector| |#4|) $) "\\spad{basis((f1,...,fn))} = the vector \\spad{[f1,...,fn]}."))) 
 NIL 
-((|HasCategory| |#4| (LIST (QUOTE -1044) (|devaluate| |#2|)))) 
-(-421 AR R AS S) 
+((|HasCategory| |#4| (LIST (QUOTE -1065) (|devaluate| |#2|)))) 
+(-441 AR R AS S) 
 ((|constructor| (NIL "\\spad{FramedNonAssociativeAlgebraFunctions2} implements functions between two framed non associative algebra domains defined over different rings. The function map is used to coerce between algebras over different domains having the same structural constants.")) (|map| ((|#3| (|Mapping| |#4| |#2|) |#1|) "\\spad{map(f,u)} maps \\spad{f} onto the coordinates of \\spad{u} to get an element in \\spad{AS} via identification of the basis of \\spad{AR} as beginning part of the basis of \\spad{AS}."))) 
 NIL 
 NIL 
-(-422 S R) 
+(-442 S R) 
 ((|constructor| (NIL "FramedNonAssociativeAlgebra(R) is a \\spadtype{FiniteRankNonAssociativeAlgebra} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free \\spad{R}-module of finite rank) over a commutative ring \\spad{R} together with a fixed \\spad{R}-module basis.")) (|apply| (($ (|Matrix| |#2|) $) "\\spad{apply(m,a)} defines a left operation of \\spad{n} by \\spad{n} matrices where \\spad{n} is the rank of the algebra in terms of matrix-vector multiplication, this is a substitute for a left module structure. Error: if shape of matrix doesn't fit.")) (|rightRankPolynomial| (((|SparseUnivariatePolynomial| (|Polynomial| |#2|))) "\\spad{rightRankPolynomial()} calculates the right minimal polynomial of the generic element in the algebra, defined by the same structural constants over the polynomial ring in symbolic coefficients with respect to the fixed basis.")) (|leftRankPolynomial| (((|SparseUnivariatePolynomial| (|Polynomial| |#2|))) "\\spad{leftRankPolynomial()} calculates the left minimal polynomial of the generic element in the algebra, defined by the same structural constants over the polynomial ring in symbolic coefficients with respect to the fixed basis.")) (|rightRegularRepresentation| (((|Matrix| |#2|) $) "\\spad{rightRegularRepresentation(a)} returns the matrix of the linear map defined by right multiplication by \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|leftRegularRepresentation| (((|Matrix| |#2|) $) "\\spad{leftRegularRepresentation(a)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|rightTraceMatrix| (((|Matrix| |#2|)) "\\spad{rightTraceMatrix()} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the right trace of the product \\spad{vi*vj}, where \\spad{v1},...,\\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|leftTraceMatrix| (((|Matrix| |#2|)) "\\spad{leftTraceMatrix()} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by left trace of the product \\spad{vi*vj}, where \\spad{v1},...,\\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|rightDiscriminant| ((|#2|) "\\spad{rightDiscriminant()} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the right trace of the product \\spad{vi*vj}, where \\spad{v1},...,\\spad{vn} are the elements of the fixed \\spad{R}-module basis. Note that the same as \\spad{determinant(rightTraceMatrix())}.")) (|leftDiscriminant| ((|#2|) "\\spad{leftDiscriminant()} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the left trace of the product \\spad{vi*vj}, where \\spad{v1},...,\\spad{vn} are the elements of the fixed \\spad{R}-module basis. Note that the same as \\spad{determinant(leftTraceMatrix())}.")) (|convert| (($ (|Vector| |#2|)) "\\spad{convert([a1,...,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where \\spad{v1}, ..., \\spad{vn} are the elements of the fixed \\spad{R}-module basis.") (((|Vector| |#2|) $) "\\spad{convert(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|represents| (($ (|Vector| |#2|)) "\\spad{represents([a1,...,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where \\spad{v1}, ..., \\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|conditionsForIdempotents| (((|List| (|Polynomial| |#2|))) "\\spad{conditionsForIdempotents()} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the fixed \\spad{R}-module basis.")) (|structuralConstants| (((|Vector| (|Matrix| |#2|))) "\\spad{structuralConstants()} calculates the structural constants \\spad{[(gammaijk) for \\spad{k} in 1..rank()]} defined by \\spad{vi * \\spad{vj} = \\spad{gammaij1} * \\spad{v1} + \\spad{...} + gammaijn * vn}, where \\spad{v1},...,\\spad{vn} is the fixed \\spad{R}-module basis.")) (|elt| ((|#2| $ (|Integer|)) "\\spad{elt(a,i)} returns the \\spad{i}-th coefficient of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|coordinates| (((|Matrix| |#2|) (|Vector| $)) "\\spad{coordinates([a1,...,am])} returns a matrix whose \\spad{i}-th row is formed by the coordinates of \\spad{ai} with respect to the fixed \\spad{R}-module basis.") (((|Vector| |#2|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|basis| (((|Vector| $)) "\\spad{basis()} returns the fixed \\spad{R}-module basis."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-368)))) 
-(-423 R) 
+((|HasCategory| |#2| (QUOTE (-388)))) 
+(-443 R) 
 ((|constructor| (NIL "FramedNonAssociativeAlgebra(R) is a \\spadtype{FiniteRankNonAssociativeAlgebra} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free \\spad{R}-module of finite rank) over a commutative ring \\spad{R} together with a fixed \\spad{R}-module basis.")) (|apply| (($ (|Matrix| |#1|) $) "\\spad{apply(m,a)} defines a left operation of \\spad{n} by \\spad{n} matrices where \\spad{n} is the rank of the algebra in terms of matrix-vector multiplication, this is a substitute for a left module structure. Error: if shape of matrix doesn't fit.")) (|rightRankPolynomial| (((|SparseUnivariatePolynomial| (|Polynomial| |#1|))) "\\spad{rightRankPolynomial()} calculates the right minimal polynomial of the generic element in the algebra, defined by the same structural constants over the polynomial ring in symbolic coefficients with respect to the fixed basis.")) (|leftRankPolynomial| (((|SparseUnivariatePolynomial| (|Polynomial| |#1|))) "\\spad{leftRankPolynomial()} calculates the left minimal polynomial of the generic element in the algebra, defined by the same structural constants over the polynomial ring in symbolic coefficients with respect to the fixed basis.")) (|rightRegularRepresentation| (((|Matrix| |#1|) $) "\\spad{rightRegularRepresentation(a)} returns the matrix of the linear map defined by right multiplication by \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|leftRegularRepresentation| (((|Matrix| |#1|) $) "\\spad{leftRegularRepresentation(a)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|rightTraceMatrix| (((|Matrix| |#1|)) "\\spad{rightTraceMatrix()} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the right trace of the product \\spad{vi*vj}, where \\spad{v1},...,\\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|leftTraceMatrix| (((|Matrix| |#1|)) "\\spad{leftTraceMatrix()} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by left trace of the product \\spad{vi*vj}, where \\spad{v1},...,\\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|rightDiscriminant| ((|#1|) "\\spad{rightDiscriminant()} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the right trace of the product \\spad{vi*vj}, where \\spad{v1},...,\\spad{vn} are the elements of the fixed \\spad{R}-module basis. Note that the same as \\spad{determinant(rightTraceMatrix())}.")) (|leftDiscriminant| ((|#1|) "\\spad{leftDiscriminant()} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}-th row and \\spad{j}-th column is given by the left trace of the product \\spad{vi*vj}, where \\spad{v1},...,\\spad{vn} are the elements of the fixed \\spad{R}-module basis. Note that the same as \\spad{determinant(leftTraceMatrix())}.")) (|convert| (($ (|Vector| |#1|)) "\\spad{convert([a1,...,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where \\spad{v1}, ..., \\spad{vn} are the elements of the fixed \\spad{R}-module basis.") (((|Vector| |#1|) $) "\\spad{convert(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|represents| (($ (|Vector| |#1|)) "\\spad{represents([a1,...,an])} returns \\spad{a1*v1 + \\spad{...} + an*vn}, where \\spad{v1}, ..., \\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|conditionsForIdempotents| (((|List| (|Polynomial| |#1|))) "\\spad{conditionsForIdempotents()} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the fixed \\spad{R}-module basis.")) (|structuralConstants| (((|Vector| (|Matrix| |#1|))) "\\spad{structuralConstants()} calculates the structural constants \\spad{[(gammaijk) for \\spad{k} in 1..rank()]} defined by \\spad{vi * \\spad{vj} = \\spad{gammaij1} * \\spad{v1} + \\spad{...} + gammaijn * vn}, where \\spad{v1},...,\\spad{vn} is the fixed \\spad{R}-module basis.")) (|elt| ((|#1| $ (|Integer|)) "\\spad{elt(a,i)} returns the \\spad{i}-th coefficient of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $)) "\\spad{coordinates([a1,...,am])} returns a matrix whose \\spad{i}-th row is formed by the coordinates of \\spad{ai} with respect to the fixed \\spad{R}-module basis.") (((|Vector| |#1|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|basis| (((|Vector| $)) "\\spad{basis()} returns the fixed \\spad{R}-module basis."))) 
-((-4599 |has| |#1| (-562)) (-4597 . T) (-4596 . T)) 
+((-4622 |has| |#1| (-582)) (-4620 . T) (-4619 . T)) 
 NIL 
-(-424 R) 
+(-444 R) 
 ((|constructor| (NIL "\\spadtype{Factored} creates a domain whose objects are kept in factored form as long as possible. Thus certain operations like multiplication and \\spad{gcd} are relatively easy to do. Others, like addition require somewhat more work, and unless the argument domain provides a factor function, the result may not be completely factored. Each object consists of a unit and a list of factors, where a factor has a member of \\spad{R} (the \"base\"), and exponent and a flag indicating what is known about the base. A flag may be one of \"nil\", \"sqfr\", \"irred\" or \"prime\", which respectively mean that nothing is known about the base, it is square-free, it is irreducible, or it is prime. The current restriction to integral domains allows simplification to be performed without worrying about multiplication order.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(u)} returns a rational number if \\spad{u} really is one, and \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(u)} assumes spadvar{u} is actually a rational number and does the conversion to rational number (see \\spadtype{Fraction Integer}).")) (|rational?| (((|Boolean|) $) "\\spad{rational?(u)} tests if \\spadvar{u} is actually a rational number (see \\spadtype{Fraction Integer}).")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\indented{1}{map(fn,u) maps the function \\userfun{fn} across the factors of} \\indented{1}{\\spadvar{u} and creates a new factored object. Note: this clears} \\indented{1}{the information flags (sets them to \"nil\") because the effect of} \\indented{1}{\\userfun{fn} is clearly not known in general.} \\blankline \\spad{X} m(a:Factored Polynomial Integer):Factored Polynomial Integer \\spad{==} \\spad{a^2} \\spad{X} \\spad{f:=x*y^3-3*x^2*y^2+3*x^3*y-x^4} \\spad{X} map(m,f) \\spad{X} g:=makeFR(z,factorList \\spad{f)} \\spad{X} map(m,g)")) (|unitNormalize| (($ $) "\\spad{unitNormalize(u)} normalizes the unit part of the factorization. For example, when working with factored integers, this operation will ensure that the bases are all positive integers.")) (|unit| ((|#1| $) "\\indented{1}{unit(u) extracts the unit part of the factorization.} \\blankline \\spad{X} \\spad{f:=x*y^3-3*x^2*y^2+3*x^3*y-x^4} \\spad{X} unit \\spad{f} \\spad{X} g:=makeFR(z,factorList \\spad{f)} \\spad{X} unit \\spad{g}")) (|flagFactor| (($ |#1| (|Integer|) (|Union| "nil" "sqfr" "irred" "prime")) "\\spad{flagFactor(base,exponent,flag)} creates a factored object with a single factor whose \\spad{base} is asserted to be properly described by the information flag.")) (|sqfrFactor| (($ |#1| (|Integer|)) "\\indented{1}{sqfrFactor(base,exponent) creates a factored object with} \\indented{1}{a single factor whose base is asserted to be square-free} \\indented{1}{(flag = \"sqfr\").} \\blankline \\spad{X} a:=sqfrFactor(3,5) \\spad{X} nthFlag(a,1)")) (|primeFactor| (($ |#1| (|Integer|)) "\\indented{1}{primeFactor(base,exponent) creates a factored object with} \\indented{1}{a single factor whose base is asserted to be prime} \\indented{1}{(flag = \"prime\").} \\blankline \\spad{X} a:=primeFactor(3,4) \\spad{X} nthFlag(a,1)")) (|numberOfFactors| (((|NonNegativeInteger|) $) "\\indented{1}{numberOfFactors(u) returns the number of factors in \\spadvar{u}.} \\blankline \\spad{X} a:=factor 9720000 \\spad{X} numberOfFactors a")) (|nthFlag| (((|Union| "nil" "sqfr" "irred" "prime") $ (|Integer|)) "\\indented{1}{nthFlag(u,n) returns the information flag of the \\spad{n}th factor of} \\indented{1}{\\spadvar{u}.\\space{2}If \\spadvar{n} is not a valid index for a factor} \\indented{1}{(for example, less than 1 or too big), \"nil\" is returned.} \\blankline \\spad{X} a:=factor 9720000 \\spad{X} nthFlag(a,2)")) (|nthFactor| ((|#1| $ (|Integer|)) "\\indented{1}{nthFactor(u,n) returns the base of the \\spad{n}th factor of} \\indented{1}{\\spadvar{u}.\\space{2}If \\spadvar{n} is not a valid index for a factor} \\indented{1}{(for example, less than 1 or too big), 1 is returned.\\space{2}If} \\indented{1}{\\spadvar{u} consists only of a unit, the unit is returned.} \\blankline \\spad{X} a:=factor 9720000 \\spad{X} nthFactor(a,2)")) (|nthExponent| (((|Integer|) $ (|Integer|)) "\\indented{1}{nthExponent(u,n) returns the exponent of the \\spad{n}th factor of} \\indented{1}{\\spadvar{u}.\\space{2}If \\spadvar{n} is not a valid index for a factor} \\indented{1}{(for example, less than 1 or too big), 0 is returned.} \\blankline \\spad{X} a:=factor 9720000 \\spad{X} nthExponent(a,2)")) (|irreducibleFactor| (($ |#1| (|Integer|)) "\\indented{1}{irreducibleFactor(base,exponent) creates a factored object with} \\indented{1}{a single factor whose base is asserted to be irreducible} \\indented{1}{(flag = \"irred\").} \\blankline \\spad{X} a:=irreducibleFactor(3,1) \\spad{X} nthFlag(a,1)")) (|factors| (((|List| (|Record| (|:| |factor| |#1|) (|:| |exponent| (|Integer|)))) $) "\\indented{1}{factors(u) returns a list of the factors in a form suitable} \\indented{1}{for iteration. That is, it returns a list where each element} \\indented{1}{is a record containing a base and exponent.\\space{2}The original} \\indented{1}{object is the product of all the factors and the unit (which} \\indented{1}{can be extracted by \\axiom{unit(u)}).} \\blankline \\spad{X} \\spad{f:=x*y^3-3*x^2*y^2+3*x^3*y-x^4} \\spad{X} factors \\spad{f} \\spad{X} g:=makeFR(z,factorList \\spad{f)} \\spad{X} factors \\spad{g}")) (|nilFactor| (($ |#1| (|Integer|)) "\\indented{1}{nilFactor(base,exponent) creates a factored object with} \\indented{1}{a single factor with no information about the kind of} \\indented{1}{base (flag = \"nil\").} \\blankline \\spad{X} nilFactor(24,2) \\spad{X} nilFactor(x-y,3)")) (|factorList| (((|List| (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (|Integer|)))) $) "\\indented{1}{factorList(u) returns the list of factors with flags (for} \\indented{1}{use by factoring code).} \\blankline \\spad{X} f:=nilFactor(x-y,3) \\spad{X} factorList \\spad{f}")) (|makeFR| (($ |#1| (|List| (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (|Integer|))))) "\\indented{1}{makeFR(unit,listOfFactors) creates a factored object (for} \\indented{1}{use by factoring code).} \\blankline \\spad{X} f:=nilFactor(x-y,3) \\spad{X} g:=factorList \\spad{f} \\spad{X} makeFR(z,g)")) (|exponent| (((|Integer|) $) "\\indented{1}{exponent(u) returns the exponent of the first factor of} \\indented{1}{\\spadvar{u}, or 0 if the factored form consists solely of a unit.} \\blankline \\spad{X} f:=nilFactor(y-x,3) \\spad{X} exponent(f)")) (|expand| ((|#1| $) "\\indented{1}{expand(f) multiplies the unit and factors together, yielding an} \\indented{1}{\"unfactored\" object. Note: this is purposely not called} \\indented{1}{\\spadfun{coerce} which would cause the interpreter to do this} \\indented{1}{automatically.} \\blankline \\spad{X} f:=nilFactor(y-x,3) \\spad{X} expand(f)"))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -527) (QUOTE (-1170)) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -305) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -283) (QUOTE $) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-1214))) (|HasCategory| |#1| (QUOTE (-1028))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -283) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-1214))))) 
-(-425 R) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -547) (QUOTE (-1191)) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -325) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -303) (QUOTE $) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-1235))) (|HasCategory| |#1| (QUOTE (-1049))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-1235))))) 
+(-445 R) 
 ((|constructor| (NIL "\\spadtype{FactoredFunctionUtilities} implements some utility functions for manipulating factored objects.")) (|mergeFactors| (((|Factored| |#1|) (|Factored| |#1|) (|Factored| |#1|)) "\\spad{mergeFactors(u,v)} is used when the factorizations of \\spadvar{u} and \\spadvar{v} are known to be disjoint, \\spadignore{e.g.} resulting from a content/primitive part split. Essentially, it creates a new factored object by multiplying the units together and appending the lists of factors.")) (|refine| (((|Factored| |#1|) (|Factored| |#1|) (|Mapping| (|Factored| |#1|) |#1|)) "\\spad{refine(u,fn)} is used to apply the function \\userfun{fn} to each factor of \\spadvar{u} and then build a new factored object from the results. For example, if \\spadvar{u} were created by calling \\spad{nilFactor(10,2)} then \\spad{refine(u,factor)} would create a factored object equal to that created by \\spad{factor(100)} or \\spad{primeFactor(2,2) * primeFactor(5,2)}."))) 
 NIL 
 NIL 
-(-426 R FE |x| |cen|) 
+(-446 R FE |x| |cen|) 
 ((|constructor| (NIL "This package converts expressions in some function space to exponential expansions.")) (|localAbs| ((|#2| |#2|) "\\spad{localAbs(fcn)} = \\spad{abs(fcn)} or \\spad{sqrt(fcn**2)} depending on whether or not FE has a function \\spad{abs}. This should be a local function, but the compiler won't allow it.")) (|exprToXXP| (((|Union| (|:| |%expansion| (|ExponentialExpansion| |#1| |#2| |#3| |#4|)) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|))))) |#2| (|Boolean|)) "\\spad{exprToXXP(fcn,posCheck?)} converts the expression \\spad{fcn} to an exponential expansion. If \\spad{posCheck?} is true, log's of negative numbers are not allowed nor are \\spad{n}th roots of negative numbers with \\spad{n} even. If \\spad{posCheck?} is false, these are allowed."))) 
 NIL 
 NIL 
-(-427 R A S B) 
+(-447 R A S B) 
 ((|constructor| (NIL "Lifting of maps to function spaces This package allows a mapping \\spad{R} \\spad{->} \\spad{S} to be lifted to a mapping from a function space over \\spad{R} to a function space over \\spad{S;}")) (|map| ((|#4| (|Mapping| |#3| |#1|) |#2|) "\\spad{map(f, a)} applies \\spad{f} to all the constants in \\spad{R} appearing in \\spad{a}."))) 
 NIL 
 NIL 
-(-428 R FE |Expon| UPS TRAN |x|) 
+(-448 R FE |Expon| UPS TRAN |x|) 
 ((|constructor| (NIL "This package converts expressions in some function space to power series in a variable \\spad{x} with coefficients in that function space. The function \\spadfun{exprToUPS} converts expressions to power series whose coefficients do not contain the variable \\spad{x.} The function \\spadfun{exprToGenUPS} converts functional expressions to power series whose coefficients may involve functions of \\spad{log(x)}.")) (|localAbs| ((|#2| |#2|) "\\spad{localAbs(fcn)} = \\spad{abs(fcn)} or \\spad{sqrt(fcn**2)} depending on whether or not FE has a function \\spad{abs}. This should be a local function, but the compiler won't allow it.")) (|exprToGenUPS| (((|Union| (|:| |%series| |#4|) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|))))) |#2| (|Boolean|) (|String|)) "\\spad{exprToGenUPS(fcn,posCheck?,atanFlag)} converts the expression \\spad{fcn} to a generalized power series. If \\spad{posCheck?} is true, log's of negative numbers are not allowed nor are \\spad{n}th roots of negative numbers with \\spad{n} even. If \\spad{posCheck?} is false, these are allowed. \\spad{atanFlag} determines how the case \\spad{atan(f(x))}, where \\spad{f(x)} has a pole, will be treated. The possible values of \\spad{atanFlag} are \\spad{\"complex\"}, \\spad{\"real: two sides\"}, \\spad{\"real: left side\"}, \\spad{\"real: right side\"}, and \\spad{\"just do it\"}. If \\spad{atanFlag} is \\spad{\"complex\"}, then no series expansion will be computed because, viewed as a function of a complex variable, \\spad{atan(f(x))} has an essential singularity. Otherwise, the sign of the leading coefficient of the series expansion of \\spad{f(x)} determines the constant coefficient in the series expansion of \\spad{atan(f(x))}. If this sign cannot be determined, a series expansion is computed only when \\spad{atanFlag} is \\spad{\"just do it\"}. When the leading term in the series expansion of \\spad{f(x)} is of odd degree (or is a rational degree with odd numerator), then the constant coefficient in the series expansion of \\spad{atan(f(x))} for values to the left differs from that for values to the right. If \\spad{atanFlag} is \\spad{\"real: two sides\"}, no series expansion will be computed. If \\spad{atanFlag} is \\spad{\"real: left side\"} the constant coefficient for values to the left will be used and if \\spad{atanFlag} \\spad{\"real: right side\"} the constant coefficient for values to the right will be used. If there is a problem in converting the function to a power series, we return a record containing the name of the function that caused the problem and a brief description of the problem. When expanding the expression into a series it is assumed that the series is centered at 0. For a series centered at a, the user should perform the substitution \\spad{x \\spad{->} \\spad{x} + a} before calling this function.")) (|exprToUPS| (((|Union| (|:| |%series| |#4|) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|))))) |#2| (|Boolean|) (|String|)) "\\spad{exprToUPS(fcn,posCheck?,atanFlag)} converts the expression \\spad{fcn} to a power series. If \\spad{posCheck?} is true, log's of negative numbers are not allowed nor are \\spad{n}th roots of negative numbers with \\spad{n} even. If \\spad{posCheck?} is false, these are allowed. \\spad{atanFlag} determines how the case \\spad{atan(f(x))}, where \\spad{f(x)} has a pole, will be treated. The possible values of \\spad{atanFlag} are \\spad{\"complex\"}, \\spad{\"real: two sides\"}, \\spad{\"real: left side\"}, \\spad{\"real: right side\"}, and \\spad{\"just do it\"}. If \\spad{atanFlag} is \\spad{\"complex\"}, then no series expansion will be computed because, viewed as a function of a complex variable, \\spad{atan(f(x))} has an essential singularity. Otherwise, the sign of the leading coefficient of the series expansion of \\spad{f(x)} determines the constant coefficient in the series expansion of \\spad{atan(f(x))}. If this sign cannot be determined, a series expansion is computed only when \\spad{atanFlag} is \\spad{\"just do it\"}. When the leading term in the series expansion of \\spad{f(x)} is of odd degree (or is a rational degree with odd numerator), then the constant coefficient in the series expansion of \\spad{atan(f(x))} for values to the left differs from that for values to the right. If \\spad{atanFlag} is \\spad{\"real: two sides\"}, no series expansion will be computed. If \\spad{atanFlag} is \\spad{\"real: left side\"} the constant coefficient for values to the left will be used and if \\spad{atanFlag} \\spad{\"real: right side\"} the constant coefficient for values to the right will be used. If there is a problem in converting the function to a power series, a record containing the name of the function that caused the problem and a brief description of the problem is returned. When expanding the expression into a series it is assumed that the series is centered at 0. For a series centered at a, the user should perform the substitution \\spad{x \\spad{->} \\spad{x} + a} before calling this function.")) (|integrate| (($ $) "\\spad{integrate(x)} returns the integral of \\spad{x} since we need to be able to integrate a power series")) (|differentiate| (($ $) "\\spad{differentiate(x)} returns the derivative of \\spad{x} since we need to be able to differentiate a power series")) (|coerce| (($ |#3|) "\\spad{coerce(e)} converts an 'exponent' \\spad{e} to an 'expression'"))) 
 NIL 
 NIL 
-(-429 S A R B) 
+(-449 S A R B) 
 ((|constructor| (NIL "\\spad{FiniteSetAggregateFunctions2} provides functions involving two finite set aggregates where the underlying domains might be different. An example of this is to create a set of rational numbers by mapping a function across a set of integers, where the function divides each integer by 1000.")) (|scan| ((|#4| (|Mapping| |#3| |#1| |#3|) |#2| |#3|) "\\spad{scan(f,a,r)} successively applies \\spad{reduce(f,x,r)} to more and more leading sub-aggregates \\spad{x} of aggregate \\spad{a}. More precisely, if \\spad{a} is \\spad{[a1,a2,...]}, then \\spad{scan(f,a,r)} returns \\spad {[reduce(f,[a1],r),reduce(f,[a1,a2],r),...]}.")) (|reduce| ((|#3| (|Mapping| |#3| |#1| |#3|) |#2| |#3|) "\\spad{reduce(f,a,r)} applies function \\spad{f} to each successive element of the aggregate \\spad{a} and an accumulant initialised to \\spad{r.} For example, \\spad{reduce(_+$Integer,[1,2,3],0)} does a \\spad{3+(2+(1+0))}. Note that third argument \\spad{r} may be regarded as an identity element for the function.")) (|map| ((|#4| (|Mapping| |#3| |#1|) |#2|) "\\spad{map(f,a)} applies function \\spad{f} to each member of aggregate \\spad{a}, creating a new aggregate with a possibly different underlying domain."))) 
 NIL 
 NIL 
-(-430 A S) 
+(-450 A S) 
 ((|constructor| (NIL "A finite-set aggregate models the notion of a finite set, that is, a collection of elements characterized by membership, but not by order or multiplicity. See \\spadtype{Set} for an example.")) (|min| ((|#2| $) "\\spad{min(u)} returns the smallest element of aggregate u.")) (|max| ((|#2| $) "\\spad{max(u)} returns the largest element of aggregate u.")) (|universe| (($) "\\spad{universe()}$D returns the universal set for finite set aggregate \\spad{D.}")) (|complement| (($ $) "\\spad{complement(u)} returns the complement of the set u, that is, the set of all values not in u.")) (|cardinality| (((|NonNegativeInteger|) $) "\\spad{cardinality(u)} returns the number of elements of u. Note that \\axiom{cardinality(u) = \\#u}."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-374)))) 
-(-431 S) 
+((|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-394)))) 
+(-451 S) 
 ((|constructor| (NIL "A finite-set aggregate models the notion of a finite set, that is, a collection of elements characterized by membership, but not by order or multiplicity. See \\spadtype{Set} for an example.")) (|min| ((|#1| $) "\\spad{min(u)} returns the smallest element of aggregate u.")) (|max| ((|#1| $) "\\spad{max(u)} returns the largest element of aggregate u.")) (|universe| (($) "\\spad{universe()}$D returns the universal set for finite set aggregate \\spad{D.}")) (|complement| (($ $) "\\spad{complement(u)} returns the complement of the set u, that is, the set of all values not in u.")) (|cardinality| (((|NonNegativeInteger|) $) "\\spad{cardinality(u)} returns the number of elements of u. Note that \\axiom{cardinality(u) = \\#u}."))) 
-((-4602 . T) (-4592 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4615 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-432 R -3313) 
+(-452 R -3958) 
 ((|constructor| (NIL "Top-level complex function integration \\spadtype{FunctionSpaceComplexIntegration} provides functions for the indefinite integration of complex-valued functions.")) (|complexIntegrate| ((|#2| |#2| (|Symbol|)) "\\spad{complexIntegrate(f, \\spad{x)}} returns the integral of \\spad{f(x)dx} where \\spad{x} is viewed as a complex variable.")) (|internalIntegrate0| (((|IntegrationResult| |#2|) |#2| (|Symbol|)) "\\spad{internalIntegrate0 should} be a local function, but is conditional.")) (|internalIntegrate| (((|IntegrationResult| |#2|) |#2| (|Symbol|)) "\\spad{internalIntegrate(f, \\spad{x)}} returns the integral of \\spad{f(x)dx} where \\spad{x} is viewed as a complex variable."))) 
 NIL 
 NIL 
-(-433 R E) 
+(-453 R E) 
 ((|constructor| (NIL "This domain converts terms into Fourier series")) (|makeCos| (($ |#2| |#1|) "\\indented{1}{makeCos(e,r) makes a sin expression with given} argument and coefficient")) (|makeSin| (($ |#2| |#1|) "\\spad{makeSin(e,r)} makes a sin expression with given argument and coefficient")) (|coerce| (($ (|FourierComponent| |#2|)) "\\spad{coerce(c)} converts sin/cos terms into Fourier Series") (($ |#1|) "\\spad{coerce(r)} converts coefficients into Fourier Series"))) 
-((-4589 -12 (|has| |#1| (-6 -4589)) (|has| |#2| (-6 -4589))) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((-12 (|HasAttribute| |#1| (QUOTE -4589)) (|HasAttribute| |#2| (QUOTE -4589)))) 
-(-434 R -3313) 
+((-4612 -12 (|has| |#1| (-6 -4612)) (|has| |#2| (-6 -4612))) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((-12 (|HasAttribute| |#1| (QUOTE -4612)) (|HasAttribute| |#2| (QUOTE -4612)))) 
+(-454 R -3958) 
 ((|constructor| (NIL "Top-level real function integration \\spadtype{FunctionSpaceIntegration} provides functions for the indefinite integration of real-valued functions.")) (|integrate| (((|Union| |#2| (|List| |#2|)) |#2| (|Symbol|)) "\\spad{integrate(f, \\spad{x)}} returns the integral of \\spad{f(x)dx} where \\spad{x} is viewed as a real variable."))) 
 NIL 
 NIL 
-(-435 S R) 
+(-455 S R) 
 ((|constructor| (NIL "Category for formal functions A space of formal functions with arguments in an arbitrary ordered set.")) (|univariate| (((|Fraction| (|SparseUnivariatePolynomial| $)) $ (|Kernel| $)) "\\spad{univariate(f, \\spad{k)}} returns \\spad{f} viewed as a univariate fraction in \\spad{k.}")) (/ (($ (|SparseMultivariatePolynomial| |#2| (|Kernel| $)) (|SparseMultivariatePolynomial| |#2| (|Kernel| $))) "\\spad{p1/p2} returns the quotient of \\spad{p1} and \\spad{p2} as an element of \\spad{%.}")) (|denominator| (($ $) "\\spad{denominator(f)} returns the denominator of \\spad{f} converted to \\spad{%.}")) (|denom| (((|SparseMultivariatePolynomial| |#2| (|Kernel| $)) $) "\\spad{denom(f)} returns the denominator of \\spad{f} viewed as a polynomial in the kernels over \\spad{R.}")) (|convert| (($ (|Factored| $)) "\\spad{convert(f1\\^e1 \\spad{...} fm\\^em)} returns \\spad{(f1)\\^e1 \\spad{...} (fm)\\^em} as an element of \\spad{%,} using formal kernels created using a \\spadfunFrom{paren}{ExpressionSpace}.")) (|isPower| (((|Union| (|Record| (|:| |val| $) (|:| |exponent| (|Integer|))) "failed") $) "\\spad{isPower(p)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0}.")) (|numerator| (($ $) "\\spad{numerator(f)} returns the numerator of \\spad{f} converted to \\spad{%.}")) (|numer| (((|SparseMultivariatePolynomial| |#2| (|Kernel| $)) $) "\\spad{numer(f)} returns the numerator of \\spad{f} viewed as a polynomial in the kernels over \\spad{R} if \\spad{R} is an integral domain. If not, then numer(f) = \\spad{f} viewed as a polynomial in the kernels over \\spad{R.}")) (|coerce| (($ (|Fraction| (|Polynomial| (|Fraction| |#2|)))) "\\spad{coerce(f)} returns \\spad{f} as an element of \\spad{%.}") (($ (|Polynomial| (|Fraction| |#2|))) "\\spad{coerce(p)} returns \\spad{p} as an element of \\spad{%.}") (($ (|Fraction| |#2|)) "\\spad{coerce(q)} returns \\spad{q} as an element of \\spad{%.}") (($ (|SparseMultivariatePolynomial| |#2| (|Kernel| $))) "\\spad{coerce(p)} returns \\spad{p} as an element of \\spad{%.}")) (|isMult| (((|Union| (|Record| (|:| |coef| (|Integer|)) (|:| |var| (|Kernel| $))) "failed") $) "\\spad{isMult(p)} returns \\spad{[n, \\spad{x]}} if \\spad{p = \\spad{n} * \\spad{x}} and \\spad{n \\spad{<>} 0}.")) (|isPlus| (((|Union| (|List| $) "failed") $) "\\spad{isPlus(p)} returns \\spad{[m1,...,mn]} if \\spad{p = \\spad{m1} +...+ \\spad{mn}} and \\spad{n > 1}.")) (|isExpt| (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $ (|Symbol|)) "\\spad{isExpt(p,f)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0} and \\spad{x = f(a)}.") (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $ (|BasicOperator|)) "\\spad{isExpt(p,op)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0} and \\spad{x = op(a)}.") (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $) "\\spad{isExpt(p)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0}.")) (|isTimes| (((|Union| (|List| $) "failed") $) "\\spad{isTimes(p)} returns \\spad{[a1,...,an]} if \\spad{p = a1*...*an} and \\spad{n > 1}.")) (** (($ $ (|NonNegativeInteger|)) "\\spad{x**n} returns \\spad{x} * \\spad{x} * \\spad{x} * \\spad{...} * \\spad{x} \\spad{(n} times).")) (|eval| (($ $ (|Symbol|) (|NonNegativeInteger|) (|Mapping| $ $)) "\\spad{eval(x, \\spad{s,} \\spad{n,} \\spad{f)}} replaces every \\spad{s(a)**n} in \\spad{x} by \\spad{f(a)} for any \\spad{a}.") (($ $ (|Symbol|) (|NonNegativeInteger|) (|Mapping| $ (|List| $))) "\\spad{eval(x, \\spad{s,} \\spad{n,} \\spad{f)}} replaces every \\spad{s(a1,...,am)**n} in \\spad{x} by \\spad{f(a1,...,am)} for any a1,...,am.") (($ $ (|List| (|Symbol|)) (|List| (|NonNegativeInteger|)) (|List| (|Mapping| $ (|List| $)))) "\\spad{eval(x, [s1,...,sm], [n1,...,nm], [f1,...,fm])} replaces every \\spad{si(a1,...,an)**ni} in \\spad{x} by \\spad{fi(a1,...,an)} for any a1,...,am.") (($ $ (|List| (|Symbol|)) (|List| (|NonNegativeInteger|)) (|List| (|Mapping| $ $))) "\\spad{eval(x, [s1,...,sm], [n1,...,nm], [f1,...,fm])} replaces every \\spad{si(a)**ni} in \\spad{x} by \\spad{fi(a)} for any \\spad{a}.") (($ $ (|List| (|BasicOperator|)) (|List| $) (|Symbol|)) "\\spad{eval(x, [s1,...,sm], [f1,...,fm], \\spad{y)}} replaces every \\spad{si(a)} in \\spad{x} by \\spad{fi(y)} with \\spad{y} replaced by \\spad{a} for any \\spad{a}.") (($ $ (|BasicOperator|) $ (|Symbol|)) "\\spad{eval(x, \\spad{s,} \\spad{f,} \\spad{y)}} replaces every \\spad{s(a)} in \\spad{x} by \\spad{f(y)} with \\spad{y} replaced by \\spad{a} for any \\spad{a}.") (($ $) "\\spad{eval(f)} unquotes all the quoted operators in \\spad{f.}") (($ $ (|List| (|Symbol|))) "\\spad{eval(f, [foo1,...,foon])} unquotes all the \\spad{fooi}'s in \\spad{f.}") (($ $ (|Symbol|)) "\\spad{eval(f, foo)} unquotes all the foo's in \\spad{f.}")) (|applyQuote| (($ (|Symbol|) (|List| $)) "\\spad{applyQuote(foo, [x1,...,xn])} returns \\spad{'foo(x1,...,xn)}.") (($ (|Symbol|) $ $ $ $) "\\spad{applyQuote(foo, \\spad{x,} \\spad{y,} \\spad{z,} \\spad{t)}} returns \\spad{'foo(x,y,z,t)}.") (($ (|Symbol|) $ $ $) "\\spad{applyQuote(foo, \\spad{x,} \\spad{y,} \\spad{z)}} returns \\spad{'foo(x,y,z)}.") (($ (|Symbol|) $ $) "\\spad{applyQuote(foo, \\spad{x,} \\spad{y)}} returns \\spad{'foo(x,y)}.") (($ (|Symbol|) $) "\\spad{applyQuote(foo, \\spad{x)}} returns \\spad{'foo(x)}.")) (|variables| (((|List| (|Symbol|)) $) "\\spad{variables(f)} returns the list of all the variables of \\spad{f.}")) (|ground| ((|#2| $) "\\spad{ground(f)} returns \\spad{f} as an element of \\spad{R.} An error occurs if \\spad{f} is not an element of \\spad{R.}")) (|ground?| (((|Boolean|) $) "\\spad{ground?(f)} tests if \\spad{f} is an element of \\spad{R.}"))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-482))) (|HasCategory| |#2| (QUOTE (-1110))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) 
-(-436 R) 
+((|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-502))) (|HasCategory| |#2| (QUOTE (-1131))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) 
+(-456 R) 
 ((|constructor| (NIL "Category for formal functions A space of formal functions with arguments in an arbitrary ordered set.")) (|univariate| (((|Fraction| (|SparseUnivariatePolynomial| $)) $ (|Kernel| $)) "\\spad{univariate(f, \\spad{k)}} returns \\spad{f} viewed as a univariate fraction in \\spad{k.}")) (/ (($ (|SparseMultivariatePolynomial| |#1| (|Kernel| $)) (|SparseMultivariatePolynomial| |#1| (|Kernel| $))) "\\spad{p1/p2} returns the quotient of \\spad{p1} and \\spad{p2} as an element of \\spad{%.}")) (|denominator| (($ $) "\\spad{denominator(f)} returns the denominator of \\spad{f} converted to \\spad{%.}")) (|denom| (((|SparseMultivariatePolynomial| |#1| (|Kernel| $)) $) "\\spad{denom(f)} returns the denominator of \\spad{f} viewed as a polynomial in the kernels over \\spad{R.}")) (|convert| (($ (|Factored| $)) "\\spad{convert(f1\\^e1 \\spad{...} fm\\^em)} returns \\spad{(f1)\\^e1 \\spad{...} (fm)\\^em} as an element of \\spad{%,} using formal kernels created using a \\spadfunFrom{paren}{ExpressionSpace}.")) (|isPower| (((|Union| (|Record| (|:| |val| $) (|:| |exponent| (|Integer|))) "failed") $) "\\spad{isPower(p)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0}.")) (|numerator| (($ $) "\\spad{numerator(f)} returns the numerator of \\spad{f} converted to \\spad{%.}")) (|numer| (((|SparseMultivariatePolynomial| |#1| (|Kernel| $)) $) "\\spad{numer(f)} returns the numerator of \\spad{f} viewed as a polynomial in the kernels over \\spad{R} if \\spad{R} is an integral domain. If not, then numer(f) = \\spad{f} viewed as a polynomial in the kernels over \\spad{R.}")) (|coerce| (($ (|Fraction| (|Polynomial| (|Fraction| |#1|)))) "\\spad{coerce(f)} returns \\spad{f} as an element of \\spad{%.}") (($ (|Polynomial| (|Fraction| |#1|))) "\\spad{coerce(p)} returns \\spad{p} as an element of \\spad{%.}") (($ (|Fraction| |#1|)) "\\spad{coerce(q)} returns \\spad{q} as an element of \\spad{%.}") (($ (|SparseMultivariatePolynomial| |#1| (|Kernel| $))) "\\spad{coerce(p)} returns \\spad{p} as an element of \\spad{%.}")) (|isMult| (((|Union| (|Record| (|:| |coef| (|Integer|)) (|:| |var| (|Kernel| $))) "failed") $) "\\spad{isMult(p)} returns \\spad{[n, \\spad{x]}} if \\spad{p = \\spad{n} * \\spad{x}} and \\spad{n \\spad{<>} 0}.")) (|isPlus| (((|Union| (|List| $) "failed") $) "\\spad{isPlus(p)} returns \\spad{[m1,...,mn]} if \\spad{p = \\spad{m1} +...+ \\spad{mn}} and \\spad{n > 1}.")) (|isExpt| (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $ (|Symbol|)) "\\spad{isExpt(p,f)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0} and \\spad{x = f(a)}.") (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $ (|BasicOperator|)) "\\spad{isExpt(p,op)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0} and \\spad{x = op(a)}.") (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $) "\\spad{isExpt(p)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0}.")) (|isTimes| (((|Union| (|List| $) "failed") $) "\\spad{isTimes(p)} returns \\spad{[a1,...,an]} if \\spad{p = a1*...*an} and \\spad{n > 1}.")) (** (($ $ (|NonNegativeInteger|)) "\\spad{x**n} returns \\spad{x} * \\spad{x} * \\spad{x} * \\spad{...} * \\spad{x} \\spad{(n} times).")) (|eval| (($ $ (|Symbol|) (|NonNegativeInteger|) (|Mapping| $ $)) "\\spad{eval(x, \\spad{s,} \\spad{n,} \\spad{f)}} replaces every \\spad{s(a)**n} in \\spad{x} by \\spad{f(a)} for any \\spad{a}.") (($ $ (|Symbol|) (|NonNegativeInteger|) (|Mapping| $ (|List| $))) "\\spad{eval(x, \\spad{s,} \\spad{n,} \\spad{f)}} replaces every \\spad{s(a1,...,am)**n} in \\spad{x} by \\spad{f(a1,...,am)} for any a1,...,am.") (($ $ (|List| (|Symbol|)) (|List| (|NonNegativeInteger|)) (|List| (|Mapping| $ (|List| $)))) "\\spad{eval(x, [s1,...,sm], [n1,...,nm], [f1,...,fm])} replaces every \\spad{si(a1,...,an)**ni} in \\spad{x} by \\spad{fi(a1,...,an)} for any a1,...,am.") (($ $ (|List| (|Symbol|)) (|List| (|NonNegativeInteger|)) (|List| (|Mapping| $ $))) "\\spad{eval(x, [s1,...,sm], [n1,...,nm], [f1,...,fm])} replaces every \\spad{si(a)**ni} in \\spad{x} by \\spad{fi(a)} for any \\spad{a}.") (($ $ (|List| (|BasicOperator|)) (|List| $) (|Symbol|)) "\\spad{eval(x, [s1,...,sm], [f1,...,fm], \\spad{y)}} replaces every \\spad{si(a)} in \\spad{x} by \\spad{fi(y)} with \\spad{y} replaced by \\spad{a} for any \\spad{a}.") (($ $ (|BasicOperator|) $ (|Symbol|)) "\\spad{eval(x, \\spad{s,} \\spad{f,} \\spad{y)}} replaces every \\spad{s(a)} in \\spad{x} by \\spad{f(y)} with \\spad{y} replaced by \\spad{a} for any \\spad{a}.") (($ $) "\\spad{eval(f)} unquotes all the quoted operators in \\spad{f.}") (($ $ (|List| (|Symbol|))) "\\spad{eval(f, [foo1,...,foon])} unquotes all the \\spad{fooi}'s in \\spad{f.}") (($ $ (|Symbol|)) "\\spad{eval(f, foo)} unquotes all the foo's in \\spad{f.}")) (|applyQuote| (($ (|Symbol|) (|List| $)) "\\spad{applyQuote(foo, [x1,...,xn])} returns \\spad{'foo(x1,...,xn)}.") (($ (|Symbol|) $ $ $ $) "\\spad{applyQuote(foo, \\spad{x,} \\spad{y,} \\spad{z,} \\spad{t)}} returns \\spad{'foo(x,y,z,t)}.") (($ (|Symbol|) $ $ $) "\\spad{applyQuote(foo, \\spad{x,} \\spad{y,} \\spad{z)}} returns \\spad{'foo(x,y,z)}.") (($ (|Symbol|) $ $) "\\spad{applyQuote(foo, \\spad{x,} \\spad{y)}} returns \\spad{'foo(x,y)}.") (($ (|Symbol|) $) "\\spad{applyQuote(foo, \\spad{x)}} returns \\spad{'foo(x)}.")) (|variables| (((|List| (|Symbol|)) $) "\\spad{variables(f)} returns the list of all the variables of \\spad{f.}")) (|ground| ((|#1| $) "\\spad{ground(f)} returns \\spad{f} as an element of \\spad{R.} An error occurs if \\spad{f} is not an element of \\spad{R.}")) (|ground?| (((|Boolean|) $) "\\spad{ground?(f)} tests if \\spad{f} is an element of \\spad{R.}"))) 
-((-4599 -1841 (|has| |#1| (-1054)) (|has| |#1| (-482))) (-4597 |has| |#1| (-174)) (-4596 |has| |#1| (-174)) ((-4604 "*") |has| |#1| (-562)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-562)) (-4594 |has| |#1| (-562)) (-3389 . T)) 
+((-4622 -3836 (|has| |#1| (-1075)) (|has| |#1| (-502))) (-4620 |has| |#1| (-194)) (-4619 |has| |#1| (-194)) ((-4627 "*") |has| |#1| (-582)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-582)) (-4617 |has| |#1| (-582)) (-2623 . T)) 
 NIL 
-(-437 R -3313) 
+(-457 R -3958) 
 ((|constructor| (NIL "Provides some special functions over an integral domain.")) (|iiAiryBi| ((|#2| |#2|) "\\spad{iiAiryBi(x)} should be local but conditional.")) (|iiAiryAi| ((|#2| |#2|) "\\spad{iiAiryAi(x)} should be local but conditional.")) (|iiBesselK| ((|#2| (|List| |#2|)) "\\spad{iiBesselK(x)} should be local but conditional.")) (|iiBesselI| ((|#2| (|List| |#2|)) "\\spad{iiBesselI(x)} should be local but conditional.")) (|iiBesselY| ((|#2| (|List| |#2|)) "\\spad{iiBesselY(x)} should be local but conditional.")) (|iiBesselJ| ((|#2| (|List| |#2|)) "\\spad{iiBesselJ(x)} should be local but conditional.")) (|iipolygamma| ((|#2| (|List| |#2|)) "\\spad{iipolygamma(x)} should be local but conditional.")) (|iidigamma| ((|#2| |#2|) "\\spad{iidigamma(x)} should be local but conditional.")) (|iiBeta| ((|#2| (|List| |#2|)) "\\spad{iiBeta(x)} should be local but conditional.")) (|iiabs| ((|#2| |#2|) "\\spad{iiabs(x)} should be local but conditional.")) (|iiGamma| ((|#2| |#2|) "\\spad{iiGamma(x)} should be local but conditional.")) (|airyBi| ((|#2| |#2|) "\\spad{airyBi(x)} returns the airybi function applied to \\spad{x}")) (|airyAi| ((|#2| |#2|) "\\spad{airyAi(x)} returns the airyai function applied to \\spad{x}")) (|besselK| ((|#2| |#2| |#2|) "\\spad{besselK(x,y)} returns the besselk function applied to \\spad{x} and \\spad{y}")) (|besselI| ((|#2| |#2| |#2|) "\\spad{besselI(x,y)} returns the besseli function applied to \\spad{x} and \\spad{y}")) (|besselY| ((|#2| |#2| |#2|) "\\spad{besselY(x,y)} returns the bessely function applied to \\spad{x} and \\spad{y}")) (|besselJ| ((|#2| |#2| |#2|) "\\spad{besselJ(x,y)} returns the besselj function applied to \\spad{x} and \\spad{y}")) (|polygamma| ((|#2| |#2| |#2|) "\\spad{polygamma(x,y)} returns the polygamma function applied to \\spad{x} and \\spad{y}")) (|digamma| ((|#2| |#2|) "\\spad{digamma(x)} returns the digamma function applied to \\spad{x}")) (|Beta| ((|#2| |#2| |#2|) "\\spad{Beta(x,y)} returns the beta function applied to \\spad{x} and \\spad{y}")) (|Gamma| ((|#2| |#2| |#2|) "\\spad{Gamma(a,x)} returns the incomplete Gamma function applied to a and \\spad{x}") ((|#2| |#2|) "\\spad{Gamma(f)} returns the formal Gamma function applied to \\spad{f}")) (|abs| ((|#2| |#2|) "\\spad{abs(f)} returns the absolute value operator applied to \\spad{f}")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns a copy of \\spad{op} with the domain-dependent properties appropriate for \\spad{F;} error if \\spad{op} is not a special function operator")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} is \\spad{true} if \\spad{op} is a special function operator."))) 
 NIL 
 NIL 
-(-438 R -3313) 
+(-458 R -3958) 
 ((|constructor| (NIL "FunctionsSpacePrimitiveElement provides functions to compute primitive elements in functions spaces.")) (|primitiveElement| (((|Record| (|:| |primelt| |#2|) (|:| |pol1| (|SparseUnivariatePolynomial| |#2|)) (|:| |pol2| (|SparseUnivariatePolynomial| |#2|)) (|:| |prim| (|SparseUnivariatePolynomial| |#2|))) |#2| |#2|) "\\spad{primitiveElement(a1, a2)} returns \\spad{[a, \\spad{q1,} \\spad{q2,} \\spad{q]}} such that \\spad{k(a1, a2) = k(a)}, \\spad{ai = qi(a)}, and \\spad{q(a) = 0}. The minimal polynomial for \\spad{a2} may involve a1, but the minimal polynomial for \\spad{a1} may not involve a2; This operations uses \\spadfun{resultant}.") (((|Record| (|:| |primelt| |#2|) (|:| |poly| (|List| (|SparseUnivariatePolynomial| |#2|))) (|:| |prim| (|SparseUnivariatePolynomial| |#2|))) (|List| |#2|)) "\\spad{primitiveElement([a1,...,an])} returns \\spad{[a, [q1,...,qn], \\spad{q]}} such that then \\spad{k(a1,...,an) = k(a)}, \\spad{ai = qi(a)}, and \\spad{q(a) = 0}. This operation uses the technique of \\spadglossSee{groebner bases}{Groebner basis}."))) 
 NIL 
 ((|HasCategory| |#2| (QUOTE (-27)))) 
-(-439 R -3313) 
+(-459 R -3958) 
 ((|constructor| (NIL "Reduction from a function space to the rational numbers This package provides function which replaces transcendental kernels in a function space by random integers. The correspondence between the kernels and the integers is fixed between calls to new().")) (|newReduc| (((|Void|)) "\\spad{newReduc()} \\undocumented")) (|bringDown| (((|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) |#2| (|Kernel| |#2|)) "\\spad{bringDown(f,k)} \\undocumented") (((|Fraction| (|Integer|)) |#2|) "\\spad{bringDown(f)} \\undocumented"))) 
 NIL 
 NIL 
-(-440) 
+(-460) 
 ((|constructor| (NIL "Creates and manipulates objects which correspond to the basic FORTRAN data types: REAL, INTEGER, COMPLEX, LOGICAL and CHARACTER")) (= (((|Boolean|) $ $) "\\spad{x=y} tests for equality")) (|logical?| (((|Boolean|) $) "\\spad{logical?(t)} tests whether \\spad{t} is equivalent to the FORTRAN type LOGICAL.")) (|character?| (((|Boolean|) $) "\\spad{character?(t)} tests whether \\spad{t} is equivalent to the FORTRAN type CHARACTER.")) (|doubleComplex?| (((|Boolean|) $) "\\spad{doubleComplex?(t)} tests whether \\spad{t} is equivalent to the (non-standard) FORTRAN type DOUBLE COMPLEX.")) (|complex?| (((|Boolean|) $) "\\spad{complex?(t)} tests whether \\spad{t} is equivalent to the FORTRAN type COMPLEX.")) (|integer?| (((|Boolean|) $) "\\spad{integer?(t)} tests whether \\spad{t} is equivalent to the FORTRAN type INTEGER.")) (|double?| (((|Boolean|) $) "\\spad{double?(t)} tests whether \\spad{t} is equivalent to the FORTRAN type DOUBLE PRECISION")) (|real?| (((|Boolean|) $) "\\spad{real?(t)} tests whether \\spad{t} is equivalent to the FORTRAN type REAL.")) (|coerce| (((|SExpression|) $) "\\spad{coerce(x)} returns the s-expression associated with \\spad{x}") (((|Symbol|) $) "\\spad{coerce(x)} returns the symbol associated with \\spad{x}") (($ (|Symbol|)) "\\spad{coerce(s)} transforms the symbol \\spad{s} into an element of FortranScalarType provided \\spad{s} is one of real, complex,double precision, logical, integer, character, REAL, COMPLEX, LOGICAL, INTEGER, CHARACTER, DOUBLE PRECISION") (($ (|String|)) "\\spad{coerce(s)} transforms the string \\spad{s} into an element of FortranScalarType provided \\spad{s} is one of \"real\", \"double precision\", \"complex\", \"logical\", \"integer\", \"character\", \"REAL\", \"COMPLEX\", \"LOGICAL\", \"INTEGER\", \"CHARACTER\", \"DOUBLE PRECISION\""))) 
 NIL 
 NIL 
-(-441 R -3313 UP) 
+(-461 R -3958 UP) 
 ((|constructor| (NIL "This package is used internally by IR2F")) (|anfactor| (((|Union| (|Factored| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))) "failed") |#3|) "\\spad{anfactor(p)} tries to factor \\spad{p} over algebraic numbers, returning \"failed\" if it cannot")) (|UP2ifCan| (((|Union| (|:| |overq| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|:| |overan| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))) (|:| |failed| (|Boolean|))) |#3|) "\\spad{UP2ifCan(x)} should be local but conditional.")) (|qfactor| (((|Union| (|Factored| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) "failed") |#3|) "\\spad{qfactor(p)} tries to factor \\spad{p} over fractions of integers, returning \"failed\" if it cannot")) (|ffactor| (((|Factored| |#3|) |#3|) "\\spad{ffactor(p)} tries to factor a univariate polynomial \\spad{p} over \\spad{F}"))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-53))))) 
-(-442) 
+((|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-53))))) 
+(-462) 
 ((|constructor| (NIL "Code to manipulate Fortran templates")) (|fortranCarriageReturn| (((|Void|)) "\\spad{fortranCarriageReturn()} produces a carriage return on the current Fortran output stream")) (|fortranLiteral| (((|Void|) (|String|)) "\\spad{fortranLiteral(s)} writes \\spad{s} to the current Fortran output stream")) (|fortranLiteralLine| (((|Void|) (|String|)) "\\spad{fortranLiteralLine(s)} writes \\spad{s} to the current Fortran output stream, followed by a carriage return")) (|processTemplate| (((|FileName|) (|FileName|)) "\\spad{processTemplate(tp)} processes the template \\spad{tp,} writing the result to the current FORTRAN output stream.") (((|FileName|) (|FileName|) (|FileName|)) "\\spad{processTemplate(tp,fn)} processes the template \\spad{tp,} writing the result out to \\spad{fn.}"))) 
 NIL 
 NIL 
-(-443) 
+(-463) 
 ((|constructor| (NIL "Creates and manipulates objects which correspond to FORTRAN data types, including array dimensions.")) (|fortranCharacter| (($) "\\spad{fortranCharacter()} returns CHARACTER, an element of FortranType")) (|fortranDoubleComplex| (($) "\\spad{fortranDoubleComplex()} returns DOUBLE COMPLEX, an element of FortranType")) (|fortranComplex| (($) "\\spad{fortranComplex()} returns COMPLEX, an element of FortranType")) (|fortranLogical| (($) "\\spad{fortranLogical()} returns LOGICAL, an element of FortranType")) (|fortranInteger| (($) "\\spad{fortranInteger()} returns INTEGER, an element of FortranType")) (|fortranDouble| (($) "\\spad{fortranDouble()} returns DOUBLE PRECISION, an element of FortranType")) (|fortranReal| (($) "\\spad{fortranReal()} returns REAL, an element of FortranType")) (|construct| (($ (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void")) (|List| (|Polynomial| (|Integer|))) (|Boolean|)) "\\spad{construct(type,dims)} creates an element of FortranType") (($ (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void")) (|List| (|Symbol|)) (|Boolean|)) "\\spad{construct(type,dims)} creates an element of FortranType")) (|external?| (((|Boolean|) $) "\\spad{external?(u)} returns \\spad{true} if \\spad{u} is declared to be EXTERNAL")) (|dimensionsOf| (((|List| (|Polynomial| (|Integer|))) $) "\\spad{dimensionsOf(t)} returns the dimensions of \\spad{t}")) (|scalarTypeOf| (((|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void")) $) "\\spad{scalarTypeOf(t)} returns the FORTRAN data type of \\spad{t}")) (|coerce| (($ (|FortranScalarType|)) "\\spad{coerce(t)} creates an element from a scalar type") (((|OutputForm|) $) "\\spad{coerce(x)} provides a printable form for \\spad{x}"))) 
 NIL 
 NIL 
-(-444 |f|) 
+(-464 |f|) 
 ((|constructor| (NIL "This domain implements named functions")) (|name| (((|Symbol|) $) "\\spad{name(x)} returns the symbol"))) 
 NIL 
 NIL 
-(-445) 
+(-465) 
 ((|constructor| (NIL "\\axiomType{FortranVectorCategory} provides support for producing Functions and Subroutines when the input to these is an AXIOM object of type \\axiomType{Vector} or in domains involving \\axiomType{FortranCode}.")) (|coerce| (($ (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) "\\spad{coerce(e)} takes the component of \\spad{e} from \\spadtype{List FortranCode} and uses it as the body of the ASP, making the declarations in the \\spadtype{SymbolTable} component.") (($ (|FortranCode|)) "\\spad{coerce(e)} takes an object from \\spadtype{FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|List| (|FortranCode|))) "\\spad{coerce(e)} takes an object from \\spadtype{List FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|Vector| (|MachineFloat|))) "\\spad{coerce(v)} produces an ASP which returns the value of \\spad{v}."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-446) 
+(-466) 
 ((|constructor| (NIL "\\axiomType{FortranVectorFunctionCategory} is the catagory of arguments to NAG Library routines which return the values of vectors of functions.")) (|retractIfCan| (((|Union| $ "failed") (|Vector| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Vector| (|Fraction| (|Polynomial| (|Float|))))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Vector| (|Polynomial| (|Integer|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Vector| (|Polynomial| (|Float|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Vector| (|Expression| (|Integer|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (((|Union| $ "failed") (|Vector| (|Expression| (|Float|)))) "\\spad{retractIfCan(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}")) (|retract| (($ (|Vector| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Vector| (|Fraction| (|Polynomial| (|Float|))))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Vector| (|Polynomial| (|Integer|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Vector| (|Polynomial| (|Float|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Vector| (|Expression| (|Integer|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}") (($ (|Vector| (|Expression| (|Float|)))) "\\spad{retract(e)} tries to convert \\spad{e} into an ASP, checking that \\indented{1}{legal \\spad{Fortran-77} is produced.}")) (|coerce| (($ (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) "\\spad{coerce(e)} takes the component of \\spad{e} from \\spadtype{List FortranCode} and uses it as the body of the ASP, making the declarations in the \\spadtype{SymbolTable} component.") (($ (|FortranCode|)) "\\spad{coerce(e)} takes an object from \\spadtype{FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|List| (|FortranCode|))) "\\spad{coerce(e)} takes an object from \\spadtype{List FortranCode} and \\indented{1}{uses it as the body of an ASP.}"))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-447 UP) 
+(-467 UP) 
 ((|constructor| (NIL "\\spadtype{GaloisGroupFactorizer} provides functions to factor resolvents.")) (|btwFact| (((|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| |#1|) (|:| |pow| (|Integer|)))))) |#1| (|Boolean|) (|Set| (|NonNegativeInteger|)) (|NonNegativeInteger|)) "\\spad{btwFact(p,sqf,pd,r)} returns the factorization of \\spad{p,} the result is a Record such that \\spad{contp=}content \\spad{p,} \\spad{factors=}List of irreducible factors of \\spad{p} with exponent. If \\spad{sqf=true} the polynomial is assumed to be square free (\\spadignore{i.e.} without repeated factors). \\spad{pd} is the \\spadtype{Set} of possible degrees. \\spad{r} is a lower bound for the number of factors of \\spad{p.} Please do not use this function in your code because its design may change.")) (|henselFact| (((|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| |#1|) (|:| |pow| (|Integer|)))))) |#1| (|Boolean|)) "\\spad{henselFact(p,sqf)} returns the factorization of \\spad{p,} the result is a Record such that \\spad{contp=}content \\spad{p,} \\spad{factors=}List of irreducible factors of \\spad{p} with exponent. If \\spad{sqf=true} the polynomial is assumed to be square free (\\spadignore{i.e.} without repeated factors).")) (|factorOfDegree| (((|Union| |#1| "failed") (|PositiveInteger|) |#1| (|List| (|NonNegativeInteger|)) (|NonNegativeInteger|) (|Boolean|)) "\\spad{factorOfDegree(d,p,listOfDegrees,r,sqf)} returns a factor of \\spad{p} of degree \\spad{d} knowing that \\spad{p} has for possible splitting of its degree listOfDegrees, and that \\spad{p} has at least \\spad{r} factors. If \\spad{sqf=true} the polynomial is assumed to be square free (\\spadignore{i.e.} without repeated factors).") (((|Union| |#1| "failed") (|PositiveInteger|) |#1| (|List| (|NonNegativeInteger|)) (|NonNegativeInteger|)) "\\spad{factorOfDegree(d,p,listOfDegrees,r)} returns a factor of \\spad{p} of degree \\spad{d} knowing that \\spad{p} has for possible splitting of its degree listOfDegrees, and that \\spad{p} has at least \\spad{r} factors.") (((|Union| |#1| "failed") (|PositiveInteger|) |#1| (|List| (|NonNegativeInteger|))) "\\spad{factorOfDegree(d,p,listOfDegrees)} returns a factor of \\spad{p} of degree \\spad{d} knowing that \\spad{p} has for possible splitting of its degree listOfDegrees.") (((|Union| |#1| "failed") (|PositiveInteger|) |#1| (|NonNegativeInteger|)) "\\spad{factorOfDegree(d,p,r)} returns a factor of \\spad{p} of degree \\spad{d} knowing that \\spad{p} has at least \\spad{r} factors.") (((|Union| |#1| "failed") (|PositiveInteger|) |#1|) "\\spad{factorOfDegree(d,p)} returns a factor of \\spad{p} of degree \\spad{d.}")) (|factorSquareFree| (((|Factored| |#1|) |#1| (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{factorSquareFree(p,d,r)} factorizes the polynomial \\spad{p} using the single factor bound algorithm, knowing that \\spad{d} divides the degree of all factors of \\spad{p} and that \\spad{p} has at least \\spad{r} factors. \\spad{f} is supposed not having any repeated factor (this is not checked).") (((|Factored| |#1|) |#1| (|List| (|NonNegativeInteger|)) (|NonNegativeInteger|)) "\\spad{factorSquareFree(p,listOfDegrees,r)} factorizes the polynomial \\spad{p} using the single factor bound algorithm, knowing that \\spad{p} has for possible splitting of its degree \\spad{listOfDegrees} and that \\spad{p} has at least \\spad{r} factors. \\spad{f} is supposed not having any repeated factor (this is not checked).") (((|Factored| |#1|) |#1| (|List| (|NonNegativeInteger|))) "\\spad{factorSquareFree(p,listOfDegrees)} factorizes the polynomial \\spad{p} using the single factor bound algorithm and knowing that \\spad{p} has for possible splitting of its degree listOfDegrees. \\spad{f} is supposed not having any repeated factor (this is not checked).") (((|Factored| |#1|) |#1| (|NonNegativeInteger|)) "\\spad{factorSquareFree(p,r)} factorizes the polynomial \\spad{p} using the single factor bound algorithm and knowing that \\spad{p} has at least \\spad{r} factors. \\spad{f} is supposed not having any repeated factor (this is not checked).") (((|Factored| |#1|) |#1|) "\\spad{factorSquareFree(p)} returns the factorization of \\spad{p} which is supposed not having any repeated factor (this is not checked).")) (|factor| (((|Factored| |#1|) |#1| (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{factor(p,d,r)} factorizes the polynomial \\spad{p} using the single factor bound algorithm, knowing that \\spad{d} divides the degree of all factors of \\spad{p} and that \\spad{p} has at least \\spad{r} factors.") (((|Factored| |#1|) |#1| (|List| (|NonNegativeInteger|)) (|NonNegativeInteger|)) "\\spad{factor(p,listOfDegrees,r)} factorizes the polynomial \\spad{p} using the single factor bound algorithm, knowing that \\spad{p} has for possible splitting of its degree \\spad{listOfDegrees} and that \\spad{p} has at least \\spad{r} factors.") (((|Factored| |#1|) |#1| (|List| (|NonNegativeInteger|))) "\\spad{factor(p,listOfDegrees)} factorizes the polynomial \\spad{p} using the single factor bound algorithm and knowing that \\spad{p} has for possible splitting of its degree listOfDegrees.") (((|Factored| |#1|) |#1| (|NonNegativeInteger|)) "\\spad{factor(p,r)} factorizes the polynomial \\spad{p} using the single factor bound algorithm and knowing that \\spad{p} has at least \\spad{r} factors.") (((|Factored| |#1|) |#1|) "\\spad{factor(p)} returns the factorization of \\spad{p} over the integers.")) (|tryFunctionalDecomposition| (((|Boolean|) (|Boolean|)) "\\spad{tryFunctionalDecomposition(b)} chooses whether factorizers have to look for functional decomposition of polynomials (\\spad{true}) or not (\\spad{false}). Returns the previous value.")) (|tryFunctionalDecomposition?| (((|Boolean|)) "\\spad{tryFunctionalDecomposition?()} returns \\spad{true} if factorizers try functional decomposition of polynomials before factoring them.")) (|eisensteinIrreducible?| (((|Boolean|) |#1|) "\\spad{eisensteinIrreducible?(p)} returns \\spad{true} if \\spad{p} can be shown to be irreducible by Eisenstein's criterion, \\spad{false} is inconclusive.")) (|useEisensteinCriterion| (((|Boolean|) (|Boolean|)) "\\spad{useEisensteinCriterion(b)} chooses whether factorizers check Eisenstein's criterion before factoring: \\spad{true} for using it, \\spad{false} else. Returns the previous value.")) (|useEisensteinCriterion?| (((|Boolean|)) "\\spad{useEisensteinCriterion?()} returns \\spad{true} if factorizers check Eisenstein's criterion before factoring.")) (|useSingleFactorBound| (((|Boolean|) (|Boolean|)) "\\spad{useSingleFactorBound(b)} chooses the algorithm to be used by the factorizers: \\spad{true} for algorithm with single factor bound, \\spad{false} for algorithm with overall bound. Returns the previous value.")) (|useSingleFactorBound?| (((|Boolean|)) "\\spad{useSingleFactorBound?()} returns \\spad{true} if algorithm with single factor bound is used for factorization, \\spad{false} for algorithm with overall bound.")) (|modularFactor| (((|Record| (|:| |prime| (|Integer|)) (|:| |factors| (|List| |#1|))) |#1|) "\\spad{modularFactor(f)} chooses a \"good\" prime and returns the factorization of \\spad{f} modulo this prime in a form that may be used by completeHensel. If prime is zero it means that \\spad{f} has been proved to be irreducible over the integers or that \\spad{f} is a unit (\\spadignore{i.e.} 1 or -1). \\spad{f} shall be primitive (\\spadignore{i.e.} content(p)=1) and square free (\\spadignore{i.e.} without repeated factors).")) (|numberOfFactors| (((|NonNegativeInteger|) (|List| (|Record| (|:| |factor| |#1|) (|:| |degree| (|Integer|))))) "\\spad{numberOfFactors(ddfactorization)} returns the number of factors of the polynomial \\spad{f} modulo \\spad{p} where \\spad{ddfactorization} is the distinct degree factorization of \\spad{f} computed by ddFact for some prime \\spad{p.}")) (|stopMusserTrials| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{stopMusserTrials(n)} sets to \\spad{n} the bound on the number of factors for which \\spadfun{modularFactor} stops to look for an other prime. You will have to remember that the step of recombining the extraneous factors may take up to \\spad{2**n} trials. Returns the previous value.") (((|PositiveInteger|)) "\\spad{stopMusserTrials()} returns the bound on the number of factors for which \\spadfun{modularFactor} stops to look for an other prime. You will have to remember that the step of recombining the extraneous factors may take up to \\spad{2**stopMusserTrials()} trials.")) (|musserTrials| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{musserTrials(n)} sets to \\spad{n} the number of primes to be tried in \\spadfun{modularFactor} and returns the previous value.") (((|PositiveInteger|)) "\\spad{musserTrials()} returns the number of primes that are tried in \\spadfun{modularFactor}.")) (|degreePartition| (((|Multiset| (|NonNegativeInteger|)) (|List| (|Record| (|:| |factor| |#1|) (|:| |degree| (|Integer|))))) "\\spad{degreePartition(ddfactorization)} returns the degree partition of the polynomial \\spad{f} modulo \\spad{p} where \\spad{ddfactorization} is the distinct degree factorization of \\spad{f} computed by ddFact for some prime \\spad{p.}")) (|makeFR| (((|Factored| |#1|) (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| |#1|) (|:| |pow| (|Integer|))))))) "\\spad{makeFR(flist)} turns the final factorization of henselFact into a \\spadtype{Factored} object."))) 
 NIL 
 NIL 
-(-448 R UP -3313) 
+(-468 R UP -3958) 
 ((|constructor| (NIL "\\spadtype{GaloisGroupFactorizationUtilities} provides functions that will be used by the factorizer.")) (|length| ((|#3| |#2|) "\\spad{length(p)} returns the sum of the absolute values of the coefficients of the polynomial \\spad{p.}")) (|height| ((|#3| |#2|) "\\spad{height(p)} returns the maximal absolute value of the coefficients of the polynomial \\spad{p.}")) (|infinityNorm| ((|#3| |#2|) "\\spad{infinityNorm(f)} returns the maximal absolute value of the coefficients of the polynomial \\spad{f.}")) (|quadraticNorm| ((|#3| |#2|) "\\spad{quadraticNorm(f)} returns the \\spad{l2} norm of the polynomial \\spad{f.}")) (|norm| ((|#3| |#2| (|PositiveInteger|)) "\\spad{norm(f,p)} returns the \\spad{lp} norm of the polynomial \\spad{f.}")) (|singleFactorBound| (((|Integer|) |#2|) "\\spad{singleFactorBound(p,r)} returns a bound on the infinite norm of the factor of \\spad{p} with smallest Bombieri's norm. \\spad{p} shall be of degree higher or equal to 2.") (((|Integer|) |#2| (|NonNegativeInteger|)) "\\spad{singleFactorBound(p,r)} returns a bound on the infinite norm of the factor of \\spad{p} with smallest Bombieri's norm. \\spad{r} is a lower bound for the number of factors of \\spad{p.} \\spad{p} shall be of degree higher or equal to 2.")) (|rootBound| (((|Integer|) |#2|) "\\spad{rootBound(p)} returns a bound on the largest norm of the complex roots of \\spad{p.}")) (|bombieriNorm| ((|#3| |#2| (|PositiveInteger|)) "\\spad{bombieriNorm(p,n)} returns the \\spad{n}th Bombieri's norm of \\spad{p.}") ((|#3| |#2|) "\\spad{bombieriNorm(p)} returns quadratic Bombieri's norm of \\spad{p.}")) (|beauzamyBound| (((|Integer|) |#2|) "\\spad{beauzamyBound(p)} returns a bound on the larger coefficient of any factor of \\spad{p.}"))) 
 NIL 
 NIL 
-(-449 R UP) 
+(-469 R UP) 
 ((|constructor| (NIL "\\spadtype{GaloisGroupPolynomialUtilities} provides useful functions for univariate polynomials which should be added to \\spadtype{UnivariatePolynomialCategory} or to \\spadtype{Factored}")) (|factorsOfDegree| (((|List| |#2|) (|PositiveInteger|) (|Factored| |#2|)) "\\spad{factorsOfDegree(d,f)} returns the factors of degree \\spad{d} of the factored polynomial \\spad{f.}")) (|factorOfDegree| ((|#2| (|PositiveInteger|) (|Factored| |#2|)) "\\spad{factorOfDegree(d,f)} returns a factor of degree \\spad{d} of the factored polynomial \\spad{f.} Such a factor shall exist.")) (|degreePartition| (((|Multiset| (|NonNegativeInteger|)) (|Factored| |#2|)) "\\spad{degreePartition(f)} returns the degree partition (\\spadignore{i.e.} the multiset of the degrees of the irreducible factors) of the polynomial \\spad{f.}")) (|shiftRoots| ((|#2| |#2| |#1|) "\\spad{shiftRoots(p,c)} returns the polynomial which has for roots \\spad{c} added to the roots of \\spad{p.}")) (|scaleRoots| ((|#2| |#2| |#1|) "\\spad{scaleRoots(p,c)} returns the polynomial which has \\spad{c} times the roots of \\spad{p.}")) (|reverse| ((|#2| |#2|) "\\spad{reverse(p)} returns the reverse polynomial of \\spad{p.}")) (|unvectorise| ((|#2| (|Vector| |#1|)) "\\spad{unvectorise(v)} returns the polynomial which has for coefficients the entries of \\spad{v} in the increasing order.")) (|monic?| (((|Boolean|) |#2|) "\\spad{monic?(p)} tests if \\spad{p} is monic (\\spadignore{i.e.} leading coefficient equal to 1)."))) 
 NIL 
 NIL 
-(-450 R) 
+(-470 R) 
 ((|constructor| (NIL "\\spadtype{GaloisGroupUtilities} provides several useful functions.")) (|safetyMargin| (((|NonNegativeInteger|)) "\\spad{safetyMargin()} returns the number of low weight digits we do not trust in the floating point representation (used by \\spadfun{safeCeiling}).") (((|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{safetyMargin(n)} sets to \\spad{n} the number of low weight digits we do not trust in the floating point representation and returns the previous value (for use by \\spadfun{safeCeiling}).")) (|safeFloor| (((|Integer|) |#1|) "\\spad{safeFloor(x)} returns the integer which is lower or equal to the largest integer which has the same floating point number representation.")) (|safeCeiling| (((|Integer|) |#1|) "\\spad{safeCeiling(x)} returns the integer which is greater than any integer with the same floating point number representation.")) (|fillPascalTriangle| (((|Void|)) "\\spad{fillPascalTriangle()} fills the stored table.")) (|sizePascalTriangle| (((|NonNegativeInteger|)) "\\spad{sizePascalTriangle()} returns the number of entries currently stored in the table.")) (|rangePascalTriangle| (((|NonNegativeInteger|)) "\\spad{rangePascalTriangle()} returns the maximal number of lines stored.") (((|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{rangePascalTriangle(n)} sets the maximal number of lines which are stored and returns the previous value.")) (|pascalTriangle| ((|#1| (|NonNegativeInteger|) (|Integer|)) "\\spad{pascalTriangle(n,r)} returns the binomial coefficient \\spad{C(n,r)=n!/(r! (n-r)!)} and stores it in a table to prevent recomputation."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-410)))) 
-(-451) 
+((|HasCategory| |#1| (QUOTE (-430)))) 
+(-471) 
 ((|constructor| (NIL "Package for the factorization of complex or gaussian integers.")) (|prime?| (((|Boolean|) (|Complex| (|Integer|))) "\\spad{prime?(zi)} tests if the complex integer \\spad{zi} is prime.")) (|sumSquares| (((|List| (|Integer|)) (|Integer|)) "\\spad{sumSquares(p)} construct \\spad{a} and \\spad{b} such that \\spad{a**2+b**2} is equal to the integer prime \\spad{p,} and otherwise returns an error. It will succeed if the prime number \\spad{p} is 2 or congruent to 1 mod 4.")) (|factor| (((|Factored| (|Complex| (|Integer|))) (|Complex| (|Integer|))) "\\spad{factor(zi)} produces the complete factorization of the complex integer zi."))) 
 NIL 
 NIL 
-(-452 |Dom| |Expon| |VarSet| |Dpol|) 
+(-472 |Dom| |Expon| |VarSet| |Dpol|) 
 ((|constructor| (NIL "\\spadtype{EuclideanGroebnerBasisPackage} computes groebner bases for polynomial ideals over euclidean domains. The basic computation provides a distinguished set of generators for these ideals. This basis allows an easy test for membership: the operation \\spadfun{euclideanNormalForm} returns zero on ideal members. The string \"info\" and \"redcrit\" can be given as additional args to provide incremental information during the computation. If \"info\" is given, a computational summary is given for each s-polynomial. If \"redcrit\" is given, the reduced critical pairs are printed. The term ordering is determined by the polynomial type used. Suggested types include \\spadtype{DistributedMultivariatePolynomial}, \\spadtype{HomogeneousDistributedMultivariatePolynomial}, \\spadtype{GeneralDistributedMultivariatePolynomial}.")) (|euclideanGroebner| (((|List| |#4|) (|List| |#4|) (|String|) (|String|)) "\\indented{1}{euclideanGroebner(lp, \"info\", \"redcrit\") computes a groebner basis} \\indented{1}{for a polynomial ideal generated by the list of polynomials lp.} \\indented{1}{If the second argument is \"info\",} \\indented{1}{a summary is given of the critical pairs.} \\indented{1}{If the third argument is \"redcrit\", critical pairs are printed.} \\blankline \\spad{X} a1:DMP([y,x],INT):= \\spad{(9*x**2} + 5*x - 3)+ \\spad{y*(3*x**2} + 2*x + 1) \\spad{X} a2:DMP([y,x],INT):= \\spad{(6*x**3} - 2*x**2 - 3*x \\spad{+3)} + \\spad{y*(2*x**3} - \\spad{x} - 1) \\spad{X} a3:DMP([y,x],INT):= \\spad{(3*x**3} + 2*x**2) + \\spad{y*(x**3} + x**2) \\spad{X} an:=[a1,a2,a3] \\spad{X} euclideanGroebner(an,\"info\",\"redcrit\")") (((|List| |#4|) (|List| |#4|) (|String|)) "\\indented{1}{euclideanGroebner(lp, infoflag) computes a groebner basis} \\indented{1}{for a polynomial ideal over a euclidean domain} \\indented{1}{generated by the list of polynomials lp.} \\indented{1}{During computation, additional information is printed out} \\indented{1}{if infoflag is given as} \\indented{1}{either \"info\" (for summary information) or} \\indented{1}{\"redcrit\" (for reduced critical pairs)} \\blankline \\spad{X} a1:DMP([y,x],INT):= \\spad{(9*x**2} + 5*x - 3)+ \\spad{y*(3*x**2} + 2*x + 1) \\spad{X} a2:DMP([y,x],INT):= \\spad{(6*x**3} - 2*x**2 - 3*x \\spad{+3)} + \\spad{y*(2*x**3} - \\spad{x} - 1) \\spad{X} a3:DMP([y,x],INT):= \\spad{(3*x**3} + 2*x**2) + \\spad{y*(x**3} + x**2) \\spad{X} an:=[a1,a2,a3] \\spad{X} euclideanGroebner(an,\"redcrit\") \\spad{X} euclideanGroebner(an,\"info\")") (((|List| |#4|) (|List| |#4|)) "\\indented{1}{euclideanGroebner(lp) computes a groebner basis for a polynomial} \\indented{1}{ideal over a euclidean domain generated by the list of polys lp.} \\blankline \\spad{X} a1:DMP([y,x],INT):= \\spad{(9*x**2} + 5*x - 3)+ \\spad{y*(3*x**2} + 2*x + 1) \\spad{X} a2:DMP([y,x],INT):= \\spad{(6*x**3} - 2*x**2 - 3*x \\spad{+3)} + \\spad{y*(2*x**3} - \\spad{x} - 1) \\spad{X} a3:DMP([y,x],INT):= \\spad{(3*x**3} + 2*x**2) + \\spad{y*(x**3} + x**2) \\spad{X} an:=[a1,a2,a3] \\spad{X} euclideanGroebner(an)")) (|euclideanNormalForm| ((|#4| |#4| (|List| |#4|)) "\\spad{euclideanNormalForm(poly,gb)} reduces the polynomial \\spad{poly} modulo the precomputed groebner basis \\spad{gb} giving a canonical representative of the residue class."))) 
 NIL 
 NIL 
-(-453 |Dom| |Expon| |VarSet| |Dpol|) 
+(-473 |Dom| |Expon| |VarSet| |Dpol|) 
 ((|constructor| (NIL "\\spadtype{GroebnerFactorizationPackage} provides the function groebnerFactor\" which uses the factorization routines of Axiom to factor each polynomial under consideration while doing the groebner basis algorithm. Then it writes the ideal as an intersection of ideals determined by the irreducible factors. Note that the whole ring may occur as well as other redundancies. We also use the fact, that from the second factor on we can assume that the preceding factors are not equal to 0 and we divide all polynomials under considerations by the elements of this list of \"nonZeroRestrictions\". The result is a list of groebner bases, whose union of solutions of the corresponding systems of equations is the solution of the system of equation corresponding to the input list. The term ordering is determined by the polynomial type used. Suggested types include \\spadtype{DistributedMultivariatePolynomial}, \\spadtype{HomogeneousDistributedMultivariatePolynomial}, \\spadtype{GeneralDistributedMultivariatePolynomial}.")) (|groebnerFactorize| (((|List| (|List| |#4|)) (|List| |#4|) (|Boolean|)) "\\spad{groebnerFactorize(listOfPolys, info)} returns a list of groebner bases. The union of their solutions is the solution of the system of equations given by listOfPolys. At each stage the polynomial \\spad{p} under consideration (either from the given basis or obtained from a reduction of the next S-polynomial) is factorized. For each irreducible factors of \\spad{p,} a new createGroebnerBasis is started doing the usual updates with the factor in place of \\spad{p.} If info is true, information is printed about partial results.") (((|List| (|List| |#4|)) (|List| |#4|)) "\\indented{1}{groebnerFactorize(listOfPolys) returns} \\indented{1}{a list of groebner bases. The union of their solutions} \\indented{1}{is the solution of the system of equations given by listOfPolys.} \\indented{1}{At each stage the polynomial \\spad{p} under consideration (either from} \\indented{1}{the given basis or obtained from a reduction of the next S-polynomial)} \\indented{1}{is factorized. For each irreducible factors of \\spad{p,} a} \\indented{1}{new createGroebnerBasis is started} \\indented{1}{doing the usual updates with the factor} \\indented{1}{in place of \\spad{p.}} \\blankline \\spad{X} mfzn : SQMATRIX(6,DMP([x,y,z],Fraction INT)) \\spad{:=} \\spad{++X} [ [0,1,1,1,1,1], [1,0,1,8/3,x,8/3], [1,1,0,1,8/3,y], \\spad{++X} [1,8/3,1,0,1,8/3], [1,x,8/3,1,0,1], [1,8/3,y,8/3,1,0] ] \\spad{X} eq \\spad{:=} determinant mfzn \\spad{X} groebnerFactorize \\spad{++X} [eq,eval(eq, [x,y,z],[y,z,x]), eval(eq,[x,y,z],[z,x,y])]") (((|List| (|List| |#4|)) (|List| |#4|) (|List| |#4|) (|Boolean|)) "\\spad{groebnerFactorize(listOfPolys, nonZeroRestrictions, info)} returns a list of groebner basis. The union of their solutions is the solution of the system of equations given by \\spad{listOfPolys} under the restriction that the polynomials of \\spad{nonZeroRestrictions} don't vanish. At each stage the polynomial \\spad{p} under consideration (either from the given basis or obtained from a reduction of the next S-polynomial) is factorized. For each irreducible factors of \\spad{p} a new createGroebnerBasis is started doing the usual updates with the factor in place of \\spad{p.} If argument info is true, information is printed about partial results.") (((|List| (|List| |#4|)) (|List| |#4|) (|List| |#4|)) "\\spad{groebnerFactorize(listOfPolys, nonZeroRestrictions)} returns a list of groebner basis. The union of their solutions is the solution of the system of equations given by \\spad{listOfPolys} under the restriction that the polynomials of nonZeroRestrictions don't vanish. At each stage the polynomial \\spad{p} under consideration (either from the given basis or obtained from a reduction of the next S-polynomial) is factorized. For each irreducible factors of \\spad{p,} a new createGroebnerBasis is started doing the usual updates with the factor in place of \\spad{p.}")) (|factorGroebnerBasis| (((|List| (|List| |#4|)) (|List| |#4|) (|Boolean|)) "\\spad{factorGroebnerBasis(basis,info)} checks whether the \\spad{basis} contains reducible polynomials and uses these to split the basis. If argument \\spad{info} is true, information is printed about partial results.") (((|List| (|List| |#4|)) (|List| |#4|)) "\\spad{factorGroebnerBasis(basis)} checks whether the \\spad{basis} contains reducible polynomials and uses these to split the basis."))) 
 NIL 
 NIL 
-(-454 |Dom| |Expon| |VarSet| |Dpol|) 
+(-474 |Dom| |Expon| |VarSet| |Dpol|) 
 ((|constructor| (NIL "This package provides low level tools for Groebner basis computations")) (|virtualDegree| (((|NonNegativeInteger|) |#4|) "\\spad{virtualDegree }\\undocumented")) (|makeCrit| (((|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (|Record| (|:| |totdeg| (|NonNegativeInteger|)) (|:| |pol| |#4|)) |#4| (|NonNegativeInteger|)) "\\spad{makeCrit }\\undocumented")) (|critpOrder| (((|Boolean|) (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|))) "\\spad{critpOrder }\\undocumented")) (|prinb| (((|Void|) (|Integer|)) "\\spad{prinb }\\undocumented")) (|prinpolINFO| (((|Void|) (|List| |#4|)) "\\spad{prinpolINFO }\\undocumented")) (|fprindINFO| (((|Integer|) (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{fprindINFO }\\undocumented")) (|prindINFO| (((|Integer|) (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (|Integer|) (|Integer|) (|Integer|)) "\\spad{prindINFO }\\undocumented")) (|prinshINFO| (((|Void|) |#4|) "\\spad{prinshINFO }\\undocumented")) (|lepol| (((|Integer|) |#4|) "\\spad{lepol }\\undocumented")) (|minGbasis| (((|List| |#4|) (|List| |#4|)) "\\spad{minGbasis }\\undocumented")) (|updatD| (((|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) "\\spad{updatD }\\undocumented")) (|sPol| ((|#4| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|))) "\\spad{sPol }\\undocumented")) (|updatF| (((|List| (|Record| (|:| |totdeg| (|NonNegativeInteger|)) (|:| |pol| |#4|))) |#4| (|NonNegativeInteger|) (|List| (|Record| (|:| |totdeg| (|NonNegativeInteger|)) (|:| |pol| |#4|)))) "\\spad{updatF }\\undocumented")) (|hMonic| ((|#4| |#4|) "\\spad{hMonic }\\undocumented")) (|redPo| (((|Record| (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (|List| |#4|)) "\\spad{redPo }\\undocumented")) (|critMonD1| (((|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) "\\spad{critMonD1 }\\undocumented")) (|critMTonD1| (((|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) "\\spad{critMTonD1 }\\undocumented")) (|critBonD| (((|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (|List| (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) "\\spad{critBonD }\\undocumented")) (|critB| (((|Boolean|) |#2| |#2| |#2| |#2|) "\\spad{critB }\\undocumented")) (|critM| (((|Boolean|) |#2| |#2|) "\\spad{critM }\\undocumented")) (|critT| (((|Boolean|) (|Record| (|:| |lcmfij| |#2|) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| |#4|) (|:| |polj| |#4|))) "\\spad{critT }\\undocumented")) (|gbasis| (((|List| |#4|) (|List| |#4|) (|Integer|) (|Integer|)) "\\spad{gbasis }\\undocumented")) (|redPol| ((|#4| |#4| (|List| |#4|)) "\\spad{redPol }\\undocumented")) (|credPol| ((|#4| |#4| (|List| |#4|)) "\\spad{credPol }\\undocumented"))) 
 NIL 
 NIL 
-(-455 |Dom| |Expon| |VarSet| |Dpol|) 
+(-475 |Dom| |Expon| |VarSet| |Dpol|) 
 ((|constructor| (NIL "\\spadtype{GroebnerPackage} computes groebner bases for polynomial ideals. The basic computation provides a distinguished set of generators for polynomial ideals over fields. This basis allows an easy test for membership: the operation \\spadfun{normalForm} returns zero on ideal members. When the provided coefficient domain, Dom, is not a field, the result is equivalent to considering the extended ideal with \\spadtype{Fraction(Dom)} as coefficients, but considerably more efficient since all calculations are performed in Dom. Additional argument \"info\" and \"redcrit\" can be given to provide incremental information during computation. Argument \"info\" produces a computational summary for each s-polynomial. Argument \"redcrit\" prints out the reduced critical pairs. The term ordering is determined by the polynomial type used. Suggested types include \\spadtype{DistributedMultivariatePolynomial}, \\spadtype{HomogeneousDistributedMultivariatePolynomial}, \\spadtype{GeneralDistributedMultivariatePolynomial}.")) (|normalForm| ((|#4| |#4| (|List| |#4|)) "\\spad{normalForm(poly,gb)} reduces the polynomial \\spad{poly} modulo the precomputed groebner basis \\spad{gb} giving a canonical representative of the residue class.")) (|groebner| (((|List| |#4|) (|List| |#4|) (|String|) (|String|)) "\\indented{1}{groebner(lp, \"info\", \"redcrit\") computes a groebner basis} \\indented{1}{for a polynomial ideal generated by the list of polynomials lp,} \\indented{1}{displaying both a summary of the critical pairs considered (\"info\")} \\indented{1}{and the result of reducing each critical pair (\"redcrit\").} \\indented{1}{If the second or third arguments have any other string value,} \\indented{1}{the indicated information is suppressed.} \\blankline \\spad{X} s1:DMP([w,p,z,t,s,b],FRAC(INT)):= 45*p + 35*s - 165*b - 36 \\spad{X} s2:DMP([w,p,z,t,s,b],FRAC(INT)):= 35*p + 40*z + 25*t - 27*s \\spad{X} s3:DMP([w,p,z,t,s,b],FRAC(INT)):= 15*w + 25*p*s + 30*z - 18*t - 165*b**2 \\spad{X} s4:DMP([w,p,z,t,s,b],FRAC(INT)):= -9*w + 15*p*t + 20*z*s \\spad{X} s5:DMP([w,p,z,t,s,b],FRAC(INT)):= \\spad{w*p} + 2*z*t - 11*b**3 \\spad{X} s6:DMP([w,p,z,t,s,b],FRAC(INT)):= 99*w - 11*b*s + 3*b**2 \\spad{X} s7:DMP([w,p,z,t,s,b],FRAC(INT)):= \\spad{b**2} + 33/50*b + 2673/10000 \\spad{X} sn7:=[s1,s2,s3,s4,s5,s6,s7] \\spad{X} groebner(sn7,\"info\",\"redcrit\")") (((|List| |#4|) (|List| |#4|) (|String|)) "\\indented{1}{groebner(lp, infoflag) computes a groebner basis} \\indented{1}{for a polynomial ideal} \\indented{1}{generated by the list of polynomials lp.} \\indented{1}{Argument infoflag is used to get information on the computation.} \\indented{1}{If infoflag is \"info\", then summary information} \\indented{1}{is displayed for each s-polynomial generated.} \\indented{1}{If infoflag is \"redcrit\", the reduced critical pairs are displayed.} \\indented{1}{If infoflag is any other string,} \\indented{1}{no information is printed during computation.} \\blankline \\spad{X} s1:DMP([w,p,z,t,s,b],FRAC(INT)):= 45*p + 35*s - 165*b - 36 \\spad{X} s2:DMP([w,p,z,t,s,b],FRAC(INT)):= 35*p + 40*z + 25*t - 27*s \\spad{X} s3:DMP([w,p,z,t,s,b],FRAC(INT)):= 15*w + 25*p*s + 30*z - 18*t - 165*b**2 \\spad{X} s4:DMP([w,p,z,t,s,b],FRAC(INT)):= -9*w + 15*p*t + 20*z*s \\spad{X} s5:DMP([w,p,z,t,s,b],FRAC(INT)):= \\spad{w*p} + 2*z*t - 11*b**3 \\spad{X} s6:DMP([w,p,z,t,s,b],FRAC(INT)):= 99*w - 11*b*s + 3*b**2 \\spad{X} s7:DMP([w,p,z,t,s,b],FRAC(INT)):= \\spad{b**2} + 33/50*b + 2673/10000 \\spad{X} sn7:=[s1,s2,s3,s4,s5,s6,s7] \\spad{X} groebner(sn7,\"info\") \\spad{X} groebner(sn7,\"redcrit\")") (((|List| |#4|) (|List| |#4|)) "\\indented{1}{groebner(lp) computes a groebner basis for a polynomial ideal} \\indented{1}{generated by the list of polynomials lp.} \\blankline \\spad{X} s1:DMP([w,p,z,t,s,b],FRAC(INT)):= 45*p + 35*s - 165*b - 36 \\spad{X} s2:DMP([w,p,z,t,s,b],FRAC(INT)):= 35*p + 40*z + 25*t - 27*s \\spad{X} s3:DMP([w,p,z,t,s,b],FRAC(INT)):= 15*w + 25*p*s + 30*z - 18*t - 165*b**2 \\spad{X} s4:DMP([w,p,z,t,s,b],FRAC(INT)):= -9*w + 15*p*t + 20*z*s \\spad{X} s5:DMP([w,p,z,t,s,b],FRAC(INT)):= \\spad{w*p} + 2*z*t - 11*b**3 \\spad{X} s6:DMP([w,p,z,t,s,b],FRAC(INT)):= 99*w - 11*b*s + 3*b**2 \\spad{X} s7:DMP([w,p,z,t,s,b],FRAC(INT)):= \\spad{b**2} + 33/50*b + 2673/10000 \\spad{X} sn7:=[s1,s2,s3,s4,s5,s6,s7] \\spad{X} groebner(sn7)"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368)))) 
-(-456 S) 
+((|HasCategory| |#1| (QUOTE (-388)))) 
+(-476 S) 
 ((|constructor| (NIL "This category describes domains where \\spadfun{gcd} can be computed but where there is no guarantee of the existence of \\spadfun{factor} operation for factorisation into irreducibles. However, if such a \\spadfun{factor} operation exist, factorization will be unique up to order and units.")) (|gcdPolynomial| (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $)) "\\spad{gcdPolynomial(p,q)} returns the greatest common divisor (gcd) of univariate polynomials over the domain")) (|lcm| (($ (|List| $)) "\\spad{lcm(l)} returns the least common multiple of the elements of the list \\spad{l.}") (($ $ $) "\\spad{lcm(x,y)} returns the least common multiple of \\spad{x} and \\spad{y.}")) (|gcd| (($ (|List| $)) "\\spad{gcd(l)} returns the common \\spad{gcd} of the elements in the list \\spad{l.}") (($ $ $) "\\spad{gcd(x,y)} returns the greatest common divisor of \\spad{x} and \\spad{y.}"))) 
 NIL 
 NIL 
-(-457) 
+(-477) 
 ((|constructor| (NIL "This category describes domains where \\spadfun{gcd} can be computed but where there is no guarantee of the existence of \\spadfun{factor} operation for factorisation into irreducibles. However, if such a \\spadfun{factor} operation exist, factorization will be unique up to order and units.")) (|gcdPolynomial| (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $)) "\\spad{gcdPolynomial(p,q)} returns the greatest common divisor (gcd) of univariate polynomials over the domain")) (|lcm| (($ (|List| $)) "\\spad{lcm(l)} returns the least common multiple of the elements of the list \\spad{l.}") (($ $ $) "\\spad{lcm(x,y)} returns the least common multiple of \\spad{x} and \\spad{y.}")) (|gcd| (($ (|List| $)) "\\spad{gcd(l)} returns the common \\spad{gcd} of the elements in the list \\spad{l.}") (($ $ $) "\\spad{gcd(x,y)} returns the greatest common divisor of \\spad{x} and \\spad{y.}"))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-458 R |n| |ls| |gamma|) 
+(-478 R |n| |ls| |gamma|) 
 ((|constructor| (NIL "AlgebraGenericElementPackage allows you to create generic elements of an algebra, \\spadignore{i.e.} the scalars are extended to include symbolic coefficients")) (|conditionsForIdempotents| (((|List| (|Polynomial| |#1|))) "\\spad{conditionsForIdempotents()} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the fixed \\spad{R}-module basis") (((|List| (|Polynomial| |#1|)) (|Vector| $)) "\\spad{conditionsForIdempotents([v1,...,vn])} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}")) (|genericRightDiscriminant| (((|Fraction| (|Polynomial| |#1|))) "\\spad{genericRightDiscriminant()} is the determinant of the generic left trace forms of all products of basis element, if the generic left trace form is associative, an algebra is separable if the generic left discriminant is invertible, if it is non-zero, there is some ring extension which makes the algebra separable")) (|genericRightTraceForm| (((|Fraction| (|Polynomial| |#1|)) $ $) "\\spad{genericRightTraceForm (a,b)} is defined to be \\spadfun{genericRightTrace (a*b)}, this defines a symmetric bilinear form on the algebra")) (|genericLeftDiscriminant| (((|Fraction| (|Polynomial| |#1|))) "\\spad{genericLeftDiscriminant()} is the determinant of the generic left trace forms of all products of basis element, if the generic left trace form is associative, an algebra is separable if the generic left discriminant is invertible, if it is non-zero, there is some ring extension which makes the algebra separable")) (|genericLeftTraceForm| (((|Fraction| (|Polynomial| |#1|)) $ $) "\\spad{genericLeftTraceForm (a,b)} is defined to be \\spad{genericLeftTrace (a*b)}, this defines a symmetric bilinear form on the algebra")) (|genericRightNorm| (((|Fraction| (|Polynomial| |#1|)) $) "\\spad{genericRightNorm(a)} substitutes the coefficients of \\spad{a} for the generic coefficients into the coefficient of the constant term in \\spadfun{rightRankPolynomial} and changes the sign if the degree of this polynomial is odd")) (|genericRightTrace| (((|Fraction| (|Polynomial| |#1|)) $) "\\spad{genericRightTrace(a)} substitutes the coefficients of \\spad{a} for the generic coefficients into the coefficient of the second highest term in \\spadfun{rightRankPolynomial} and changes the sign")) (|genericRightMinimalPolynomial| (((|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|))) $) "\\spad{genericRightMinimalPolynomial(a)} substitutes the coefficients of \\spad{a} for the generic coefficients in \\spadfun{rightRankPolynomial}")) (|rightRankPolynomial| (((|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|)))) "\\spad{rightRankPolynomial()} returns the right minimimal polynomial of the generic element")) (|genericLeftNorm| (((|Fraction| (|Polynomial| |#1|)) $) "\\spad{genericLeftNorm(a)} substitutes the coefficients of \\spad{a} for the generic coefficients into the coefficient of the constant term in \\spadfun{leftRankPolynomial} and changes the sign if the degree of this polynomial is odd. This is a form of degree \\spad{k}")) (|genericLeftTrace| (((|Fraction| (|Polynomial| |#1|)) $) "\\spad{genericLeftTrace(a)} substitutes the coefficients of \\spad{a} for the generic coefficients into the coefficient of the second highest term in \\spadfun{leftRankPolynomial} and changes the sign. \\indented{1}{This is a linear form}")) (|genericLeftMinimalPolynomial| (((|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|))) $) "\\spad{genericLeftMinimalPolynomial(a)} substitutes the coefficients of {em a} for the generic coefficients in \\spad{leftRankPolynomial()}")) (|leftRankPolynomial| (((|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|)))) "\\spad{leftRankPolynomial()} returns the left minimimal polynomial of the generic element")) (|generic| (($ (|Vector| (|Symbol|)) (|Vector| $)) "\\spad{generic(vs,ve)} returns a generic element, \\spadignore{i.e.} the linear combination of \\spad{ve} with the symbolic coefficients \\spad{vs} error, if the vector of symbols is shorter than the vector of elements") (($ (|Symbol|) (|Vector| $)) "\\spad{generic(s,v)} returns a generic element, \\spadignore{i.e.} the linear combination of \\spad{v} with the symbolic coefficients \\spad{s1,s2,..}") (($ (|Vector| $)) "\\spad{generic(ve)} returns a generic element, \\spadignore{i.e.} the linear combination of \\spad{ve} basis with the symbolic coefficients \\spad{\\%x1,\\%x2,..}") (($ (|Vector| (|Symbol|))) "\\spad{generic(vs)} returns a generic element, \\spadignore{i.e.} the linear combination of the fixed basis with the symbolic coefficients \\spad{vs}; error, if the vector of symbols is too short") (($ (|Symbol|)) "\\spad{generic(s)} returns a generic element, \\spadignore{i.e.} the linear combination of the fixed basis with the symbolic coefficients \\spad{s1,s2,..}") (($) "\\spad{generic()} returns a generic element, \\spadignore{i.e.} the linear combination of the fixed basis with the symbolic coefficients \\spad{\\%x1,\\%x2,..}")) (|rightUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{rightUnits()} returns the affine space of all right units of the algebra, or \\spad{\"failed\"} if there is none")) (|leftUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{leftUnits()} returns the affine space of all left units of the algebra, or \\spad{\"failed\"} if there is none")) (|coerce| (($ (|Vector| (|Fraction| (|Polynomial| |#1|)))) "\\spad{coerce(v)} assumes that it is called with a vector of length equal to the dimension of the algebra, then a linear combination with the basis element is formed"))) 
-((-4599 |has| (-413 (-959 |#1|)) (-562)) (-4597 . T) (-4596 . T)) 
-((|HasCategory| (-413 (-959 |#1|)) (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| (-413 (-959 |#1|)) (QUOTE (-562)))) 
-(-459 |vl| R E) 
+((-4622 |has| (-433 (-980 |#1|)) (-582)) (-4620 . T) (-4619 . T)) 
+((|HasCategory| (-433 (-980 |#1|)) (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| (-433 (-980 |#1|)) (QUOTE (-582)))) 
+(-479 |vl| R E) 
 ((|constructor| (NIL "This type supports distributed multivariate polynomials whose variables are from a user specified list of symbols. The coefficient ring may be non commutative, but the variables are assumed to commute. The term ordering is specified by its third parameter. Suggested types which define term orderings include: \\spadtype{DirectProduct}, \\spadtype{HomogeneousDirectProduct}, \\spadtype{SplitHomogeneousDirectProduct} and finally \\spadtype{OrderedDirectProduct} which accepts an arbitrary user function to define a term ordering.")) (|reorder| (($ $ (|List| (|Integer|))) "\\spad{reorder(p, perm)} applies the permutation perm to the variables in a polynomial and returns the new correctly ordered polynomial"))) 
-(((-4604 "*") |has| |#2| (-174)) (-4595 |has| |#2| (-562)) (-4600 |has| |#2| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-562)))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#2| (QUOTE -4600)) (|HasCategory| |#2| (QUOTE (-457))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (|HasCategory| |#2| (QUOTE (-149))))) 
-(-460) 
+(((-4627 "*") |has| |#2| (-194)) (-4618 |has| |#2| (-582)) (-4623 |has| |#2| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-582)))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#2| (QUOTE -4623)) (|HasCategory| |#2| (QUOTE (-477))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (|HasCategory| |#2| (QUOTE (-169))))) 
+(-480) 
 ((|constructor| (NIL "This package provides support for gnuplot. These routines generate output files contain gnuplot scripts that may be processed directly by gnuplot. This is especially convenient in the axiom-wiki environment where gnuplot is called from LaTeX via gnuplottex.")) (|gnuDraw| (((|Void|) (|Expression| (|Float|)) (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|)) (|String|)) "\\indented{1}{\\spad{gnuDraw} provides 3d surface plotting, default options} \\blankline \\spad{X} gnuDraw(sin(x)*cos(y),x=-6..4,y=-4..6,\"out3d.dat\") \\spad{X} )sys gnuplot -persist out3d.dat") (((|Void|) (|Expression| (|Float|)) (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|)) (|String|) (|List| (|DrawOption|))) "\\indented{1}{\\spad{gnuDraw} provides 3d surface plotting with options} \\blankline \\spad{X} gnuDraw(sin(x)*cos(y),x=-6..4,y=-4..6,\"out3d.dat\",title==\"out3d\") \\spad{X} )sys gnuplot -persist out3d.dat") (((|Void|) (|Expression| (|Float|)) (|SegmentBinding| (|Float|)) (|String|)) "\\indented{1}{\\spad{gnuDraw} provides 2d plotting, default options} \\blankline \\spad{X} gnuDraw(D(cos(exp(z))/exp(z^2),z),z=-5..5,\"out2d.dat\") \\spad{X} )sys gnuplot -persist out2d.dat") (((|Void|) (|Expression| (|Float|)) (|SegmentBinding| (|Float|)) (|String|) (|List| (|DrawOption|))) "\\indented{1}{\\spad{gnuDraw} provides 2d plotting with options} \\blankline \\spad{X} gnuDraw(D(cos(exp(z))/exp(z^2),z),z=-5..5,\"out2d.dat\",title==\"out2d\") \\spad{X} )sys gnuplot -persist out2d.dat"))) 
 NIL 
 NIL 
-(-461 R BP) 
+(-481 R BP) 
 ((|constructor| (NIL "\\indented{1}{Author : P.Gianni.} Date Created: January 1990 Description:")) (|testModulus| (((|Boolean|) |#1| (|List| |#2|)) "\\spad{testModulus(p,lp)} returns \\spad{true} if the the prime \\spad{p} is valid for the list of polynomials \\spad{lp,} \\spadignore{i.e.} preserves the degree and they remain relatively prime.")) (|solveid| (((|Union| (|List| |#2|) "failed") |#2| |#1| (|Vector| (|List| |#2|))) "\\spad{solveid(h,table)} computes the coefficients of the extended euclidean algorithm for a list of polynomials whose tablePow is \\spad{table} and with right side \\spad{h.}")) (|tablePow| (((|Union| (|Vector| (|List| |#2|)) "failed") (|NonNegativeInteger|) |#1| (|List| |#2|)) "\\spad{tablePow(maxdeg,prime,lpol)} constructs the table with the coefficients of the Extended Euclidean Algorithm for lpol. Here the right side is \\spad{x**k}, for \\spad{k} less or equal to maxdeg. The operation returns \"failed\" when the elements are not coprime modulo prime.")) (|compBound| (((|NonNegativeInteger|) |#2| (|List| |#2|)) "\\spad{compBound(p,lp)} computes a bound for the coefficients of the solution polynomials. Given a polynomial right hand side \\spad{p,} and a list \\spad{lp} of left hand side polynomials. Exported because it depends on the valuation.")) (|reduction| ((|#2| |#2| |#1|) "\\spad{reduction(p,prime)} reduces the polynomial \\spad{p} modulo \\spad{prime} of \\spad{R.} Note that this function is exported only because it's conditional."))) 
 NIL 
 NIL 
-(-462 OV E S R P) 
+(-482 OV E S R P) 
 ((|constructor| (NIL "This is the top level package for doing multivariate factorization over basic domains like \\spadtype{Integer} or \\spadtype{Fraction Integer}.")) (|factor| (((|Factored| |#5|) |#5|) "\\spad{factor(p)} factors the multivariate polynomial \\spad{p} over its coefficient domain")) (|variable| (((|Union| $ "failed") (|Symbol|)) "\\spad{variable(s)} makes an element from symbol \\spad{s} or fails.")) (|convert| (((|Symbol|) $) "\\spad{convert(x)} converts \\spad{x} to a symbol"))) 
 NIL 
 NIL 
-(-463 E OV R P) 
+(-483 E OV R P) 
 ((|constructor| (NIL "Description:")) (|randomR| ((|#3|) "\\spad{randomR()} should be local but conditional")) (|gcdPolynomial| (((|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{gcdPolynomial(p,q)} returns the \\spad{GCD} of \\spad{p} and \\spad{q}"))) 
 NIL 
 NIL 
-(-464 R) 
+(-484 R) 
 ((|constructor| (NIL "This package provides operations for the factorization of univariate polynomials with integer coefficients. The factorization is done by \"lifting\" the finite \"berlekamp's\" factorization")) (|factor| (((|Factored| (|SparseUnivariatePolynomial| |#1|)) (|SparseUnivariatePolynomial| |#1|)) "\\spad{factor(p)} returns the factorisation of \\spad{p}"))) 
 NIL 
 NIL 
-(-465 R FE) 
+(-485 R FE) 
 ((|constructor| (NIL "\\spadtype{GenerateUnivariatePowerSeries} provides functions that create power series from explicit formulas for their \\spad{n}th coefficient.")) (|series| (((|Any|) |#2| (|Symbol|) (|Equation| |#2|) (|UniversalSegment| (|Fraction| (|Integer|))) (|Fraction| (|Integer|))) "\\spad{series(a(n),n,x = a,r0..,r)} returns \\spad{sum(n = \\spad{r0,r0} + \\spad{r,r0} + 2*r..., \\spad{a(n)} * \\spad{(x} - a)**n)}; \\spad{series(a(n),n,x = a,r0..r1,r)} returns \\spad{sum(n = \\spad{r0} + \\spad{k*r} while \\spad{n} \\spad{<=} \\spad{r1,} \\spad{a(n)} * \\spad{(x} - a)**n)}.") (((|Any|) (|Mapping| |#2| (|Fraction| (|Integer|))) (|Equation| |#2|) (|UniversalSegment| (|Fraction| (|Integer|))) (|Fraction| (|Integer|))) "\\spad{series(n \\spad{+->} a(n),x = a,r0..,r)} returns \\spad{sum(n = \\spad{r0,r0} + \\spad{r,r0} + 2*r..., a(n) * \\spad{(x} - a)**n)}; \\spad{series(n \\spad{+->} a(n),x = a,r0..r1,r)} returns \\spad{sum(n = \\spad{r0} + \\spad{k*r} while \\spad{n} \\spad{<=} \\spad{r1,} a(n) * \\spad{(x} - a)**n)}.") (((|Any|) |#2| (|Symbol|) (|Equation| |#2|) (|UniversalSegment| (|Integer|))) "\\spad{series(a(n),n,x=a,n0..)} returns \\spad{sum(n = n0..,a(n) * \\spad{(x} - a)**n)}; \\spad{series(a(n),n,x=a,n0..n1)} returns \\spad{sum(n = n0..n1,a(n) * \\spad{(x} - a)**n)}.") (((|Any|) (|Mapping| |#2| (|Integer|)) (|Equation| |#2|) (|UniversalSegment| (|Integer|))) "\\spad{series(n \\spad{+->} a(n),x = a,n0..)} returns \\spad{sum(n = n0..,a(n) * \\spad{(x} - a)**n)}; \\spad{series(n \\spad{+->} a(n),x = a,n0..n1)} returns \\spad{sum(n = n0..n1,a(n) * \\spad{(x} - a)**n)}.") (((|Any|) |#2| (|Symbol|) (|Equation| |#2|)) "\\spad{series(a(n),n,x = a)} returns \\spad{sum(n = 0..,a(n)*(x-a)**n)}.") (((|Any|) (|Mapping| |#2| (|Integer|)) (|Equation| |#2|)) "\\spad{series(n \\spad{+->} a(n),x = a)} returns \\spad{sum(n = 0..,a(n)*(x-a)**n)}.")) (|puiseux| (((|Any|) |#2| (|Symbol|) (|Equation| |#2|) (|UniversalSegment| (|Fraction| (|Integer|))) (|Fraction| (|Integer|))) "\\spad{puiseux(a(n),n,x = a,r0..,r)} returns \\spad{sum(n = \\spad{r0,r0} + \\spad{r,r0} + 2*r..., \\spad{a(n)} * \\spad{(x} - a)**n)}; \\spad{puiseux(a(n),n,x = a,r0..r1,r)} returns \\spad{sum(n = \\spad{r0} + \\spad{k*r} while \\spad{n} \\spad{<=} \\spad{r1,} \\spad{a(n)} * \\spad{(x} - a)**n)}.") (((|Any|) (|Mapping| |#2| (|Fraction| (|Integer|))) (|Equation| |#2|) (|UniversalSegment| (|Fraction| (|Integer|))) (|Fraction| (|Integer|))) "\\spad{puiseux(n \\spad{+->} a(n),x = a,r0..,r)} returns \\spad{sum(n = \\spad{r0,r0} + \\spad{r,r0} + 2*r..., a(n) * \\spad{(x} - a)**n)}; \\spad{puiseux(n \\spad{+->} a(n),x = a,r0..r1,r)} returns \\spad{sum(n = \\spad{r0} + \\spad{k*r} while \\spad{n} \\spad{<=} \\spad{r1,} a(n) * \\spad{(x} - a)**n)}.")) (|laurent| (((|Any|) |#2| (|Symbol|) (|Equation| |#2|) (|UniversalSegment| (|Integer|))) "\\spad{laurent(a(n),n,x=a,n0..)} returns \\spad{sum(n = n0..,a(n) * \\spad{(x} - a)**n)}; \\spad{laurent(a(n),n,x=a,n0..n1)} returns \\spad{sum(n = n0..n1,a(n) * \\spad{(x} - a)**n)}.") (((|Any|) (|Mapping| |#2| (|Integer|)) (|Equation| |#2|) (|UniversalSegment| (|Integer|))) "\\spad{laurent(n \\spad{+->} a(n),x = a,n0..)} returns \\spad{sum(n = n0..,a(n) * \\spad{(x} - a)**n)}; \\spad{laurent(n \\spad{+->} a(n),x = a,n0..n1)} returns \\spad{sum(n = n0..n1,a(n) * \\spad{(x} - a)**n)}.")) (|taylor| (((|Any|) |#2| (|Symbol|) (|Equation| |#2|) (|UniversalSegment| (|NonNegativeInteger|))) "\\spad{taylor(a(n),n,x = a,n0..)} returns \\spad{sum(n = n0..,a(n)*(x-a)**n)}; \\spad{taylor(a(n),n,x = a,n0..n1)} returns \\spad{sum(n = n0..,a(n)*(x-a)**n)}.") (((|Any|) (|Mapping| |#2| (|Integer|)) (|Equation| |#2|) (|UniversalSegment| (|NonNegativeInteger|))) "\\spad{taylor(n \\spad{+->} a(n),x = a,n0..)} returns \\spad{sum(n=n0..,a(n)*(x-a)**n)}; \\spad{taylor(n \\spad{+->} a(n),x = a,n0..n1)} returns \\spad{sum(n = n0..,a(n)*(x-a)**n)}.") (((|Any|) |#2| (|Symbol|) (|Equation| |#2|)) "\\spad{taylor(a(n),n,x = a)} returns \\spad{sum(n = 0..,a(n)*(x-a)**n)}.") (((|Any|) (|Mapping| |#2| (|Integer|)) (|Equation| |#2|)) "\\spad{taylor(n \\spad{+->} a(n),x = a)} returns \\spad{sum(n = 0..,a(n)*(x-a)**n)}."))) 
 NIL 
 NIL 
-(-466 RP TP) 
+(-486 RP TP) 
 ((|constructor| (NIL "General Hensel Lifting Used for Factorization of bivariate polynomials over a finite field.")) (|reduction| ((|#2| |#2| |#1|) "\\spad{reduction(u,pol)} computes the symmetric reduction of \\spad{u} mod \\spad{pol}")) (|completeHensel| (((|List| |#2|) |#2| (|List| |#2|) |#1| (|PositiveInteger|)) "\\spad{completeHensel(pol,lfact,prime,bound)} lifts lfact, the factorization mod \\spad{prime} of pol, to the factorization mod prime**k>bound. Factors are recombined on the way.")) (|HenselLift| (((|Record| (|:| |plist| (|List| |#2|)) (|:| |modulo| |#1|)) |#2| (|List| |#2|) |#1| (|PositiveInteger|)) "\\spad{HenselLift(pol,lfacts,prime,bound)} lifts lfacts, that are the factors of \\spad{pol} mod prime, to factors of \\spad{pol} mod prime**k > bound. No recombining is done ."))) 
 NIL 
 NIL 
-(-467 |vl| R IS E |ff| P) 
+(-487 |vl| R IS E |ff| P) 
 ((|constructor| (NIL "This package is undocumented")) (* (($ |#6| $) "\\spad{p*x} is not documented")) (|multMonom| (($ |#2| |#4| $) "\\spad{multMonom(r,e,x)} is not documented")) (|build| (($ |#2| |#3| |#4|) "\\spad{build(r,i,e)} is not documented")) (|unitVector| (($ |#3|) "\\spad{unitVector(x)} is not documented")) (|monomial| (($ |#2| (|ModuleMonomial| |#3| |#4| |#5|)) "\\spad{monomial(r,x)} is not documented")) (|reductum| (($ $) "\\spad{reductum(x)} is not documented")) (|leadingIndex| ((|#3| $) "\\spad{leadingIndex(x)} is not documented")) (|leadingExponent| ((|#4| $) "\\spad{leadingExponent(x)} is not documented")) (|leadingMonomial| (((|ModuleMonomial| |#3| |#4| |#5|) $) "\\spad{leadingMonomial(x)} is not documented")) (|leadingCoefficient| ((|#2| $) "\\spad{leadingCoefficient(x)} is not documented"))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-468) 
+(-488) 
 ((|constructor| (NIL "\\spad{GuessOptionFunctions0} provides operations that extract the values of options for Guess.")) (|checkOptions| (((|Void|) (|List| (|GuessOption|))) "\\spad{checkOptions checks} whether the given options are consistent, and yields an error otherwise")) (|debug| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{debug returns} whether we want additional output on the progress, default being \\spad{false}")) (|displayAsGF| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{displayAsGF specifies} whether the result is a generating function or a recurrence. This option should not be set by the user, but rather by the HP-specification, therefore, there is no default.")) (|indexName| (((|Symbol|) (|List| (|GuessOption|))) "\\spad{indexName returns} the name of the index variable used for the formulas, default being \\spad{n}")) (|variableName| (((|Symbol|) (|List| (|GuessOption|))) "\\spad{variableName returns} the name of the variable used in by the algebraic differential equation, default being \\spad{x}")) (|functionName| (((|Symbol|) (|List| (|GuessOption|))) "\\spad{functionName returns} the name of the function given by the algebraic differential equation, default being \\spad{f}")) (|one| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{one returns} whether we need only one solution, default being true.")) (|checkExtraValues| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{checkExtraValues(d)} specifies whether we want to check the solution beyond the order given by the degree bounds. The default is true.")) (|check| (((|Union| "skip" "MonteCarlo" "deterministic") (|List| (|GuessOption|))) "\\spad{check(d)} specifies how we want to check the solution. If the value is \"skip\", we return the solutions found by the interpolation routine without checking. If the value is \"MonteCarlo\", we use a probabilistic check. The default is \"deterministic\".")) (|safety| (((|NonNegativeInteger|) (|List| (|GuessOption|))) "\\spad{safety returns} the specified safety or 1 as default.")) (|allDegrees| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{allDegrees returns} whether all possibilities of the degree vector should be tried, the default being false.")) (|maxMixedDegree| (((|NonNegativeInteger|) (|List| (|GuessOption|))) "\\spad{maxMixedDegree returns} the specified maxMixedDegree.")) (|maxDegree| (((|Union| (|NonNegativeInteger|) "arbitrary") (|List| (|GuessOption|))) "\\spad{maxDegree returns} the specified maxDegree.")) (|maxLevel| (((|Union| (|NonNegativeInteger|) "arbitrary") (|List| (|GuessOption|))) "\\spad{maxLevel returns} the specified maxLevel.")) (|Somos| (((|Union| (|PositiveInteger|) (|Boolean|)) (|List| (|GuessOption|))) "\\spad{Somos returns} whether we allow only Somos-like operators, default being \\spad{false}")) (|homogeneous| (((|Union| (|PositiveInteger|) (|Boolean|)) (|List| (|GuessOption|))) "\\spad{homogeneous returns} whether we allow only homogeneous algebraic differential equations, default being \\spad{false}")) (|maxPower| (((|Union| (|PositiveInteger|) "arbitrary") (|List| (|GuessOption|))) "\\spad{maxPower returns} the specified maxPower.")) (|maxSubst| (((|Union| (|PositiveInteger|) "arbitrary") (|List| (|GuessOption|))) "\\spad{maxSubst returns} the specified maxSubst.")) (|maxShift| (((|Union| (|NonNegativeInteger|) "arbitrary") (|List| (|GuessOption|))) "\\spad{maxShift returns} the specified maxShift.")) (|maxDerivative| (((|Union| (|NonNegativeInteger|) "arbitrary") (|List| (|GuessOption|))) "\\spad{maxDerivative returns} the specified maxDerivative."))) 
 NIL 
 NIL 
-(-469) 
+(-489) 
 ((|constructor| (NIL "GuessOption is a domain whose elements are various options used by Guess.")) (|option| (((|Union| (|Any|) "failed") (|List| $) (|Symbol|)) "\\spad{option(l, option)} returns which options are given.")) (|displayKind| (($ (|Symbol|)) "\\spad{displayKind(d)} specifies kind of the result: generating function, recurrence or equation. This option should not be set by the user, but rather by the HP-specification.")) (|indexName| (($ (|Symbol|)) "\\spad{indexName(d)} specifies the index variable used for the formulas. This option is expressed in the form \\spad{indexName \\spad{==} \\spad{d}.}")) (|variableName| (($ (|Symbol|)) "\\spad{variableName(d)} specifies the variable used in by the algebraic differential equation. This option is expressed in the form \\spad{variableName \\spad{==} \\spad{d}.}")) (|functionNames| (($ (|List| (|Symbol|))) "\\spad{functionNames(d)} specifies the names for the function in algebraic dependence. This option is expressed in the form \\spad{functionNames \\spad{==} \\spad{d}.}")) (|functionName| (($ (|Symbol|)) "\\spad{functionName(d)} specifies the name of the function given by the algebraic differential equation or recurrence. This option is expressed in the form \\spad{functionName \\spad{==} \\spad{d}.}")) (|debug| (($ (|Boolean|)) "\\spad{debug(d)} specifies whether we want additional output on the progress. This option is expressed in the form \\spad{debug \\spad{==} \\spad{d}.}")) (|one| (($ (|Boolean|)) "\\spad{one(d)} specifies whether we are happy with one solution. This option is expressed in the form \\spad{one \\spad{==} \\spad{d}.}")) (|checkExtraValues| (($ (|Boolean|)) "\\spad{checkExtraValues(d)} specifies whether we want to check the solution beyond the order given by the degree bounds. This option is expressed in the form \\spad{checkExtraValues \\spad{==} \\spad{d}}")) (|check| (($ (|Union| "skip" "MonteCarlo" "deterministic")) "\\spad{check(d)} specifies how we want to check the solution. If the value is \"skip\", we return the solutions found by the interpolation routine without checking. If the value is \"MonteCarlo\", we use a probabilistic check. This option is expressed in the form \\spad{check \\spad{==} \\spad{d}}")) (|safety| (($ (|NonNegativeInteger|)) "\\spad{safety(d)} specifies the number of values reserved for testing any solutions found. This option is expressed in the form \\spad{safety \\spad{==} \\spad{d}.}")) (|allDegrees| (($ (|Boolean|)) "\\spad{allDegrees(d)} specifies whether all possibilities of the degree vector - taking into account maxDegree - should be tried. This is mainly interesting for rational interpolation. This option is expressed in the form \\spad{allDegrees \\spad{==} \\spad{d}.}")) (|maxMixedDegree| (($ (|NonNegativeInteger|)) "\\spad{maxMixedDegree(d)} specifies the maximum q-degree of the coefficient polynomials in a recurrence with polynomial coefficients, in the case of mixed shifts. Although slightly inconsistent, maxMixedDegree(0) specifies that no mixed shifts are allowed. This option is expressed in the form \\spad{maxMixedDegree \\spad{==} \\spad{d}.}")) (|maxDegree| (($ (|Union| (|NonNegativeInteger|) "arbitrary")) "\\spad{maxDegree(d)} specifies the maximum degree of the coefficient polynomials in an algebraic differential equation or a recursion with polynomial coefficients. For rational functions with an exponential term, \\spad{maxDegree} bounds the degree of the denominator polynomial. This option is expressed in the form \\spad{maxDegree \\spad{==} \\spad{d}.}")) (|maxLevel| (($ (|Union| (|NonNegativeInteger|) "arbitrary")) "\\spad{maxLevel(d)} specifies the maximum number of recursion levels operators guessProduct and guessSum will be applied. This option is expressed in the form spad{maxLevel \\spad{==} \\spad{d}.}")) (|Somos| (($ (|Union| (|PositiveInteger|) (|Boolean|))) "\\spad{Somos(d)} specifies whether we want that the total degree of the differential operators is constant, and equal to \\spad{d,} or maxDerivative if true. If true, maxDerivative must be set, too.")) (|homogeneous| (($ (|Union| (|PositiveInteger|) (|Boolean|))) "\\spad{homogeneous(d)} specifies whether we allow only homogeneous algebraic differential equations. This option is expressed in the form \\spad{homogeneous \\spad{==} \\spad{d}.} If true, then maxPower must be set, too, and ADEs with constant total degree are allowed. If a PositiveInteger is given, only ADE's with this total degree are allowed.")) (|maxPower| (($ (|Union| (|PositiveInteger|) "arbitrary")) "\\spad{maxPower(d)} specifies the maximum degree in an algebraic differential equation. For example, the degree of \\spad{(f'')^3} \\spad{f'} is 4. maxPower(-1) specifies that the maximum exponent can be arbitrary. This option is expressed in the form \\spad{maxPower \\spad{==} \\spad{d}.}")) (|maxSubst| (($ (|Union| (|PositiveInteger|) "arbitrary")) "\\spad{maxSubst(d)} specifies the maximum degree of the monomial substituted into the function we are looking for. That is, if \\spad{maxSubst \\spad{==} \\spad{d},} we look for polynomials such that $p(f(x), f(x^2), ..., f(x^d))=0$. equation. This option is expressed in the form \\spad{maxSubst \\spad{==} \\spad{d}.}")) (|maxShift| (($ (|Union| (|NonNegativeInteger|) "arbitrary")) "\\spad{maxShift(d)} specifies the maximum shift in a recurrence equation. This option is expressed in the form \\spad{maxShift \\spad{==} \\spad{d}.}")) (|maxDerivative| (($ (|Union| (|NonNegativeInteger|) "arbitrary")) "\\spad{maxDerivative(d)} specifies the maximum derivative in an algebraic differential equation. This option is expressed in the form \\spad{maxDerivative \\spad{==} \\spad{d}.}"))) 
 NIL 
 NIL 
-(-470 E V R P Q) 
+(-490 E V R P Q) 
 ((|constructor| (NIL "Gosper's summation algorithm.")) (|GospersMethod| (((|Union| |#5| "failed") |#5| |#2| (|Mapping| |#2|)) "\\spad{GospersMethod(b, \\spad{n,} new)} returns a rational function \\spad{rf(n)} such that \\spad{a(n) * rf(n)} is the indefinite sum of \\spad{a(n)} with respect to upward difference on \\spad{n}, \\spadignore{i.e.} \\spad{a(n+1) * rf(n+1) - a(n) * rf(n) = a(n)}, where \\spad{b(n) = a(n)/a(n-1)} is a rational function. Returns \"failed\" if no such rational function \\spad{rf(n)} exists. Note that \\spad{new} is a nullary function returning a new \\spad{V} every time. The condition on \\spad{a(n)} is that \\spad{a(n)/a(n-1)} is a rational function of \\spad{n}."))) 
 NIL 
 NIL 
-(-471 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR |InfClsPoint| |DesTree| BLMET) 
+(-491 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR |InfClsPoint| |DesTree| BLMET) 
 ((|constructor| (NIL "A package that implements the Brill-Noether algorithm. Part of the PAFF package.")) (|ZetaFunction| (((|UnivariateTaylorSeriesCZero| (|Integer|) |t|) (|PositiveInteger|)) "Returns the Zeta function of the curve in constant field extension. Calculated by using the L-Polynomial") (((|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) "Returns the Zeta function of the curve. Calculated by using the L-Polynomial")) (|numberPlacesDegExtDeg| (((|Integer|) (|PositiveInteger|) (|PositiveInteger|)) "numberRatPlacesExtDegExtDeg(d, \\spad{n)} returns the number of places of degree \\spad{d} in the constant field extension of degree \\spad{n}")) (|numberRatPlacesExtDeg| (((|Integer|) (|PositiveInteger|)) "\\spad{numberRatPlacesExtDeg(n)} returns the number of rational places in the constant field extenstion of degree \\spad{n}")) (|numberOfPlacesOfDegree| (((|Integer|) (|PositiveInteger|)) "returns the number of places of the given degree")) (|placesOfDegree| (((|List| |#7|) (|PositiveInteger|)) "\\spad{placesOfDegree(d)} returns all places of degree \\spad{d} of the curve.")) (|classNumber| (((|Integer|)) "Returns the class number of the curve.")) (|LPolynomial| (((|SparseUnivariatePolynomial| (|Integer|)) (|PositiveInteger|)) "\\spad{LPolynomial(d)} returns the L-Polynomial of the curve in constant field extension of degree \\spad{d.}") (((|SparseUnivariatePolynomial| (|Integer|))) "Returns the L-Polynomial of the curve.")) (|rationalPlaces| (((|List| |#7|)) "\\spad{rationalPlaces returns} all the rational places of the curve defined by the polynomial given to the package.")) (|pointDominateBy| ((|#5| |#7|) "\\spad{pointDominateBy(pl)} returns the projective point dominated by the place \\spad{pl.}")) (|adjunctionDivisor| ((|#8|) "\\spad{adjunctionDivisor computes} the adjunction divisor of the plane curve given by the polynomial crv.")) (|intersectionDivisor| ((|#8| |#3|) "\\spad{intersectionDivisor(pol)} compute the intersection divisor (the Cartier divisor) of the form \\spad{pol} with the curve. If some intersection points lie in an extension of the ground field, an error message is issued specifying the extension degree needed to find all the intersection points. (If \\spad{pol} is not homogeneous an error message is issued).")) (|evalIfCan| (((|Union| |#1| "failed") (|Fraction| |#3|) |#7|) "\\spad{evalIfCan(u,pl)} evaluate the function \\spad{u} at the place \\spad{pl} (returns \"failed\" if it is a pole).") (((|Union| |#1| "failed") |#3| |#3| |#7|) "\\spad{evalIfCan(f,g,pl)} evaluate the function \\spad{f/g} at the place \\spad{pl} (returns \"failed\" if it is a pole).") (((|Union| |#1| "failed") |#3| |#7|) "\\spad{evalIfCan(f,pl)} evaluate \\spad{f} at the place \\spad{pl} (returns \"failed\" if it is a pole).")) (|eval| ((|#1| (|Fraction| |#3|) |#7|) "\\spad{eval(u,pl)} evaluate the function \\spad{u} at the place \\spad{pl.}") ((|#1| |#3| |#3| |#7|) "\\spad{eval(f,g,pl)} evaluate the function \\spad{f/g} at the place \\spad{pl.}") ((|#1| |#3| |#7|) "\\spad{eval(f,pl)} evaluate \\spad{f} at the place \\spad{pl.}")) (|interpolateForms| (((|List| |#3|) |#8| (|NonNegativeInteger|)) "\\spad{interpolateForms(d,n)} returns a basis of the interpolate forms of degree \\spad{n} of the divisor \\spad{d.}")) (|lBasis| (((|Record| (|:| |num| (|List| |#3|)) (|:| |den| |#3|)) |#8|) "\\spad{lBasis computes} a basis associated to the specified divisor")) (|parametrize| ((|#6| |#3| |#7|) "\\spad{parametrize(f,pl)} returns a local parametrization of \\spad{f} at the place \\spad{pl.}")) (|singularPoints| (((|List| |#5|)) "rationalPoints() returns the singular points of the curve defined by the polynomial given to the package. If the singular points lie in an extension of the specified ground field an error message is issued specifying the extension degree needed to find all singular points.")) (|setSingularPoints| (((|List| |#5|) (|List| |#5|)) "\\spad{setSingularPoints(lpt)} sets the singular points to be used. Beware: no attempt is made to check if the points are singular or not, nor if all of the singular points are presents. Hence, results of some computation maybe false. It is intend to be use when one want to compute the singular points are computed by other means than to use the function singularPoints.")) (|desingTreeWoFullParam| (((|List| |#10|)) "\\spad{desingTreeWoFullParam returns} the desingularisation trees at all singular points of the curve defined by the polynomial given to the package. The local parametrizations are not computed.")) (|desingTree| (((|List| |#10|)) "\\spad{desingTree returns} the desingularisation trees at all singular points of the curve defined by the polynomial given to the package.")) (|genus| (((|NonNegativeInteger|)) "\\spad{genus returns} the genus of the curve defined by the polynomial given to the package.")) (|theCurve| ((|#3|) "\\spad{theCurve returns} the specified polynomial for the package.")) (|printInfo| (((|Void|) (|List| (|Boolean|))) "\\spad{printInfo(lbool)} prints some information comming from various package and domain used by this package."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-374)))) 
-(-472 R E |VarSet| P) 
+((|HasCategory| |#1| (QUOTE (-394)))) 
+(-492 R E |VarSet| P) 
 ((|constructor| (NIL "A domain for polynomial sets.")) (|convert| (($ (|List| |#4|)) "\\axiom{convert(lp)} returns the polynomial set whose members are the polynomials of \\axiom{lp}."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#4| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#4| (QUOTE (-1098))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-562)))) 
-(-473 S R E) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#4| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#4| (QUOTE (-1119))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-582)))) 
+(-493 S R E) 
 ((|constructor| (NIL "GradedAlgebra(R,E) denotes ``E-graded R-algebra''. A graded algebra is a graded module together with a degree preserving R-linear map, called the product. \\blankline The name ``product'' is written out in full so inner and outer products with the same mapping type can be distinguished by name.")) (|product| (($ $ $) "\\spad{product(a,b)} is the degree-preserving R-linear product: \\blankline \\spad{degree product(a,b) = degree a + degree \\spad{b}} \\spad{product(a1+a2,b) = product(a1,b) + product(a2,b)} \\spad{product(a,b1+b2) = product(a,b1) + product(a,b2)} \\spad{product(r*a,b) = product(a,r*b) = r*product(a,b)} \\spad{product(a,product(b,c)) = product(product(a,b),c)}")) ((|One|) (($) "\\spad{1} is the identity for \\spad{product}."))) 
 NIL 
 NIL 
-(-474 R E) 
+(-494 R E) 
 ((|constructor| (NIL "GradedAlgebra(R,E) denotes ``E-graded R-algebra''. A graded algebra is a graded module together with a degree preserving R-linear map, called the product. \\blankline The name ``product'' is written out in full so inner and outer products with the same mapping type can be distinguished by name.")) (|product| (($ $ $) "\\spad{product(a,b)} is the degree-preserving R-linear product: \\blankline \\spad{degree product(a,b) = degree a + degree \\spad{b}} \\spad{product(a1+a2,b) = product(a1,b) + product(a2,b)} \\spad{product(a,b1+b2) = product(a,b1) + product(a,b2)} \\spad{product(r*a,b) = product(a,r*b) = r*product(a,b)} \\spad{product(a,product(b,c)) = product(product(a,b),c)}")) ((|One|) (($) "\\spad{1} is the identity for \\spad{product}."))) 
 NIL 
 NIL 
-(-475) 
+(-495) 
 ((|constructor| (NIL "GrayCode provides a function for efficiently running through all subsets of a finite set, only changing one element by another one.")) (|firstSubsetGray| (((|Vector| (|Vector| (|Integer|))) (|PositiveInteger|)) "\\spad{firstSubsetGray(n)} creates the first vector \\spad{ww} to start a loop using nextSubsetGray(ww,n)")) (|nextSubsetGray| (((|Vector| (|Vector| (|Integer|))) (|Vector| (|Vector| (|Integer|))) (|PositiveInteger|)) "\\spad{nextSubsetGray(ww,n)} returns a vector \\spad{vv} whose components have the following meanings:\\br vv.1: a vector of length \\spad{n} whose entries are 0 or 1. This can be interpreted as a code for a subset of the set 1,...,n; \\spad{vv.1} differs from \\spad{ww.1} by exactly one entry;\\br \\spad{vv.2.1} is the number of the entry of \\spad{vv.1} which will be changed next time;\\br \\spad{vv.2.1} = \\spad{n+1} means that \\spad{vv.1} is the last subset; trying to compute nextSubsetGray(vv) if \\spad{vv.2.1} = \\spad{n+1} will produce an error!\\br \\blankline The other components of \\spad{vv.2} are needed to compute nextSubsetGray efficiently. Note that this is an implementation of [Williamson, Topic II, 3.54, \\spad{p.} 112] for the special case \\spad{r1} = \\spad{r2} = \\spad{...} = \\spad{rn} = 2; Note that nextSubsetGray produces a side-effect, \\spadignore{i.e.} nextSubsetGray(vv) and \\spad{vv} \\spad{:=} nextSubsetGray(vv) will have the same effect."))) 
 NIL 
 NIL 
-(-476) 
+(-496) 
 ((|constructor| (NIL "TwoDimensionalPlotSettings sets global flags and constants for 2-dimensional plotting.")) (|screenResolution| (((|Integer|) (|Integer|)) "\\spad{screenResolution(n)} sets the screen resolution to \\spad{n.}") (((|Integer|)) "\\spad{screenResolution()} returns the screen resolution \\spad{n.}")) (|minPoints| (((|Integer|) (|Integer|)) "\\spad{minPoints()} sets the minimum number of points in a plot.") (((|Integer|)) "\\spad{minPoints()} returns the minimum number of points in a plot.")) (|maxPoints| (((|Integer|) (|Integer|)) "\\spad{maxPoints()} sets the maximum number of points in a plot.") (((|Integer|)) "\\spad{maxPoints()} returns the maximum number of points in a plot.")) (|adaptive| (((|Boolean|) (|Boolean|)) "\\spad{adaptive(true)} turns adaptive plotting on; \\spad{adaptive(false)} turns adaptive plotting off.") (((|Boolean|)) "\\spad{adaptive()} determines whether plotting will be done adaptively.")) (|drawToScale| (((|Boolean|) (|Boolean|)) "\\spad{drawToScale(true)} causes plots to be drawn to scale. \\spad{drawToScale(false)} causes plots to be drawn so that they fill up the viewport window. The default setting is false.") (((|Boolean|)) "\\spad{drawToScale()} determines whether or not plots are to be drawn to scale.")) (|clipPointsDefault| (((|Boolean|) (|Boolean|)) "\\spad{clipPointsDefault(true)} turns on automatic clipping; \\spad{clipPointsDefault(false)} turns off automatic clipping. The default setting is true.") (((|Boolean|)) "\\spad{clipPointsDefault()} determines whether or not automatic clipping is to be done."))) 
 NIL 
 NIL 
-(-477) 
+(-497) 
 ((|constructor| (NIL "TwoDimensionalGraph creates virtual two dimensional graphs (to be displayed on TwoDimensionalViewports).")) (|putColorInfo| (((|List| (|List| (|Point| (|DoubleFloat|)))) (|List| (|List| (|Point| (|DoubleFloat|)))) (|List| (|Palette|))) "\\spad{putColorInfo(llp,lpal)} takes a list of list of points, \\spad{llp}, and returns the points with their hue and shade components set according to the list of palette colors, \\spad{lpal}.")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(gi)} returns the indicated graph, \\spad{gi}, of domain \\spadtype{GraphImage} as output of the domain \\spadtype{OutputForm}.") (($ (|List| (|List| (|Point| (|DoubleFloat|))))) "\\spad{coerce(llp)} component(gi,pt) creates and returns a graph of the domain \\spadtype{GraphImage} which is composed of the list of list of points given by \\spad{llp}, and whose point colors, line colors and point sizes are determined by the default functions \\spadfun{pointColorDefault}, \\spadfun{lineColorDefault}, and \\spadfun{pointSizeDefault}. The graph data is then sent to the viewport manager where it waits to be included in a two-dimensional viewport window.")) (|point| (((|Void|) $ (|Point| (|DoubleFloat|)) (|Palette|)) "\\spad{point(gi,pt,pal)} modifies the graph \\spad{gi} of the domain \\spadtype{GraphImage} to contain one point component, \\spad{pt} whose point color is set to be the palette color \\spad{pal}, and whose line color and point size are determined by the default functions \\spadfun{lineColorDefault} and \\spadfun{pointSizeDefault}.")) (|appendPoint| (((|Void|) $ (|Point| (|DoubleFloat|))) "\\spad{appendPoint(gi,pt)} appends the point \\spad{pt} to the end of the list of points component for the graph, \\spad{gi}, which is of the domain \\spadtype{GraphImage}.")) (|component| (((|Void|) $ (|Point| (|DoubleFloat|)) (|Palette|) (|Palette|) (|PositiveInteger|)) "\\spad{component(gi,pt,pal1,pal2,ps)} modifies the graph \\spad{gi} of the domain \\spadtype{GraphImage} to contain one point component, \\spad{pt} whose point color is set to the palette color \\spad{pal1}, line color is set to the palette color \\spad{pal2}, and point size is set to the positive integer \\spad{ps}.") (((|Void|) $ (|Point| (|DoubleFloat|))) "\\spad{component(gi,pt)} modifies the graph \\spad{gi} of the domain \\spadtype{GraphImage} to contain one point component, \\spad{pt} whose point color, line color and point size are determined by the default functions \\spadfun{pointColorDefault}, \\spadfun{lineColorDefault}, and \\spadfun{pointSizeDefault}.") (((|Void|) $ (|List| (|Point| (|DoubleFloat|))) (|Palette|) (|Palette|) (|PositiveInteger|)) "\\spad{component(gi,lp,pal1,pal2,p)} sets the components of the graph, \\spad{gi} of the domain \\spadtype{GraphImage}, to the values given. The point list for \\spad{gi} is set to the list \\spad{lp}, the color of the points in \\spad{lp} is set to the palette color \\spad{pal1}, the color of the lines which connect the points \\spad{lp} is set to the palette color \\spad{pal2}, and the size of the points in \\spad{lp} is given by the integer \\spad{p.}")) (|units| (((|List| (|Float|)) $ (|List| (|Float|))) "\\spad{units(gi,lu)} modifies the list of unit increments for the \\spad{x} and \\spad{y} axes of the given graph, \\spad{gi} of the domain \\spadtype{GraphImage}, to be that of the list of unit increments, \\spad{lu}, and returns the new list of units for \\spad{gi}.") (((|List| (|Float|)) $) "\\spad{units(gi)} returns the list of unit increments for the \\spad{x} and \\spad{y} axes of the indicated graph, \\spad{gi}, of the domain \\spadtype{GraphImage}.")) (|ranges| (((|List| (|Segment| (|Float|))) $ (|List| (|Segment| (|Float|)))) "\\spad{ranges(gi,lr)} modifies the list of ranges for the given graph, \\spad{gi} of the domain \\spadtype{GraphImage}, to be that of the list of range segments, \\spad{lr}, and returns the new range list for \\spad{gi}.") (((|List| (|Segment| (|Float|))) $) "\\spad{ranges(gi)} returns the list of ranges of the point components from the indicated graph, \\spad{gi}, of the domain \\spadtype{GraphImage}.")) (|key| (((|Integer|) $) "\\spad{key(gi)} returns the process ID of the given graph, \\spad{gi}, of the domain \\spadtype{GraphImage}.")) (|pointLists| (((|List| (|List| (|Point| (|DoubleFloat|)))) $) "\\spad{pointLists(gi)} returns the list of lists of points which compose the given graph, \\spad{gi}, of the domain \\spadtype{GraphImage}.")) (|makeGraphImage| (($ (|List| (|List| (|Point| (|DoubleFloat|)))) (|List| (|Palette|)) (|List| (|Palette|)) (|List| (|PositiveInteger|)) (|List| (|DrawOption|))) "\\spad{makeGraphImage(llp,lpal1,lpal2,lp,lopt)} returns a graph of the domain \\spadtype{GraphImage} which is composed of the points and lines from the list of lists of points, \\spad{llp}, whose point colors are indicated by the list of palette colors, \\spad{lpal1}, and whose lines are colored according to the list of palette colors, \\spad{lpal2}. The paramater \\spad{lp} is a list of integers which denote the size of the data points, and \\spad{lopt} is the list of draw command options. The graph data is then sent to the viewport manager where it waits to be included in a two-dimensional viewport window.") (($ (|List| (|List| (|Point| (|DoubleFloat|)))) (|List| (|Palette|)) (|List| (|Palette|)) (|List| (|PositiveInteger|))) "\\spad{makeGraphImage(llp,lpal1,lpal2,lp)} returns a graph of the domain \\spadtype{GraphImage} which is composed of the points and lines from the list of lists of points, \\spad{llp}, whose point colors are indicated by the list of palette colors, \\spad{lpal1}, and whose lines are colored according to the list of palette colors, \\spad{lpal2}. The paramater \\spad{lp} is a list of integers which denote the size of the data points. The graph data is then sent to the viewport manager where it waits to be included in a two-dimensional viewport window.") (($ (|List| (|List| (|Point| (|DoubleFloat|))))) "\\spad{makeGraphImage(llp)} returns a graph of the domain \\spadtype{GraphImage} which is composed of the points and lines from the list of lists of points, \\spad{llp}, with default point size and default point and line colours. The graph data is then sent to the viewport manager where it waits to be included in a two-dimensional viewport window.") (($ $) "\\spad{makeGraphImage(gi)} takes the given graph, \\spad{gi} of the domain \\spadtype{GraphImage}, and sends it's data to the viewport manager where it waits to be included in a two-dimensional viewport window. \\spad{gi} cannot be an empty graph, and it's elements must have been created using the \\spadfun{point} or \\spadfun{component} functions, not by a previous \\spadfun{makeGraphImage}.")) (|graphImage| (($) "\\spad{graphImage()} returns an empty graph with 0 point lists of the domain \\spadtype{GraphImage}. A graph image contains the graph data component of a two dimensional viewport."))) 
 NIL 
 NIL 
-(-478 S R E) 
+(-498 S R E) 
 ((|constructor| (NIL "GradedModule(R,E) denotes ``E-graded R-module'', that is, collection of R-modules indexed by an abelian monoid E. An element \\spad{g} of \\spad{G[s]} for some specific \\spad{s} in \\spad{E} is said to be an element of \\spad{G} with degree \\spad{s}. Sums are defined in each module \\spad{G[s]} so two elements of \\spad{G} have a sum if they have the same degree. \\blankline Morphisms can be defined and composed by degree to give the mathematical category of graded modules.")) (+ (($ $ $) "\\spad{g+h} is the sum of \\spad{g} and \\spad{h} in the module of elements of the same degree as \\spad{g} and \\spad{h.} Error: if \\spad{g} and \\spad{h} have different degrees.")) (- (($ $ $) "\\spad{g-h} is the difference of \\spad{g} and \\spad{h} in the module of elements of the same degree as \\spad{g} and \\spad{h.} Error: if \\spad{g} and \\spad{h} have different degrees.") (($ $) "\\spad{-g} is the additive inverse of \\spad{g} in the module of elements of the same grade as \\spad{g.}")) (* (($ $ |#2|) "\\spad{g*r} is right module multiplication.") (($ |#2| $) "\\spad{r*g} is left module multiplication.")) ((|Zero|) (($) "\\spad{0} denotes the zero of degree 0.")) (|degree| ((|#3| $) "\\spad{degree(g)} names the degree of \\spad{g.} The set of all elements of a given degree form an R-module."))) 
 NIL 
 NIL 
-(-479 R E) 
+(-499 R E) 
 ((|constructor| (NIL "GradedModule(R,E) denotes ``E-graded R-module'', that is, collection of R-modules indexed by an abelian monoid E. An element \\spad{g} of \\spad{G[s]} for some specific \\spad{s} in \\spad{E} is said to be an element of \\spad{G} with degree \\spad{s}. Sums are defined in each module \\spad{G[s]} so two elements of \\spad{G} have a sum if they have the same degree. \\blankline Morphisms can be defined and composed by degree to give the mathematical category of graded modules.")) (+ (($ $ $) "\\spad{g+h} is the sum of \\spad{g} and \\spad{h} in the module of elements of the same degree as \\spad{g} and \\spad{h.} Error: if \\spad{g} and \\spad{h} have different degrees.")) (- (($ $ $) "\\spad{g-h} is the difference of \\spad{g} and \\spad{h} in the module of elements of the same degree as \\spad{g} and \\spad{h.} Error: if \\spad{g} and \\spad{h} have different degrees.") (($ $) "\\spad{-g} is the additive inverse of \\spad{g} in the module of elements of the same grade as \\spad{g.}")) (* (($ $ |#1|) "\\spad{g*r} is right module multiplication.") (($ |#1| $) "\\spad{r*g} is left module multiplication.")) ((|Zero|) (($) "\\spad{0} denotes the zero of degree 0.")) (|degree| ((|#2| $) "\\spad{degree(g)} names the degree of \\spad{g.} The set of all elements of a given degree form an R-module."))) 
 NIL 
 NIL 
-(-480 |lv| -3313 R) 
+(-500 |lv| -3958 R) 
 ((|constructor| (NIL "Solve systems of polynomial equations using Groebner bases Total order Groebner bases are computed and then converted to lex ones This package is mostly intended for internal use.")) (|genericPosition| (((|Record| (|:| |dpolys| (|List| (|DistributedMultivariatePolynomial| |#1| |#2|))) (|:| |coords| (|List| (|Integer|)))) (|List| (|DistributedMultivariatePolynomial| |#1| |#2|)) (|List| (|OrderedVariableList| |#1|))) "\\spad{genericPosition(lp,lv)} puts a radical zero dimensional ideal in general position, for system \\spad{lp} in variables \\spad{lv.}")) (|testDim| (((|Union| (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) "failed") (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) (|List| (|OrderedVariableList| |#1|))) "\\spad{testDim(lp,lv)} tests if the polynomial system \\spad{lp} in variables \\spad{lv} is zero dimensional.")) (|groebSolve| (((|List| (|List| (|DistributedMultivariatePolynomial| |#1| |#2|))) (|List| (|DistributedMultivariatePolynomial| |#1| |#2|)) (|List| (|OrderedVariableList| |#1|))) "\\spad{groebSolve(lp,lv)} reduces the polynomial system \\spad{lp} in variables \\spad{lv} to triangular form. Algorithm based on groebner bases algorithm with linear algebra for change of ordering. Preprocessing for the general solver. The polynomials in input are of type \\spadtype{DMP}."))) 
 NIL 
 NIL 
-(-481 S) 
+(-501 S) 
 ((|constructor| (NIL "The class of multiplicative groups, that is, monoids with multiplicative inverses. \\blankline Axioms\\br \\tab{5}\\spad{leftInverse(\"*\":(\\%,\\%)->\\%,inv)}\\tab{5}\\spad{inv(x)*x = 1}\\br \\tab{5}\\spad{rightInverse(\"*\":(\\%,\\%)->\\%,inv)}\\tab{4}\\spad{x*inv(x) = 1}")) (|commutator| (($ $ $) "\\spad{commutator(p,q)} computes \\spad{inv(p) * inv(q) * \\spad{p} * \\spad{q}.}")) (|conjugate| (($ $ $) "\\spad{conjugate(p,q)} computes \\spad{inv(q) * \\spad{p} * \\spad{q};} this is 'right action by conjugation'.")) (|unitsKnown| ((|attribute|) "unitsKnown asserts that recip only returns \"failed\" for non-units.")) (^ (($ $ (|Integer|)) "\\spad{x^n} returns \\spad{x} raised to the integer power \\spad{n.}")) (** (($ $ (|Integer|)) "\\spad{x**n} returns \\spad{x} raised to the integer power \\spad{n.}")) (/ (($ $ $) "\\spad{x/y} is the same as \\spad{x} times the inverse of \\spad{y.}")) (|inv| (($ $) "\\spad{inv(x)} returns the inverse of \\spad{x.}"))) 
 NIL 
 NIL 
-(-482) 
+(-502) 
 ((|constructor| (NIL "The class of multiplicative groups, that is, monoids with multiplicative inverses. \\blankline Axioms\\br \\tab{5}\\spad{leftInverse(\"*\":(\\%,\\%)->\\%,inv)}\\tab{5}\\spad{inv(x)*x = 1}\\br \\tab{5}\\spad{rightInverse(\"*\":(\\%,\\%)->\\%,inv)}\\tab{4}\\spad{x*inv(x) = 1}")) (|commutator| (($ $ $) "\\spad{commutator(p,q)} computes \\spad{inv(p) * inv(q) * \\spad{p} * \\spad{q}.}")) (|conjugate| (($ $ $) "\\spad{conjugate(p,q)} computes \\spad{inv(q) * \\spad{p} * \\spad{q};} this is 'right action by conjugation'.")) (|unitsKnown| ((|attribute|) "unitsKnown asserts that recip only returns \"failed\" for non-units.")) (^ (($ $ (|Integer|)) "\\spad{x^n} returns \\spad{x} raised to the integer power \\spad{n.}")) (** (($ $ (|Integer|)) "\\spad{x**n} returns \\spad{x} raised to the integer power \\spad{n.}")) (/ (($ $ $) "\\spad{x/y} is the same as \\spad{x} times the inverse of \\spad{y.}")) (|inv| (($ $) "\\spad{inv(x)} returns the inverse of \\spad{x.}"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-483 |Coef| |var| |cen|) 
+(-503 |Coef| |var| |cen|) 
 ((|constructor| (NIL "This is a category of univariate Puiseux series constructed from univariate Laurent series. A Puiseux series is represented by a pair \\spad{[r,f(x)]}, where \\spad{r} is a positive rational number and \\spad{f(x)} is a Laurent series. This pair represents the Puiseux series \\spad{f(x\\^r)}.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|UnivariatePuiseuxSeries| |#1| |#2| |#3|)) "\\spad{coerce(f)} converts a Puiseux series to a general power series.") (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Puiseux series."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|))))) (|HasCategory| (-413 (-572)) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-484 |Key| |Entry| |Tbl| |dent|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|))))) (|HasCategory| (-433 (-592)) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-504 |Key| |Entry| |Tbl| |dent|) 
 ((|constructor| (NIL "A sparse table has a default entry, which is returned if no other value has been explicitly stored for a key."))) 
-((-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098)))) (-1841 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-1098))))) 
-(-485 R E V P) 
+((-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119)))) (-3836 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-1119))))) 
+(-505 R E V P) 
 ((|constructor| (NIL "A domain constructor of the category \\axiomType{TriangularSetCategory}. The only requirement for a list of polynomials to be a member of such a domain is the following: no polynomial is constant and two distinct polynomials have distinct main variables. Such a triangular set may not be auto-reduced or consistent. Triangular sets are stored as sorted lists w.r.t. the main variables of their members but they are displayed in reverse order."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#4| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#4| (QUOTE (-1098))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#3| (QUOTE (-374)))) 
-(-486) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#4| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#4| (QUOTE (-1119))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#3| (QUOTE (-394)))) 
+(-506) 
 ((|constructor| (NIL "This package exports guessing of sequences of rational functions"))) 
 NIL 
-((|HasCategory| (-53) (LIST (QUOTE -1044) (QUOTE (-1170))))) 
-(-487 -3313) 
+((|HasCategory| (-53) (LIST (QUOTE -1065) (QUOTE (-1191))))) 
+(-507 -3958) 
 ((|constructor| (NIL "This package exports guessing of sequences of numbers in a finite field"))) 
 NIL 
 NIL 
-(-488 -3313) 
+(-508 -3958) 
 ((|constructor| (NIL "This package exports guessing of sequences of numbers in a finite field"))) 
 NIL 
-((|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-1170))))) 
-(-489) 
+((|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-1191))))) 
+(-509) 
 ((|constructor| (NIL "This package exports guessing of sequences of rational numbers"))) 
 NIL 
-((-12 (|HasCategory| (-413 (-572)) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-1170)))))) 
-(-490 -3313 S EXPRR R -1318 -3972) 
+((-12 (|HasCategory| (-433 (-592)) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-1191)))))) 
+(-510 -3958 S EXPRR R -2400 -1683) 
 ((|constructor| (NIL "This package implements guessing of sequences. Packages for the most common cases are provided as \\spadtype{GuessInteger}, \\spadtype{GuessPolynomial}, etc.")) (|shiftHP| (((|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{shiftHP options} returns a specification for Hermite-Pade approximation with the $q$-shift operator") (((|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|))) "\\spad{shiftHP options} returns a specification for Hermite-Pade approximation with the shift operator")) (|diffHP| (((|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{diffHP options} returns a specification for Hermite-Pade approximation with the $q$-dilation operator") (((|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|))) "\\spad{diffHP options} returns a specification for Hermite-Pade approximation with the differential operator")) (|guessRat| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessRat \\spad{q}} returns a guesser that tries to find a q-rational function whose first values are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessRec} with \\spad{(l, maxShift \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true)}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessRat \\spad{l}} tries to find a rational function whose first values are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessRec}\\spad{(l, maxShift \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true)}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessRat(l, options)} tries to find a rational function whose first values are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(l, maxShift \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true)}.")) (|guessPRec| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessPRec \\spad{q}} returns a guesser that tries to find a linear q-recurrence with polynomial coefficients whose first values are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(q)} with \\spad{maxPower \\spad{==} 1}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessPRec \\spad{l}} tries to find a linear recurrence with polynomial coefficients whose first values are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessRec}\\spad{(l, maxPower \\spad{==} 1)}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessPRec(l, options)} tries to find a linear recurrence with polynomial coefficients whose first values are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(l, options)} with \\spad{maxPower \\spad{==} 1}.")) (|guessRec| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessRec \\spad{q}} returns a guesser that finds an ordinary q-difference equation whose first values are given by \\spad{l,} using the given options.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessRec(l, options)} tries to find an ordinary difference equation whose first values are given by \\spad{l,} using the given options.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessRec \\spad{l}} tries to find an ordinary difference equation whose first values are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}.")) (|guessPade| (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessPade(l, options)} tries to find a rational function whose first Taylor coefficients are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}\\spad{(l, options)} with \\spad{maxDerivative \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessPade(l, options)} tries to find a rational function whose first Taylor coefficients are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessADE}\\spad{(l, maxDerivative \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true)}.")) (|guessHolo| (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessHolo(l, options)} tries to find an ordinary linear differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessADE}\\spad{(l, options)} with \\spad{maxPower \\spad{==} 1}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessHolo \\spad{l}} tries to find an ordinary linear differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}\\spad{(l, maxPower \\spad{==} 1)}.")) (|guessAlg| (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessAlg(l, options)} tries to find an algebraic equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessADE}(l, options) with \\spad{maxDerivative \\spad{==} 0}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessAlg \\spad{l}} tries to find an algebraic equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}(l, maxDerivative \\spad{==} 0).")) (|guessADE| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessADE \\spad{q}} returns a guesser that tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the given options.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessADE(l, options)} tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the given options.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessADE \\spad{l}} tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}.")) (|guessHP| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) "\\spad{guessHP \\spad{f}} constructs an operation that applies Hermite-Pade approximation to the series generated by the given function \\spad{f.}")) (|guessBinRat| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessBinRat \\spad{q}} returns a guesser that tries to find a function of the form n+->qbinomial(a+b \\spad{n,} \\spad{n)} r(n), where r(q^n) is a q-rational function, that fits \\spad{l.}") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessBinRat(l, options)} tries to find a function of the form n+->binomial(a+b \\spad{n,} \\spad{n)} r(n), where r(n) is a rational function, that fits \\spad{l.}") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessBinRat(l, options)} tries to find a function of the form n+->binomial(a+b \\spad{n,} \\spad{n)} r(n), where r(n) is a rational function, that fits \\spad{l.}")) (|guessExpRat| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessExpRat \\spad{q}} returns a guesser that tries to find a function of the form n+->(a+b q^n)^n r(q^n), where r(q^n) is a q-rational function, that fits \\spad{l.}") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessExpRat(l, options)} tries to find a function of the form n+->(a+b n)^n r(n), where r(n) is a rational function, that fits \\spad{l.}") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessExpRat \\spad{l}} tries to find a function of the form n+->(a+b n)^n r(n), where r(n) is a rational function, that fits \\spad{l.}")) (|guess| (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|)))) (|List| (|Symbol|)) (|List| (|GuessOption|))) "\\spad{guess(l, guessers, ops)} applies recursively the given \\spad{guessers} to the successive differences if ops contains the symbol \\spad{guessSum} and quotients if ops contains the symbol \\spad{guessProduct} to the list. The given options are used.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|)))) (|List| (|Symbol|))) "\\spad{guess(l, guessers, ops)} applies recursively the given \\spad{guessers} to the successive differences if ops contains the symbol guessSum and quotients if ops contains the symbol guessProduct to the list. Default options as described in \\spadtype{GuessOptionFunctions0} are used.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guess(l, options)} applies recursively \\spadfun{guessRec} and \\spadfun{guessADE} to the successive differences and quotients of the list. The given options are used.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guess \\spad{l}} applies recursively \\spadfun{guessRec} and \\spadfun{guessADE} to the successive differences and quotients of the list. Default options as described in \\spadtype{GuessOptionFunctions0} are used."))) 
 NIL 
-((-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170)))))) 
-(-491) 
+((-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191)))))) 
+(-511) 
 ((|constructor| (NIL "This package exports guessing of sequences of rational functions"))) 
 NIL 
-((-12 (|HasCategory| (-413 (-959 (-572))) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-959 (-572)) (LIST (QUOTE -1044) (QUOTE (-1170)))))) 
-(-492 |q|) 
+((-12 (|HasCategory| (-433 (-980 (-592))) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-980 (-592)) (LIST (QUOTE -1065) (QUOTE (-1191)))))) 
+(-512 |q|) 
 ((|constructor| (NIL "This package exports guessing of sequences of univariate rational functions")) (|shiftHP| (((|Mapping| HPSPEC (|List| (|GuessOption|))) (|Symbol|)) "\\spad{shiftHP options} returns a specification for Hermite-Pade approximation with the $q$-shift operator") ((HPSPEC (|List| (|GuessOption|))) "\\spad{shiftHP options} returns a specification for Hermite-Pade approximation with the shift operator")) (|diffHP| (((|Mapping| HPSPEC (|List| (|GuessOption|))) (|Symbol|)) "\\spad{diffHP options} returns a specification for Hermite-Pade approximation with the $q$-dilation operator") ((HPSPEC (|List| (|GuessOption|))) "\\spad{diffHP options} returns a specification for Hermite-Pade approximation with the differential operator")) (|guessRat| (((|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessRat \\spad{q}} returns a guesser that tries to find a q-rational function whose first values are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessRec} with \\spad{(l, maxShift \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true)}.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessRat \\spad{l}} tries to find a rational function whose first values are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessRec}\\spad{(l, maxShift \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true)}.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessRat(l, options)} tries to find a rational function whose first values are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(l, maxShift \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true)}.")) (|guessPRec| (((|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessPRec \\spad{q}} returns a guesser that tries to find a linear q-recurrence with polynomial coefficients whose first values are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(q)} with \\spad{maxPower \\spad{==} 1}.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessPRec \\spad{l}} tries to find a linear recurrence with polynomial coefficients whose first values are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessRec}\\spad{(l, maxPower \\spad{==} 1)}.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessPRec(l, options)} tries to find a linear recurrence with polynomial coefficients whose first values are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(l, options)} with \\spad{maxPower \\spad{==} 1}.")) (|guessRec| (((|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessRec \\spad{q}} returns a guesser that finds an ordinary q-difference equation whose first values are given by \\spad{l,} using the given options.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessRec(l, options)} tries to find an ordinary difference equation whose first values are given by \\spad{l,} using the given options.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessRec \\spad{l}} tries to find an ordinary difference equation whose first values are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}.")) (|guessPade| (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessPade(l, options)} tries to find a rational function whose first Taylor coefficients are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}\\spad{(l, options)} with \\spad{maxDerivative \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true}.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessPade(l, options)} tries to find a rational function whose first Taylor coefficients are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessADE}\\spad{(l, maxDerivative \\spad{==} 0, maxPower \\spad{==} 1, allDegrees \\spad{==} true)}.")) (|guessHolo| (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessHolo(l, options)} tries to find an ordinary linear differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessADE}\\spad{(l, options)} with \\spad{maxPower \\spad{==} 1}.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessHolo \\spad{l}} tries to find an ordinary linear differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}\\spad{(l, maxPower \\spad{==} 1)}.")) (|guessAlg| (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessAlg(l, options)} tries to find an algebraic equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the given options. It is equivalent to \\spadfun{guessADE}(l, options) with \\spad{maxDerivative \\spad{==} 0}.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessAlg \\spad{l}} tries to find an algebraic equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}(l, maxDerivative \\spad{==} 0).")) (|guessADE| (((|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessADE \\spad{q}} returns a guesser that tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the given options.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessADE(l, options)} tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the given options.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessADE \\spad{l}} tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l,} using the default options described in \\spadtype{GuessOptionFunctions0}.")) (|guessHP| (((|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) (|Mapping| HPSPEC (|List| (|GuessOption|)))) "\\spad{guessHP \\spad{f}} constructs an operation that applies Hermite-Pade approximation to the series generated by the given function \\spad{f.}")) (|guessBinRat| (((|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessBinRat \\spad{q}} returns a guesser that tries to find a function of the form n+->qbinomial(a+b \\spad{n,} \\spad{n)} r(n), where r(q^n) is a q-rational function, that fits \\spad{l.}") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessBinRat(l, options)} tries to find a function of the form n+->binomial(a+b \\spad{n,} \\spad{n)} r(n), where r(n) is a rational function, that fits \\spad{l.}") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessBinRat(l, options)} tries to find a function of the form n+->binomial(a+b \\spad{n,} \\spad{n)} r(n), where r(n) is a rational function, that fits \\spad{l.}")) (|guessExpRat| (((|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessExpRat \\spad{q}} returns a guesser that tries to find a function of the form n+->(a+b q^n)^n r(q^n), where r(q^n) is a q-rational function, that fits \\spad{l.}") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guessExpRat(l, options)} tries to find a function of the form n+->(a+b n)^n r(n), where r(n) is a rational function, that fits \\spad{l.}") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guessExpRat \\spad{l}} tries to find a function of the form n+->(a+b n)^n r(n), where r(n) is a rational function, that fits \\spad{l.}")) (|guess| (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|)))) (|List| (|Symbol|)) (|List| (|GuessOption|))) "\\spad{guess(l, guessers, ops)} applies recursively the given \\spad{guessers} to the successive differences if ops contains the symbol \\spad{guessSum} and quotients if ops contains the symbol \\spad{guessProduct} to the list. The given options are used.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|)))) (|List| (|Symbol|))) "\\spad{guess(l, guessers, ops)} applies recursively the given \\spad{guessers} to the successive differences if ops contains the symbol guessSum and quotients if ops contains the symbol guessProduct to the list. Default options as described in \\spadtype{GuessOptionFunctions0} are used.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|)))) (|List| (|GuessOption|))) "\\spad{guess(l, options)} applies recursively \\spadfun{guessRec} and \\spadfun{guessADE} to the successive differences and quotients of the list. The given options are used.") (((|List| (|Record| (|:| |function| (|MyExpression| |#1| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| |#1| (|Integer|))))) "\\spad{guess \\spad{l}} applies recursively \\spadfun{guessRec} and \\spadfun{guessADE} to the successive differences and quotients of the list. Default options as described in \\spadtype{GuessOptionFunctions0} are used."))) 
 NIL 
 NIL 
-(-493) 
+(-513) 
 ((|constructor| (NIL "Symbolic fractions in \\%pi with integer coefficients; The point for using \\spad{Pi} as the default domain for those fractions is that \\spad{Pi} is coercible to the float types, and not Expression.")) (|pi| (($) "\\spad{pi()} returns the symbolic \\%pi."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-494 |Key| |Entry| |hashfn|) 
+(-514 |Key| |Entry| |hashfn|) 
 ((|constructor| (NIL "This domain provides access to the underlying Lisp hash tables. By varying the hashfn parameter, tables suited for different purposes can be obtained."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098))) (-1841 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-1098)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098))))) 
-(-495) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119))) (-3836 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-1119)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119))))) 
+(-515) 
 ((|constructor| (NIL "Generate a basis for the free Lie algebra on \\spad{n} generators over a ring \\spad{R} with identity up to basic commutators of length \\spad{c} using the algorithm of \\spad{P.} Hall as given in Serre's book Lie Groups \\spad{--} Lie Algebras")) (|generate| (((|Vector| (|List| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{generate(numberOfGens, maximalWeight)} generates a vector of elements of the form [left,weight,right] which represents a \\spad{P.} Hall basis element for the free lie algebra on \\spad{numberOfGens} generators. We only generate those basis elements of weight less than or equal to maximalWeight")) (|inHallBasis?| (((|Boolean|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{inHallBasis?(numberOfGens, leftCandidate, rightCandidate, left)} tests to see if a new element should be added to the \\spad{P.} Hall basis being constructed. The list \\spad{[leftCandidate,wt,rightCandidate]} is included in the basis if in the unique factorization of rightCandidate, we have left factor leftOfRight, and leftOfRight \\spad{<=} \\spad{leftCandidate}")) (|lfunc| (((|Integer|) (|Integer|) (|Integer|)) "\\spad{lfunc(d,n)} computes the rank of the \\spad{n}th factor in the lower central series of the free d-generated free Lie algebra; This rank is \\spad{d} if \\spad{n} = 1 and binom(d,2) if \\spad{n} = 2"))) 
 NIL 
 NIL 
-(-496 |vl| R) 
+(-516 |vl| R) 
 ((|constructor| (NIL "This type supports distributed multivariate polynomials whose variables are from a user specified list of symbols. The coefficient ring may be non commutative, but the variables are assumed to commute. The term ordering is total degree ordering refined by reverse lexicographic ordering with respect to the position that the variables appear in the list of variables parameter.")) (|reorder| (($ $ (|List| (|Integer|))) "\\spad{reorder(p, perm)} applies the permutation perm to the variables in a polynomial and returns the new correctly ordered polynomial"))) 
-(((-4604 "*") |has| |#2| (-174)) (-4595 |has| |#2| (-562)) (-4600 |has| |#2| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-562)))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#2| (QUOTE -4600)) (|HasCategory| |#2| (QUOTE (-457))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (|HasCategory| |#2| (QUOTE (-149))))) 
-(-497 -3465 S) 
+(((-4627 "*") |has| |#2| (-194)) (-4618 |has| |#2| (-582)) (-4623 |has| |#2| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-582)))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#2| (QUOTE -4623)) (|HasCategory| |#2| (QUOTE (-477))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (|HasCategory| |#2| (QUOTE (-169))))) 
+(-517 -3832 S) 
 ((|constructor| (NIL "This type represents the finite direct or cartesian product of an underlying ordered component type. The vectors are ordered first by the sum of their components, and then refined using a reverse lexicographic ordering. This type is a suitable third argument for \\spadtype{GeneralDistributedMultivariatePolynomial}."))) 
-((-4596 |has| |#2| (-1054)) (-4597 |has| |#2| (-1054)) (-4599 |has| |#2| (-6 -4599)) ((-4604 "*") |has| |#2| (-174)) (-4602 . T)) 
-((|HasCategory| |#2| (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846))) (-1841 (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846)))) (|HasCategory| |#2| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368)))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| |#2| (QUOTE (-374))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasAttribute| |#2| (QUOTE -4599)) (|HasCategory| |#2| (QUOTE (-138))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| |#2| (QUOTE (-25))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-374))) (|HasCategory| |#2| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1098))))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))))) 
-(-498 S) 
+((-4619 |has| |#2| (-1075)) (-4620 |has| |#2| (-1075)) (-4622 |has| |#2| (-6 -4622)) ((-4627 "*") |has| |#2| (-194)) (-4625 . T)) 
+((|HasCategory| |#2| (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867))) (-3836 (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867)))) (|HasCategory| |#2| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388)))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| |#2| (QUOTE (-394))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasAttribute| |#2| (QUOTE -4622)) (|HasCategory| |#2| (QUOTE (-158))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| |#2| (QUOTE (-25))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-394))) (|HasCategory| |#2| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1119))))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))))) 
+(-518 S) 
 ((|constructor| (NIL "Heap implemented in a flexible array to allow for insertions")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} member?(3,a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} count(4,a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} count(x+->(x>2),a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} any?(x+->(x=4),a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} every?(x+->(x=4),a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} b:Heap INT:= heap [1,2,3,4,5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} map!(x+->x+10,a) \\spad{X} a")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} size?(a,5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} more?(a,9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} less?(a,9)")) (|sample| (($) "\\blankline \\spad{X} sample()$Heap(INT)")) (|merge!| (($ $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} b:Heap INT:= heap [6,7,8,9,10] \\spad{X} merge!(a,b) \\spad{X} a \\spad{X} \\spad{b}")) (|merge| (($ $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} b:Heap INT:= heap [6,7,8,9,10] \\spad{X} merge(a,b)")) (|max| ((|#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} max a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} map(x+->x+10,a) \\spad{X} a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} insert!(8,a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} extract! a \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} eq?(a,b)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()$(Heap INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} empty? a")) (|copy| (($ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,2,3,4,5] \\spad{X} copy a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,2,3,4,5])$Heap(INT)")) (|heap| (($ (|List| |#1|)) "\\indented{1}{heap(ls) creates a heap of elements consisting of the} \\indented{1}{elements of ls.} \\blankline \\spad{E} i:Heap INT \\spad{:=} heap [1,6,3,7,5,2,4]"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-499 -3313 UP UPUP R) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-519 -3958 UP UPUP R) 
 ((|constructor| (NIL "This domains implements finite rational divisors on an hyperelliptic curve, that is finite formal sums SUM(n * \\spad{P)} where the \\spad{n's} are integers and the \\spad{P's} are finite rational points on the curve. The equation of the curve must be \\spad{y^2} = f(x) and \\spad{f} must have odd degree."))) 
 NIL 
 NIL 
-(-500 BP) 
+(-520 BP) 
 ((|constructor| (NIL "This package provides the functions for the heuristic integer gcd. Geddes's algorithm,for univariate polynomials with integer coefficients")) (|lintgcd| (((|Integer|) (|List| (|Integer|))) "\\spad{lintgcd([a1,..,ak])} = \\spad{gcd} of a list of integers")) (|content| (((|List| (|Integer|)) (|List| |#1|)) "\\spad{content([f1,..,fk])} = content of a list of univariate polynonials")) (|gcdcofactprim| (((|List| |#1|) (|List| |#1|)) "\\spad{gcdcofactprim([f1,..fk])} = \\spad{gcd} and cofactors of \\spad{k} primitive polynomials.")) (|gcdcofact| (((|List| |#1|) (|List| |#1|)) "\\spad{gcdcofact([f1,..fk])} = \\spad{gcd} and cofactors of \\spad{k} univariate polynomials.")) (|gcdprim| ((|#1| (|List| |#1|)) "\\spad{gcdprim([f1,..,fk])} = \\spad{gcd} of \\spad{k} PRIMITIVE univariate polynomials")) (|gcd| ((|#1| (|List| |#1|)) "\\indented{1}{gcd([f1,..,fk]) = \\spad{gcd} of the polynomials fi.} \\blankline \\spad{X} gcd([671*671*x^2-1,671*671*x^2+2*671*x+1]) \\spad{X} gcd([7*x^2+1,(7*x^2+1)^2])"))) 
 NIL 
 NIL 
-(-501) 
+(-521) 
 ((|constructor| (NIL "This domain allows rational numbers to be presented as repeating hexadecimal expansions.")) (|hex| (($ (|Fraction| (|Integer|))) "\\spad{hex(r)} converts a rational number to a hexadecimal expansion.")) (|fractionPart| (((|Fraction| (|Integer|)) $) "\\spad{fractionPart(h)} returns the fractional part of a hexadecimal expansion.")) (|coerce| (((|RadixExpansion| 16) $) "\\spad{coerce(h)} converts a hexadecimal expansion to a radix expansion with base 16.") (((|Fraction| (|Integer|)) $) "\\spad{coerce(h)} converts a hexadecimal expansion to a rational number."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-572) (QUOTE (-910))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-572) (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-151))) (|HasCategory| (-572) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-572) (QUOTE (-1028))) (|HasCategory| (-572) (QUOTE (-821))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1144))) (|HasCategory| (-572) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| (-572) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| (-572) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| (-572) (QUOTE (-227))) (|HasCategory| (-572) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-572) (LIST (QUOTE -527) (QUOTE (-1170)) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -283) (QUOTE (-572)) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-303))) (|HasCategory| (-572) (QUOTE (-554))) (|HasCategory| (-572) (QUOTE (-848))) (-1841 (|HasCategory| (-572) (QUOTE (-821))) (|HasCategory| (-572) (QUOTE (-848)))) (|HasCategory| (-572) (LIST (QUOTE -634) (QUOTE (-572)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-910)))) (|HasCategory| (-572) (QUOTE (-149))))) 
-(-502 A S) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-592) (QUOTE (-931))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-592) (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-171))) (|HasCategory| (-592) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-592) (QUOTE (-1049))) (|HasCategory| (-592) (QUOTE (-842))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1165))) (|HasCategory| (-592) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| (-592) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| (-592) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| (-592) (QUOTE (-247))) (|HasCategory| (-592) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-592) (LIST (QUOTE -547) (QUOTE (-1191)) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -303) (QUOTE (-592)) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-323))) (|HasCategory| (-592) (QUOTE (-574))) (|HasCategory| (-592) (QUOTE (-869))) (-3836 (|HasCategory| (-592) (QUOTE (-842))) (|HasCategory| (-592) (QUOTE (-869)))) (|HasCategory| (-592) (LIST (QUOTE -654) (QUOTE (-592)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-931)))) (|HasCategory| (-592) (QUOTE (-169))))) 
+(-522 A S) 
 ((|constructor| (NIL "A homogeneous aggregate is an aggregate of elements all of the same type. In the current system, all aggregates are homogeneous. Two attributes characterize classes of aggregates. Aggregates from domains with attribute \\spadatt{finiteAggregate} have a finite number of members. Those with attribute \\spadatt{shallowlyMutable} allow an element to be modified or updated without changing its overall value.")) (|member?| (((|Boolean|) |#2| $) "\\spad{member?(x,u)} tests if \\spad{x} is a member of u. For collections, \\axiom{member?(x,u) = reduce(or,[x=y for \\spad{y} in u],false)}.")) (|members| (((|List| |#2|) $) "\\spad{members(u)} returns a list of the consecutive elements of u. For collections, \\axiom{parts([x,y,...,z]) = (x,y,...,z)}.")) (|parts| (((|List| |#2|) $) "\\spad{parts(u)} returns a list of the consecutive elements of u. For collections, \\axiom{parts([x,y,...,z]) = (x,y,...,z)}.")) (|count| (((|NonNegativeInteger|) |#2| $) "\\spad{count(x,u)} returns the number of occurrences of \\spad{x} in u. For collections, \\axiom{count(x,u) = reduce(+,[x=y for \\spad{y} in u],0)}.") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#2|) $) "\\spad{count(p,u)} returns the number of elements \\spad{x} in \\spad{u} such that \\axiom{p(x)} is true. For collections, \\axiom{count(p,u) = \\spad{reduce(+,[1} for \\spad{x} in \\spad{u} | p(x)],0)}.")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#2|) $) "\\spad{every?(f,u)} tests if p(x) is \\spad{true} for all elements \\spad{x} of u. Note that for collections, \\axiom{every?(p,u) = reduce(and,map(f,u),true,false)}.")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#2|) $) "\\spad{any?(p,u)} tests if \\axiom{p(x)} is \\spad{true} for any element \\spad{x} of u. Note that for collections, \\axiom{any?(p,u) = reduce(or,map(f,u),false,true)}.")) (|map!| (($ (|Mapping| |#2| |#2|) $) "\\spad{map!(f,u)} destructively replaces each element \\spad{x} of \\spad{u} by \\axiom{f(x)}.")) (|map| (($ (|Mapping| |#2| |#2|) $) "\\spad{map(f,u)} returns a copy of \\spad{u} with each element \\spad{x} replaced by f(x). For collections, \\axiom{map(f,u) = [f(x) for \\spad{x} in u]}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4602)) (|HasAttribute| |#1| (QUOTE -4603)) (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) 
-(-503 S) 
+((|HasAttribute| |#1| (QUOTE -4625)) (|HasAttribute| |#1| (QUOTE -4626)) (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) 
+(-523 S) 
 ((|constructor| (NIL "A homogeneous aggregate is an aggregate of elements all of the same type. In the current system, all aggregates are homogeneous. Two attributes characterize classes of aggregates. Aggregates from domains with attribute \\spadatt{finiteAggregate} have a finite number of members. Those with attribute \\spadatt{shallowlyMutable} allow an element to be modified or updated without changing its overall value.")) (|member?| (((|Boolean|) |#1| $) "\\spad{member?(x,u)} tests if \\spad{x} is a member of u. For collections, \\axiom{member?(x,u) = reduce(or,[x=y for \\spad{y} in u],false)}.")) (|members| (((|List| |#1|) $) "\\spad{members(u)} returns a list of the consecutive elements of u. For collections, \\axiom{parts([x,y,...,z]) = (x,y,...,z)}.")) (|parts| (((|List| |#1|) $) "\\spad{parts(u)} returns a list of the consecutive elements of u. For collections, \\axiom{parts([x,y,...,z]) = (x,y,...,z)}.")) (|count| (((|NonNegativeInteger|) |#1| $) "\\spad{count(x,u)} returns the number of occurrences of \\spad{x} in u. For collections, \\axiom{count(x,u) = reduce(+,[x=y for \\spad{y} in u],0)}.") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\spad{count(p,u)} returns the number of elements \\spad{x} in \\spad{u} such that \\axiom{p(x)} is true. For collections, \\axiom{count(p,u) = \\spad{reduce(+,[1} for \\spad{x} in \\spad{u} | p(x)],0)}.")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\spad{every?(f,u)} tests if p(x) is \\spad{true} for all elements \\spad{x} of u. Note that for collections, \\axiom{every?(p,u) = reduce(and,map(f,u),true,false)}.")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\spad{any?(p,u)} tests if \\axiom{p(x)} is \\spad{true} for any element \\spad{x} of u. Note that for collections, \\axiom{any?(p,u) = reduce(or,map(f,u),false,true)}.")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\spad{map!(f,u)} destructively replaces each element \\spad{x} of \\spad{u} by \\axiom{f(x)}.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f,u)} returns a copy of \\spad{u} with each element \\spad{x} replaced by f(x). For collections, \\axiom{map(f,u) = [f(x) for \\spad{x} in u]}."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-504) 
+(-524) 
 ((|constructor| (NIL "HtmlFormat provides a coercion from OutputForm to html.")) (|display| (((|Void|) (|String|)) "\\indented{1}{display(o) prints the string returned by coerce.} \\blankline \\spad{X} display(coerce(sqrt(3+x)::OutputForm)$HTMLFORM)$HTMLFORM")) (|exprex| (((|String|) (|OutputForm|)) "\\indented{1}{exprex(o) coverts \\spadtype{OutputForm} to \\spadtype{String}} \\blankline \\spad{X} exprex(sqrt(3+x)::OutputForm)$HTMLFORM")) (|coerceL| (((|String|) (|OutputForm|)) "\\indented{1}{coerceL(o) changes \\spad{o} in the standard output format to html} \\indented{1}{format and displays result as one long string.} \\blankline \\spad{X} coerceL(sqrt(3+x)::OutputForm)$HTMLFORM")) (|coerceS| (((|String|) (|OutputForm|)) "\\indented{1}{coerceS(o) changes \\spad{o} in the standard output format to html} \\indented{1}{format and displays formatted result.} \\blankline \\spad{X} coerceS(sqrt(3+x)::OutputForm)$HTMLFORM")) (|coerce| (((|String|) (|OutputForm|)) "\\indented{1}{coerce(o) changes \\spad{o} in the standard output format to html format.} \\blankline \\spad{X} coerce(sqrt(3+x)::OutputForm)$HTMLFORM"))) 
 NIL 
 NIL 
-(-505 S) 
+(-525 S) 
 ((|constructor| (NIL "\\indented{1}{Date Last Updated: 14 May 1991} Category for the hyperbolic trigonometric functions.")) (|tanh| (($ $) "\\spad{tanh(x)} returns the hyperbolic tangent of \\spad{x.}")) (|sinh| (($ $) "\\spad{sinh(x)} returns the hyperbolic sine of \\spad{x.}")) (|sech| (($ $) "\\spad{sech(x)} returns the hyperbolic secant of \\spad{x.}")) (|csch| (($ $) "\\spad{csch(x)} returns the hyperbolic cosecant of \\spad{x.}")) (|coth| (($ $) "\\spad{coth(x)} returns the hyperbolic cotangent of \\spad{x.}")) (|cosh| (($ $) "\\spad{cosh(x)} returns the hyperbolic cosine of \\spad{x.}"))) 
 NIL 
 NIL 
-(-506) 
+(-526) 
 ((|constructor| (NIL "\\indented{1}{Date Last Updated: 14 May 1991} Category for the hyperbolic trigonometric functions.")) (|tanh| (($ $) "\\spad{tanh(x)} returns the hyperbolic tangent of \\spad{x.}")) (|sinh| (($ $) "\\spad{sinh(x)} returns the hyperbolic sine of \\spad{x.}")) (|sech| (($ $) "\\spad{sech(x)} returns the hyperbolic secant of \\spad{x.}")) (|csch| (($ $) "\\spad{csch(x)} returns the hyperbolic cosecant of \\spad{x.}")) (|coth| (($ $) "\\spad{coth(x)} returns the hyperbolic cotangent of \\spad{x.}")) (|cosh| (($ $) "\\spad{cosh(x)} returns the hyperbolic cosine of \\spad{x.}"))) 
 NIL 
 NIL 
-(-507 -3313 UP |AlExt| |AlPol|) 
+(-527 -3958 UP |AlExt| |AlPol|) 
 ((|constructor| (NIL "Factorisation in a simple algebraic extension Factorization of univariate polynomials with coefficients in an algebraic extension of a field over which we can factor UP's.")) (|factor| (((|Factored| |#4|) |#4| (|Mapping| (|Factored| |#2|) |#2|)) "\\spad{factor(p, \\spad{f)}} returns a prime factorisation of \\spad{p;} \\spad{f} is a factorisation map for elements of UP."))) 
 NIL 
 NIL 
-(-508) 
+(-528) 
 ((|constructor| (NIL "Algebraic closure of the rational numbers.")) (|norm| (($ $ (|List| (|Kernel| $))) "\\spad{norm(f,l)} computes the norm of the algebraic number \\spad{f} with respect to the extension generated by kernels \\spad{l}") (($ $ (|Kernel| $)) "\\spad{norm(f,k)} computes the norm of the algebraic number \\spad{f} with respect to the extension generated by kernel \\spad{k}") (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|List| (|Kernel| $))) "\\spad{norm(p,l)} computes the norm of the polynomial \\spad{p} with respect to the extension generated by kernels \\spad{l}") (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|Kernel| $)) "\\spad{norm(p,k)} computes the norm of the polynomial \\spad{p} with respect to the extension generated by kernel \\spad{k}")) (|trueEqual| (((|Boolean|) $ $) "\\spad{trueEqual(x,y)} tries to determine if the two numbers are equal")) (|reduce| (($ $) "\\spad{reduce(f)} simplifies all the unreduced algebraic numbers present in \\spad{f} by applying their defining relations.")) (|denom| (((|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $)) $) "\\spad{denom(f)} returns the denominator of \\spad{f} viewed as a polynomial in the kernels over \\spad{Z.}")) (|numer| (((|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $)) $) "\\spad{numer(f)} returns the numerator of \\spad{f} viewed as a polynomial in the kernels over \\spad{Z.}")) (|coerce| (($ (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $))) "\\spad{coerce(p)} returns \\spad{p} viewed as an algebraic number."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| $ (QUOTE (-1054))) (|HasCategory| $ (LIST (QUOTE -1044) (QUOTE (-572))))) 
-(-509 S |mn|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| $ (QUOTE (-1075))) (|HasCategory| $ (LIST (QUOTE -1065) (QUOTE (-592))))) 
+(-529 S |mn|) 
 ((|constructor| (NIL "This is the basic one dimensional array data type."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-510 R |mnRow| |mnCol|) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-530 R |mnRow| |mnCol|) 
 ((|constructor| (NIL "This domain implements two dimensional arrays"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-511 K R UP) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-531 K R UP) 
 ((|constructor| (NIL "This package has no description")) (|chineseRemainder| (((|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|))) (|List| |#3|) (|List| (|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|)))) (|NonNegativeInteger|)) "\\spad{chineseRemainder(lu,lr,n)} \\undocumented")) (|listConjugateBases| (((|List| (|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|)))) (|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|))) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{listConjugateBases(bas,q,n)} returns the list \\spad{[bas,bas^Frob,bas^(Frob^2),...bas^(Frob^(n-1))]}, where \\spad{Frob} raises the coefficients of all polynomials appearing in the basis \\spad{bas} to the \\spad{q}th power.")) (|factorList| (((|List| (|SparseUnivariatePolynomial| |#1|)) |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{factorList(k,n,m,j)} \\undocumented"))) 
 NIL 
 NIL 
-(-512 R UP -3313) 
+(-532 R UP -3958) 
 ((|constructor| (NIL "This package contains functions used in the packages FunctionFieldIntegralBasis and NumberFieldIntegralBasis.")) (|moduleSum| (((|Record| (|:| |basis| (|Matrix| |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (|Matrix| |#1|))) (|Record| (|:| |basis| (|Matrix| |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (|Matrix| |#1|))) (|Record| (|:| |basis| (|Matrix| |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (|Matrix| |#1|)))) "\\spad{moduleSum(m1,m2)} returns the sum of two modules in the framed algebra \\spad{F}. Each module \\spad{mi} is represented as follows: \\spad{F} is a framed algebra with R-module basis \\spad{w1,w2,...,wn} and \\spad{mi} is a record \\spad{[basis,basisDen,basisInv]}. If \\spad{basis} is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then a basis \\spad{v1,...,vn} for \\spad{mi} is given by \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of 'basis' contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if \\spad{basisInv} is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}.")) (|idealiserMatrix| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{idealiserMatrix(m1, m2)} returns the matrix representing the linear conditions on the Ring associatied with an ideal defined by \\spad{m1} and \\spad{m2.}")) (|idealiser| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) |#1|) "\\spad{idealiser(m1,m2,d)} computes the order of an ideal defined by \\spad{m1} and \\spad{m2} where \\spad{d} is the known part of the denominator") (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{idealiser(m1,m2)} computes the order of an ideal defined by \\spad{m1} and \\spad{m2}")) (|leastPower| (((|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{leastPower(p,n)} returns e, where \\spad{e} is the smallest integer such that \\spad{p **e \\spad{>=} \\spad{n}}")) (|divideIfCan!| ((|#1| (|Matrix| |#1|) (|Matrix| |#1|) |#1| (|Integer|)) "\\spad{divideIfCan!(matrix,matrixOut,prime,n)} attempts to divide the entries of \\spad{matrix} by \\spad{prime} and store the result in \\spad{matrixOut}. If it is successful, 1 is returned and if not, \\spad{prime} is returned. Here both \\spad{matrix} and \\spad{matrixOut} are \\spad{n}-by-\\spad{n} upper triangular matrices.")) (|matrixGcd| ((|#1| (|Matrix| |#1|) |#1| (|NonNegativeInteger|)) "\\spad{matrixGcd(mat,sing,n)} is \\spad{gcd(sing,g)} where \\spad{g} is the \\spad{gcd} of the entries of the \\spad{n}-by-\\spad{n} upper-triangular matrix \\spad{mat}.")) (|diagonalProduct| ((|#1| (|Matrix| |#1|)) "\\spad{diagonalProduct(m)} returns the product of the elements on the diagonal of the matrix \\spad{m}")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(x)} returns a square-free factorisation of \\spad{x}"))) 
 NIL 
 NIL 
-(-513 |mn|) 
+(-533 |mn|) 
 ((|constructor| (NIL "\\spadtype{IndexedBits} is a domain to compactly represent large quantities of Boolean data.")) (|And| (($ $ $) "\\spad{And(n,m)} returns the bit-by-bit logical And of \\spad{n} and \\spad{m.}")) (|Or| (($ $ $) "\\spad{Or(n,m)} returns the bit-by-bit logical Or of \\spad{n} and \\spad{m.}")) (|Not| (($ $) "\\spad{Not(n)} returns the bit-by-bit logical Not of \\spad{n.}"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-121) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-121) (QUOTE (-848))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-121) (QUOTE (-1098))) (-12 (|HasCategory| (-121) (LIST (QUOTE -305) (QUOTE (-121)))) (|HasCategory| (-121) (QUOTE (-1098))))) 
-(-514 K R UP L) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-141) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-141) (QUOTE (-869))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-141) (QUOTE (-1119))) (-12 (|HasCategory| (-141) (LIST (QUOTE -325) (QUOTE (-141)))) (|HasCategory| (-141) (QUOTE (-1119))))) 
+(-534 K R UP L) 
 ((|constructor| (NIL "IntegralBasisPolynomialTools provides functions for mapping functions on the coefficients of univariate and bivariate polynomials.")) (|mapBivariate| (((|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#4|)) (|Mapping| |#4| |#1|) |#3|) "\\spad{mapBivariate(f,p(x,y))} applies the function \\spad{f} to the coefficients of \\spad{p(x,y)}.")) (|mapMatrixIfCan| (((|Union| (|Matrix| |#2|) "failed") (|Mapping| (|Union| |#1| "failed") |#4|) (|Matrix| (|SparseUnivariatePolynomial| |#4|))) "\\spad{mapMatrixIfCan(f,mat)} applies the function \\spad{f} to the coefficients of the entries of \\spad{mat} if possible, and returns \\spad{\"failed\"} otherwise.")) (|mapUnivariateIfCan| (((|Union| |#2| "failed") (|Mapping| (|Union| |#1| "failed") |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{mapUnivariateIfCan(f,p(x))} applies the function \\spad{f} to the coefficients of \\spad{p(x)}, if possible, and returns \\spad{\"failed\"} otherwise.")) (|mapUnivariate| (((|SparseUnivariatePolynomial| |#4|) (|Mapping| |#4| |#1|) |#2|) "\\spad{mapUnivariate(f,p(x))} applies the function \\spad{f} to the coefficients of \\spad{p(x)}.") ((|#2| (|Mapping| |#1| |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{mapUnivariate(f,p(x))} applies the function \\spad{f} to the coefficients of \\spad{p(x)}."))) 
 NIL 
 NIL 
-(-515) 
+(-535) 
 ((|constructor| (NIL "This domain implements a container of information about the AXIOM library")) (|coerce| (($ (|String|)) "\\spad{coerce(s)} converts \\axiom{s} into an \\axiom{IndexCard}. Warning: if \\axiom{s} is not of the right format then an error will occur")) (|fullDisplay| (((|Void|) $) "\\spad{fullDisplay(ic)} prints all of the information contained in \\axiom{ic}.")) (|display| (((|Void|) $) "\\spad{display(ic)} prints a summary of information contained in \\axiom{ic}.")) (|elt| (((|String|) $ (|Symbol|)) "\\spad{elt(ic,s)} selects a particular field from \\axiom{ic}. Valid fields are \\axiom{name, nargs, exposed, type, abbreviation, kind, origin, params, condition, doc}."))) 
 NIL 
 NIL 
-(-516 R Q A B) 
+(-536 R Q A B) 
 ((|constructor| (NIL "InnerCommonDenominator provides functions to compute the common denominator of a finite linear aggregate of elements of the quotient field of an integral domain.")) (|splitDenominator| (((|Record| (|:| |num| |#3|) (|:| |den| |#1|)) |#4|) "\\spad{splitDenominator([q1,...,qn])} returns \\spad{[[p1,...,pn], \\spad{d]}} such that \\spad{qi = pi/d} and \\spad{d} is a common denominator for the qi's.")) (|clearDenominator| ((|#3| |#4|) "\\spad{clearDenominator([q1,...,qn])} returns \\spad{[p1,...,pn]} such that \\spad{qi = pi/d} where \\spad{d} is a common denominator for the qi's.")) (|commonDenominator| ((|#1| |#4|) "\\spad{commonDenominator([q1,...,qn])} returns a common denominator \\spad{d} for q1,...,qn."))) 
 NIL 
 NIL 
-(-517 K |symb| BLMET) 
+(-537 K |symb| BLMET) 
 ((|constructor| (NIL "This domain is part of the PAFF package")) (|fullOutput| (((|Boolean|)) "\\spad{fullOutput returns} the value of the flag set by fullOutput(b).") (((|Boolean|) (|Boolean|)) "\\spad{fullOutput(b)} sets a flag such that when true, a coerce to OutputForm yields the full output of \\spad{tr,} otherwise encode(tr) is output (see encode function). The default is false.")) (|fullOut| (((|OutputForm|) $) "\\spad{fullOut(tr)} yields a full output of \\spad{tr} (see function fullOutput)."))) 
 NIL 
 NIL 
-(-518 -3313 |Expon| |VarSet| |DPoly|) 
+(-538 -3958 |Expon| |VarSet| |DPoly|) 
 ((|constructor| (NIL "This domain represents polynomial ideals with coefficients in any field and supports the basic ideal operations, including intersection sum and quotient. An ideal is represented by a list of polynomials (the generators of the ideal) and a boolean that is \\spad{true} if the generators are a Groebner basis. The algorithms used are based on Groebner basis computations. The ordering is determined by the datatype of the input polynomials. Users may use refinements of total degree orderings.")) (|relationsIdeal| (((|SuchThat| (|List| (|Polynomial| |#1|)) (|List| (|Equation| (|Polynomial| |#1|)))) (|List| |#4|)) "\\spad{relationsIdeal(polyList)} returns the ideal of relations among the polynomials in polyList.")) (|saturate| (($ $ |#4| (|List| |#3|)) "\\spad{saturate(I,f,lvar)} is the saturation with respect to the prime principal ideal which is generated by \\spad{f} in the polynomial ring \\spad{F[lvar]}.") (($ $ |#4|) "\\spad{saturate(I,f)} is the saturation of the ideal \\spad{I} with respect to the multiplicative set generated by the polynomial \\spad{f.}")) (|coerce| (($ (|List| |#4|)) "\\spad{coerce(polyList)} converts the list of polynomials \\spad{polyList} to an ideal.")) (|generators| (((|List| |#4|) $) "\\spad{generators(I)} returns a list of generators for the ideal I.")) (|groebner?| (((|Boolean|) $) "\\spad{groebner?(I)} tests if the generators of the ideal \\spad{I} are a Groebner basis.")) (|groebnerIdeal| (($ (|List| |#4|)) "\\spad{groebnerIdeal(polyList)} constructs the ideal generated by the list of polynomials \\spad{polyList} which are assumed to be a Groebner basis. Note: this operation avoids a Groebner basis computation.")) (|ideal| (($ (|List| |#4|)) "\\spad{ideal(polyList)} constructs the ideal generated by the list of polynomials polyList.")) (|leadingIdeal| (($ $) "\\spad{leadingIdeal(I)} is the ideal generated by the leading terms of the elements of the ideal I.")) (|dimension| (((|Integer|) $) "\\spad{dimension(I)} gives the dimension of the ideal I. in the ring \\spad{F[lvar]}, where lvar are the variables appearing in \\spad{I}") (((|Integer|) $ (|List| |#3|)) "\\spad{dimension(I,lvar)} gives the dimension of the ideal I, in the ring \\spad{F[lvar]}")) (|backOldPos| (($ (|Record| (|:| |mval| (|Matrix| |#1|)) (|:| |invmval| (|Matrix| |#1|)) (|:| |genIdeal| $))) "\\spad{backOldPos(genPos)} takes the result produced by generalPosition from PolynomialIdeals and performs the inverse transformation, returning the original ideal \\spad{backOldPos(generalPosition(I,listvar))} = I.")) (|generalPosition| (((|Record| (|:| |mval| (|Matrix| |#1|)) (|:| |invmval| (|Matrix| |#1|)) (|:| |genIdeal| $)) $ (|List| |#3|)) "\\spad{generalPosition(I,listvar)} perform a random linear transformation on the variables in \\spad{listvar} and returns the transformed ideal along with the change of basis matrix.")) (|groebner| (($ $) "\\spad{groebner(I)} returns a set of generators of \\spad{I} that are a Groebner basis for I.")) (|quotient| (($ $ |#4|) "\\spad{quotient(I,f)} computes the quotient of the ideal \\spad{I} by the principal ideal generated by the polynomial \\spad{f,} \\spad{(I:(f))}.") (($ $ $) "\\spad{quotient(I,J)} computes the quotient of the ideals \\spad{I} and \\spad{J,} \\spad{(I:J)}.")) (|intersect| (($ (|List| $)) "\\spad{intersect(LI)} computes the intersection of the list of ideals LI.") (($ $ $) "\\spad{intersect(I,J)} computes the intersection of the ideals \\spad{I} and \\spad{J.}")) (|zeroDim?| (((|Boolean|) $) "\\spad{zeroDim?(I)} tests if the ideal \\spad{I} is zero dimensional, \\spadignore{i.e.} all its associated primes are maximal, in the ring \\spad{F[lvar]}, where lvar are the variables appearing in \\spad{I}") (((|Boolean|) $ (|List| |#3|)) "\\spad{zeroDim?(I,lvar)} tests if the ideal \\spad{I} is zero dimensional, \\spadignore{i.e.} all its associated primes are maximal, in the ring \\spad{F[lvar]}")) (|inRadical?| (((|Boolean|) |#4| $) "\\spad{inRadical?(f,I)} tests if some power of the polynomial \\spad{f} belongs to the ideal I.")) (|in?| (((|Boolean|) $ $) "\\spad{in?(I,J)} tests if the ideal \\spad{I} is contained in the ideal \\spad{J.}")) (|element?| (((|Boolean|) |#4| $) "\\spad{element?(f,I)} tests whether the polynomial \\spad{f} belongs to the ideal I.")) (|zero?| (((|Boolean|) $) "\\spad{zero?(I)} tests whether the ideal \\spad{I} is the zero ideal")) (|one?| (((|Boolean|) $) "\\spad{one?(I)} tests whether the ideal \\spad{I} is the unit ideal, \\spadignore{i.e.} contains 1.")) (+ (($ $ $) "\\spad{I+J} computes the ideal generated by the union of \\spad{I} and \\spad{J.}")) (** (($ $ (|NonNegativeInteger|)) "\\spad{I**n} computes the \\spad{n}th power of the ideal I.")) (* (($ $ $) "\\spad{I*J} computes the product of the ideal \\spad{I} and \\spad{J.}"))) 
 NIL 
-((|HasCategory| |#3| (LIST (QUOTE -613) (QUOTE (-1170))))) 
-(-519 |vl| |nv|) 
+((|HasCategory| |#3| (LIST (QUOTE -633) (QUOTE (-1191))))) 
+(-539 |vl| |nv|) 
 ((|constructor| (NIL "This package provides functions for the primary decomposition of polynomial ideals over the rational numbers. The ideals are members of the \\spadtype{PolynomialIdeals} domain, and the polynomial generators are required to be from the \\spadtype{DistributedMultivariatePolynomial} domain.")) (|contract| (((|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|)))) (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|)))) (|List| (|OrderedVariableList| |#1|))) "\\spad{contract(I,lvar)} contracts the ideal \\spad{I} to the polynomial ring \\spad{F[lvar]}.")) (|primaryDecomp| (((|List| (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|))))) (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|))))) "\\spad{primaryDecomp(I)} returns a list of primary ideals such that their intersection is the ideal I.")) (|radical| (((|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|)))) (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|))))) "\\spad{radical(I)} returns the radical of the ideal I.")) (|prime?| (((|Boolean|) (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|))))) "\\spad{prime?(I)} tests if the ideal \\spad{I} is prime.")) (|zeroDimPrimary?| (((|Boolean|) (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|))))) "\\spad{zeroDimPrimary?(I)} tests if the ideal \\spad{I} is 0-dimensional primary.")) (|zeroDimPrime?| (((|Boolean|) (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|OrderedVariableList| |#1|) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|))))) "\\spad{zeroDimPrime?(I)} tests if the ideal \\spad{I} is a 0-dimensional prime."))) 
 NIL 
 NIL 
-(-520 A S) 
+(-540 A S) 
 ((|constructor| (NIL "Indexed direct products of abelian groups over an abelian group \\spad{A} of generators indexed by the ordered set \\spad{S.} All items have finite support: only non-zero terms are stored."))) 
 NIL 
 NIL 
-(-521 A S) 
+(-541 A S) 
 ((|constructor| (NIL "Indexed direct products of abelian monoids over an abelian monoid \\spad{A} of generators indexed by the ordered set \\spad{S.} All items have finite support. Only non-zero terms are stored."))) 
 NIL 
 NIL 
-(-522 A S) 
+(-542 A S) 
 ((|constructor| (NIL "This category represents the direct product of some set with respect to an ordered indexing set.")) (|reductum| (($ $) "\\spad{reductum(z)} returns a new element created by removing the leading coefficient/support pair from the element \\spad{z.} Error: if \\spad{z} has no support.")) (|leadingSupport| ((|#2| $) "\\spad{leadingSupport(z)} returns the index of leading (with respect to the ordering on the indexing set) monomial of \\spad{z.} Error: if \\spad{z} has no support.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(z)} returns the coefficient of the leading (with respect to the ordering on the indexing set) monomial of \\spad{z.} Error: if \\spad{z} has no support.")) (|monomial| (($ |#1| |#2|) "\\spad{monomial(a,s)} constructs a direct product element with the \\spad{s} component set to \\spad{a}")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f,z)} returns the new element created by applying the function \\spad{f} to each component of the direct product element \\spad{z.}"))) 
 NIL 
 NIL 
-(-523 A S) 
+(-543 A S) 
 ((|constructor| (NIL "Indexed direct products of ordered abelian monoids \\spad{A} of generators indexed by the ordered set \\spad{S.} The inherited order is lexicographical. All items have finite support: only non-zero terms are stored."))) 
 NIL 
 NIL 
-(-524 A S) 
+(-544 A S) 
 ((|constructor| (NIL "Indexed direct products of ordered abelian monoid sups \\spad{A}, generators indexed by the ordered set \\spad{S.} All items have finite support: only non-zero terms are stored."))) 
 NIL 
 NIL 
-(-525 A S) 
+(-545 A S) 
 ((|constructor| (NIL "Indexed direct products of objects over a set \\spad{A} of generators indexed by an ordered set \\spad{S.} All items have finite support."))) 
 NIL 
 NIL 
-(-526 S A B) 
+(-546 S A B) 
 ((|constructor| (NIL "This category provides \\spadfun{eval} operations. A domain may belong to this category if it is possible to make ``evaluation'' substitutions. The difference between this and \\spadtype{Evalable} is that the operations in this category specify the substitution as a pair of arguments rather than as an equation.")) (|eval| (($ $ (|List| |#2|) (|List| |#3|)) "\\spad{eval(f, [x1,...,xn], [v1,...,vn])} replaces \\spad{xi} by \\spad{vi} in \\spad{f.}") (($ $ |#2| |#3|) "\\spad{eval(f, \\spad{x,} \\spad{v)}} replaces \\spad{x} by \\spad{v} in \\spad{f.}"))) 
 NIL 
 NIL 
-(-527 A B) 
+(-547 A B) 
 ((|constructor| (NIL "This category provides \\spadfun{eval} operations. A domain may belong to this category if it is possible to make ``evaluation'' substitutions. The difference between this and \\spadtype{Evalable} is that the operations in this category specify the substitution as a pair of arguments rather than as an equation.")) (|eval| (($ $ (|List| |#1|) (|List| |#2|)) "\\spad{eval(f, [x1,...,xn], [v1,...,vn])} replaces \\spad{xi} by \\spad{vi} in \\spad{f.}") (($ $ |#1| |#2|) "\\spad{eval(f, \\spad{x,} \\spad{v)}} replaces \\spad{x} by \\spad{v} in \\spad{f.}"))) 
 NIL 
 NIL 
-(-528 S E |un|) 
+(-548 S E |un|) 
 ((|constructor| (NIL "Internal implementation of a free abelian monoid on any set of generators"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-793)))) 
-(-529 S |mn|) 
+((|HasCategory| |#2| (QUOTE (-814)))) 
+(-549 S |mn|) 
 ((|constructor| (NIL "A FlexibleArray is the notion of an array intended to allow for growth at the end only. Hence the following efficient operations\\br \\spad{append(x,a)} meaning append item \\spad{x} at the end of the array \\spad{a}\\br \\spad{delete(a,n)} meaning delete the last item from the array \\spad{a}\\br Flexible arrays support the other operations inherited from \\spadtype{ExtensibleLinearAggregate}. However, these are not efficient. Flexible arrays combine the \\spad{O(1)} access time property of arrays with growing and shrinking at the end in \\spad{O(1)} (average) time. This is done by using an ordinary array which may have zero or more empty slots at the end. When the array becomes full it is copied into a new larger (50% larger) array. Conversely, when the array becomes less than 1/2 full, it is copied into a smaller array. Flexible arrays provide for an efficient implementation of many data structures in particular heaps, stacks and sets.")) (|shrinkable| (((|Boolean|) (|Boolean|)) "\\indented{1}{shrinkable(b) sets the shrinkable attribute of flexible arrays to \\spad{b}} \\indented{1}{and returns the previous value} \\blankline \\spad{X} T1:=IndexedFlexibleArray(Integer,20) \\spad{X} \\spad{shrinkable(false)$T1}")) (|physicalLength!| (($ $ (|Integer|)) "\\indented{1}{physicalLength!(x,n) changes the physical length of \\spad{x} to be \\spad{n} and} \\indented{1}{returns the new array.} \\blankline \\spad{X} T1:=IndexedFlexibleArray(Integer,20) \\spad{X} t2:=flexibleArray([i for \\spad{i} in 1..10])$T1 \\spad{X} physicalLength!(t2,15)")) (|physicalLength| (((|NonNegativeInteger|) $) "\\indented{1}{physicalLength(x) returns the number of elements \\spad{x} can} \\indented{1}{accomodate before growing} \\blankline \\spad{X} T1:=IndexedFlexibleArray(Integer,20) \\spad{X} t2:=flexibleArray([i for \\spad{i} in 1..10])$T1 \\spad{X} physicalLength \\spad{t2}")) (|flexibleArray| (($ (|List| |#1|)) "\\indented{1}{flexibleArray(l) creates a flexible array from the list of elements \\spad{l}} \\blankline \\spad{X} T1:=IndexedFlexibleArray(Integer,20) \\spad{X} flexibleArray([i for \\spad{i} in 1..10])$T1"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-530 |p| |n|) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-550 |p| |n|) 
 ((|constructor| (NIL "InnerFiniteField(p,n) implements finite fields with \\spad{p**n} elements where \\spad{p} is assumed prime but does not check. For a version which checks that \\spad{p} is prime, see \\spadtype{FiniteField}."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-585 |#1|) (QUOTE (-151))) (|HasCategory| (-585 |#1|) (QUOTE (-374))) (|HasCategory| (-585 |#1|) (QUOTE (-149))) (-1841 (|HasCategory| (-585 |#1|) (QUOTE (-149))) (|HasCategory| (-585 |#1|) (QUOTE (-374))))) 
-(-531 R |mnRow| |mnCol| |Row| |Col|) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-605 |#1|) (QUOTE (-171))) (|HasCategory| (-605 |#1|) (QUOTE (-394))) (|HasCategory| (-605 |#1|) (QUOTE (-169))) (-3836 (|HasCategory| (-605 |#1|) (QUOTE (-169))) (|HasCategory| (-605 |#1|) (QUOTE (-394))))) 
+(-551 R |mnRow| |mnCol| |Row| |Col|) 
 ((|constructor| (NIL "There is no description for this domain"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-532 S |mn|) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-552 S |mn|) 
 ((|constructor| (NIL "\\spadtype{IndexedList} is a basic implementation of the functions in \\spadtype{ListAggregate}, often using functions in the underlying LISP system. The second parameter to the constructor (\\spad{mn}) is the beginning index of the list. That is, if \\spad{l} is a list, then \\spad{elt(l,mn)} is the first value. This constructor is probably best viewed as the implementation of singly-linked lists that are addressable by index rather than as a mere wrapper for LISP lists."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-533 R |Row| |Col| M) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-553 R |Row| |Col| M) 
 ((|constructor| (NIL "\\spadtype{InnerMatrixLinearAlgebraFunctions} is an internal package which provides standard linear algebra functions on domains in \\spad{MatrixCategory}")) (|inverse| (((|Union| |#4| "failed") |#4|) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m.} If the matrix is not invertible, \"failed\" is returned. Error: if the matrix is not square.")) (|generalizedInverse| ((|#4| |#4|) "\\spad{generalizedInverse(m)} returns the generalized (Moore--Penrose) inverse of the matrix \\spad{m,} \\spadignore{i.e.} the matrix \\spad{h} such that m*h*m=h, h*m*h=m, \\spad{m*h} and \\spad{h*m} are both symmetric matrices.")) (|determinant| ((|#1| |#4|) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m.} an error message is returned if the matrix is not square.")) (|nullSpace| (((|List| |#3|) |#4|) "\\spad{nullSpace(m)} returns a basis for the null space of the matrix \\spad{m.}")) (|nullity| (((|NonNegativeInteger|) |#4|) "\\spad{nullity(m)} returns the mullity of the matrix \\spad{m.} This is the dimension of the null space of the matrix \\spad{m.}")) (|rank| (((|NonNegativeInteger|) |#4|) "\\spad{rank(m)} returns the rank of the matrix \\spad{m.}")) (|rowEchelon| ((|#4| |#4|) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m.}"))) 
 NIL 
-((|HasAttribute| |#3| (QUOTE -4603))) 
-(-534 R |Row| |Col| M QF |Row2| |Col2| M2) 
+((|HasAttribute| |#3| (QUOTE -4626))) 
+(-554 R |Row| |Col| M QF |Row2| |Col2| M2) 
 ((|constructor| (NIL "\\spadtype{InnerMatrixQuotientFieldFunctions} provides functions on matrices over an integral domain which involve the quotient field of that integral domain. The functions rowEchelon and inverse return matrices with entries in the quotient field.")) (|nullSpace| (((|List| |#3|) |#4|) "\\spad{nullSpace(m)} returns a basis for the null space of the matrix \\spad{m.}")) (|inverse| (((|Union| |#8| "failed") |#4|) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m.} If the matrix is not invertible, \"failed\" is returned. Error: if the matrix is not square. Note that the result will have entries in the quotient field.")) (|rowEchelon| ((|#8| |#4|) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m.} the result will have entries in the quotient field."))) 
 NIL 
-((|HasAttribute| |#7| (QUOTE -4603))) 
-(-535 R |mnRow| |mnCol|) 
+((|HasAttribute| |#7| (QUOTE -4626))) 
+(-555 R |mnRow| |mnCol|) 
 ((|constructor| (NIL "An \\spad{IndexedMatrix} is a matrix where the minimal row and column indices are parameters of the type. The domains Row and Col are both IndexedVectors. The index of the 'first' row may be obtained by calling the function \\spadfun{minRowIndex}. The index of the 'first' column may be obtained by calling the function \\spadfun{minColIndex}. The index of the first element of a 'Row' is the same as the index of the first column in a matrix and vice versa."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-562))) (|HasAttribute| |#1| (QUOTE (-4604 "*"))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-536 GF) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-582))) (|HasAttribute| |#1| (QUOTE (-4627 "*"))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-556 GF) 
 ((|constructor| (NIL "InnerNormalBasisFieldFunctions(GF) (unexposed): This package has functions used by every normal basis finite field extension domain.")) (|minimalPolynomial| (((|SparseUnivariatePolynomial| |#1|) (|Vector| |#1|)) "\\spad{minimalPolynomial(x)} \\undocumented{} See \\axiomFunFrom{minimalPolynomial}{FiniteAlgebraicExtensionField}")) (|normalElement| (((|Vector| |#1|) (|PositiveInteger|)) "\\spad{normalElement(n)} \\undocumented{} See \\axiomFunFrom{normalElement}{FiniteAlgebraicExtensionField}")) (|basis| (((|Vector| (|Vector| |#1|)) (|PositiveInteger|)) "\\spad{basis(n)} \\undocumented{} See \\axiomFunFrom{basis}{FiniteAlgebraicExtensionField}")) (|normal?| (((|Boolean|) (|Vector| |#1|)) "\\spad{normal?(x)} \\undocumented{} See \\axiomFunFrom{normal?}{FiniteAlgebraicExtensionField}")) (|lookup| (((|PositiveInteger|) (|Vector| |#1|)) "\\spad{lookup(x)} \\undocumented{} See \\axiomFunFrom{lookup}{Finite}")) (|inv| (((|Vector| |#1|) (|Vector| |#1|)) "\\spad{inv \\spad{x}} \\undocumented{} See \\axiomFunFrom{inv}{DivisionRing}")) (|trace| (((|Vector| |#1|) (|Vector| |#1|) (|PositiveInteger|)) "\\spad{trace(x,n)} \\undocumented{} See \\axiomFunFrom{trace}{FiniteAlgebraicExtensionField}")) (|norm| (((|Vector| |#1|) (|Vector| |#1|) (|PositiveInteger|)) "\\spad{norm(x,n)} \\undocumented{} See \\axiomFunFrom{norm}{FiniteAlgebraicExtensionField}")) (/ (((|Vector| |#1|) (|Vector| |#1|) (|Vector| |#1|)) "\\spad{x/y} \\undocumented{} See \\axiomFunFrom{/}{Field}")) (* (((|Vector| |#1|) (|Vector| |#1|) (|Vector| |#1|)) "\\spad{x*y} \\undocumented{} See \\axiomFunFrom{*}{SemiGroup}")) (** (((|Vector| |#1|) (|Vector| |#1|) (|Integer|)) "\\spad{x**n} \\undocumented{} See \\axiomFunFrom{**}{DivisionRing}")) (|qPot| (((|Vector| |#1|) (|Vector| |#1|) (|Integer|)) "\\spad{qPot(v,e)} computes \\spad{v**(q**e)}, interpreting \\spad{v} as an element of normal basis field, \\spad{q} the size of the ground field. This is done by a cyclic e-shift of the vector \\spad{v.}")) (|expPot| (((|Vector| |#1|) (|Vector| |#1|) (|SingleInteger|) (|SingleInteger|)) "\\spad{expPot(v,e,d)} returns the sum from \\spad{i = 0} to \\spad{e - 1} of \\spad{v**(q**i*d)}, interpreting \\spad{v} as an element of a normal basis field and where \\spad{q} is the size of the ground field. Note that for a description of the algorithm, see T.Itoh and S.Tsujii, \"A fast algorithm for computing multiplicative inverses in GF(2^m) using normal bases\", Information and Computation 78, pp.171-177, 1988.")) (|repSq| (((|Vector| |#1|) (|Vector| |#1|) (|NonNegativeInteger|)) "\\spad{repSq(v,e)} computes \\spad{v**e} by repeated squaring, interpreting \\spad{v} as an element of a normal basis field.")) (|dAndcExp| (((|Vector| |#1|) (|Vector| |#1|) (|NonNegativeInteger|) (|SingleInteger|)) "\\spad{dAndcExp(v,n,k)} computes \\spad{v**e} interpreting \\spad{v} as an element of normal basis field. A divide and conquer algorithm similar to the one from D.R.Stinson, \"Some observations on parallel Algorithms for fast exponentiation in GF(2^n)\", Siam \\spad{J.} Computation, Vol.19, No.4, pp.711-717, August 1990 is used. Argument \\spad{k} is a parameter of this algorithm.")) (|xn| (((|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|)) "\\spad{xn(n)} returns the polynomial \\spad{x**n-1}.")) (|pol| (((|SparseUnivariatePolynomial| |#1|) (|Vector| |#1|)) "\\spad{pol(v)} turns the vector \\spad{[v0,...,vn]} into the polynomial \\spad{v0+v1*x+ \\spad{...} + vn*x**n}.")) (|index| (((|Vector| |#1|) (|PositiveInteger|) (|PositiveInteger|)) "\\spad{index(n,m)} is a index function for vectors of length \\spad{n} over the ground field.")) (|random| (((|Vector| |#1|) (|PositiveInteger|)) "\\spad{random(n)} creates a vector over the ground field with random entries.")) (|setFieldInfo| (((|Void|) (|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|))))) |#1|) "\\spad{setFieldInfo(m,p)} initializes the field arithmetic, where \\spad{m} is the multiplication table and \\spad{p} is the respective normal element of the ground field \\spad{GF.}"))) 
 NIL 
 NIL 
-(-537 R) 
+(-557 R) 
 ((|constructor| (NIL "This package provides operations to create incrementing functions.")) (|incrementBy| (((|Mapping| |#1| |#1|) |#1|) "\\spad{incrementBy(n)} produces a function which adds \\spad{n} to whatever argument it is given. For example, if \\spad{{f} \\spad{:=} increment(n)} then \\spad{f \\spad{x}} is \\spad{x+n}.")) (|increment| (((|Mapping| |#1| |#1|)) "\\spad{increment()} produces a function which adds \\spad{1} to whatever argument it is given. For example, if \\spad{{f} \\spad{:=} increment()} then \\spad{f \\spad{x}} is \\spad{x+1}."))) 
 NIL 
 NIL 
-(-538 |Varset|) 
+(-558 |Varset|) 
 ((|constructor| (NIL "converts entire exponents to OutputForm"))) 
 NIL 
 NIL 
-(-539 K -3313 |Par|) 
+(-559 K -3958 |Par|) 
 ((|constructor| (NIL "This package is the inner package to be used by NumericRealEigenPackage and NumericComplexEigenPackage for the computation of numeric eigenvalues and eigenvectors.")) (|innerEigenvectors| (((|List| (|Record| (|:| |outval| |#2|) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| |#2|))))) (|Matrix| |#1|) |#3| (|Mapping| (|Factored| (|SparseUnivariatePolynomial| |#1|)) (|SparseUnivariatePolynomial| |#1|))) "\\spad{innerEigenvectors(m,eps,factor)} computes explicitly the eigenvalues and the correspondent eigenvectors of the matrix \\spad{m.} The parameter \\spad{eps} determines the type of the output, \\spad{factor} is the univariate factorizer to \\spad{br} used to reduce the characteristic polynomial into irreducible factors.")) (|solve1| (((|List| |#2|) (|SparseUnivariatePolynomial| |#1|) |#3|) "\\spad{solve1(pol, eps)} finds the roots of the univariate polynomial polynomial \\spad{pol} to precision eps. If \\spad{K} is \\spad{Fraction Integer} then only the real roots are returned, if \\spad{K} is \\spad{Complex Fraction Integer} then all roots are found.")) (|charpol| (((|SparseUnivariatePolynomial| |#1|) (|Matrix| |#1|)) "\\spad{charpol(m)} computes the characteristic polynomial of a matrix \\spad{m} with entries in \\spad{K.} This function returns a polynomial over \\spad{K,} while the general one (that is in EiegenPackage) returns Fraction \\spad{P} \\spad{K}"))) 
 NIL 
 NIL 
-(-540 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR BLMET) 
+(-560 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR BLMET) 
 ((|constructor| (NIL "This category is part of the PAFF package")) (|excpDivV| ((|#8| $) "\\spad{excpDivV returns} the exceptional divisor of the infinitly close point.")) (|chartV| ((|#9| $) "chartV is the chart of the infinitly close point. The first integer correspond to variable defining the exceptional line, the last one the affine neighboorhood and the second one is the remaining integer. For example [1,2,3] means that Z=1, \\spad{X=X} and Y=XY. [2,3,1] means that X=1, \\spad{Y=Y} and Z=YZ.")) (|multV| (((|NonNegativeInteger|) $) "\\spad{multV returns} the multiplicity of the infinitly close point.")) (|localPointV| (((|AffinePlane| |#1|) $) "\\spad{localPointV returns} the coordinates of the local infinitly close point")) (|curveV| (((|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) |#1|) $) "\\spad{curveV(p)} returns the defining polynomial of the strict transform on which lies the corresponding infinitly close point.")) (|pointV| ((|#5| $) "\\spad{pointV returns} the infinitly close point.")) (|create| (($ |#5| (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) |#1|) (|AffinePlane| |#1|) (|NonNegativeInteger|) |#9| (|NonNegativeInteger|) |#8| |#1| (|Symbol|)) "\\spad{create an} infinitly close point"))) 
 NIL 
 NIL 
-(-541 K |symb| BLMET) 
+(-561 K |symb| BLMET) 
 ((|constructor| (NIL "This domain is part of the PAFF package")) (|fullOutput| (((|Boolean|)) "\\spad{fullOutput returns} the value of the flag set by fullOutput(b).") (((|Boolean|) (|Boolean|)) "\\spad{fullOutput(b)} sets a flag such that when true, a coerce to OutputForm \\indented{1}{yields the full output of \\spad{tr,} otherwise encode(tr) is output} (see encode function). The default is false.")) (|fullOut| (((|OutputForm|) $) "\\spad{fullOut(tr)} yields a full output of \\spad{tr} (see function fullOutput)."))) 
 NIL 
 NIL 
-(-542 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR BLMET) 
+(-562 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR BLMET) 
 ((|constructor| (NIL "This domain is part of the PAFF package")) (|fullOutput| (((|Boolean|)) "\\spad{fullOutput returns} the value of the flag set by fullOutput(b).") (((|Boolean|) (|Boolean|)) "\\spad{fullOutput(b)} sets a flag such that when true, a coerce to OutputForm yields the full output of \\spad{tr,} otherwise encode(tr) is output (see encode function). The default is false.")) (|fullOut| (((|OutputForm|) $) "\\spad{fullOut(tr)} yields a full output of \\spad{tr} (see function fullOutput)."))) 
 NIL 
 NIL 
-(-543) 
+(-563) 
 ((|constructor| (NIL "Top-level infinity Default infinity signatures for the interpreter.")) (|minusInfinity| (((|OrderedCompletion| (|Integer|))) "\\spad{minusInfinity()} returns minusInfinity.")) (|plusInfinity| (((|OrderedCompletion| (|Integer|))) "\\spad{plusInfinity()} returns plusIinfinity.")) (|infinity| (((|OnePointCompletion| (|Integer|))) "\\spad{infinity()} returns infinity."))) 
 NIL 
 NIL 
-(-544 R) 
+(-564 R) 
 ((|constructor| (NIL "Tools for manipulating input forms.")) (|interpret| ((|#1| (|InputForm|)) "\\spad{interpret(f)} passes \\spad{f} to the interpreter, and transforms the result into an object of type \\spad{R.}")) (|packageCall| (((|InputForm|) (|Symbol|)) "\\spad{packageCall(f)} returns the input form corresponding to f$R."))) 
 NIL 
 NIL 
-(-545) 
+(-565) 
 ((|constructor| (NIL "Domain of parsed forms which can be passed to the interpreter. This is also the interface between algebra code and facilities in the interpreter.")) (|compile| (((|Symbol|) (|Symbol|) (|List| $)) "\\spad{compile(f, [t1,...,tn])} forces the interpreter to compile the function \\spad{f} with signature \\spad{(t1,...,tn) \\spad{->} \\spad{?}.} returns the symbol \\spad{f} if successful. Error: if \\spad{f} was not defined beforehand in the interpreter, or if the ti's are not valid types, or if the compiler fails.")) (|declare| (((|Symbol|) (|List| $)) "\\spad{declare(t)} returns a name \\spad{f} such that \\spad{f} has been declared to the interpreter to be of type \\spad{t,} but has not been assigned a value yet. Note: \\spad{t} should be created as \\spad{devaluate(T)$Lisp} where \\spad{T} is the actual type of \\spad{f} (this hack is required for the case where \\spad{T} is a mapping type).")) (|parse| (($ (|String|)) "\\spad{parse(s)} is the inverse of unparse. It parses a string to InputForm.")) (|unparse| (((|String|) $) "\\spad{unparse(f)} returns a string \\spad{s} such that the parser would transform \\spad{s} to \\spad{f.} Error: if \\spad{f} is not the parsed form of a string.")) (|flatten| (($ $) "\\spad{flatten(s)} returns an input form corresponding to \\spad{s} with all the nested operations flattened to triples using new local variables. If \\spad{s} is a piece of code, this speeds up the compilation tremendously later on.")) ((|One|) (($) "\\spad{1} returns the input form corresponding to 1.")) ((|Zero|) (($) "\\spad{0} returns the input form corresponding to 0.")) (** (($ $ (|Integer|)) "\\spad{a \\spad{**} \\spad{b}} returns the input form corresponding to \\spad{a \\spad{**} \\spad{b}.}") (($ $ (|NonNegativeInteger|)) "\\spad{a \\spad{**} \\spad{b}} returns the input form corresponding to \\spad{a \\spad{**} \\spad{b}.}")) (/ (($ $ $) "\\spad{a / \\spad{b}} returns the input form corresponding to \\spad{a / \\spad{b}.}")) (* (($ $ $) "\\spad{a * \\spad{b}} returns the input form corresponding to \\spad{a * \\spad{b}.}")) (+ (($ $ $) "\\spad{a + \\spad{b}} returns the input form corresponding to \\spad{a + \\spad{b}.}")) (|lambda| (($ $ (|List| (|Symbol|))) "\\spad{lambda(code, [x1,...,xn])} returns the input form corresponding to \\spad{(x1,...,xn) \\spad{+->} code} if \\spad{n > 1}, or to \\spad{x1 \\spad{+->} code} if \\spad{n = 1}.")) (|function| (($ $ (|List| (|Symbol|)) (|Symbol|)) "\\spad{function(code, [x1,...,xn], \\spad{f)}} returns the input form corresponding to \\spad{f(x1,...,xn) \\spad{==} code}.")) (|binary| (($ $ (|List| $)) "\\indented{1}{\\spad{binary(op, [a1,...,an])} returns the input form} \\indented{1}{corresponding \\spad{to\\space{2}\\spad{a1} op \\spad{a2} op \\spad{...} op an}.} \\blankline \\spad{X} a:=[1,2,3]::List(InputForm) \\spad{X} binary(_+::InputForm,a)")) (|convert| (($ (|SExpression|)) "\\spad{convert(s)} makes \\spad{s} into an input form.")) (|interpret| (((|Any|) $) "\\spad{interpret(f)} passes \\spad{f} to the interpreter."))) 
 NIL 
 NIL 
-(-546 |Coef| UTS) 
+(-566 |Coef| UTS) 
 ((|constructor| (NIL "This package computes infinite products of univariate Taylor series over an integral domain of characteristic 0.")) (|generalInfiniteProduct| ((|#2| |#2| (|Integer|) (|Integer|)) "\\spad{generalInfiniteProduct(f(x),a,d)} computes \\spad{product(n=a,a+d,a+2*d,...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|oddInfiniteProduct| ((|#2| |#2|) "\\spad{oddInfiniteProduct(f(x))} computes \\spad{product(n=1,3,5...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|evenInfiniteProduct| ((|#2| |#2|) "\\spad{evenInfiniteProduct(f(x))} computes \\spad{product(n=2,4,6...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|infiniteProduct| ((|#2| |#2|) "\\spad{infiniteProduct(f(x))} computes \\spad{product(n=1,2,3...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1."))) 
 NIL 
 NIL 
-(-547 K -3313 |Par|) 
+(-567 K -3958 |Par|) 
 ((|constructor| (NIL "This is an internal package for computing approximate solutions to systems of polynomial equations. The parameter \\spad{K} specifies the coefficient field of the input polynomials and must be either \\spad{Fraction(Integer)} or \\spad{Complex(Fraction Integer)}. The parameter \\spad{F} specifies where the solutions must lie and can be one of the following: \\spad{Float}, \\spad{Fraction(Integer)}, \\spad{Complex(Float)}, \\spad{Complex(Fraction Integer)}. The last parameter specifies the type of the precision operand and must be either \\spad{Fraction(Integer)} or \\spad{Float}.")) (|makeEq| (((|List| (|Equation| (|Polynomial| |#2|))) (|List| |#2|) (|List| (|Symbol|))) "\\spad{makeEq(lsol,lvar)} returns a list of equations formed by corresponding members of \\spad{lvar} and lsol.")) (|innerSolve| (((|List| (|List| |#2|)) (|List| (|Polynomial| |#1|)) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|)) |#3|) "\\spad{innerSolve(lnum,lden,lvar,eps)} returns a list of solutions of the system of polynomials lnum, with the side condition that none of the members of \\spad{lden} vanish identically on any solution. Each solution is expressed as a list corresponding to the list of variables in \\spad{lvar} and with precision specified by eps.")) (|innerSolve1| (((|List| |#2|) (|Polynomial| |#1|) |#3|) "\\spad{innerSolve1(p,eps)} returns the list of the zeros of the polynomial \\spad{p} with precision eps.") (((|List| |#2|) (|SparseUnivariatePolynomial| |#1|) |#3|) "\\spad{innerSolve1(up,eps)} returns the list of the zeros of the univariate polynomial \\spad{up} with precision eps."))) 
 NIL 
 NIL 
-(-548 R BP |pMod| |nextMod|) 
+(-568 R BP |pMod| |nextMod|) 
 ((|constructor| (NIL "This file contains the functions for modular \\spad{gcd} algorithm for univariate polynomials with coefficients in a non-trivial euclidean domain (\\spadignore{i.e.} not a field). The package parametrised by the coefficient domain, the polynomial domain, a prime, and a function for choosing the next prime")) (|reduction| ((|#2| |#2| |#1|) "\\spad{reduction(f,p)} reduces the coefficients of the polynomial \\spad{f} modulo the prime \\spad{p.}")) (|modularGcd| ((|#2| (|List| |#2|)) "\\spad{modularGcd(listf)} computes the \\spad{gcd} of the list of polynomials \\spad{listf} by modular methods.")) (|modularGcdPrimitive| ((|#2| (|List| |#2|)) "\\spad{modularGcdPrimitive(f1,f2)} computes the \\spad{gcd} of the two polynomials \\spad{f1} and \\spad{f2} by modular methods."))) 
 NIL 
 NIL 
-(-549 OV E R P) 
+(-569 OV E R P) 
 ((|constructor| (NIL "This is an inner package for factoring multivariate polynomials over various coefficient domains in characteristic 0. The univariate factor operation is passed as a parameter. Multivariate hensel lifting is used to lift the univariate factorization")) (|factor| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|) (|Mapping| (|Factored| (|SparseUnivariatePolynomial| |#3|)) (|SparseUnivariatePolynomial| |#3|))) "\\spad{factor(p,ufact)} factors the multivariate polynomial \\spad{p} by specializing variables and calling the univariate factorizer ufact. \\spad{p} is represented as a univariate polynomial with multivariate coefficients.") (((|Factored| |#4|) |#4| (|Mapping| (|Factored| (|SparseUnivariatePolynomial| |#3|)) (|SparseUnivariatePolynomial| |#3|))) "\\spad{factor(p,ufact)} factors the multivariate polynomial \\spad{p} by specializing variables and calling the univariate factorizer ufact."))) 
 NIL 
 NIL 
-(-550 K UP |Coef| UTS) 
+(-570 K UP |Coef| UTS) 
 ((|constructor| (NIL "This package computes infinite products of univariate Taylor series over an arbitrary finite field.")) (|generalInfiniteProduct| ((|#4| |#4| (|Integer|) (|Integer|)) "\\spad{generalInfiniteProduct(f(x),a,d)} computes \\spad{product(n=a,a+d,a+2*d,...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|oddInfiniteProduct| ((|#4| |#4|) "\\spad{oddInfiniteProduct(f(x))} computes \\spad{product(n=1,3,5...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|evenInfiniteProduct| ((|#4| |#4|) "\\spad{evenInfiniteProduct(f(x))} computes \\spad{product(n=2,4,6...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|infiniteProduct| ((|#4| |#4|) "\\spad{infiniteProduct(f(x))} computes \\spad{product(n=1,2,3...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1."))) 
 NIL 
 NIL 
-(-551 |Coef| UTS) 
+(-571 |Coef| UTS) 
 ((|constructor| (NIL "This package computes infinite products of univariate Taylor series over a field of prime order.")) (|generalInfiniteProduct| ((|#2| |#2| (|Integer|) (|Integer|)) "\\spad{generalInfiniteProduct(f(x),a,d)} computes \\spad{product(n=a,a+d,a+2*d,...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|oddInfiniteProduct| ((|#2| |#2|) "\\spad{oddInfiniteProduct(f(x))} computes \\spad{product(n=1,3,5...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|evenInfiniteProduct| ((|#2| |#2|) "\\spad{evenInfiniteProduct(f(x))} computes \\spad{product(n=2,4,6...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|infiniteProduct| ((|#2| |#2|) "\\spad{infiniteProduct(f(x))} computes \\spad{product(n=1,2,3...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1."))) 
 NIL 
 NIL 
-(-552 R UP) 
+(-572 R UP) 
 ((|constructor| (NIL "Find the sign of a polynomial around a point or infinity.")) (|signAround| (((|Union| (|Integer|) "failed") |#2| |#1| (|Mapping| (|Union| (|Integer|) "failed") |#1|)) "\\spad{signAround(u,r,f)} \\undocumented") (((|Union| (|Integer|) "failed") |#2| |#1| (|Integer|) (|Mapping| (|Union| (|Integer|) "failed") |#1|)) "\\spad{signAround(u,r,i,f)} \\undocumented") (((|Union| (|Integer|) "failed") |#2| (|Integer|) (|Mapping| (|Union| (|Integer|) "failed") |#1|)) "\\spad{signAround(u,i,f)} \\undocumented"))) 
 NIL 
 NIL 
-(-553 S) 
+(-573 S) 
 ((|constructor| (NIL "An \\spad{IntegerNumberSystem} is a model for the integers.")) (|invmod| (($ $ $) "\\spad{invmod(a,b)}, \\spad{0<=a<b>1}, \\spad{(a,b)=1} means \\spad{1/a mod \\spad{b}.}")) (|powmod| (($ $ $ $) "\\spad{powmod(a,b,p)}, \\spad{0<=a,b<p>1}, means \\spad{a**b mod \\spad{p}.}")) (|mulmod| (($ $ $ $) "\\spad{mulmod(a,b,p)}, \\spad{0<=a,b<p>1}, means \\spad{a*b mod \\spad{p}.}")) (|submod| (($ $ $ $) "\\spad{submod(a,b,p)}, \\spad{0<=a,b<p>1}, means \\spad{a-b mod \\spad{p}.}")) (|addmod| (($ $ $ $) "\\spad{addmod(a,b,p)}, \\spad{0<=a,b<p>1}, means \\spad{a+b mod \\spad{p}.}")) (|mask| (($ $) "\\spad{mask(n)} returns \\spad{2**n-1} (an \\spad{n} bit mask).")) (|dec| (($ $) "\\spad{dec(x)} returns \\spad{x - 1}.")) (|inc| (($ $) "\\spad{inc(x)} returns \\spad{x + 1}.")) (|copy| (($ $) "\\spad{copy(n)} gives a copy of \\spad{n.}")) (|hash| (($ $) "\\spad{hash(n)} returns the hash code of \\spad{n.}")) (|random| (($ $) "\\spad{random(a)} creates a random element from 0 to \\spad{n-1}.") (($) "\\spad{random()} creates a random element.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(n)} creates a rational number, or returns \"failed\" if this is not possible.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(n)} creates a rational number (see \\spadtype{Fraction Integer})..")) (|rational?| (((|Boolean|) $) "\\spad{rational?(n)} tests if \\spad{n} is a rational number (see \\spadtype{Fraction Integer}).")) (|symmetricRemainder| (($ $ $) "\\spad{symmetricRemainder(a,b)} (where \\spad{b > 1}) yields \\spad{r} where \\spad{ \\spad{-b/2} \\spad{<=} \\spad{r} < \\spad{b/2} \\spad{}.}")) (|positiveRemainder| (($ $ $) "\\spad{positiveRemainder(a,b)} (where \\spad{b > 1}) yields \\spad{r} where \\spad{0 \\spad{<=} \\spad{r} < \\spad{b}} and \\spad{r \\spad{==} a rem \\spad{b}.}")) (|bit?| (((|Boolean|) $ $) "\\spad{bit?(n,i)} returns \\spad{true} if and only if \\spad{i}-th bit of \\spad{n} is a 1.")) (|shift| (($ $ $) "\\spad{shift(a,i)} shift \\spad{a} by \\spad{i} digits.")) (|length| (($ $) "\\spad{length(a)} length of \\spad{a} in digits.")) (|base| (($) "\\spad{base()} returns the base for the operations of \\spad{IntegerNumberSystem}.")) (|multiplicativeValuation| ((|attribute|) "euclideanSize(a*b) returns \\spad{euclideanSize(a)*euclideanSize(b)}.")) (|even?| (((|Boolean|) $) "\\spad{even?(n)} returns \\spad{true} if and only if \\spad{n} is even.")) (|odd?| (((|Boolean|) $) "\\spad{odd?(n)} returns \\spad{true} if and only if \\spad{n} is odd."))) 
 NIL 
 NIL 
-(-554) 
+(-574) 
 ((|constructor| (NIL "An \\spad{IntegerNumberSystem} is a model for the integers.")) (|invmod| (($ $ $) "\\spad{invmod(a,b)}, \\spad{0<=a<b>1}, \\spad{(a,b)=1} means \\spad{1/a mod \\spad{b}.}")) (|powmod| (($ $ $ $) "\\spad{powmod(a,b,p)}, \\spad{0<=a,b<p>1}, means \\spad{a**b mod \\spad{p}.}")) (|mulmod| (($ $ $ $) "\\spad{mulmod(a,b,p)}, \\spad{0<=a,b<p>1}, means \\spad{a*b mod \\spad{p}.}")) (|submod| (($ $ $ $) "\\spad{submod(a,b,p)}, \\spad{0<=a,b<p>1}, means \\spad{a-b mod \\spad{p}.}")) (|addmod| (($ $ $ $) "\\spad{addmod(a,b,p)}, \\spad{0<=a,b<p>1}, means \\spad{a+b mod \\spad{p}.}")) (|mask| (($ $) "\\spad{mask(n)} returns \\spad{2**n-1} (an \\spad{n} bit mask).")) (|dec| (($ $) "\\spad{dec(x)} returns \\spad{x - 1}.")) (|inc| (($ $) "\\spad{inc(x)} returns \\spad{x + 1}.")) (|copy| (($ $) "\\spad{copy(n)} gives a copy of \\spad{n.}")) (|hash| (($ $) "\\spad{hash(n)} returns the hash code of \\spad{n.}")) (|random| (($ $) "\\spad{random(a)} creates a random element from 0 to \\spad{n-1}.") (($) "\\spad{random()} creates a random element.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(n)} creates a rational number, or returns \"failed\" if this is not possible.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(n)} creates a rational number (see \\spadtype{Fraction Integer})..")) (|rational?| (((|Boolean|) $) "\\spad{rational?(n)} tests if \\spad{n} is a rational number (see \\spadtype{Fraction Integer}).")) (|symmetricRemainder| (($ $ $) "\\spad{symmetricRemainder(a,b)} (where \\spad{b > 1}) yields \\spad{r} where \\spad{ \\spad{-b/2} \\spad{<=} \\spad{r} < \\spad{b/2} \\spad{}.}")) (|positiveRemainder| (($ $ $) "\\spad{positiveRemainder(a,b)} (where \\spad{b > 1}) yields \\spad{r} where \\spad{0 \\spad{<=} \\spad{r} < \\spad{b}} and \\spad{r \\spad{==} a rem \\spad{b}.}")) (|bit?| (((|Boolean|) $ $) "\\spad{bit?(n,i)} returns \\spad{true} if and only if \\spad{i}-th bit of \\spad{n} is a 1.")) (|shift| (($ $ $) "\\spad{shift(a,i)} shift \\spad{a} by \\spad{i} digits.")) (|length| (($ $) "\\spad{length(a)} length of \\spad{a} in digits.")) (|base| (($) "\\spad{base()} returns the base for the operations of \\spad{IntegerNumberSystem}.")) (|multiplicativeValuation| ((|attribute|) "euclideanSize(a*b) returns \\spad{euclideanSize(a)*euclideanSize(b)}.")) (|even?| (((|Boolean|) $) "\\spad{even?(n)} returns \\spad{true} if and only if \\spad{n} is even.")) (|odd?| (((|Boolean|) $) "\\spad{odd?(n)} returns \\spad{true} if and only if \\spad{n} is odd."))) 
-((-4600 . T) (-4601 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4623 . T) (-4624 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-555 |Key| |Entry| |addDom|) 
+(-575 |Key| |Entry| |addDom|) 
 ((|constructor| (NIL "This domain is used to provide a conditional \"add\" domain for the implementation of \\spadtype{Table}."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098))) (-1841 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-1098)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098))))) 
-(-556 R -3313) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119))) (-3836 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-1119)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119))))) 
+(-576 R -3958) 
 ((|constructor| (NIL "This package provides functions for the integration of algebraic integrands over transcendental functions.")) (|algint| (((|IntegrationResult| |#2|) |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|Mapping| (|SparseUnivariatePolynomial| |#2|) (|SparseUnivariatePolynomial| |#2|))) "\\spad{algint(f, \\spad{x,} \\spad{y,} \\spad{d)}} returns the integral of \\spad{f(x,y)dx} where \\spad{y} is an algebraic function of \\spad{x;} \\spad{d} is the derivation to use on \\spad{k[x]}."))) 
 NIL 
 NIL 
-(-557 R0 -3313 UP UPUP R) 
+(-577 R0 -3958 UP UPUP R) 
 ((|constructor| (NIL "This package provides functions for integrating a function on an algebraic curve.")) (|palginfieldint| (((|Union| |#5| "failed") |#5| (|Mapping| |#3| |#3|)) "\\spad{palginfieldint(f, \\spad{d)}} returns an algebraic function \\spad{g} such that \\spad{dg = \\spad{f}} if such a \\spad{g} exists, \"failed\" otherwise. Argument \\spad{f} must be a pure algebraic function.")) (|palgintegrate| (((|IntegrationResult| |#5|) |#5| (|Mapping| |#3| |#3|)) "\\spad{palgintegrate(f, \\spad{d)}} integrates \\spad{f} with respect to the derivation \\spad{d.} Argument \\spad{f} must be a pure algebraic function.")) (|algintegrate| (((|IntegrationResult| |#5|) |#5| (|Mapping| |#3| |#3|)) "\\spad{algintegrate(f, \\spad{d)}} integrates \\spad{f} with respect to the derivation \\spad{d.}"))) 
 NIL 
 NIL 
-(-558) 
+(-578) 
 ((|constructor| (NIL "This package provides functions to lookup bits in integers")) (|bitTruth| (((|Boolean|) (|Integer|) (|Integer|)) "\\spad{bitTruth(n,m)} returns \\spad{true} if coefficient of 2**m in abs(n) is 1")) (|bitCoef| (((|Integer|) (|Integer|) (|Integer|)) "\\spad{bitCoef(n,m)} returns the coefficient of 2**m in abs(n)")) (|bitLength| (((|Integer|) (|Integer|)) "\\spad{bitLength(n)} returns the number of bits to represent abs(n)"))) 
 NIL 
 NIL 
-(-559 R) 
+(-579 R) 
 ((|constructor| (NIL "This category implements of interval arithmetic and transcendental functions over intervals.")) (|contains?| (((|Boolean|) $ |#1|) "\\spad{contains?(i,f)} returns \\spad{true} if \\axiom{f} is contained within the interval \\axiom{i}, \\spad{false} otherwise.")) (|negative?| (((|Boolean|) $) "\\spad{negative?(u)} returns \\axiom{true} if every element of \\spad{u} is negative, \\axiom{false} otherwise.")) (|positive?| (((|Boolean|) $) "\\spad{positive?(u)} returns \\axiom{true} if every element of \\spad{u} is positive, \\axiom{false} otherwise.")) (|width| ((|#1| $) "\\spad{width(u)} returns \\axiom{sup(u) - inf(u)}.")) (|sup| ((|#1| $) "\\spad{sup(u)} returns the supremum of \\axiom{u}.")) (|inf| ((|#1| $) "\\spad{inf(u)} returns the infinum of \\axiom{u}.")) (|qinterval| (($ |#1| |#1|) "\\spad{qinterval(inf,sup)} creates a new interval \\axiom{[inf,sup]}, without checking the ordering on the elements.")) (|interval| (($ (|Fraction| (|Integer|))) "\\spad{interval(f)} creates a new interval around \\spad{f.}") (($ |#1|) "\\spad{interval(f)} creates a new interval around \\spad{f.}") (($ |#1| |#1|) "\\spad{interval(inf,sup)} creates a new interval, either \\axiom{[inf,sup]} if \\axiom{inf \\spad{<=} sup} or \\axiom{[sup,in]} otherwise."))) 
-((-3410 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-2642 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-560 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR |InfClsPoint| |DesTree| BLMET) 
+(-580 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR |InfClsPoint| |DesTree| BLMET) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|placesOfDegree| (((|Void|) (|PositiveInteger|) |#3| (|List| |#5|)) "\\spad{placesOfDegree(d, \\spad{f,} pts)} compute the places of degree dividing \\spad{d} of the curve \\spad{f.} \\spad{pts} should be the singular points of the curve \\spad{f.} For \\spad{d} > 1 this only works if \\spad{K} has \\axiomType{PseudoAlgebraicClosureOfFiniteFieldCategory}.")) (|intersectionDivisor| ((|#8| |#3| |#3| (|List| |#10|) (|List| |#5|)) "\\spad{intersectionDivisor(f,pol,listOfTree)} returns the intersection divisor of \\spad{f} with a curve defined by pol. \\spad{listOfTree} must contain all the desingularisation trees of all singular points on the curve \\indented{1}{defined by pol.}"))) 
 NIL 
 NIL 
-(-561 S) 
+(-581 S) 
 ((|constructor| (NIL "The category of commutative integral domains, \\spadignore{i.e.} commutative rings with no zero divisors. \\blankline Conditional attributes\\br canonicalUnitNormal\\tab{5}the canonical field is the same for all associates\\br canonicalsClosed\\tab{5}the product of two canonicals is itself canonical")) (|unit?| (((|Boolean|) $) "\\spad{unit?(x)} tests whether \\spad{x} is a unit, \\spadignore{i.e.} is invertible.")) (|associates?| (((|Boolean|) $ $) "\\spad{associates?(x,y)} tests whether \\spad{x} and \\spad{y} are associates, \\spadignore{i.e.} differ by a unit factor.")) (|unitCanonical| (($ $) "\\spad{unitCanonical(x)} returns \\spad{unitNormal(x).canonical}.")) (|unitNormal| (((|Record| (|:| |unit| $) (|:| |canonical| $) (|:| |associate| $)) $) "\\spad{unitNormal(x)} tries to choose a canonical element from the associate class of \\spad{x.} The attribute canonicalUnitNormal, if asserted, means that the \"canonical\" element is the same across all associates of \\spad{x} if \\spad{unitNormal(x) = [u,c,a]} then \\spad{u*c = \\spad{x},} \\spad{a*u = 1}.")) (|exquo| (((|Union| $ "failed") $ $) "\\spad{exquo(a,b)} either returns an element \\spad{c} such that \\spad{c*b=a} or \"failed\" if no such element can be found."))) 
 NIL 
 NIL 
-(-562) 
+(-582) 
 ((|constructor| (NIL "The category of commutative integral domains, \\spadignore{i.e.} commutative rings with no zero divisors. \\blankline Conditional attributes\\br canonicalUnitNormal\\tab{5}the canonical field is the same for all associates\\br canonicalsClosed\\tab{5}the product of two canonicals is itself canonical")) (|unit?| (((|Boolean|) $) "\\spad{unit?(x)} tests whether \\spad{x} is a unit, \\spadignore{i.e.} is invertible.")) (|associates?| (((|Boolean|) $ $) "\\spad{associates?(x,y)} tests whether \\spad{x} and \\spad{y} are associates, \\spadignore{i.e.} differ by a unit factor.")) (|unitCanonical| (($ $) "\\spad{unitCanonical(x)} returns \\spad{unitNormal(x).canonical}.")) (|unitNormal| (((|Record| (|:| |unit| $) (|:| |canonical| $) (|:| |associate| $)) $) "\\spad{unitNormal(x)} tries to choose a canonical element from the associate class of \\spad{x.} The attribute canonicalUnitNormal, if asserted, means that the \"canonical\" element is the same across all associates of \\spad{x} if \\spad{unitNormal(x) = [u,c,a]} then \\spad{u*c = \\spad{x},} \\spad{a*u = 1}.")) (|exquo| (((|Union| $ "failed") $ $) "\\spad{exquo(a,b)} either returns an element \\spad{c} such that \\spad{c*b=a} or \"failed\" if no such element can be found."))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-563 R -3313) 
+(-583 R -3958) 
 ((|constructor| (NIL "This package provides functions for integration, limited integration, extended integration and the risch differential equation for elementary functions.")) (|lfextlimint| (((|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| (|Symbol|) (|Kernel| |#2|) (|List| (|Kernel| |#2|))) "\\spad{lfextlimint(f,x,k,[k1,...,kn])} returns functions \\spad{[h, \\spad{c]}} such that \\spad{dh/dx = \\spad{f} - \\spad{c} dk/dx}. Value \\spad{h} is looked for in a field containing \\spad{f} and k1,...,kn (the ki's must be logs).")) (|lfintegrate| (((|IntegrationResult| |#2|) |#2| (|Symbol|)) "\\spad{lfintegrate(f, \\spad{x)}} = \\spad{g} such that \\spad{dg/dx = \\spad{f}.}")) (|lfinfieldint| (((|Union| |#2| "failed") |#2| (|Symbol|)) "\\spad{lfinfieldint(f, \\spad{x)}} returns a function \\spad{g} such that \\spad{dg/dx = \\spad{f}} if \\spad{g} exists, \"failed\" otherwise.")) (|lflimitedint| (((|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (|Symbol|) (|List| |#2|)) "\\spad{lflimitedint(f,x,[g1,...,gn])} returns functions \\spad{[h,[[ci, gi]]]} such that the gi's are among \\spad{[g1,...,gn]}, and \\spad{d(h+sum(ci log(gi)))/dx = \\spad{f},} if possible, \"failed\" otherwise.")) (|lfextendedint| (((|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| (|Symbol|) |#2|) "\\spad{lfextendedint(f, \\spad{x,} \\spad{g)}} returns functions \\spad{[h, \\spad{c]}} such that \\spad{dh/dx = \\spad{f} - cg}, if \\spad{(h,} \\spad{c)} exist, \"failed\" otherwise."))) 
 NIL 
 NIL 
-(-564 K |symb| E OV R) 
+(-584 K |symb| E OV R) 
 ((|constructor| (NIL "Part of the Package for Algebraic Function Fields in one variable PAFF"))) 
 NIL 
 NIL 
-(-565 I) 
+(-585 I) 
 ((|constructor| (NIL "This Package contains basic methods for integer factorization. The factor operation employs trial division up to 10,000. It then tests to see if \\spad{n} is a perfect power before using Pollards rho method. Because Pollards method may fail, the result of factor may contain composite factors. We should also employ Lenstra's eliptic curve method.")) (|PollardSmallFactor| (((|Union| |#1| "failed") |#1|) "\\spad{PollardSmallFactor(n)} returns a factor of \\spad{n} or \"failed\" if no one is found")) (|BasicMethod| (((|Factored| |#1|) |#1|) "\\spad{BasicMethod(n)} returns the factorization of integer \\spad{n} by trial division")) (|squareFree| (((|Factored| |#1|) |#1|) "\\spad{squareFree(n)} returns the square free factorization of integer \\spad{n}")) (|factor| (((|Factored| |#1|) |#1|) "\\spad{factor(n)} returns the full factorization of integer \\spad{n}"))) 
 NIL 
 NIL 
-(-566 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR) 
+(-586 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|interpolateForms| (((|List| |#3|) |#8| (|NonNegativeInteger|) |#3| (|List| |#3|)) "\\spad{interpolateForms(D,n,pol,base)} compute the basis of the sub-vector space \\spad{W} of \\spad{V} = <base>, such that for all \\spad{G} in \\spad{W,} the divisor \\spad{(G)} \\spad{>=} \\spad{D.} All the elements in \\spad{base} must be homogeneous polynomial of degree \\spad{n.} Typicaly, \\spad{base} is the set of all monomial of degree \\spad{n:} in that case, interpolateForms(D,n,pol,base) returns the basis of the vector space of all forms of degree \\spad{d} that interpolated \\spad{D.} The argument \\spad{pol} must be the same polynomial that defined the curve form which the divisor \\spad{D} is defined."))) 
 NIL 
 NIL 
-(-567) 
+(-587) 
 ((|constructor| (NIL "There is no description for this domain")) (|entry| (((|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{entry(n)} is not documented")) (|entries| (((|List| (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $) "\\spad{entries(x)} is not documented")) (|showAttributes| (((|Union| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{showAttributes(x)} is not documented")) (|insert!| (($ (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) "\\spad{insert!(r)} inserts an entry \\spad{r} into theIFTable")) (|fTable| (($ (|List| (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) "\\spad{fTable(l)} creates a functions table from the elements of \\spad{l.}")) (|keys| (((|List| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) $) "\\spad{keys(f)} returns the list of keys of \\spad{f}")) (|clearTheFTable| (((|Void|)) "\\spad{clearTheFTable()} clears the current table of functions.")) (|showTheFTable| (($) "\\spad{showTheFTable()} returns the current table of functions."))) 
 NIL 
 NIL 
-(-568 R -3313 L) 
+(-588 R -3958 L) 
 ((|constructor| (NIL "Rationalization of several types of genus 0 integrands; This internal package rationalises integrands on curves of the form:\\br \\tab{5}\\spad{y\\^2 = a \\spad{x\\^2} + \\spad{b} \\spad{x} + c}\\br \\tab{5}\\spad{y\\^2 = (a \\spad{x} + \\spad{b)} / \\spad{(c} \\spad{x} + d)}\\br \\tab{5}\\spad{f(x, \\spad{y)} = 0} where \\spad{f} has degree 1 in x\\br The rationalization is done for integration, limited integration, extended integration and the risch differential equation.")) (|palgLODE0| (((|Record| (|:| |particular| (|Union| |#2| "failed")) (|:| |basis| (|List| |#2|))) |#3| |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|Kernel| |#2|) |#2| (|Fraction| (|SparseUnivariatePolynomial| |#2|))) "\\spad{palgLODE0(op,g,x,y,z,t,c)} returns the solution of \\spad{op \\spad{f} = \\spad{g}} Argument \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{f(x,y)dx = \\spad{c} f(t,y) dy}; \\spad{c} and \\spad{t} are rational functions of \\spad{y.}") (((|Record| (|:| |particular| (|Union| |#2| "failed")) (|:| |basis| (|List| |#2|))) |#3| |#2| (|Kernel| |#2|) (|Kernel| |#2|) |#2| (|SparseUnivariatePolynomial| |#2|)) "\\spad{palgLODE0(op, \\spad{g,} \\spad{x,} \\spad{y,} \\spad{d,} \\spad{p)}} returns the solution of \\spad{op \\spad{f} = \\spad{g}.} Argument \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{d(x)\\^2y(x)\\^2 = P(x)}.")) (|lift| (((|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| |#2|))) (|SparseUnivariatePolynomial| |#2|) (|Kernel| |#2|)) "\\spad{lift(u,k)} \\undocumented")) (|multivariate| ((|#2| (|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| |#2|))) (|Kernel| |#2|) |#2|) "\\spad{multivariate(u,k,f)} \\undocumented")) (|univariate| (((|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| |#2|))) |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|SparseUnivariatePolynomial| |#2|)) "\\spad{univariate(f,k,k,p)} \\undocumented")) (|palgRDE0| (((|Union| |#2| "failed") |#2| |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|Mapping| (|Union| |#2| "failed") |#2| |#2| (|Symbol|)) (|Kernel| |#2|) |#2| (|Fraction| (|SparseUnivariatePolynomial| |#2|))) "\\spad{palgRDE0(f, \\spad{g,} \\spad{x,} \\spad{y,} foo, \\spad{t,} \\spad{c)}} returns a function \\spad{z(x,y)} such that \\spad{dz/dx + \\spad{n} * df/dx z(x,y) = g(x,y)} if such a \\spad{z} exists, and \"failed\" otherwise. Argument \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{f(x,y)dx = \\spad{c} f(t,y) dy}; \\spad{c} and \\spad{t} are rational functions of \\spad{y.} Argument \\spad{foo}, called by \\spad{foo(a, \\spad{b,} x)}, is a function that solves \\spad{du/dx + \\spad{n} * da/dx u(x) = u(x)} for an unknown \\spad{u(x)} not involving \\spad{y.}") (((|Union| |#2| "failed") |#2| |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|Mapping| (|Union| |#2| "failed") |#2| |#2| (|Symbol|)) |#2| (|SparseUnivariatePolynomial| |#2|)) "\\spad{palgRDE0(f, \\spad{g,} \\spad{x,} \\spad{y,} foo, \\spad{d,} \\spad{p)}} returns a function \\spad{z(x,y)} such that \\spad{dz/dx + \\spad{n} * df/dx z(x,y) = g(x,y)} if such a \\spad{z} exists, and \"failed\" otherwise. Argument \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{d(x)\\^2y(x)\\^2 = P(x)}. Argument foo, called by \\spad{foo(a, \\spad{b,} x)}, is a function that solves \\spad{du/dx + \\spad{n} * da/dx u(x) = u(x)} for an unknown \\spad{u(x)} not involving \\spad{y.}")) (|palglimint0| (((|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|List| |#2|) (|Kernel| |#2|) |#2| (|Fraction| (|SparseUnivariatePolynomial| |#2|))) "\\spad{palglimint0(f, \\spad{x,} \\spad{y,} [u1,...,un], \\spad{z,} \\spad{t,} \\spad{c)}} returns functions \\spad{[h,[[ci, ui]]]} such that the ui's are among \\spad{[u1,...,un]} and \\spad{d(h + sum(ci log(ui)))/dx = f(x,y)} if such functions exist, and \"failed\" otherwise. Argument \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{f(x,y)dx = \\spad{c} f(t,y) dy}; \\spad{c} and \\spad{t} are rational functions of \\spad{y.}") (((|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|List| |#2|) |#2| (|SparseUnivariatePolynomial| |#2|)) "\\spad{palglimint0(f, \\spad{x,} \\spad{y,} [u1,...,un], \\spad{d,} \\spad{p)}} returns functions \\spad{[h,[[ci, ui]]]} such that the ui's are among \\spad{[u1,...,un]} and \\spad{d(h + sum(ci log(ui)))/dx = f(x,y)} if such functions exist, and \"failed\" otherwise. Argument \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{d(x)\\^2y(x)\\^2 = P(x)}.")) (|palgextint0| (((|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| (|Kernel| |#2|) (|Kernel| |#2|) |#2| (|Kernel| |#2|) |#2| (|Fraction| (|SparseUnivariatePolynomial| |#2|))) "\\spad{palgextint0(f, \\spad{x,} \\spad{y,} \\spad{g,} \\spad{z,} \\spad{t,} \\spad{c)}} returns functions \\spad{[h, \\spad{d]}} such that \\spad{dh/dx = f(x,y) - \\spad{d} \\spad{g},} where \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{f(x,y)dx = \\spad{c} f(t,y) dy}, and \\spad{c} and \\spad{t} are rational functions of \\spad{y.} Argument \\spad{z} is a dummy variable not appearing in \\spad{f(x,y)}. The operation returns \"failed\" if no such functions exist.") (((|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| (|Kernel| |#2|) (|Kernel| |#2|) |#2| |#2| (|SparseUnivariatePolynomial| |#2|)) "\\spad{palgextint0(f, \\spad{x,} \\spad{y,} \\spad{g,} \\spad{d,} \\spad{p)}} returns functions \\spad{[h, \\spad{c]}} such that \\spad{dh/dx = f(x,y) - \\spad{c} \\spad{g},} where \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{d(x)\\^2 \\spad{y(x)\\^2} = P(x)}, or \"failed\" if no such functions exist.")) (|palgint0| (((|IntegrationResult| |#2|) |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|Kernel| |#2|) |#2| (|Fraction| (|SparseUnivariatePolynomial| |#2|))) "\\spad{palgint0(f, \\spad{x,} \\spad{y,} \\spad{z,} \\spad{t,} \\spad{c)}} returns the integral of \\spad{f(x,y)dx} where \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{f(x,y)dx = \\spad{c} f(t,y) dy}; \\spad{c} and \\spad{t} are rational functions of \\spad{y.} Argument \\spad{z} is a dummy variable not appearing in \\spad{f(x,y)}.") (((|IntegrationResult| |#2|) |#2| (|Kernel| |#2|) (|Kernel| |#2|) |#2| (|SparseUnivariatePolynomial| |#2|)) "\\spad{palgint0(f, \\spad{x,} \\spad{y,} \\spad{d,} \\spad{p)}} returns the integral of \\spad{f(x,y)dx} where \\spad{y} is an algebraic function of \\spad{x} satisfying \\spad{d(x)\\^2 \\spad{y(x)\\^2} = P(x)}."))) 
 NIL 
-((|HasCategory| |#3| (LIST (QUOTE -650) (|devaluate| |#2|)))) 
-(-569) 
+((|HasCategory| |#3| (LIST (QUOTE -670) (|devaluate| |#2|)))) 
+(-589) 
 ((|constructor| (NIL "This package provides various number theoretic functions on the integers.")) (|sumOfKthPowerDivisors| (((|Integer|) (|Integer|) (|NonNegativeInteger|)) "\\spad{sumOfKthPowerDivisors(n,k)} returns the sum of the \\spad{k}th powers of the integers between 1 and \\spad{n} (inclusive) which divide \\spad{n.} the sum of the \\spad{k}th powers of the divisors of \\spad{n} is often denoted by \\spad{sigma_k(n)}.")) (|sumOfDivisors| (((|Integer|) (|Integer|)) "\\spad{sumOfDivisors(n)} returns the sum of the integers between 1 and \\spad{n} (inclusive) which divide \\spad{n.} The sum of the divisors of \\spad{n} is often denoted by \\spad{sigma(n)}.")) (|numberOfDivisors| (((|Integer|) (|Integer|)) "\\spad{numberOfDivisors(n)} returns the number of integers between 1 and \\spad{n} (inclusive) which divide \\spad{n.} The number of divisors of \\spad{n} is often denoted by \\spad{tau(n)}.")) (|moebiusMu| (((|Integer|) (|Integer|)) "\\spad{moebiusMu(n)} returns the Moebius function \\spad{mu(n)}. \\spad{mu(n)} is either \\spad{-1,0} or 1 as follows: \\spad{mu(n) = 0} if \\spad{n} is divisible by a square > 1, \\spad{mu(n) = (-1)^k} if \\spad{n} is square-free and has \\spad{k} distinct prime divisors.")) (|legendre| (((|Integer|) (|Integer|) (|Integer|)) "\\spad{legendre(a,p)} returns the Legendre symbol \\spad{L(a/p)}. \\spad{L(a/p) = (-1)**((p-1)/2) mod \\spad{p}} \\spad{(p} prime), which is 0 if \\spad{a} is 0, 1 if \\spad{a} is a quadratic residue \\spad{mod \\spad{p}} and \\spad{-1} otherwise. Note that because the primality test is expensive, if it is known that \\spad{p} is prime then use \\spad{jacobi(a,p)}.")) (|jacobi| (((|Integer|) (|Integer|) (|Integer|)) "\\spad{jacobi(a,b)} returns the Jacobi symbol \\spad{J(a/b)}. When \\spad{b} is odd, \\spad{J(a/b) = product(L(a/p) for \\spad{p} in factor \\spad{b} \\spad{)}.} Note that by convention, 0 is returned if \\spad{gcd(a,b) \\spad{^=} 1}. Iterative \\spad{O(log(b)^2)} version coded by Michael Monagan June 1987.")) (|harmonic| (((|Fraction| (|Integer|)) (|Integer|)) "\\spad{harmonic(n)} returns the \\spad{n}th harmonic number. This is \\spad{H[n] = sum(1/k,k=1..n)}.")) (|fibonacci| (((|Integer|) (|Integer|)) "\\spad{fibonacci(n)} returns the \\spad{n}th Fibonacci number. the Fibonacci numbers \\spad{F[n]} are defined by \\spad{F[0] = F[1] = 1} and \\spad{F[n] = F[n-1] + F[n-2]}. The algorithm has running time \\spad{O(log(n)^3)}. Reference: Knuth, The Art of Computer Programming Vol 2, Semi-Numerical Algorithms.")) (|eulerPhi| (((|Integer|) (|Integer|)) "\\spad{eulerPhi(n)} returns the number of integers between 1 and \\spad{n} (including 1) which are relatively prime to \\spad{n.} This is the Euler phi function \\spad{\\phi(n)} is also called the totient function.")) (|euler| (((|Integer|) (|Integer|)) "\\spad{euler(n)} returns the \\spad{n}th Euler number. This is \\spad{2^n E(n,1/2)}, where \\spad{E(n,x)} is the \\spad{n}th Euler polynomial.")) (|divisors| (((|List| (|Integer|)) (|Integer|)) "\\spad{divisors(n)} returns a list of the divisors of \\spad{n.}")) (|chineseRemainder| (((|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{chineseRemainder(x1,m1,x2,m2)} returns \\spad{w,} where \\spad{w} is such that \\spad{w = \\spad{x1} mod \\spad{m1}} and \\spad{w = \\spad{x2} mod m2}. Note that \\spad{m1} and \\spad{m2} must be relatively prime.")) (|bernoulli| (((|Fraction| (|Integer|)) (|Integer|)) "\\spad{bernoulli(n)} returns the \\spad{n}th Bernoulli number. this is \\spad{B(n,0)}, where \\spad{B(n,x)} is the \\spad{n}th Bernoulli polynomial."))) 
 NIL 
 NIL 
-(-570 -3313 UP UPUP R) 
+(-590 -3958 UP UPUP R) 
 ((|constructor| (NIL "Algebraic Hermite reduction.")) (|HermiteIntegrate| (((|Record| (|:| |answer| |#4|) (|:| |logpart| |#4|)) |#4| (|Mapping| |#2| |#2|)) "\\spad{HermiteIntegrate(f, \\spad{')}} returns \\spad{[g,h]} such that \\spad{f = \\spad{g'} + \\spad{h}} and \\spad{h} has a only simple finite normal poles."))) 
 NIL 
 NIL 
-(-571 -3313 UP) 
+(-591 -3958 UP) 
 ((|constructor| (NIL "Hermite integration, transcendental case.")) (|HermiteIntegrate| (((|Record| (|:| |answer| (|Fraction| |#2|)) (|:| |logpart| (|Fraction| |#2|)) (|:| |specpart| (|Fraction| |#2|)) (|:| |polypart| |#2|)) (|Fraction| |#2|) (|Mapping| |#2| |#2|)) "\\spad{HermiteIntegrate(f, \\spad{D)}} returns \\spad{[g, \\spad{h,} \\spad{s,} \\spad{p]}} such that \\spad{f = \\spad{Dg} + \\spad{h} + \\spad{s} + \\spad{p},} \\spad{h} has a squarefree denominator normal w.r.t. \\spad{D,} and all the squarefree factors of the denominator of \\spad{s} are special w.r.t. \\spad{D.} Furthermore, \\spad{h} and \\spad{s} have no polynomial parts. \\spad{D} is the derivation to use on \\spadtype{UP}."))) 
 NIL 
 NIL 
-(-572) 
+(-592) 
 ((|constructor| (NIL "\\spadtype{Integer} provides the domain of arbitrary precision integers.")) (|infinite| ((|attribute|) "nextItem never returns \"failed\".")) (|noetherian| ((|attribute|) "ascending chain condition on ideals.")) (|canonicalsClosed| ((|attribute|) "two positives multiply to give positive.")) (|canonical| ((|attribute|) "mathematical equality is data structure equality.")) (|random| (($ $) "\\spad{random(n)} returns a random integer from 0 to \\spad{n-1}."))) 
-((-4584 . T) (-4590 . T) (-4594 . T) (-4589 . T) (-4600 . T) (-4601 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4607 . T) (-4613 . T) (-4617 . T) (-4612 . T) (-4623 . T) (-4624 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-573) 
+(-593) 
 ((|constructor| (NIL "\\axiomType{AnnaNumericalIntegrationPackage} is a \\axiom{package} of functions for the \\axiom{category} \\axiomType{NumericalIntegrationCategory} with \\axiom{measure}, and \\axiom{integrate}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|))) (|NumericalIntegrationProblem|) (|RoutinesTable|)) "\\spad{measure(prob,R)} is a top level ANNA function for identifying the most appropriate numerical routine from those in the routines table provided for solving the numerical integration problem defined by \\axiom{prob}. \\blankline It calls each \\axiom{domain} listed in \\axiom{R} of \\axiom{category} \\axiomType{NumericalIntegrationCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information.") (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|))) (|NumericalIntegrationProblem|)) "\\spad{measure(prob)} is a top level ANNA function for identifying the most appropriate numerical routine for solving the numerical integration problem defined by \\axiom{prob}. \\blankline It calls each \\axiom{domain} of \\axiom{category} \\axiomType{NumericalIntegrationCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information.")) (|integrate| (((|Union| (|Result|) "failed") (|Expression| (|Float|)) (|SegmentBinding| (|OrderedCompletion| (|Float|))) (|Symbol|)) "\\spad{integrate(exp, \\spad{x} = a..b, numerical)} is a top level ANNA function to integrate an expression, {\\tt exp}, over a given range, {\\tt a} to {\\tt \\spad{b}.} \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline Default values for the absolute and relative error are used. \\blankline It is an error if the last argument is not {\\tt numerical}.") (((|Union| (|Result|) "failed") (|Expression| (|Float|)) (|SegmentBinding| (|OrderedCompletion| (|Float|))) (|String|)) "\\spad{integrate(exp, \\spad{x} = a..b, \"numerical\")} is a top level ANNA function to integrate an expression, {\\tt exp}, over a given range, {\\tt a} to {\\tt \\spad{b}.} \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline Default values for the absolute and relative error are used. \\blankline It is an error of the last argument is not {\\tt \"numerical\"}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Segment| (|OrderedCompletion| (|Float|)))) (|Float|) (|Float|) (|RoutinesTable|)) "\\spad{integrate(exp, [a..b,c..d,...], epsabs, epsrel, routines)} is a top level ANNA function to integrate a multivariate expression, {\\tt exp}, over a given set of ranges to the required absolute and relative accuracy, using the routines available in the RoutinesTable provided. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Segment| (|OrderedCompletion| (|Float|)))) (|Float|) (|Float|)) "\\spad{integrate(exp, [a..b,c..d,...], epsabs, epsrel)} is a top level ANNA function to integrate a multivariate expression, {\\tt exp}, over a given set of ranges to the required absolute and relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Segment| (|OrderedCompletion| (|Float|)))) (|Float|)) "\\spad{integrate(exp, [a..b,c..d,...], epsrel)} is a top level ANNA function to integrate a multivariate expression, {\\tt exp}, over a given set of ranges to the required relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline If epsrel = 0, a default absolute accuracy is used.") (((|Result|) (|Expression| (|Float|)) (|List| (|Segment| (|OrderedCompletion| (|Float|))))) "\\spad{integrate(exp, [a..b,c..d,...])} is a top level ANNA function to integrate a multivariate expression, {\\tt exp}, over a given set of ranges. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline Default values for the absolute and relative error are used.") (((|Result|) (|Expression| (|Float|)) (|Segment| (|OrderedCompletion| (|Float|)))) "\\spad{integrate(exp, a..b)} is a top level ANNA function to integrate an expression, {\\tt exp}, over a given range {\\tt a} to {\\tt \\spad{b}.} \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline Default values for the absolute and relative error are used.") (((|Result|) (|Expression| (|Float|)) (|Segment| (|OrderedCompletion| (|Float|))) (|Float|)) "\\spad{integrate(exp, a..b, epsrel)} is a top level ANNA function to integrate an expression, {\\tt exp}, over a given range {\\tt a} to {\\tt \\spad{b}} to the required relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline If epsrel = 0, a default absolute accuracy is used.") (((|Result|) (|Expression| (|Float|)) (|Segment| (|OrderedCompletion| (|Float|))) (|Float|) (|Float|)) "\\spad{integrate(exp, a..b, epsabs, epsrel)} is a top level ANNA function to integrate an expression, {\\tt exp}, over a given range {\\tt a} to {\\tt \\spad{b}} to the required absolute and relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}.") (((|Result|) (|NumericalIntegrationProblem|)) "\\spad{integrate(IntegrationProblem)} is a top level ANNA function to integrate an expression over a given range or ranges to the required absolute and relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|Segment| (|OrderedCompletion| (|Float|))) (|Float|) (|Float|) (|RoutinesTable|)) "\\spad{integrate(exp, a..b, epsrel, routines)} is a top level ANNA function to integrate an expression, {\\tt exp}, over a given range {\\tt a} to {\\tt \\spad{b}} to the required absolute and relative accuracy using the routines available in the RoutinesTable provided. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}."))) 
 NIL 
 NIL 
-(-574 R -3313 L) 
+(-594 R -3958 L) 
 ((|constructor| (NIL "Integration of pure algebraic functions; This package provides functions for integration, limited integration, extended integration and the risch differential equation for pure algebraic integrands.")) (|palgLODE| (((|Record| (|:| |particular| (|Union| |#2| "failed")) (|:| |basis| (|List| |#2|))) |#3| |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|Symbol|)) "\\spad{palgLODE(op, \\spad{g,} \\spad{kx,} \\spad{y,} \\spad{x)}} returns the solution of \\spad{op \\spad{f} = \\spad{g}.} \\spad{y} is an algebraic function of \\spad{x.}")) (|palgRDE| (((|Union| |#2| "failed") |#2| |#2| |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|Mapping| (|Union| |#2| "failed") |#2| |#2| (|Symbol|))) "\\spad{palgRDE(nfp, \\spad{f,} \\spad{g,} \\spad{x,} \\spad{y,} foo)} returns a function \\spad{z(x,y)} such that \\spad{dz/dx + \\spad{n} * df/dx z(x,y) = g(x,y)} if such a \\spad{z} exists, \"failed\" otherwise; \\spad{y} is an algebraic function of \\spad{x;} \\spad{foo(a, \\spad{b,} \\spad{x)}} is a function that solves \\spad{du/dx + \\spad{n} * da/dx u(x) = u(x)} for an unknown \\spad{u(x)} not involving \\spad{y.} \\spad{nfp} is \\spad{n * df/dx}.")) (|palglimint| (((|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|List| |#2|)) "\\spad{palglimint(f, \\spad{x,} \\spad{y,} [u1,...,un])} returns functions \\spad{[h,[[ci, ui]]]} such that the ui's are among \\spad{[u1,...,un]} and \\spad{d(h + sum(ci log(ui)))/dx = f(x,y)} if such functions exist, \"failed\" otherwise; \\spad{y} is an algebraic function of \\spad{x.}")) (|palgextint| (((|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| (|Kernel| |#2|) (|Kernel| |#2|) |#2|) "\\spad{palgextint(f, \\spad{x,} \\spad{y,} \\spad{g)}} returns functions \\spad{[h, \\spad{c]}} such that \\spad{dh/dx = f(x,y) - \\spad{c} \\spad{g},} where \\spad{y} is an algebraic function of \\spad{x;} returns \"failed\" if no such functions exist.")) (|palgint| (((|IntegrationResult| |#2|) |#2| (|Kernel| |#2|) (|Kernel| |#2|)) "\\spad{palgint(f, \\spad{x,} \\spad{y)}} returns the integral of \\spad{f(x,y)dx} where \\spad{y} is an algebraic function of \\spad{x.}"))) 
 NIL 
-((|HasCategory| |#3| (LIST (QUOTE -650) (|devaluate| |#2|)))) 
-(-575 R -3313) 
+((|HasCategory| |#3| (LIST (QUOTE -670) (|devaluate| |#2|)))) 
+(-595 R -3958) 
 ((|constructor| (NIL "\\spadtype{PatternMatchIntegration} provides functions that use the pattern matcher to find some indefinite and definite integrals involving special functions and found in the litterature.")) (|pmintegrate| (((|Union| |#2| "failed") |#2| (|Symbol|) (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|)) "\\spad{pmintegrate(f, \\spad{x} = a..b)} returns the integral of \\spad{f(x)dx} from a to \\spad{b} if it can be found by the built-in pattern matching rules.") (((|Union| (|Record| (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (|Symbol|)) "\\spad{pmintegrate(f, \\spad{x)}} returns either \"failed\" or \\spad{[g,h]} such that \\spad{integrate(f,x) = \\spad{g} + integrate(h,x)}.")) (|pmComplexintegrate| (((|Union| (|Record| (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (|Symbol|)) "\\spad{pmComplexintegrate(f, \\spad{x)}} returns either \"failed\" or \\spad{[g,h]} such that \\spad{integrate(f,x) = \\spad{g} + integrate(h,x)}. It only looks for special complex integrals that pmintegrate does not return.")) (|splitConstant| (((|Record| (|:| |const| |#2|) (|:| |nconst| |#2|)) |#2| (|Symbol|)) "\\spad{splitConstant(f, \\spad{x)}} returns \\spad{[c, \\spad{g]}} such that \\spad{f = \\spad{c} * \\spad{g}} and \\spad{c} does not involve \\spad{t}."))) 
 NIL 
-((-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1132)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-624))))) 
-(-576 -3313 UP) 
+((-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1153)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-644))))) 
+(-596 -3958 UP) 
 ((|constructor| (NIL "Rational function integration This package provides functions for the base case of the Risch algorithm.")) (|limitedint| (((|Union| (|Record| (|:| |mainpart| (|Fraction| |#2|)) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| (|Fraction| |#2|)) (|:| |logand| (|Fraction| |#2|)))))) "failed") (|Fraction| |#2|) (|List| (|Fraction| |#2|))) "\\spad{limitedint(f, [g1,...,gn])} returns fractions \\spad{[h,[[ci, gi]]]} such that the gi's are among \\spad{[g1,...,gn]}, \\spad{ci' = 0}, and \\spad{(h+sum(ci log(gi)))' = \\spad{f},} if possible, \"failed\" otherwise.")) (|extendedint| (((|Union| (|Record| (|:| |ratpart| (|Fraction| |#2|)) (|:| |coeff| (|Fraction| |#2|))) "failed") (|Fraction| |#2|) (|Fraction| |#2|)) "\\spad{extendedint(f, \\spad{g)}} returns fractions \\spad{[h, \\spad{c]}} such that \\spad{c' = 0} and \\spad{h' = \\spad{f} - cg}, if \\spad{(h, \\spad{c)}} exist, \"failed\" otherwise.")) (|infieldint| (((|Union| (|Fraction| |#2|) "failed") (|Fraction| |#2|)) "\\spad{infieldint(f)} returns \\spad{g} such that \\spad{g' = \\spad{f}} or \"failed\" if the integral of \\spad{f} is not a rational function.")) (|integrate| (((|IntegrationResult| (|Fraction| |#2|)) (|Fraction| |#2|)) "\\spad{integrate(f)} returns \\spad{g} such that \\spad{g' = \\spad{f}.}"))) 
 NIL 
 NIL 
-(-577 S) 
+(-597 S) 
 ((|constructor| (NIL "Provides integer testing and retraction functions.")) (|integerIfCan| (((|Union| (|Integer|) "failed") |#1|) "\\spad{integerIfCan(x)} returns \\spad{x} as an integer, \"failed\" if \\spad{x} is not an integer.")) (|integer?| (((|Boolean|) |#1|) "\\spad{integer?(x)} is \\spad{true} if \\spad{x} is an integer, \\spad{false} otherwise.")) (|integer| (((|Integer|) |#1|) "\\spad{integer(x)} returns \\spad{x} as an integer; error if \\spad{x} is not an integer."))) 
 NIL 
 NIL 
-(-578 -3313) 
+(-598 -3958) 
 ((|constructor| (NIL "This package provides functions for the integration of rational functions.")) (|extendedIntegrate| (((|Union| (|Record| (|:| |ratpart| (|Fraction| (|Polynomial| |#1|))) (|:| |coeff| (|Fraction| (|Polynomial| |#1|)))) "failed") (|Fraction| (|Polynomial| |#1|)) (|Symbol|) (|Fraction| (|Polynomial| |#1|))) "\\spad{extendedIntegrate(f, \\spad{x,} \\spad{g)}} returns fractions \\spad{[h, \\spad{c]}} such that \\spad{dc/dx = 0} and \\spad{dh/dx = \\spad{f} - cg}, if \\spad{(h, \\spad{c)}} exist, \"failed\" otherwise.")) (|limitedIntegrate| (((|Union| (|Record| (|:| |mainpart| (|Fraction| (|Polynomial| |#1|))) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| (|Fraction| (|Polynomial| |#1|))) (|:| |logand| (|Fraction| (|Polynomial| |#1|))))))) "failed") (|Fraction| (|Polynomial| |#1|)) (|Symbol|) (|List| (|Fraction| (|Polynomial| |#1|)))) "\\spad{limitedIntegrate(f, \\spad{x,} [g1,...,gn])} returns fractions \\spad{[h, [[ci,gi]]]} such that the gi's are among \\spad{[g1,...,gn]}, \\spad{dci/dx = 0}, and \\spad{d(h + sum(ci log(gi)))/dx = \\spad{f}} if possible, \"failed\" otherwise.")) (|infieldIntegrate| (((|Union| (|Fraction| (|Polynomial| |#1|)) "failed") (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{infieldIntegrate(f, \\spad{x)}} returns a fraction \\spad{g} such that \\spad{dg/dx = \\spad{f}} if \\spad{g} exists, \"failed\" otherwise.")) (|internalIntegrate| (((|IntegrationResult| (|Fraction| (|Polynomial| |#1|))) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{internalIntegrate(f, \\spad{x)}} returns \\spad{g} such that \\spad{dg/dx = \\spad{f}.}"))) 
 NIL 
 NIL 
-(-579 R) 
+(-599 R) 
 ((|constructor| (NIL "This domain is an implementation of interval arithmetic and transcendental functions over intervals."))) 
-((-3410 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-2642 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-580) 
+(-600) 
 ((|constructor| (NIL "This package provides the implementation for the \\spadfun{solveLinearPolynomialEquation} operation over the integers. It uses a lifting technique from the package GenExEuclid")) (|solveLinearPolynomialEquation| (((|Union| (|List| (|SparseUnivariatePolynomial| (|Integer|))) "failed") (|List| (|SparseUnivariatePolynomial| (|Integer|))) (|SparseUnivariatePolynomial| (|Integer|))) "\\spad{solveLinearPolynomialEquation([f1, ..., fn], \\spad{g)}} (where the \\spad{fi} are relatively prime to each other) returns a list of \\spad{ai} such that \\spad{g/prod \\spad{fi} = sum ai/fi} or returns \"failed\" if no such list of ai's exists."))) 
 NIL 
 NIL 
-(-581 R -3313) 
+(-601 R -3958) 
 ((|constructor| (NIL "Tools for the integrator")) (|intPatternMatch| (((|IntegrationResult| |#2|) |#2| (|Symbol|) (|Mapping| (|IntegrationResult| |#2|) |#2| (|Symbol|)) (|Mapping| (|Union| (|Record| (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (|Symbol|))) "\\spad{intPatternMatch(f, \\spad{x,} int, pmint)} tries to integrate \\spad{f} first by using the integration function \\spad{int}, and then by using the pattern match intetgration function \\spad{pmint} on any remaining unintegrable part.")) (|mkPrim| ((|#2| |#2| (|Symbol|)) "\\spad{mkPrim(f, \\spad{x)}} makes the logs in \\spad{f} which are linear in \\spad{x} primitive with respect to \\spad{x.}")) (|removeConstantTerm| ((|#2| |#2| (|Symbol|)) "\\spad{removeConstantTerm(f, \\spad{x)}} returns \\spad{f} minus any additive constant with respect to \\spad{x.}")) (|vark| (((|List| (|Kernel| |#2|)) (|List| |#2|) (|Symbol|)) "\\spad{vark([f1,...,fn],x)} returns the set-theoretic union of \\spad{(varselect(f1,x),...,varselect(fn,x))}.")) (|union| (((|List| (|Kernel| |#2|)) (|List| (|Kernel| |#2|)) (|List| (|Kernel| |#2|))) "\\spad{union(l1, l2)} returns set-theoretic union of \\spad{l1} and \\spad{l2.}")) (|ksec| (((|Kernel| |#2|) (|Kernel| |#2|) (|List| (|Kernel| |#2|)) (|Symbol|)) "\\spad{ksec(k, [k1,...,kn], \\spad{x)}} returns the second top-level \\spad{ki} after \\spad{k} involving \\spad{x.}")) (|kmax| (((|Kernel| |#2|) (|List| (|Kernel| |#2|))) "\\spad{kmax([k1,...,kn])} returns the top-level \\spad{ki} for integration.")) (|varselect| (((|List| (|Kernel| |#2|)) (|List| (|Kernel| |#2|)) (|Symbol|)) "\\spad{varselect([k1,...,kn], \\spad{x)}} returns the \\spad{ki} which involve \\spad{x.}"))) 
 NIL 
-((-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-281))) (|HasCategory| |#2| (QUOTE (-624)))) (-12 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-281)))) (|HasCategory| |#1| (QUOTE (-562)))) 
-(-582 -3313 UP) 
+((-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-644)))) (-12 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-301)))) (|HasCategory| |#1| (QUOTE (-582)))) 
+(-602 -3958 UP) 
 ((|constructor| (NIL "This package provides functions for the transcendental case of the Risch algorithm.")) (|monomialIntPoly| (((|Record| (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (|Mapping| |#2| |#2|)) "\\spad{monomialIntPoly(p, \\spad{')}} returns \\spad{[q,} \\spad{r]} such that \\spad{p = \\spad{q'} + \\spad{r}} and \\spad{degree(r) < degree(t')}. Error if \\spad{degree(t') < 2}.")) (|monomialIntegrate| (((|Record| (|:| |ir| (|IntegrationResult| (|Fraction| |#2|))) (|:| |specpart| (|Fraction| |#2|)) (|:| |polypart| |#2|)) (|Fraction| |#2|) (|Mapping| |#2| |#2|)) "\\spad{monomialIntegrate(f, \\spad{')}} returns \\spad{[ir, \\spad{s,} \\spad{p]}} such that \\spad{f = ir' + \\spad{s} + \\spad{p}} and all the squarefree factors of the denominator of \\spad{s} are special w.r.t the derivation \\spad{'.}")) (|expintfldpoly| (((|Union| (|LaurentPolynomial| |#1| |#2|) "failed") (|LaurentPolynomial| |#1| |#2|) (|Mapping| (|Record| (|:| |ans| |#1|) (|:| |right| |#1|) (|:| |sol?| (|Boolean|))) (|Integer|) |#1|)) "\\spad{expintfldpoly(p, foo)} returns \\spad{q} such that \\spad{p' = \\spad{q}} or \"failed\" if no such \\spad{q} exists. Argument foo is a Risch differential equation function on \\spad{F.}")) (|primintfldpoly| (((|Union| |#2| "failed") |#2| (|Mapping| (|Union| (|Record| (|:| |ratpart| |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|) "\\spad{primintfldpoly(p, \\spad{',} t')} returns \\spad{q} such that \\spad{p' = \\spad{q}} or \"failed\" if no such \\spad{q} exists. Argument \\spad{t'} is the derivative of the primitive generating the extension.")) (|primlimintfrac| (((|Union| (|Record| (|:| |mainpart| (|Fraction| |#2|)) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| (|Fraction| |#2|)) (|:| |logand| (|Fraction| |#2|)))))) "failed") (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|List| (|Fraction| |#2|))) "\\spad{primlimintfrac(f, \\spad{',} [u1,...,un])} returns \\spad{[v, [c1,...,cn]]} such that \\spad{ci' = 0} and \\spad{f = \\spad{v'} + +/[ci * ui'/ui]}. Error: if \\spad{degree numer \\spad{f} \\spad{>=} degree denom \\spad{f}.}")) (|primextintfrac| (((|Union| (|Record| (|:| |ratpart| (|Fraction| |#2|)) (|:| |coeff| (|Fraction| |#2|))) "failed") (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|Fraction| |#2|)) "\\spad{primextintfrac(f, \\spad{',} \\spad{g)}} returns \\spad{[v, \\spad{c]}} such that \\spad{f = \\spad{v'} + \\spad{c} \\spad{g}} and \\spad{c' = 0}. Error: if \\spad{degree numer \\spad{f} \\spad{>=} degree denom \\spad{f}} or if \\spad{degree numer \\spad{g} \\spad{>=} degree denom \\spad{g}} or if \\spad{denom \\spad{g}} is not squarefree.")) (|explimitedint| (((|Union| (|Record| (|:| |answer| (|Record| (|:| |mainpart| (|Fraction| |#2|)) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| (|Fraction| |#2|)) (|:| |logand| (|Fraction| |#2|))))))) (|:| |a0| |#1|)) "failed") (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|Mapping| (|Record| (|:| |ans| |#1|) (|:| |right| |#1|) (|:| |sol?| (|Boolean|))) (|Integer|) |#1|) (|List| (|Fraction| |#2|))) "\\spad{explimitedint(f, \\spad{',} foo, [u1,...,un])} returns \\spad{[v, [c1,...,cn], a]} such that \\spad{ci' = 0}, \\spad{f = \\spad{v'} + a + reduce(+,[ci * ui'/ui])}, and \\spad{a = 0} or \\spad{a} has no integral in \\spad{F.} Returns \"failed\" if no such \\spad{v,} ci, a exist. Argument \\spad{foo} is a Risch differential equation function on \\spad{F.}")) (|primlimitedint| (((|Union| (|Record| (|:| |answer| (|Record| (|:| |mainpart| (|Fraction| |#2|)) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| (|Fraction| |#2|)) (|:| |logand| (|Fraction| |#2|))))))) (|:| |a0| |#1|)) "failed") (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|Mapping| (|Union| (|Record| (|:| |ratpart| |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (|List| (|Fraction| |#2|))) "\\spad{primlimitedint(f, \\spad{',} foo, [u1,...,un])} returns \\spad{[v, [c1,...,cn], a]} such that \\spad{ci' = 0}, \\spad{f = \\spad{v'} + a + reduce(+,[ci * ui'/ui])}, and \\spad{a = 0} or \\spad{a} has no integral in UP. Returns \"failed\" if no such \\spad{v,} ci, a exist. Argument \\spad{foo} is an extended integration function on \\spad{F.}")) (|expextendedint| (((|Union| (|Record| (|:| |answer| (|Fraction| |#2|)) (|:| |a0| |#1|)) (|Record| (|:| |ratpart| (|Fraction| |#2|)) (|:| |coeff| (|Fraction| |#2|))) "failed") (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|Mapping| (|Record| (|:| |ans| |#1|) (|:| |right| |#1|) (|:| |sol?| (|Boolean|))) (|Integer|) |#1|) (|Fraction| |#2|)) "\\spad{expextendedint(f, \\spad{',} foo, \\spad{g)}} returns either \\spad{[v, \\spad{c]}} such that \\spad{f = \\spad{v'} + \\spad{c} \\spad{g}} and \\spad{c' = 0}, or \\spad{[v, a]} such that \\spad{f = \\spad{g'} + a}, and \\spad{a = 0} or \\spad{a} has no integral in \\spad{F.} Returns \"failed\" if neither case can hold. Argument \\spad{foo} is a Risch differential equation function on \\spad{F.}")) (|primextendedint| (((|Union| (|Record| (|:| |answer| (|Fraction| |#2|)) (|:| |a0| |#1|)) (|Record| (|:| |ratpart| (|Fraction| |#2|)) (|:| |coeff| (|Fraction| |#2|))) "failed") (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|Mapping| (|Union| (|Record| (|:| |ratpart| |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (|Fraction| |#2|)) "\\spad{primextendedint(f, \\spad{',} foo, \\spad{g)}} returns either \\spad{[v, \\spad{c]}} such that \\spad{f = \\spad{v'} + \\spad{c} \\spad{g}} and \\spad{c' = 0}, or \\spad{[v, a]} such that \\spad{f = \\spad{g'} + a}, and \\spad{a = 0} or \\spad{a} has no integral in UP. Returns \"failed\" if neither case can hold. Argument \\spad{foo} is an extended integration function on \\spad{F.}")) (|tanintegrate| (((|Record| (|:| |answer| (|IntegrationResult| (|Fraction| |#2|))) (|:| |a0| |#1|)) (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|Mapping| (|Union| (|List| |#1|) "failed") (|Integer|) |#1| |#1|)) "\\spad{tanintegrate(f, \\spad{',} foo)} returns \\spad{[g, a]} such that \\spad{f = \\spad{g'} + a}, and \\spad{a = 0} or \\spad{a} has no integral in \\spad{F;} Argument foo is a Risch differential system solver on \\spad{F;}")) (|expintegrate| (((|Record| (|:| |answer| (|IntegrationResult| (|Fraction| |#2|))) (|:| |a0| |#1|)) (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|Mapping| (|Record| (|:| |ans| |#1|) (|:| |right| |#1|) (|:| |sol?| (|Boolean|))) (|Integer|) |#1|)) "\\spad{expintegrate(f, \\spad{',} foo)} returns \\spad{[g, a]} such that \\spad{f = \\spad{g'} + a}, and \\spad{a = 0} or \\spad{a} has no integral in \\spad{F;} Argument foo is a Risch differential equation solver on \\spad{F;}")) (|primintegrate| (((|Record| (|:| |answer| (|IntegrationResult| (|Fraction| |#2|))) (|:| |a0| |#1|)) (|Fraction| |#2|) (|Mapping| |#2| |#2|) (|Mapping| (|Union| (|Record| (|:| |ratpart| |#1|) (|:| |coeff| |#1|)) "failed") |#1|)) "\\spad{primintegrate(f, \\spad{',} foo)} returns \\spad{[g, a]} such that \\spad{f = \\spad{g'} + a}, and \\spad{a = 0} or \\spad{a} has no integral in UP. Argument foo is an extended integration function on \\spad{F.}"))) 
 NIL 
 NIL 
-(-583 R -3313) 
+(-603 R -3958) 
 ((|constructor| (NIL "This package computes the inverse Laplace Transform.")) (|inverseLaplace| (((|Union| |#2| "failed") |#2| (|Symbol|) (|Symbol|)) "\\spad{inverseLaplace(f, \\spad{s,} \\spad{t)}} returns the Inverse Laplace transform of \\spad{f(s)} using \\spad{t} as the new variable or \"failed\" if unable to find a closed form. Handles only rational \\spad{f(s)}."))) 
 NIL 
 NIL 
-(-584 |p| |unBalanced?|) 
+(-604 |p| |unBalanced?|) 
 ((|constructor| (NIL "This domain implements \\spad{Zp,} the p-adic completion of the integers. This is an internal domain."))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-585 |p|) 
+(-605 |p|) 
 ((|constructor| (NIL "InnerPrimeField(p) implements the field with \\spad{p} elements."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| $ (QUOTE (-151))) (|HasCategory| $ (QUOTE (-149))) (|HasCategory| $ (QUOTE (-374)))) 
-(-586) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| $ (QUOTE (-171))) (|HasCategory| $ (QUOTE (-169))) (|HasCategory| $ (QUOTE (-394)))) 
+(-606) 
 ((|constructor| (NIL "A package to print strings without line-feed nor carriage-return.")) (|iprint| (((|Void|) (|String|)) "\\axiom{iprint(s)} prints \\axiom{s} at the current position of the cursor."))) 
 NIL 
 NIL 
-(-587 R -3313) 
+(-607 R -3958) 
 ((|constructor| (NIL "Conversion of integration results to top-level expressions This package allows a sum of logs over the roots of a polynomial to be expressed as explicit logarithms and arc tangents, provided that the indexing polynomial can be factored into quadratics.")) (|complexExpand| ((|#2| (|IntegrationResult| |#2|)) "\\spad{complexExpand(i)} returns the expanded complex function corresponding to i.")) (|expand| (((|List| |#2|) (|IntegrationResult| |#2|)) "\\spad{expand(i)} returns the list of possible real functions corresponding to i.")) (|split| (((|IntegrationResult| |#2|) (|IntegrationResult| |#2|)) "\\spad{split(u(x) + sum_{P(a)=0} Q(a,x))} returns \\spad{u(x) + sum_{P1(a)=0} Q(a,x) + \\spad{...} + sum_{Pn(a)=0} Q(a,x)} where P1,...,Pn are the factors of \\spad{P.}"))) 
 NIL 
 NIL 
-(-588 E -3313) 
+(-608 E -3958) 
 ((|constructor| (NIL "Internally used by the integration packages")) (|map| (((|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (|Mapping| |#2| |#1|) (|Union| (|Record| (|:| |mainpart| |#1|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")) "\\spad{map(f,ufe)} \\undocumented") (((|Union| |#2| "failed") (|Mapping| |#2| |#1|) (|Union| |#1| "failed")) "\\spad{map(f,ue)} \\undocumented") (((|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") (|Mapping| |#2| |#1|) (|Union| (|Record| (|:| |ratpart| |#1|) (|:| |coeff| |#1|)) "failed")) "\\spad{map(f,ure)} \\undocumented") (((|IntegrationResult| |#2|) (|Mapping| |#2| |#1|) (|IntegrationResult| |#1|)) "\\spad{map(f,ire)} \\undocumented"))) 
 NIL 
 NIL 
-(-589 -3313) 
+(-609 -3958) 
 ((|constructor| (NIL "The result of a transcendental integration. If a function \\spad{f} has an elementary integral \\spad{g,} then \\spad{g} can be written in the form \\spad{g = \\spad{h} + \\spad{c1} log(u1) + \\spad{c2} log(u2) + \\spad{...} + \\spad{cn} log(un)} where \\spad{h,} which is in the same field than \\spad{f,} is called the rational part of the integral, and \\spad{c1 log(u1) + \\spad{...} \\spad{cn} log(un)} is called the logarithmic part of the integral. This domain manipulates integrals represented in that form, by keeping both parts separately. The logs are not explicitly computed.")) (|differentiate| ((|#1| $ (|Symbol|)) "\\spad{differentiate(ir,x)} differentiates \\spad{ir} with respect to \\spad{x}") ((|#1| $ (|Mapping| |#1| |#1|)) "\\spad{differentiate(ir,D)} differentiates \\spad{ir} with respect to the derivation \\spad{D.}")) (|integral| (($ |#1| (|Symbol|)) "\\spad{integral(f,x)} returns the formal integral of \\spad{f} with respect to \\spad{x}") (($ |#1| |#1|) "\\spad{integral(f,x)} returns the formal integral of \\spad{f} with respect to \\spad{x}")) (|elem?| (((|Boolean|) $) "\\spad{elem?(ir)} tests if an integration result is elementary over \\spad{F?}")) (|notelem| (((|List| (|Record| (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $) "\\spad{notelem(ir)} returns the non-elementary part of an integration result")) (|logpart| (((|List| (|Record| (|:| |scalar| (|Fraction| (|Integer|))) (|:| |coeff| (|SparseUnivariatePolynomial| |#1|)) (|:| |logand| (|SparseUnivariatePolynomial| |#1|)))) $) "\\spad{logpart(ir)} returns the logarithmic part of an integration result")) (|ratpart| ((|#1| $) "\\spad{ratpart(ir)} returns the rational part of an integration result")) (|mkAnswer| (($ |#1| (|List| (|Record| (|:| |scalar| (|Fraction| (|Integer|))) (|:| |coeff| (|SparseUnivariatePolynomial| |#1|)) (|:| |logand| (|SparseUnivariatePolynomial| |#1|)))) (|List| (|Record| (|:| |integrand| |#1|) (|:| |intvar| |#1|)))) "\\spad{mkAnswer(r,l,ne)} creates an integration result from a rational part \\spad{r,} a logarithmic part \\spad{l,} and a non-elementary part ne."))) 
-((-4597 . T) (-4596 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-1170))))) 
-(-590 I) 
+((-4620 . T) (-4619 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-1191))))) 
+(-610 I) 
 ((|constructor| (NIL "The \\spadtype{IntegerRoots} package computes square roots and \\spad{n}th roots of integers efficiently.")) (|approxSqrt| ((|#1| |#1|) "\\spad{approxSqrt(n)} returns an approximation \\spad{x} to \\spad{sqrt(n)} such that \\spad{-1 < \\spad{x} - sqrt(n) < 1}. Compute an approximation \\spad{s} to \\spad{sqrt(n)} such that \\indented{10}{\\spad{-1 < \\spad{s} - sqrt(n) < 1}} A variable precision Newton iteration is used. The running time is \\spad{O( \\spad{log(n)**2} \\spad{)}.}")) (|perfectSqrt| (((|Union| |#1| "failed") |#1|) "\\spad{perfectSqrt(n)} returns the square root of \\spad{n} if \\spad{n} is a perfect square and returns \"failed\" otherwise")) (|perfectSquare?| (((|Boolean|) |#1|) "\\spad{perfectSquare?(n)} returns \\spad{true} if \\spad{n} is a perfect square and \\spad{false} otherwise")) (|approxNthRoot| ((|#1| |#1| (|NonNegativeInteger|)) "\\spad{approxRoot(n,r)} returns an approximation \\spad{x} to \\spad{n**(1/r)} such that \\spad{-1 < \\spad{x} - n**(1/r) < 1}")) (|perfectNthRoot| (((|Record| (|:| |base| |#1|) (|:| |exponent| (|NonNegativeInteger|))) |#1|) "\\spad{perfectNthRoot(n)} returns \\spad{[x,r]}, where \\spad{n = x\\^r} and \\spad{r} is the largest integer such that \\spad{n} is a perfect \\spad{r}th power") (((|Union| |#1| "failed") |#1| (|NonNegativeInteger|)) "\\spad{perfectNthRoot(n,r)} returns the \\spad{r}th root of \\spad{n} if \\spad{n} is an \\spad{r}th power and returns \"failed\" otherwise")) (|perfectNthPower?| (((|Boolean|) |#1| (|NonNegativeInteger|)) "\\spad{perfectNthPower?(n,r)} returns \\spad{true} if \\spad{n} is an \\spad{r}th power and \\spad{false} otherwise"))) 
 NIL 
 NIL 
-(-591 GF) 
+(-611 GF) 
 ((|constructor| (NIL "This package exports the function generateIrredPoly that computes a monic irreducible polynomial of degree \\spad{n} over a finite field.")) (|generateIrredPoly| (((|SparseUnivariatePolynomial| |#1|) (|PositiveInteger|)) "\\spad{generateIrredPoly(n)} generates an irreducible univariate polynomial of the given degree \\spad{n} over the finite field."))) 
 NIL 
 NIL 
-(-592 R) 
+(-612 R) 
 ((|constructor| (NIL "Conversion of integration results to top-level expressions. This package allows a sum of logs over the roots of a polynomial to be expressed as explicit logarithms and arc tangents, provided that the indexing polynomial can be factored into quadratics.")) (|complexIntegrate| (((|Expression| |#1|) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{complexIntegrate(f, \\spad{x)}} returns the integral of \\spad{f(x)dx} where \\spad{x} is viewed as a complex variable.")) (|integrate| (((|Union| (|Expression| |#1|) (|List| (|Expression| |#1|))) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{integrate(f, \\spad{x)}} returns the integral of \\spad{f(x)dx} where \\spad{x} is viewed as a real variable..")) (|complexExpand| (((|Expression| |#1|) (|IntegrationResult| (|Fraction| (|Polynomial| |#1|)))) "\\spad{complexExpand(i)} returns the expanded complex function corresponding to i.")) (|expand| (((|List| (|Expression| |#1|)) (|IntegrationResult| (|Fraction| (|Polynomial| |#1|)))) "\\spad{expand(i)} returns the list of possible real functions corresponding to i.")) (|split| (((|IntegrationResult| (|Fraction| (|Polynomial| |#1|))) (|IntegrationResult| (|Fraction| (|Polynomial| |#1|)))) "\\spad{split(u(x) + sum_{P(a)=0} Q(a,x))} returns \\spad{u(x) + sum_{P1(a)=0} Q(a,x) + \\spad{...} + sum_{Pn(a)=0} Q(a,x)} where P1,...,Pn are the factors of \\spad{P.}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-151)))) 
-(-593) 
+((|HasCategory| |#1| (QUOTE (-171)))) 
+(-613) 
 ((|constructor| (NIL "IrrRepSymNatPackage contains functions for computing the ordinary irreducible representations of symmetric groups on \\spad{n} letters {1,2,...,n} in Young's natural form and their dimensions. These representations can be labelled by number partitions of \\spad{n,} \\spadignore{i.e.} a weakly decreasing sequence of integers summing up to \\spad{n,} \\spadignore{e.g.} [3,3,3,1] labels an irreducible representation for \\spad{n} equals 10. Note that whenever a \\spadtype{List Integer} appears in a signature, a partition required.")) (|irreducibleRepresentation| (((|List| (|Matrix| (|Integer|))) (|List| (|Integer|)) (|List| (|Permutation| (|Integer|)))) "\\spad{irreducibleRepresentation(lambda,listOfPerm)} is the list of the irreducible representations corresponding to \\spad{lambda} in Young's natural form for the list of permutations given by listOfPerm.") (((|List| (|Matrix| (|Integer|))) (|List| (|Integer|))) "\\spad{irreducibleRepresentation(lambda)} is the list of the two irreducible representations corresponding to the partition \\spad{lambda} in Young's natural form for the following two generators of the symmetric group, whose elements permute {1,2,...,n}, namely \\spad{(1} 2) (2-cycle) and \\spad{(1} 2 \\spad{...} \\spad{n)} (n-cycle).") (((|Matrix| (|Integer|)) (|List| (|Integer|)) (|Permutation| (|Integer|))) "\\spad{irreducibleRepresentation(lambda,pi)} is the irreducible representation corresponding to partition \\spad{lambda} in Young's natural form of the permutation \\spad{pi} in the symmetric group, whose elements permute {1,2,...,n}.")) (|dimensionOfIrreducibleRepresentation| (((|NonNegativeInteger|) (|List| (|Integer|))) "\\spad{dimensionOfIrreducibleRepresentation(lambda)} is the dimension of the ordinary irreducible representation of the symmetric group corresponding to lambda. Note that the Robinson-Thrall hook formula is implemented."))) 
 NIL 
 NIL 
-(-594 R E V P TS) 
+(-614 R E V P TS) 
 ((|constructor| (NIL "\\indented{1}{Author: Marc Moreno Maza} Date Created: 01/1999 Date Last Updated: 23/01/1999 References: \\indented{1}{[1] \\spad{D.} LAZARD \"Solving Zero-dimensional Algebraic Systems\"} \\indented{5}{Journal of Symbolic Computation, 1992, 13, 117-131} Description:")) (|checkRur| (((|Boolean|) |#5| (|List| |#5|)) "\\spad{checkRur(ts,lus)} returns \\spad{true} if \\spad{lus} is a rational univariate representation of \\spad{ts}.")) (|rur| (((|List| |#5|) |#5| (|Boolean|)) "\\spad{rur(ts,univ?)} returns a rational univariate representation of \\spad{ts}. This assumes that the lowest polynomial in \\spad{ts} is a variable \\spad{v} which does not occur in the other polynomials of \\spad{ts}. This variable will be used to define the simple algebraic extension over which these other polynomials will be rewritten as univariate polynomials with degree one. If \\spad{univ?} is \\spad{true} then these polynomials will have a constant initial."))) 
 NIL 
 NIL 
-(-595 |mn|) 
+(-615 |mn|) 
 ((|constructor| (NIL "This domain implements low-level strings")) (|hash| (((|Integer|) $) "\\spad{hash(x)} provides a hashing function for strings"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-148) (QUOTE (-1098))) (|HasCategory| (-148) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-148) (QUOTE (-848))) (-1841 (|HasCategory| (-148) (QUOTE (-848))) (|HasCategory| (-148) (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-848)))) (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-1098)))))) 
-(-596 E V R P) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-168) (QUOTE (-1119))) (|HasCategory| (-168) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-168) (QUOTE (-869))) (-3836 (|HasCategory| (-168) (QUOTE (-869))) (|HasCategory| (-168) (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-869)))) (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-1119)))))) 
+(-616 E V R P) 
 ((|constructor| (NIL "Tools for the summation packages of polynomials")) (|sum| (((|Record| (|:| |num| |#4|) (|:| |den| (|Integer|))) |#4| |#2|) "\\spad{sum(p(n), \\spad{n)}} returns \\spad{P(n)}, the indefinite sum of \\spad{p(n)} with respect to upward difference on \\spad{n,} \\spadignore{i.e.} \\spad{P(n+1) - P(n) = a(n)}.") (((|Record| (|:| |num| |#4|) (|:| |den| (|Integer|))) |#4| |#2| (|Segment| |#4|)) "\\spad{sum(p(n), \\spad{n} = a..b)} returns \\spad{p(a) + p(a+1) + \\spad{...} + p(b)}."))) 
 NIL 
 NIL 
-(-597 |Coef|) 
+(-617 |Coef|) 
 ((|constructor| (NIL "InnerSparseUnivariatePowerSeries is an internal domain used for creating sparse Taylor and Laurent series.")) (|cAcsch| (($ $) "\\spad{cAcsch(f)} computes the inverse hyperbolic cosecant of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAsech| (($ $) "\\spad{cAsech(f)} computes the inverse hyperbolic secant of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAcoth| (($ $) "\\spad{cAcoth(f)} computes the inverse hyperbolic cotangent of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAtanh| (($ $) "\\spad{cAtanh(f)} computes the inverse hyperbolic tangent of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAcosh| (($ $) "\\spad{cAcosh(f)} computes the inverse hyperbolic cosine of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAsinh| (($ $) "\\spad{cAsinh(f)} computes the inverse hyperbolic sine of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cCsch| (($ $) "\\spad{cCsch(f)} computes the hyperbolic cosecant of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cSech| (($ $) "\\spad{cSech(f)} computes the hyperbolic secant of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cCoth| (($ $) "\\spad{cCoth(f)} computes the hyperbolic cotangent of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cTanh| (($ $) "\\spad{cTanh(f)} computes the hyperbolic tangent of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cCosh| (($ $) "\\spad{cCosh(f)} computes the hyperbolic cosine of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cSinh| (($ $) "\\spad{cSinh(f)} computes the hyperbolic sine of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAcsc| (($ $) "\\spad{cAcsc(f)} computes the arccosecant of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAsec| (($ $) "\\spad{cAsec(f)} computes the arcsecant of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAcot| (($ $) "\\spad{cAcot(f)} computes the arccotangent of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAtan| (($ $) "\\spad{cAtan(f)} computes the arctangent of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAcos| (($ $) "\\spad{cAcos(f)} computes the arccosine of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cAsin| (($ $) "\\spad{cAsin(f)} computes the arcsine of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cCsc| (($ $) "\\spad{cCsc(f)} computes the cosecant of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cSec| (($ $) "\\spad{cSec(f)} computes the secant of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cCot| (($ $) "\\spad{cCot(f)} computes the cotangent of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cTan| (($ $) "\\spad{cTan(f)} computes the tangent of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cCos| (($ $) "\\spad{cCos(f)} computes the cosine of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cSin| (($ $) "\\spad{cSin(f)} computes the sine of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cLog| (($ $) "\\spad{cLog(f)} computes the logarithm of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cExp| (($ $) "\\spad{cExp(f)} computes the exponential of the power series \\spad{f.} For use when the coefficient ring is commutative.")) (|cRationalPower| (($ $ (|Fraction| (|Integer|))) "\\spad{cRationalPower(f,r)} computes \\spad{f^r}. For use when the coefficient ring is commutative.")) (|cPower| (($ $ |#1|) "\\spad{cPower(f,r)} computes \\spad{f^r}, where \\spad{f} has constant coefficient 1. For use when the coefficient ring is commutative.")) (|integrate| (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. Warning: function does not check for a term of degree \\spad{-1.}")) (|seriesToOutputForm| (((|OutputForm|) (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|))) (|Reference| (|OrderedCompletion| (|Integer|))) (|Symbol|) |#1| (|Fraction| (|Integer|))) "\\spad{seriesToOutputForm(st,refer,var,cen,r)} prints the series \\spad{f((var - cen)^r)}.")) (|iCompose| (($ $ $) "\\spad{iCompose(f,g)} returns \\spad{f(g(x))}. This is an internal function which should only be called for Taylor series \\spad{f(x)} and \\spad{g(x)} such that the constant coefficient of \\spad{g(x)} is zero.")) (|taylorQuoByVar| (($ $) "\\spad{taylorQuoByVar(a0 + \\spad{a1} \\spad{x} + \\spad{a2} \\spad{x**2} + ...)} returns \\spad{a1 + \\spad{a2} \\spad{x} + \\spad{a3} \\spad{x**2} + ...}")) (|iExquo| (((|Union| $ "failed") $ $ (|Boolean|)) "\\spad{iExquo(f,g,taylor?)} is the quotient of the power series \\spad{f} and \\spad{g.} If \\spad{taylor?} is \\spad{true}, then we must have \\spad{order(f) \\spad{>=} order(g)}.")) (|multiplyCoefficients| (($ (|Mapping| |#1| (|Integer|)) $) "\\spad{multiplyCoefficients(fn,f)} returns the series \\spad{sum(fn(n) * an * x^n,n = n0..)}, where \\spad{f} is the series \\spad{sum(an * x^n,n = n0..)}.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(f)} tests if \\spad{f} is a single monomial.")) (|series| (($ (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|)))) "\\spad{series(st)} creates a series from a stream of non-zero terms, where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents.")) (|getStream| (((|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|))) $) "\\spad{getStream(f)} returns the stream of terms representing the series \\spad{f.}")) (|getRef| (((|Reference| (|OrderedCompletion| (|Integer|))) $) "\\spad{getRef(f)} returns a reference containing the order to which the terms of \\spad{f} have been computed.")) (|makeSeries| (($ (|Reference| (|OrderedCompletion| (|Integer|))) (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|)))) "\\spad{makeSeries(refer,str)} creates a power series from the reference \\spad{refer} and the stream \\spad{str}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|))))) (|HasCategory| (-572) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170))))))) 
-(-598 |Coef|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|))))) (|HasCategory| (-592) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191))))))) 
+(-618 |Coef|) 
 ((|constructor| (NIL "Internal package for dense Taylor series. This is an internal Taylor series type in which Taylor series are represented by a \\spadtype{Stream} of \\spadtype{Ring} elements. For univariate series, the \\spad{Stream} elements are the Taylor coefficients. For multivariate series, the \\spad{n}th Stream element is a form of degree \\spad{n} in the power series variables.")) (* (($ $ (|Integer|)) "\\spad{x*i} returns the product of integer \\spad{i} and the series \\spad{x.}") (($ $ |#1|) "\\spad{x*c} returns the product of \\spad{c} and the series \\spad{x.}") (($ |#1| $) "\\spad{c*x} returns the product of \\spad{c} and the series \\spad{x.}")) (|order| (((|NonNegativeInteger|) $ (|NonNegativeInteger|)) "\\spad{order(x,n)} returns the minimum of \\spad{n} and the order of \\spad{x.}") (((|NonNegativeInteger|) $) "\\spad{order(x)} returns the order of a power series \\spad{x,} \\indented{1}{\\spadignore{i.e.} the degree of the first non-zero term of the series.}")) (|pole?| (((|Boolean|) $) "\\spad{pole?(x)} tests if the series \\spad{x} has a pole. \\indented{1}{Note: this is \\spad{false} when \\spad{x} is a Taylor series.}")) (|series| (($ (|Stream| |#1|)) "\\spad{series(s)} creates a power series from a stream of \\indented{1}{ring elements.} \\indented{1}{For univariate series types, the stream \\spad{s} should be a stream} \\indented{1}{of Taylor coefficients. For multivariate series types, the} \\indented{1}{stream \\spad{s} should be a stream of forms the \\spad{n}th element} \\indented{1}{of which is a} \\indented{1}{form of degree \\spad{n} in the power series variables.}")) (|coefficients| (((|Stream| |#1|) $) "\\spad{coefficients(x)} returns a stream of ring elements. \\indented{1}{When \\spad{x} is a univariate series, this is a stream of Taylor} \\indented{1}{coefficients. When \\spad{x} is a multivariate series, the} \\indented{1}{\\spad{n}th element of the stream is a form of} \\indented{1}{degree \\spad{n} in the power series variables.}"))) 
-((-4597 |has| |#1| (-562)) (-4596 |has| |#1| (-562)) ((-4604 "*") |has| |#1| (-562)) (-4595 |has| |#1| (-562)) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-562)))) 
-(-599 A B) 
+((-4620 |has| |#1| (-582)) (-4619 |has| |#1| (-582)) ((-4627 "*") |has| |#1| (-582)) (-4618 |has| |#1| (-582)) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-582)))) 
+(-619 A B) 
 ((|constructor| (NIL "Functions defined on streams with entries in two sets.")) (|map| (((|InfiniteTuple| |#2|) (|Mapping| |#2| |#1|) (|InfiniteTuple| |#1|)) "\\spad{map(f,[x0,x1,x2,...])} returns \\spad{[f(x0),f(x1),f(x2),..]}."))) 
 NIL 
 NIL 
-(-600 A B C) 
+(-620 A B C) 
 ((|constructor| (NIL "Functions defined on streams with entries in two sets.")) (|map| (((|Stream| |#3|) (|Mapping| |#3| |#1| |#2|) (|InfiniteTuple| |#1|) (|Stream| |#2|)) "\\spad{map(f,a,b)} \\undocumented") (((|Stream| |#3|) (|Mapping| |#3| |#1| |#2|) (|Stream| |#1|) (|InfiniteTuple| |#2|)) "\\spad{map(f,a,b)} \\undocumented") (((|InfiniteTuple| |#3|) (|Mapping| |#3| |#1| |#2|) (|InfiniteTuple| |#1|) (|InfiniteTuple| |#2|)) "\\spad{map(f,a,b)} \\undocumented"))) 
 NIL 
 NIL 
-(-601 R -3313 FG) 
+(-621 R -3958 FG) 
 ((|constructor| (NIL "This package provides transformations from trigonometric functions to exponentials and logarithms, and back. \\spad{F} and \\spad{FG} should be the same type of function space.")) (|trigs2explogs| ((|#3| |#3| (|List| (|Kernel| |#3|)) (|List| (|Symbol|))) "\\spad{trigs2explogs(f, [k1,...,kn], [x1,...,xm])} rewrites all the trigonometric functions appearing in \\spad{f} and involving one of the \\spad{xi's} in terms of complex logarithms and exponentials. A kernel of the form \\spad{tan(u)} is expressed using \\spad{exp(u)**2} if it is one of the \\spad{ki's}, in terms of \\spad{exp(2*u)} otherwise.")) (|explogs2trigs| (((|Complex| |#2|) |#3|) "\\spad{explogs2trigs(f)} rewrites all the complex logs and exponentials appearing in \\spad{f} in terms of trigonometric functions.")) (F2FG ((|#3| |#2|) "\\spad{F2FG(a + sqrt(-1) \\spad{b)}} returns \\spad{a + \\spad{i} \\spad{b}.}")) (FG2F ((|#2| |#3|) "\\spad{FG2F(a + \\spad{i} \\spad{b)}} returns \\spad{a + sqrt(-1) \\spad{b}.}")) (GF2FG ((|#3| (|Complex| |#2|)) "\\spad{GF2FG(a + \\spad{i} \\spad{b)}} returns \\spad{a + \\spad{i} \\spad{b}} viewed as a function with the \\spad{i} pushed down into the coefficient domain."))) 
 NIL 
 NIL 
-(-602 S) 
+(-622 S) 
 ((|constructor| (NIL "This package implements 'infinite tuples' for the interpreter. The representation is a stream.")) (|construct| (((|Stream| |#1|) $) "\\spad{construct(t)} converts an infinite tuple to a stream.")) (|generate| (($ (|Mapping| |#1| |#1|) |#1|) "\\spad{generate(f,s)} returns \\spad{[s,f(s),f(f(s)),...]}.")) (|select| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{select(p,t)} returns \\spad{[x for \\spad{x} in \\spad{t} | p(x)]}.")) (|filterUntil| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{filterUntil(p,t)} returns \\spad{[x for \\spad{x} in \\spad{t} while not p(x)]}.")) (|filterWhile| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{filterWhile(p,t)} returns \\spad{[x for \\spad{x} in \\spad{t} while p(x)]}.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f,t)} replaces the tuple \\spad{t} by \\spad{[f(x) for \\spad{x} in t]}."))) 
 NIL 
 NIL 
-(-603 R |mn|) 
+(-623 R |mn|) 
 ((|constructor| (NIL "This type represents vector like objects with varying lengths and a user-specified initial index."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-722))) (|HasCategory| |#1| (QUOTE (-1054))) (-12 (|HasCategory| |#1| (QUOTE (-1009))) (|HasCategory| |#1| (QUOTE (-1054)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-604 S |Index| |Entry|) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-743))) (|HasCategory| |#1| (QUOTE (-1075))) (-12 (|HasCategory| |#1| (QUOTE (-1030))) (|HasCategory| |#1| (QUOTE (-1075)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-624 S |Index| |Entry|) 
 ((|constructor| (NIL "An indexed aggregate is a many-to-one mapping of indices to entries. For example, a one-dimensional-array is an indexed aggregate where the index is an integer. Also, a table is an indexed aggregate where the indices and entries may have any type.")) (|swap!| (((|Void|) $ |#2| |#2|) "\\spad{swap!(u,i,j)} interchanges elements \\spad{i} and \\spad{j} of aggregate u. No meaningful value is returned.")) (|fill!| (($ $ |#3|) "\\spad{fill!(u,x)} replaces each entry in aggregate \\spad{u} by \\spad{x.} The modified \\spad{u} is returned as value.")) (|first| ((|#3| $) "\\spad{first(u)} returns the first element \\spad{x} of u. Note that for collections, \\axiom{first([x,y,...,z]) = \\spad{x}.} Error: if \\spad{u} is empty.")) (|minIndex| ((|#2| $) "\\spad{minIndex(u)} returns the minimum index \\spad{i} of aggregate u. Note that in general, \\axiom{minIndex(a) = reduce(min,[i for \\spad{i} in indices a])}; for lists, \\axiom{minIndex(a) = 1}.")) (|maxIndex| ((|#2| $) "\\spad{maxIndex(u)} returns the maximum index \\spad{i} of aggregate u. Note that in general, \\axiom{maxIndex(u) = reduce(max,[i for \\spad{i} in indices u])}; if \\spad{u} is a list, \\axiom{maxIndex(u) = \\#u}.")) (|entry?| (((|Boolean|) |#3| $) "\\spad{entry?(x,u)} tests if \\spad{x} equals \\axiom{u . i} for some index i.")) (|indices| (((|List| |#2|) $) "\\spad{indices(u)} returns a list of indices of aggregate \\spad{u} in no particular order. to become indices:")) (|index?| (((|Boolean|) |#2| $) "\\spad{index?(i,u)} tests if \\spad{i} is an index of aggregate u.")) (|entries| (((|List| |#3|) $) "\\spad{entries(u)} returns a list of all the entries of aggregate \\spad{u} in no assumed order."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4603)) (|HasCategory| |#2| (QUOTE (-848))) (|HasAttribute| |#1| (QUOTE -4602)) (|HasCategory| |#3| (QUOTE (-1098)))) 
-(-605 |Index| |Entry|) 
+((|HasAttribute| |#1| (QUOTE -4626)) (|HasCategory| |#2| (QUOTE (-869))) (|HasAttribute| |#1| (QUOTE -4625)) (|HasCategory| |#3| (QUOTE (-1119)))) 
+(-625 |Index| |Entry|) 
 ((|constructor| (NIL "An indexed aggregate is a many-to-one mapping of indices to entries. For example, a one-dimensional-array is an indexed aggregate where the index is an integer. Also, a table is an indexed aggregate where the indices and entries may have any type.")) (|swap!| (((|Void|) $ |#1| |#1|) "\\spad{swap!(u,i,j)} interchanges elements \\spad{i} and \\spad{j} of aggregate u. No meaningful value is returned.")) (|fill!| (($ $ |#2|) "\\spad{fill!(u,x)} replaces each entry in aggregate \\spad{u} by \\spad{x.} The modified \\spad{u} is returned as value.")) (|first| ((|#2| $) "\\spad{first(u)} returns the first element \\spad{x} of u. Note that for collections, \\axiom{first([x,y,...,z]) = \\spad{x}.} Error: if \\spad{u} is empty.")) (|minIndex| ((|#1| $) "\\spad{minIndex(u)} returns the minimum index \\spad{i} of aggregate u. Note that in general, \\axiom{minIndex(a) = reduce(min,[i for \\spad{i} in indices a])}; for lists, \\axiom{minIndex(a) = 1}.")) (|maxIndex| ((|#1| $) "\\spad{maxIndex(u)} returns the maximum index \\spad{i} of aggregate u. Note that in general, \\axiom{maxIndex(u) = reduce(max,[i for \\spad{i} in indices u])}; if \\spad{u} is a list, \\axiom{maxIndex(u) = \\#u}.")) (|entry?| (((|Boolean|) |#2| $) "\\spad{entry?(x,u)} tests if \\spad{x} equals \\axiom{u . i} for some index i.")) (|indices| (((|List| |#1|) $) "\\spad{indices(u)} returns a list of indices of aggregate \\spad{u} in no particular order. to become indices:")) (|index?| (((|Boolean|) |#1| $) "\\spad{index?(i,u)} tests if \\spad{i} is an index of aggregate u.")) (|entries| (((|List| |#2|) $) "\\spad{entries(u)} returns a list of all the entries of aggregate \\spad{u} in no assumed order."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-606 R A) 
+(-626 R A) 
 ((|constructor| (NIL "AssociatedJordanAlgebra takes an algebra \\spad{A} and uses \\spadfun{*$A} to define the new multiplications \\spad{a*b \\spad{:=} (a *$A \\spad{b} + \\spad{b} *$A a)/2} (anticommutator). The usual notation \\spad{{a,b}_+} cannot be used due to restrictions in the current language. This domain only gives a Jordan algebra if the Jordan-identity \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} holds for all \\spad{a},\\spad{b},\\spad{c} in \\spad{A}. This relation can be checked by \\spadfun{jordanAdmissible?()$A}. \\blankline If the underlying algebra is of type \\spadtype{FramedNonAssociativeAlgebra(R)} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free R-module of finite rank, together with a fixed R-module basis), then the same is \\spad{true} for the associated Jordan algebra. Moreover, if the underlying algebra is of type \\spadtype{FiniteRankNonAssociativeAlgebra(R)} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free R-module of finite rank), then the same \\spad{true} for the associated Jordan algebra.")) (|coerce| (($ |#2|) "\\spad{coerce(a)} coerces the element \\spad{a} of the algebra \\spad{A} to an element of the Jordan algebra \\spadtype{AssociatedJordanAlgebra}(R,A)."))) 
-((-4599 -1841 (-4028 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))) (-4597 . T) (-4596 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -423) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -423) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -372) (|devaluate| |#1|))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -372) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -423) (|devaluate| |#1|)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#2| (LIST (QUOTE -372) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#2| (LIST (QUOTE -423) (|devaluate| |#1|)))))) 
-(-607 |Entry|) 
+((-4622 -3836 (-1732 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))) (-4620 . T) (-4619 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -443) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -443) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -392) (|devaluate| |#1|))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -392) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -443) (|devaluate| |#1|)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#2| (LIST (QUOTE -392) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#2| (LIST (QUOTE -443) (|devaluate| |#1|)))))) 
+(-627 |Entry|) 
 ((|constructor| (NIL "This domain allows a random access file to be viewed both as a table and as a file object. The KeyedAccessFile format is a directory containing a single file called ``index.kaf''. This file is a random access file. The first thing in the file is an integer which is the byte offset of an association list (the dictionary) at the end of the file. The association list is of the form ((key . byteoffset) (key . byteoffset)...) where the byte offset is the number of bytes from the beginning of the file. This offset contains an s-expression for the value of the key.")) (|pack!| (($ $) "\\spad{pack!(f)} reorganizes the file \\spad{f} on disk to recover unused space."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-1152) (QUOTE (-848))) (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (QUOTE (-1152))) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (QUOTE (-1098))))) 
-(-608 S |Key| |Entry|) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-1173) (QUOTE (-869))) (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (QUOTE (-1173))) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (QUOTE (-1119))))) 
+(-628 S |Key| |Entry|) 
 ((|constructor| (NIL "A keyed dictionary is a dictionary of key-entry pairs for which there is a unique entry for each key.")) (|search| (((|Union| |#3| "failed") |#2| $) "\\spad{search(k,t)} searches the table \\spad{t} for the key \\spad{k,} returning the entry stored in \\spad{t} for key \\spad{k.} If \\spad{t} has no such key, \\axiom{search(k,t)} returns \"failed\".")) (|remove!| (((|Union| |#3| "failed") |#2| $) "\\spad{remove!(k,t)} searches the table \\spad{t} for the key \\spad{k} removing (and return) the entry if there. If \\spad{t} has no such key, \\axiom{remove!(k,t)} returns \"failed\".")) (|keys| (((|List| |#2|) $) "\\spad{keys(t)} returns the list the keys in table \\spad{t.}")) (|key?| (((|Boolean|) |#2| $) "\\spad{key?(k,t)} tests if \\spad{k} is a key in table \\spad{t.}"))) 
 NIL 
 NIL 
-(-609 |Key| |Entry|) 
+(-629 |Key| |Entry|) 
 ((|constructor| (NIL "A keyed dictionary is a dictionary of key-entry pairs for which there is a unique entry for each key.")) (|search| (((|Union| |#2| "failed") |#1| $) "\\spad{search(k,t)} searches the table \\spad{t} for the key \\spad{k,} returning the entry stored in \\spad{t} for key \\spad{k.} If \\spad{t} has no such key, \\axiom{search(k,t)} returns \"failed\".")) (|remove!| (((|Union| |#2| "failed") |#1| $) "\\spad{remove!(k,t)} searches the table \\spad{t} for the key \\spad{k} removing (and return) the entry if there. If \\spad{t} has no such key, \\axiom{remove!(k,t)} returns \"failed\".")) (|keys| (((|List| |#1|) $) "\\spad{keys(t)} returns the list the keys in table \\spad{t.}")) (|key?| (((|Boolean|) |#1| $) "\\spad{key?(k,t)} tests if \\spad{k} is a key in table \\spad{t.}"))) 
-((-4603 . T) (-3389 . T)) 
+((-4626 . T) (-2623 . T)) 
 NIL 
-(-610 R S) 
+(-630 R S) 
 ((|constructor| (NIL "This package exports some auxiliary functions on kernels")) (|constantIfCan| (((|Union| |#1| "failed") (|Kernel| |#2|)) "\\spad{constantIfCan(k)} \\undocumented")) (|constantKernel| (((|Kernel| |#2|) |#1|) "\\spad{constantKernel(r)} \\undocumented"))) 
 NIL 
 NIL 
-(-611 S) 
+(-631 S) 
 ((|constructor| (NIL "A kernel over a set \\spad{S} is an operator applied to a given list of arguments from \\spad{S.}")) (|is?| (((|Boolean|) $ (|Symbol|)) "\\spad{is?(op(a1,...,an), \\spad{s)}} tests if the name of op is \\spad{s.}") (((|Boolean|) $ (|BasicOperator|)) "\\spad{is?(op(a1,...,an), \\spad{f)}} tests if op = \\spad{f.}")) (|symbolIfCan| (((|Union| (|Symbol|) "failed") $) "\\spad{symbolIfCan(k)} returns \\spad{k} viewed as a symbol if \\spad{k} is a symbol, and \"failed\" otherwise.")) (|kernel| (($ (|Symbol|)) "\\spad{kernel(x)} returns \\spad{x} viewed as a kernel.") (($ (|BasicOperator|) (|List| |#1|) (|NonNegativeInteger|)) "\\spad{kernel(op, [a1,...,an], \\spad{m)}} returns the kernel \\spad{op(a1,...,an)} of nesting level \\spad{m.} Error: if \\spad{op} is k-ary for some \\spad{k} not equal to \\spad{m.}")) (|height| (((|NonNegativeInteger|) $) "\\spad{height(k)} returns the nesting level of \\spad{k.}")) (|argument| (((|List| |#1|) $) "\\spad{argument(op(a1,...,an))} returns \\spad{[a1,...,an]}.")) (|operator| (((|BasicOperator|) $) "\\spad{operator(op(a1,...,an))} returns the operator op.")) (|name| (((|Symbol|) $) "\\spad{name(op(a1,...,an))} returns the name of op."))) 
 NIL 
-((|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) 
-(-612 S) 
+((|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) 
+(-632 S) 
 ((|constructor| (NIL "A is coercible to \\spad{B} means any element of A can automatically be converted into an element of \\spad{B} by the interpreter.")) (|coerce| ((|#1| $) "\\spad{coerce(a)} transforms a into an element of \\spad{S.}"))) 
 NIL 
 NIL 
-(-613 S) 
+(-633 S) 
 ((|constructor| (NIL "A is convertible to \\spad{B} means any element of A can be converted into an element of \\spad{B,} but not automatically by the interpreter.")) (|convert| ((|#1| $) "\\spad{convert(a)} transforms a into an element of \\spad{S.}"))) 
 NIL 
 NIL 
-(-614 -3313 UP) 
+(-634 -3958 UP) 
 ((|constructor| (NIL "\\spadtype{Kovacic} provides a modified Kovacic's algorithm for solving explicitely irreducible 2nd order linear ordinary differential equations.")) (|kovacic| (((|Union| (|SparseUnivariatePolynomial| (|Fraction| |#2|)) "failed") (|Fraction| |#2|) (|Fraction| |#2|) (|Fraction| |#2|) (|Mapping| (|Factored| |#2|) |#2|)) "\\spad{kovacic(a_0,a_1,a_2,ezfactor)} returns either \"failed\" or P(u) such that \\spad{$e^{\\int(-a_1/2a_2)} e^{\\int u}$} is a solution of \\indented{5}{\\spad{$a_2 \\spad{y''} + \\spad{a_1} \\spad{y'} + \\spad{a0} \\spad{y} = 0$}} whenever \\spad{u} is a solution of \\spad{P \\spad{u} = 0}. The equation must be already irreducible over the rational functions. Argument \\spad{ezfactor} is a factorisation in \\spad{UP}, not necessarily into irreducibles.") (((|Union| (|SparseUnivariatePolynomial| (|Fraction| |#2|)) "failed") (|Fraction| |#2|) (|Fraction| |#2|) (|Fraction| |#2|)) "\\spad{kovacic(a_0,a_1,a_2)} returns either \"failed\" or P(u) such that \\spad{$e^{\\int(-a_1/2a_2)} e^{\\int u}$} is a solution of \\indented{5}{\\spad{a_2 \\spad{y''} + \\spad{a_1} \\spad{y'} + \\spad{a0} \\spad{y} = 0}} whenever \\spad{u} is a solution of \\spad{P \\spad{u} = 0}. The equation must be already irreducible over the rational functions."))) 
 NIL 
 NIL 
-(-615 S R) 
+(-635 S R) 
 ((|constructor| (NIL "The category of all left algebras over an arbitrary ring.")) (|coerce| (($ |#2|) "\\spad{coerce(r)} returns \\spad{r} * 1 where 1 is the identity of the left algebra."))) 
 NIL 
 NIL 
-(-616 R) 
+(-636 R) 
 ((|constructor| (NIL "The category of all left algebras over an arbitrary ring.")) (|coerce| (($ |#1|) "\\spad{coerce(r)} returns \\spad{r} * 1 where 1 is the identity of the left algebra."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-617 A R S) 
+(-637 A R S) 
 ((|constructor| (NIL "LocalAlgebra produces the localization of an algebra, \\spadignore{i.e.} fractions whose numerators come from some \\spad{R} algebra.")) (|denom| ((|#3| $) "\\spad{denom \\spad{x}} returns the denominator of \\spad{x.}")) (|numer| ((|#1| $) "\\spad{numer \\spad{x}} returns the numerator of \\spad{x.}")) (/ (($ |#1| |#3|) "\\spad{a / \\spad{d}} divides the element \\spad{a} by \\spad{d.}") (($ $ |#3|) "\\spad{x / \\spad{d}} divides the element \\spad{x} by \\spad{d.}"))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-846)))) 
-(-618 R -3313) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-867)))) 
+(-638 R -3958) 
 ((|constructor| (NIL "This package computes the forward Laplace Transform.")) (|laplace| ((|#2| |#2| (|Symbol|) (|Symbol|)) "\\spad{laplace(f, \\spad{t,} \\spad{s)}} returns the Laplace transform of \\spad{f(t)} using \\spad{s} as the new variable. This is \\spad{integral(exp(-s*t)*f(t), \\spad{t} = 0..%plusInfinity)}. Returns the formal object \\spad{laplace(f, \\spad{t,} \\spad{s)}} if it cannot compute the transform."))) 
 NIL 
 NIL 
-(-619 R UP) 
+(-639 R UP) 
 ((|constructor| (NIL "Univariate polynomials with negative and positive exponents.")) (|separate| (((|Record| (|:| |polyPart| $) (|:| |fracPart| (|Fraction| |#2|))) (|Fraction| |#2|)) "\\spad{separate(x)} is not documented")) (|monomial| (($ |#1| (|Integer|)) "\\spad{monomial(x,n)} is not documented")) (|coefficient| ((|#1| $ (|Integer|)) "\\spad{coefficient(x,n)} is not documented")) (|trailingCoefficient| ((|#1| $) "trailingCoefficient is not documented")) (|leadingCoefficient| ((|#1| $) "leadingCoefficient is not documented")) (|reductum| (($ $) "\\spad{reductum(x)} is not documented")) (|order| (((|Integer|) $) "\\spad{order(x)} is not documented")) (|degree| (((|Integer|) $) "\\spad{degree(x)} is not documented")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(x)} is not documented"))) 
-((-4597 . T) (-4596 . T) ((-4604 "*") . T) (-4595 . T) (-4599 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572))))) 
-(-620 R E V P TS ST) 
+((-4620 . T) (-4619 . T) ((-4627 "*") . T) (-4618 . T) (-4622 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592))))) 
+(-640 R E V P TS ST) 
 ((|constructor| (NIL "A package for solving polynomial systems by means of Lazard triangular sets. This package provides two operations. One for solving in the sense of the regular zeros, and the other for solving in the sense of the Zariski closure. Both produce square-free regular sets. Moreover, the decompositions do not contain any redundant component. However, only zero-dimensional regular sets are normalized, since normalization may be time consumming in positive dimension. The decomposition process is that of [2].")) (|zeroSetSplit| (((|List| |#6|) (|List| |#4|) (|Boolean|)) "\\axiom{zeroSetSplit(lp,clos?)} has the same specifications as zeroSetSplit(lp,clos?) from RegularTriangularSetCategory.")) (|normalizeIfCan| ((|#6| |#6|) "\\axiom{normalizeIfCan(ts)} returns \\axiom{ts} in an normalized shape if \\axiom{ts} is zero-dimensional."))) 
 NIL 
 NIL 
-(-621 OV E Z P) 
+(-641 OV E Z P) 
 ((|constructor| (NIL "Package for leading coefficient determination in the lifting step. Package working for every \\spad{R} euclidean with property \"F\".")) (|distFact| (((|Union| (|Record| (|:| |polfac| (|List| |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (|List| (|SparseUnivariatePolynomial| |#3|)))) "failed") |#3| (|List| (|SparseUnivariatePolynomial| |#3|)) (|Record| (|:| |contp| |#3|) (|:| |factors| (|List| (|Record| (|:| |irr| |#4|) (|:| |pow| (|Integer|)))))) (|List| |#3|) (|List| |#1|) (|List| |#3|)) "\\spad{distFact(contm,unilist,plead,vl,lvar,lval)}, where \\spad{contm} is the content of the evaluated polynomial, \\spad{unilist} is the list of factors of the evaluated polynomial, \\spad{plead} is the complete factorization of the leading coefficient, \\spad{vl} is the list of factors of the leading coefficient evaluated, \\spad{lvar} is the list of variables, \\spad{lval} is the list of values, returns a record giving the list of leading coefficients to impose on the univariate factors.")) (|polCase| (((|Boolean|) |#3| (|NonNegativeInteger|) (|List| |#3|)) "\\spad{polCase(contprod, numFacts, evallcs)}, where \\spad{contprod} is the product of the content of the leading coefficient of the polynomial to be factored with the content of the evaluated polynomial, \\spad{numFacts} is the number of factors of the leadingCoefficient, and evallcs is the list of the evaluated factors of the leadingCoefficient, returns \\spad{true} if the factors of the leading Coefficient can be distributed with this valuation."))) 
 NIL 
 NIL 
-(-622 |VarSet| R |Order|) 
+(-642 |VarSet| R |Order|) 
 ((|constructor| (NIL "Management of the Lie Group associated with a free nilpotent Lie algebra. Every Lie bracket with length greater than \\axiom{Order} are assumed to be null. The implementation inherits from the \\spadtype{XPBWPolynomial} domain constructor: Lyndon coordinates are exponential coordinates of the second kind.")) (|identification| (((|List| (|Equation| |#2|)) $ $) "\\axiom{identification(g,h)} returns the list of equations \\axiom{g_i = h_i}, where \\axiom{g_i} (resp. \\axiom{h_i}) are exponential coordinates of \\axiom{g} (resp. \\axiom{h}).")) (|LyndonCoordinates| (((|List| (|Record| (|:| |k| (|LyndonWord| |#1|)) (|:| |c| |#2|))) $) "\\axiom{LyndonCoordinates(g)} returns the exponential coordinates of \\axiom{g}.")) (|LyndonBasis| (((|List| (|LiePolynomial| |#1| |#2|)) (|List| |#1|)) "\\axiom{LyndonBasis(lv)} returns the Lyndon basis of the nilpotent free Lie algebra.")) (|varList| (((|List| |#1|) $) "\\axiom{varList(g)} returns the list of variables of \\axiom{g}.")) (|mirror| (($ $) "\\axiom{mirror(g)} is the mirror of the internal representation of \\axiom{g}.")) (|coerce| (((|XPBWPolynomial| |#1| |#2|) $) "\\axiom{coerce(g)} returns the internal representation of \\axiom{g}.") (((|XDistributedPolynomial| |#1| |#2|) $) "\\axiom{coerce(g)} returns the internal representation of \\axiom{g}.")) (|listOfTerms| (((|List| (|Record| (|:| |k| (|PoincareBirkhoffWittLyndonBasis| |#1|)) (|:| |c| |#2|))) $) "\\axiom{listOfTerms(p)} returns the internal representation of \\axiom{p}.")) (|log| (((|LiePolynomial| |#1| |#2|) $) "\\axiom{log(p)} returns the logarithm of \\axiom{p}.")) (|exp| (($ (|LiePolynomial| |#1| |#2|)) "\\axiom{exp(p)} returns the exponential of \\axiom{p}."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-623 R |ls|) 
+(-643 R |ls|) 
 ((|constructor| (NIL "A package for solving polynomial systems with finitely many solutions. The decompositions are given by means of regular triangular sets. The computations use lexicographical Groebner bases. The main operations are lexTriangular and squareFreeLexTriangular. The second one provide decompositions by means of square-free regular triangular sets. Both are based on the lexTriangular method described in [1]. They differ from the algorithm described in \\spad{[2]} by the fact that multiciplities of the roots are not kept. With the squareFreeLexTriangular operation all multiciplities are removed. With the other operation some multiciplities may remain. Both operations admit an optional argument to produce normalized triangular sets.")) (|zeroSetSplit| (((|List| (|SquareFreeRegularTriangularSet| |#1| (|IndexedExponents| (|OrderedVariableList| |#2|)) (|OrderedVariableList| |#2|) (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|)) "\\axiom{zeroSetSplit(lp, norm?)} decomposes the variety associated with \\axiom{lp} into square-free regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{lp} needs to generate a zero-dimensional ideal. If \\axiom{norm?} is \\axiom{true} then the regular sets are normalized.") (((|List| (|RegularChain| |#1| |#2|)) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|)) "\\axiom{zeroSetSplit(lp, norm?)} decomposes the variety associated with \\axiom{lp} into regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{lp} needs to generate a zero-dimensional ideal. If \\axiom{norm?} is \\axiom{true} then the regular sets are normalized.")) (|squareFreeLexTriangular| (((|List| (|SquareFreeRegularTriangularSet| |#1| (|IndexedExponents| (|OrderedVariableList| |#2|)) (|OrderedVariableList| |#2|) (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|)) "\\axiom{squareFreeLexTriangular(base, norm?)} decomposes the variety associated with \\axiom{base} into square-free regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{base} needs to be a lexicographical Groebner basis of a zero-dimensional ideal. If \\axiom{norm?} is \\axiom{true} then the regular sets are normalized.")) (|lexTriangular| (((|List| (|RegularChain| |#1| |#2|)) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|)) "\\axiom{lexTriangular(base, norm?)} decomposes the variety associated with \\axiom{base} into regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{base} needs to be a lexicographical Groebner basis of a zero-dimensional ideal. If \\axiom{norm?} is \\axiom{true} then the regular sets are normalized.")) (|groebner| (((|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) "\\axiom{groebner(lp)} returns the lexicographical Groebner basis of \\axiom{lp}. If \\axiom{lp} generates a zero-dimensional ideal then the FGLM strategy is used, otherwise the Sugar strategy is used.")) (|fglmIfCan| (((|Union| (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) "failed") (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) "\\axiom{fglmIfCan(lp)} returns the lexicographical Groebner basis of \\axiom{lp} by using the FGLM strategy, if \\axiom{zeroDimensional?(lp)} holds .")) (|zeroDimensional?| (((|Boolean|) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) "\\axiom{zeroDimensional?(lp)} returns \\spad{true} iff \\axiom{lp} generates a zero-dimensional ideal w.r.t. the variables involved in \\axiom{lp}."))) 
 NIL 
 NIL 
-(-624) 
+(-644) 
 ((|constructor| (NIL "Category for the transcendental Liouvillian functions.")) (|fresnelC| (($ $) "\\spad{fresnelC(x)} is the Fresnel integral \\spad{C,} defined by C(x) = integrate(cos(t^2),t=0..x)")) (|fresnelS| (($ $) "\\spad{fresnelS(x)} is the Fresnel integral \\spad{S,} defined by S(x) = integrate(sin(t^2),t=0..x)")) (|erf| (($ $) "\\spad{erf(x)} returns the error function of \\spad{x,} that is, \\spad{2 / sqrt(\\%pi)} times the integral of \\spad{exp(-x**2) dx}.")) (|dilog| (($ $) "\\spad{dilog(x)} returns the dilogarithm of \\spad{x,} that is, the integral of \\spad{log(x) / \\spad{(1} - \\spad{x)} dx}.")) (|li| (($ $) "\\spad{li(x)} returns the logarithmic integral of \\spad{x,} that is, the integral of \\spad{dx / log(x)}.")) (|Ci| (($ $) "\\spad{Ci(x)} returns the cosine integral of \\spad{x,} that is, the integral of \\spad{cos(x) / \\spad{x} dx}.")) (|Si| (($ $) "\\spad{Si(x)} returns the sine integral of \\spad{x,} that is, the integral of \\spad{sin(x) / \\spad{x} dx}.")) (|Ei| (($ $) "\\spad{Ei(x)} returns the exponential integral of \\spad{x,} that is, the integral of \\spad{exp(x)/x dx}."))) 
 NIL 
 NIL 
-(-625 R -3313) 
+(-645 R -3958) 
 ((|constructor| (NIL "This package provides liouvillian functions over an integral domain.")) (|integral| ((|#2| |#2| (|SegmentBinding| |#2|)) "\\spad{integral(f,x = a..b)} denotes the definite integral of \\spad{f} with respect to \\spad{x} from \\spad{a} to \\spad{b.}") ((|#2| |#2| (|Symbol|)) "\\spad{integral(f,x)} indefinite integral of \\spad{f} with respect to \\spad{x.}")) (|fresnelC| ((|#2| |#2|) "\\spad{fresnelC(f)} denotes the Fresnel integral \\spad{C}")) (|fresnelS| ((|#2| |#2|) "\\spad{fresnelS(f)} denotes the Fresnel integral \\spad{S}")) (|dilog| ((|#2| |#2|) "\\spad{dilog(f)} denotes the dilogarithm")) (|erf| ((|#2| |#2|) "\\spad{erf(f)} denotes the error function")) (|li| ((|#2| |#2|) "\\spad{li(f)} denotes the logarithmic integral")) (|Ci| ((|#2| |#2|) "\\spad{Ci(f)} denotes the cosine integral")) (|Si| ((|#2| |#2|) "\\spad{Si(f)} denotes the sine integral")) (|Ei| ((|#2| |#2|) "\\spad{Ei(f)} denotes the exponential integral")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns the Liouvillian operator based on \\spad{op}")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} checks if \\spad{op} is Liouvillian"))) 
 NIL 
 NIL 
-(-626 |lv| -3313) 
+(-646 |lv| -3958) 
 ((|constructor| (NIL "Given a Groebner basis \\spad{B} with respect to the total degree ordering for a zero-dimensional ideal I, compute a Groebner basis with respect to the lexicographical ordering by using linear algebra.")) (|transform| (((|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|) (|DistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{transform }\\undocumented")) (|choosemon| (((|DistributedMultivariatePolynomial| |#1| |#2|) (|DistributedMultivariatePolynomial| |#1| |#2|) (|List| (|DistributedMultivariatePolynomial| |#1| |#2|))) "\\spad{choosemon }\\undocumented")) (|intcompBasis| (((|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) (|OrderedVariableList| |#1|) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|))) "\\spad{intcompBasis }\\undocumented")) (|anticoord| (((|DistributedMultivariatePolynomial| |#1| |#2|) (|List| |#2|) (|DistributedMultivariatePolynomial| |#1| |#2|) (|List| (|DistributedMultivariatePolynomial| |#1| |#2|))) "\\spad{anticoord }\\undocumented")) (|coord| (((|Vector| |#2|) (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|))) "\\spad{coord }\\undocumented")) (|computeBasis| (((|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|))) "\\spad{computeBasis }\\undocumented")) (|minPol| (((|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) (|OrderedVariableList| |#1|)) "\\spad{minPol }\\undocumented") (((|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) (|OrderedVariableList| |#1|)) "\\spad{minPol }\\undocumented")) (|totolex| (((|List| (|DistributedMultivariatePolynomial| |#1| |#2|)) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|))) "\\spad{totolex }\\undocumented")) (|groebgen| (((|Record| (|:| |glbase| (|List| (|DistributedMultivariatePolynomial| |#1| |#2|))) (|:| |glval| (|List| (|Integer|)))) (|List| (|DistributedMultivariatePolynomial| |#1| |#2|))) "\\spad{groebgen }\\undocumented")) (|linGenPos| (((|Record| (|:| |gblist| (|List| (|DistributedMultivariatePolynomial| |#1| |#2|))) (|:| |gvlist| (|List| (|Integer|)))) (|List| (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|))) "\\spad{linGenPos }\\undocumented"))) 
 NIL 
 NIL 
-(-627) 
+(-647) 
 ((|constructor| (NIL "This domain provides a simple way to save values in files.")) (|close!| (($ $) "\\spad{close!(f)} returns the library \\spad{f} closed to input and output.")) (|setelt| (((|Any|) $ (|Symbol|) (|Any|)) "\\spad{lib.k \\spad{:=} \\spad{v}} saves the value \\spad{v} in the library \\spad{lib}. It can later be extracted using the key \\spad{k}.")) (|elt| (((|Any|) $ (|Symbol|)) "\\spad{elt(lib,k)} or lib.k extracts the value corresponding to the key \\spad{k} from the library \\spad{lib}.")) (|pack!| (($ $) "\\spad{pack!(f)} reorganizes the file \\spad{f} on disk to recover unused space.")) (|library| (($ (|FileName|)) "\\spad{library(ln)} creates a new library file."))) 
-((-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-1152) (QUOTE (-848))) (|HasCategory| (-57) (QUOTE (-1098))) (-12 (|HasCategory| (-57) (LIST (QUOTE -305) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1098)))) (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (QUOTE (-1152))) (LIST (QUOTE |:|) (QUOTE -4320) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (QUOTE (-1098)))) (-1841 (|HasCategory| (-57) (QUOTE (-1098))) (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (QUOTE (-1098))))) 
-(-628 S R) 
+((-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-1173) (QUOTE (-869))) (|HasCategory| (-57) (QUOTE (-1119))) (-12 (|HasCategory| (-57) (LIST (QUOTE -325) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1119)))) (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (QUOTE (-1173))) (LIST (QUOTE |:|) (QUOTE -3552) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (QUOTE (-1119)))) (-3836 (|HasCategory| (-57) (QUOTE (-1119))) (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (QUOTE (-1119))))) 
+(-648 S R) 
 ((|constructor| (NIL "The category of Lie Algebras. It is used by the domains of non-commutative algebra, LiePolynomial and XPBWPolynomial.")) (/ (($ $ |#2|) "\\axiom{x/r} returns the division of \\axiom{x} by \\axiom{r}.")) (|construct| (($ $ $) "\\axiom{construct(x,y)} returns the Lie bracket of \\axiom{x} and \\axiom{y}."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-368)))) 
-(-629 R) 
+((|HasCategory| |#2| (QUOTE (-388)))) 
+(-649 R) 
 ((|constructor| (NIL "The category of Lie Algebras. It is used by the domains of non-commutative algebra, LiePolynomial and XPBWPolynomial.")) (/ (($ $ |#1|) "\\axiom{x/r} returns the division of \\axiom{x} by \\axiom{r}.")) (|construct| (($ $ $) "\\axiom{construct(x,y)} returns the Lie bracket of \\axiom{x} and \\axiom{y}."))) 
-((|JacobiIdentity| . T) (|NullSquare| . T) (-4597 . T) (-4596 . T)) 
+((|JacobiIdentity| . T) (|NullSquare| . T) (-4620 . T) (-4619 . T)) 
 NIL 
-(-630 R A) 
+(-650 R A) 
 ((|constructor| (NIL "AssociatedLieAlgebra takes an algebra \\spad{A} and uses \\spadfun{*$A} to define the Lie bracket \\spad{a*b \\spad{:=} (a *$A \\spad{b} - \\spad{b} *$A a)} (commutator). Note that the notation \\spad{[a,b]} cannot be used due to restrictions of the current compiler. This domain only gives a Lie algebra if the Jacobi-identity \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} holds for all \\spad{a},\\spad{b},\\spad{c} in \\spad{A}. This relation can be checked by \\spad{lieAdmissible?()$A}. \\blankline If the underlying algebra is of type \\spadtype{FramedNonAssociativeAlgebra(R)} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free \\spad{R}-module of finite rank, together with a fixed \\spad{R}-module basis), then the same is \\spad{true} for the associated Lie algebra. Also, if the underlying algebra is of type \\spadtype{FiniteRankNonAssociativeAlgebra(R)} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free R-module of finite rank), then the same is \\spad{true} for the associated Lie algebra.")) (|coerce| (($ |#2|) "\\spad{coerce(a)} coerces the element \\spad{a} of the algebra \\spad{A} to an element of the Lie algebra \\spadtype{AssociatedLieAlgebra}(R,A)."))) 
-((-4599 -1841 (-4028 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))) (-4597 . T) (-4596 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -423) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -423) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -372) (|devaluate| |#1|))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -372) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -423) (|devaluate| |#1|)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#2| (LIST (QUOTE -372) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#2| (LIST (QUOTE -423) (|devaluate| |#1|)))))) 
-(-631 R FE) 
+((-4622 -3836 (-1732 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))) (-4620 . T) (-4619 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -443) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -443) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -392) (|devaluate| |#1|))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -392) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -443) (|devaluate| |#1|)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#2| (LIST (QUOTE -392) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#2| (LIST (QUOTE -443) (|devaluate| |#1|)))))) 
+(-651 R FE) 
 ((|constructor| (NIL "PowerSeriesLimitPackage implements limits of expressions in one or more variables as one of the variables approaches a limiting value. Included are two-sided limits, left- and right- hand limits, and limits at plus or minus infinity.")) (|complexLimit| (((|Union| (|OnePointCompletion| |#2|) "failed") |#2| (|Equation| (|OnePointCompletion| |#2|))) "\\spad{complexLimit(f(x),x = a)} computes the complex limit \\spad{lim(x \\spad{->} a,f(x))}.")) (|limit| (((|Union| (|OrderedCompletion| |#2|) "failed") |#2| (|Equation| |#2|) (|String|)) "\\spad{limit(f(x),x=a,\"left\")} computes the left hand real limit \\spad{lim(x \\spad{->} a-,f(x))}; \\spad{limit(f(x),x=a,\"right\")} computes the right hand real limit \\spad{lim(x \\spad{->} a+,f(x))}.") (((|Union| (|OrderedCompletion| |#2|) (|Record| (|:| |leftHandLimit| (|Union| (|OrderedCompletion| |#2|) "failed")) (|:| |rightHandLimit| (|Union| (|OrderedCompletion| |#2|) "failed"))) "failed") |#2| (|Equation| (|OrderedCompletion| |#2|))) "\\spad{limit(f(x),x = a)} computes the real limit \\spad{lim(x \\spad{->} a,f(x))}."))) 
 NIL 
 NIL 
-(-632 R) 
+(-652 R) 
 ((|constructor| (NIL "Computation of limits for rational functions.")) (|complexLimit| (((|OnePointCompletion| (|Fraction| (|Polynomial| |#1|))) (|Fraction| (|Polynomial| |#1|)) (|Equation| (|Fraction| (|Polynomial| |#1|)))) "\\spad{complexLimit(f(x),x = a)} computes the complex limit of \\spad{f} as its argument \\spad{x} approaches \\spad{a}.") (((|OnePointCompletion| (|Fraction| (|Polynomial| |#1|))) (|Fraction| (|Polynomial| |#1|)) (|Equation| (|OnePointCompletion| (|Polynomial| |#1|)))) "\\spad{complexLimit(f(x),x = a)} computes the complex limit of \\spad{f} as its argument \\spad{x} approaches \\spad{a}.")) (|limit| (((|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|))) "failed") (|Fraction| (|Polynomial| |#1|)) (|Equation| (|Fraction| (|Polynomial| |#1|))) (|String|)) "\\spad{limit(f(x),x,a,\"left\")} computes the real limit of \\spad{f} as its argument \\spad{x} approaches \\spad{a} from the left; limit(f(x),x,a,\"right\") computes the corresponding limit as \\spad{x} approaches \\spad{a} from the right.") (((|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|))) (|Record| (|:| |leftHandLimit| (|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|))) "failed")) (|:| |rightHandLimit| (|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|))) "failed"))) "failed") (|Fraction| (|Polynomial| |#1|)) (|Equation| (|Fraction| (|Polynomial| |#1|)))) "\\spad{limit(f(x),x = a)} computes the real two-sided limit of \\spad{f} as its argument \\spad{x} approaches \\spad{a}.") (((|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|))) (|Record| (|:| |leftHandLimit| (|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|))) "failed")) (|:| |rightHandLimit| (|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|))) "failed"))) "failed") (|Fraction| (|Polynomial| |#1|)) (|Equation| (|OrderedCompletion| (|Polynomial| |#1|)))) "\\spad{limit(f(x),x = a)} computes the real two-sided limit of \\spad{f} as its argument \\spad{x} approaches \\spad{a}."))) 
 NIL 
 NIL 
-(-633 S R) 
+(-653 S R) 
 ((|constructor| (NIL "Test for linear dependence.")) (|solveLinear| (((|Union| (|Vector| (|Fraction| |#1|)) "failed") (|Vector| |#2|) |#2|) "\\spad{solveLinear([v1,...,vn], u)} returns \\spad{[c1,...,cn]} such that \\spad{c1*v1 + \\spad{...} + cn*vn = u}, \"failed\" if no such ci's exist in the quotient field of \\spad{S.}") (((|Union| (|Vector| |#1|) "failed") (|Vector| |#2|) |#2|) "\\spad{solveLinear([v1,...,vn], u)} returns \\spad{[c1,...,cn]} such that \\spad{c1*v1 + \\spad{...} + cn*vn = u}, \"failed\" if no such ci's exist in \\spad{S.}")) (|linearDependence| (((|Union| (|Vector| |#1|) "failed") (|Vector| |#2|)) "\\spad{linearDependence([v1,...,vn])} returns \\spad{[c1,...,cn]} if \\spad{c1*v1 + \\spad{...} + cn*vn = 0} and not all the ci's are 0, \"failed\" if the vi's are linearly independent over \\spad{S.}")) (|linearlyDependent?| (((|Boolean|) (|Vector| |#2|)) "\\spad{linearlyDependent?([v1,...,vn])} returns \\spad{true} if the vi's are linearly dependent over \\spad{S,} \\spad{false} otherwise."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368))) (-2959 (|HasCategory| |#1| (QUOTE (-368))))) 
-(-634 R) 
+((|HasCategory| |#1| (QUOTE (-388))) (-3252 (|HasCategory| |#1| (QUOTE (-388))))) 
+(-654 R) 
 ((|constructor| (NIL "An extension ring with an explicit linear dependence test.")) (|reducedSystem| (((|Record| (|:| |mat| (|Matrix| |#1|)) (|:| |vec| (|Vector| |#1|))) (|Matrix| $) (|Vector| $)) "\\spad{reducedSystem(A, \\spad{v)}} returns a matrix \\spad{B} and a vector \\spad{w} such that \\spad{A \\spad{x} = \\spad{v}} and \\spad{B \\spad{x} = \\spad{w}} have the same solutions in \\spad{R.}") (((|Matrix| |#1|) (|Matrix| $)) "\\spad{reducedSystem(A)} returns a matrix \\spad{B} such that \\spad{A \\spad{x} = 0} and \\spad{B \\spad{x} = 0} have the same solutions in \\spad{R.}"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-635 A B) 
+(-655 A B) 
 ((|constructor| (NIL "\\spadtype{ListToMap} allows mappings to be described by a pair of lists of equal lengths. The image of an element \\spad{x}, which appears in position \\spad{n} in the first list, is then the \\spad{n}th element of the second list. A default value or default function can be specified to be used when \\spad{x} does not appear in the first list. In the absence of defaults, an error will occur in that case.")) (|match| ((|#2| (|List| |#1|) (|List| |#2|) |#1| (|Mapping| |#2| |#1|)) "\\spad{match(la, \\spad{lb,} a, \\spad{f)}} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length. and applies this map to a. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb.} Argument \\spad{f} is a default function to call if a is not in la. The value returned is then obtained by applying \\spad{f} to argument a.") (((|Mapping| |#2| |#1|) (|List| |#1|) (|List| |#2|) (|Mapping| |#2| |#1|)) "\\spad{match(la, \\spad{lb,} \\spad{f)}} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb.} Argument \\spad{f} is used as the function to call when the given function argument is not in \\spad{la}. The value returned is \\spad{f} applied to that argument.") ((|#2| (|List| |#1|) (|List| |#2|) |#1| |#2|) "\\spad{match(la, \\spad{lb,} a, \\spad{b)}} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length. and applies this map to a. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb.} Argument \\spad{b} is the default target value if a is not in la. Error: if \\spad{la} and \\spad{lb} are not of equal length.") (((|Mapping| |#2| |#1|) (|List| |#1|) (|List| |#2|) |#2|) "\\spad{match(la, \\spad{lb,} \\spad{b)}} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length, where \\spad{b} is used as the default target value if the given function argument is not in \\spad{la}. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb.} Error: if \\spad{la} and \\spad{lb} are not of equal length.") ((|#2| (|List| |#1|) (|List| |#2|) |#1|) "\\spad{match(la, \\spad{lb,} a)} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length, where \\spad{a} is used as the default source value if the given one is not in \\spad{la}. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb.} Error: if \\spad{la} and \\spad{lb} are not of equal length.") (((|Mapping| |#2| |#1|) (|List| |#1|) (|List| |#2|)) "\\spad{match(la, lb)} creates a map with no default source or target values defined by lists \\spad{la} and \\spad{lb} of equal length. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb.} Error: if \\spad{la} and \\spad{lb} are not of equal length. Note that when this map is applied, an error occurs when applied to a value missing from la."))) 
 NIL 
 NIL 
-(-636 A B) 
+(-656 A B) 
 ((|constructor| (NIL "\\spadtype{ListFunctions2} implements utility functions that operate on two kinds of lists, each with a possibly different type of element.")) (|map| (((|List| |#2|) (|Mapping| |#2| |#1|) (|List| |#1|)) "\\spad{map(fn,u)} applies \\spad{fn} to each element of list \\spad{u} and returns a new list with the results. For example \\spad{map(square,[1,2,3]) = [1,4,9]}.")) (|reduce| ((|#2| (|Mapping| |#2| |#1| |#2|) (|List| |#1|) |#2|) "\\spad{reduce(fn,u,ident)} successively uses the binary function \\spad{fn} on the elements of list \\spad{u} and the result of previous applications. \\spad{ident} is returned if the \\spad{u} is empty. Note the order of application in the following examples: \\spad{reduce(fn,[1,2,3],0) = fn(3,fn(2,fn(1,0)))} and \\spad{reduce(*,[2,3],1) = 3 * \\spad{(2} * 1)}.")) (|scan| (((|List| |#2|) (|Mapping| |#2| |#1| |#2|) (|List| |#1|) |#2|) "\\spad{scan(fn,u,ident)} successively uses the binary function \\spad{fn} to reduce more and more of list \\spad{u}. \\spad{ident} is returned if the \\spad{u} is empty. The result is a list of the reductions at each step. See \\spadfun{reduce} for more information. Examples: \\spad{scan(fn,[1,2],0) = [fn(2,fn(1,0)),fn(1,0)]} and \\spad{scan(*,[2,3],1) = \\spad{[2} * 1, 3 * \\spad{(2} * 1)]}."))) 
 NIL 
 NIL 
-(-637 A B C) 
+(-657 A B C) 
 ((|constructor| (NIL "\\spadtype{ListFunctions3} implements utility functions that operate on three kinds of lists, each with a possibly different type of element.")) (|map| (((|List| |#3|) (|Mapping| |#3| |#1| |#2|) (|List| |#1|) (|List| |#2|)) "\\spad{map(fn,list1, u2)} applies the binary function \\spad{fn} to corresponding elements of lists \\spad{u1} and \\spad{u2} and returns a list of the results (in the same order). Thus \\spad{map(/,[1,2,3],[4,5,6]) = [1/4,2/4,1/2]}. The computation terminates when the end of either list is reached. That is, the length of the result list is equal to the minimum of the lengths of \\spad{u1} and \\spad{u2}."))) 
 NIL 
 NIL 
-(-638 S) 
+(-658 S) 
 ((|constructor| (NIL "\\spadtype{List} implements singly-linked lists that are addressable by indices; the index of the first element is 1. In addition to the operations provided by \\spadtype{IndexedList}, this constructor provides some LISP-like functions such as \\spadfun{null} and \\spadfun{cons}.")) (|setDifference| (($ $ $) "\\spad{setDifference(u1,u2)} returns a list of the elements of \\spad{u1} that are not also in \\spad{u2}. The order of elements in the resulting list is unspecified.")) (|setIntersection| (($ $ $) "\\spad{setIntersection(u1,u2)} returns a list of the elements that lists \\spad{u1} and \\spad{u2} have in common. The order of elements in the resulting list is unspecified.")) (|setUnion| (($ $ $) "\\spad{setUnion(u1,u2)} appends the two lists \\spad{u1} and u2, then removes all duplicates. The order of elements in the resulting list is unspecified.")) (|append| (($ $ $) "\\spad{append(u1,u2)} appends the elements of list \\spad{u1} onto the front of list \\spad{u2}. This new list and \\spad{u2} will share some structure.")) (|cons| (($ |#1| $) "\\spad{cons(element,u)} appends \\spad{element} onto the front of list \\spad{u} and returns the new list. This new list and the old one will share some structure.")) (|null| (((|Boolean|) $) "\\spad{null(u)} tests if list \\spad{u} is the empty list.")) (|nil| (($) "\\spad{nil()} returns the empty list."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-829))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-639 K PCS) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-850))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-659 K PCS) 
 ((|constructor| (NIL "Part of the PAFF package")) (|finiteSeries2LinSys| (((|Matrix| |#1|) (|List| |#2|) (|Integer|)) "\\spad{finiteSeries2LinSys(ls,n)} returns a matrix which right kernel is the solution of the linear combinations of the series in \\spad{ls} which has order greater or equal to \\spad{n.} NOTE: All the series in \\spad{ls} must be finite and must have order at least 0: so one must first call on each of them the function filterUpTo(s,n) and apply an appropriate shift (mult by a power of \\spad{t).}"))) 
 NIL 
 NIL 
-(-640 S) 
+(-660 S) 
 ((|constructor| (NIL "The \\spadtype{ListMultiDictionary} domain implements a dictionary with duplicates allowed. The representation is a list with duplicates represented explicitly. Hence most operations will be relatively inefficient when the number of entries in the dictionary becomes large. If the objects in the dictionary belong to an ordered set, the entries are maintained in ascending order.")) (|substitute| (($ |#1| |#1| $) "\\spad{substitute(x,y,d)} replace \\spad{x's} with \\spad{y's} in dictionary \\spad{d.}")) (|duplicates?| (((|Boolean|) $) "\\spad{duplicates?(d)} tests if dictionary \\spad{d} has duplicate entries."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545))))) 
-(-641 R) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565))))) 
+(-661 R) 
 ((|constructor| (NIL "The category of left modules over an \\spad{rng} (ring not necessarily with unit). This is an abelian group which supports left multiplation by elements of the rng. \\blankline Axioms\\br \\tab{5}\\spad{ (a*b)*x = a*(b*x) }\\br \\tab{5}\\spad{ (a+b)*x = (a*x)+(b*x) }\\br \\tab{5}\\spad{ a*(x+y) = (a*x)+(a*y) }")) (* (($ |#1| $) "\\spad{r*x} returns the left multiplication of the module element \\spad{x} by the ring element \\spad{r.}"))) 
 NIL 
 NIL 
-(-642 S E |un|) 
+(-662 S E |un|) 
 ((|constructor| (NIL "This internal package represents monoid (abelian or not, with or without inverses) as lists and provides some common operations to the various flavors of monoids.")) (|mapGen| (($ (|Mapping| |#1| |#1|) $) "\\spad{mapGen(f, \\spad{a1\\^e1} \\spad{...} an\\^en)} returns \\spad{f(a1)\\^e1 \\spad{...} f(an)\\^en}.")) (|mapExpon| (($ (|Mapping| |#2| |#2|) $) "\\spad{mapExpon(f, \\spad{a1\\^e1} \\spad{...} an\\^en)} returns \\spad{a1\\^f(e1) \\spad{...} an\\^f(en)}.")) (|commutativeEquality| (((|Boolean|) $ $) "\\spad{commutativeEquality(x,y)} returns \\spad{true} if \\spad{x} and \\spad{y} are equal assuming commutativity")) (|plus| (($ $ $) "\\spad{plus(x, \\spad{y)}} returns \\spad{x + \\spad{y}} where \\spad{+} is the monoid operation, which is assumed commutative.") (($ |#1| |#2| $) "\\spad{plus(s, e, \\spad{x)}} returns \\spad{e * \\spad{s} + \\spad{x}} where \\spad{+} is the monoid operation, which is assumed commutative.")) (|leftMult| (($ |#1| $) "\\spad{leftMult(s, a)} returns \\spad{s * a} where \\spad{*} is the monoid operation, which is assumed non-commutative.")) (|rightMult| (($ $ |#1|) "\\spad{rightMult(a, \\spad{s)}} returns \\spad{a * \\spad{s}} where \\spad{*} is the monoid operation, which is assumed non-commutative.")) (|makeUnit| (($) "\\spad{makeUnit()} returns the unit element of the monomial.")) (|size| (((|NonNegativeInteger|) $) "\\spad{size(l)} returns the number of monomials forming \\spad{l.}")) (|reverse!| (($ $) "\\spad{reverse!(l)} reverses the list of monomials forming \\spad{l,} destroying the element \\spad{l.}")) (|reverse| (($ $) "\\spad{reverse(l)} reverses the list of monomials forming \\spad{l.} This has some effect if the monoid is non-abelian, \\spadignore{i.e.} \\spad{reverse(a1\\^e1 \\spad{...} an\\^en) = an\\^en \\spad{...} a1\\^e1} which is different.")) (|nthFactor| ((|#1| $ (|Integer|)) "\\spad{nthFactor(l, \\spad{n)}} returns the factor of the n^th monomial of \\spad{l.}")) (|nthExpon| ((|#2| $ (|Integer|)) "\\spad{nthExpon(l, \\spad{n)}} returns the exponent of the n^th monomial of \\spad{l.}")) (|makeMulti| (($ (|List| (|Record| (|:| |gen| |#1|) (|:| |exp| |#2|)))) "\\spad{makeMulti(l)} returns the element whose list of monomials is \\spad{l.}")) (|makeTerm| (($ |#1| |#2|) "\\spad{makeTerm(s, e)} returns the monomial \\spad{s} exponentiated by \\spad{e} (\\spadignore{e.g.} s^e or \\spad{e} * \\spad{s).}")) (|listOfMonoms| (((|List| (|Record| (|:| |gen| |#1|) (|:| |exp| |#2|))) $) "\\spad{listOfMonoms(l)} returns the list of the monomials forming \\spad{l.}")) (|outputForm| (((|OutputForm|) $ (|Mapping| (|OutputForm|) (|OutputForm|) (|OutputForm|)) (|Mapping| (|OutputForm|) (|OutputForm|) (|OutputForm|)) (|Integer|)) "\\spad{outputForm(l, fop, fexp, unit)} converts the monoid element represented by \\spad{l} to an \\spadtype{OutputForm}. Argument unit is the output form for the \\spadignore{unit} of the monoid (\\spadignore{e.g.} 0 or 1), \\spad{fop(a, \\spad{b)}} is the output form for the monoid operation applied to \\spad{a} and \\spad{b} (\\spadignore{e.g.} \\spad{a + \\spad{b},} \\spad{a * \\spad{b},} \\spad{ab}), and \\spad{fexp(a, \\spad{n)}} is the output form for the exponentiation operation applied to \\spad{a} and \\spad{n} (\\spadignore{e.g.} \\spad{n a}, \\spad{n * a}, \\spad{a \\spad{**} \\spad{n},} \\spad{a\\^n})."))) 
 NIL 
 NIL 
-(-643 A S) 
+(-663 A S) 
 ((|constructor| (NIL "A linear aggregate is an aggregate whose elements are indexed by integers. Examples of linear aggregates are strings, lists, and arrays. Most of the exported operations for linear aggregates are non-destructive but are not always efficient for a particular aggregate. For example, \\spadfun{concat} of two lists needs only to copy its first argument, whereas \\spadfun{concat} of two arrays needs to copy both arguments. Most of the operations exported here apply to infinite objects (\\spadignore{e.g.} streams) as well to finite ones. For finite linear aggregates, see \\spadtype{FiniteLinearAggregate}.")) (|setelt| ((|#2| $ (|UniversalSegment| (|Integer|)) |#2|) "\\spad{setelt(u,i..j,x)} (also written: \\axiom{u(i..j) \\spad{:=} \\spad{x})} destructively replaces each element in the segment \\axiom{u(i..j)} by \\spad{x.} The value \\spad{x} is returned. Note that \\spad{u} is destructively change so that \\axiom{u.k \\spad{:=} \\spad{x} for \\spad{k} in i..j}; its length remains unchanged.")) (|insert| (($ $ $ (|Integer|)) "\\spad{insert(v,u,k)} returns a copy of \\spad{u} having \\spad{v} inserted beginning at the \\axiom{i}th element. Note that \\axiom{insert(v,u,k) = concat( u(0..k-1), \\spad{v,} u(k..) \\spad{)}.}") (($ |#2| $ (|Integer|)) "\\spad{insert(x,u,i)} returns a copy of \\spad{u} having \\spad{x} as its \\axiom{i}th element. Note that \\axiom{insert(x,a,k) = concat(concat(a(0..k-1),x),a(k..))}.")) (|delete| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{delete(u,i..j)} returns a copy of \\spad{u} with the \\axiom{i}th through \\axiom{j}th element deleted. Note that \\axiom{delete(a,i..j) = concat(a(0..i-1),a(j+1..))}.") (($ $ (|Integer|)) "\\spad{delete(u,i)} returns a copy of \\spad{u} with the \\axiom{i}th element deleted. Note that for lists, \\axiom{delete(a,i) \\spad{==} concat(a(0..i - 1),a(i + 1,..))}.")) (|elt| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{elt(u,i..j)} (also written: \\axiom{a(i..j)}) returns the aggregate of elements \\axiom{u} for \\spad{k} from \\spad{i} to \\spad{j} in that order. Note that in general, \\axiom{a.s = [a.k for \\spad{i} in s]}.")) (|map| (($ (|Mapping| |#2| |#2| |#2|) $ $) "\\spad{map(f,u,v)} returns a new collection \\spad{w} with elements \\axiom{z = f(x,y)} for corresponding elements \\spad{x} and \\spad{y} from \\spad{u} and \\spad{v.} Note that for linear aggregates, \\axiom{w.i = f(u.i,v.i)}.")) (|concat| (($ (|List| $)) "\\spad{concat(u)}, where \\spad{u} is a lists of aggregates \\axiom{[a,b,...,c]}, returns a single aggregate consisting of the elements of \\axiom{a} followed by those of \\spad{b} followed \\spad{...} by the elements of \\spad{c.} Note that \\axiom{concat(a,b,...,c) = concat(a,concat(b,...,c))}.") (($ $ $) "\\spad{concat(u,v)} returns an aggregate consisting of the elements of \\spad{u} followed by the elements of \\spad{v.} Note that if \\axiom{w = concat(u,v)} then \\axiom{w.i = u.i for \\spad{i} in indices u} and \\axiom{w.(j + maxIndex u) = \\spad{v.j} for \\spad{j} in indices \\spad{v}.}") (($ |#2| $) "\\spad{concat(x,u)} returns aggregate \\spad{u} with additional element at the front. Note that for lists: \\axiom{concat(x,u) \\spad{==} concat([x],u)}.") (($ $ |#2|) "\\spad{concat(u,x)} returns aggregate \\spad{u} with additional element \\spad{x} at the end. Note that for lists, \\axiom{concat(u,x) \\spad{==} concat(u,[x])}")) (|new| (($ (|NonNegativeInteger|) |#2|) "\\spad{new(n,x)} returns \\axiom{fill!(new n,x)}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4603))) 
-(-644 S) 
+((|HasAttribute| |#1| (QUOTE -4626))) 
+(-664 S) 
 ((|constructor| (NIL "A linear aggregate is an aggregate whose elements are indexed by integers. Examples of linear aggregates are strings, lists, and arrays. Most of the exported operations for linear aggregates are non-destructive but are not always efficient for a particular aggregate. For example, \\spadfun{concat} of two lists needs only to copy its first argument, whereas \\spadfun{concat} of two arrays needs to copy both arguments. Most of the operations exported here apply to infinite objects (\\spadignore{e.g.} streams) as well to finite ones. For finite linear aggregates, see \\spadtype{FiniteLinearAggregate}.")) (|setelt| ((|#1| $ (|UniversalSegment| (|Integer|)) |#1|) "\\spad{setelt(u,i..j,x)} (also written: \\axiom{u(i..j) \\spad{:=} \\spad{x})} destructively replaces each element in the segment \\axiom{u(i..j)} by \\spad{x.} The value \\spad{x} is returned. Note that \\spad{u} is destructively change so that \\axiom{u.k \\spad{:=} \\spad{x} for \\spad{k} in i..j}; its length remains unchanged.")) (|insert| (($ $ $ (|Integer|)) "\\spad{insert(v,u,k)} returns a copy of \\spad{u} having \\spad{v} inserted beginning at the \\axiom{i}th element. Note that \\axiom{insert(v,u,k) = concat( u(0..k-1), \\spad{v,} u(k..) \\spad{)}.}") (($ |#1| $ (|Integer|)) "\\spad{insert(x,u,i)} returns a copy of \\spad{u} having \\spad{x} as its \\axiom{i}th element. Note that \\axiom{insert(x,a,k) = concat(concat(a(0..k-1),x),a(k..))}.")) (|delete| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{delete(u,i..j)} returns a copy of \\spad{u} with the \\axiom{i}th through \\axiom{j}th element deleted. Note that \\axiom{delete(a,i..j) = concat(a(0..i-1),a(j+1..))}.") (($ $ (|Integer|)) "\\spad{delete(u,i)} returns a copy of \\spad{u} with the \\axiom{i}th element deleted. Note that for lists, \\axiom{delete(a,i) \\spad{==} concat(a(0..i - 1),a(i + 1,..))}.")) (|elt| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{elt(u,i..j)} (also written: \\axiom{a(i..j)}) returns the aggregate of elements \\axiom{u} for \\spad{k} from \\spad{i} to \\spad{j} in that order. Note that in general, \\axiom{a.s = [a.k for \\spad{i} in s]}.")) (|map| (($ (|Mapping| |#1| |#1| |#1|) $ $) "\\spad{map(f,u,v)} returns a new collection \\spad{w} with elements \\axiom{z = f(x,y)} for corresponding elements \\spad{x} and \\spad{y} from \\spad{u} and \\spad{v.} Note that for linear aggregates, \\axiom{w.i = f(u.i,v.i)}.")) (|concat| (($ (|List| $)) "\\spad{concat(u)}, where \\spad{u} is a lists of aggregates \\axiom{[a,b,...,c]}, returns a single aggregate consisting of the elements of \\axiom{a} followed by those of \\spad{b} followed \\spad{...} by the elements of \\spad{c.} Note that \\axiom{concat(a,b,...,c) = concat(a,concat(b,...,c))}.") (($ $ $) "\\spad{concat(u,v)} returns an aggregate consisting of the elements of \\spad{u} followed by the elements of \\spad{v.} Note that if \\axiom{w = concat(u,v)} then \\axiom{w.i = u.i for \\spad{i} in indices u} and \\axiom{w.(j + maxIndex u) = \\spad{v.j} for \\spad{j} in indices \\spad{v}.}") (($ |#1| $) "\\spad{concat(x,u)} returns aggregate \\spad{u} with additional element at the front. Note that for lists: \\axiom{concat(x,u) \\spad{==} concat([x],u)}.") (($ $ |#1|) "\\spad{concat(u,x)} returns aggregate \\spad{u} with additional element \\spad{x} at the end. Note that for lists, \\axiom{concat(u,x) \\spad{==} concat(u,[x])}")) (|new| (($ (|NonNegativeInteger|) |#1|) "\\spad{new(n,x)} returns \\axiom{fill!(new n,x)}."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-645 K) 
+(-665 K) 
 ((|printInfo| (((|Boolean|)) "returns the value of the \\spad{printInfo} flag.") (((|Boolean|) (|Boolean|)) "\\spad{printInfo(b)} set a flag such that when \\spad{true} \\spad{(b} \\spad{<-} true) prints some information during some critical computation.")) (|coefOfFirstNonZeroTerm| ((|#1| $) "\\spad{coefOfFirstNonZeroTerm(s)} returns the first non zero coefficient of the series.")) (|filterUpTo| (($ $ (|Integer|)) "\\spad{filterUpTo(s,n)} returns the series consisting of the terms of \\spad{s} having degree strictly less than \\spad{n.}")) (|shift| (($ $ (|Integer|)) "\\spad{shift(s,n)} returns t**n * \\spad{s}")) (|series| (($ (|Integer|) |#1| $) "\\spad{series(e,c,s)} create the series c*t**e + \\spad{s.}")) (|removeZeroes| (($ $) "\\spad{removeZeroes(s)} removes the zero terms in \\spad{s.}") (($ (|Integer|) $) "\\spad{removeZeroes(n,s)} removes the zero terms in the first \\spad{n} terms of \\spad{s.}")) (|monomial2series| (($ (|List| $) (|List| (|NonNegativeInteger|)) (|Integer|)) "\\spad{monomial2series(ls,le,n)} returns t**n * reduce(\"*\",[s \\spad{**} \\spad{e} for \\spad{s} in \\spad{ls} for \\spad{e} in le])")) (|delay| (($ (|Mapping| $)) "\\spad{delay delayed} the computation of the next term of the series given by the input function.")) (|posExpnPart| (($ $) "\\spad{posExpnPart(s)} returns the series \\spad{s} less the terms with negative exponant.")) (|order| (((|Integer|) $) "\\spad{order(s)} returns the order of \\spad{s.}"))) 
-(((-4604 "*") . T) (-4595 . T) (-4594 . T) (-4600 . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") . T) (-4618 . T) (-4617 . T) (-4623 . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-646 R -3313 L) 
+(-666 R -3958 L) 
 ((|constructor| (NIL "\\spad{ElementaryFunctionLODESolver} provides the top-level functions for finding closed form solutions of linear ordinary differential equations and initial value problems.")) (|solve| (((|Union| |#2| "failed") |#3| |#2| (|Symbol|) |#2| (|List| |#2|)) "\\spad{solve(op, \\spad{g,} \\spad{x,} a, [y0,...,ym])} returns either the solution of the initial value problem \\spad{op \\spad{y} = \\spad{g,} y(a) = \\spad{y0,} y'(a) = y1,...} or \"failed\" if the solution cannot be found; \\spad{x} is the dependent variable.") (((|Union| (|Record| (|:| |particular| |#2|) (|:| |basis| (|List| |#2|))) "failed") |#3| |#2| (|Symbol|)) "\\spad{solve(op, \\spad{g,} \\spad{x)}} returns either a solution of the ordinary differential equation \\spad{op \\spad{y} = \\spad{g}} or \"failed\" if no non-trivial solution can be found; When found, the solution is returned in the form \\spad{[h, [b1,...,bm]]} where \\spad{h} is a particular solution and and \\spad{[b1,...bm]} are linearly independent solutions of the associated homogenuous equation \\spad{op \\spad{y} = 0}. A full basis for the solutions of the homogenuous equation is not always returned, only the solutions which were found; \\spad{x} is the dependent variable."))) 
 NIL 
 NIL 
-(-647 A) 
+(-667 A) 
 ((|constructor| (NIL "\\spad{LinearOrdinaryDifferentialOperator1} defines a ring of differential operators with coefficients in a differential ring A. Multiplication of operators corresponds to functional composition:\\br \\spad{(L1 * L2).(f) = \\spad{L1} \\spad{L2} \\spad{f}}"))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-648 A M) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-668 A M) 
 ((|constructor| (NIL "\\spad{LinearOrdinaryDifferentialOperator2} defines a ring of differential operators with coefficients in a differential ring A and acting on an A-module \\spad{M.} Multiplication of operators corresponds to functional composition:\\br \\spad{(L1 * L2).(f) = \\spad{L1} \\spad{L2} \\spad{f}}")) (|differentiate| (($ $) "\\spad{differentiate(x)} returns the derivative of \\spad{x}"))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-649 S A) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-669 S A) 
 ((|constructor| (NIL "LinearOrdinaryDifferentialOperatorCategory is the category of differential operators with coefficients in a ring A with a given derivation. \\blankline Multiplication of operators corresponds to functional composition:\\br \\spad{(L1} * L2).(f) = \\spad{L1} \\spad{L2} \\spad{f}")) (|directSum| (($ $ $) "\\spad{directSum(a,b)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the sums of a solution of \\spad{a} by a solution of \\spad{b}.")) (|symmetricSquare| (($ $) "\\spad{symmetricSquare(a)} computes \\spad{symmetricProduct(a,a)} using a more efficient method.")) (|symmetricPower| (($ $ (|NonNegativeInteger|)) "\\spad{symmetricPower(a,n)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of \\spad{n} solutions of \\spad{a}.")) (|symmetricProduct| (($ $ $) "\\spad{symmetricProduct(a,b)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of a solution of \\spad{a} by a solution of \\spad{b}.")) (|adjoint| (($ $) "\\spad{adjoint(a)} returns the adjoint operator of a.")) (D (($) "\\spad{D()} provides the operator corresponding to a derivation in the ring \\spad{A}."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-368)))) 
-(-650 A) 
+((|HasCategory| |#2| (QUOTE (-388)))) 
+(-670 A) 
 ((|constructor| (NIL "LinearOrdinaryDifferentialOperatorCategory is the category of differential operators with coefficients in a ring A with a given derivation. \\blankline Multiplication of operators corresponds to functional composition:\\br \\spad{(L1} * L2).(f) = \\spad{L1} \\spad{L2} \\spad{f}")) (|directSum| (($ $ $) "\\spad{directSum(a,b)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the sums of a solution of \\spad{a} by a solution of \\spad{b}.")) (|symmetricSquare| (($ $) "\\spad{symmetricSquare(a)} computes \\spad{symmetricProduct(a,a)} using a more efficient method.")) (|symmetricPower| (($ $ (|NonNegativeInteger|)) "\\spad{symmetricPower(a,n)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of \\spad{n} solutions of \\spad{a}.")) (|symmetricProduct| (($ $ $) "\\spad{symmetricProduct(a,b)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of a solution of \\spad{a} by a solution of \\spad{b}.")) (|adjoint| (($ $) "\\spad{adjoint(a)} returns the adjoint operator of a.")) (D (($) "\\spad{D()} provides the operator corresponding to a derivation in the ring \\spad{A}."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-651 -3313 UP) 
+(-671 -3958 UP) 
 ((|constructor| (NIL "\\spadtype{LinearOrdinaryDifferentialOperatorFactorizer} provides a factorizer for linear ordinary differential operators whose coefficients are rational functions.")) (|factor1| (((|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) "\\spad{factor1(a)} returns the factorisation of a, assuming that a has no first-order right factor.")) (|factor| (((|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) "\\spad{factor(a)} returns the factorisation of a.") (((|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|)) (|Mapping| (|List| |#1|) |#2|)) "\\spad{factor(a, zeros)} returns the factorisation of a. \\spad{zeros} is a zero finder in \\spad{UP}."))) 
 NIL 
 ((|HasCategory| |#1| (QUOTE (-27)))) 
-(-652 A -3903) 
+(-672 A -2485) 
 ((|constructor| (NIL "\\spad{LinearOrdinaryDifferentialOperator} defines a ring of differential operators with coefficients in a ring A with a given derivation. Multiplication of operators corresponds to functional composition:\\br \\spad{(L1 * L2).(f) = \\spad{L1} \\spad{L2} \\spad{f}}"))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-653 A L) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-673 A L) 
 ((|constructor| (NIL "\\spad{LinearOrdinaryDifferentialOperatorsOps} provides symmetric products and sums for linear ordinary differential operators.")) (|directSum| ((|#2| |#2| |#2| (|Mapping| |#1| |#1|)) "\\spad{directSum(a,b,D)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the sums of a solution of \\spad{a} by a solution of \\spad{b}. \\spad{D} is the derivation to use.")) (|symmetricPower| ((|#2| |#2| (|NonNegativeInteger|) (|Mapping| |#1| |#1|)) "\\spad{symmetricPower(a,n,D)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of \\spad{n} solutions of \\spad{a}. \\spad{D} is the derivation to use.")) (|symmetricProduct| ((|#2| |#2| |#2| (|Mapping| |#1| |#1|)) "\\spad{symmetricProduct(a,b,D)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of a solution of \\spad{a} by a solution of \\spad{b}. \\spad{D} is the derivation to use."))) 
 NIL 
 NIL 
-(-654 S) 
+(-674 S) 
 ((|constructor| (NIL "Logic provides the basic operations for lattices, for example, boolean algebra.")) (|\\/| (($ $ $) "\\spadignore{\\/} returns the logical `join', for example, `or'.")) (|/\\| (($ $ $) "\\spadignore{/\\} returns the logical `meet', for example, `and'.")) (~ (($ $) "\\spad{~(x)} returns the logical complement of \\spad{x.}"))) 
 NIL 
 NIL 
-(-655) 
+(-675) 
 ((|constructor| (NIL "Logic provides the basic operations for lattices, for example, boolean algebra.")) (|\\/| (($ $ $) "\\spadignore{\\/} returns the logical `join', for example, `or'.")) (|/\\| (($ $ $) "\\spadignore{/\\} returns the logical `meet', for example, `and'.")) (~ (($ $) "\\spad{~(x)} returns the logical complement of \\spad{x.}"))) 
 NIL 
 NIL 
-(-656 M R S) 
+(-676 M R S) 
 ((|constructor| (NIL "Localize(M,R,S) produces fractions with numerators from an \\spad{R} module \\spad{M} and denominators from some multiplicative subset \\spad{D} of \\spad{R.}")) (|denom| ((|#3| $) "\\spad{denom \\spad{x}} returns the denominator of \\spad{x.}")) (|numer| ((|#1| $) "\\spad{numer \\spad{x}} returns the numerator of \\spad{x.}")) (/ (($ |#1| |#3|) "\\spad{m / \\spad{d}} divides the element \\spad{m} by \\spad{d.}") (($ $ |#3|) "\\spad{x / \\spad{d}} divides the element \\spad{x} by \\spad{d.}"))) 
-((-4597 . T) (-4596 . T)) 
-((|HasCategory| |#1| (QUOTE (-792)))) 
-(-657 K) 
+((-4620 . T) (-4619 . T)) 
+((|HasCategory| |#1| (QUOTE (-813)))) 
+(-677 K) 
 ((|constructor| (NIL "A package that exports several linear algebra operations over lines of matrices. Part of the PAFF package.")) (|reduceRowOnList| (((|List| (|List| |#1|)) (|List| |#1|) (|List| (|List| |#1|))) "\\spad{reduceRowOnList(v,lvec)} applies a row reduction on each of the element of \\spad{lv} using \\spad{v} according to a pivot in \\spad{v} which is set to be the first non nul element in \\spad{v.}")) (|reduceLineOverLine| (((|List| |#1|) (|List| |#1|) (|List| |#1|) |#1|) "\\spad{reduceLineOverLine(v1,v2,a)} returns \\spad{v1-a*v1} where \\indented{1}{v1 and \\spad{v2} are considered as vector space.}")) (|quotVecSpaceBasis| (((|List| (|List| |#1|)) (|List| (|List| |#1|)) (|List| (|List| |#1|))) "\\spad{quotVecSpaceBasis(b1,b2)} returns a basis of \\spad{V1/V2} where \\spad{V1} and \\spad{V2} are vector space with basis \\spad{b1} and \\spad{b2} resp. and \\spad{V2} is suppose to be include in \\spad{V1;} Note that if it is not the case then it returs the basis of V1/W where \\spad{W} = intersection of \\spad{V1} and \\spad{V2}")) (|reduceRow| (((|List| (|List| |#1|)) (|List| (|List| |#1|))) "reduceRow: if the input is considered as a matrix, the output would be the row reduction matrix. It's almost the rowEchelon form except that no permution of lines is performed."))) 
 NIL 
 NIL 
-(-658 K |symb| |PolyRing| E |ProjPt| PCS |Plc|) 
+(-678) 
+((|constructor| (NIL "This is the category of left ore rings, that is noncommutative rings without zero divisors where we can compute the least left common multiple.")) (|lcmCoef| (((|Record| (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) "\\spad{lcmCoef(c1, c2)} computes (llcm_res, coeff1, coeff2) such that llcm_res is least left common multiple of \\spad{c1} and \\spad{c2} and llcm_res = \\spad{coeff1*c1} = \\spad{coeff2*c2}"))) 
+((-4618 . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+NIL 
+(-679 K |symb| |PolyRing| E |ProjPt| PCS |Plc|) 
 ((|constructor| (NIL "This package is part of the PAFF package")) (|localize| (((|Record| (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (|List| (|Integer|)))) |#3| |#5| |#3| (|Integer|)) "\\spad{localize(f,pt,crv,n)} returns a record containing the polynomials \\spad{f} and \\spad{crv} translate to the origin with respect to \\spad{pt.} The last element of the records, consisting of three integers contains information about the local parameter that will be used (either \\spad{x} or \\spad{y):} the first integer correspond to the variable that will be used as a local parameter.")) (|pointDominateBy| ((|#5| |#7|) "\\spad{pointDominateBy(pl)} returns the projective point dominated by the place \\spad{pl.}")) (|localParamOfSimplePt| (((|List| |#6|) |#5| |#3| (|Integer|)) "\\spad{localParamOfSimplePt(pt,pol,n)} computes the local parametrization of the simple point \\spad{pt} on the curve defined by pol. This local parametrization is done according to the standard open affine plane set by \\spad{n}")) (|pointToPlace| ((|#7| |#5| |#3|) "\\spad{pointToPlace(pt,pol)} takes for input a simple point \\spad{pt} on the curve defined by \\spad{pol} and set the local parametrization of the point.")) (|printInfo| (((|Boolean|)) "returns the value of the \\spad{printInfo} flag.") (((|Boolean|) (|Boolean|)) "\\spad{printInfo(b)} set a flag such that when \\spad{true} \\spad{(b} \\spad{<-} true) prints some information during some critical computation."))) 
 NIL 
 NIL 
-(-659 R) 
+(-680 R) 
 ((|constructor| (NIL "Given a PolynomialFactorizationExplicit ring, this package provides a defaulting rule for the \\spad{solveLinearPolynomialEquation} operation, by moving into the field of fractions, and solving it there via the \\spad{multiEuclidean} operation.")) (|solveLinearPolynomialEquationByFractions| (((|Union| (|List| (|SparseUnivariatePolynomial| |#1|)) "failed") (|List| (|SparseUnivariatePolynomial| |#1|)) (|SparseUnivariatePolynomial| |#1|)) "\\spad{solveLinearPolynomialEquationByFractions([f1, ..., fn], \\spad{g)}} (where the \\spad{fi} are relatively prime to each other) returns a list of \\spad{ai} such that \\spad{g/prod \\spad{fi} = sum ai/fi} or returns \"failed\" if no such exists."))) 
 NIL 
 NIL 
-(-660 |VarSet| R) 
+(-681 |VarSet| R) 
 ((|constructor| (NIL "This type supports Lie polynomials in Lyndon basis see Free Lie Algebras by \\spad{C.} Reutenauer (Oxford science publications).")) (|construct| (($ $ (|LyndonWord| |#1|)) "\\axiom{construct(x,y)} returns the Lie bracket \\axiom{[x,y]}.") (($ (|LyndonWord| |#1|) $) "\\axiom{construct(x,y)} returns the Lie bracket \\axiom{[x,y]}.") (($ (|LyndonWord| |#1|) (|LyndonWord| |#1|)) "\\axiom{construct(x,y)} returns the Lie bracket \\axiom{[x,y]}.")) (|LiePolyIfCan| (((|Union| $ "failed") (|XDistributedPolynomial| |#1| |#2|)) "\\axiom{LiePolyIfCan(p)} returns \\axiom{p} in Lyndon basis if \\axiom{p} is a Lie polynomial, otherwise \\axiom{\"failed\"} is returned."))) 
-((|JacobiIdentity| . T) (|NullSquare| . T) (-4597 . T) (-4596 . T)) 
-((|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-174)))) 
-(-661 A S) 
+((|JacobiIdentity| . T) (|NullSquare| . T) (-4620 . T) (-4619 . T)) 
+((|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-194)))) 
+(-682 A S) 
 ((|constructor| (NIL "A list aggregate is a model for a linked list data structure. A linked list is a versatile data structure. Insertion and deletion are efficient and searching is a linear operation.")) (|list| (($ |#2|) "\\spad{list(x)} returns the list of one element \\spad{x.}"))) 
 NIL 
 NIL 
-(-662 S) 
+(-683 S) 
 ((|constructor| (NIL "A list aggregate is a model for a linked list data structure. A linked list is a versatile data structure. Insertion and deletion are efficient and searching is a linear operation.")) (|list| (($ |#1|) "\\spad{list(x)} returns the list of one element \\spad{x.}"))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-663 -3313) 
+(-684 -3958) 
 ((|constructor| (NIL "This package solves linear system in the matrix form \\spad{AX = \\spad{B}.} It is essentially a particular instantiation of the package \\spadtype{LinearSystemMatrixPackage} for Matrix and Vector. This package's existence makes it easier to use \\spadfun{solve} in the AXIOM interpreter.")) (|rank| (((|NonNegativeInteger|) (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{rank(A,B)} computes the rank of the complete matrix \\spad{(A|B)} of the linear system \\spad{AX = \\spad{B}.}")) (|hasSolution?| (((|Boolean|) (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{hasSolution?(A,B)} tests if the linear system \\spad{AX = \\spad{B}} has a solution.")) (|particularSolution| (((|Union| (|Vector| |#1|) "failed") (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{particularSolution(A,B)} finds a particular solution of the linear system \\spad{AX = \\spad{B}.}")) (|solve| (((|List| (|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|))))) (|List| (|List| |#1|)) (|List| (|Vector| |#1|))) "\\spad{solve(A,LB)} finds a particular soln of the systems \\spad{AX = \\spad{B}} and a basis of the associated homogeneous systems \\spad{AX = 0} where \\spad{B} varies in the list of column vectors \\spad{LB.}") (((|List| (|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|))))) (|Matrix| |#1|) (|List| (|Vector| |#1|))) "\\spad{solve(A,LB)} finds a particular soln of the systems \\spad{AX = \\spad{B}} and a basis of the associated homogeneous systems \\spad{AX = 0} where \\spad{B} varies in the list of column vectors \\spad{LB.}") (((|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|)))) (|List| (|List| |#1|)) (|Vector| |#1|)) "\\spad{solve(A,B)} finds a particular solution of the system \\spad{AX = \\spad{B}} and a basis of the associated homogeneous system \\spad{AX = 0}.") (((|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|)))) (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{solve(A,B)} finds a particular solution of the system \\spad{AX = \\spad{B}} and a basis of the associated homogeneous system \\spad{AX = 0}."))) 
 NIL 
 NIL 
-(-664 -3313 |Row| |Col| M) 
+(-685 -3958 |Row| |Col| M) 
 ((|constructor| (NIL "This package solves linear system in the matrix form \\spad{AX = \\spad{B}.}")) (|rank| (((|NonNegativeInteger|) |#4| |#3|) "\\spad{rank(A,B)} computes the rank of the complete matrix \\spad{(A|B)} of the linear system \\spad{AX = \\spad{B}.}")) (|hasSolution?| (((|Boolean|) |#4| |#3|) "\\spad{hasSolution?(A,B)} tests if the linear system \\spad{AX = \\spad{B}} has a solution.")) (|particularSolution| (((|Union| |#3| "failed") |#4| |#3|) "\\spad{particularSolution(A,B)} finds a particular solution of the linear system \\spad{AX = \\spad{B}.}")) (|solve| (((|List| (|Record| (|:| |particular| (|Union| |#3| "failed")) (|:| |basis| (|List| |#3|)))) |#4| (|List| |#3|)) "\\spad{solve(A,LB)} finds a particular soln of the systems \\spad{AX = \\spad{B}} and a basis of the associated homogeneous systems \\spad{AX = 0} where \\spad{B} varies in the list of column vectors \\spad{LB.}") (((|Record| (|:| |particular| (|Union| |#3| "failed")) (|:| |basis| (|List| |#3|))) |#4| |#3|) "\\spad{solve(A,B)} finds a particular solution of the system \\spad{AX = \\spad{B}} and a basis of the associated homogeneous system \\spad{AX = 0}."))) 
 NIL 
 NIL 
-(-665 R E OV P) 
+(-686 R E OV P) 
 ((|constructor| (NIL "This package finds the solutions of linear systems presented as a list of polynomials.")) (|linSolve| (((|Record| (|:| |particular| (|Union| (|Vector| (|Fraction| |#4|)) "failed")) (|:| |basis| (|List| (|Vector| (|Fraction| |#4|))))) (|List| |#4|) (|List| |#3|)) "\\spad{linSolve(lp,lvar)} finds the solutions of the linear system of polynomials \\spad{lp} = 0 with respect to the list of symbols lvar."))) 
 NIL 
 NIL 
-(-666 |n| R) 
+(-687 |n| R) 
 ((|constructor| (NIL "LieSquareMatrix(n,R) implements the Lie algebra of the \\spad{n} by \\spad{n} matrices over the commutative ring \\spad{R.} The Lie bracket (commutator) of the algebra is given by\\br \\spad{a*b \\spad{:=} (a *$SQMATRIX(n,R) \\spad{b} - \\spad{b} *$SQMATRIX(n,R) a)},\\br where \\spadfun{*$SQMATRIX(n,R)} is the usual matrix multiplication."))) 
-((-4599 . T) (-4602 . T) (-4596 . T) (-4597 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227))) (|HasAttribute| |#2| (QUOTE (-4604 "*"))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-303))) (|HasCategory| |#2| (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-562))) (-1841 (|HasAttribute| |#2| (QUOTE (-4604 "*"))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098))))) (|HasCategory| |#2| (QUOTE (-174)))) 
-(-667 |VarSet|) 
+((-4622 . T) (-4625 . T) (-4619 . T) (-4620 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247))) (|HasAttribute| |#2| (QUOTE (-4627 "*"))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-323))) (|HasCategory| |#2| (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-582))) (-3836 (|HasAttribute| |#2| (QUOTE (-4627 "*"))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119))))) (|HasCategory| |#2| (QUOTE (-194)))) 
+(-688 |VarSet|) 
 ((|constructor| (NIL "Lyndon words over arbitrary (ordered) symbols: see Free Lie Algebras by \\spad{C.} Reutenauer (Oxford science publications). A Lyndon word is a word which is smaller than any of its right factors w.r.t. the pure lexicographical ordering. If \\axiom{a} and \\axiom{b} are two Lyndon words such that \\axiom{a < \\spad{b}} holds w.r.t lexicographical ordering then \\axiom{a*b} is a Lyndon word. Parenthesized Lyndon words can be generated from symbols by using the following rule:\\br \\axiom{[[a,b],c]} is a Lyndon word iff \\axiom{a*b < \\spad{c} \\spad{<=} \\spad{b}} holds.\\br Lyndon words are internally represented by binary trees using the \\spadtype{Magma} domain constructor. Two ordering are provided: lexicographic and length-lexicographic.")) (|LyndonWordsList| (((|List| $) (|List| |#1|) (|PositiveInteger|)) "\\axiom{LyndonWordsList(vl, \\spad{n)}} returns the list of Lyndon words over the alphabet \\axiom{vl}, up to order \\axiom{n}.")) (|LyndonWordsList1| (((|OneDimensionalArray| (|List| $)) (|List| |#1|) (|PositiveInteger|)) "\\axiom{LyndonWordsList1(vl, \\spad{n)}} returns an array of lists of Lyndon words over the alphabet \\axiom{vl}, up to order \\axiom{n}.")) (|varList| (((|List| |#1|) $) "\\axiom{varList(x)} returns the list of distinct entries of \\axiom{x}.")) (|lyndonIfCan| (((|Union| $ "failed") (|OrderedFreeMonoid| |#1|)) "\\axiom{lyndonIfCan(w)} convert \\axiom{w} into a Lyndon word.")) (|lyndon| (($ (|OrderedFreeMonoid| |#1|)) "\\axiom{lyndon(w)} convert \\axiom{w} into a Lyndon word, error if \\axiom{w} is not a Lyndon word.")) (|lyndon?| (((|Boolean|) (|OrderedFreeMonoid| |#1|)) "\\axiom{lyndon?(w)} test if \\axiom{w} is a Lyndon word.")) (|factor| (((|List| $) (|OrderedFreeMonoid| |#1|)) "\\axiom{factor(x)} returns the decreasing factorization into Lyndon words.")) (|coerce| (((|Magma| |#1|) $) "\\axiom{coerce(x)} returns the element of \\axiomType{Magma}(VarSet) corresponding to \\axiom{x}.") (((|OrderedFreeMonoid| |#1|) $) "\\axiom{coerce(x)} returns the element of \\axiomType{OrderedFreeMonoid}(VarSet) corresponding to \\axiom{x}.")) (|lexico| (((|Boolean|) $ $) "\\axiom{lexico(x,y)} returns \\axiom{true} iff \\axiom{x} is smaller than \\axiom{y} w.r.t. the lexicographical ordering induced by \\axiom{VarSet}.")) (|length| (((|PositiveInteger|) $) "\\axiom{length(x)} returns the number of entries in \\axiom{x}.")) (|right| (($ $) "\\axiom{right(x)} returns right subtree of \\axiom{x} or error if retractable?(x) is true.")) (|left| (($ $) "\\axiom{left(x)} returns left subtree of \\axiom{x} or error if retractable?(x) is true.")) (|retractable?| (((|Boolean|) $) "\\axiom{retractable?(x)} tests if \\axiom{x} is a tree with only one entry."))) 
 NIL 
 NIL 
-(-668 A S) 
+(-689 A S) 
 ((|constructor| (NIL "LazyStreamAggregate is the category of streams with lazy evaluation. It is understood that the function 'empty?' will cause lazy evaluation if necessary to determine if there are entries. Functions which call 'empty?', for example 'first' and 'rest', will also cause lazy evaluation if necessary.")) (|complete| (($ $) "\\spad{complete(st)} causes all entries of 'st' to be computed. \\indented{1}{this function should only be called on streams which are} \\indented{1}{known to be finite.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..] \\spad{X} n:=filterUntil(i+->i>100,m) \\spad{X} numberOfComputedEntries \\spad{n} \\spad{X} complete \\spad{n} \\spad{X} numberOfComputedEntries \\spad{n}")) (|extend| (($ $ (|Integer|)) "\\spad{extend(st,n)} causes entries to be computed, if necessary, \\indented{1}{so that 'st' will have at least \\spad{'n'} explicit entries or so} \\indented{1}{that all entries of 'st' will be computed if 'st' is finite} \\indented{1}{with length \\spad{<=} \\spad{n.}} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} numberOfComputedEntries \\spad{m} \\spad{X} extend(m,20) \\spad{X} numberOfComputedEntries \\spad{m}")) (|numberOfComputedEntries| (((|NonNegativeInteger|) $) "\\spad{numberOfComputedEntries(st)} returns the number of explicitly \\indented{1}{computed entries of stream \\spad{st} which exist immediately prior to the} \\indented{1}{time this function is called.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} numberOfComputedEntries \\spad{m}")) (|rst| (($ $) "\\spad{rst(s)} returns a pointer to the next node of stream \\spad{s.} \\indented{1}{Cautrion: this function should only be called after a \\spad{empty?}} \\indented{1}{test has been made since there no error check.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} \\spad{rst} \\spad{m}")) (|frst| ((|#2| $) "\\spad{frst(s)} returns the first element of stream \\spad{s.} \\indented{1}{Caution: this function should only be called after a \\spad{empty?}} \\indented{1}{test has been made since there no error check.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} frst \\spad{m}")) (|lazyEvaluate| (($ $) "\\spad{lazyEvaluate(s)} causes one lazy evaluation of stream \\spad{s.} \\indented{1}{Caution: the first node must be a lazy evaluation mechanism} \\indented{1}{(satisfies \\spad{lazy?(s) = true}) as there is no error check.} \\indented{1}{Note that a call to this function may} \\indented{1}{or may not produce an explicit first entry}")) (|lazy?| (((|Boolean|) $) "\\spad{lazy?(s)} returns \\spad{true} if the first node of the stream \\spad{s} \\indented{1}{is a lazy evaluation mechanism which could produce an} \\indented{1}{additional entry to \\spad{s.}} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} lazy? \\spad{m}")) (|explicitlyEmpty?| (((|Boolean|) $) "\\spad{explicitlyEmpty?(s)} returns \\spad{true} if the stream is an \\indented{1}{(explicitly) empty stream.} \\indented{1}{Note that this is a null test which will not cause lazy evaluation.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} explicitlyEmpty? \\spad{m}")) (|explicitEntries?| (((|Boolean|) $) "\\spad{explicitEntries?(s)} returns \\spad{true} if the stream \\spad{s} has \\indented{1}{explicitly computed entries, and \\spad{false} otherwise.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} explicitEntries? \\spad{m}")) (|select| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{select(f,st)} returns a stream consisting of those elements of stream \\indented{1}{st satisfying the predicate \\spad{f.}} \\indented{1}{Note that \\spad{select(f,st) = \\spad{[x} for \\spad{x} in \\spad{st} | f(x)]}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} select(x+->prime? x,m)")) (|remove| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{remove(f,st)} returns a stream consisting of those elements of stream \\indented{1}{st which do not satisfy the predicate \\spad{f.}} \\indented{1}{Note that \\spad{remove(f,st) = \\spad{[x} for \\spad{x} in \\spad{st} | not f(x)]}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..] \\spad{X} f(i:PositiveInteger):Boolean \\spad{==} even? \\spad{i} \\spad{X} remove(f,m)"))) 
 NIL 
 NIL 
-(-669 S) 
+(-690 S) 
 ((|constructor| (NIL "LazyStreamAggregate is the category of streams with lazy evaluation. It is understood that the function 'empty?' will cause lazy evaluation if necessary to determine if there are entries. Functions which call 'empty?', for example 'first' and 'rest', will also cause lazy evaluation if necessary.")) (|complete| (($ $) "\\spad{complete(st)} causes all entries of 'st' to be computed. \\indented{1}{this function should only be called on streams which are} \\indented{1}{known to be finite.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..] \\spad{X} n:=filterUntil(i+->i>100,m) \\spad{X} numberOfComputedEntries \\spad{n} \\spad{X} complete \\spad{n} \\spad{X} numberOfComputedEntries \\spad{n}")) (|extend| (($ $ (|Integer|)) "\\spad{extend(st,n)} causes entries to be computed, if necessary, \\indented{1}{so that 'st' will have at least \\spad{'n'} explicit entries or so} \\indented{1}{that all entries of 'st' will be computed if 'st' is finite} \\indented{1}{with length \\spad{<=} \\spad{n.}} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} numberOfComputedEntries \\spad{m} \\spad{X} extend(m,20) \\spad{X} numberOfComputedEntries \\spad{m}")) (|numberOfComputedEntries| (((|NonNegativeInteger|) $) "\\spad{numberOfComputedEntries(st)} returns the number of explicitly \\indented{1}{computed entries of stream \\spad{st} which exist immediately prior to the} \\indented{1}{time this function is called.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} numberOfComputedEntries \\spad{m}")) (|rst| (($ $) "\\spad{rst(s)} returns a pointer to the next node of stream \\spad{s.} \\indented{1}{Cautrion: this function should only be called after a \\spad{empty?}} \\indented{1}{test has been made since there no error check.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} \\spad{rst} \\spad{m}")) (|frst| ((|#1| $) "\\spad{frst(s)} returns the first element of stream \\spad{s.} \\indented{1}{Caution: this function should only be called after a \\spad{empty?}} \\indented{1}{test has been made since there no error check.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} frst \\spad{m}")) (|lazyEvaluate| (($ $) "\\spad{lazyEvaluate(s)} causes one lazy evaluation of stream \\spad{s.} \\indented{1}{Caution: the first node must be a lazy evaluation mechanism} \\indented{1}{(satisfies \\spad{lazy?(s) = true}) as there is no error check.} \\indented{1}{Note that a call to this function may} \\indented{1}{or may not produce an explicit first entry}")) (|lazy?| (((|Boolean|) $) "\\spad{lazy?(s)} returns \\spad{true} if the first node of the stream \\spad{s} \\indented{1}{is a lazy evaluation mechanism which could produce an} \\indented{1}{additional entry to \\spad{s.}} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} lazy? \\spad{m}")) (|explicitlyEmpty?| (((|Boolean|) $) "\\spad{explicitlyEmpty?(s)} returns \\spad{true} if the stream is an \\indented{1}{(explicitly) empty stream.} \\indented{1}{Note that this is a null test which will not cause lazy evaluation.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} explicitlyEmpty? \\spad{m}")) (|explicitEntries?| (((|Boolean|) $) "\\spad{explicitEntries?(s)} returns \\spad{true} if the stream \\spad{s} has \\indented{1}{explicitly computed entries, and \\spad{false} otherwise.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} explicitEntries? \\spad{m}")) (|select| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{select(f,st)} returns a stream consisting of those elements of stream \\indented{1}{st satisfying the predicate \\spad{f.}} \\indented{1}{Note that \\spad{select(f,st) = \\spad{[x} for \\spad{x} in \\spad{st} | f(x)]}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 0..] \\spad{X} select(x+->prime? x,m)")) (|remove| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{remove(f,st)} returns a stream consisting of those elements of stream \\indented{1}{st which do not satisfy the predicate \\spad{f.}} \\indented{1}{Note that \\spad{remove(f,st) = \\spad{[x} for \\spad{x} in \\spad{st} | not f(x)]}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..] \\spad{X} f(i:PositiveInteger):Boolean \\spad{==} even? \\spad{i} \\spad{X} remove(f,m)"))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-670 R) 
+(-691 R) 
 ((|constructor| (NIL "This domain represents three dimensional matrices over a general object type")) (|matrixDimensions| (((|Vector| (|NonNegativeInteger|)) $) "\\spad{matrixDimensions(x)} returns the dimensions of a matrix")) (|matrixConcat3D| (($ (|Symbol|) $ $) "\\spad{matrixConcat3D(s,x,y)} concatenates two 3-D matrices along a specified axis")) (|coerce| (((|PrimitiveArray| (|PrimitiveArray| (|PrimitiveArray| |#1|))) $) "\\spad{coerce(x)} moves from the domain to the representation type") (($ (|PrimitiveArray| (|PrimitiveArray| (|PrimitiveArray| |#1|)))) "\\spad{coerce(p)} moves from the representation type (PrimitiveArray PrimitiveArray PrimitiveArray \\spad{R)} to the domain")) (|setelt!| ((|#1| $ (|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|) |#1|) "\\spad{setelt!(x,i,j,k,s)} (or x.i.j.k:=s) sets a specific element of the array to some value of type \\spad{R}")) (|elt| ((|#1| $ (|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{elt(x,i,j,k)} extract an element from the matrix \\spad{x}")) (|construct| (($ (|List| (|List| (|List| |#1|)))) "\\spad{construct(lll)} creates a 3-D matrix from a List List List \\spad{R} \\spad{lll}")) (|plus| (($ $ $) "\\spad{plus(x,y)} adds two matrices, term by term we note that they must be the same size")) (|identityMatrix| (($ (|NonNegativeInteger|)) "\\spad{identityMatrix(n)} create an identity matrix we note that this must be square")) (|zeroMatrix| (($ (|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{zeroMatrix(i,j,k)} create a matrix with all zero terms"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (QUOTE (-1054))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1054)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-671 MPT MD) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (QUOTE (-1075))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1075)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-692 MPT MD) 
 ((|constructor| (NIL "This category specifies operations needed by ModularAlgebraicGcd package. Since we have multiple implementations we specify interface here and put implementations in separate packages. Most operations are done using special purpose abstract representation. Apropriate types are passesd as parametes: \\spad{MPT} is type of modular polynomials in one variable with coefficients in some algebraic extension. \\spad{MD} is type of modulus. Final results are converted to packed representation, with coefficients (from prime field) stored in one array and exponents (in main variable and in auxilary variables representing generators of algebrac extension) stored in parallel array.")) (|repack1| (((|Void|) |#1| (|U32Vector|) (|Integer|) |#2|) "\\spad{repack1(x, a, \\spad{d,} \\spad{m)}} stores coefficients of \\spad{x} in a. \\spad{d} is degree of \\spad{x.} Corresponding exponents are given by packExps.")) (|packExps| ((|SortedExponentVector| (|Integer|) (|Integer|) |#2|) "\\spad{packExps(d, \\spad{s,} \\spad{m)}} produces vector of exponents up to degree \\spad{d.} \\spad{s} is size (degree) of algebraic extension. Use together with repack1.")) (|degree| (((|Integer|) |#1|) "\\spad{degree(x)} gives degree of \\spad{x.}")) (|zero?| (((|Boolean|) |#1|) "\\spad{zero?(x)} checks if \\spad{x} is zero.")) (|MPtoMPT| ((|#1| (|Polynomial| (|Integer|)) (|Symbol|) (|List| (|Symbol|)) |#2|) "\\spad{MPtoMPT(p, \\spad{s,} \\spad{ls,} \\spad{m)}} coverts \\spad{p} to packed represntation.")) (|packModulus| (((|Union| |#2| "failed") (|List| (|Polynomial| (|Integer|))) (|List| (|Symbol|)) (|Integer|)) "\\spad{packModulus(lp, \\spad{ls,} \\spad{p)}} converts \\spad{lp,} \\spad{ls} and prime \\spad{p} which together describe algebraic extension to packed representation.")) (|canonicalIfCan| (((|Union| |#1| "failed") |#1| |#2|) "\\spad{canonicalIfCan(x, \\spad{m)}} tries to divide \\spad{x} by its leading coefficient modulo \\spad{m.}")) (|pseudoRem| ((|#1| |#1| |#1| |#2|) "\\spad{pseudoRem(x, \\spad{y,} \\spad{m)}} computes pseudoremainder of \\spad{x} by \\spad{y} modulo \\spad{m.}"))) 
 NIL 
 NIL 
-(-672 |VarSet|) 
+(-693 |VarSet|) 
 ((|constructor| (NIL "This type is the basic representation of parenthesized words (binary trees over arbitrary symbols) useful in \\spadtype{LiePolynomial}.")) (|varList| (((|List| |#1|) $) "\\axiom{varList(x)} returns the list of distinct entries of \\axiom{x}.")) (|right| (($ $) "\\axiom{right(x)} returns right subtree of \\axiom{x} or error if retractable?(x) is true.")) (|retractable?| (((|Boolean|) $) "\\axiom{retractable?(x)} tests if \\axiom{x} is a tree with only one entry.")) (|rest| (($ $) "\\axiom{rest(x)} return \\axiom{x} without the first entry or error if retractable?(x) is true.")) (|mirror| (($ $) "\\axiom{mirror(x)} returns the reversed word of \\axiom{x}. That is \\axiom{x} itself if retractable?(x) is \\spad{true} and \\axiom{mirror(z) * mirror(y)} if \\axiom{x} is \\axiom{y*z}.")) (|lexico| (((|Boolean|) $ $) "\\axiom{lexico(x,y)} returns \\axiom{true} iff \\axiom{x} is smaller than \\axiom{y} w.r.t. the lexicographical ordering induced by \\axiom{VarSet}. N.B. This operation does not take into account the tree structure of its arguments. Thus this is not a total ordering.")) (|length| (((|PositiveInteger|) $) "\\axiom{length(x)} returns the number of entries in \\axiom{x}.")) (|left| (($ $) "\\axiom{left(x)} returns left subtree of \\axiom{x} or error if retractable?(x) is true.")) (|first| ((|#1| $) "\\axiom{first(x)} returns the first entry of the tree \\axiom{x}.")) (|coerce| (((|OrderedFreeMonoid| |#1|) $) "\\indented{1}{\\axiom{coerce(x)} returns the element of} \\axiomType{OrderedFreeMonoid}(VarSet) \\indented{1}{corresponding to \\axiom{x} by removing parentheses.}")) (* (($ $ $) "\\axiom{x*y} returns the tree \\axiom{[x,y]}."))) 
 NIL 
 NIL 
-(-673 R |Row| |Col| M) 
+(-694 R |Row| |Col| M) 
 ((|constructor| (NIL "Some functions for manipulating (dense) matrices. Supported are various kinds of slicing, splitting and stacking of matrices. The functions resemble operations often used in numerical linear algebra algorithms.")) (|blockSplit| (((|List| (|List| |#4|)) |#4| (|List| (|PositiveInteger|)) (|List| (|PositiveInteger|))) "\\spad{blockSplit} splits a matrix into multiple submatrices row and column wise, dividing a matrix into blocks.") (((|List| (|List| |#4|)) |#4| (|PositiveInteger|) (|List| (|PositiveInteger|))) "\\spad{blockSplit} splits a matrix into multiple submatrices row and column wise, dividing a matrix into blocks.") (((|List| (|List| |#4|)) |#4| (|List| (|PositiveInteger|)) (|PositiveInteger|)) "\\spad{blockSplit} splits a matrix into multiple submatrices row and column wise, dividing a matrix into blocks.") (((|List| (|List| |#4|)) |#4| (|PositiveInteger|) (|PositiveInteger|)) "\\spad{blockSplit} splits a matrix into multiple submatrices row and column wise, dividing a matrix into blocks.")) (|horizSplit| (((|List| |#4|) |#4| (|List| (|PositiveInteger|))) "\\spad{horizSplit} splits a matrix into multiple submatrices column wise.") (((|List| |#4|) |#4| (|PositiveInteger|)) "\\spad{horizSplit} splits a matrix into multiple submatrices column wise.")) (|vertSplit| (((|List| |#4|) |#4| (|List| (|PositiveInteger|))) "\\spad{vertSplit} splits a matrix into multiple submatrices row wise.") (((|List| |#4|) |#4| (|PositiveInteger|)) "\\spad{vertSplit} splits a matrix into multiple submatrices row wise.")) (|blockConcat| ((|#4| (|List| (|List| |#4|))) "\\spad{blockConcat} concatenates matrices row and column wise, building a block matrix. The order is row major as in \\spad{matrix}.")) (|vertConcat| ((|#4| (|List| |#4|)) "\\spad{vertConcat} concatenates matrices row wise.")) (|horizConcat| ((|#4| (|List| |#4|)) "\\spad{horizConcat} concatenates matrices column wise.")) (|bandMatrix| ((|#4| |#4| (|Segment| (|Integer|))) "\\spad{bandMatrix} returns multiple diagonals out of a matrix. The diagonals are put into a matrix of same shape as the original one. Positive integer arguments select upper off-diagonals, negative ones lower off-diagonals.") ((|#4| |#4| (|List| (|Integer|))) "\\spad{bandMatrix} returns multiple diagonals out of a matrix. The diagonals are put into a matrix of same shape as the original one. Positive integer arguments select upper off-diagonals, negative ones lower off-diagonals.")) (|diagonalMatrix| ((|#4| |#4|) "\\spad{diagonalMatrix} returns the main diagonal out of a matrix. The diagonal is put into a matrix of same shape as the original one.") ((|#4| |#4| (|Integer|)) "\\spad{diagonalMatrix} returns a diagonal out of a matrix. The diagonal is put into a matrix of same shape as the original one. Positive integer arguments select upper off-diagonals, negative ones lower off-diagonals.")) (|subMatrix| ((|#4| |#4| (|Segment| (|PositiveInteger|)) (|Segment| (|PositiveInteger|))) "\\spad{subMatrix} returns several elements out of a matrix. The elements are stacked into a submatrix.") ((|#4| |#4| (|List| (|PositiveInteger|)) (|List| (|PositiveInteger|))) "\\spad{subMatrix} returns several elements out of a matrix. The elements are stacked into a submatrix.")) (|columns| ((|#4| |#4| (|Segment| (|PositiveInteger|))) "\\spad{columns} returns several columns out of a matrix. The columns are stacked into a matrix.") ((|#4| |#4| (|List| (|PositiveInteger|))) "\\spad{columns} returns several columns out of a matrix. The columns are stacked into a matrix.")) (|aColumn| ((|#4| |#4| (|PositiveInteger|)) "\\spad{aColumn} returns a single column out of a matrix. The column is put into a one by \\spad{N} matrix.")) (|rows| ((|#4| |#4| (|Segment| (|PositiveInteger|))) "\\spad{rows} returns several rows out of a matrix. The rows are stacked into a matrix.") ((|#4| |#4| (|List| (|PositiveInteger|))) "\\spad{rows} returns several rows out of a matrix. The rows are stacked into a matrix.")) (|aRow| ((|#4| |#4| (|PositiveInteger|)) "\\spad{aRow} returns a single row out of a matrix. The row is put into a one by \\spad{N} matrix.")) (|element| ((|#4| |#4| (|PositiveInteger|) (|PositiveInteger|)) "\\spad{element} returns a single element out of a matrix. The element is put into a one by one matrix."))) 
 NIL 
 NIL 
-(-674 A) 
+(-695 A) 
 ((|constructor| (NIL "Various Currying operations.")) (|recur| ((|#1| (|Mapping| |#1| (|NonNegativeInteger|) |#1|) (|NonNegativeInteger|) |#1|) "\\spad{recur(n,g,x)} is \\spad{g(n,g(n-1,..g(1,x)..))}.")) (|iter| ((|#1| (|Mapping| |#1| |#1|) (|NonNegativeInteger|) |#1|) "\\spad{iter(f,n,x)} applies \\spad{f \\spad{n}} times to \\spad{x}."))) 
 NIL 
 NIL 
-(-675 A C) 
+(-696 A C) 
 ((|constructor| (NIL "Various Currying operations.")) (|arg2| ((|#2| |#1| |#2|) "\\spad{arg2(a,c)} selects its second argument.")) (|arg1| ((|#1| |#1| |#2|) "\\spad{arg1(a,c)} selects its first argument."))) 
 NIL 
 NIL 
-(-676 A B C) 
+(-697 A B C) 
 ((|constructor| (NIL "Various Currying operations.")) (|comp| ((|#3| (|Mapping| |#3| |#2|) (|Mapping| |#2| |#1|) |#1|) "\\spad{comp(f,g,x)} is \\spad{f(g x)}."))) 
 NIL 
 NIL 
-(-677 A) 
+(-698 A) 
 ((|constructor| (NIL "Various Currying operations.")) (|recur| (((|Mapping| |#1| (|NonNegativeInteger|) |#1|) (|Mapping| |#1| (|NonNegativeInteger|) |#1|)) "\\spad{recur(g)} is the function \\spad{h} such that \\indented{1}{\\spad{h(n,x)= g(n,g(n-1,..g(1,x)..))}.}")) (** (((|Mapping| |#1| |#1|) (|Mapping| |#1| |#1|) (|NonNegativeInteger|)) "\\spad{f**n} is the function which is the n-fold application \\indented{1}{of \\spad{f}.}")) (|id| ((|#1| |#1|) "\\spad{id \\spad{x}} is \\spad{x}.")) (|fixedPoint| (((|List| |#1|) (|Mapping| (|List| |#1|) (|List| |#1|)) (|Integer|)) "\\spad{fixedPoint(f,n)} is the fixed point of function \\indented{1}{\\spad{f} which is assumed to transform a list of length} \\indented{1}{\\spad{n}.}") ((|#1| (|Mapping| |#1| |#1|)) "\\spad{fixedPoint \\spad{f}} is the fixed point of function \\spad{f}. \\indented{1}{that is, such that \\spad{fixedPoint \\spad{f} = f(fixedPoint f)}.}")) (|coerce| (((|Mapping| |#1|) |#1|) "\\spad{coerce A} changes its argument into a \\indented{1}{nullary function.}")) (|nullary| (((|Mapping| |#1|) |#1|) "\\spad{nullary A} changes its argument into a \\indented{1}{nullary function.}"))) 
 NIL 
 NIL 
-(-678 A C) 
+(-699 A C) 
 ((|constructor| (NIL "Various Currying operations.")) (|diag| (((|Mapping| |#2| |#1|) (|Mapping| |#2| |#1| |#1|)) "\\spad{diag(f)} is the function \\spad{g} \\indented{1}{such that \\spad{g a = f(a,a)}.}")) (|constant| (((|Mapping| |#2| |#1|) (|Mapping| |#2|)) "\\spad{vu(f)} is the function \\spad{g} \\indented{1}{such that \\spad{g a= \\spad{f} ()}.}")) (|curry| (((|Mapping| |#2|) (|Mapping| |#2| |#1|) |#1|) "\\spad{cu(f,a)} is the function \\spad{g} \\indented{1}{such that \\spad{g \\spad{()=} \\spad{f} a}.}")) (|const| (((|Mapping| |#2| |#1|) |#2|) "\\spad{const \\spad{c}} is a function which produces \\spad{c} when \\indented{1}{applied to its argument.}"))) 
 NIL 
 NIL 
-(-679 A B C) 
+(-700 A B C) 
 ((|constructor| (NIL "Various Currying operations.")) (* (((|Mapping| |#3| |#1|) (|Mapping| |#3| |#2|) (|Mapping| |#2| |#1|)) "\\spad{f*g} is the function \\spad{h} \\indented{1}{such that \\spad{h \\spad{x=} \\spad{f(g} x)}.}")) (|twist| (((|Mapping| |#3| |#2| |#1|) (|Mapping| |#3| |#1| |#2|)) "\\spad{twist(f)} is the function \\spad{g} \\indented{1}{such that \\spad{g (a,b)= f(b,a)}.}")) (|constantLeft| (((|Mapping| |#3| |#1| |#2|) (|Mapping| |#3| |#2|)) "\\spad{constantLeft(f)} is the function \\spad{g} \\indented{1}{such that \\spad{g (a,b)= \\spad{f} b}.}")) (|constantRight| (((|Mapping| |#3| |#1| |#2|) (|Mapping| |#3| |#1|)) "\\spad{constantRight(f)} is the function \\spad{g} \\indented{1}{such that \\spad{g (a,b)= \\spad{f} a}.}")) (|curryLeft| (((|Mapping| |#3| |#2|) (|Mapping| |#3| |#1| |#2|) |#1|) "\\spad{curryLeft(f,a)} is the function \\spad{g} \\indented{1}{such that \\spad{g \\spad{b} = f(a,b)}.}")) (|curryRight| (((|Mapping| |#3| |#1|) (|Mapping| |#3| |#1| |#2|) |#2|) "\\spad{curryRight(f,b)} is the function \\spad{g} such that \\indented{1}{\\spad{g a = f(a,b)}.}"))) 
 NIL 
 NIL 
-(-680 A B) 
+(-701 A B) 
 ((|constructor| (NIL "Functional Composition. Given functions \\spad{f} and \\spad{g,} returns the applicable closure")) (/ (((|Mapping| (|Expression| (|Integer|)) |#1|) (|Mapping| (|Expression| (|Integer|)) |#1|) (|Mapping| (|Expression| (|Integer|)) |#1|)) "\\indented{1}{\\spad(+) does functional addition} \\blankline \\spad{X} p:=(x:EXPR(INT)):EXPR(INT)+->3*x \\spad{X} \\spad{q:=(x:EXPR(INT)):EXPR(INT)+->2*x+3} \\spad{X} (p/q)(4) \\spad{X} (p/q)(x)")) (* (((|Mapping| |#2| |#1|) (|Mapping| |#2| |#1|) (|Mapping| |#2| |#1|)) "\\indented{1}{\\spad(+) does functional addition} \\blankline \\spad{X} f:=(x:INT):INT \\spad{+->} 3*x \\spad{X} g:=(x:INT):INT \\spad{+->} 2*x+3 \\spad{X} (f*g)(4)")) (- (((|Mapping| |#2| |#1|) (|Mapping| |#2| |#1|) (|Mapping| |#2| |#1|)) "\\indented{1}{\\spad(+) does functional addition} \\blankline \\spad{X} f:=(x:INT):INT \\spad{+->} 3*x \\spad{X} g:=(x:INT):INT \\spad{+->} 2*x+3 \\spad{X} (f-g)(4)")) (+ (((|Mapping| |#2| |#1|) (|Mapping| |#2| |#1|) (|Mapping| |#2| |#1|)) "\\indented{1}{\\spad(+) does functional addition} \\blankline \\spad{X} f:=(x:INT):INT \\spad{+->} 3*x \\spad{X} g:=(x:INT):INT \\spad{+->} 2*x+3 \\spad{X} (f+g)(4)"))) 
 NIL 
 NIL 
-(-681 R1 |Row1| |Col1| M1 R2 |Row2| |Col2| M2) 
+(-702 R1 |Row1| |Col1| M1 R2 |Row2| |Col2| M2) 
 ((|constructor| (NIL "\\spadtype{MatrixCategoryFunctions2} provides functions between two matrix domains. The functions provided are \\spadfun{map} and \\spadfun{reduce}.")) (|reduce| ((|#5| (|Mapping| |#5| |#1| |#5|) |#4| |#5|) "\\spad{reduce(f,m,r)} returns a matrix \\spad{n} where \\spad{n[i,j] = f(m[i,j],r)} for all indices \\spad{i} and \\spad{j.}")) (|map| (((|Union| |#8| "failed") (|Mapping| (|Union| |#5| "failed") |#1|) |#4|) "\\spad{map(f,m)} applies the function \\spad{f} to the elements of the matrix \\spad{m.}") ((|#8| (|Mapping| |#5| |#1|) |#4|) "\\spad{map(f,m)} applies the function \\spad{f} to the elements of the matrix \\spad{m.}"))) 
 NIL 
 NIL 
-(-682 S R |Row| |Col|) 
+(-703 S R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{MatrixCategory} is a general matrix category which allows different representations and indexing schemes. Rows and columns may be extracted with rows returned as objects of type Row and colums returned as objects of type Col. A domain belonging to this category will be shallowly mutable. The index of the 'first' row may be obtained by calling the function \\spadfun{minRowIndex}. The index of the 'first' column may be obtained by calling the function \\spadfun{minColIndex}. The index of the first element of a Row is the same as the index of the first column in a matrix and vice versa.")) (|inverse| (((|Union| $ "failed") $) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m.} \\indented{1}{If the matrix is not invertible, \"failed\" is returned.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} inverse matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|pfaffian| ((|#2| $) "\\spad{pfaffian(m)} returns the Pfaffian of the matrix \\spad{m.} \\indented{1}{Error if the matrix is not antisymmetric} \\blankline \\spad{X} pfaffian [[0,1,0,0],[-1,0,0,0],[0,0,0,1],[0,0,-1,0]]")) (|minordet| ((|#2| $) "\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using \\indented{1}{minors. Error: if the matrix is not square.} \\blankline \\spad{X} minordet matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|determinant| ((|#2| $) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} determinant matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|nullSpace| (((|List| |#4|) $) "\\spad{nullSpace(m)} returns a basis for the null space of \\indented{1}{the matrix \\spad{m.}} \\blankline \\spad{X} nullSpace matrix [[1,2,3],[4,5,6],[7,8,9]]")) (|nullity| (((|NonNegativeInteger|) $) "\\spad{nullity(m)} returns the nullity of the matrix \\spad{m.} This is \\indented{1}{the dimension of the null space of the matrix \\spad{m.}} \\blankline \\spad{X} nullity matrix [[1,2,3],[4,5,6],[7,8,9]]")) (|rank| (((|NonNegativeInteger|) $) "\\spad{rank(m)} returns the rank of the matrix \\spad{m.} \\blankline \\spad{X} rank matrix [[1,2,3],[4,5,6],[7,8,9]]")) (|columnSpace| (((|List| |#4|) $) "\\spad{columnSpace(m)} returns a sublist of columns of the matrix \\spad{m} \\indented{1}{forming a basis of its column space} \\blankline \\spad{X} columnSpace matrix [[1,2,3],[4,5,6],[7,8,9],[1,1,1]]")) (|rowEchelon| (($ $) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m.} \\blankline \\spad{X} rowEchelon matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (/ (($ $ |#2|) "\\spad{m/r} divides the elements of \\spad{m} by \\spad{r.} Error: if \\spad{r = 0}. \\blankline \\spad{X} m:=matrix [[2**i for \\spad{i} in 2..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m/4}")) (|exquo| (((|Union| $ "failed") $ |#2|) "\\spad{exquo(m,r)} computes the exact quotient of the elements \\indented{1}{of \\spad{m} by \\spad{r,} returning \\axiom{\"failed\"} if this is not possible.} \\blankline \\spad{X} m:=matrix [[2**i for \\spad{i} in 2..4] for \\spad{j} in 1..5] \\spad{X} exquo(m,2)")) (** (($ $ (|Integer|)) "\\spad{m**n} computes an integral power of the matrix \\spad{m.} \\indented{1}{Error: if matrix is not square or if the matrix} \\indented{1}{is square but not invertible.} \\blankline \\spad{X} (matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]) \\spad{**} 2") (($ $ (|NonNegativeInteger|)) "\\spad{x \\spad{**} \\spad{n}} computes a non-negative integral power of the matrix \\spad{x.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m**3}")) (* ((|#3| |#3| $) "\\spad{r * \\spad{x}} is the product of the row vector \\spad{r} and the matrix \\spad{x.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} r:=transpose([1,2,3,4,5])@Matrix(INT) \\spad{X} \\spad{r*m}") ((|#4| $ |#4|) "\\spad{x * \\spad{c}} is the product of the matrix \\spad{x} and the column vector \\spad{c.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} c:=coerce([1,2,3,4,5])@Matrix(INT) \\spad{X} \\spad{m*c}") (($ (|Integer|) $) "\\spad{n * \\spad{x}} is an integer multiple. \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} 3*m") (($ $ |#2|) "\\spad{x * \\spad{r}} is the right scalar multiple of the scalar \\spad{r} and the \\indented{1}{matrix \\spad{x.}} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m*1/3}") (($ |#2| $) "\\spad{r*x} is the left scalar multiple of the scalar \\spad{r} and the \\indented{1}{matrix \\spad{x.}} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} 1/3*m") (($ $ $) "\\spad{x * \\spad{y}} is the product of the matrices \\spad{x} and \\spad{y.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m*m}")) (- (($ $) "\\spad{-x} returns the negative of the matrix \\spad{x.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{-m}") (($ $ $) "\\spad{x - \\spad{y}} is the difference of the matrices \\spad{x} and \\spad{y.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m-m}")) (+ (($ $ $) "\\spad{x + \\spad{y}} is the sum of the matrices \\spad{x} and \\spad{y.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m+m}")) (|setsubMatrix!| (($ $ (|Integer|) (|Integer|) $) "\\spad{setsubMatrix!(x,i1,j1,y)} destructively alters the \\indented{1}{matrix \\spad{x.} Here \\spad{x(i,j)} is set to \\spad{y(i-i1+1,j-j1+1)} for} \\indented{1}{\\spad{i = i1,...,i1-1+nrows \\spad{y}} and \\spad{j = j1,...,j1-1+ncols y}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} setsubMatrix!(m,2,2,matrix [[3,3],[3,3]])")) (|subMatrix| (($ $ (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{subMatrix(x,i1,i2,j1,j2)} extracts the submatrix \\indented{1}{\\spad{[x(i,j)]} where the index \\spad{i} ranges from \\spad{i1} to \\spad{i2}} \\indented{1}{and the index \\spad{j} ranges from \\spad{j1} to \\spad{j2}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} subMatrix(m,1,3,2,4)")) (|swapColumns!| (($ $ (|Integer|) (|Integer|)) "\\spad{swapColumns!(m,i,j)} interchanges the \\spad{i}th and \\spad{j}th \\indented{1}{columns of \\spad{m.} This destructively alters the matrix.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} swapColumns!(m,2,4)")) (|swapRows!| (($ $ (|Integer|) (|Integer|)) "\\spad{swapRows!(m,i,j)} interchanges the \\spad{i}th and \\spad{j}th \\indented{1}{rows of \\spad{m.} This destructively alters the matrix.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} swapRows!(m,2,4)")) (|setelt| (($ $ (|List| (|Integer|)) (|List| (|Integer|)) $) "\\spad{setelt(x,rowList,colList,y)} destructively alters the matrix \\spad{x.} \\indented{1}{If \\spad{y} is \\spad{m}-by-\\spad{n}, \\spad{rowList = [i<1>,i<2>,...,i<m>]}} \\indented{1}{and \\spad{colList = [j<1>,j<2>,...,j<n>]}, then \\spad{x(i<k>,j<l>)}} \\indented{1}{is set to \\spad{y(k,l)} for \\spad{k = 1,...,m} and \\spad{l = 1,...,n}} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} setelt(m,3,3,10)")) (|elt| (($ $ (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{elt(x,rowList,colList)} returns an m-by-n matrix consisting \\indented{1}{of elements of \\spad{x,} where \\spad{m = \\# rowList} and \\spad{n = \\# colList}} \\indented{1}{If \\spad{rowList = [i<1>,i<2>,...,i<m>]} and \\spad{colList \\spad{=}} \\indented{1}{[j<1>,j<2>,...,j<n>]}, then the \\spad{(k,l)}th entry of} \\indented{1}{\\spad{elt(x,rowList,colList)} is \\spad{x(i<k>,j<l>)}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} elt(m,3,3)")) (|listOfLists| (((|List| (|List| |#2|)) $) "\\spad{listOfLists(m)} returns the rows of the matrix \\spad{m} as a list \\indented{1}{of lists.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} listOfLists \\spad{m}")) (|vertConcat| (($ $ $) "\\spad{vertConcat(x,y)} vertically concatenates two matrices with an \\indented{1}{equal number of columns. The entries of \\spad{y} appear below} \\indented{1}{of the entries of x.\\space{2}Error: if the matrices} \\indented{1}{do not have the same number of columns.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} vertConcat(m,m)")) (|horizConcat| (($ $ $) "\\spad{horizConcat(x,y)} horizontally concatenates two matrices with \\indented{1}{an equal number of rows. The entries of \\spad{y} appear to the right} \\indented{1}{of the entries of x.\\space{2}Error: if the matrices} \\indented{1}{do not have the same number of rows.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} horizConcat(m,m)")) (|squareTop| (($ $) "\\spad{squareTop(m)} returns an n-by-n matrix consisting of the first \\indented{1}{n rows of the m-by-n matrix \\spad{m.} Error: if} \\indented{1}{\\spad{m < n}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..2] for \\spad{j} in 1..5] \\spad{X} squareTop \\spad{m}")) (|transpose| (($ $) "\\spad{transpose(m)} returns the transpose of the matrix \\spad{m.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} transpose \\spad{m}") (($ |#3|) "\\spad{transpose(r)} converts the row \\spad{r} to a row matrix. \\blankline \\spad{X} transpose([1,2,3])@Matrix(INT)")) (|coerce| (($ |#4|) "\\spad{coerce(col)} converts the column \\spad{col} to a column matrix. \\blankline \\spad{X} coerce([1,2,3])@Matrix(INT)")) (|diagonalMatrix| (($ (|List| $)) "\\spad{diagonalMatrix([m1,...,mk])} creates a block diagonal matrix \\indented{1}{M with block matrices m1,...,mk down the diagonal,} \\indented{1}{with 0 block matrices elsewhere.} \\indented{1}{More precisly: if \\spad{ri \\spad{:=} nrows mi}, \\spad{ci \\spad{:=} ncols mi},} \\indented{1}{then \\spad{m} is an (r1+..+rk) by (c1+..+ck) - matrix\\space{2}with entries} \\indented{1}{\\spad{m.i.j = ml.(i-r1-..-r(l-1)).(j-n1-..-n(l-1))}, if} \\indented{1}{\\spad{(r1+..+r(l-1)) < \\spad{i} \\spad{<=} r1+..+rl} and} \\indented{1}{\\spad{(c1+..+c(l-1)) < \\spad{i} \\spad{<=} c1+..+cl},} \\indented{1}{\\spad{m.i.j} = 0\\space{2}otherwise.} \\blankline \\spad{X} diagonalMatrix [matrix [[1,2],[3,4]], matrix [[4,5],[6,7]]]") (($ (|List| |#2|)) "\\spad{diagonalMatrix(l)} returns a diagonal matrix with the elements \\indented{1}{of \\spad{l} on the diagonal.} \\blankline \\spad{X} diagonalMatrix [1,2,3]")) (|scalarMatrix| (($ (|NonNegativeInteger|) |#2|) "\\spad{scalarMatrix(n,r)} returns an n-by-n matrix with \\spad{r's} on the \\indented{1}{diagonal and zeroes elsewhere.} \\blankline \\spad{X} z:Matrix(INT):=scalarMatrix(3,5)")) (|matrix| (($ (|NonNegativeInteger|) (|NonNegativeInteger|) (|Mapping| |#2| (|Integer|) (|Integer|))) "\\spad{matrix(n,m,f)} constructs an \\spad{n * \\spad{m}} matrix with \\indented{1}{the \\spad{(i,j)} entry equal to \\spad{f(i,j)}} \\blankline \\spad{X} f(i:INT,j:INT):INT \\spad{==} i+j \\spad{X} matrix(3,4,f)") (($ (|List| (|List| |#2|))) "\\spad{matrix(l)} converts the list of lists \\spad{l} to a matrix, where the \\indented{1}{list of lists is viewed as a list of the rows of the matrix.} \\blankline \\spad{X} matrix [[1,2,3],[4,5,6],[7,8,9],[1,1,1]]")) (|zero| (($ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{zero(m,n)} returns an m-by-n zero matrix. \\blankline \\spad{X} z:Matrix(INT):=zero(3,3)")) (|antisymmetric?| (((|Boolean|) $) "\\spad{antisymmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and \\indented{1}{antisymmetric (that is, \\spad{m[i,j] = -m[j,i]} for all \\spad{i} and \\spad{j)}} \\indented{1}{and \\spad{false} otherwise.} \\blankline \\spad{X} antisymmetric? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|symmetric?| (((|Boolean|) $) "\\spad{symmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and \\indented{1}{symmetric (that is, \\spad{m[i,j] = m[j,i]} for all \\spad{i} and \\spad{j)} and false} \\indented{1}{otherwise.} \\blankline \\spad{X} symmetric? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|diagonal?| (((|Boolean|) $) "\\spad{diagonal?(m)} returns \\spad{true} if the matrix \\spad{m} is square and \\indented{1}{diagonal (that is, all entries of \\spad{m} not on the diagonal are zero) and} \\indented{1}{false otherwise.} \\blankline \\spad{X} diagonal? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|square?| (((|Boolean|) $) "\\spad{square?(m)} returns \\spad{true} if \\spad{m} is a square matrix \\indented{1}{(if \\spad{m} has the same number of rows as columns) and \\spad{false} otherwise.} \\blankline \\spad{X} square matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|finiteAggregate| ((|attribute|) "matrices are finite")) (|shallowlyMutable| ((|attribute|) "One may destructively alter matrices"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-174))) (|HasAttribute| |#2| (QUOTE (-4604 "*"))) (|HasCategory| |#2| (QUOTE (-303))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-562)))) 
-(-683 R |Row| |Col|) 
+((|HasCategory| |#2| (QUOTE (-194))) (|HasAttribute| |#2| (QUOTE (-4627 "*"))) (|HasCategory| |#2| (QUOTE (-323))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-582)))) 
+(-704 R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{MatrixCategory} is a general matrix category which allows different representations and indexing schemes. Rows and columns may be extracted with rows returned as objects of type Row and colums returned as objects of type Col. A domain belonging to this category will be shallowly mutable. The index of the 'first' row may be obtained by calling the function \\spadfun{minRowIndex}. The index of the 'first' column may be obtained by calling the function \\spadfun{minColIndex}. The index of the first element of a Row is the same as the index of the first column in a matrix and vice versa.")) (|inverse| (((|Union| $ "failed") $) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m.} \\indented{1}{If the matrix is not invertible, \"failed\" is returned.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} inverse matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|pfaffian| ((|#1| $) "\\spad{pfaffian(m)} returns the Pfaffian of the matrix \\spad{m.} \\indented{1}{Error if the matrix is not antisymmetric} \\blankline \\spad{X} pfaffian [[0,1,0,0],[-1,0,0,0],[0,0,0,1],[0,0,-1,0]]")) (|minordet| ((|#1| $) "\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using \\indented{1}{minors. Error: if the matrix is not square.} \\blankline \\spad{X} minordet matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|determinant| ((|#1| $) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} determinant matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|nullSpace| (((|List| |#3|) $) "\\spad{nullSpace(m)} returns a basis for the null space of \\indented{1}{the matrix \\spad{m.}} \\blankline \\spad{X} nullSpace matrix [[1,2,3],[4,5,6],[7,8,9]]")) (|nullity| (((|NonNegativeInteger|) $) "\\spad{nullity(m)} returns the nullity of the matrix \\spad{m.} This is \\indented{1}{the dimension of the null space of the matrix \\spad{m.}} \\blankline \\spad{X} nullity matrix [[1,2,3],[4,5,6],[7,8,9]]")) (|rank| (((|NonNegativeInteger|) $) "\\spad{rank(m)} returns the rank of the matrix \\spad{m.} \\blankline \\spad{X} rank matrix [[1,2,3],[4,5,6],[7,8,9]]")) (|columnSpace| (((|List| |#3|) $) "\\spad{columnSpace(m)} returns a sublist of columns of the matrix \\spad{m} \\indented{1}{forming a basis of its column space} \\blankline \\spad{X} columnSpace matrix [[1,2,3],[4,5,6],[7,8,9],[1,1,1]]")) (|rowEchelon| (($ $) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m.} \\blankline \\spad{X} rowEchelon matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (/ (($ $ |#1|) "\\spad{m/r} divides the elements of \\spad{m} by \\spad{r.} Error: if \\spad{r = 0}. \\blankline \\spad{X} m:=matrix [[2**i for \\spad{i} in 2..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m/4}")) (|exquo| (((|Union| $ "failed") $ |#1|) "\\spad{exquo(m,r)} computes the exact quotient of the elements \\indented{1}{of \\spad{m} by \\spad{r,} returning \\axiom{\"failed\"} if this is not possible.} \\blankline \\spad{X} m:=matrix [[2**i for \\spad{i} in 2..4] for \\spad{j} in 1..5] \\spad{X} exquo(m,2)")) (** (($ $ (|Integer|)) "\\spad{m**n} computes an integral power of the matrix \\spad{m.} \\indented{1}{Error: if matrix is not square or if the matrix} \\indented{1}{is square but not invertible.} \\blankline \\spad{X} (matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]) \\spad{**} 2") (($ $ (|NonNegativeInteger|)) "\\spad{x \\spad{**} \\spad{n}} computes a non-negative integral power of the matrix \\spad{x.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m**3}")) (* ((|#2| |#2| $) "\\spad{r * \\spad{x}} is the product of the row vector \\spad{r} and the matrix \\spad{x.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} r:=transpose([1,2,3,4,5])@Matrix(INT) \\spad{X} \\spad{r*m}") ((|#3| $ |#3|) "\\spad{x * \\spad{c}} is the product of the matrix \\spad{x} and the column vector \\spad{c.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} c:=coerce([1,2,3,4,5])@Matrix(INT) \\spad{X} \\spad{m*c}") (($ (|Integer|) $) "\\spad{n * \\spad{x}} is an integer multiple. \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} 3*m") (($ $ |#1|) "\\spad{x * \\spad{r}} is the right scalar multiple of the scalar \\spad{r} and the \\indented{1}{matrix \\spad{x.}} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m*1/3}") (($ |#1| $) "\\spad{r*x} is the left scalar multiple of the scalar \\spad{r} and the \\indented{1}{matrix \\spad{x.}} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} 1/3*m") (($ $ $) "\\spad{x * \\spad{y}} is the product of the matrices \\spad{x} and \\spad{y.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m*m}")) (- (($ $) "\\spad{-x} returns the negative of the matrix \\spad{x.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{-m}") (($ $ $) "\\spad{x - \\spad{y}} is the difference of the matrices \\spad{x} and \\spad{y.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m-m}")) (+ (($ $ $) "\\spad{x + \\spad{y}} is the sum of the matrices \\spad{x} and \\spad{y.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m+m}")) (|setsubMatrix!| (($ $ (|Integer|) (|Integer|) $) "\\spad{setsubMatrix!(x,i1,j1,y)} destructively alters the \\indented{1}{matrix \\spad{x.} Here \\spad{x(i,j)} is set to \\spad{y(i-i1+1,j-j1+1)} for} \\indented{1}{\\spad{i = i1,...,i1-1+nrows \\spad{y}} and \\spad{j = j1,...,j1-1+ncols y}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} setsubMatrix!(m,2,2,matrix [[3,3],[3,3]])")) (|subMatrix| (($ $ (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{subMatrix(x,i1,i2,j1,j2)} extracts the submatrix \\indented{1}{\\spad{[x(i,j)]} where the index \\spad{i} ranges from \\spad{i1} to \\spad{i2}} \\indented{1}{and the index \\spad{j} ranges from \\spad{j1} to \\spad{j2}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} subMatrix(m,1,3,2,4)")) (|swapColumns!| (($ $ (|Integer|) (|Integer|)) "\\spad{swapColumns!(m,i,j)} interchanges the \\spad{i}th and \\spad{j}th \\indented{1}{columns of \\spad{m.} This destructively alters the matrix.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} swapColumns!(m,2,4)")) (|swapRows!| (($ $ (|Integer|) (|Integer|)) "\\spad{swapRows!(m,i,j)} interchanges the \\spad{i}th and \\spad{j}th \\indented{1}{rows of \\spad{m.} This destructively alters the matrix.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} swapRows!(m,2,4)")) (|setelt| (($ $ (|List| (|Integer|)) (|List| (|Integer|)) $) "\\spad{setelt(x,rowList,colList,y)} destructively alters the matrix \\spad{x.} \\indented{1}{If \\spad{y} is \\spad{m}-by-\\spad{n}, \\spad{rowList = [i<1>,i<2>,...,i<m>]}} \\indented{1}{and \\spad{colList = [j<1>,j<2>,...,j<n>]}, then \\spad{x(i<k>,j<l>)}} \\indented{1}{is set to \\spad{y(k,l)} for \\spad{k = 1,...,m} and \\spad{l = 1,...,n}} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} setelt(m,3,3,10)")) (|elt| (($ $ (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{elt(x,rowList,colList)} returns an m-by-n matrix consisting \\indented{1}{of elements of \\spad{x,} where \\spad{m = \\# rowList} and \\spad{n = \\# colList}} \\indented{1}{If \\spad{rowList = [i<1>,i<2>,...,i<m>]} and \\spad{colList \\spad{=}} \\indented{1}{[j<1>,j<2>,...,j<n>]}, then the \\spad{(k,l)}th entry of} \\indented{1}{\\spad{elt(x,rowList,colList)} is \\spad{x(i<k>,j<l>)}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} elt(m,3,3)")) (|listOfLists| (((|List| (|List| |#1|)) $) "\\spad{listOfLists(m)} returns the rows of the matrix \\spad{m} as a list \\indented{1}{of lists.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} listOfLists \\spad{m}")) (|vertConcat| (($ $ $) "\\spad{vertConcat(x,y)} vertically concatenates two matrices with an \\indented{1}{equal number of columns. The entries of \\spad{y} appear below} \\indented{1}{of the entries of x.\\space{2}Error: if the matrices} \\indented{1}{do not have the same number of columns.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} vertConcat(m,m)")) (|horizConcat| (($ $ $) "\\spad{horizConcat(x,y)} horizontally concatenates two matrices with \\indented{1}{an equal number of rows. The entries of \\spad{y} appear to the right} \\indented{1}{of the entries of x.\\space{2}Error: if the matrices} \\indented{1}{do not have the same number of rows.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} horizConcat(m,m)")) (|squareTop| (($ $) "\\spad{squareTop(m)} returns an n-by-n matrix consisting of the first \\indented{1}{n rows of the m-by-n matrix \\spad{m.} Error: if} \\indented{1}{\\spad{m < n}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..2] for \\spad{j} in 1..5] \\spad{X} squareTop \\spad{m}")) (|transpose| (($ $) "\\spad{transpose(m)} returns the transpose of the matrix \\spad{m.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} transpose \\spad{m}") (($ |#2|) "\\spad{transpose(r)} converts the row \\spad{r} to a row matrix. \\blankline \\spad{X} transpose([1,2,3])@Matrix(INT)")) (|coerce| (($ |#3|) "\\spad{coerce(col)} converts the column \\spad{col} to a column matrix. \\blankline \\spad{X} coerce([1,2,3])@Matrix(INT)")) (|diagonalMatrix| (($ (|List| $)) "\\spad{diagonalMatrix([m1,...,mk])} creates a block diagonal matrix \\indented{1}{M with block matrices m1,...,mk down the diagonal,} \\indented{1}{with 0 block matrices elsewhere.} \\indented{1}{More precisly: if \\spad{ri \\spad{:=} nrows mi}, \\spad{ci \\spad{:=} ncols mi},} \\indented{1}{then \\spad{m} is an (r1+..+rk) by (c1+..+ck) - matrix\\space{2}with entries} \\indented{1}{\\spad{m.i.j = ml.(i-r1-..-r(l-1)).(j-n1-..-n(l-1))}, if} \\indented{1}{\\spad{(r1+..+r(l-1)) < \\spad{i} \\spad{<=} r1+..+rl} and} \\indented{1}{\\spad{(c1+..+c(l-1)) < \\spad{i} \\spad{<=} c1+..+cl},} \\indented{1}{\\spad{m.i.j} = 0\\space{2}otherwise.} \\blankline \\spad{X} diagonalMatrix [matrix [[1,2],[3,4]], matrix [[4,5],[6,7]]]") (($ (|List| |#1|)) "\\spad{diagonalMatrix(l)} returns a diagonal matrix with the elements \\indented{1}{of \\spad{l} on the diagonal.} \\blankline \\spad{X} diagonalMatrix [1,2,3]")) (|scalarMatrix| (($ (|NonNegativeInteger|) |#1|) "\\spad{scalarMatrix(n,r)} returns an n-by-n matrix with \\spad{r's} on the \\indented{1}{diagonal and zeroes elsewhere.} \\blankline \\spad{X} z:Matrix(INT):=scalarMatrix(3,5)")) (|matrix| (($ (|NonNegativeInteger|) (|NonNegativeInteger|) (|Mapping| |#1| (|Integer|) (|Integer|))) "\\spad{matrix(n,m,f)} constructs an \\spad{n * \\spad{m}} matrix with \\indented{1}{the \\spad{(i,j)} entry equal to \\spad{f(i,j)}} \\blankline \\spad{X} f(i:INT,j:INT):INT \\spad{==} i+j \\spad{X} matrix(3,4,f)") (($ (|List| (|List| |#1|))) "\\spad{matrix(l)} converts the list of lists \\spad{l} to a matrix, where the \\indented{1}{list of lists is viewed as a list of the rows of the matrix.} \\blankline \\spad{X} matrix [[1,2,3],[4,5,6],[7,8,9],[1,1,1]]")) (|zero| (($ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{zero(m,n)} returns an m-by-n zero matrix. \\blankline \\spad{X} z:Matrix(INT):=zero(3,3)")) (|antisymmetric?| (((|Boolean|) $) "\\spad{antisymmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and \\indented{1}{antisymmetric (that is, \\spad{m[i,j] = -m[j,i]} for all \\spad{i} and \\spad{j)}} \\indented{1}{and \\spad{false} otherwise.} \\blankline \\spad{X} antisymmetric? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|symmetric?| (((|Boolean|) $) "\\spad{symmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and \\indented{1}{symmetric (that is, \\spad{m[i,j] = m[j,i]} for all \\spad{i} and \\spad{j)} and false} \\indented{1}{otherwise.} \\blankline \\spad{X} symmetric? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|diagonal?| (((|Boolean|) $) "\\spad{diagonal?(m)} returns \\spad{true} if the matrix \\spad{m} is square and \\indented{1}{diagonal (that is, all entries of \\spad{m} not on the diagonal are zero) and} \\indented{1}{false otherwise.} \\blankline \\spad{X} diagonal? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|square?| (((|Boolean|) $) "\\spad{square?(m)} returns \\spad{true} if \\spad{m} is a square matrix \\indented{1}{(if \\spad{m} has the same number of rows as columns) and \\spad{false} otherwise.} \\blankline \\spad{X} square matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|finiteAggregate| ((|attribute|) "matrices are finite")) (|shallowlyMutable| ((|attribute|) "One may destructively alter matrices"))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-684 R |Row| |Col| M) 
+(-705 R |Row| |Col| M) 
 ((|constructor| (NIL "\\spadtype{MatrixLinearAlgebraFunctions} provides functions to compute inverses and canonical forms.")) (|inverse| (((|Union| |#4| "failed") |#4|) "\\spad{inverse(m)} returns the inverse of the matrix. If the matrix is not invertible, \"failed\" is returned. Error: if the matrix is not square.")) (|normalizedDivide| (((|Record| (|:| |quotient| |#1|) (|:| |remainder| |#1|)) |#1| |#1|) "\\spad{normalizedDivide(n,d)} returns a normalized quotient and remainder such that consistently unique representatives for the residue class are chosen, \\spadignore{e.g.} positive remainders")) (|rowEchelon| ((|#4| |#4|) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m.}")) (|adjoint| (((|Record| (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|) "\\spad{adjoint(m)} returns the ajoint matrix of \\spad{m} (\\spadignore{i.e.} the matrix \\spad{n} such that \\spad{m*n} = determinant(m)*id) and the detrminant of \\spad{m.}")) (|invertIfCan| (((|Union| |#4| "failed") |#4|) "\\spad{invertIfCan(m)} returns the inverse of \\spad{m} over \\spad{R}")) (|fractionFreeGauss!| ((|#4| |#4|) "\\spad{fractionFreeGauss(m)} performs the fraction free gaussian elimination on the matrix \\spad{m.}")) (|nullSpace| (((|List| |#3|) |#4|) "\\spad{nullSpace(m)} returns a basis for the null space of the matrix \\spad{m.}")) (|nullity| (((|NonNegativeInteger|) |#4|) "\\spad{nullity(m)} returns the mullity of the matrix \\spad{m.} This is the dimension of the null space of the matrix \\spad{m.}")) (|rank| (((|NonNegativeInteger|) |#4|) "\\spad{rank(m)} returns the rank of the matrix \\spad{m.}")) (|elColumn2!| ((|#4| |#4| |#1| (|Integer|) (|Integer|)) "\\spad{elColumn2!(m,a,i,j)} adds to column \\spad{i} a*column(m,j) : elementary operation of second kind. \\spad{(i} ^=j)")) (|elRow2!| ((|#4| |#4| |#1| (|Integer|) (|Integer|)) "\\spad{elRow2!(m,a,i,j)} adds to row \\spad{i} a*row(m,j) : elementary operation of second kind. \\spad{(i} ^=j)")) (|elRow1!| ((|#4| |#4| (|Integer|) (|Integer|)) "\\spad{elRow1!(m,i,j)} swaps rows \\spad{i} and \\spad{j} of matrix \\spad{m} : elementary operation of first kind")) (|minordet| ((|#1| |#4|) "\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using minors. Error: if the matrix is not square.")) (|determinant| ((|#1| |#4|) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m.} an error message is returned if the matrix is not square."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-562)))) 
-(-685 R) 
+((|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-582)))) 
+(-706 R) 
 ((|constructor| (NIL "\\spadtype{Matrix} is a matrix domain where 1-based indexing is used for both rows and columns.")) (|inverse| (((|Union| $ "failed") $) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m.} If the matrix is not invertible, \"failed\" is returned. Error: if the matrix is not square.")) (|diagonalMatrix| (($ (|Vector| |#1|)) "\\spad{diagonalMatrix(v)} returns a diagonal matrix where the elements of \\spad{v} appear on the diagonal."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-562))) (|HasAttribute| |#1| (QUOTE (-4604 "*"))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-686 R) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-582))) (|HasAttribute| |#1| (QUOTE (-4627 "*"))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-707 R) 
 ((|constructor| (NIL "This package provides standard arithmetic operations on matrices. The functions in this package store the results of computations in existing matrices, rather than creating new matrices. This package works only for matrices of type Matrix and uses the internal representation of this type.")) (** (((|Matrix| |#1|) (|Matrix| |#1|) (|NonNegativeInteger|)) "\\spad{x \\spad{**} \\spad{n}} computes the \\spad{n}-th power of a square matrix. The power \\spad{n} is assumed greater than 1.")) (|power!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|NonNegativeInteger|)) "\\spad{power!(a,b,c,m,n)} computes \\spad{m} \\spad{**} \\spad{n} and stores the result in \\spad{a}. The matrices \\spad{b} and \\spad{c} are used to store intermediate results. Error: if \\spad{a}, \\spad{b,} \\spad{c,} and \\spad{m} are not square and of the same dimensions.")) (|times!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{times!(c,a,b)} computes the matrix product \\spad{a * \\spad{b}} and stores the result in the matrix \\spad{c.} Error: if \\spad{a}, \\spad{b,} and \\spad{c} do not have compatible dimensions.")) (|rightScalarTimes!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) |#1|) "\\spad{rightScalarTimes!(c,a,r)} computes the scalar product \\spad{a * \\spad{r}} and stores the result in the matrix \\spad{c.} Error: if \\spad{a} and \\spad{c} do not have the same dimensions.")) (|leftScalarTimes!| (((|Matrix| |#1|) (|Matrix| |#1|) |#1| (|Matrix| |#1|)) "\\spad{leftScalarTimes!(c,r,a)} computes the scalar product \\spad{r * a} and stores the result in the matrix \\spad{c.} Error: if \\spad{a} and \\spad{c} do not have the same dimensions.")) (|minus!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{!minus!(c,a,b)} computes the matrix difference \\spad{a - \\spad{b}} and stores the result in the matrix \\spad{c.} Error: if \\spad{a}, \\spad{b,} and \\spad{c} do not have the same dimensions.") (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{minus!(c,a)} computes \\spad{-a} and stores the result in the matrix \\spad{c.} Error: if a and \\spad{c} do not have the same dimensions.")) (|plus!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{plus!(c,a,b)} computes the matrix sum \\spad{a + \\spad{b}} and stores the result in the matrix \\spad{c.} Error: if \\spad{a}, \\spad{b,} and \\spad{c} do not have the same dimensions.")) (|copy!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{copy!(c,a)} copies the matrix \\spad{a} into the matrix \\spad{c.} Error: if \\spad{a} and \\spad{c} do not have the same dimensions."))) 
 NIL 
 NIL 
-(-687 S -3313 FLAF FLAS) 
+(-708 S -3958 FLAF FLAS) 
 ((|constructor| (NIL "\\spadtype{MultiVariableCalculusFunctions} Package provides several functions for multivariable calculus. These include gradient, hessian and jacobian, divergence and laplacian. Various forms for banded and sparse storage of matrices are included.")) (|bandedJacobian| (((|Matrix| |#2|) |#3| |#4| (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{bandedJacobian(vf,xlist,kl,ku)} computes the jacobian, the matrix of first partial derivatives, of the vector field \\spad{vf,} \\spad{vf} a vector function of the variables listed in xlist, \\spad{kl} is the number of nonzero subdiagonals, \\spad{ku} is the number of nonzero superdiagonals, \\spad{kl+ku+1} being actual bandwidth. Stores the nonzero band in a matrix, dimensions \\spad{kl+ku+1} by \\#xlist. The upper triangle is in the top \\spad{ku} rows, the diagonal is in row ku+1, the lower triangle in the last \\spad{kl} rows. Entries in a column in the band store correspond to entries in same column of full store. (The notation conforms to \\spad{LAPACK/NAG-F07} conventions.)")) (|jacobian| (((|Matrix| |#2|) |#3| |#4|) "\\spad{jacobian(vf,xlist)} computes the jacobian, the matrix of first partial derivatives, of the vector field \\spad{vf,} \\spad{vf} a vector function of the variables listed in xlist.")) (|bandedHessian| (((|Matrix| |#2|) |#2| |#4| (|NonNegativeInteger|)) "\\spad{bandedHessian(v,xlist,k)} computes the hessian, the matrix of second partial derivatives, of the scalar field \\spad{v,} \\spad{v} a function of the variables listed in xlist, \\spad{k} is the semi-bandwidth, the number of nonzero subdiagonals, 2*k+1 being actual bandwidth. Stores the nonzero band in lower triangle in a matrix, dimensions \\spad{k+1} by \\#xlist, whose rows are the vectors formed by diagonal, subdiagonal, etc. of the real, full-matrix, hessian. (The notation conforms to \\spad{LAPACK/NAG-F07} conventions.)")) (|hessian| (((|Matrix| |#2|) |#2| |#4|) "\\spad{hessian(v,xlist)} computes the hessian, the matrix of second partial derivatives, of the scalar field \\spad{v,} \\spad{v} a function of the variables listed in xlist.")) (|laplacian| ((|#2| |#2| |#4|) "\\spad{laplacian(v,xlist)} computes the laplacian of the scalar field \\spad{v,} \\spad{v} a function of the variables listed in xlist.")) (|divergence| ((|#2| |#3| |#4|) "\\spad{divergence(vf,xlist)} computes the divergence of the vector field \\spad{vf,} \\spad{vf} a vector function of the variables listed in xlist.")) (|gradient| (((|Vector| |#2|) |#2| |#4|) "\\spad{gradient(v,xlist)} computes the gradient, the vector of first partial derivatives, of the scalar field \\spad{v,} \\spad{v} a function of the variables listed in xlist."))) 
 NIL 
 NIL 
-(-688 R Q) 
+(-709 R Q) 
 ((|constructor| (NIL "MatrixCommonDenominator provides functions to compute the common denominator of a matrix of elements of the quotient field of an integral domain.")) (|splitDenominator| (((|Record| (|:| |num| (|Matrix| |#1|)) (|:| |den| |#1|)) (|Matrix| |#2|)) "\\spad{splitDenominator(q)} returns \\spad{[p, \\spad{d]}} such that \\spad{q = p/d} and \\spad{d} is a common denominator for the elements of \\spad{q.}")) (|clearDenominator| (((|Matrix| |#1|) (|Matrix| |#2|)) "\\spad{clearDenominator(q)} returns \\spad{p} such that \\spad{q = p/d} where \\spad{d} is a common denominator for the elements of \\spad{q.}")) (|commonDenominator| ((|#1| (|Matrix| |#2|)) "\\spad{commonDenominator(q)} returns a common denominator \\spad{d} for the elements of \\spad{q.}"))) 
 NIL 
 NIL 
-(-689) 
+(-710) 
 ((|constructor| (NIL "A domain which models the complex number representation used by machines in the AXIOM-NAG link.")) (|coerce| (((|Complex| (|Float|)) $) "\\spad{coerce(u)} transforms \\spad{u} into a COmplex Float") (($ (|Complex| (|MachineInteger|))) "\\spad{coerce(u)} transforms \\spad{u} into a MachineComplex") (($ (|Complex| (|MachineFloat|))) "\\spad{coerce(u)} transforms \\spad{u} into a MachineComplex") (($ (|Complex| (|Integer|))) "\\spad{coerce(u)} transforms \\spad{u} into a MachineComplex") (($ (|Complex| (|Float|))) "\\spad{coerce(u)} transforms \\spad{u} into a MachineComplex"))) 
-((-4595 . T) (-4600 |has| (-694) (-368)) (-4594 |has| (-694) (-368)) (-3363 . T) (-4601 |has| (-694) (-6 -4601)) (-4598 |has| (-694) (-6 -4598)) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-694) (QUOTE (-151))) (|HasCategory| (-694) (QUOTE (-149))) (|HasCategory| (-694) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-694) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| (-694) (QUOTE (-374))) (|HasCategory| (-694) (QUOTE (-368))) (|HasCategory| (-694) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-694) (QUOTE (-227))) (|HasCategory| (-694) (QUOTE (-353))) (-1841 (|HasCategory| (-694) (QUOTE (-368))) (|HasCategory| (-694) (QUOTE (-353)))) (|HasCategory| (-694) (LIST (QUOTE -283) (QUOTE (-694)) (QUOTE (-694)))) (|HasCategory| (-694) (LIST (QUOTE -305) (QUOTE (-694)))) (|HasCategory| (-694) (LIST (QUOTE -527) (QUOTE (-1170)) (QUOTE (-694)))) (|HasCategory| (-694) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| (-694) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| (-694) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| (-694) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| (-694) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-694) (QUOTE (-1028))) (|HasCategory| (-694) (QUOTE (-1190))) (-12 (|HasCategory| (-694) (QUOTE (-1009))) (|HasCategory| (-694) (QUOTE (-1190)))) (|HasCategory| (-694) (QUOTE (-554))) (|HasCategory| (-694) (QUOTE (-1063))) (-12 (|HasCategory| (-694) (QUOTE (-1063))) (|HasCategory| (-694) (QUOTE (-1190)))) (-1841 (|HasCategory| (-694) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-694) (QUOTE (-368)))) (|HasCategory| (-694) (QUOTE (-303))) (-1841 (|HasCategory| (-694) (QUOTE (-303))) (|HasCategory| (-694) (QUOTE (-368))) (|HasCategory| (-694) (QUOTE (-353)))) (|HasCategory| (-694) (QUOTE (-910))) (-12 (|HasCategory| (-694) (QUOTE (-227))) (|HasCategory| (-694) (QUOTE (-368)))) (-12 (|HasCategory| (-694) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-694) (QUOTE (-368)))) (|HasCategory| (-694) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-694) (QUOTE (-848))) (|HasCategory| (-694) (QUOTE (-562))) (|HasAttribute| (-694) (QUOTE -4601)) (|HasAttribute| (-694) (QUOTE -4598)) (-12 (|HasCategory| (-694) (QUOTE (-303))) (|HasCategory| (-694) (QUOTE (-910)))) (-1841 (-12 (|HasCategory| (-694) (QUOTE (-303))) (|HasCategory| (-694) (QUOTE (-910)))) (|HasCategory| (-694) (QUOTE (-368))) (-12 (|HasCategory| (-694) (QUOTE (-353))) (|HasCategory| (-694) (QUOTE (-910))))) (-1841 (-12 (|HasCategory| (-694) (QUOTE (-303))) (|HasCategory| (-694) (QUOTE (-910)))) (-12 (|HasCategory| (-694) (QUOTE (-368))) (|HasCategory| (-694) (QUOTE (-910)))) (-12 (|HasCategory| (-694) (QUOTE (-353))) (|HasCategory| (-694) (QUOTE (-910))))) (-1841 (-12 (|HasCategory| (-694) (QUOTE (-303))) (|HasCategory| (-694) (QUOTE (-910)))) (|HasCategory| (-694) (QUOTE (-368)))) (-1841 (-12 (|HasCategory| (-694) (QUOTE (-303))) (|HasCategory| (-694) (QUOTE (-910)))) (|HasCategory| (-694) (QUOTE (-562)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-694) (QUOTE (-303))) (|HasCategory| (-694) (QUOTE (-910)))) (|HasCategory| (-694) (QUOTE (-149)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-694) (QUOTE (-303))) (|HasCategory| (-694) (QUOTE (-910)))) (|HasCategory| (-694) (QUOTE (-353))))) 
-(-690 S) 
+((-4618 . T) (-4623 |has| (-715) (-388)) (-4617 |has| (-715) (-388)) (-4001 . T) (-4624 |has| (-715) (-6 -4624)) (-4621 |has| (-715) (-6 -4621)) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-715) (QUOTE (-171))) (|HasCategory| (-715) (QUOTE (-169))) (|HasCategory| (-715) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-715) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| (-715) (QUOTE (-394))) (|HasCategory| (-715) (QUOTE (-388))) (|HasCategory| (-715) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-715) (QUOTE (-247))) (|HasCategory| (-715) (QUOTE (-373))) (-3836 (|HasCategory| (-715) (QUOTE (-388))) (|HasCategory| (-715) (QUOTE (-373)))) (|HasCategory| (-715) (LIST (QUOTE -303) (QUOTE (-715)) (QUOTE (-715)))) (|HasCategory| (-715) (LIST (QUOTE -325) (QUOTE (-715)))) (|HasCategory| (-715) (LIST (QUOTE -547) (QUOTE (-1191)) (QUOTE (-715)))) (|HasCategory| (-715) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| (-715) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| (-715) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| (-715) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| (-715) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-715) (QUOTE (-1049))) (|HasCategory| (-715) (QUOTE (-1211))) (-12 (|HasCategory| (-715) (QUOTE (-1030))) (|HasCategory| (-715) (QUOTE (-1211)))) (|HasCategory| (-715) (QUOTE (-574))) (|HasCategory| (-715) (QUOTE (-1084))) (-12 (|HasCategory| (-715) (QUOTE (-1084))) (|HasCategory| (-715) (QUOTE (-1211)))) (-3836 (|HasCategory| (-715) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-715) (QUOTE (-388)))) (|HasCategory| (-715) (QUOTE (-323))) (-3836 (|HasCategory| (-715) (QUOTE (-323))) (|HasCategory| (-715) (QUOTE (-388))) (|HasCategory| (-715) (QUOTE (-373)))) (|HasCategory| (-715) (QUOTE (-931))) (-12 (|HasCategory| (-715) (QUOTE (-247))) (|HasCategory| (-715) (QUOTE (-388)))) (-12 (|HasCategory| (-715) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-715) (QUOTE (-388)))) (|HasCategory| (-715) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-715) (QUOTE (-869))) (|HasCategory| (-715) (QUOTE (-582))) (|HasAttribute| (-715) (QUOTE -4624)) (|HasAttribute| (-715) (QUOTE -4621)) (-12 (|HasCategory| (-715) (QUOTE (-323))) (|HasCategory| (-715) (QUOTE (-931)))) (-3836 (-12 (|HasCategory| (-715) (QUOTE (-323))) (|HasCategory| (-715) (QUOTE (-931)))) (|HasCategory| (-715) (QUOTE (-388))) (-12 (|HasCategory| (-715) (QUOTE (-373))) (|HasCategory| (-715) (QUOTE (-931))))) (-3836 (-12 (|HasCategory| (-715) (QUOTE (-323))) (|HasCategory| (-715) (QUOTE (-931)))) (-12 (|HasCategory| (-715) (QUOTE (-388))) (|HasCategory| (-715) (QUOTE (-931)))) (-12 (|HasCategory| (-715) (QUOTE (-373))) (|HasCategory| (-715) (QUOTE (-931))))) (-3836 (-12 (|HasCategory| (-715) (QUOTE (-323))) (|HasCategory| (-715) (QUOTE (-931)))) (|HasCategory| (-715) (QUOTE (-388)))) (-3836 (-12 (|HasCategory| (-715) (QUOTE (-323))) (|HasCategory| (-715) (QUOTE (-931)))) (|HasCategory| (-715) (QUOTE (-582)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-715) (QUOTE (-323))) (|HasCategory| (-715) (QUOTE (-931)))) (|HasCategory| (-715) (QUOTE (-169)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-715) (QUOTE (-323))) (|HasCategory| (-715) (QUOTE (-931)))) (|HasCategory| (-715) (QUOTE (-373))))) 
+(-711 S) 
 ((|constructor| (NIL "A multi-dictionary is a dictionary which may contain duplicates. As for any dictionary, its size is assumed large so that copying (non-destructive) operations are generally to be avoided.")) (|duplicates| (((|List| (|Record| (|:| |entry| |#1|) (|:| |count| (|NonNegativeInteger|)))) $) "\\spad{duplicates(d)} returns a list of values which have duplicates in \\spad{d}")) (|removeDuplicates!| (($ $) "\\spad{removeDuplicates!(d)} destructively removes any duplicate values in dictionary \\spad{d.}")) (|insert!| (($ |#1| $ (|NonNegativeInteger|)) "\\spad{insert!(x,d,n)} destructively inserts \\spad{n} copies of \\spad{x} into dictionary \\spad{d.}"))) 
-((-4603 . T) (-3389 . T)) 
+((-4626 . T) (-2623 . T)) 
 NIL 
-(-691 U) 
+(-712 U) 
 ((|constructor| (NIL "This package supports factorization and gcds of univariate polynomials over the integers modulo different primes. The inputs are given as polynomials over the integers with the prime passed explicitly as an extra argument.")) (|exptMod| ((|#1| |#1| (|Integer|) |#1| (|Integer|)) "\\spad{exptMod(f,n,g,p)} raises the univariate polynomial \\spad{f} to the \\spad{n}th power modulo the polynomial \\spad{g} and the prime \\spad{p.}")) (|separateFactors| (((|List| |#1|) (|List| (|Record| (|:| |factor| |#1|) (|:| |degree| (|Integer|)))) (|Integer|)) "\\spad{separateFactors(ddl, \\spad{p)}} refines the distinct degree factorization produced by ddFact to give a complete list of factors.")) (|ddFact| (((|List| (|Record| (|:| |factor| |#1|) (|:| |degree| (|Integer|)))) |#1| (|Integer|)) "\\spad{ddFact(f,p)} computes a distinct degree factorization of the polynomial \\spad{f} modulo the prime \\spad{p,} \\spadignore{i.e.} such that each factor is a product of irreducibles of the same degrees. The input polynomial \\spad{f} is assumed to be square-free modulo \\spad{p.}")) (|factor| (((|List| |#1|) |#1| (|Integer|)) "\\spad{factor(f1,p)} returns the list of factors of the univariate polynomial \\spad{f1} modulo the integer prime \\spad{p.} Error: if \\spad{f1} is not square-free modulo \\spad{p.}")) (|linears| ((|#1| |#1| (|Integer|)) "\\spad{linears(f,p)} returns the product of all the linear factors of \\spad{f} modulo \\spad{p.} Potentially incorrect result if \\spad{f} is not square-free modulo \\spad{p.}")) (|gcd| ((|#1| |#1| |#1| (|Integer|)) "\\spad{gcd(f1,f2,p)} computes the \\spad{gcd} of the univariate polynomials \\spad{f1} and \\spad{f2} modulo the integer prime \\spad{p.}"))) 
 NIL 
 NIL 
-(-692) 
+(-713) 
 ((|constructor| (NIL "This package has no description")) (|ptFunc| (((|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) "\\spad{ptFunc(a,b,c,d)} is an internal function exported in order to compile packages.")) (|meshPar1Var| (((|ThreeSpace| (|DoubleFloat|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Expression| (|Integer|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{meshPar1Var(s,t,u,f,s1,l)} \\undocumented")) (|meshFun2Var| (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Union| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "undefined") (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{meshFun2Var(f,g,s1,s2,l)} \\undocumented")) (|meshPar2Var| (((|ThreeSpace| (|DoubleFloat|)) (|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{meshPar2Var(sp,f,s1,s2,l)} \\undocumented") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{meshPar2Var(f,s1,s2,l)} \\undocumented") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Union| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "undefined") (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{meshPar2Var(f,g,h,j,s1,s2,l)} \\undocumented"))) 
 NIL 
 NIL 
-(-693 OV E -3313 PG) 
+(-714 OV E -3958 PG) 
 ((|constructor| (NIL "Package for factorization of multivariate polynomials over finite fields.")) (|factor| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factor(p)} produces the complete factorization of the multivariate polynomial \\spad{p} over a finite field. \\spad{p} is represented as a univariate polynomial with multivariate coefficients over a finite field.") (((|Factored| |#4|) |#4|) "\\spad{factor(p)} produces the complete factorization of the multivariate polynomial \\spad{p} over a finite field."))) 
 NIL 
 NIL 
-(-694) 
+(-715) 
 ((|constructor| (NIL "A domain which models the floating point representation used by machines in the AXIOM-NAG link.")) (|changeBase| (($ (|Integer|) (|Integer|) (|PositiveInteger|)) "\\spad{changeBase(exp,man,base)} is not documented")) (|exponent| (((|Integer|) $) "\\spad{exponent(u)} returns the exponent of \\spad{u}")) (|mantissa| (((|Integer|) $) "\\spad{mantissa(u)} returns the mantissa of \\spad{u}")) (|coerce| (($ (|MachineInteger|)) "\\spad{coerce(u)} transforms a MachineInteger into a MachineFloat") (((|Float|) $) "\\spad{coerce(u)} transforms a MachineFloat to a standard Float")) (|minimumExponent| (((|Integer|)) "\\spad{minimumExponent()} returns the minimum exponent in the model") (((|Integer|) (|Integer|)) "\\spad{minimumExponent(e)} sets the minimum exponent in the model to \\spad{e}")) (|maximumExponent| (((|Integer|)) "\\spad{maximumExponent()} returns the maximum exponent in the model") (((|Integer|) (|Integer|)) "\\spad{maximumExponent(e)} sets the maximum exponent in the model to \\spad{e}")) (|base| (((|PositiveInteger|)) "\\spad{base()} returns the base of the model") (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{base(b)} sets the base of the model to \\spad{b}")) (|precision| (((|PositiveInteger|)) "\\spad{precision()} returns the number of digits in the model") (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{precision(p)} sets the number of digits in the model to \\spad{p}"))) 
-((-3410 . T) (-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-2642 . T) (-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-695 R) 
+(-716 R) 
 ((|constructor| (NIL "Modular hermitian row reduction.")) (|normalizedDivide| (((|Record| (|:| |quotient| |#1|) (|:| |remainder| |#1|)) |#1| |#1|) "\\spad{normalizedDivide(n,d)} returns a normalized quotient and remainder such that consistently unique representatives for the residue class are chosen, \\spadignore{e.g.} positive remainders")) (|rowEchelonLocal| (((|Matrix| |#1|) (|Matrix| |#1|) |#1| |#1|) "\\spad{rowEchelonLocal(m, \\spad{d,} \\spad{p)}} computes the row-echelon form of \\spad{m} concatenated with \\spad{d} times the identity matrix over a local ring where \\spad{p} is the only prime.")) (|rowEchLocal| (((|Matrix| |#1|) (|Matrix| |#1|) |#1|) "\\spad{rowEchLocal(m,p)} computes a modular row-echelon form of \\spad{m,} finding an appropriate modulus over a local ring where \\spad{p} is the only prime.")) (|rowEchelon| (((|Matrix| |#1|) (|Matrix| |#1|) |#1|) "\\spad{rowEchelon(m, \\spad{d)}} computes a modular row-echelon form mod \\spad{d} of \\indented{3}{[d\\space{5}]} \\indented{3}{[\\space{2}d\\space{3}]} \\indented{3}{[\\space{4}. \\spad{]}} \\indented{3}{[\\space{5}d]} \\indented{3}{[\\space{3}M\\space{2}]} where \\spad{M = \\spad{m} mod \\spad{d}.}")) (|rowEch| (((|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{rowEch(m)} computes a modular row-echelon form of \\spad{m,} finding an appropriate modulus."))) 
 NIL 
 NIL 
-(-696) 
+(-717) 
 ((|constructor| (NIL "A domain which models the integer representation used by machines in the AXIOM-NAG link.")) (|coerce| (((|Expression| $) (|Expression| (|Integer|))) "\\spad{coerce(x)} returns \\spad{x} with coefficients in the domain")) (|maxint| (((|PositiveInteger|)) "\\spad{maxint()} returns the maximum integer in the model") (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{maxint(u)} sets the maximum integer in the model to \\spad{u}"))) 
-((-4601 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4624 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-697 S D1 D2 I) 
+(-718 S D1 D2 I) 
 ((|constructor| (NIL "Tools and transforms for making compiled functions from top-level expressions")) (|compiledFunction| (((|Mapping| |#4| |#2| |#3|) |#1| (|Symbol|) (|Symbol|)) "\\spad{compiledFunction(expr,x,y)} returns a function \\spad{f: (D1, \\spad{D2)} \\spad{->} I} defined by \\spad{f(x, \\spad{y)} \\spad{==} expr}. Function \\spad{f} is compiled and directly applicable to objects of type \\spad{(D1, D2)}")) (|binaryFunction| (((|Mapping| |#4| |#2| |#3|) (|Symbol|)) "\\spad{binaryFunction(s)} is a local function"))) 
 NIL 
 NIL 
-(-698 S) 
+(-719 S) 
 ((|constructor| (NIL "MakeCachableSet(S) returns a cachable set which is equal to \\spad{S} as a set.")) (|coerce| (($ |#1|) "\\spad{coerce(s)} returns \\spad{s} viewed as an element of \\spad{%.}"))) 
 NIL 
 NIL 
-(-699 S) 
+(-720 S) 
 ((|constructor| (NIL "Tools for making compiled functions from top-level expressions MakeFloatCompiledFunction transforms top-level objects into compiled Lisp functions whose arguments are Lisp floats. This by-passes the Axiom compiler and interpreter, thereby gaining several orders of magnitude.")) (|makeFloatFunction| (((|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) |#1| (|Symbol|) (|Symbol|)) "\\spad{makeFloatFunction(expr, \\spad{x,} \\spad{y)}} returns a Lisp function \\spad{f: (\\axiomType{DoubleFloat}, \\axiomType{DoubleFloat}) \\spad{->} \\axiomType{DoubleFloat}} defined by \\spad{f(x, \\spad{y)} \\spad{==} expr}. Function \\spad{f} is compiled and directly applicable to objects of type \\spad{(\\axiomType{DoubleFloat}, \\axiomType{DoubleFloat})}.") (((|Mapping| (|DoubleFloat|) (|DoubleFloat|)) |#1| (|Symbol|)) "\\spad{makeFloatFunction(expr, \\spad{x)}} returns a Lisp function \\spad{f: \\axiomType{DoubleFloat} \\spad{->} \\axiomType{DoubleFloat}} defined by \\spad{f(x) \\spad{==} expr}. Function \\spad{f} is compiled and directly applicable to objects of type \\axiomType{DoubleFloat}."))) 
 NIL 
 NIL 
-(-700 S) 
+(-721 S) 
 ((|constructor| (NIL "Tools for making interpreter functions from top-level expressions Transforms top-level objects into interpreter functions.")) (|function| (((|Symbol|) |#1| (|Symbol|) (|List| (|Symbol|))) "\\spad{function(e, foo, [x1,...,xn])} creates a function \\spad{foo(x1,...,xn) \\spad{==} e}.") (((|Symbol|) |#1| (|Symbol|) (|Symbol|) (|Symbol|)) "\\spad{function(e, foo, \\spad{x,} \\spad{y)}} creates a function \\spad{foo(x, \\spad{y)} = e}.") (((|Symbol|) |#1| (|Symbol|) (|Symbol|)) "\\spad{function(e, foo, \\spad{x)}} creates a function \\spad{foo(x) \\spad{==} e}.") (((|Symbol|) |#1| (|Symbol|)) "\\spad{function(e, foo)} creates a function \\spad{foo() \\spad{==} e}."))) 
 NIL 
 NIL 
-(-701 S T$) 
+(-722 S T$) 
 ((|constructor| (NIL "MakeRecord is used internally by the interpreter to create record types which are used for doing parallel iterations on streams.")) (|makeRecord| (((|Record| (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|) "\\spad{makeRecord(a,b)} creates a record object with type Record(part1:S, part2:R), where \\spad{part1} is \\spad{a} and \\spad{part2} is \\spad{b}."))) 
 NIL 
 NIL 
-(-702 S -1557 I) 
+(-723 S -1940 I) 
 ((|constructor| (NIL "Tools for making compiled functions from top-level expressions Transforms top-level objects into compiled functions.")) (|compiledFunction| (((|Mapping| |#3| |#2|) |#1| (|Symbol|)) "\\spad{compiledFunction(expr, \\spad{x)}} returns a function \\spad{f: \\spad{D} \\spad{->} I} defined by \\spad{f(x) \\spad{==} expr}. Function \\spad{f} is compiled and directly applicable to objects of type \\spad{D.}")) (|unaryFunction| (((|Mapping| |#3| |#2|) (|Symbol|)) "\\spad{unaryFunction(a)} is a local function"))) 
 NIL 
 NIL 
-(-703 E OV R P) 
+(-724 E OV R P) 
 ((|constructor| (NIL "This package provides the functions for the multivariate \"lifting\", using an algorithm of Paul Wang. This package will work for every euclidean domain \\spad{R} which has property \\spad{F,} \\spadignore{i.e.} there exists a factor operation in \\spad{R[x]}.")) (|lifting1| (((|Union| (|List| (|SparseUnivariatePolynomial| |#4|)) "failed") (|SparseUnivariatePolynomial| |#4|) (|List| |#2|) (|List| (|SparseUnivariatePolynomial| |#4|)) (|List| |#3|) (|List| |#4|) (|List| (|List| (|Record| (|:| |expt| (|NonNegativeInteger|)) (|:| |pcoef| |#4|)))) (|List| (|NonNegativeInteger|)) (|Vector| (|List| (|SparseUnivariatePolynomial| |#3|))) |#3|) "\\spad{lifting1(u,lv,lu,lr,lp,lt,ln,t,r)} \\undocumented")) (|lifting| (((|Union| (|List| (|SparseUnivariatePolynomial| |#4|)) "failed") (|SparseUnivariatePolynomial| |#4|) (|List| |#2|) (|List| (|SparseUnivariatePolynomial| |#3|)) (|List| |#3|) (|List| |#4|) (|List| (|NonNegativeInteger|)) |#3|) "\\spad{lifting(u,lv,lu,lr,lp,ln,r)} \\undocumented")) (|corrPoly| (((|Union| (|List| (|SparseUnivariatePolynomial| |#4|)) "failed") (|SparseUnivariatePolynomial| |#4|) (|List| |#2|) (|List| |#3|) (|List| (|NonNegativeInteger|)) (|List| (|SparseUnivariatePolynomial| |#4|)) (|Vector| (|List| (|SparseUnivariatePolynomial| |#3|))) |#3|) "\\spad{corrPoly(u,lv,lr,ln,lu,t,r)} \\undocumented"))) 
 NIL 
 NIL 
-(-704 R) 
+(-725 R) 
 ((|constructor| (NIL "This is the category of linear operator rings with one generator. The generator is not named by the category but can always be constructed as \\spad{monomial(1,1)}. \\blankline For convenience, call the generator \\spad{G}. Then each value is equal to \\spad{sum(a(i)*G**i, \\spad{i} = 0..n)} for some unique \\spad{n} and \\spad{a(i)} in \\spad{R}. \\blankline Note that multiplication is not necessarily commutative. In fact, if \\spad{a} is in \\spad{R}, it is quite normal to have \\spad{a*G \\spad{\\^=} G*a}.")) (|monomial| (($ |#1| (|NonNegativeInteger|)) "\\spad{monomial(c,k)} produces \\spad{c} times the \\spad{k}-th power of the generating operator, \\spad{monomial(1,1)}.")) (|coefficient| ((|#1| $ (|NonNegativeInteger|)) "\\spad{coefficient(l,k)} is \\spad{a(k)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|reductum| (($ $) "\\spad{reductum(l)} is \\spad{l - monomial(a(n),n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(l)} is \\spad{a(n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|minimumDegree| (((|NonNegativeInteger|) $) "\\spad{minimumDegree(l)} is the smallest \\spad{k} such that \\spad{a(k) \\spad{\\^=} 0} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(l)} is \\spad{n} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}"))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-705 R1 UP1 UPUP1 R2 UP2 UPUP2) 
+(-726 R1 UP1 UPUP1 R2 UP2 UPUP2) 
 ((|constructor| (NIL "Lifting of a map through 2 levels of polynomials.")) (|map| ((|#6| (|Mapping| |#4| |#1|) |#3|) "\\spad{map(f, \\spad{p)}} lifts \\spad{f} to the domain of \\spad{p} then applies it to \\spad{p.}"))) 
 NIL 
 NIL 
-(-706) 
+(-727) 
 ((|constructor| (NIL "This package is based on the TeXFormat domain by Robert \\spad{S.} Sutor \\spadtype{MathMLFormat} provides a coercion from \\spadtype{OutputForm} to MathML format.")) (|display| (((|Void|) (|String|)) "prints the string returned by coerce, adding <math ...> tags.")) (|exprex| (((|String|) (|OutputForm|)) "coverts \\spadtype{OutputForm} to \\spadtype{String} with the structure preserved with braces. Actually this is not quite accurate. The function \\spadfun{precondition} is first applied to the \\spadtype{OutputForm} expression before \\spadfun{exprex}. The raw \\spadtype{OutputForm} and the nature of the \\spadfun{precondition} function is still obscure to me at the time of this writing (2007-02-14).")) (|coerceL| (((|String|) (|OutputForm|)) "coerceS(o) changes \\spad{o} in the standard output format to MathML format and displays result as one long string.")) (|coerceS| (((|String|) (|OutputForm|)) "\\spad{coerceS(o)} changes \\spad{o} in the standard output format to MathML format and displays formatted result.")) (|coerce| (((|String|) (|OutputForm|)) "coerceS(o) changes \\spad{o} in the standard output format to MathML format."))) 
 NIL 
 NIL 
-(-707 R |Mod| -4007 -4475 |exactQuo|) 
+(-728 R |Mod| -3674 -4491 |exactQuo|) 
 ((|constructor| (NIL "These domains are used for the factorization and gcds of univariate polynomials over the integers in order to work modulo different primes. See \\spadtype{ModularRing}, \\spadtype{EuclideanModularRing}")) (|exQuo| (((|Union| $ "failed") $ $) "\\spad{exQuo(x,y)} is not documented")) (|reduce| (($ |#1| |#2|) "\\spad{reduce(r,m)} is not documented")) (|coerce| ((|#1| $) "\\spad{coerce(x)} is not documented")) (|modulus| ((|#2| $) "\\spad{modulus(x)} is not documented"))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-708 R |Rep|) 
+(-729 R |Rep|) 
 ((|constructor| (NIL "This package has not been documented")) (|frobenius| (($ $) "\\spad{frobenius(x)} is not documented")) (|computePowers| (((|PrimitiveArray| $)) "\\spad{computePowers()} is not documented")) (|pow| (((|PrimitiveArray| $)) "\\spad{pow()} is not documented")) (|An| (((|Vector| |#1|) $) "\\spad{An(x)} is not documented")) (|UnVectorise| (($ (|Vector| |#1|)) "\\spad{UnVectorise(v)} is not documented")) (|Vectorise| (((|Vector| |#1|) $) "\\spad{Vectorise(x)} is not documented")) (|coerce| (($ |#2|) "\\spad{coerce(x)} is not documented")) (|lift| ((|#2| $) "\\spad{lift(x)} is not documented")) (|reduce| (($ |#2|) "\\spad{reduce(x)} is not documented")) (|modulus| ((|#2|) "\\spad{modulus()} is not documented")) (|setPoly| ((|#2| |#2|) "\\spad{setPoly(x)} is not documented"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4598 |has| |#1| (-368)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-1144))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-353))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasCategory| |#1| (QUOTE (-227))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-709 IS E |ff|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4621 |has| |#1| (-388)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-1165))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-373))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasCategory| |#1| (QUOTE (-247))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-730 IS E |ff|) 
 ((|constructor| (NIL "This package has no documentation")) (|construct| (($ |#1| |#2|) "\\spad{construct(i,e)} is not documented")) (|coerce| (((|Record| (|:| |index| |#1|) (|:| |exponent| |#2|)) $) "\\spad{coerce(x)} is not documented") (($ (|Record| (|:| |index| |#1|) (|:| |exponent| |#2|))) "\\spad{coerce(x)} is not documented")) (|index| ((|#1| $) "\\spad{index(x)} is not documented")) (|exponent| ((|#2| $) "\\spad{exponent(x)} is not documented"))) 
 NIL 
 NIL 
-(-710 R M) 
+(-731 R M) 
 ((|constructor| (NIL "Algebra of ADDITIVE operators on a module.")) (|makeop| (($ |#1| (|FreeGroup| (|BasicOperator|))) "\\spad{makeop should} be local but conditional")) (|opeval| ((|#2| (|BasicOperator|) |#2|) "\\spad{opeval should} be local but conditional")) (** (($ $ (|Integer|)) "\\spad{op**n} is not documented") (($ (|BasicOperator|) (|Integer|)) "\\spad{op**n} is not documented")) (|evaluateInverse| (($ $ (|Mapping| |#2| |#2|)) "\\spad{evaluateInverse(x,f)} is not documented")) (|evaluate| (($ $ (|Mapping| |#2| |#2|)) "\\spad{evaluate(f, \\spad{u} \\spad{+->} \\spad{g} u)} attaches the map \\spad{g} to \\spad{f.} \\spad{f} must be a basic operator \\spad{g} MUST be additive, \\spadignore{i.e.} \\spad{g(a + \\spad{b)} = g(a) + g(b)} for any \\spad{a}, \\spad{b} in \\spad{M.} This implies that \\spad{g(n a) = \\spad{n} g(a)} for any \\spad{a} in \\spad{M} and integer \\spad{n > 0}.")) (|conjug| ((|#1| |#1|) "\\spad{conjug(x)}should be local but conditional")) (|adjoint| (($ $ $) "\\spad{adjoint(op1, op2)} sets the adjoint of \\spad{op1} to be op2. \\spad{op1} must be a basic operator") (($ $) "\\spad{adjoint(op)} returns the adjoint of the operator \\spad{op}."))) 
-((-4597 |has| |#1| (-174)) (-4596 |has| |#1| (-174)) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151)))) 
-(-711 R |Mod| -4007 -4475 |exactQuo|) 
+((-4620 |has| |#1| (-194)) (-4619 |has| |#1| (-194)) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171)))) 
+(-732 R |Mod| -3674 -4491 |exactQuo|) 
 ((|constructor| (NIL "These domains are used for the factorization and gcds of univariate polynomials over the integers in order to work modulo different primes. See \\spadtype{EuclideanModularRing} ,\\spadtype{ModularField}")) (|inv| (($ $) "\\spad{inv(x)} is not documented")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} is not documented")) (|exQuo| (((|Union| $ "failed") $ $) "\\spad{exQuo(x,y)} is not documented")) (|reduce| (($ |#1| |#2|) "\\spad{reduce(r,m)} is not documented")) (|coerce| ((|#1| $) "\\spad{coerce(x)} is not documented")) (|modulus| ((|#2| $) "\\spad{modulus(x)} is not documented"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-712 S R) 
+(-733 S R) 
 ((|constructor| (NIL "The category of modules over a commutative ring. \\blankline Axioms\\br \\tab{5}\\spad{1*x = x}\\br \\tab{5}\\spad{(a*b)*x = a*(b*x)}\\br \\tab{5}\\spad{(a+b)*x = (a*x)+(b*x)}\\br \\tab{5}\\spad{a*(x+y) = (a*x)+(a*y)}"))) 
 NIL 
 NIL 
-(-713 R) 
+(-734 R) 
 ((|constructor| (NIL "The category of modules over a commutative ring. \\blankline Axioms\\br \\tab{5}\\spad{1*x = x}\\br \\tab{5}\\spad{(a*b)*x = a*(b*x)}\\br \\tab{5}\\spad{(a+b)*x = (a*x)+(b*x)}\\br \\tab{5}\\spad{a*(x+y) = (a*x)+(a*y)}"))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-714 -3313) 
+(-735 -3958) 
 ((|constructor| (NIL "MoebiusTransform(F) is the domain of fractional linear (Moebius) transformations over \\spad{F.} This a domain of 2-by-2 matrices acting on P1(F).")) (|eval| (((|OnePointCompletion| |#1|) $ (|OnePointCompletion| |#1|)) "\\spad{eval(m,x)} returns \\spad{(a*x + b)/(c*x + \\spad{d)}} where \\spad{m = moebius(a,b,c,d)} (see moebius from MoebiusTransform).") ((|#1| $ |#1|) "\\spad{eval(m,x)} returns \\spad{(a*x + b)/(c*x + \\spad{d)}} where \\spad{m = moebius(a,b,c,d)} (see moebius from MoebiusTransform).")) (|recip| (($ $) "\\spad{recip(m)} = recip() * \\spad{m}") (($) "\\spad{recip()} returns \\spad{matrix [[0,1],[1,0]]} representing the map \\spad{x \\spad{->} 1 / \\spad{x}.}")) (|scale| (($ $ |#1|) "\\spad{scale(m,h)} returns \\spad{scale(h) * \\spad{m}} (see shift from MoebiusTransform).") (($ |#1|) "\\spad{scale(k)} returns \\spad{matrix [[k,0],[0,1]]} representing the map \\spad{x \\spad{->} \\spad{k} * \\spad{x}.}")) (|shift| (($ $ |#1|) "\\spad{shift(m,h)} returns \\spad{shift(h) * \\spad{m}} (see shift from MoebiusTransform).") (($ |#1|) "\\spad{shift(k)} returns \\spad{matrix [[1,k],[0,1]]} representing the map \\spad{x \\spad{->} \\spad{x} + \\spad{k}.}")) (|moebius| (($ |#1| |#1| |#1| |#1|) "\\spad{moebius(a,b,c,d)} returns \\spad{matrix [[a,b],[c,d]]}."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-715 S) 
+(-736 S) 
 ((|constructor| (NIL "Monad is the class of all multiplicative monads, that is sets with a binary operation.")) (** (($ $ (|PositiveInteger|)) "\\spad{a**n} returns the \\spad{n}-th power of \\spad{a}, defined by repeated squaring.")) (|leftPower| (($ $ (|PositiveInteger|)) "\\spad{leftPower(a,n)} returns the \\spad{n}-th left power of \\spad{a}, that is, \\spad{leftPower(a,n) \\spad{:=} a * leftPower(a,n-1)} and \\spad{leftPower(a,1) \\spad{:=} a}.")) (|rightPower| (($ $ (|PositiveInteger|)) "\\spad{rightPower(a,n)} returns the \\spad{n}-th right power of \\spad{a}, that is, \\spad{rightPower(a,n) \\spad{:=} rightPower(a,n-1) * a} and \\spad{rightPower(a,1) \\spad{:=} a}.")) (* (($ $ $) "\\spad{a*b} is the product of \\spad{a} and \\spad{b} in a set with a binary operation."))) 
 NIL 
 NIL 
-(-716) 
+(-737) 
 ((|constructor| (NIL "Monad is the class of all multiplicative monads, that is sets with a binary operation.")) (** (($ $ (|PositiveInteger|)) "\\spad{a**n} returns the \\spad{n}-th power of \\spad{a}, defined by repeated squaring.")) (|leftPower| (($ $ (|PositiveInteger|)) "\\spad{leftPower(a,n)} returns the \\spad{n}-th left power of \\spad{a}, that is, \\spad{leftPower(a,n) \\spad{:=} a * leftPower(a,n-1)} and \\spad{leftPower(a,1) \\spad{:=} a}.")) (|rightPower| (($ $ (|PositiveInteger|)) "\\spad{rightPower(a,n)} returns the \\spad{n}-th right power of \\spad{a}, that is, \\spad{rightPower(a,n) \\spad{:=} rightPower(a,n-1) * a} and \\spad{rightPower(a,1) \\spad{:=} a}.")) (* (($ $ $) "\\spad{a*b} is the product of \\spad{a} and \\spad{b} in a set with a binary operation."))) 
 NIL 
 NIL 
-(-717 S) 
+(-738 S) 
 ((|constructor| (NIL "MonadWithUnit is the class of multiplicative monads with unit, that is, sets with a binary operation and a unit element. \\blankline Axioms\\br \\tab{5}leftIdentity(\"*\":(\\%,\\%)->\\%,1) for example, 1*x=x\\br \\tab{5}rightIdentity(\"*\":(\\%,\\%)->\\%,1) for example, x*1=x \\blankline Common Additional Axioms\\br \\tab{5}unitsKnown - if \"recip\" says \"failed\", it PROVES input wasn't a unit")) (|rightRecip| (((|Union| $ "failed") $) "\\spad{rightRecip(a)} returns an element, which is a right inverse of \\spad{a}, or \\spad{\"failed\"} if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|leftRecip| (((|Union| $ "failed") $) "\\spad{leftRecip(a)} returns an element, which is a left inverse of \\spad{a}, or \\spad{\"failed\"} if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(a)} returns an element, which is both a left and a right inverse of \\spad{a}, or \\spad{\"failed\"} if such an element doesn't exist or cannot be determined (see unitsKnown).")) (** (($ $ (|NonNegativeInteger|)) "\\spad{a**n} returns the \\spad{n}-th power of \\spad{a}, defined by repeated squaring.")) (|leftPower| (($ $ (|NonNegativeInteger|)) "\\spad{leftPower(a,n)} returns the \\spad{n}-th left power of \\spad{a}, that is, \\spad{leftPower(a,n) \\spad{:=} a * leftPower(a,n-1)} and \\spad{leftPower(a,0) \\spad{:=} 1}.")) (|rightPower| (($ $ (|NonNegativeInteger|)) "\\spad{rightPower(a,n)} returns the \\spad{n}-th right power of \\spad{a}, that is, \\spad{rightPower(a,n) \\spad{:=} rightPower(a,n-1) * a} and \\spad{rightPower(a,0) \\spad{:=} 1}.")) (|one?| (((|Boolean|) $) "\\spad{one?(a)} tests whether \\spad{a} is the unit 1.")) ((|One|) (($) "\\spad{1} returns the unit element, denoted by 1."))) 
 NIL 
 NIL 
-(-718) 
+(-739) 
 ((|constructor| (NIL "MonadWithUnit is the class of multiplicative monads with unit, that is, sets with a binary operation and a unit element. \\blankline Axioms\\br \\tab{5}leftIdentity(\"*\":(\\%,\\%)->\\%,1) for example, 1*x=x\\br \\tab{5}rightIdentity(\"*\":(\\%,\\%)->\\%,1) for example, x*1=x \\blankline Common Additional Axioms\\br \\tab{5}unitsKnown - if \"recip\" says \"failed\", it PROVES input wasn't a unit")) (|rightRecip| (((|Union| $ "failed") $) "\\spad{rightRecip(a)} returns an element, which is a right inverse of \\spad{a}, or \\spad{\"failed\"} if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|leftRecip| (((|Union| $ "failed") $) "\\spad{leftRecip(a)} returns an element, which is a left inverse of \\spad{a}, or \\spad{\"failed\"} if such an element doesn't exist or cannot be determined (see unitsKnown).")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(a)} returns an element, which is both a left and a right inverse of \\spad{a}, or \\spad{\"failed\"} if such an element doesn't exist or cannot be determined (see unitsKnown).")) (** (($ $ (|NonNegativeInteger|)) "\\spad{a**n} returns the \\spad{n}-th power of \\spad{a}, defined by repeated squaring.")) (|leftPower| (($ $ (|NonNegativeInteger|)) "\\spad{leftPower(a,n)} returns the \\spad{n}-th left power of \\spad{a}, that is, \\spad{leftPower(a,n) \\spad{:=} a * leftPower(a,n-1)} and \\spad{leftPower(a,0) \\spad{:=} 1}.")) (|rightPower| (($ $ (|NonNegativeInteger|)) "\\spad{rightPower(a,n)} returns the \\spad{n}-th right power of \\spad{a}, that is, \\spad{rightPower(a,n) \\spad{:=} rightPower(a,n-1) * a} and \\spad{rightPower(a,0) \\spad{:=} 1}.")) (|one?| (((|Boolean|) $) "\\spad{one?(a)} tests whether \\spad{a} is the unit 1.")) ((|One|) (($) "\\spad{1} returns the unit element, denoted by 1."))) 
 NIL 
 NIL 
-(-719 S R UP) 
+(-740 S R UP) 
 ((|constructor| (NIL "A \\spadtype{MonogenicAlgebra} is an algebra of finite rank which can be generated by a single element.")) (|derivationCoordinates| (((|Matrix| |#2|) (|Vector| $) (|Mapping| |#2| |#2|)) "\\spad{derivationCoordinates(b, \\spad{')}} returns \\spad{M} such that \\spad{b' = \\spad{M} \\spad{b}.}")) (|lift| ((|#3| $) "\\spad{lift(z)} returns a minimal degree univariate polynomial up such that \\spad{z=reduce up}.")) (|convert| (($ |#3|) "\\spad{convert(up)} converts the univariate polynomial \\spad{up} to an algebra element, reducing by the \\spad{definingPolynomial()} if necessary.")) (|reduce| (((|Union| $ "failed") (|Fraction| |#3|)) "\\spad{reduce(frac)} converts the fraction \\spad{frac} to an algebra element.") (($ |#3|) "\\spad{reduce(up)} converts the univariate polynomial \\spad{up} to an algebra element, reducing by the \\spad{definingPolynomial()} if necessary.")) (|definingPolynomial| ((|#3|) "\\spad{definingPolynomial()} returns the minimal polynomial which \\spad{generator()} satisfies.")) (|generator| (($) "\\spad{generator()} returns the generator for this domain."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-353))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-374)))) 
-(-720 R UP) 
+((|HasCategory| |#2| (QUOTE (-373))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-394)))) 
+(-741 R UP) 
 ((|constructor| (NIL "A \\spadtype{MonogenicAlgebra} is an algebra of finite rank which can be generated by a single element.")) (|derivationCoordinates| (((|Matrix| |#1|) (|Vector| $) (|Mapping| |#1| |#1|)) "\\spad{derivationCoordinates(b, \\spad{')}} returns \\spad{M} such that \\spad{b' = \\spad{M} \\spad{b}.}")) (|lift| ((|#2| $) "\\spad{lift(z)} returns a minimal degree univariate polynomial up such that \\spad{z=reduce up}.")) (|convert| (($ |#2|) "\\spad{convert(up)} converts the univariate polynomial \\spad{up} to an algebra element, reducing by the \\spad{definingPolynomial()} if necessary.")) (|reduce| (((|Union| $ "failed") (|Fraction| |#2|)) "\\spad{reduce(frac)} converts the fraction \\spad{frac} to an algebra element.") (($ |#2|) "\\spad{reduce(up)} converts the univariate polynomial \\spad{up} to an algebra element, reducing by the \\spad{definingPolynomial()} if necessary.")) (|definingPolynomial| ((|#2|) "\\spad{definingPolynomial()} returns the minimal polynomial which \\spad{generator()} satisfies.")) (|generator| (($) "\\spad{generator()} returns the generator for this domain."))) 
-((-4595 |has| |#1| (-368)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 |has| |#1| (-388)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-721 S) 
+(-742 S) 
 ((|constructor| (NIL "The class of multiplicative monoids, \\spadignore{i.e.} semigroups with a multiplicative identity element. \\blankline Axioms\\br \\tab{5}\\spad{leftIdentity(\"*\":(\\%,\\%)->\\%,1)}\\tab{5}\\spad{1*x=x}\\br \\tab{5}\\spad{rightIdentity(\"*\":(\\%,\\%)->\\%,1)}\\tab{4}\\spad{x*1=x} \\blankline Conditional attributes\\br \\tab{5}unitsKnown - \\spadfun{recip} only returns \"failed\" on non-units")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} tries to compute the multiplicative inverse for \\spad{x} or \"failed\" if it cannot find the inverse (see unitsKnown).")) (^ (($ $ (|NonNegativeInteger|)) "\\spad{x^n} returns the repeated product of \\spad{x} \\spad{n} times, \\spadignore{i.e.} exponentiation.")) (** (($ $ (|NonNegativeInteger|)) "\\spad{x**n} returns the repeated product of \\spad{x} \\spad{n} times, \\spadignore{i.e.} exponentiation.")) (|one?| (((|Boolean|) $) "\\spad{one?(x)} tests if \\spad{x} is equal to 1.")) (|sample| (($) "\\spad{sample yields} a value of type \\%")) ((|One|) (($) "1 is the multiplicative identity."))) 
 NIL 
 NIL 
-(-722) 
+(-743) 
 ((|constructor| (NIL "The class of multiplicative monoids, \\spadignore{i.e.} semigroups with a multiplicative identity element. \\blankline Axioms\\br \\tab{5}\\spad{leftIdentity(\"*\":(\\%,\\%)->\\%,1)}\\tab{5}\\spad{1*x=x}\\br \\tab{5}\\spad{rightIdentity(\"*\":(\\%,\\%)->\\%,1)}\\tab{4}\\spad{x*1=x} \\blankline Conditional attributes\\br \\tab{5}unitsKnown - \\spadfun{recip} only returns \"failed\" on non-units")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} tries to compute the multiplicative inverse for \\spad{x} or \"failed\" if it cannot find the inverse (see unitsKnown).")) (^ (($ $ (|NonNegativeInteger|)) "\\spad{x^n} returns the repeated product of \\spad{x} \\spad{n} times, \\spadignore{i.e.} exponentiation.")) (** (($ $ (|NonNegativeInteger|)) "\\spad{x**n} returns the repeated product of \\spad{x} \\spad{n} times, \\spadignore{i.e.} exponentiation.")) (|one?| (((|Boolean|) $) "\\spad{one?(x)} tests if \\spad{x} is equal to 1.")) (|sample| (($) "\\spad{sample yields} a value of type \\%")) ((|One|) (($) "1 is the multiplicative identity."))) 
 NIL 
 NIL 
-(-723 -3313 UP) 
+(-744 -3958 UP) 
 ((|constructor| (NIL "Tools for handling monomial extensions.")) (|decompose| (((|Record| (|:| |poly| |#2|) (|:| |normal| (|Fraction| |#2|)) (|:| |special| (|Fraction| |#2|))) (|Fraction| |#2|) (|Mapping| |#2| |#2|)) "\\spad{decompose(f, \\spad{D)}} returns \\spad{[p,n,s]} such that \\spad{f = p+n+s}, all the squarefree factors of \\spad{denom(n)} are normal w.r.t. \\spad{D,} \\spad{denom(s)} is special w.r.t. \\spad{D,} and \\spad{n} and \\spad{s} are proper fractions (no pole at infinity). \\spad{D} is the derivation to use.")) (|normalDenom| ((|#2| (|Fraction| |#2|) (|Mapping| |#2| |#2|)) "\\spad{normalDenom(f, \\spad{D)}} returns the product of all the normal factors of \\spad{denom(f)}. \\spad{D} is the derivation to use.")) (|splitSquarefree| (((|Record| (|:| |normal| (|Factored| |#2|)) (|:| |special| (|Factored| |#2|))) |#2| (|Mapping| |#2| |#2|)) "\\spad{splitSquarefree(p, \\spad{D)}} returns \\spad{[n_1 \\spad{n_2\\^2} \\spad{...} n_m\\^m, \\spad{s_1} \\spad{s_2\\^2} \\spad{...} s_q\\^q]} such that \\spad{p = \\spad{n_1} \\spad{n_2\\^2} \\spad{...} n_m\\^m \\spad{s_1} \\spad{s_2\\^2} \\spad{...} s_q\\^q}, each \\spad{n_i} is normal w.r.t. \\spad{D} and each \\spad{s_i} is special w.r.t \\spad{D.} \\spad{D} is the derivation to use.")) (|split| (((|Record| (|:| |normal| |#2|) (|:| |special| |#2|)) |#2| (|Mapping| |#2| |#2|)) "\\spad{split(p, \\spad{D)}} returns \\spad{[n,s]} such that \\spad{p = \\spad{n} \\spad{s},} all the squarefree factors of \\spad{n} are normal w.r.t. \\spad{D,} and \\spad{s} is special w.r.t. \\spad{D.} \\spad{D} is the derivation to use."))) 
 NIL 
 NIL 
-(-724 |VarSet| -3670 E2 R S PR PS) 
+(-745 |VarSet| -2194 E2 R S PR PS) 
 ((|constructor| (NIL "Utilities for MPolyCat")) (|reshape| ((|#7| (|List| |#5|) |#6|) "\\spad{reshape(l,p)} \\undocumented")) (|map| ((|#7| (|Mapping| |#5| |#4|) |#6|) "\\spad{map(f,p)} \\undocumented"))) 
 NIL 
 NIL 
-(-725 |Vars1| |Vars2| -3670 E2 R PR1 PR2) 
+(-746 |Vars1| |Vars2| -2194 E2 R PR1 PR2) 
 ((|constructor| (NIL "This package has no description")) (|map| ((|#7| (|Mapping| |#2| |#1|) |#6|) "\\spad{map(f,x)} \\undocumented"))) 
 NIL 
 NIL 
-(-726 E OV R PPR) 
+(-747 E OV R PPR) 
 ((|constructor| (NIL "This package exports a factor operation for multivariate polynomials with coefficients which are polynomials over some ring \\spad{R} over which we can factor. It is used internally by packages such as the solve package which need to work with polynomials in a specific set of variables with coefficients which are polynomials in all the other variables.")) (|factor| (((|Factored| |#4|) |#4|) "\\spad{factor(p)} factors a polynomial with polynomial coefficients.")) (|variable| (((|Union| $ "failed") (|Symbol|)) "\\spad{variable(s)} makes an element from symbol \\spad{s} or fails.")) (|convert| (((|Symbol|) $) "\\spad{convert(x)} converts \\spad{x} to a symbol"))) 
 NIL 
 NIL 
-(-727 |vl| R) 
+(-748 |vl| R) 
 ((|constructor| (NIL "This type is the basic representation of sparse recursive multivariate polynomials whose variables are from a user specified list of symbols. The ordering is specified by the position of the variable in the list. The coefficient ring may be non commutative, but the variables are assumed to commute."))) 
-(((-4604 "*") |has| |#2| (-174)) (-4595 |has| |#2| (-562)) (-4600 |has| |#2| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-562)))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-858 |#1|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#2| (QUOTE -4600)) (|HasCategory| |#2| (QUOTE (-457))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (|HasCategory| |#2| (QUOTE (-149))))) 
-(-728 E OV R PRF) 
+(((-4627 "*") |has| |#2| (-194)) (-4618 |has| |#2| (-582)) (-4623 |has| |#2| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-582)))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-879 |#1|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#2| (QUOTE -4623)) (|HasCategory| |#2| (QUOTE (-477))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (|HasCategory| |#2| (QUOTE (-169))))) 
+(-749 E OV R PRF) 
 ((|constructor| (NIL "This package exports a factor operation for multivariate polynomials with coefficients which are rational functions over some ring \\spad{R} over which we can factor. It is used internally by packages such as primary decomposition which need to work with polynomials with rational function coefficients, \\spadignore{i.e.} themselves fractions of polynomials.")) (|factor| (((|Factored| |#4|) |#4|) "\\spad{factor(prf)} factors a polynomial with rational function coefficients.")) (|pushuconst| ((|#4| (|Fraction| (|Polynomial| |#3|)) |#2|) "\\spad{pushuconst(r,var)} takes a rational function and raises all occurances of the variable \\spad{var} to the polynomial level.")) (|pushucoef| ((|#4| (|SparseUnivariatePolynomial| (|Polynomial| |#3|)) |#2|) "\\spad{pushucoef(upoly,var)} converts the anonymous univariate polynomial \\spad{upoly} to a polynomial in \\spad{var} over rational functions.")) (|pushup| ((|#4| |#4| |#2|) "\\spad{pushup(prf,var)} raises all occurences of the variable \\spad{var} in the coefficients of the polynomial \\spad{prf} back to the polynomial level.")) (|pushdterm| ((|#4| (|SparseUnivariatePolynomial| |#4|) |#2|) "\\spad{pushdterm(monom,var)} pushes all top level occurences of the variable \\spad{var} into the coefficient domain for the monomial monom.")) (|pushdown| ((|#4| |#4| |#2|) "\\spad{pushdown(prf,var)} pushes all top level occurences of the variable \\spad{var} into the coefficient domain for the polynomial prf.")) (|totalfract| (((|Record| (|:| |sup| (|Polynomial| |#3|)) (|:| |inf| (|Polynomial| |#3|))) |#4|) "\\spad{totalfract(prf)} takes a polynomial whose coefficients are themselves fractions of polynomials and returns a record containing the numerator and denominator resulting from putting \\spad{prf} over a common denominator.")) (|convert| (((|Symbol|) $) "\\spad{convert(x)} converts \\spad{x} to a symbol"))) 
 NIL 
 NIL 
-(-729 E OV R P) 
+(-750 E OV R P) 
 ((|constructor| (NIL "MRationalFactorize contains the factor function for multivariate polynomials over the quotient field of a ring \\spad{R} such that the package MultivariateFactorize can factor multivariate polynomials over \\spad{R.}")) (|factor| (((|Factored| |#4|) |#4|) "\\spad{factor(p)} factors the multivariate polynomial \\spad{p} with coefficients which are fractions of elements of \\spad{R.}"))) 
 NIL 
 NIL 
-(-730 R S M) 
+(-751 R S M) 
 ((|constructor| (NIL "\\spad{MonoidRingFunctions2} implements functions between two monoid rings defined with the same monoid over different rings.")) (|map| (((|MonoidRing| |#2| |#3|) (|Mapping| |#2| |#1|) (|MonoidRing| |#1| |#3|)) "\\spad{map(f,u)} maps \\spad{f} onto the coefficients \\spad{f} the element \\spad{u} of the monoid ring to create an element of a monoid ring with the same monoid \\spad{b.}"))) 
 NIL 
 NIL 
-(-731 R M) 
+(-752 R M) 
 ((|constructor| (NIL "\\spadtype{MonoidRing}(R,M), implements the algebra of all maps from the monoid \\spad{M} to the commutative ring \\spad{R} with finite support. Multiplication of two maps \\spad{f} and \\spad{g} is defined to map an element \\spad{c} of \\spad{M} to the (convolution) sum over f(a)g(b) such that ab = \\spad{c.} Thus \\spad{M} can be identified with a canonical basis and the maps can also be considered as formal linear combinations of the elements in \\spad{M.} Scalar multiples of a basis element are called monomials. A prominent example is the class of polynomials where the monoid is a direct product of the natural numbers with pointwise addition. When \\spad{M} is \\spadtype{FreeMonoid Symbol}, one gets polynomials in infinitely many non-commuting variables. Another application area is representation theory of finite groups \\spad{G,} where modules over \\spadtype{MonoidRing}(R,G) are studied.")) (|reductum| (($ $) "\\spad{reductum(f)} is \\spad{f} minus its leading monomial.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(f)} gives the coefficient of \\spad{f,} whose corresponding monoid element is the greatest among all those with non-zero coefficients.")) (|leadingMonomial| ((|#2| $) "\\spad{leadingMonomial(f)} gives the monomial of \\spad{f} whose corresponding monoid element is the greatest among all those with non-zero coefficients.")) (|numberOfMonomials| (((|NonNegativeInteger|) $) "\\spad{numberOfMonomials(f)} is the number of non-zero coefficients with respect to the canonical basis.")) (|monomials| (((|List| $) $) "\\spad{monomials(f)} gives the list of all monomials whose sum is \\spad{f.}")) (|coefficients| (((|List| |#1|) $) "\\spad{coefficients(f)} lists all non-zero coefficients.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(f)} tests if \\spad{f} is a single monomial.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(fn,u)} maps function \\spad{fn} onto the coefficients of the non-zero monomials of u.")) (|terms| (((|List| (|Record| (|:| |coef| |#1|) (|:| |monom| |#2|))) $) "\\spad{terms(f)} gives the list of non-zero coefficients combined with their corresponding basis element as records. This is the internal representation.")) (|coerce| (($ (|List| (|Record| (|:| |coef| |#1|) (|:| |monom| |#2|)))) "\\spad{coerce(lt)} converts a list of terms and coefficients to a member of the domain.")) (|coefficient| ((|#1| $ |#2|) "\\spad{coefficient(f,m)} extracts the coefficient of \\spad{m} in \\spad{f} with respect to the canonical basis \\spad{M.}")) (|monomial| (($ |#1| |#2|) "\\spad{monomial(r,m)} creates a scalar multiple of the basis element \\spad{m.}"))) 
-((-4597 |has| |#1| (-174)) (-4596 |has| |#1| (-174)) (-4599 . T)) 
-((-12 (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#2| (QUOTE (-374)))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-848)))) 
-(-732 S) 
+((-4620 |has| |#1| (-194)) (-4619 |has| |#1| (-194)) (-4622 . T)) 
+((-12 (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#2| (QUOTE (-394)))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-869)))) 
+(-753 S) 
 ((|constructor| (NIL "A multi-set aggregate is a set which keeps track of the multiplicity of its elements."))) 
-((-4592 . T) (-4603 . T) (-3389 . T)) 
+((-4615 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-733 S) 
+(-754 S) 
 ((|constructor| (NIL "A multiset is a set with multiplicities.")) (|remove!| (($ (|Mapping| (|Boolean|) |#1|) $ (|Integer|)) "\\spad{remove!(p,ms,number)} removes destructively at most \\spad{number} copies of elements \\spad{x} such that \\spad{p(x)} is \\spadfun{true} if \\spad{number} is positive, all of them if \\spad{number} equals zero, and all but at most \\spad{-number} if \\spad{number} is negative.") (($ |#1| $ (|Integer|)) "\\spad{remove!(x,ms,number)} removes destructively at most \\spad{number} copies of element \\spad{x} if \\spad{number} is positive, all of them if \\spad{number} equals zero, and all but at most \\spad{-number} if \\spad{number} is negative.")) (|remove| (($ (|Mapping| (|Boolean|) |#1|) $ (|Integer|)) "\\spad{remove(p,ms,number)} removes at most \\spad{number} copies of elements \\spad{x} such that \\spad{p(x)} is \\spadfun{true} if \\spad{number} is positive, all of them if \\spad{number} equals zero, and all but at most \\spad{-number} if \\spad{number} is negative.") (($ |#1| $ (|Integer|)) "\\spad{remove(x,ms,number)} removes at most \\spad{number} copies of element \\spad{x} if \\spad{number} is positive, all of them if \\spad{number} equals zero, and all but at most \\spad{-number} if \\spad{number} is negative.")) (|members| (((|List| |#1|) $) "\\spad{members(ms)} returns a list of the elements of \\spad{ms} without their multiplicity. See also \\spadfun{parts}.")) (|multiset| (($ (|List| |#1|)) "\\spad{multiset(ls)} creates a multiset with elements from \\spad{ls}.") (($ |#1|) "\\spad{multiset(s)} creates a multiset with singleton \\spad{s.}") (($) "\\spad{multiset()}$D creates an empty multiset of domain \\spad{D.}"))) 
-((-4602 . T) (-4592 . T) (-4603 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-734) 
+((-4625 . T) (-4615 . T) (-4626 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-755) 
 ((|constructor| (NIL "\\spadtype{MoreSystemCommands} implements an interface with the system command facility. These are the commands that are issued from source files or the system interpreter and they start with a close parenthesis, for example, the \"what\" commands.")) (|systemCommand| (((|Void|) (|String|)) "\\spad{systemCommand(cmd)} takes the string \\spadvar{cmd} and passes it to the runtime environment for execution as a system command. Although various things may be printed, no usable value is returned."))) 
 NIL 
 NIL 
-(-735 S) 
+(-756 S) 
 ((|constructor| (NIL "This package exports tools for merging lists")) (|mergeDifference| (((|List| |#1|) (|List| |#1|) (|List| |#1|)) "\\spad{mergeDifference(l1,l2)} returns a list of elements in \\spad{l1} not present in \\spad{l2.} Assumes lists are ordered and all \\spad{x} in \\spad{l2} are also in \\spad{l1.}"))) 
 NIL 
 NIL 
-(-736 |Coef| |Var|) 
+(-757 |Coef| |Var|) 
 ((|constructor| (NIL "\\spadtype{MultivariateTaylorSeriesCategory} is the most general multivariate Taylor series category.")) (|integrate| (($ $ |#2|) "\\spad{integrate(f,x)} returns the anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{x} with constant coefficient 1. We may integrate a series when we can divide coefficients by integers.")) (|polynomial| (((|Polynomial| |#1|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{polynomial(f,k1,k2)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 \\spad{<=} \\spad{d} \\spad{<=} k2}.") (((|Polynomial| |#1|) $ (|NonNegativeInteger|)) "\\spad{polynomial(f,k)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{<= \\spad{k}.}")) (|order| (((|NonNegativeInteger|) $ |#2| (|NonNegativeInteger|)) "\\spad{order(f,x,n)} returns \\spad{min(n,order(f,x))}.") (((|NonNegativeInteger|) $ |#2|) "\\spad{order(f,x)} returns the order of \\spad{f} viewed as a series in \\spad{x} may result in an infinite loop if \\spad{f} has no non-zero terms.")) (|monomial| (($ $ (|List| |#2|) (|List| (|NonNegativeInteger|))) "\\spad{monomial(a,[x1,x2,...,xk],[n1,n2,...,nk])} returns \\spad{a * \\spad{x1^n1} * \\spad{...} * xk^nk}.") (($ $ |#2| (|NonNegativeInteger|)) "\\spad{monomial(a,x,n)} returns \\spad{a*x^n}.")) (|extend| (($ $ (|NonNegativeInteger|)) "\\spad{extend(f,n)} causes all terms of \\spad{f} of degree \\spad{<= \\spad{n}} to be computed.")) (|coefficient| (($ $ (|List| |#2|) (|List| (|NonNegativeInteger|))) "\\spad{coefficient(f,[x1,x2,...,xk],[n1,n2,...,nk])} returns the coefficient of \\spad{x1^n1 * \\spad{...} * xk^nk} in \\spad{f.}") (($ $ |#2| (|NonNegativeInteger|)) "\\spad{coefficient(f,x,n)} returns the coefficient of \\spad{x^n} in \\spad{f.}"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4597 . T) (-4596 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4620 . T) (-4619 . T) (-4622 . T)) 
 NIL 
-(-737 OV E R P) 
+(-758 OV E R P) 
 ((|constructor| (NIL "This is the top level package for doing multivariate factorization over basic domains like \\spadtype{Integer} or \\spadtype{Fraction Integer}.")) (|factor| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factor(p)} factors the multivariate polynomial \\spad{p} over its coefficient domain where \\spad{p} is represented as a univariate polynomial with multivariate coefficients") (((|Factored| |#4|) |#4|) "\\spad{factor(p)} factors the multivariate polynomial \\spad{p} over its coefficient domain"))) 
 NIL 
 NIL 
-(-738 E OV R P) 
+(-759 E OV R P) 
 ((|constructor| (NIL "This package provides the functions for the computation of the square free decomposition of a multivariate polynomial. It uses the package GenExEuclid for the resolution of the equation \\spad{Af + \\spad{Bg} = \\spad{h}} and its generalization to \\spad{n} polynomials over an integral domain and the package \\spad{MultivariateLifting} for the \"multivariate\" lifting.")) (|normDeriv2| (((|SparseUnivariatePolynomial| |#3|) (|SparseUnivariatePolynomial| |#3|) (|Integer|)) "\\spad{normDeriv2 should} be local")) (|myDegree| (((|List| (|NonNegativeInteger|)) (|SparseUnivariatePolynomial| |#4|) (|List| |#2|) (|NonNegativeInteger|)) "\\spad{myDegree should} be local")) (|lift| (((|Union| (|List| (|SparseUnivariatePolynomial| |#4|)) "failed") (|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#3|) (|SparseUnivariatePolynomial| |#3|) |#4| (|List| |#2|) (|List| (|NonNegativeInteger|)) (|List| |#3|)) "\\spad{lift should} be local")) (|check| (((|Boolean|) (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| |#3|)) (|:| |exponent| (|Integer|)))) (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| |#3|)) (|:| |exponent| (|Integer|))))) "\\spad{check should} be local")) (|coefChoose| ((|#4| (|Integer|) (|Factored| |#4|)) "\\spad{coefChoose should} be local")) (|intChoose| (((|Record| (|:| |upol| (|SparseUnivariatePolynomial| |#3|)) (|:| |Lval| (|List| |#3|)) (|:| |Lfact| (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| |#3|)) (|:| |exponent| (|Integer|))))) (|:| |ctpol| |#3|)) (|SparseUnivariatePolynomial| |#4|) (|List| |#2|) (|List| (|List| |#3|))) "\\spad{intChoose should} be local")) (|nsqfree| (((|Record| (|:| |unitPart| |#4|) (|:| |suPart| (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| |#4|)) (|:| |exponent| (|Integer|)))))) (|SparseUnivariatePolynomial| |#4|) (|List| |#2|) (|List| (|List| |#3|))) "\\spad{nsqfree should} be local")) (|consnewpol| (((|Record| (|:| |pol| (|SparseUnivariatePolynomial| |#4|)) (|:| |polval| (|SparseUnivariatePolynomial| |#3|))) (|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#3|) (|Integer|)) "\\spad{consnewpol should} be local")) (|univcase| (((|Factored| |#4|) |#4| |#2|) "\\spad{univcase should} be local")) (|compdegd| (((|Integer|) (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| |#3|)) (|:| |exponent| (|Integer|))))) "\\spad{compdegd should} be local")) (|squareFreePrim| (((|Factored| |#4|) |#4|) "\\spad{squareFreePrim(p)} compute the square free decomposition of a primitive multivariate polynomial \\spad{p.}")) (|squareFree| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{squareFree(p)} computes the square free decomposition of a multivariate polynomial \\spad{p} presented as a univariate polynomial with multivariate coefficients.") (((|Factored| |#4|) |#4|) "\\spad{squareFree(p)} computes the square free decomposition of a multivariate polynomial \\spad{p.}"))) 
 NIL 
 NIL 
-(-739 |q| R) 
+(-760 |q| R) 
 ((|constructor| (NIL "This domain has no description"))) 
-((-4600 |has| |#2| (-562)) (-4594 |has| |#2| (-562)) (-4599 -1841 (|has| |#2| (-482)) (|has| |#2| (-1054))) (-4597 |has| |#2| (-174)) (-4596 |has| |#2| (-174)) ((-4604 "*") |has| |#2| (-562)) (-4595 |has| |#2| (-562))) 
-((|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-482))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (-1841 (|HasCategory| |#2| (QUOTE (-482))) (|HasCategory| |#2| (QUOTE (-562)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (|HasCategory| |#2| (QUOTE (-482))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-1110))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-562)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-562)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-562))))) (|HasCategory| $ (QUOTE (-1054))) (|HasCategory| $ (LIST (QUOTE -1044) (QUOTE (-572))))) 
-(-740 |x| R) 
+((-4623 |has| |#2| (-582)) (-4617 |has| |#2| (-582)) (-4622 -3836 (|has| |#2| (-502)) (|has| |#2| (-1075))) (-4620 |has| |#2| (-194)) (-4619 |has| |#2| (-194)) ((-4627 "*") |has| |#2| (-582)) (-4618 |has| |#2| (-582))) 
+((|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-502))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (-3836 (|HasCategory| |#2| (QUOTE (-502))) (|HasCategory| |#2| (QUOTE (-582)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (|HasCategory| |#2| (QUOTE (-502))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-1131))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-582)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-582)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-582))))) (|HasCategory| $ (QUOTE (-1075))) (|HasCategory| $ (LIST (QUOTE -1065) (QUOTE (-592))))) 
+(-761 |x| R) 
 ((|constructor| (NIL "This domain has no description")) (|fmecg| (($ $ (|NonNegativeInteger|) |#2| $) "\\spad{fmecg(p1,e,r,p2)} finds \\spad{x} : \\spad{p1} - \\spad{r} * x**e * \\spad{p2}")) (|coerce| (($ (|Variable| |#1|)) "\\spad{coerce(x)} converts the variable \\spad{x} to a univariate polynomial."))) 
-(((-4604 "*") |has| |#2| (-174)) (-4595 |has| |#2| (-562)) (-4598 |has| |#2| (-368)) (-4600 |has| |#2| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-562)))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1144))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasCategory| |#2| (QUOTE (-227))) (|HasAttribute| |#2| (QUOTE -4600)) (|HasCategory| |#2| (QUOTE (-457))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (|HasCategory| |#2| (QUOTE (-149))))) 
-(-741 S R) 
+(((-4627 "*") |has| |#2| (-194)) (-4618 |has| |#2| (-582)) (-4621 |has| |#2| (-388)) (-4623 |has| |#2| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-582)))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1165))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasCategory| |#2| (QUOTE (-247))) (|HasAttribute| |#2| (QUOTE -4623)) (|HasCategory| |#2| (QUOTE (-477))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (|HasCategory| |#2| (QUOTE (-169))))) 
+(-762 S R) 
 ((|constructor| (NIL "NonAssociativeAlgebra is the category of non associative algebras (modules which are themselves non associative rngs).\\br \\blankline Axioms\\br \\tab{5}r*(a*b) = (r*a)*b = a*(r*b)")) (|plenaryPower| (($ $ (|PositiveInteger|)) "\\spad{plenaryPower(a,n)} is recursively defined to be \\spad{plenaryPower(a,n-1)*plenaryPower(a,n-1)} for \\spad{n>1} and \\spad{a} for \\spad{n=1}."))) 
 NIL 
 NIL 
-(-742 R) 
+(-763 R) 
 ((|constructor| (NIL "NonAssociativeAlgebra is the category of non associative algebras (modules which are themselves non associative rngs).\\br \\blankline Axioms\\br \\tab{5}r*(a*b) = (r*a)*b = a*(r*b)")) (|plenaryPower| (($ $ (|PositiveInteger|)) "\\spad{plenaryPower(a,n)} is recursively defined to be \\spad{plenaryPower(a,n-1)*plenaryPower(a,n-1)} for \\spad{n>1} and \\spad{a} for \\spad{n=1}."))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-743) 
+(-764) 
 ((|constructor| (NIL "This package uses the NAG Library to compute the zeros of a polynomial with real or complex coefficients.")) (|c02agf| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Boolean|) (|Integer|)) "\\spad{c02agf(a,n,scale,ifail)} finds all the roots of a real polynomial equation, using a variant of Laguerre's Method. See \\downlink{Manual Page}{manpageXXc02agf}.")) (|c02aff| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Boolean|) (|Integer|)) "\\spad{c02aff(a,n,scale,ifail)} finds all the roots of a complex polynomial equation, using a variant of Laguerre's Method. See \\downlink{Manual Page}{manpageXXc02aff}."))) 
 NIL 
 NIL 
-(-744) 
+(-765) 
 ((|constructor| (NIL "This package uses the NAG Library to calculate real zeros of continuous real functions of one or more variables. (Complex equations must be expressed in terms of the equivalent larger system of real equations.)")) (|c05pbf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp35| FCN)))) "\\spad{c05pbf(n,ldfjac,lwa,x,xtol,ifail,fcn)} is an easy-to-use routine to find a solution of a system of nonlinear equations by a modification of the Powell hybrid method. The user must provide the Jacobian. See \\downlink{Manual Page}{manpageXXc05pbf}.")) (|c05nbf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp6| FCN)))) "\\spad{c05nbf(n,lwa,x,xtol,ifail,fcn)} is an easy-to-use routine to find a solution of a system of nonlinear equations by a modification of the Powell hybrid method. See \\downlink{Manual Page}{manpageXXc05nbf}.")) (|c05adf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) "\\spad{c05adf(a,b,eps,eta,ifail,f)} locates a zero of a continuous function in a given interval by a combination of the methods of linear interpolation, extrapolation and bisection. See \\downlink{Manual Page}{manpageXXc05adf}."))) 
 NIL 
 NIL 
-(-745) 
+(-766) 
 ((|constructor| (NIL "This package uses the NAG Library to calculate the discrete Fourier transform of a sequence of real or complex data values, and applies it to calculate convolutions and correlations.")) (|c06gsf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06gsf(m,n,x,ifail)} takes \\spad{m} Hermitian sequences, each containing \\spad{n} data values, and forms the real and imaginary parts of the \\spad{m} corresponding complex sequences. See \\downlink{Manual Page}{manpageXXc06gsf}.")) (|c06gqf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06gqf(m,n,x,ifail)} forms the complex conjugates, each containing \\spad{n} data values. See \\downlink{Manual Page}{manpageXXc06gqf}.")) (|c06gcf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06gcf(n,y,ifail)} forms the complex conjugate of a sequence of \\spad{n} data values. See \\downlink{Manual Page}{manpageXXc06gcf}.")) (|c06gbf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06gbf(n,x,ifail)} forms the complex conjugate of \\spad{n} data values. See \\downlink{Manual Page}{manpageXXc06gbf}.")) (|c06fuf| (((|Result|) (|Integer|) (|Integer|) (|String|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06fuf(m,n,init,x,y,trigm,trign,ifail)} computes the two-dimensional discrete Fourier transform of a bivariate sequence of complex data values. This routine is designed to be particularly efficient on vector processors. See \\downlink{Manual Page}{manpageXXc06fuf}.")) (|c06frf| (((|Result|) (|Integer|) (|Integer|) (|String|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06frf(m,n,init,x,y,trig,ifail)} computes the discrete Fourier transforms of \\spad{m} sequences, each containing \\spad{n} complex data values. This routine is designed to be particularly efficient on vector processors. See \\downlink{Manual Page}{manpageXXc06frf}.")) (|c06fqf| (((|Result|) (|Integer|) (|Integer|) (|String|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06fqf(m,n,init,x,trig,ifail)} computes the discrete Fourier transforms of \\spad{m} Hermitian sequences, each containing \\spad{n} complex data values. This routine is designed to be particularly efficient on vector processors. See \\downlink{Manual Page}{manpageXXc06fqf}.")) (|c06fpf| (((|Result|) (|Integer|) (|Integer|) (|String|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06fpf(m,n,init,x,trig,ifail)} computes the discrete Fourier transforms of \\spad{m} sequences, each containing \\spad{n} real data values. This routine is designed to be particularly efficient on vector processors. See \\downlink{Manual Page}{manpageXXc06fpf}.")) (|c06ekf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06ekf(job,n,x,y,ifail)} calculates the circular convolution of two real vectors of period \\spad{n.} No extra workspace is required. See \\downlink{Manual Page}{manpageXXc06ekf}.")) (|c06ecf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06ecf(n,x,y,ifail)} calculates the discrete Fourier transform of a sequence of \\spad{n} complex data values. (No extra workspace required.) See \\downlink{Manual Page}{manpageXXc06ecf}.")) (|c06ebf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06ebf(n,x,ifail)} calculates the discrete Fourier transform of a Hermitian sequence of \\spad{n} complex data values. (No extra workspace required.) See \\downlink{Manual Page}{manpageXXc06ebf}.")) (|c06eaf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{c06eaf(n,x,ifail)} calculates the discrete Fourier transform of a sequence of \\spad{n} real data values. (No extra workspace required.) See \\downlink{Manual Page}{manpageXXc06eaf}."))) 
 NIL 
 NIL 
-(-746) 
+(-767) 
 ((|constructor| (NIL "This package uses the NAG Library to calculate the numerical value of definite integrals in one or more dimensions and to evaluate weights and abscissae of integration rules.")) (|d01gbf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp4| FUNCTN)))) "\\spad{d01gbf(ndim,a,b,maxcls,eps,lenwrk,mincls,wrkstr,ifail,functn)} returns an approximation to the integral of a function over a hyper-rectangular region, using a Monte Carlo method. An approximate relative error estimate is also returned. This routine is suitable for low accuracy work. See \\downlink{Manual Page}{manpageXXd01gbf}.")) (|d01gaf| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|)) "\\spad{d01gaf(x,y,n,ifail)} integrates a function which is specified numerically at four or more points, over the whole of its specified range, using third-order finite-difference formulae with error estimates, according to a method due to Gill and Miller. See \\downlink{Manual Page}{manpageXXd01gaf}.")) (|d01fcf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp4| FUNCTN)))) "\\spad{d01fcf(ndim,a,b,maxpts,eps,lenwrk,minpts,ifail,functn)} attempts to evaluate a multi-dimensional integral (up to 15 dimensions), with constant and finite limits, to a specified relative accuracy, using an adaptive subdivision strategy. See \\downlink{Manual Page}{manpageXXd01fcf}.")) (|d01bbf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{d01bbf(a,b,itype,n,gtype,ifail)} returns the weight appropriate to a Gaussian quadrature. The formulae provided are Gauss-Legendre, Gauss-Rational, Gauss- Laguerre and Gauss-Hermite. See \\downlink{Manual Page}{manpageXXd01bbf}.")) (|d01asf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| G)))) "\\spad{d01asf(a,omega,key,epsabs,limlst,lw,liw,ifail,g)} calculates an approximation to the sine or the cosine transform of a function \\spad{g} over [a,infty): See \\downlink{Manual Page}{manpageXXd01asf}.")) (|d01aqf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| G)))) "\\spad{d01aqf(a,b,c,epsabs,epsrel,lw,liw,ifail,g)} calculates an approximation to the Hilbert transform of a function g(x) over [a,b]: See \\downlink{Manual Page}{manpageXXd01aqf}.")) (|d01apf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| G)))) "\\spad{d01apf(a,b,alfa,beta,key,epsabs,epsrel,lw,liw,ifail,g)} is an adaptive integrator which calculates an approximation to the integral of a function g(x)w(x) over a finite interval [a,b]: See \\downlink{Manual Page}{manpageXXd01apf}.")) (|d01anf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| G)))) "\\spad{d01anf(a,b,omega,key,epsabs,epsrel,lw,liw,ifail,g)} calculates an approximation to the sine or the cosine transform of a function \\spad{g} over [a,b]: See \\downlink{Manual Page}{manpageXXd01anf}.")) (|d01amf| (((|Result|) (|DoubleFloat|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) "\\spad{d01amf(bound,inf,epsabs,epsrel,lw,liw,ifail,f)} calculates an approximation to the integral of a function f(x) over an infinite or semi-infinite interval [a,b]: See \\downlink{Manual Page}{manpageXXd01amf}.")) (|d01alf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) "\\spad{d01alf(a,b,npts,points,epsabs,epsrel,lw,liw,ifail,f)} is a general purpose integrator which calculates an approximation to the integral of a function f(x) over a finite interval [a,b]: See \\downlink{Manual Page}{manpageXXd01alf}.")) (|d01akf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) "\\spad{d01akf(a,b,epsabs,epsrel,lw,liw,ifail,f)} is an adaptive integrator, especially suited to oscillating, non-singular integrands, which calculates an approximation to the integral of a function f(x) over a finite interval [a,b]: See \\downlink{Manual Page}{manpageXXd01akf}.")) (|d01ajf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) "\\spad{d01ajf(a,b,epsabs,epsrel,lw,liw,ifail,f)} is a general-purpose integrator which calculates an approximation to the integral of a function f(x) over a finite interval [a,b]: See \\downlink{Manual Page}{manpageXXd01ajf}."))) 
 NIL 
 NIL 
-(-747) 
+(-768) 
 ((|constructor| (NIL "This package uses the NAG Library to calculate the numerical solution of ordinary differential equations. There are two main types of problem, those in which all boundary conditions are specified at one point (initial-value problems), and those in which the boundary conditions are distributed between two or more points (boundary- value problems and eigenvalue problems). Routines are available for initial-value problems, two-point boundary-value problems and Sturm-Liouville eigenvalue problems.")) (|d02raf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp41| FCN JACOBF JACEPS))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp42| G JACOBG JACGEP)))) "d02raf(n,mnp,numbeg,nummix,tol,init,iy,ijac,lwork, \\indented{7}{liwork,np,x,y,deleps,ifail,fcn,g)} solves the two-point boundary-value problem with general boundary conditions for a system of ordinary differential equations, using a deferred correction technique and Newton iteration. See \\downlink{Manual Page}{manpageXXd02raf}.")) (|d02kef| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp10| COEFFN))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp80| BDYVAL))) (|FileName|) (|FileName|)) "d02kef(xpoint,m,k,tol,maxfun,match,elam,delam, \\indented{7}{hmax,maxit,ifail,coeffn,bdyval,monit,report)} finds a specified eigenvalue of a regular singular second- order Sturm-Liouville system on a finite or infinite range, using a Pruefer transformation and a shooting method. It also reports values of the eigenfunction and its derivatives. Provision is made for discontinuities in the coefficient functions or their derivatives. See \\downlink{Manual Page}{manpageXXd02kef}. Files \\spad{monit} and \\spad{report} will be used to define the subroutines for the MONIT and REPORT arguments. See \\downlink{Manual Page}{manpageXXd02gbf}.") (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp10| COEFFN))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp80| BDYVAL)))) "d02kef(xpoint,m,k,tol,maxfun,match,elam,delam, \\indented{7}{hmax,maxit,ifail,coeffn,bdyval)} finds a specified eigenvalue of a regular singular second- order Sturm-Liouville system on a finite or infinite range, using a Pruefer transformation and a shooting method. It also reports values of the eigenfunction and its derivatives. Provision is made for discontinuities in the coefficient functions or their derivatives. See \\downlink{Manual Page}{manpageXXd02kef}. ASP domains \\spad{Asp12} and \\spad{Asp33} are used to supply default subroutines for the MONIT and REPORT arguments via their \\axiomOp{outputAsFortran} operation.")) (|d02gbf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp77| FCNF))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp78| FCNG)))) "\\spad{d02gbf(a,b,n,tol,mnp,lw,liw,c,d,gam,x,np,ifail,fcnf,fcng)} solves a general linear two-point boundary value problem for a system of ordinary differential equations using a deferred correction technique. See \\downlink{Manual Page}{manpageXXd02gbf}.")) (|d02gaf| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) "\\spad{d02gaf(u,v,n,a,b,tol,mnp,lw,liw,x,np,ifail,fcn)} solves the two-point boundary-value problem with assigned boundary values for a system of ordinary differential equations, using a deferred correction technique and a Newton iteration. See \\downlink{Manual Page}{manpageXXd02gaf}.")) (|d02ejf| (((|Result|) (|DoubleFloat|) (|Integer|) (|Integer|) (|String|) (|Integer|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp9| G))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp31| PEDERV))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp8| OUTPUT)))) "\\spad{d02ejf(xend,m,n,relabs,iw,x,y,tol,ifail,g,fcn,pederv,output)} integrates a stiff system of first-order ordinary differential equations over an interval with suitable initial conditions, using a variable-order, variable-step method implementing the Backward Differentiation Formulae (BDF), until a user-specified function, if supplied, of the solution is zero, and returns the solution at points specified by the user, if desired. See \\downlink{Manual Page}{manpageXXd02ejf}.")) (|d02cjf| (((|Result|) (|DoubleFloat|) (|Integer|) (|Integer|) (|DoubleFloat|) (|String|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp9| G))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp8| OUTPUT)))) "\\spad{d02cjf(xend,m,n,tol,relabs,x,y,ifail,g,fcn,output)} integrates a system of first-order ordinary differential equations over a range with suitable initial conditions, using a variable-order, variable-step Adams method until a user-specified function, if supplied, of the solution is zero, and returns the solution at points specified by the user, if desired. See \\downlink{Manual Page}{manpageXXd02cjf}.")) (|d02bhf| (((|Result|) (|DoubleFloat|) (|Integer|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp9| G))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) "\\spad{d02bhf(xend,n,irelab,hmax,x,y,tol,ifail,g,fcn)} integrates a system of first-order ordinary differential equations over an interval with suitable initial conditions, using a Runge-Kutta-Merson method, until a user-specified function of the solution is zero. See \\downlink{Manual Page}{manpageXXd02bhf}.")) (|d02bbf| (((|Result|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp8| OUTPUT)))) "\\spad{d02bbf(xend,m,n,irelab,x,y,tol,ifail,fcn,output)} integrates a system of first-order ordinary differential equations over an interval with suitable initial conditions, using a Runge-Kutta-Merson method, and returns the solution at points specified by the user. See \\downlink{Manual Page}{manpageXXd02bbf}."))) 
 NIL 
 NIL 
-(-748) 
+(-769) 
 ((|constructor| (NIL "This package uses the NAG Library to solve partial differential equations.")) (|d03faf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|ThreeDimensionalMatrix| (|DoubleFloat|)) (|Integer|)) "d03faf(xs,xf,l,lbdcnd,bdxs,bdxf,ys,yf,m,mbdcnd,bdys,bdyf,zs, \\indented{7}{zf,n,nbdcnd,bdzs,bdzf,lambda,ldimf,mdimf,lwrk,f,ifail)} solves the Helmholtz equation in Cartesian co-ordinates in three dimensions using the standard seven-point finite difference approximation. This routine is designed to be particularly efficient on vector processors. See \\downlink{Manual Page}{manpageXXd03faf}.")) (|d03eef| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|String|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp73| PDEF))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp74| BNDY)))) "\\spad{d03eef(xmin,xmax,ymin,ymax,ngx,ngy,lda,scheme,ifail,pdef,bndy)} discretizes a second order elliptic partial differential equation (PDE) on a rectangular region. See \\downlink{Manual Page}{manpageXXd03eef}.")) (|d03edf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{d03edf(ngx,ngy,lda,maxit,acc,iout,a,rhs,ub,ifail)} solves seven-diagonal systems of linear equations which arise from the discretization of an elliptic partial differential equation on a rectangular region. This routine uses a multigrid technique. See \\downlink{Manual Page}{manpageXXd03edf}."))) 
 NIL 
 NIL 
-(-749) 
+(-770) 
 ((|constructor| (NIL "This package uses the NAG Library to calculate the interpolation of a function of one or two variables. When provided with the value of the function (and possibly one or more of its lowest-order derivatives) at each of a number of values of the variable(s), the routines provide either an interpolating function or an interpolated value. For some of the interpolating functions, there are supporting routines to evaluate, differentiate or integrate them.")) (|e01sff| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{e01sff(m,x,y,f,rnw,fnodes,px,py,ifail)} evaluates at a given point the two-dimensional interpolating function computed by E01SEF. See \\downlink{Manual Page}{manpageXXe01sff}.")) (|e01sef| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{e01sef(m,x,y,f,nw,nq,rnw,rnq,ifail)} generates a two-dimensional surface interpolating a set of scattered data points, using a modified Shepard method. See \\downlink{Manual Page}{manpageXXe01sef}.")) (|e01sbf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{e01sbf(m,x,y,f,triang,grads,px,py,ifail)} evaluates at a given point the two-dimensional interpolant function computed by E01SAF. See \\downlink{Manual Page}{manpageXXe01sbf}.")) (|e01saf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e01saf(m,x,y,f,ifail)} generates a two-dimensional surface interpolating a set of scattered data points, using the method of Renka and Cline. See \\downlink{Manual Page}{manpageXXe01saf}.")) (|e01daf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e01daf(mx,my,x,y,f,ifail)} computes a bicubic spline interpolating surface through a set of data values, given on a rectangular grid in the x-y plane. See \\downlink{Manual Page}{manpageXXe01daf}.")) (|e01bhf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{e01bhf(n,x,f,d,a,b,ifail)} evaluates the definite integral of a piecewise cubic Hermite interpolant over the interval [a,b]. See \\downlink{Manual Page}{manpageXXe01bhf}.")) (|e01bgf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e01bgf(n,x,f,d,m,px,ifail)} evaluates a piecewise cubic Hermite interpolant and its first derivative at a set of points. See \\downlink{Manual Page}{manpageXXe01bgf}.")) (|e01bff| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e01bff(n,x,f,d,m,px,ifail)} evaluates a piecewise cubic Hermite interpolant at a set of points. See \\downlink{Manual Page}{manpageXXe01bff}.")) (|e01bef| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e01bef(n,x,f,ifail)} computes a monotonicity-preserving piecewise cubic Hermite interpolant to a set of data points. See \\downlink{Manual Page}{manpageXXe01bef}.")) (|e01baf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{e01baf(m,x,y,lck,lwrk,ifail)} determines a cubic spline to a given set of data. See \\downlink{Manual Page}{manpageXXe01baf}."))) 
 NIL 
 NIL 
-(-750) 
+(-771) 
 ((|constructor| (NIL "This package uses the NAG Library to find a function which approximates a set of data points. Typically the data contain random errors, as of experimental measurement, which need to be smoothed out. To seek an approximation to the data, it is first necessary to specify for the approximating function a mathematical form (a polynomial, for example) which contains a number of unspecified coefficients: the appropriate fitting routine then derives for the coefficients the values which provide the best fit of that particular form. The package deals mainly with curve and surface fitting (\\spadignore{i.e.} fitting with functions of one and of two variables) when a polynomial or a cubic spline is used as the fitting function, since these cover the most common needs. However, fitting with other functions and/or more variables can be undertaken by means of general linear or nonlinear routines (some of which are contained in other packages) depending on whether the coefficients in the function occur linearly or nonlinearly. Cases where a graph rather than a set of data points is given can be treated simply by first reading a suitable set of points from the graph. The package also contains routines for evaluating, differentiating and integrating polynomial and spline curves and surfaces, once the numerical values of their coefficients have been determined.")) (|e02zaf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{e02zaf(px,py,lamda,mu,m,x,y,npoint,nadres,ifail)} sorts two-dimensional data into rectangular panels. See \\downlink{Manual Page}{manpageXXe02zaf}.")) (|e02gaf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e02gaf(m,la,nplus2,toler,a,b,ifail)} calculates an \\spad{l} solution to an over-determined system of linear equations. See \\downlink{Manual Page}{manpageXXe02gaf}.")) (|e02dff| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{e02dff(mx,my,px,py,x,y,lamda,mu,c,lwrk,liwrk,ifail)} calculates values of a bicubic spline representation. The spline is evaluated at all points on a rectangular grid. See \\downlink{Manual Page}{manpageXXe02dff}.")) (|e02def| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e02def(m,px,py,x,y,lamda,mu,c,ifail)} calculates values of a bicubic spline representation. See \\downlink{Manual Page}{manpageXXe02def}.")) (|e02ddf| (((|Result|) (|String|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e02ddf(start,m,x,y,f,w,s,nxest,nyest,lwrk,liwrk,nx, \\spad{++} lamda,ny,mu,wrk,ifail)} computes a bicubic spline approximation to a set of scattered data are located automatically, but a single parameter must be specified to control the trade-off between closeness of fit and smoothness of fit. See \\downlink{Manual Page}{manpageXXe02ddf}.")) (|e02dcf| (((|Result|) (|String|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Integer|)) "\\spad{e02dcf(start,mx,x,my,y,f,s,nxest,nyest,lwrk,liwrk,nx, \\spad{++} lamda,ny,mu,wrk,iwrk,ifail)} computes a bicubic spline approximation to a set of data values, given on a rectangular grid in the x-y plane. The knots of the spline are located automatically, but a single parameter must be specified to control the trade-off between closeness of fit and smoothness of fit. See \\downlink{Manual Page}{manpageXXe02dcf}.")) (|e02daf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e02daf(m,px,py,x,y,f,w,mu,point,npoint,nc,nws,eps,lamda,ifail)} forms a minimal, weighted least-squares bicubic spline surface fit with prescribed knots to a given set of data points. See \\downlink{Manual Page}{manpageXXe02daf}.")) (|e02bef| (((|Result|) (|String|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|))) "\\spad{e02bef(start,m,x,y,w,s,nest,lwrk,n,lamda,ifail,wrk,iwrk)} computes a cubic spline approximation to an arbitrary set of data points. The knot are located automatically, but a single parameter must be specified to control the trade-off between closeness of fit and smoothness of fit. See \\downlink{Manual Page}{manpageXXe02bef}.")) (|e02bdf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e02bdf(ncap7,lamda,c,ifail)} computes the definite integral from its B-spline representation. See \\downlink{Manual Page}{manpageXXe02bdf}.")) (|e02bcf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|) (|Integer|)) "\\spad{e02bcf(ncap7,lamda,c,x,left,ifail)} evaluates a cubic spline and its first three derivatives from its B-spline representation. See \\downlink{Manual Page}{manpageXXe02bcf}.")) (|e02bbf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|)) "\\spad{e02bbf(ncap7,lamda,c,x,ifail)} evaluates a cubic spline representation. See \\downlink{Manual Page}{manpageXXe02bbf}.")) (|e02baf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e02baf(m,ncap7,x,y,w,lamda,ifail)} computes a weighted least-squares approximation to an arbitrary set of data points by a cubic splines prescribed by the user. Cubic spline can also be carried out. See \\downlink{Manual Page}{manpageXXe02baf}.")) (|e02akf| (((|Result|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|)) "\\spad{e02akf(np1,xmin,xmax,a,ia1,la,x,ifail)} evaluates a polynomial from its Chebyshev-series representation, allowing an arbitrary index increment for accessing the array of coefficients. See \\downlink{Manual Page}{manpageXXe02akf}.")) (|e02ajf| (((|Result|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{e02ajf(np1,xmin,xmax,a,ia1,la,qatm1,iaint1,laint,ifail)} determines the coefficients in the Chebyshev-series representation of the indefinite integral of a polynomial given in Chebyshev-series form. See \\downlink{Manual Page}{manpageXXe02ajf}.")) (|e02ahf| (((|Result|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{e02ahf(np1,xmin,xmax,a,ia1,la,iadif1,ladif,ifail)} determines the coefficients in the Chebyshev-series representation of the derivative of a polynomial given in Chebyshev-series form. See \\downlink{Manual Page}{manpageXXe02ahf}.")) (|e02agf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|Integer|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{e02agf(m,kplus1,nrows,xmin,xmax,x,y,w,mf,xf,yf,lyf,ip,lwrk,liwrk,ifail)} computes constrained weighted least-squares polynomial approximations in Chebyshev-series form to an arbitrary set of data points. The values of the approximations and any number of their derivatives can be specified at selected points. See \\downlink{Manual Page}{manpageXXe02agf}.")) (|e02aef| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|DoubleFloat|) (|Integer|)) "\\spad{e02aef(nplus1,a,xcap,ifail)} evaluates a polynomial from its Chebyshev-series representation. See \\downlink{Manual Page}{manpageXXe02aef}.")) (|e02adf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e02adf(m,kplus1,nrows,x,y,w,ifail)} computes weighted least-squares polynomial approximations to an arbitrary set of data points. See \\downlink{Manual Page}{manpageXXe02adf}."))) 
 NIL 
 NIL 
-(-751) 
+(-772) 
 ((|constructor| (NIL "This package uses the NAG Library to perform optimization. An optimization problem involves minimizing a function (called the objective function) of several variables, possibly subject to restrictions on the values of the variables defined by a set of constraint functions. The routines in the NAG Foundation Library are concerned with function minimization only, since the problem of maximizing a given function can be transformed into a minimization problem simply by multiplying the function by \\spad{-1.}")) (|e04ycf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{e04ycf(job,m,n,fsumsq,s,lv,v,ifail)} returns estimates of elements of the variance matrix of the estimated regression coefficients for a nonlinear least squares problem. The estimates are derived from the Jacobian of the function f(x) at the solution. See \\downlink{Manual Page}{manpageXXe04ycf}.")) (|e04ucf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Boolean|) (|DoubleFloat|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Boolean|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Boolean|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|Integer|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp55| CONFUN))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp49| OBJFUN)))) "e04ucf(n,nclin,ncnln,nrowa,nrowj,nrowr,a,bl,bu,liwork,lwork,sta, \\indented{7}{cra,der,fea,fun,hes,infb,infs,linf,lint,list,maji,majp,mini,} \\indented{7}{minp,mon,nonf,opt,ste,stao,stac,stoo,stoc,ve,istate,cjac,} \\indented{7}{clamda,r,x,ifail,confun,objfun)} is designed to minimize an arbitrary smooth function subject to constraints on the variables, linear constraints. (E04UCF may be used for unconstrained, bound-constrained and linearly constrained optimization.) The user must provide subroutines that define the objective and constraint functions and as many of their first partial derivatives as possible. Unspecified derivatives are approximated by finite differences. All matrices are treated as dense, and hence E04UCF is not intended for large sparse problems. See \\downlink{Manual Page}{manpageXXe04ucf}.")) (|e04naf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Boolean|) (|Boolean|) (|Boolean|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp20| QPHESS)))) "e04naf(itmax,msglvl,n,nclin,nctotl,nrowa,nrowh,ncolh,bigbnd,a,bl, bu,cvec,featol,hess,cold,lpp,orthog,liwork,lwork,x,istate,ifail,qphess) is a comprehensive programming (QP) or linear programming (LP) problems. It is not intended for large sparse problems. See \\downlink{Manual Page}{manpageXXe04naf}.")) (|e04mbf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Boolean|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "e04mbf(itmax,msglvl,n,nclin,nctotl,nrowa,a,bl,bu, \\indented{7}{cvec,linobj,liwork,lwork,x,ifail)} is an easy-to-use routine for solving linear programming problems, or for finding a feasible point for such problems. It is not intended for large sparse problems. See \\downlink{Manual Page}{manpageXXe04mbf}.")) (|e04jaf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp24| FUNCT1)))) "\\spad{e04jaf(n,ibound,liw,lw,bl,bu,x,ifail,funct1)} is an easy-to-use quasi-Newton algorithm for finding a minimum of a function \\spad{F(x} \\spad{,x} ,...,x \\spad{),} subject to fixed upper and \\indented{25}{1\\space{2}2\\space{6}n} lower bounds of the independent variables \\spad{x} \\spad{,x} ,...,x ,{} using \\indented{43}{1\\space{2}2\\space{6}n} function values only. See \\downlink{Manual Page}{manpageXXe04jaf}.")) (|e04gcf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp19| LSFUN2)))) "\\spad{e04gcf(m,n,liw,lw,x,ifail,lsfun2)} is an easy-to-use quasi-Newton algorithm for finding an unconstrained minimum of \\spad{m} nonlinear functions in \\spad{n} variables (m>=n). First derivatives are required. See \\downlink{Manual Page}{manpageXXe04gcf}.")) (|e04fdf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp50| LSFUN1)))) "\\spad{e04fdf(m,n,liw,lw,x,ifail,lsfun1)} is an easy-to-use algorithm for finding an unconstrained minimum of a sum of squares of \\spad{m} nonlinear functions in \\spad{n} variables (m>=n). No derivatives are required. See \\downlink{Manual Page}{manpageXXe04fdf}.")) (|e04dgf| (((|Result|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|DoubleFloat|) (|Boolean|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp49| OBJFUN)))) "\\spad{e04dgf(n,es,fu,it,lin,list,ma,op,pr,sta,sto,ve,x,ifail,objfun)} minimizes an unconstrained nonlinear function of several variables using a pre-conditioned, limited memory quasi-Newton conjugate gradient method. First derivatives are required. The routine is intended for use on large scale problems. See \\downlink{Manual Page}{manpageXXe04dgf}."))) 
 NIL 
 NIL 
-(-752) 
+(-773) 
 ((|constructor| (NIL "This package uses the NAG Library to provide facilities for matrix factorizations and associated transformations.")) (|f01ref| (((|Result|) (|String|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|Complex| (|DoubleFloat|))) (|Matrix| (|Complex| (|DoubleFloat|))) (|Integer|)) "\\spad{f01ref(wheret,m,n,ncolq,lda,theta,a,ifail)} returns the first \\spad{ncolq} columns of the complex \\spad{m} by \\spad{m} unitary matrix \\spad{Q,} where \\spad{Q} is given as the product of Householder transformation matrices. See \\downlink{Manual Page}{manpageXXf01ref}.")) (|f01rdf| (((|Result|) (|String|) (|String|) (|Integer|) (|Integer|) (|Matrix| (|Complex| (|DoubleFloat|))) (|Integer|) (|Matrix| (|Complex| (|DoubleFloat|))) (|Integer|) (|Integer|) (|Matrix| (|Complex| (|DoubleFloat|))) (|Integer|)) "\\spad{f01rdf(trans,wheret,m,n,a,lda,theta,ncolb,ldb,b,ifail)} performs one of the transformations See \\downlink{Manual Page}{manpageXXf01rdf}.")) (|f01rcf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|Complex| (|DoubleFloat|))) (|Integer|)) "\\spad{f01rcf(m,n,lda,a,ifail)} finds the \\spad{QR} factorization of the complex \\spad{m} by \\spad{n} matrix A, where m>=n. See \\downlink{Manual Page}{manpageXXf01rcf}.")) (|f01qef| (((|Result|) (|String|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f01qef(wheret,m,n,ncolq,lda,zeta,a,ifail)} returns the first \\spad{ncolq} columns of the real \\spad{m} by \\spad{m} orthogonal matrix \\spad{Q,} where \\spad{Q} is given as the product of Householder transformation matrices. See \\downlink{Manual Page}{manpageXXf01qef}.")) (|f01qdf| (((|Result|) (|String|) (|String|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f01qdf(trans,wheret,m,n,a,lda,zeta,ncolb,ldb,b,ifail)} performs one of the transformations See \\downlink{Manual Page}{manpageXXf01qdf}.")) (|f01qcf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f01qcf(m,n,lda,a,ifail)} finds the \\spad{QR} factorization of the real \\spad{m} by \\spad{n} matrix A, where m>=n. See \\downlink{Manual Page}{manpageXXf01qcf}.")) (|f01mcf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|Integer|)) (|Integer|)) "\\spad{f01mcf(n,avals,lal,nrow,ifail)} computes the Cholesky factorization of a real symmetric positive-definite variable-bandwidth matrix. See \\downlink{Manual Page}{manpageXXf01mcf}.")) (|f01maf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|List| (|Boolean|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Matrix| (|Integer|)) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{f01maf(n,nz,licn,lirn,abort,avals,irn,icn,droptl,densw,ifail)} computes an incomplete Cholesky factorization of a real sparse symmetric positive-definite matrix A. See \\downlink{Manual Page}{manpageXXf01maf}.")) (|f01bsf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|Integer|)) (|Matrix| (|Integer|)) (|Matrix| (|Integer|)) (|Matrix| (|Integer|)) (|Boolean|) (|DoubleFloat|) (|Boolean|) (|Matrix| (|Integer|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "f01bsf(n,nz,licn,ivect,jvect,icn,ikeep,grow, \\indented{7}{eta,abort,idisp,avals,ifail)} factorizes a real sparse matrix using the pivotal sequence previously obtained by F01BRF when a matrix of the same sparsity pattern was factorized. See \\downlink{Manual Page}{manpageXXf01bsf}.")) (|f01brf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Boolean|) (|Boolean|) (|List| (|Boolean|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Matrix| (|Integer|)) (|Integer|)) "\\spad{f01brf(n,nz,licn,lirn,pivot,lblock,grow,abort,a,irn,icn,ifail)} factorizes a real sparse matrix. The routine either forms the LU factorization of a permutation of the entire matrix, or, optionally, first permutes the matrix to block lower triangular form and then only factorizes the diagonal blocks. See \\downlink{Manual Page}{manpageXXf01brf}."))) 
 NIL 
 NIL 
-(-753) 
+(-774) 
 ((|constructor| (NIL "This package uses the NAG Library to compute\\br \\tab{5}eigenvalues and eigenvectors of a matrix\\br \\tab{5} eigenvalues and eigenvectors of generalized matrix eigenvalue problems\\br \\tab{5}singular values and singular vectors of a matrix.")) (|f02xef| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Boolean|) (|Integer|) (|Boolean|) (|Integer|) (|Matrix| (|Complex| (|DoubleFloat|))) (|Matrix| (|Complex| (|DoubleFloat|))) (|Integer|)) "\\spad{f02xef(m,n,lda,ncolb,ldb,wantq,ldq,wantp,ldph,a,b,ifail)} returns all, or part, of the singular value decomposition of a general complex matrix. See \\downlink{Manual Page}{manpageXXf02xef}.")) (|f02wef| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Boolean|) (|Integer|) (|Boolean|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02wef(m,n,lda,ncolb,ldb,wantq,ldq,wantp,ldpt,a,b,ifail)} returns all, or part, of the singular value decomposition of a general real matrix. See \\downlink{Manual Page}{manpageXXf02wef}.")) (|f02fjf| (((|Result|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp27| DOT))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp28| IMAGE))) (|FileName|)) "f02fjf(n,k,tol,novecs,nrx,lwork,lrwork, \\indented{7}{liwork,m,noits,x,ifail,dot,image,monit)} finds eigenvalues of a real sparse symmetric or generalized symmetric eigenvalue problem. See \\downlink{Manual Page}{manpageXXf02fjf}.") (((|Result|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp27| DOT))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp28| IMAGE)))) "f02fjf(n,k,tol,novecs,nrx,lwork,lrwork, \\indented{7}{liwork,m,noits,x,ifail,dot,image)} finds eigenvalues of a real sparse symmetric or generalized symmetric eigenvalue problem. See \\downlink{Manual Page}{manpageXXf02fjf}.")) (|f02bjf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Boolean|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02bjf(n,ia,ib,eps1,matv,iv,a,b,ifail)} calculates all the eigenvalues and, if required, all the eigenvectors of the generalized eigenproblem Ax=(lambda)Bx where A and \\spad{B} are real, square matrices, using the \\spad{QZ} algorithm. See \\downlink{Manual Page}{manpageXXf02bjf}.")) (|f02bbf| (((|Result|) (|Integer|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02bbf(ia,n,alb,ub,m,iv,a,ifail)} calculates selected eigenvalues of a real symmetric matrix by reduction to tridiagonal form, bisection and inverse iteration, where the selected eigenvalues lie within a given interval. See \\downlink{Manual Page}{manpageXXf02bbf}.")) (|f02axf| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{f02axf(ar,iar,ai,iai,n,ivr,ivi,ifail)} calculates all the eigenvalues of a complex Hermitian matrix. See \\downlink{Manual Page}{manpageXXf02axf}.")) (|f02awf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02awf(iar,iai,n,ar,ai,ifail)} calculates all the eigenvalues of a complex Hermitian matrix. See \\downlink{Manual Page}{manpageXXf02awf}.")) (|f02akf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02akf(iar,iai,n,ivr,ivi,ar,ai,ifail)} calculates all the eigenvalues of a complex matrix. See \\downlink{Manual Page}{manpageXXf02akf}.")) (|f02ajf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02ajf(iar,iai,n,ar,ai,ifail)} calculates all the eigenvalue. See \\downlink{Manual Page}{manpageXXf02ajf}.")) (|f02agf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02agf(ia,n,ivr,ivi,a,ifail)} calculates all the eigenvalues of a real unsymmetric matrix. See \\downlink{Manual Page}{manpageXXf02agf}.")) (|f02aff| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02aff(ia,n,a,ifail)} calculates all the eigenvalues of a real unsymmetric matrix. See \\downlink{Manual Page}{manpageXXf02aff}.")) (|f02aef| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02aef(ia,ib,n,iv,a,b,ifail)} calculates all the eigenvalues of Ax=(lambda)Bx, where A is a real symmetric matrix and \\spad{B} is a real symmetric positive-definite matrix. See \\downlink{Manual Page}{manpageXXf02aef}.")) (|f02adf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02adf(ia,ib,n,a,b,ifail)} calculates all the eigenvalues of Ax=(lambda)Bx, where A is a real symmetric matrix and \\spad{B} is a real symmetric positive- definite matrix. See \\downlink{Manual Page}{manpageXXf02adf}.")) (|f02abf| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{f02abf(a,ia,n,iv,ifail)} calculates all the eigenvalues of a real symmetric matrix. See \\downlink{Manual Page}{manpageXXf02abf}.")) (|f02aaf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f02aaf(ia,n,a,ifail)} calculates all the eigenvalue. See \\downlink{Manual Page}{manpageXXf02aaf}."))) 
 NIL 
 NIL 
-(-754) 
+(-775) 
 ((|constructor| (NIL "This package uses the NAG Library to solve the matrix equation \\spad{\\br} \\tab{5}\\axiom{AX=B}, where \\axiom{B}\\br may be a single vector or a matrix of multiple right-hand sides. The matrix \\axiom{A} may be real, complex, symmetric, Hermitian positive- definite, or sparse. It may also be rectangular, in which case a least-squares solution is obtained.")) (|f04qaf| (((|Result|) (|Integer|) (|Integer|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp30| APROD)))) "f04qaf(m,n,damp,atol,btol,conlim,itnlim,msglvl, \\indented{7}{lrwork,liwork,b,ifail,aprod)} solves sparse unsymmetric equations, sparse linear least- squares problems and sparse damped linear least-squares problems, using a Lanczos algorithm. See \\downlink{Manual Page}{manpageXXf04qaf}.")) (|f04mcf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{f04mcf(n,al,lal,d,nrow,ir,b,nrb,iselct,nrx,ifail)} computes the approximate solution of a system of real linear equations with multiple right-hand sides, AX=B, where A is a symmetric positive-definite variable-bandwidth matrix, which has previously been factorized by F01MCF. Related systems may also be solved. See \\downlink{Manual Page}{manpageXXf04mcf}.")) (|f04mbf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Boolean|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp28| APROD))) (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp34| MSOLVE)))) "\\spad{f04mbf(n,b,precon,shift,itnlim,msglvl,lrwork, \\spad{++} liwork,rtol,ifail,aprod,msolve)} solves a system of real sparse symmetric linear equations using a Lanczos algorithm. See \\downlink{Manual Page}{manpageXXf04mbf}.")) (|f04maf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|Integer|)) (|Integer|) (|Matrix| (|Integer|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Matrix| (|Integer|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|Integer|)) (|Integer|)) "f04maf(n,nz,avals,licn,irn,lirn,icn,wkeep,ikeep, \\indented{7}{inform,b,acc,noits,ifail)} \\spad{e} a sparse symmetric positive-definite system of linear equations, Ax=b, using a pre-conditioned conjugate gradient method, where A has been factorized by F01MAF. See \\downlink{Manual Page}{manpageXXf04maf}.")) (|f04jgf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|DoubleFloat|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f04jgf(m,n,nra,tol,lwork,a,b,ifail)} finds the solution of a linear least-squares problem, Ax=b ,{} where A is a real \\spad{m} by \\spad{n} (m>=n) matrix and \\spad{b} is an \\spad{m} element vector. If the matrix of observations is not of full rank, then the minimal least-squares solution is returned. See \\downlink{Manual Page}{manpageXXf04jgf}.")) (|f04faf| (((|Result|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f04faf(job,n,d,e,b,ifail)} calculates the approximate solution of a set of real symmetric positive-definite tridiagonal linear equations. See \\downlink{Manual Page}{manpageXXf04faf}.")) (|f04axf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|Integer|)) (|Matrix| (|Integer|)) (|Integer|) (|Matrix| (|Integer|)) (|Matrix| (|DoubleFloat|))) "\\spad{f04axf(n,a,licn,icn,ikeep,mtype,idisp,rhs)} calculates the approximate solution of a set of real sparse linear equations with a single right-hand side, Ax=b or \\indented{1}{T} A x=b, where A has been factorized by F01BRF or F01BSF. See \\downlink{Manual Page}{manpageXXf04axf}.")) (|f04atf| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{f04atf(a,ia,b,n,iaa,ifail)} calculates the accurate solution of a set of real linear equations with a single right-hand side, using an LU factorization with partial pivoting, and iterative refinement. See \\downlink{Manual Page}{manpageXXf04atf}.")) (|f04asf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f04asf(ia,b,n,a,ifail)} calculates the accurate solution of a set of real symmetric positive-definite linear equations with a single right- hand side, Ax=b, using a Cholesky factorization and iterative refinement. See \\downlink{Manual Page}{manpageXXf04asf}.")) (|f04arf| (((|Result|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|)) "\\spad{f04arf(ia,b,n,a,ifail)} calculates the approximate solution of a set of real linear equations with a single right-hand side, using an LU factorization with partial pivoting. See \\downlink{Manual Page}{manpageXXf04arf}.")) (|f04adf| (((|Result|) (|Integer|) (|Matrix| (|Complex| (|DoubleFloat|))) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|Complex| (|DoubleFloat|))) (|Integer|)) "\\spad{f04adf(ia,b,ib,n,m,ic,a,ifail)} calculates the approximate solution of a set of complex linear equations with multiple right-hand sides, using an LU factorization with partial pivoting. See \\downlink{Manual Page}{manpageXXf04adf}."))) 
 NIL 
 NIL 
-(-755) 
+(-776) 
 ((|constructor| (NIL "This package uses the NAG Library to compute matrix factorizations, and to solve systems of linear equations following the matrix factorizations.")) (|f07fef| (((|Result|) (|String|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|))) "\\spad{f07fef(uplo,n,nrhs,a,lda,ldb,b)} (DPOTRS) solves a real symmetric positive-definite system of linear equations with multiple right-hand sides, AX=B, where A has been factorized by F07FDF (DPOTRF). See \\downlink{Manual Page}{manpageXXf07fef}.")) (|f07fdf| (((|Result|) (|String|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|))) "\\spad{f07fdf(uplo,n,lda,a)} (DPOTRF) computes the Cholesky factorization of a real symmetric positive-definite matrix. See \\downlink{Manual Page}{manpageXXf07fdf}.")) (|f07aef| (((|Result|) (|String|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Matrix| (|Integer|)) (|Integer|) (|Matrix| (|DoubleFloat|))) "\\spad{f07aef(trans,n,nrhs,a,lda,ipiv,ldb,b)} (DGETRS) solves a real system of linear equations with \\indented{36}{T} multiple right-hand sides, AX=B or A X=B, where A has been factorized by F07ADF (DGETRF). See \\downlink{Manual Page}{manpageXXf07aef}.")) (|f07adf| (((|Result|) (|Integer|) (|Integer|) (|Integer|) (|Matrix| (|DoubleFloat|))) "\\spad{f07adf(m,n,lda,a)} (DGETRF) computes the LU factorization of a real \\spad{m} by \\spad{n} matrix. See \\downlink{Manual Page}{manpageXXf07adf}."))) 
 NIL 
 NIL 
-(-756) 
+(-777) 
 ((|constructor| (NIL "This package uses the NAG Library to compute some commonly occurring physical and mathematical functions.")) (|s21bdf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{s21bdf(x,y,z,r,ifail)} returns a value of the symmetrised elliptic integral of the third kind, via the routine name. See \\downlink{Manual Page}{manpageXXs21bdf}.")) (|s21bcf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{s21bcf(x,y,z,ifail)} returns a value of the symmetrised elliptic integral of the second kind, via the routine name. See \\downlink{Manual Page}{manpageXXs21bcf}.")) (|s21bbf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{s21bbf(x,y,z,ifail)} returns a value of the symmetrised elliptic integral of the first kind, via the routine name. See \\downlink{Manual Page}{manpageXXs21bbf}.")) (|s21baf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{s21baf(x,y,ifail)} returns a value of an elementary integral, which occurs as a degenerate case of an elliptic integral of the first kind, via the routine name. See \\downlink{Manual Page}{manpageXXs21baf}.")) (|s20adf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s20adf(x,ifail)} returns a value for the Fresnel Integral C(x), via the routine name. See \\downlink{Manual Page}{manpageXXs20adf}.")) (|s20acf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s20acf(x,ifail)} returns a value for the Fresnel Integral S(x), via the routine name. See \\downlink{Manual Page}{manpageXXs20acf}.")) (|s19adf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s19adf(x,ifail)} returns a value for the Kelvin function kei(x) via the routine name. See \\downlink{Manual Page}{manpageXXs19adf}.")) (|s19acf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s19acf(x,ifail)} returns a value for the Kelvin function ker(x), via the routine name. See \\downlink{Manual Page}{manpageXXs19acf}.")) (|s19abf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s19abf(x,ifail)} returns a value for the Kelvin function bei(x) via the routine name. See \\downlink{Manual Page}{manpageXXs19abf}.")) (|s19aaf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s19aaf(x,ifail)} returns a value for the Kelvin function ber(x) via the routine name. See \\downlink{Manual Page}{manpageXXs19aaf}.")) (|s18def| (((|Result|) (|DoubleFloat|) (|Complex| (|DoubleFloat|)) (|Integer|) (|String|) (|Integer|)) "\\spad{s18def(fnu,z,n,scale,ifail)} returns a sequence of values for the modified Bessel functions \\indented{1}{I\\space{6}(z) for complex \\spad{z,} non-negative (nu) and} \\indented{2}{(nu)+n} n=0,1,...,N-1, with an option for exponential scaling. See \\downlink{Manual Page}{manpageXXs18def}.")) (|s18dcf| (((|Result|) (|DoubleFloat|) (|Complex| (|DoubleFloat|)) (|Integer|) (|String|) (|Integer|)) "\\spad{s18dcf(fnu,z,n,scale,ifail)} returns a sequence of values for the modified Bessel functions \\indented{1}{K\\space{6}(z) for complex \\spad{z,} non-negative (nu) and} \\indented{2}{(nu)+n} n=0,1,...,N-1, with an option for exponential scaling. See \\downlink{Manual Page}{manpageXXs18dcf}.")) (|s18aff| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s18aff(x,ifail)} returns a value for the modified Bessel Function \\indented{1}{I (x), via the routine name.} \\indented{2}{1} See \\downlink{Manual Page}{manpageXXs18aff}.")) (|s18aef| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s18aef(x,ifail)} returns the value of the modified Bessel Function \\indented{1}{I (x), via the routine name.} \\indented{2}{0} See \\downlink{Manual Page}{manpageXXs18aef}.")) (|s18adf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s18adf(x,ifail)} returns the value of the modified Bessel Function \\indented{1}{K (x), via the routine name.} \\indented{2}{1} See \\downlink{Manual Page}{manpageXXs18adf}.")) (|s18acf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s18acf(x,ifail)} returns the value of the modified Bessel Function \\indented{1}{K (x), via the routine name.} \\indented{2}{0} See \\downlink{Manual Page}{manpageXXs18acf}.")) (|s17dlf| (((|Result|) (|Integer|) (|DoubleFloat|) (|Complex| (|DoubleFloat|)) (|Integer|) (|String|) (|Integer|)) "\\spad{s17dlf(m,fnu,z,n,scale,ifail)} returns a sequence of values for the Hankel functions \\indented{2}{(1)\\space{11}(2)} \\indented{1}{H\\space{6}(z) or H\\space{6}(z) for complex \\spad{z,} non-negative (nu) and} \\indented{2}{(nu)+n\\space{8}(nu)+n} n=0,1,...,N-1, with an option for exponential scaling. See \\downlink{Manual Page}{manpageXXs17dlf}.")) (|s17dhf| (((|Result|) (|String|) (|Complex| (|DoubleFloat|)) (|String|) (|Integer|)) "\\spad{s17dhf(deriv,z,scale,ifail)} returns the value of the Airy function Bi(z) or its derivative Bi'(z) for complex \\spad{z,} with an option for exponential scaling. See \\downlink{Manual Page}{manpageXXs17dhf}.")) (|s17dgf| (((|Result|) (|String|) (|Complex| (|DoubleFloat|)) (|String|) (|Integer|)) "\\spad{s17dgf(deriv,z,scale,ifail)} returns the value of the Airy function Ai(z) or its derivative Ai'(z) for complex \\spad{z,} with an option for exponential scaling. See \\downlink{Manual Page}{manpageXXs17dgf}.")) (|s17def| (((|Result|) (|DoubleFloat|) (|Complex| (|DoubleFloat|)) (|Integer|) (|String|) (|Integer|)) "\\spad{s17def(fnu,z,n,scale,ifail)} returns a sequence of values for the Bessel functions \\indented{1}{J\\space{6}(z) for complex \\spad{z,} non-negative (nu) and n=0,1,...,N-1,} \\indented{2}{(nu)+n} with an option for exponential scaling. See \\downlink{Manual Page}{manpageXXs17def}.")) (|s17dcf| (((|Result|) (|DoubleFloat|) (|Complex| (|DoubleFloat|)) (|Integer|) (|String|) (|Integer|)) "\\spad{s17dcf(fnu,z,n,scale,ifail)} returns a sequence of values for the Bessel functions \\indented{1}{Y\\space{6}(z) for complex \\spad{z,} non-negative (nu) and n=0,1,...,N-1,} \\indented{2}{(nu)+n} with an option for exponential scaling. See \\downlink{Manual Page}{manpageXXs17dcf}.")) (|s17akf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s17akf(x,ifail)} returns a value for the derivative of the Airy function Bi(x), via the routine name. See \\downlink{Manual Page}{manpageXXs17akf}.")) (|s17ajf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s17ajf(x,ifail)} returns a value of the derivative of the Airy function Ai(x), via the routine name. See \\downlink{Manual Page}{manpageXXs17ajf}.")) (|s17ahf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s17ahf(x,ifail)} returns a value of the Airy function, Bi(x), via the routine name. See \\downlink{Manual Page}{manpageXXs17ahf}.")) (|s17agf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s17agf(x,ifail)} returns a value for the Airy function, Ai(x), via the routine name. See \\downlink{Manual Page}{manpageXXs17agf}.")) (|s17aff| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s17aff(x,ifail)} returns the value of the Bessel Function \\indented{1}{J (x), via the routine name.} \\indented{2}{1} See \\downlink{Manual Page}{manpageXXs17aff}.")) (|s17aef| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s17aef(x,ifail)} returns the value of the Bessel Function \\indented{1}{J (x), via the routine name.} \\indented{2}{0} See \\downlink{Manual Page}{manpageXXs17aef}.")) (|s17adf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s17adf(x,ifail)} returns the value of the Bessel Function \\indented{1}{Y (x), via the routine name.} \\indented{2}{1} See \\downlink{Manual Page}{manpageXXs17adf}.")) (|s17acf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s17acf(x,ifail)} returns the value of the Bessel Function \\indented{1}{Y (x), via the routine name.} \\indented{2}{0} See \\downlink{Manual Page}{manpageXXs17acf}.")) (|s15aef| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s15aef(x,ifail)} returns the value of the error function erf(x), via the routine name. See \\downlink{Manual Page}{manpageXXs15aef}.")) (|s15adf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s15adf(x,ifail)} returns the value of the complementary error function, erfc(x), via the routine name. See \\downlink{Manual Page}{manpageXXs15adf}.")) (|s14baf| (((|Result|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|)) "\\spad{s14baf(a,x,tol,ifail)} computes values for the incomplete gamma functions P(a,x) and Q(a,x). See \\downlink{Manual Page}{manpageXXs14baf}.")) (|s14abf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s14abf(x,ifail)} returns a value for the log, ln(Gamma(x)), via the routine name. See \\downlink{Manual Page}{manpageXXs14abf}.")) (|s14aaf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s14aaf(x,ifail)} returns the value of the Gamma function (Gamma)(x), via the routine name. See \\downlink{Manual Page}{manpageXXs14aaf}.")) (|s13adf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s13adf(x,ifail)} returns the value of the sine integral See \\downlink{Manual Page}{manpageXXs13adf}.")) (|s13acf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s13acf(x,ifail)} returns the value of the cosine integral See \\downlink{Manual Page}{manpageXXs13acf}.")) (|s13aaf| (((|Result|) (|DoubleFloat|) (|Integer|)) "\\spad{s13aaf(x,ifail)} returns the value of the exponential integral \\indented{1}{E (x), via the routine name.} \\indented{2}{1} See \\downlink{Manual Page}{manpageXXs13aaf}.")) (|s01eaf| (((|Result|) (|Complex| (|DoubleFloat|)) (|Integer|)) "\\spad{s01eaf(z,ifail)} S01EAF evaluates the exponential function exp(z) ,{} for complex \\spad{z.} See \\downlink{Manual Page}{manpageXXs01eaf}."))) 
 NIL 
 NIL 
-(-757) 
+(-778) 
 ((|constructor| (NIL "Support functions for the NAG Library Link functions")) (|restorePrecision| (((|Void|)) "\\spad{restorePrecision()} \\undocumented{}")) (|checkPrecision| (((|Boolean|)) "\\spad{checkPrecision()} \\undocumented{}")) (|dimensionsOf| (((|SExpression|) (|Symbol|) (|Matrix| (|Integer|))) "\\spad{dimensionsOf(s,m)} \\undocumented{}") (((|SExpression|) (|Symbol|) (|Matrix| (|DoubleFloat|))) "\\spad{dimensionsOf(s,m)} \\undocumented{}")) (|aspFilename| (((|String|) (|String|)) "\\spad{aspFilename(\"f\")} returns a String consisting of \\spad{\"f\"} suffixed with \\indented{1}{an extension identifying the current AXIOM session.}")) (|fortranLinkerArgs| (((|String|)) "\\spad{fortranLinkerArgs()} returns the current linker arguments")) (|fortranCompilerName| (((|String|)) "\\spad{fortranCompilerName()} returns the name of the currently selected \\indented{1}{Fortran compiler}"))) 
 NIL 
 NIL 
-(-758 S) 
+(-779 S) 
 ((|constructor| (NIL "NonAssociativeRng is a basic ring-type structure, not necessarily commutative or associative, and not necessarily with unit.\\br Axioms\\br \\tab{5}x*(y+z) = x*y + x*z\\br \\tab{5}(x+y)*z = \\spad{x*z} + y*z\\br \\blankline Common Additional Axioms\\br \\tab{5}noZeroDivisors\\tab{5} ab = 0 \\spad{=>} \\spad{a=0} or \\spad{b=0}")) (|antiCommutator| (($ $ $) "\\spad{antiCommutator(a,b)} returns \\spad{a*b+b*a}.")) (|commutator| (($ $ $) "\\spad{commutator(a,b)} returns \\spad{a*b-b*a}.")) (|associator| (($ $ $ $) "\\spad{associator(a,b,c)} returns \\spad{(a*b)*c-a*(b*c)}."))) 
 NIL 
 NIL 
-(-759) 
+(-780) 
 ((|constructor| (NIL "NonAssociativeRng is a basic ring-type structure, not necessarily commutative or associative, and not necessarily with unit.\\br Axioms\\br \\tab{5}x*(y+z) = x*y + x*z\\br \\tab{5}(x+y)*z = \\spad{x*z} + y*z\\br \\blankline Common Additional Axioms\\br \\tab{5}noZeroDivisors\\tab{5} ab = 0 \\spad{=>} \\spad{a=0} or \\spad{b=0}")) (|antiCommutator| (($ $ $) "\\spad{antiCommutator(a,b)} returns \\spad{a*b+b*a}.")) (|commutator| (($ $ $) "\\spad{commutator(a,b)} returns \\spad{a*b-b*a}.")) (|associator| (($ $ $ $) "\\spad{associator(a,b,c)} returns \\spad{(a*b)*c-a*(b*c)}."))) 
 NIL 
 NIL 
-(-760 S) 
+(-781 S) 
 ((|constructor| (NIL "A NonAssociativeRing is a non associative \\spad{rng} which has a unit, the multiplication is not necessarily commutative or associative.")) (|coerce| (($ (|Integer|)) "\\spad{coerce(n)} coerces the integer \\spad{n} to an element of the ring.")) (|characteristic| (((|NonNegativeInteger|)) "\\spad{characteristic()} returns the characteristic of the ring."))) 
 NIL 
 NIL 
-(-761) 
+(-782) 
 ((|constructor| (NIL "A NonAssociativeRing is a non associative \\spad{rng} which has a unit, the multiplication is not necessarily commutative or associative.")) (|coerce| (($ (|Integer|)) "\\spad{coerce(n)} coerces the integer \\spad{n} to an element of the ring.")) (|characteristic| (((|NonNegativeInteger|)) "\\spad{characteristic()} returns the characteristic of the ring."))) 
 NIL 
 NIL 
-(-762 |Par|) 
+(-783 |Par|) 
 ((|constructor| (NIL "This package computes explicitly eigenvalues and eigenvectors of matrices with entries over the complex rational numbers. The results are expressed either as complex floating numbers or as complex rational numbers depending on the type of the precision parameter.")) (|complexEigenvectors| (((|List| (|Record| (|:| |outval| (|Complex| |#1|)) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| (|Complex| |#1|)))))) (|Matrix| (|Complex| (|Fraction| (|Integer|)))) |#1|) "\\spad{complexEigenvectors(m,eps)} returns a list of records each one containing a complex eigenvalue, its algebraic multiplicity, and a list of associated eigenvectors. All these results are computed to precision \\spad{eps} and are expressed as complex floats or complex rational numbers depending on the type of \\spad{eps} (float or rational).")) (|complexEigenvalues| (((|List| (|Complex| |#1|)) (|Matrix| (|Complex| (|Fraction| (|Integer|)))) |#1|) "\\spad{complexEigenvalues(m,eps)} computes the eigenvalues of the matrix \\spad{m} to precision eps. The eigenvalues are expressed as complex floats or complex rational numbers depending on the type of \\spad{eps} (float or rational).")) (|characteristicPolynomial| (((|Polynomial| (|Complex| (|Fraction| (|Integer|)))) (|Matrix| (|Complex| (|Fraction| (|Integer|)))) (|Symbol|)) "\\spad{characteristicPolynomial(m,x)} returns the characteristic polynomial of the matrix \\spad{m} expressed as polynomial over Complex Rationals with variable \\spad{x.}") (((|Polynomial| (|Complex| (|Fraction| (|Integer|)))) (|Matrix| (|Complex| (|Fraction| (|Integer|))))) "\\spad{characteristicPolynomial(m)} returns the characteristic polynomial of the matrix \\spad{m} expressed as polynomial over complex rationals with a new symbol as variable."))) 
 NIL 
 NIL 
-(-763 -3313) 
+(-784 -3958) 
 ((|constructor| (NIL "\\spadtype{NumericContinuedFraction} provides functions for converting floating point numbers to continued fractions.")) (|continuedFraction| (((|ContinuedFraction| (|Integer|)) |#1|) "\\spad{continuedFraction(f)} converts the floating point number \\spad{f} to a reduced continued fraction."))) 
 NIL 
 NIL 
-(-764 P -3313) 
+(-785 P -3958) 
 ((|constructor| (NIL "This package provides a division and related operations for \\spadtype{MonogenicLinearOperator}s over a \\spadtype{Field}. Since the multiplication is in general non-commutative, these operations all have left- and right-hand versions. This package provides the operations based on left-division.\\br \\tab{5}[q,r] = leftDivide(a,b) means a=b*q+r")) (|leftLcm| ((|#1| |#1| |#1|) "\\spad{leftLcm(a,b)} computes the value \\spad{m} of lowest degree such that \\spad{m = a*aa = b*bb} for some values \\spad{aa} and \\spad{bb}. The value \\spad{m} is computed using left-division.")) (|leftGcd| ((|#1| |#1| |#1|) "\\spad{leftGcd(a,b)} computes the value \\spad{g} of highest degree such that \\indented{3}{\\spad{a = aa*g}} \\indented{3}{\\spad{b = bb*g}} for some values \\spad{aa} and \\spad{bb}. The value \\spad{g} is computed using left-division.")) (|leftExactQuotient| (((|Union| |#1| "failed") |#1| |#1|) "\\spad{leftExactQuotient(a,b)} computes the value \\spad{q}, if it exists, \\indented{1}{such that \\spad{a = b*q}.}")) (|leftRemainder| ((|#1| |#1| |#1|) "\\spad{leftRemainder(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{r} is returned.")) (|leftQuotient| ((|#1| |#1| |#1|) "\\spad{leftQuotient(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{q} is returned.")) (|leftDivide| (((|Record| (|:| |quotient| |#1|) (|:| |remainder| |#1|)) |#1| |#1|) "\\spad{leftDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``left division''."))) 
 NIL 
 NIL 
-(-765 -3313) 
+(-786 -3958) 
 ((|constructor| (NIL "This package exports Newton interpolation for the special case where the result is known to be in the original integral domain The packages defined in this file provide fast fraction free rational interpolation algorithms. (see FAMR2, FFFG, FFFGF, NEWTON)")) (|newton| (((|SparseUnivariatePolynomial| |#1|) (|List| |#1|)) "\\spad{newton}(l) returns the interpolating polynomial for the values \\spad{l,} where the x-coordinates are assumed to be [1,2,3,...,n] and the coefficients of the interpolating polynomial are known to be in the domain \\spad{F.} I.e., it is a very streamlined version for a special case of interpolation."))) 
 NIL 
 NIL 
-(-766 UP -3313) 
+(-787 UP -3958) 
 ((|constructor| (NIL "In this package \\spad{F} is a framed algebra over the integers (typically \\spad{F = Z[a]} for some algebraic integer a). The package provides functions to compute the integral closure of \\spad{Z} in the quotient quotient field of \\spad{F.}")) (|localIntegralBasis| (((|Record| (|:| |basis| (|Matrix| (|Integer|))) (|:| |basisDen| (|Integer|)) (|:| |basisInv| (|Matrix| (|Integer|)))) (|Integer|)) "\\spad{integralBasis(p)} returns a record \\spad{[basis,basisDen,basisInv]} containing information regarding the local integral closure of \\spad{Z} at the prime \\spad{p} in the quotient field of \\spad{F,} where \\spad{F} is a framed algebra with Z-module basis \\spad{w1,w2,...,wn}. If \\spad{basis} is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then the \\spad{i}th element of the integral basis is \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of \\spad{basis} contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if \\spad{basisInv} is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}.")) (|integralBasis| (((|Record| (|:| |basis| (|Matrix| (|Integer|))) (|:| |basisDen| (|Integer|)) (|:| |basisInv| (|Matrix| (|Integer|))))) "\\spad{integralBasis()} returns a record \\spad{[basis,basisDen,basisInv]} containing information regarding the integral closure of \\spad{Z} in the quotient field of \\spad{F,} where \\spad{F} is a framed algebra with Z-module basis \\spad{w1,w2,...,wn}. If \\spad{basis} is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then the \\spad{i}th element of the integral basis is \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of \\spad{basis} contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if \\spad{basisInv} is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}.")) (|discriminant| (((|Integer|)) "\\spad{discriminant()} returns the discriminant of the integral closure of \\spad{Z} in the quotient field of the framed algebra \\spad{F.}"))) 
 NIL 
 NIL 
-(-767) 
+(-788) 
 ((|constructor| (NIL "\\axiomType{NumericalIntegrationProblem} is a \\axiom{domain} for the representation of Numerical Integration problems for use by ANNA. \\blankline The representation is a Union of two record types - one for integration of a function of one variable: \\blankline \\axiomType{Record}(var:\\axiomType{Symbol},\\br fn:\\axiomType{Expression DoubleFloat},\\br range:\\axiomType{Segment OrderedCompletion DoubleFloat},\\br abserr:\\axiomType{DoubleFloat},\\br relerr:\\axiomType{DoubleFloat},) \\blankline and one for multivariate integration: \\blankline \\axiomType{Record}(fn:\\axiomType{Expression DoubleFloat},\\br range:\\axiomType{List Segment OrderedCompletion DoubleFloat},\\br abserr:\\axiomType{DoubleFloat},\\br relerr:\\axiomType{DoubleFloat},). \\blankline")) (|retract| (((|Union| (|:| |nia| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |mdnia| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))))) $) "\\spad{retract(x)} is not documented")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(x)} is not documented") (($ (|Union| (|:| |nia| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |mdnia| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))))) "\\spad{coerce(x)} is not documented") (($ (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{coerce(x)} is not documented") (($ (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{coerce(x)} is not documented"))) 
 NIL 
 NIL 
-(-768 R) 
+(-789 R) 
 ((|constructor| (NIL "NonLinearSolvePackage is an interface to \\spadtype{SystemSolvePackage} that attempts to retract the coefficients of the equations before solving. The solutions are given in the algebraic closure of \\spad{R} whenever possible.")) (|solve| (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|))) "\\spad{solve(lp)} finds the solution in the algebraic closure of \\spad{R} of the list \\spad{lp} of rational functions with respect to all the symbols appearing in \\spad{lp.}") (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|))) "\\spad{solve(lp,lv)} finds the solutions in the algebraic closure of \\spad{R} of the list \\spad{lp} of rational functions with respect to the list of symbols \\spad{lv.}")) (|solveInField| (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|))) "\\spad{solveInField(lp)} finds the solution of the list \\spad{lp} of rational functions with respect to all the symbols appearing in \\spad{lp.}") (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|))) "\\spad{solveInField(lp,lv)} finds the solutions of the list \\spad{lp} of rational functions with respect to the list of symbols \\spad{lv.}"))) 
 NIL 
 NIL 
-(-769) 
+(-790) 
 ((|constructor| (NIL "\\spadtype{NonNegativeInteger} provides functions for non-negative integers.")) (|commutative| ((|attribute| "*") "\\spad{commutative(\"*\")} means multiplication is commutative, that is, \\spad{x*y = y*x}.")) (|random| (($ $) "\\spad{random(n)} returns a random integer from 0 to \\spad{n-1}.")) (|shift| (($ $ (|Integer|)) "\\spad{shift(a,i)} shift \\spad{a} by \\spad{i} bits.")) (|exquo| (((|Union| $ "failed") $ $) "\\spad{exquo(a,b)} returns the quotient of \\spad{a} and \\spad{b,} or \"failed\" if \\spad{b} is zero or \\spad{a} rem \\spad{b} is zero.")) (|divide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{divide(a,b)} returns a record containing both remainder and quotient.")) (|gcd| (($ $ $) "\\spad{gcd(a,b)} computes the greatest common divisor of two non negative integers \\spad{a} and \\spad{b.}")) (|rem| (($ $ $) "\\spad{a rem \\spad{b}} returns the remainder of \\spad{a} and \\spad{b.}")) (|quo| (($ $ $) "\\spad{a quo \\spad{b}} returns the quotient of \\spad{a} and \\spad{b,} forgetting the remainder."))) 
-(((-4604 "*") . T)) 
+(((-4627 "*") . T)) 
 NIL 
-(-770 R -3313) 
+(-791 R -3958) 
 ((|constructor| (NIL "NonLinearFirstOrderODESolver provides a function for finding closed form first integrals of nonlinear ordinary differential equations of order 1.")) (|solve| (((|Union| |#2| "failed") |#2| |#2| (|BasicOperator|) (|Symbol|)) "\\spad{solve(M(x,y), N(x,y), \\spad{y,} \\spad{x)}} returns \\spad{F(x,y)} such that \\spad{F(x,y) = \\spad{c}} for a constant \\spad{c} is a first integral of the equation \\spad{M(x,y) \\spad{dx} + N(x,y) dy = 0}, or \"failed\" if no first-integral can be found."))) 
 NIL 
 NIL 
-(-771 S) 
+(-792 S) 
 ((|constructor| (NIL "\\spadtype{NoneFunctions1} implements functions on \\spadtype{None}. It particular it includes a particulary dangerous coercion from any other type to \\spadtype{None}.")) (|coerce| (((|None|) |#1|) "\\spad{coerce(x)} changes \\spad{x} into an object of type \\spadtype{None}."))) 
 NIL 
 NIL 
-(-772) 
+(-793) 
 ((|constructor| (NIL "\\spadtype{None} implements a type with no objects. It is mainly used in technical situations where such a thing is needed (\\spadignore{e.g.} the interpreter and some of the internal \\spadtype{Expression} code)."))) 
 NIL 
 NIL 
-(-773 R |PolR| E |PolE|) 
+(-794 R |PolR| E |PolE|) 
 ((|constructor| (NIL "This package implements the norm of a polynomial with coefficients in a monogenic algebra (using resultants)")) (|norm| ((|#2| |#4|) "\\spad{norm \\spad{q}} returns the norm of \\spad{q,} \\spadignore{i.e.} the product of all the conjugates of \\spad{q.}"))) 
 NIL 
 NIL 
-(-774 R E V P TS) 
+(-795 R E V P TS) 
 ((|constructor| (NIL "A package for computing normalized assocites of univariate polynomials with coefficients in a tower of simple extensions of a field.")) (|normInvertible?| (((|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| |#5|))) |#4| |#5|) "\\axiom{normInvertible?(p,ts)} is an internal subroutine, exported only for developement.")) (|outputArgs| (((|Void|) (|String|) (|String|) |#4| |#5|) "\\axiom{outputArgs(s1,s2,p,ts)} is an internal subroutine, exported only for developement.")) (|normalize| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#5|) "\\axiom{normalize(p,ts)} normalizes \\axiom{p} w.r.t \\spad{ts}.")) (|normalizedAssociate| ((|#4| |#4| |#5|) "\\axiom{normalizedAssociate(p,ts)} returns a normalized polynomial \\axiom{n} w.r.t. \\spad{ts} such that \\axiom{n} and \\axiom{p} are associates w.r.t \\spad{ts} and assuming that \\axiom{p} is invertible w.r.t \\spad{ts}.")) (|recip| (((|Record| (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|) "\\axiom{recip(p,ts)} returns the inverse of \\axiom{p} w.r.t \\spad{ts} assuming that \\axiom{p} is invertible w.r.t \\spad{ts}."))) 
 NIL 
 NIL 
-(-775 -3313 |ExtF| |SUEx| |ExtP| |n|) 
+(-796 -3958 |ExtF| |SUEx| |ExtP| |n|) 
 ((|constructor| (NIL "This package has no description")) (|Frobenius| ((|#4| |#4|) "\\spad{Frobenius(x)} \\undocumented")) (|retractIfCan| (((|Union| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#1|)) "failed") |#4|) "\\spad{retractIfCan(x)} \\undocumented")) (|normFactors| (((|List| |#4|) |#4|) "\\spad{normFactors(x)} \\undocumented"))) 
 NIL 
 NIL 
-(-776 -3313) 
+(-797 -3958) 
 ((|constructor| (NIL "This is an implmenentation of the Nottingham Group"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-777 BP E OV R P) 
+(-798 BP E OV R P) 
 ((|constructor| (NIL "Package for the determination of the coefficients in the lifting process. Used by \\spadtype{MultivariateLifting}. This package will work for every euclidean domain \\spad{R} which has property \\spad{F,} \\spadignore{i.e.} there exists a factor operation in \\spad{R[x]}.")) (|listexp| (((|List| (|NonNegativeInteger|)) |#1|) "\\spad{listexp }\\undocumented")) (|npcoef| (((|Record| (|:| |deter| (|List| (|SparseUnivariatePolynomial| |#5|))) (|:| |dterm| (|List| (|List| (|Record| (|:| |expt| (|NonNegativeInteger|)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (|List| |#1|)) (|:| |nlead| (|List| |#5|))) (|SparseUnivariatePolynomial| |#5|) (|List| |#1|) (|List| |#5|)) "\\spad{npcoef }\\undocumented"))) 
 NIL 
 NIL 
-(-778 K |PolyRing| E -3465) 
+(-799 K |PolyRing| E -3832) 
 ((|constructor| (NIL "The following is part of the PAFF package"))) 
 NIL 
 NIL 
-(-779 |Par|) 
+(-800 |Par|) 
 ((|constructor| (NIL "This package computes explicitly eigenvalues and eigenvectors of matrices with entries over the Rational Numbers. The results are expressed as floating numbers or as rational numbers depending on the type of the parameter Par.")) (|realEigenvectors| (((|List| (|Record| (|:| |outval| |#1|) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| |#1|))))) (|Matrix| (|Fraction| (|Integer|))) |#1|) "\\spad{realEigenvectors(m,eps)} returns a list of records each one containing a real eigenvalue, its algebraic multiplicity, and a list of associated eigenvectors. All these results are computed to precision \\spad{eps} as floats or rational numbers depending on the type of \\spad{eps} .")) (|realEigenvalues| (((|List| |#1|) (|Matrix| (|Fraction| (|Integer|))) |#1|) "\\spad{realEigenvalues(m,eps)} computes the eigenvalues of the matrix \\spad{m} to precision eps. The eigenvalues are expressed as floats or rational numbers depending on the type of \\spad{eps} (float or rational).")) (|characteristicPolynomial| (((|Polynomial| (|Fraction| (|Integer|))) (|Matrix| (|Fraction| (|Integer|))) (|Symbol|)) "\\spad{characteristicPolynomial(m,x)} returns the characteristic polynomial of the matrix \\spad{m} expressed as polynomial over \\spad{RN} with variable \\spad{x.} Fraction \\spad{P} \\spad{RN.}") (((|Polynomial| (|Fraction| (|Integer|))) (|Matrix| (|Fraction| (|Integer|)))) "\\spad{characteristicPolynomial(m)} returns the characteristic polynomial of the matrix \\spad{m} expressed as polynomial over \\spad{RN} with a new symbol as variable."))) 
 NIL 
 NIL 
-(-780 K) 
+(-801 K) 
 ((|constructor| (NIL "This domain is part of the PAFF package"))) 
-(((-4604 "*") . T) (-4595 . T) (-4594 . T) (-4600 . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-1110))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE |k|) (QUOTE (-572))) (LIST (QUOTE |:|) (QUOTE |c|) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) 
-(-781 R |VarSet|) 
+(((-4627 "*") . T) (-4618 . T) (-4617 . T) (-4623 . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-1131))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE |k|) (QUOTE (-592))) (LIST (QUOTE |:|) (QUOTE |c|) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) 
+(-802 R |VarSet|) 
 ((|constructor| (NIL "A post-facto extension for \\axiomType{SMP} in order to speed up operations related to pseudo-division and gcd. This domain is based on the \\axiomType{NSUP} constructor which is itself a post-facto extension of the \\axiomType{SUP} constructor."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-1170)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-1170))))) (|HasCategory| |#1| (QUOTE (-368))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-1170))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-1170)))) (-2959 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-1170)))))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-1170)))) (-2959 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) (-2959 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-572)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-1170)))) (-2959 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) (-2959 (|HasCategory| |#1| (QUOTE (-554))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-1170)))) (-2959 (|HasCategory| |#1| (LIST (QUOTE -1000) (QUOTE (-572))))))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-782 R S) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-1191)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-1191))))) (|HasCategory| |#1| (QUOTE (-388))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-1191))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-1191)))) (-3252 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-1191)))))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-1191)))) (-3252 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) (-3252 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-592)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-1191)))) (-3252 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) (-3252 (|HasCategory| |#1| (QUOTE (-574))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-1191)))) (-3252 (|HasCategory| |#1| (LIST (QUOTE -1021) (QUOTE (-592))))))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-803 R S) 
 ((|constructor| (NIL "This package lifts a mapping from coefficient rings \\spad{R} to \\spad{S} to a mapping from sparse univariate polynomial over \\spad{R} to a sparse univariate polynomial over \\spad{S.} Note that the mapping is assumed to send zero to zero, since it will only be applied to the non-zero coefficients of the polynomial.")) (|map| (((|NewSparseUnivariatePolynomial| |#2|) (|Mapping| |#2| |#1|) (|NewSparseUnivariatePolynomial| |#1|)) "\\axiom{map(func, poly)} creates a new polynomial by applying func to every non-zero coefficient of the polynomial poly."))) 
 NIL 
 NIL 
-(-783 R) 
+(-804 R) 
 ((|constructor| (NIL "A post-facto extension for \\axiomType{SUP} in order to speed up operations related to pseudo-division and \\spad{gcd} for both \\axiomType{SUP} and, consequently, \\axiomType{NSMP}.")) (|halfExtendedResultant2| (((|Record| (|:| |resultant| |#1|) (|:| |coef2| $)) $ $) "\\axiom{halfExtendedResultant2(a,b)} returns \\axiom{[r,ca]} such that \\axiom{extendedResultant(a,b)} returns \\axiom{[r,ca, cb]}")) (|halfExtendedResultant1| (((|Record| (|:| |resultant| |#1|) (|:| |coef1| $)) $ $) "\\axiom{halfExtendedResultant1(a,b)} returns \\axiom{[r,ca]} such that \\axiom{extendedResultant(a,b)} returns \\axiom{[r,ca, cb]}")) (|extendedResultant| (((|Record| (|:| |resultant| |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $) "\\axiom{extendedResultant(a,b)} returns \\axiom{[r,ca,cb]} such that \\axiom{r} is the resultant of \\axiom{a} and \\axiom{b} and \\axiom{r = ca * a + \\spad{cb} * \\spad{b}}")) (|halfExtendedSubResultantGcd2| (((|Record| (|:| |gcd| $) (|:| |coef2| $)) $ $) "\\axiom{halfExtendedSubResultantGcd2(a,b)} returns \\axiom{[g,cb]} such that \\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[g,ca, cb]}")) (|halfExtendedSubResultantGcd1| (((|Record| (|:| |gcd| $) (|:| |coef1| $)) $ $) "\\axiom{halfExtendedSubResultantGcd1(a,b)} returns \\axiom{[g,ca]} such that \\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[g,ca, cb]}")) (|extendedSubResultantGcd| (((|Record| (|:| |gcd| $) (|:| |coef1| $) (|:| |coef2| $)) $ $) "\\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[g,ca, cb]} such that \\axiom{g} is a \\spad{gcd} of \\axiom{a} and \\axiom{b} in \\axiom{R^(-1) \\spad{P}} and \\axiom{g = ca * a + \\spad{cb} * \\spad{b}}")) (|lastSubResultant| (($ $ $) "\\axiom{lastSubResultant(a,b)} returns \\axiom{resultant(a,b)} if \\axiom{a} and \\axiom{b} has no non-trivial \\spad{gcd} in \\axiom{R^(-1) \\spad{P}} otherwise the non-zero sub-resultant with smallest index.")) (|subResultantsChain| (((|List| $) $ $) "\\axiom{subResultantsChain(a,b)} returns the list of the non-zero sub-resultants of \\axiom{a} and \\axiom{b} sorted by increasing degree.")) (|lazyPseudoQuotient| (($ $ $) "\\axiom{lazyPseudoQuotient(a,b)} returns \\axiom{q} if \\axiom{lazyPseudoDivide(a,b)} returns \\axiom{[c,g,q,r]}")) (|lazyPseudoDivide| (((|Record| (|:| |coef| |#1|) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{lazyPseudoDivide(a,b)} returns \\axiom{[c,g,q,r]} such that \\axiom{c^n * a = \\spad{q*b} \\spad{+r}} and \\axiom{lazyResidueClass(a,b)} returns \\axiom{[r,c,n]} where \\axiom{n + \\spad{g} = max(0, degree(b) - degree(a) + 1)}.")) (|lazyPseudoRemainder| (($ $ $) "\\axiom{lazyPseudoRemainder(a,b)} returns \\axiom{r} if \\axiom{lazyResidueClass(a,b)} returns \\axiom{[r,c,n]}. This lazy pseudo-remainder is computed by means of the fmecg from NewSparseUnivariatePolynomial operation.")) (|lazyResidueClass| (((|Record| (|:| |polnum| $) (|:| |polden| |#1|) (|:| |power| (|NonNegativeInteger|))) $ $) "\\axiom{lazyResidueClass(a,b)} returns \\axiom{[r,c,n]} such that \\axiom{r} is reduced w.r.t. \\axiom{b} and \\axiom{b} divides \\axiom{c^n * a - \\spad{r}} where \\axiom{c} is \\axiom{leadingCoefficient(b)} and \\axiom{n} is as small as possible with the previous properties.")) (|monicModulo| (($ $ $) "\\axiom{monicModulo(a,b)} returns \\axiom{r} such that \\axiom{r} is reduced w.r.t. \\axiom{b} and \\axiom{b} divides \\axiom{a \\spad{-r}} where \\axiom{b} is monic.")) (|fmecg| (($ $ (|NonNegativeInteger|) |#1| $) "\\axiom{fmecg(p1,e,r,p2)} returns \\axiom{p1 - \\spad{r} * x**e * \\spad{p2}} where \\axiom{x} is \\axiom{monomial(1,1)}"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4598 |has| |#1| (-368)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-1144))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasCategory| |#1| (QUOTE (-227))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-784 R) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4621 |has| |#1| (-388)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-1165))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasCategory| |#1| (QUOTE (-247))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-805 R) 
 ((|constructor| (NIL "This package provides polynomials as functions on a ring.")) (|eulerE| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{eulerE(n,r)} \\undocumented")) (|bernoulliB| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{bernoulliB(n,r)} \\undocumented")) (|cyclotomic| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{cyclotomic(n,r)} \\undocumented"))) 
 NIL 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) 
-(-785 R E V P) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) 
+(-806 R E V P) 
 ((|constructor| (NIL "The category of normalized triangular sets. A triangular set \\spad{ts} is said normalized if for every algebraic variable \\spad{v} of \\spad{ts} the polynomial select(ts,v) is normalized w.r.t. every polynomial in collectUnder(ts,v). A polynomial \\spad{p} is said normalized w.r.t. a non-constant polynomial \\spad{q} if \\spad{p} is constant or degree(p,mdeg(q)) = 0 and init(p) is normalized w.r.t. \\spad{q.} One of the important features of normalized triangular sets is that they are regular sets."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-786 S) 
+(-807 S) 
 ((|constructor| (NIL "Numeric provides real and complex numerical evaluation functions for various symbolic types.")) (|numericIfCan| (((|Union| (|Float|) "failed") (|Expression| |#1|) (|PositiveInteger|)) "\\spad{numericIfCan(x, \\spad{n)}} returns a real approximation of \\spad{x} up to \\spad{n} decimal places, or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Float|) "failed") (|Expression| |#1|)) "\\spad{numericIfCan(x)} returns a real approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Float|) "failed") (|Fraction| (|Polynomial| |#1|)) (|PositiveInteger|)) "\\spad{numericIfCan(x,n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places, or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Float|) "failed") (|Fraction| (|Polynomial| |#1|))) "\\spad{numericIfCan(x)} returns a real approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Float|) "failed") (|Polynomial| |#1|) (|PositiveInteger|)) "\\spad{numericIfCan(x,n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places, or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Float|) "failed") (|Polynomial| |#1|)) "\\spad{numericIfCan(x)} returns a real approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.")) (|complexNumericIfCan| (((|Union| (|Complex| (|Float|)) "failed") (|Expression| (|Complex| |#1|)) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places, or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Expression| (|Complex| |#1|))) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Expression| |#1|) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places, or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Expression| |#1|)) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Fraction| (|Polynomial| (|Complex| |#1|))) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places, or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Fraction| (|Polynomial| (|Complex| |#1|)))) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Fraction| (|Polynomial| |#1|)) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x, \\spad{n)}} returns a complex approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Fraction| (|Polynomial| |#1|))) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Polynomial| |#1|) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places, or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Polynomial| |#1|)) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Polynomial| (|Complex| |#1|)) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places, or \"failed\" if \\axiom{x} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Polynomial| (|Complex| |#1|))) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x,} or \"failed\" if \\axiom{x} is not constant.")) (|complexNumeric| (((|Complex| (|Float|)) (|Expression| (|Complex| |#1|)) (|PositiveInteger|)) "\\spad{complexNumeric(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Expression| (|Complex| |#1|))) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x.}") (((|Complex| (|Float|)) (|Expression| |#1|) (|PositiveInteger|)) "\\spad{complexNumeric(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Expression| |#1|)) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x.}") (((|Complex| (|Float|)) (|Fraction| (|Polynomial| (|Complex| |#1|))) (|PositiveInteger|)) "\\spad{complexNumeric(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Fraction| (|Polynomial| (|Complex| |#1|)))) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x.}") (((|Complex| (|Float|)) (|Fraction| (|Polynomial| |#1|)) (|PositiveInteger|)) "\\spad{complexNumeric(x, \\spad{n)}} returns a complex approximation of \\spad{x}") (((|Complex| (|Float|)) (|Fraction| (|Polynomial| |#1|))) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x.}") (((|Complex| (|Float|)) (|Polynomial| |#1|) (|PositiveInteger|)) "\\spad{complexNumeric(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Polynomial| |#1|)) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x.}") (((|Complex| (|Float|)) (|Polynomial| (|Complex| |#1|)) (|PositiveInteger|)) "\\spad{complexNumeric(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Polynomial| (|Complex| |#1|))) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x.}") (((|Complex| (|Float|)) (|Complex| |#1|) (|PositiveInteger|)) "\\spad{complexNumeric(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Complex| |#1|)) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x.}") (((|Complex| (|Float|)) |#1| (|PositiveInteger|)) "\\spad{complexNumeric(x, \\spad{n)}} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) |#1|) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x.}")) (|numeric| (((|Float|) (|Expression| |#1|) (|PositiveInteger|)) "\\spad{numeric(x, \\spad{n)}} returns a real approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Float|) (|Expression| |#1|)) "\\spad{numeric(x)} returns a real approximation of \\spad{x.}") (((|Float|) (|Fraction| (|Polynomial| |#1|)) (|PositiveInteger|)) "\\spad{numeric(x,n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Float|) (|Fraction| (|Polynomial| |#1|))) "\\spad{numeric(x)} returns a real approximation of \\spad{x.}") (((|Float|) (|Polynomial| |#1|) (|PositiveInteger|)) "\\spad{numeric(x,n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Float|) (|Polynomial| |#1|)) "\\spad{numeric(x)} returns a real approximation of \\spad{x.}") (((|Float|) |#1| (|PositiveInteger|)) "\\spad{numeric(x, \\spad{n)}} returns a real approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Float|) |#1|) "\\spad{numeric(x)} returns a real approximation of \\spad{x.}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-562))) (-12 (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-848)))) (|HasCategory| |#1| (QUOTE (-1054))) (|HasCategory| |#1| (QUOTE (-174)))) 
-(-787) 
+((|HasCategory| |#1| (QUOTE (-582))) (-12 (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-869)))) (|HasCategory| |#1| (QUOTE (-1075))) (|HasCategory| |#1| (QUOTE (-194)))) 
+(-808) 
 ((|constructor| (NIL "NumberFormats provides function to format and read arabic and roman numbers, to convert numbers to strings and to read floating-point numbers.")) (|ScanFloatIgnoreSpacesIfCan| (((|Union| (|Float|) "failed") (|String|)) "\\spad{ScanFloatIgnoreSpacesIfCan(s)} tries to form a floating point number from the string \\spad{s} ignoring any spaces.")) (|ScanFloatIgnoreSpaces| (((|Float|) (|String|)) "\\spad{ScanFloatIgnoreSpaces(s)} forms a floating point number from the string \\spad{s} ignoring any spaces. Error is generated if the string is not recognised as a floating point number.")) (|ScanRoman| (((|PositiveInteger|) (|String|)) "\\spad{ScanRoman(s)} forms an integer from a Roman numeral string \\spad{s.}")) (|FormatRoman| (((|String|) (|PositiveInteger|)) "\\spad{FormatRoman(n)} forms a Roman numeral string from an integer \\spad{n.}")) (|ScanArabic| (((|PositiveInteger|) (|String|)) "\\spad{ScanArabic(s)} forms an integer from an Arabic numeral string \\spad{s.}")) (|FormatArabic| (((|String|) (|PositiveInteger|)) "\\spad{FormatArabic(n)} forms an Arabic numeral string from an integer \\spad{n.}"))) 
 NIL 
 NIL 
-(-788) 
+(-809) 
 ((|constructor| (NIL "\\axiomType{NumericalIntegrationCategory} is the \\axiom{category} for describing the set of Numerical Integration \\axiom{domains} with \\axiomFun{measure} and \\axiomFun{numericalIntegration}.")) (|numericalIntegration| (((|Result|) (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))) (|Result|)) "\\spad{numericalIntegration(args,hints)} performs the integration of the function given the strategy or method returned by \\axiomFun{measure}.") (((|Result|) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))) (|Result|)) "\\spad{numericalIntegration(args,hints)} performs the integration of the function given the strategy or method returned by \\axiomFun{measure}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|)) (|:| |extra| (|Result|))) (|RoutinesTable|) (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{measure(R,args)} calculates an estimate of the ability of a particular method to solve a problem. \\blankline This method may be either a specific NAG routine or a strategy (such as transforming the function from one which is difficult to one which is easier to solve). \\blankline It will call whichever agents are needed to perform analysis on the problem in order to calculate the measure. There is a parameter, labelled \\axiom{sofar}, which would contain the best compatibility found so far.") (((|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|)) (|:| |extra| (|Result|))) (|RoutinesTable|) (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{measure(R,args)} calculates an estimate of the ability of a particular method to solve a problem. \\blankline This method may be either a specific NAG routine or a strategy (such as transforming the function from one which is difficult to one which is easier to solve). \\blankline It will call whichever agents are needed to perform analysis on the problem in order to calculate the measure. There is a parameter, labelled \\axiom{sofar}, which would contain the best compatibility found so far."))) 
 NIL 
 NIL 
-(-789) 
+(-810) 
 ((|constructor| (NIL "This package is a suite of functions for the numerical integration of an ordinary differential equation of \\spad{n} variables:\\br \\tab{5}dy/dx = f(y,x)\\tab{5}y is an n-vector\\br All the routines are based on a 4-th order Runge-Kutta kernel. These routines generally have as arguments:\\br \\spad{n,} the number of dependent variables;\\br \\spad{x1,} the initial point;\\br \\spad{h,} the step size;\\br \\spad{y,} a vector of initial conditions of length n\\br which upon exit contains the solution at \\spad{x1 + h};\\br \\blankline \\spad{derivs}, a function which computes the right hand side of the ordinary differential equation: \\spad{derivs(dydx,y,x)} computes \\spad{dydx}, a vector which contains the derivative information. \\blankline In order of increasing complexity:\\br \\tab{5}\\spad{rk4(y,n,x1,h,derivs)} advances the solution vector to\\br \\tab{5}\\spad{x1 + \\spad{h}} and return the values in y.\\br \\blankline \\tab{5}\\spad{rk4(y,n,x1,h,derivs,t1,t2,t3,t4)} is the same as\\br \\tab{5}\\spad{rk4(y,n,x1,h,derivs)} except that you must provide 4 scratch\\br \\tab{5}arrays \\spad{t1-t4} of size n.\\br \\blankline \\tab{5}Starting with \\spad{y} at \\spad{x1,} \\spad{rk4f(y,n,x1,x2,ns,derivs)}\\br \\tab{5}uses \\spad{ns} fixed steps of a 4-th order Runge-Kutta\\br \\tab{5}integrator to advance the solution vector to \\spad{x2} and return\\br \\tab{5}the values in \\spad{y.} Argument \\spad{x2,} is the final point, and\\br \\tab{5}\\spad{ns}, the number of steps to take. \\blankline \\spad{rk4qc(y,n,x1,step,eps,yscal,derivs)} takes a 5-th order Runge-Kutta step with monitoring of local truncation to ensure accuracy and adjust stepsize. The function takes two half steps and one full step and scales the difference in solutions at the final point. If the error is within \\spad{eps}, the step is taken and the result is returned. If the error is not within \\spad{eps}, the stepsize if decreased and the procedure is tried again until the desired accuracy is reached. Upon input, an trial step size must be given and upon return, an estimate of the next step size to use is returned as well as the step size which produced the desired accuracy. The scaled error is computed as\\br \\tab{5}\\spad{error = MAX(ABS((y2steps(i) - y1step(i))/yscal(i)))}\\br and this is compared against \\spad{eps}. If this is greater than \\spad{eps}, the step size is reduced accordingly to\\br \\tab{5}\\spad{hnew = 0.9 * hdid * (error/eps)**(-1/4)}\\br If the error criterion is satisfied, then we check if the step size was too fine and return a more efficient one. If \\spad{error > \\spad{eps} * (6.0E-04)} then the next step size should be\\br \\tab{5}\\spad{hnext = 0.9 * hdid * (error/\\spad{eps})**(-1/5)}\\br Otherwise \\spad{hnext = 4.0 * hdid} is returned. A more detailed discussion of this and related topics can be found in the book \"Numerical Recipies\" by W.Press, B.P. Flannery, S.A. Teukolsky, W.T. Vetterling published by Cambridge University Press. \\blankline Argument \\spad{step} is a record of 3 floating point numbers \\spad{(try ,{} did ,{} next)}, \\spad{eps} is the required accuracy, \\spad{yscal} is the scaling vector for the difference in solutions. On input, \\spad{step.try} should be the guess at a step size to achieve the accuracy. On output, \\spad{step.did} contains the step size which achieved the accuracy and \\spad{step.next} is the next step size to use. \\blankline \\spad{rk4qc(y,n,x1,step,eps,yscal,derivs,t1,t2,t3,t4,t5,t6,t7)} is the same as \\spad{rk4qc(y,n,x1,step,eps,yscal,derivs)} except that the user must provide the 7 scratch arrays \\spad{t1-t7} of size \\spad{n.} \\blankline \\spad{rk4a(y,n,x1,x2,eps,h,ns,derivs)} is a driver program which uses \\spad{rk4qc} to integrate \\spad{n} ordinary differential equations starting at \\spad{x1} to \\spad{x2,} keeping the local truncation error to within \\spad{eps} by changing the local step size. The scaling vector is defined as\\br \\tab{5}\\spad{yscal(i) = abs(y(i)) + abs(h*dydx(i)) + tiny}\\br where \\spad{y(i)} is the solution at location \\spad{x,} \\spad{dydx} is the ordinary differential equation's right hand side, \\spad{h} is the current step size and \\spad{tiny} is 10 times the smallest positive number representable. \\blankline The user must supply an estimate for a trial step size and the maximum number of calls to \\spad{rk4qc} to use. Argument \\spad{x2} is the final point, \\spad{eps} is local truncation, \\spad{ns} is the maximum number of call to \\spad{rk4qc} to use.")) (|rk4f| (((|Void|) (|Vector| (|Float|)) (|Integer|) (|Float|) (|Float|) (|Integer|) (|Mapping| (|Void|) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Float|))) "\\spad{rk4f(y,n,x1,x2,ns,derivs)} uses a 4-th order Runge-Kutta method to numerically integrate the ordinary differential equation dy/dx = f(y,x) of \\spad{n} variables, where \\spad{y} is an n-vector. Starting with \\spad{y} at \\spad{x1,} this function uses \\spad{ns} fixed steps of a 4-th order Runge-Kutta integrator to advance the solution vector to \\spad{x2} and return the values in \\spad{y.} For details, see \\con{NumericalOrdinaryDifferentialEquations}.")) (|rk4qc| (((|Void|) (|Vector| (|Float|)) (|Integer|) (|Float|) (|Record| (|:| |try| (|Float|)) (|:| |did| (|Float|)) (|:| |next| (|Float|))) (|Float|) (|Vector| (|Float|)) (|Mapping| (|Void|) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|))) "\\spad{rk4qc(y,n,x1,step,eps,yscal,derivs,t1,t2,t3,t4,t5,t6,t7)} is a subfunction for the numerical integration of an ordinary differential equation dy/dx = f(y,x) of \\spad{n} variables, where \\spad{y} is an n-vector using a 4-th order Runge-Kutta method. This function takes a 5-th order Runge-Kutta \\spad{step} with monitoring of local truncation to ensure accuracy and adjust stepsize. For details, see \\con{NumericalOrdinaryDifferentialEquations}.") (((|Void|) (|Vector| (|Float|)) (|Integer|) (|Float|) (|Record| (|:| |try| (|Float|)) (|:| |did| (|Float|)) (|:| |next| (|Float|))) (|Float|) (|Vector| (|Float|)) (|Mapping| (|Void|) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Float|))) "\\spad{rk4qc(y,n,x1,step,eps,yscal,derivs)} is a subfunction for the numerical integration of an ordinary differential equation dy/dx = f(y,x) of \\spad{n} variables, where \\spad{y} is an n-vector using a 4-th order Runge-Kutta method. This function takes a 5-th order Runge-Kutta \\spad{step} with monitoring of local truncation to ensure accuracy and adjust stepsize. For details, see \\con{NumericalOrdinaryDifferentialEquations}.")) (|rk4a| (((|Void|) (|Vector| (|Float|)) (|Integer|) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Mapping| (|Void|) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Float|))) "\\spad{rk4a(y,n,x1,x2,eps,h,ns,derivs)} is a driver function for the numerical integration of an ordinary differential equation dy/dx = f(y,x) of \\spad{n} variables, where \\spad{y} is an n-vector using a 4-th order Runge-Kutta method. For details, see \\con{NumericalOrdinaryDifferentialEquations}.")) (|rk4| (((|Void|) (|Vector| (|Float|)) (|Integer|) (|Float|) (|Float|) (|Mapping| (|Void|) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Vector| (|Float|))) "\\spad{rk4(y,n,x1,h,derivs,t1,t2,t3,t4)} is the same as \\spad{rk4(y,n,x1,h,derivs)} except that you must provide 4 scratch arrays \\spad{t1-t4} of size \\spad{n.} For details, see \\con{NumericalOrdinaryDifferentialEquations}.") (((|Void|) (|Vector| (|Float|)) (|Integer|) (|Float|) (|Float|) (|Mapping| (|Void|) (|Vector| (|Float|)) (|Vector| (|Float|)) (|Float|))) "\\spad{rk4(y,n,x1,h,derivs)} uses a 4-th order Runge-Kutta method to numerically integrate the ordinary differential equation dy/dx = f(y,x) of \\spad{n} variables, where \\spad{y} is an n-vector. Argument \\spad{y} is a vector of initial conditions of length \\spad{n} which upon exit contains the solution at \\spad{x1 + \\spad{h},} \\spad{n} is the number of dependent variables, \\spad{x1} is the initial point, \\spad{h} is the step size, and \\spad{derivs} is a function which computes the right hand side of the ordinary differential equation. For details, see \\spadtype{NumericalOrdinaryDifferentialEquations}."))) 
 NIL 
 NIL 
-(-790) 
+(-811) 
 ((|constructor| (NIL "This suite of routines performs numerical quadrature using algorithms derived from the basic trapezoidal rule. Because the error term of this rule contains only even powers of the step size (for open and closed versions), fast convergence can be obtained if the integrand is sufficiently smooth. \\blankline Each routine returns a Record of type TrapAns, which contains value Float: estimate of the integral error Float: estimate of the error in the computation totalpts Integer: total number of function evaluations success Boolean: if the integral was computed within the user specified error criterion To produce this estimate, each routine generates an internal sequence of sub-estimates, denoted by S(i), depending on the routine, to which the various convergence criteria are applied. The user must supply a relative accuracy, \\spad{eps_r}, and an absolute accuracy, \\spad{eps_a}. Convergence is obtained when either\\br \\tab{5}\\spad{ABS(S(i) - S(i-1)) < eps_r * ABS(S(i-1))}\\br \\tab{5}or \\spad{ABS(S(i) - S(i-1)) < eps_a} are \\spad{true} statements. \\blankline The routines come in three families and three flavors: closed: romberg, simpson, trapezoidal open: rombergo, simpsono, trapezoidalo adaptive closed: aromberg, asimpson, atrapezoidal \\blankline The S(i) for the trapezoidal family is the value of the integral using an equally spaced absicca trapezoidal rule for that level of refinement. \\blankline The S(i) for the simpson family is the value of the integral using an equally spaced absicca simpson rule for that level of refinement. \\blankline The S(i) for the romberg family is the estimate of the integral using an equally spaced absicca romberg method. For the \\spad{i}-th level, this is an appropriate combination of all the previous trapezodial estimates so that the error term starts with the 2*(i+1) power only. \\blankline The three families come in a closed version, where the formulas include the endpoints, an open version where the formulas do not include the endpoints and an adaptive version, where the user is required to input the number of subintervals over which the appropriate closed family integrator will apply with the usual convergence parmeters for each subinterval. This is useful where a large number of points are needed only in a small fraction of the entire domain. \\blankline Each routine takes as arguments:\\br \\spad{f} integrand\\br a starting point\\br \\spad{b} ending point\\br eps_r relative error\\br eps_a absolute error\\br nmin refinement level when to start checking for convergence \\spad{(>} 1)\\br nmax maximum level of refinement\\br \\blankline The adaptive routines take as an additional parameter, nint, the number of independent intervals to apply a closed family integrator of the same name. \\blankline")) (|trapezoidalo| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|)) "\\spad{trapezoidalo(fn,a,b,epsrel,epsabs,nmin,nmax)} uses the trapezoidal method to numerically integrate function \\spad{fn} over the open interval from \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details.")) (|simpsono| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|)) "\\spad{simpsono(fn,a,b,epsrel,epsabs,nmin,nmax)} uses the simpson method to numerically integrate function \\spad{fn} over the open interval from \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details.")) (|rombergo| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|)) "\\spad{rombergo(fn,a,b,epsrel,epsabs,nmin,nmax)} uses the romberg method to numerically integrate function \\spad{fn} over the open interval from \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details.")) (|trapezoidal| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|)) "\\spad{trapezoidal(fn,a,b,epsrel,epsabs,nmin,nmax)} uses the trapezoidal method to numerically integrate function \\spadvar{fn} over the closed interval \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details.")) (|simpson| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|)) "\\spad{simpson(fn,a,b,epsrel,epsabs,nmin,nmax)} uses the simpson method to numerically integrate function \\spad{fn} over the closed interval \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details.")) (|romberg| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|)) "\\spad{romberg(fn,a,b,epsrel,epsabs,nmin,nmax)} uses the romberg method to numerically integrate function \\spadvar{fn} over the closed interval \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details.")) (|atrapezoidal| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{atrapezoidal(fn,a,b,epsrel,epsabs,nmin,nmax,nint)} uses the adaptive trapezoidal method to numerically integrate function \\spad{fn} over the closed interval from \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}, and where \\spad{nint} is the number of independent intervals to apply the integrator. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details.")) (|asimpson| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{asimpson(fn,a,b,epsrel,epsabs,nmin,nmax,nint)} uses the adaptive simpson method to numerically integrate function \\spad{fn} over the closed interval from \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}, and where \\spad{nint} is the number of independent intervals to apply the integrator. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details.")) (|aromberg| (((|Record| (|:| |value| (|Float|)) (|:| |error| (|Float|)) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|))) (|Mapping| (|Float|) (|Float|)) (|Float|) (|Float|) (|Float|) (|Float|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{aromberg(fn,a,b,epsrel,epsabs,nmin,nmax,nint)} uses the adaptive romberg method to numerically integrate function \\spad{fn} over the closed interval from \\spad{a} to \\spad{b}, with relative accuracy \\spad{epsrel} and absolute accuracy \\spad{epsabs}, with the refinement levels for convergence checking vary from \\spad{nmin} to \\spad{nmax}, and where \\spad{nint} is the number of independent intervals to apply the integrator. The value returned is a record containing the value of the integral, the estimate of the error in the computation, the total number of function evaluations, and either a boolean value which is \\spad{true} if the integral was computed within the user specified error criterion. See \\spadtype{NumericalQuadrature} for details."))) 
 NIL 
 NIL 
-(-791 |Curve|) 
+(-812 |Curve|) 
 ((|constructor| (NIL "Package for constructing tubes around 3-dimensional parametric curves.")) (|tube| (((|TubePlot| |#1|) |#1| (|DoubleFloat|) (|Integer|)) "\\spad{tube(c,r,n)} creates a tube of radius \\spad{r} around the curve \\spad{c.}"))) 
 NIL 
 NIL 
-(-792) 
+(-813) 
 ((|constructor| (NIL "Ordered sets which are also abelian groups, such that the addition preserves the ordering."))) 
 NIL 
 NIL 
-(-793) 
+(-814) 
 ((|constructor| (NIL "Ordered sets which are also abelian monoids, such that the addition preserves the ordering."))) 
 NIL 
 NIL 
-(-794) 
+(-815) 
 ((|constructor| (NIL "This domain is an OrderedAbelianMonoid with a sup operation added. The purpose of the sup operator in this domain is to act as a supremum with respect to the partial order imposed by `-`, rather than with respect to the total \\spad{$>$} order (since that is \"max\"). \\blankline Axioms\\br \\tab{5}sup(a,b)-a \\~~= \"failed\"\\br \\tab{5}sup(a,b)-b \\~~= \"failed\"\\br \\tab{5}x-a \\~~= \"failed\" and \\spad{x-b} \\~~= \"failed\" \\spad{=>} \\spad{x} \\spad{>=} sup(a,b)\\br")) (|sup| (($ $ $) "\\spad{sup(x,y)} returns the least element from which both \\spad{x} and \\spad{y} can be subtracted."))) 
 NIL 
 NIL 
-(-795) 
+(-816) 
 ((|constructor| (NIL "Ordered sets which are also abelian semigroups, such that the addition preserves the ordering.\\br \\blankline Axiom\\br \\tab{5} \\spad{x} < \\spad{y} \\spad{=>} \\spad{x+z} < \\spad{y+z}"))) 
 NIL 
 NIL 
-(-796) 
+(-817) 
 ((|constructor| (NIL "Ordered sets which are also abelian cancellation monoids, such that the addition preserves the ordering."))) 
 NIL 
 NIL 
-(-797 S R) 
+(-818 S R) 
 ((|constructor| (NIL "OctonionCategory gives the categorial frame for the octonions, and eight-dimensional non-associative algebra, doubling the the quaternions in the same way as doubling the Complex numbers to get the quaternions.")) (|inv| (($ $) "\\spad{inv(o)} returns the inverse of \\spad{o} if it exists.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(o)} returns the real part if all seven imaginary parts are 0, and \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(o)} returns the real part if all seven imaginary parts are 0. Error: if \\spad{o} is not rational.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(o)} tests if \\spad{o} is rational, \\spadignore{i.e.} that all seven imaginary parts are 0.")) (|abs| ((|#2| $) "\\spad{abs(o)} computes the absolute value of an octonion, equal to the square root of the \\spadfunFrom{norm}{Octonion}.")) (|octon| (($ |#2| |#2| |#2| |#2| |#2| |#2| |#2| |#2|) "\\spad{octon(re,ri,rj,rk,rE,rI,rJ,rK)} constructs an octonion from scalars.")) (|norm| ((|#2| $) "\\spad{norm(o)} returns the norm of an octonion, equal to the sum of the squares of its coefficients.")) (|imagK| ((|#2| $) "\\spad{imagK(o)} extracts the imaginary \\spad{K} part of octonion o.")) (|imagJ| ((|#2| $) "\\spad{imagJ(o)} extracts the imaginary \\spad{J} part of octonion o.")) (|imagI| ((|#2| $) "\\spad{imagI(o)} extracts the imaginary \\spad{I} part of octonion o.")) (|imagE| ((|#2| $) "\\spad{imagE(o)} extracts the imaginary \\spad{E} part of octonion o.")) (|imagk| ((|#2| $) "\\spad{imagk(o)} extracts the \\spad{k} part of octonion o.")) (|imagj| ((|#2| $) "\\spad{imagj(o)} extracts the \\spad{j} part of octonion o.")) (|imagi| ((|#2| $) "\\spad{imagi(o)} extracts the \\spad{i} part of octonion o.")) (|real| ((|#2| $) "\\spad{real(o)} extracts real part of octonion o.")) (|conjugate| (($ $) "\\spad{conjugate(o)} negates the imaginary parts i,j,k,E,I,J,K of octonian o."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-554))) (|HasCategory| |#2| (QUOTE (-1063))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-374)))) 
-(-798 R) 
+((|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-574))) (|HasCategory| |#2| (QUOTE (-1084))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-394)))) 
+(-819 R) 
 ((|constructor| (NIL "OctonionCategory gives the categorial frame for the octonions, and eight-dimensional non-associative algebra, doubling the the quaternions in the same way as doubling the Complex numbers to get the quaternions.")) (|inv| (($ $) "\\spad{inv(o)} returns the inverse of \\spad{o} if it exists.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(o)} returns the real part if all seven imaginary parts are 0, and \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(o)} returns the real part if all seven imaginary parts are 0. Error: if \\spad{o} is not rational.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(o)} tests if \\spad{o} is rational, \\spadignore{i.e.} that all seven imaginary parts are 0.")) (|abs| ((|#1| $) "\\spad{abs(o)} computes the absolute value of an octonion, equal to the square root of the \\spadfunFrom{norm}{Octonion}.")) (|octon| (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) "\\spad{octon(re,ri,rj,rk,rE,rI,rJ,rK)} constructs an octonion from scalars.")) (|norm| ((|#1| $) "\\spad{norm(o)} returns the norm of an octonion, equal to the sum of the squares of its coefficients.")) (|imagK| ((|#1| $) "\\spad{imagK(o)} extracts the imaginary \\spad{K} part of octonion o.")) (|imagJ| ((|#1| $) "\\spad{imagJ(o)} extracts the imaginary \\spad{J} part of octonion o.")) (|imagI| ((|#1| $) "\\spad{imagI(o)} extracts the imaginary \\spad{I} part of octonion o.")) (|imagE| ((|#1| $) "\\spad{imagE(o)} extracts the imaginary \\spad{E} part of octonion o.")) (|imagk| ((|#1| $) "\\spad{imagk(o)} extracts the \\spad{k} part of octonion o.")) (|imagj| ((|#1| $) "\\spad{imagj(o)} extracts the \\spad{j} part of octonion o.")) (|imagi| ((|#1| $) "\\spad{imagi(o)} extracts the \\spad{i} part of octonion o.")) (|real| ((|#1| $) "\\spad{real(o)} extracts real part of octonion o.")) (|conjugate| (($ $) "\\spad{conjugate(o)} negates the imaginary parts i,j,k,E,I,J,K of octonian o."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-799 -1841 R OS S) 
+(-820 -3836 R OS S) 
 ((|constructor| (NIL "\\spad{OctonionCategoryFunctions2} implements functions between two octonion domains defined over different rings. The function map is used to coerce between octonion types.")) (|map| ((|#3| (|Mapping| |#4| |#2|) |#1|) "\\spad{map(f,u)} maps \\spad{f} onto the component parts of the octonion u."))) 
 NIL 
 NIL 
-(-800 R) 
+(-821 R) 
 ((|constructor| (NIL "Octonion implements octonions (Cayley-Dixon algebra) over a commutative ring, an eight-dimensional non-associative algebra, doubling the quaternions in the same way as doubling the complex numbers to get the quaternions the main constructor function is octon which takes 8 arguments: the real part, the \\spad{i} imaginary part, the \\spad{j} imaginary part, the \\spad{k} imaginary part, (as with quaternions) and in addition the imaginary parts E, I, \\spad{J,} \\spad{K.}")) (|octon| (($ (|Quaternion| |#1|) (|Quaternion| |#1|)) "\\spad{octon(qe,qE)} constructs an octonion from two quaternions using the relation \\spad{O} = \\spad{Q} + QE."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -283) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1063))) (|HasCategory| |#1| (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| (-1006 |#1|) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-1006 |#1|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (-1841 (|HasCategory| (-1006 |#1|) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (-1841 (|HasCategory| (-1006 |#1|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))))) 
-(-801) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1084))) (|HasCategory| |#1| (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| (-1027 |#1|) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-1027 |#1|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (-3836 (|HasCategory| (-1027 |#1|) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (-3836 (|HasCategory| (-1027 |#1|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))))) 
+(-822) 
 ((|constructor| (NIL "\\axiomType{OrdinaryDifferentialEquationsSolverCategory} is the \\axiom{category} for describing the set of ODE solver \\axiom{domains} with \\axiomFun{measure} and \\axiomFun{ODEsolve}.")) (|ODESolve| (((|Result|) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{ODESolve(args)} performs the integration of the function given the strategy or method returned by \\axiomFun{measure}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|))) (|RoutinesTable|) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{measure(R,args)} calculates an estimate of the ability of a particular method to solve a problem. \\blankline This method may be either a specific NAG routine or a strategy (such as transforming the function from one which is difficult to one which is easier to solve). \\blankline It will call whichever agents are needed to perform analysis on the problem in order to calculate the measure. There is a parameter, labelled \\axiom{sofar}, which would contain the best compatibility found so far."))) 
 NIL 
 NIL 
-(-802 R -3313 L) 
+(-823 R -3958 L) 
 ((|constructor| (NIL "Solution of linear ordinary differential equations, constant coefficient case.")) (|constDsolve| (((|Record| (|:| |particular| |#2|) (|:| |basis| (|List| |#2|))) |#3| |#2| (|Symbol|)) "\\spad{constDsolve(op, \\spad{g,} \\spad{x)}} returns \\spad{[f, [y1,...,ym]]} where \\spad{f} is a particular solution of the equation \\spad{op \\spad{y} = \\spad{g},} and the \\spad{yi}'s form a basis for the solutions of \\spad{op \\spad{y} = 0}."))) 
 NIL 
 NIL 
-(-803 R -3313) 
+(-824 R -3958) 
 ((|constructor| (NIL "\\spad{ElementaryFunctionODESolver} provides the top-level functions for finding closed form solutions of ordinary differential equations and initial value problems.")) (|solve| (((|Union| |#2| "failed") |#2| (|BasicOperator|) (|Equation| |#2|) (|List| |#2|)) "\\spad{solve(eq, \\spad{y,} \\spad{x} = a, [y0,...,ym])} returns either the solution of the initial value problem \\spad{eq, y(a) = \\spad{y0,} y'(a) = y1,...} or \"failed\" if the solution cannot be found; error if the equation is not one linear ordinary or of the form \\spad{dy/dx = f(x,y)}.") (((|Union| |#2| "failed") (|Equation| |#2|) (|BasicOperator|) (|Equation| |#2|) (|List| |#2|)) "\\spad{solve(eq, \\spad{y,} \\spad{x} = a, [y0,...,ym])} returns either the solution of the initial value problem \\spad{eq, y(a) = \\spad{y0,} y'(a) = y1,...} or \"failed\" if the solution cannot be found; error if the equation is not one linear ordinary or of the form \\spad{dy/dx = f(x,y)}.") (((|Union| (|Record| (|:| |particular| |#2|) (|:| |basis| (|List| |#2|))) |#2| "failed") |#2| (|BasicOperator|) (|Symbol|)) "\\spad{solve(eq, \\spad{y,} \\spad{x)}} returns either a solution of the ordinary differential equation \\spad{eq} or \"failed\" if no non-trivial solution can be found; If the equation is linear ordinary, a solution is of the form \\spad{[h, [b1,...,bm]]} where \\spad{h} is a particular solution and and \\spad{[b1,...bm]} are linearly independent solutions of the associated homogenuous equation \\spad{f(x,y) = 0}; A full basis for the solutions of the homogenuous equation is not always returned, only the solutions which were found; If the equation is of the form {dy/dx = f(x,y)}, a solution is of the form \\spad{h(x,y)} where \\spad{h(x,y) = \\spad{c}} is a first integral of the equation for any constant \\spad{c}.") (((|Union| (|Record| (|:| |particular| |#2|) (|:| |basis| (|List| |#2|))) |#2| "failed") (|Equation| |#2|) (|BasicOperator|) (|Symbol|)) "\\spad{solve(eq, \\spad{y,} \\spad{x)}} returns either a solution of the ordinary differential equation \\spad{eq} or \"failed\" if no non-trivial solution can be found; If the equation is linear ordinary, a solution is of the form \\spad{[h, [b1,...,bm]]} where \\spad{h} is a particular solution and \\spad{[b1,...bm]} are linearly independent solutions of the associated homogenuous equation \\spad{f(x,y) = 0}; A full basis for the solutions of the homogenuous equation is not always returned, only the solutions which were found; If the equation is of the form {dy/dx = f(x,y)}, a solution is of the form \\spad{h(x,y)} where \\spad{h(x,y) = \\spad{c}} is a first integral of the equation for any constant \\spad{c}; error if the equation is not one of those 2 forms.") (((|Union| (|Record| (|:| |particular| (|Vector| |#2|)) (|:| |basis| (|List| (|Vector| |#2|)))) "failed") (|List| |#2|) (|List| (|BasicOperator|)) (|Symbol|)) "\\spad{solve([eq_1,...,eq_n], [y_1,...,y_n], \\spad{x)}} returns either \"failed\" or, if the equations form a fist order linear system, a solution of the form \\spad{[y_p, [b_1,...,b_n]]} where \\spad{h_p} is a particular solution and \\spad{[b_1,...b_m]} are linearly independent solutions of the associated homogenuous system. error if the equations do not form a first order linear system") (((|Union| (|Record| (|:| |particular| (|Vector| |#2|)) (|:| |basis| (|List| (|Vector| |#2|)))) "failed") (|List| (|Equation| |#2|)) (|List| (|BasicOperator|)) (|Symbol|)) "\\spad{solve([eq_1,...,eq_n], [y_1,...,y_n], \\spad{x)}} returns either \"failed\" or, if the equations form a fist order linear system, a solution of the form \\spad{[y_p, [b_1,...,b_n]]} where \\spad{h_p} is a particular solution and \\spad{[b_1,...b_m]} are linearly independent solutions of the associated homogenuous system. error if the equations do not form a first order linear system") (((|Union| (|List| (|Vector| |#2|)) "failed") (|Matrix| |#2|) (|Symbol|)) "\\spad{solve(m, \\spad{x)}} returns a basis for the solutions of \\spad{D \\spad{y} = \\spad{m} \\spad{y}.} \\spad{x} is the dependent variable.") (((|Union| (|Record| (|:| |particular| (|Vector| |#2|)) (|:| |basis| (|List| (|Vector| |#2|)))) "failed") (|Matrix| |#2|) (|Vector| |#2|) (|Symbol|)) "\\spad{solve(m, \\spad{v,} \\spad{x)}} returns \\spad{[v_p, [v_1,...,v_m]]} such that the solutions of the system \\spad{D \\spad{y} = \\spad{m} \\spad{y} + \\spad{v}} are \\spad{v_p + \\spad{c_1} \\spad{v_1} + \\spad{...} + \\spad{c_m} v_m} where the \\spad{c_i's} are constants, and the \\spad{v_i's} form a basis for the solutions of \\spad{D \\spad{y} = \\spad{m} \\spad{y}.} \\spad{x} is the dependent variable."))) 
 NIL 
 NIL 
-(-804) 
+(-825) 
 ((|constructor| (NIL "\\axiom{ODEIntensityFunctionsTable()} provides a dynamic table and a set of functions to store details found out about sets of ODE's.")) (|showIntensityFunctions| (((|Union| (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|))) "failed") (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{showIntensityFunctions(k)} returns the entries in the table of intensity functions \\spad{k.}")) (|insert!| (($ (|Record| (|:| |key| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|)))))) "\\spad{insert!(r)} inserts an entry \\spad{r} into theIFTable")) (|iFTable| (($ (|List| (|Record| (|:| |key| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|))))))) "\\spad{iFTable(l)} creates an intensity-functions table from the elements of \\spad{l.}")) (|keys| (((|List| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) $) "\\spad{keys(tab)} returns the list of keys of \\spad{f}")) (|clearTheIFTable| (((|Void|)) "\\spad{clearTheIFTable()} clears the current table of intensity functions.")) (|showTheIFTable| (($) "\\spad{showTheIFTable()} returns the current table of intensity functions."))) 
 NIL 
 NIL 
-(-805 R -3313) 
+(-826 R -3958) 
 ((|constructor| (NIL "\\spadtype{ODEIntegration} provides an interface to the integrator. This package is intended for use by the differential equations solver but not at top-level.")) (|diff| (((|Mapping| |#2| |#2|) (|Symbol|)) "\\spad{diff(x)} returns the derivation with respect to \\spad{x.}")) (|expint| ((|#2| |#2| (|Symbol|)) "\\spad{expint(f, \\spad{x)}} returns e^{the integral of \\spad{f} with respect to \\spad{x}.}")) (|int| ((|#2| |#2| (|Symbol|)) "\\spad{int(f, \\spad{x)}} returns the integral of \\spad{f} with respect to \\spad{x.}"))) 
 NIL 
 NIL 
-(-806) 
+(-827) 
 ((|constructor| (NIL "\\axiomType{AnnaOrdinaryDifferentialEquationPackage} is a \\axiom{package} of functions for the \\axiom{category} \\axiomType{OrdinaryDifferentialEquationsSolverCategory} with \\axiom{measure}, and \\axiom{solve}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|)))) (|NumericalODEProblem|) (|RoutinesTable|)) "\\spad{measure(prob,R)} is a top level ANNA function for identifying the most appropriate numerical routine from those in the routines table provided for solving the numerical ODE problem defined by \\axiom{prob}. \\blankline It calls each \\axiom{domain} listed in \\axiom{R} of \\axiom{category} \\axiomType{OrdinaryDifferentialEquationsSolverCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information. It predicts the likely most effective NAG numerical Library routine to solve the input set of ODEs by checking various attributes of the system of ODEs and calculating a measure of compatibility of each routine to these attributes.") (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|)))) (|NumericalODEProblem|)) "\\spad{measure(prob)} is a top level ANNA function for identifying the most appropriate numerical routine from those in the routines table provided for solving the numerical ODE problem defined by \\axiom{prob}. \\blankline It calls each \\axiom{domain} of \\axiom{category} \\axiomType{OrdinaryDifferentialEquationsSolverCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information. It predicts the likely most effective NAG numerical Library routine to solve the input set of ODEs by checking various attributes of the system of ODEs and calculating a measure of compatibility of each routine to these attributes.")) (|solve| (((|Result|) (|Vector| (|Expression| (|Float|))) (|Float|) (|Float|) (|List| (|Float|)) (|Expression| (|Float|)) (|List| (|Float|)) (|Float|) (|Float|)) "\\spad{solve(f,xStart,xEnd,yInitial,G,intVals,epsabs,epsrel)} is a top level ANNA function to solve numerically a system of ordinary differential equations, \\axiom{f}, \\spadignore{i.e.} equations for the derivatives y[1]'..y[n]' defined in terms of x,y[1]..y[n] from \\axiom{xStart} to \\axiom{xEnd} with the initial values for y[1]..y[n] (\\axiom{yInitial}) to an absolute error requirement \\axiom{epsabs} and relative error \\axiom{epsrel}. The values of y[1]..y[n] will be output for the values of \\spad{x} in \\axiom{intVals}. The calculation will stop if the function G(x,y[1],..,y[n]) evaluates to zero before \\spad{x} = xEnd. \\blankline It iterates over the \\axiom{domains} of \\axiomType{OrdinaryDifferentialEquationsSolverCategory} contained in the table of routines \\axiom{R} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of ODE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine.") (((|Result|) (|Vector| (|Expression| (|Float|))) (|Float|) (|Float|) (|List| (|Float|)) (|Expression| (|Float|)) (|List| (|Float|)) (|Float|)) "\\spad{solve(f,xStart,xEnd,yInitial,G,intVals,tol)} is a top level ANNA function to solve numerically a system of ordinary differential equations, \\axiom{f}, \\spadignore{i.e.} equations for the derivatives y[1]'..y[n]' defined in terms of x,y[1]..y[n] from \\axiom{xStart} to \\axiom{xEnd} with the initial values for y[1]..y[n] (\\axiom{yInitial}) to a tolerance \\axiom{tol}. The values of y[1]..y[n] will be output for the values of \\spad{x} in \\axiom{intVals}. The calculation will stop if the function G(x,y[1],..,y[n]) evaluates to zero before \\spad{x} = xEnd. \\blankline It iterates over the \\axiom{domains} of \\axiomType{OrdinaryDifferentialEquationsSolverCategory} contained in the table of routines \\axiom{R} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of ODE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine.") (((|Result|) (|Vector| (|Expression| (|Float|))) (|Float|) (|Float|) (|List| (|Float|)) (|List| (|Float|)) (|Float|)) "\\spad{solve(f,xStart,xEnd,yInitial,intVals,tol)} is a top level ANNA function to solve numerically a system of ordinary differential equations, \\axiom{f}, \\spadignore{i.e.} equations for the derivatives y[1]'..y[n]' defined in terms of x,y[1]..y[n] from \\axiom{xStart} to \\axiom{xEnd} with the initial values for y[1]..y[n] (\\axiom{yInitial}) to a tolerance \\axiom{tol}. The values of y[1]..y[n] will be output for the values of \\spad{x} in \\axiom{intVals}. \\blankline It iterates over the \\axiom{domains} of \\axiomType{OrdinaryDifferentialEquationsSolverCategory} contained in the table of routines \\axiom{R} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of ODE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine.") (((|Result|) (|Vector| (|Expression| (|Float|))) (|Float|) (|Float|) (|List| (|Float|)) (|Expression| (|Float|)) (|Float|)) "\\spad{solve(f,xStart,xEnd,yInitial,G,tol)} is a top level ANNA function to solve numerically a system of ordinary differential equations, \\axiom{f}, \\spadignore{i.e.} equations for the derivatives y[1]'..y[n]' defined in terms of x,y[1]..y[n] from \\axiom{xStart} to \\axiom{xEnd} with the initial values for y[1]..y[n] (\\axiom{yInitial}) to a tolerance \\axiom{tol}. The calculation will stop if the function G(x,y[1],..,y[n]) evaluates to zero before \\spad{x} = xEnd. \\blankline It iterates over the \\axiom{domains} of \\axiomType{OrdinaryDifferentialEquationsSolverCategory} contained in the table of routines \\axiom{R} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of ODE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine.") (((|Result|) (|Vector| (|Expression| (|Float|))) (|Float|) (|Float|) (|List| (|Float|)) (|Float|)) "\\spad{solve(f,xStart,xEnd,yInitial,tol)} is a top level ANNA function to solve numerically a system of ordinary differential equations, \\axiom{f}, \\spadignore{i.e.} equations for the derivatives y[1]'..y[n]' defined in terms of x,y[1]..y[n] from \\axiom{xStart} to \\axiom{xEnd} with the initial values for y[1]..y[n] (\\axiom{yInitial}) to a tolerance \\axiom{tol}. \\blankline It iterates over the \\axiom{domains} of \\axiomType{OrdinaryDifferentialEquationsSolverCategory} contained in the table of routines \\axiom{R} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of ODE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine.") (((|Result|) (|Vector| (|Expression| (|Float|))) (|Float|) (|Float|) (|List| (|Float|))) "\\spad{solve(f,xStart,xEnd,yInitial)} is a top level ANNA function to solve numerically a system of ordinary differential equations \\spadignore{i.e.} equations for the derivatives y[1]'..y[n]' defined in terms of x,y[1]..y[n], together with a starting value for \\spad{x} and y[1]..y[n] (called the initial conditions) and a final value of \\spad{x.} A default value is used for the accuracy requirement. \\blankline It iterates over the \\axiom{domains} of \\axiomType{OrdinaryDifferentialEquationsSolverCategory} contained in the table of routines \\axiom{R} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of ODE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine.") (((|Result|) (|NumericalODEProblem|) (|RoutinesTable|)) "\\spad{solve(odeProblem,R)} is a top level ANNA function to solve numerically a system of ordinary differential equations \\spadignore{i.e.} equations for the derivatives y[1]'..y[n]' defined in terms of x,y[1]..y[n], together with starting values for \\spad{x} and y[1]..y[n] (called the initial conditions), a final value of \\spad{x,} an accuracy requirement and any intermediate points at which the result is required. \\blankline It iterates over the \\axiom{domains} of \\axiomType{OrdinaryDifferentialEquationsSolverCategory} contained in the table of routines \\axiom{R} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of ODE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine.") (((|Result|) (|NumericalODEProblem|)) "\\spad{solve(odeProblem)} is a top level ANNA function to solve numerically a system of ordinary differential equations \\spadignore{i.e.} equations for the derivatives y[1]'..y[n]' defined in terms of x,y[1]..y[n], together with starting values for \\spad{x} and y[1]..y[n] (called the initial conditions), a final value of \\spad{x,} an accuracy requirement and any intermediate points at which the result is required. \\blankline It iterates over the \\axiom{domains} of \\axiomType{OrdinaryDifferentialEquationsSolverCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate, \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of ODE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine."))) 
 NIL 
 NIL 
-(-807 -3313 UP UPUP R) 
+(-828 -3958 UP UPUP R) 
 ((|constructor| (NIL "In-field solution of an linear ordinary differential equation, pure algebraic case.")) (|algDsolve| (((|Record| (|:| |particular| (|Union| |#4| "failed")) (|:| |basis| (|List| |#4|))) (|LinearOrdinaryDifferentialOperator1| |#4|) |#4|) "\\spad{algDsolve(op, \\spad{g)}} returns \\spad{[\"failed\", []]} if the equation \\spad{op \\spad{y} = \\spad{g}} has no solution in \\spad{R}. Otherwise, it returns \\spad{[f, [y1,...,ym]]} where \\spad{f} is a particular rational solution and the \\spad{y_i's} form a basis for the solutions in \\spad{R} of the homogeneous equation."))) 
 NIL 
 NIL 
-(-808 -3313 UP L LQ) 
+(-829 -3958 UP L LQ) 
 ((|constructor| (NIL "\\spad{PrimitiveRatDE} provides functions for in-field solutions of linear ordinary differential equations, in the transcendental case. The derivation to use is given by the parameter \\spad{L}.")) (|splitDenominator| (((|Record| (|:| |eq| |#3|) (|:| |rh| (|List| (|Fraction| |#2|)))) |#4| (|List| (|Fraction| |#2|))) "\\spad{splitDenominator(op, [g1,...,gm])} returns \\spad{op0, [h1,...,hm]} such that the equations \\spad{op \\spad{y} = \\spad{c1} \\spad{g1} + \\spad{...} + \\spad{cm} \\spad{gm}} and \\spad{op0 \\spad{y} = \\spad{c1} \\spad{h1} + \\spad{...} + \\spad{cm} \\spad{hm}} have the same solutions.")) (|indicialEquation| ((|#2| |#4| |#1|) "\\spad{indicialEquation(op, a)} returns the indicial equation of \\spad{op} at \\spad{a}.") ((|#2| |#3| |#1|) "\\spad{indicialEquation(op, a)} returns the indicial equation of \\spad{op} at \\spad{a}.")) (|indicialEquations| (((|List| (|Record| (|:| |center| |#2|) (|:| |equation| |#2|))) |#4| |#2|) "\\spad{indicialEquations(op, \\spad{p)}} returns \\spad{[[d1,e1],...,[dq,eq]]} where the \\spad{d_i}'s are the affine singularities of \\spad{op} above the roots of \\spad{p}, and the \\spad{e_i}'s are the indicial equations at each \\spad{d_i}.") (((|List| (|Record| (|:| |center| |#2|) (|:| |equation| |#2|))) |#4|) "\\spad{indicialEquations op} returns \\spad{[[d1,e1],...,[dq,eq]]} where the \\spad{d_i}'s are the affine singularities of \\spad{op}, and the \\spad{e_i}'s are the indicial equations at each \\spad{d_i}.") (((|List| (|Record| (|:| |center| |#2|) (|:| |equation| |#2|))) |#3| |#2|) "\\spad{indicialEquations(op, \\spad{p)}} returns \\spad{[[d1,e1],...,[dq,eq]]} where the \\spad{d_i}'s are the affine singularities of \\spad{op} above the roots of \\spad{p}, and the \\spad{e_i}'s are the indicial equations at each \\spad{d_i}.") (((|List| (|Record| (|:| |center| |#2|) (|:| |equation| |#2|))) |#3|) "\\spad{indicialEquations op} returns \\spad{[[d1,e1],...,[dq,eq]]} where the \\spad{d_i}'s are the affine singularities of \\spad{op}, and the \\spad{e_i}'s are the indicial equations at each \\spad{d_i}.")) (|denomLODE| ((|#2| |#3| (|List| (|Fraction| |#2|))) "\\spad{denomLODE(op, [g1,...,gm])} returns a polynomial \\spad{d} such that any rational solution of \\spad{op \\spad{y} = \\spad{c1} \\spad{g1} + \\spad{...} + \\spad{cm} \\spad{gm}} is of the form \\spad{p/d} for some polynomial \\spad{p.}") (((|Union| |#2| "failed") |#3| (|Fraction| |#2|)) "\\spad{denomLODE(op, \\spad{g)}} returns a polynomial \\spad{d} such that any rational solution of \\spad{op \\spad{y} = \\spad{g}} is of the form \\spad{p/d} for some polynomial \\spad{p,} and \"failed\", if the equation has no rational solution."))) 
 NIL 
 NIL 
-(-809) 
+(-830) 
 ((|constructor| (NIL "\\axiomType{NumericalODEProblem} is a \\axiom{domain} for the representation of Numerical ODE problems for use by ANNA. \\blankline The representation is of type: \\blankline \\axiomType{Record}(xinit:\\axiomType{DoubleFloat},\\br xend:\\axiomType{DoubleFloat},\\br fn:\\axiomType{Vector Expression DoubleFloat},\\br yinit:\\axiomType{List DoubleFloat},intvals:\\axiomType{List DoubleFloat},\\br g:\\axiomType{Expression DoubleFloat},abserr:\\axiomType{DoubleFloat},\\br relerr:\\axiomType{DoubleFloat}) \\blankline")) (|retract| (((|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))) $) "\\spad{retract(x)} is not documented")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(x)} is not documented") (($ (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{coerce(x)} is not documented"))) 
 NIL 
 NIL 
-(-810 -3313 UP L LQ) 
+(-831 -3958 UP L LQ) 
 ((|constructor| (NIL "In-field solution of Riccati equations, primitive case.")) (|changeVar| ((|#3| |#3| (|Fraction| |#2|)) "\\spad{changeVar(+/[ai D^i], a)} returns the operator \\spad{+/[ai (D+a)^i]}.") ((|#3| |#3| |#2|) "\\spad{changeVar(+/[ai D^i], a)} returns the operator \\spad{+/[ai (D+a)^i]}.")) (|singRicDE| (((|List| (|Record| (|:| |frac| (|Fraction| |#2|)) (|:| |eq| |#3|))) |#3| (|Mapping| (|List| |#2|) |#2| (|SparseUnivariatePolynomial| |#2|)) (|Mapping| (|Factored| |#2|) |#2|)) "\\spad{singRicDE(op, zeros, ezfactor)} returns \\spad{[[f1, L1], [f2, L2], \\spad{...} ,{} [fk, Lk]]} such that the singular part of any rational solution of the associated Riccati equation of \\spad{op y=0} must be one of the fi's (up to the constant coefficient), in which case the equation for \\spad{z=y e^{-int \\spad{p}}} is \\spad{Li z=0}. \\spad{zeros(C(x),H(x,y))} returns all the \\spad{P_i(x)}'s such that \\spad{H(x,P_i(x)) = 0 modulo C(x)}. Argument \\spad{ezfactor} is a factorisation in \\spad{UP}, not necessarily into irreducibles.")) (|polyRicDE| (((|List| (|Record| (|:| |poly| |#2|) (|:| |eq| |#3|))) |#3| (|Mapping| (|List| |#1|) |#2|)) "\\spad{polyRicDE(op, zeros)} returns \\spad{[[p1, L1], [p2, L2], \\spad{...} ,{} [pk, Lk]]} such that the polynomial part of any rational solution of the associated Riccati equation of \\spad{op y=0} must be one of the pi's (up to the constant coefficient), in which case the equation for \\spad{z=y e^{-int \\spad{p}}} is \\spad{Li \\spad{z} =0}. \\spad{zeros} is a zero finder in \\spad{UP}.")) (|constantCoefficientRicDE| (((|List| (|Record| (|:| |constant| |#1|) (|:| |eq| |#3|))) |#3| (|Mapping| (|List| |#1|) |#2|)) "\\spad{constantCoefficientRicDE(op, ric)} returns \\spad{[[a1, L1], [a2, L2], \\spad{...} ,{} [ak, Lk]]} such that any rational solution with no polynomial part of the associated Riccati equation of \\spad{op \\spad{y} = 0} must be one of the ai's in which case the equation for \\spad{z = \\spad{y} e^{-int ai}} is \\spad{Li \\spad{z} = 0}. \\spad{ric} is a Riccati equation solver over \\spad{F}, whose input is the associated linear equation.")) (|leadingCoefficientRicDE| (((|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |eq| |#2|))) |#3|) "\\spad{leadingCoefficientRicDE(op)} returns \\spad{[[m1, p1], [m2, p2], \\spad{...} ,{} [mk, pk]]} such that the polynomial part of any rational solution of the associated Riccati equation of \\spad{op \\spad{y} = 0} must have degree \\spad{mj} for some \\spad{j,} and its leading coefficient is then a zero of \\spad{pj.} In addition,\\spad{m1>m2> \\spad{...} >mk}.")) (|denomRicDE| ((|#2| |#3|) "\\spad{denomRicDE(op)} returns a polynomial \\spad{d} such that any rational solution of the associated Riccati equation of \\spad{op \\spad{y} = 0} is of the form \\spad{p/d + q'/q + \\spad{r}} for some polynomials \\spad{p} and \\spad{q} and a reduced \\spad{r.} Also, \\spad{deg(p) < deg(d)} and {gcd(d,q) = 1}."))) 
 NIL 
 NIL 
-(-811 -3313 UP) 
+(-832 -3958 UP) 
 ((|constructor| (NIL "\\spad{RationalLODE} provides functions for in-field solutions of linear ordinary differential equations, in the rational case.")) (|indicialEquationAtInfinity| ((|#2| (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|))) "\\spad{indicialEquationAtInfinity op} returns the indicial equation of \\spad{op} at infinity.") ((|#2| (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) "\\spad{indicialEquationAtInfinity op} returns the indicial equation of \\spad{op} at infinity.")) (|ratDsolve| (((|Record| (|:| |basis| (|List| (|Fraction| |#2|))) (|:| |mat| (|Matrix| |#1|))) (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|)) (|List| (|Fraction| |#2|))) "\\spad{ratDsolve(op, [g1,...,gm])} returns \\spad{[[h1,...,hq], \\spad{M]}} such that any rational solution of \\spad{op \\spad{y} = \\spad{c1} \\spad{g1} + \\spad{...} + \\spad{cm} \\spad{gm}} is of the form \\spad{d1 \\spad{h1} + \\spad{...} + \\spad{dq} \\spad{hq}} where \\spad{M [d1,...,dq,c1,...,cm] = 0}.") (((|Record| (|:| |particular| (|Union| (|Fraction| |#2|) "failed")) (|:| |basis| (|List| (|Fraction| |#2|)))) (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|)) (|Fraction| |#2|)) "\\spad{ratDsolve(op, \\spad{g)}} returns \\spad{[\"failed\", []]} if the equation \\spad{op \\spad{y} = \\spad{g}} has no rational solution. Otherwise, it returns \\spad{[f, [y1,...,ym]]} where \\spad{f} is a particular rational solution and the yi's form a basis for the rational solutions of the homogeneous equation.") (((|Record| (|:| |basis| (|List| (|Fraction| |#2|))) (|:| |mat| (|Matrix| |#1|))) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|)) (|List| (|Fraction| |#2|))) "\\spad{ratDsolve(op, [g1,...,gm])} returns \\spad{[[h1,...,hq], \\spad{M]}} such that any rational solution of \\spad{op \\spad{y} = \\spad{c1} \\spad{g1} + \\spad{...} + \\spad{cm} \\spad{gm}} is of the form \\spad{d1 \\spad{h1} + \\spad{...} + \\spad{dq} \\spad{hq}} where \\spad{M [d1,...,dq,c1,...,cm] = 0}.") (((|Record| (|:| |particular| (|Union| (|Fraction| |#2|) "failed")) (|:| |basis| (|List| (|Fraction| |#2|)))) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|)) (|Fraction| |#2|)) "\\spad{ratDsolve(op, \\spad{g)}} returns \\spad{[\"failed\", []]} if the equation \\spad{op \\spad{y} = \\spad{g}} has no rational solution. Otherwise, it returns \\spad{[f, [y1,...,ym]]} where \\spad{f} is a particular rational solution and the yi's form a basis for the rational solutions of the homogeneous equation."))) 
 NIL 
 NIL 
-(-812 -3313 L UP A LO) 
+(-833 -3958 L UP A LO) 
 ((|constructor| (NIL "Elimination of an algebraic from the coefficentss of a linear ordinary differential equation.")) (|reduceLODE| (((|Record| (|:| |mat| (|Matrix| |#2|)) (|:| |vec| (|Vector| |#1|))) |#5| |#4|) "\\spad{reduceLODE(op, \\spad{g)}} returns \\spad{[m, \\spad{v]}} such that any solution in \\spad{A} of \\spad{op \\spad{z} = \\spad{g}} is of the form \\spad{z = (z_1,...,z_m) . (b_1,...,b_m)} where the \\spad{b_i's} are the basis of \\spad{A} over \\spad{F} returned by \\spadfun{basis}() from \\spad{A}, and the \\spad{z_i's} satisfy the differential system \\spad{M.z = \\spad{v}.}"))) 
 NIL 
 NIL 
-(-813 -3313 UP) 
+(-834 -3958 UP) 
 ((|constructor| (NIL "In-field solution of Riccati equations, rational case.")) (|polyRicDE| (((|List| (|Record| (|:| |poly| |#2|) (|:| |eq| (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|))))) (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|)) (|Mapping| (|List| |#1|) |#2|)) "\\spad{polyRicDE(op, zeros)} returns \\spad{[[p1,L1], [p2,L2], \\spad{...} ,{} [pk,Lk]]} such that the polynomial part of any rational solution of the associated Riccati equation of \\spad{op \\spad{y} = 0} must be one of the pi's (up to the constant coefficient), in which case the equation for \\spad{z = \\spad{y} e^{-int \\spad{p}}} is \\spad{Li \\spad{z} = 0}. \\spad{zeros} is a zero finder in \\spad{UP}.")) (|singRicDE| (((|List| (|Record| (|:| |frac| (|Fraction| |#2|)) (|:| |eq| (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|))))) (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|)) (|Mapping| (|Factored| |#2|) |#2|)) "\\spad{singRicDE(op, ezfactor)} returns \\spad{[[f1,L1], [f2,L2],..., [fk,Lk]]} such that the singular \\spad{++} part of any rational solution of the associated Riccati equation of \\spad{op \\spad{y} = 0} must be one of the fi's (up to the constant coefficient), in which case the equation for \\spad{z = \\spad{y} e^{-int ai}} is \\spad{Li \\spad{z} = 0}. Argument \\spad{ezfactor} is a factorisation in \\spad{UP}, not necessarily into irreducibles.")) (|ricDsolve| (((|List| (|Fraction| |#2|)) (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|)) (|Mapping| (|Factored| |#2|) |#2|)) "\\spad{ricDsolve(op, ezfactor)} returns the rational solutions of the associated Riccati equation of \\spad{op \\spad{y} = 0}. Argument \\spad{ezfactor} is a factorisation in \\spad{UP}, not necessarily into irreducibles.") (((|List| (|Fraction| |#2|)) (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|))) "\\spad{ricDsolve(op)} returns the rational solutions of the associated Riccati equation of \\spad{op \\spad{y} = 0}.") (((|List| (|Fraction| |#2|)) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|)) (|Mapping| (|Factored| |#2|) |#2|)) "\\spad{ricDsolve(op, ezfactor)} returns the rational solutions of the associated Riccati equation of \\spad{op \\spad{y} = 0}. Argument \\spad{ezfactor} is a factorisation in \\spad{UP}, not necessarily into irreducibles.") (((|List| (|Fraction| |#2|)) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) "\\spad{ricDsolve(op)} returns the rational solutions of the associated Riccati equation of \\spad{op \\spad{y} = 0}.") (((|List| (|Fraction| |#2|)) (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|)) (|Mapping| (|List| |#1|) |#2|) (|Mapping| (|Factored| |#2|) |#2|)) "\\spad{ricDsolve(op, zeros, ezfactor)} returns the rational solutions of the associated Riccati equation of \\spad{op \\spad{y} = 0}. \\spad{zeros} is a zero finder in \\spad{UP}. Argument \\spad{ezfactor} is a factorisation in \\spad{UP}, not necessarily into irreducibles.") (((|List| (|Fraction| |#2|)) (|LinearOrdinaryDifferentialOperator2| |#2| (|Fraction| |#2|)) (|Mapping| (|List| |#1|) |#2|)) "\\spad{ricDsolve(op, zeros)} returns the rational solutions of the associated Riccati equation of \\spad{op \\spad{y} = 0}. \\spad{zeros} is a zero finder in \\spad{UP}.") (((|List| (|Fraction| |#2|)) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|)) (|Mapping| (|List| |#1|) |#2|) (|Mapping| (|Factored| |#2|) |#2|)) "\\spad{ricDsolve(op, zeros, ezfactor)} returns the rational solutions of the associated Riccati equation of \\spad{op \\spad{y} = 0}. \\spad{zeros} is a zero finder in \\spad{UP}. Argument \\spad{ezfactor} is a factorisation in \\spad{UP}, not necessarily into irreducibles.") (((|List| (|Fraction| |#2|)) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|)) (|Mapping| (|List| |#1|) |#2|)) "\\spad{ricDsolve(op, zeros)} returns the rational solutions of the associated Riccati equation of \\spad{op \\spad{y} = 0}. \\spad{zeros} is a zero finder in \\spad{UP}."))) 
 NIL 
 ((|HasCategory| |#1| (QUOTE (-27)))) 
-(-814 -3313 LO) 
+(-835 -3958 LO) 
 ((|constructor| (NIL "SystemODESolver provides tools for triangulating and solving some systems of linear ordinary differential equations.")) (|solveInField| (((|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|)))) (|Matrix| |#2|) (|Vector| |#1|) (|Mapping| (|Record| (|:| |particular| (|Union| |#1| "failed")) (|:| |basis| (|List| |#1|))) |#2| |#1|)) "\\spad{solveInField(m, \\spad{v,} solve)} returns \\spad{[[v_1,...,v_m], v_p]} such that the solutions in \\spad{F} of the system \\spad{m \\spad{x} = \\spad{v}} are \\spad{v_p + \\spad{c_1} \\spad{v_1} + \\spad{...} + \\spad{c_m} v_m} where the \\spad{c_i's} are constants, and the \\spad{v_i's} form a basis for the solutions of \\spad{m \\spad{x} = 0}. Argument \\spad{solve} is a function for solving a single linear ordinary differential equation in \\spad{F}.")) (|solve| (((|Union| (|Record| (|:| |particular| (|Vector| |#1|)) (|:| |basis| (|Matrix| |#1|))) "failed") (|Matrix| |#1|) (|Vector| |#1|) (|Mapping| (|Union| (|Record| (|:| |particular| |#1|) (|:| |basis| (|List| |#1|))) "failed") |#2| |#1|)) "\\spad{solve(m, \\spad{v,} solve)} returns \\spad{[[v_1,...,v_m], v_p]} such that the solutions in \\spad{F} of the system \\spad{D \\spad{x} = \\spad{m} \\spad{x} + \\spad{v}} are \\spad{v_p + \\spad{c_1} \\spad{v_1} + \\spad{...} + \\spad{c_m} v_m} where the \\spad{c_i's} are constants, and the \\spad{v_i's} form a basis for the solutions of \\spad{D \\spad{x} = \\spad{m} \\spad{x}.} Argument \\spad{solve} is a function for solving a single linear ordinary differential equation in \\spad{F}.")) (|triangulate| (((|Record| (|:| |mat| (|Matrix| |#2|)) (|:| |vec| (|Vector| |#1|))) (|Matrix| |#2|) (|Vector| |#1|)) "\\spad{triangulate(m, \\spad{v)}} returns \\spad{[m_0, v_0]} such that \\spad{m_0} is upper triangular and the system \\spad{m_0 \\spad{x} = v_0} is equivalent to \\spad{m \\spad{x} = \\spad{v}.}") (((|Record| (|:| A (|Matrix| |#1|)) (|:| |eqs| (|List| (|Record| (|:| C (|Matrix| |#1|)) (|:| |g| (|Vector| |#1|)) (|:| |eq| |#2|) (|:| |rh| |#1|))))) (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{triangulate(M,v)} returns \\spad{A,[[C_1,g_1,L_1,h_1],...,[C_k,g_k,L_k,h_k]]} such that under the change of variable \\spad{y = A \\spad{z},} the first order linear system \\spad{D \\spad{y} = \\spad{M} \\spad{y} + \\spad{v}} is uncoupled as \\spad{D z_i = C_i z_i + g_i} and each \\spad{C_i} is a companion matrix corresponding to the scalar equation \\spad{L_i \\spad{z_j} = h_i}."))) 
 NIL 
 NIL 
-(-815 -3313 LODO) 
+(-836 -3958 LODO) 
 ((|constructor| (NIL "\\spad{ODETools} provides tools for the linear ODE solver.")) (|particularSolution| (((|Union| |#1| "failed") |#2| |#1| (|List| |#1|) (|Mapping| |#1| |#1|)) "\\spad{particularSolution(op, \\spad{g,} [f1,...,fm], I)} returns a particular solution \\spad{h} of the equation \\spad{op \\spad{y} = \\spad{g}} where \\spad{[f1,...,fm]} are linearly independent and \\spad{op(fi)=0}. The value \"failed\" is returned if no particular solution is found. Note that the method of variations of parameters is used.")) (|variationOfParameters| (((|Union| (|Vector| |#1|) "failed") |#2| |#1| (|List| |#1|)) "\\spad{variationOfParameters(op, \\spad{g,} [f1,...,fm])} returns \\spad{[u1,...,um]} such that a particular solution of the equation \\spad{op \\spad{y} = \\spad{g}} is \\spad{f1 int(u1) + \\spad{...} + \\spad{fm} int(um)} where \\spad{[f1,...,fm]} are linearly independent and \\spad{op(fi)=0}. The value \"failed\" is returned if \\spad{m < \\spad{n}} and no particular solution is found.")) (|wronskianMatrix| (((|Matrix| |#1|) (|List| |#1|) (|NonNegativeInteger|)) "\\spad{wronskianMatrix([f1,...,fn], \\spad{q,} \\spad{D)}} returns the \\spad{q \\spad{x} \\spad{n}} matrix \\spad{m} whose i^th row is \\spad{[f1^(i-1),...,fn^(i-1)]}.") (((|Matrix| |#1|) (|List| |#1|)) "\\spad{wronskianMatrix([f1,...,fn])} returns the \\spad{n \\spad{x} \\spad{n}} matrix \\spad{m} whose i^th row is \\spad{[f1^(i-1),...,fn^(i-1)]}."))) 
 NIL 
 NIL 
-(-816 -3465 S |f|) 
+(-837 -3832 S |f|) 
 ((|constructor| (NIL "This type represents the finite direct or cartesian product of an underlying ordered component type. The ordering on the type is determined by its third argument which represents the less than function on vectors. This type is a suitable third argument for \\spadtype{GeneralDistributedMultivariatePolynomial}."))) 
-((-4596 |has| |#2| (-1054)) (-4597 |has| |#2| (-1054)) (-4599 |has| |#2| (-6 -4599)) ((-4604 "*") |has| |#2| (-174)) (-4602 . T)) 
-((|HasCategory| |#2| (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846))) (-1841 (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846)))) (|HasCategory| |#2| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368)))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| |#2| (QUOTE (-374))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasAttribute| |#2| (QUOTE -4599)) (|HasCategory| |#2| (QUOTE (-138))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (|HasCategory| |#2| (QUOTE (-25))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-374))) (|HasCategory| |#2| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-846))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1054)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-1098))))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1098))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-174)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-368)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-846)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1054)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))))) 
-(-817 R) 
+((-4619 |has| |#2| (-1075)) (-4620 |has| |#2| (-1075)) (-4622 |has| |#2| (-6 -4622)) ((-4627 "*") |has| |#2| (-194)) (-4625 . T)) 
+((|HasCategory| |#2| (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867))) (-3836 (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867)))) (|HasCategory| |#2| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388)))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| |#2| (QUOTE (-394))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasAttribute| |#2| (QUOTE -4622)) (|HasCategory| |#2| (QUOTE (-158))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (|HasCategory| |#2| (QUOTE (-25))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-394))) (|HasCategory| |#2| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-867))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1075)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-1119))))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1119))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-194)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-388)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-867)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1075)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))))) 
+(-838 R) 
 ((|constructor| (NIL "\\spadtype{OrderlyDifferentialPolynomial} implements an ordinary differential polynomial ring in arbitrary number of differential indeterminates, with coefficients in a ring. The ranking on the differential indeterminate is orderly. This is analogous to the domain \\spadtype{Polynomial}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-819 (-1170)) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-819 (-1170)) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-819 (-1170)) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-819 (-1170)) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-819 (-1170)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-818 |Kernels| R |var|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-840 (-1191)) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-840 (-1191)) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-840 (-1191)) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-840 (-1191)) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-840 (-1191)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-839 |Kernels| R |var|) 
 ((|constructor| (NIL "This constructor produces an ordinary differential ring from a partial differential ring by specifying a variable.")) (|coerce| ((|#2| $) "\\spad{coerce(p)} views \\spad{p} as a valie in the partial differential ring.") (($ |#2|) "\\spad{coerce(r)} views \\spad{r} as a value in the ordinary differential ring."))) 
-(((-4604 "*") |has| |#2| (-368)) (-4595 |has| |#2| (-368)) (-4600 |has| |#2| (-368)) (-4594 |has| |#2| (-368)) (-4599 . T) (-4597 . T) (-4596 . T)) 
-((|HasCategory| |#2| (QUOTE (-368)))) 
-(-819 S) 
+(((-4627 "*") |has| |#2| (-388)) (-4618 |has| |#2| (-388)) (-4623 |has| |#2| (-388)) (-4617 |has| |#2| (-388)) (-4622 . T) (-4620 . T) (-4619 . T)) 
+((|HasCategory| |#2| (QUOTE (-388)))) 
+(-840 S) 
 ((|constructor| (NIL "\\spadtype{OrderlyDifferentialVariable} adds a commonly used orderly ranking to the set of derivatives of an ordered list of differential indeterminates. An orderly ranking is a ranking \\spadfun{<} of the derivatives with the property that for two derivatives \\spad{u} and \\spad{v,} \\spad{u} \\spadfun{<} \\spad{v} if the \\spadfun{order} of \\spad{u} is less than that of \\spad{v.} This domain belongs to \\spadtype{DifferentialVariableCategory}. It defines \\spadfun{weight} to be just \\spadfun{order}, and it defines an orderly ranking \\spadfun{<} on derivatives \\spad{u} via the lexicographic order on the pair (\\spadfun{order}(u), \\spadfun{variable}(u))."))) 
 NIL 
 NIL 
-(-820 S) 
+(-841 S) 
 ((|constructor| (NIL "The free monoid on a set \\spad{S} is the monoid of finite products of the form \\spad{reduce(*,[si \\spad{**} ni])} where the si's are in \\spad{S,} and the ni's are non-negative integers. The multiplication is not commutative. For two elements \\spad{x} and \\spad{y} the relation \\spad{x < \\spad{y}} holds if either \\spad{length(x) < length(y)} holds or if these lengths are equal and if \\spad{x} is smaller than \\spad{y} w.r.t. the lexicographical ordering induced by \\spad{S}. This domain inherits implementation from \\spadtype{FreeMonoid}.")) (|varList| (((|List| |#1|) $) "\\indented{1}{\\spad{varList(x)} returns the list of variables of \\spad{x}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} varList \\spad{m1}")) (|length| (((|NonNegativeInteger|) $) "\\indented{1}{\\spad{length(x)} returns the length of \\spad{x}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} length \\spad{m1}")) (|factors| (((|List| (|Record| (|:| |gen| |#1|) (|:| |exp| (|NonNegativeInteger|)))) $) "\\indented{1}{\\spad{factors(a1\\^e1,...,an\\^en)} returns} \\indented{1}{\\spad{[[a1, e1],...,[an, en]]}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} factors \\spad{m1}")) (|nthFactor| ((|#1| $ (|Integer|)) "\\indented{1}{\\spad{nthFactor(x, \\spad{n)}} returns the factor of the \\spad{n-th}} \\indented{1}{monomial of \\spad{x}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} nthFactor(m1,2)")) (|nthExpon| (((|NonNegativeInteger|) $ (|Integer|)) "\\indented{1}{\\spad{nthExpon(x, \\spad{n)}} returns the exponent of the} \\indented{1}{\\spad{n-th} monomial of \\spad{x}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} nthExpon(m1,2)")) (|size| (((|NonNegativeInteger|) $) "\\indented{1}{\\spad{size(x)} returns the number of monomials in \\spad{x}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} size(m1,2)")) (|overlap| (((|Record| (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) "\\indented{1}{\\spad{overlap(x, \\spad{y)}} returns \\spad{[l, \\spad{m,} \\spad{r]}} such that} \\indented{1}{\\spad{x = \\spad{l} * \\spad{m}} and \\spad{y = \\spad{m} * \\spad{r}} hold and such that} \\indented{1}{\\spad{l} and \\spad{r} have no overlap,} \\indented{1}{that is \\spad{overlap(l, \\spad{r)} = \\spad{[l,} 1, r]}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} m2:=(x*y)$OFMONOID(Symbol) \\spad{X} overlap(m1,m2)")) (|divide| (((|Union| (|Record| (|:| |lm| (|Union| $ "failed")) (|:| |rm| (|Union| $ "failed"))) "failed") $ $) "\\indented{1}{\\spad{divide(x,y)} returns the left and right exact quotients of} \\indented{1}{\\spad{x} by \\spad{y}, that is \\spad{[l,r]} such that \\spad{x = l*y*r}.} \\indented{1}{\"failed\" is returned iff \\spad{x} is not of the form \\spad{l * \\spad{y} * r}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} m2:=(x*y)$OFMONOID(Symbol) \\spad{X} divide(m1,m2)")) (|rquo| (((|Union| $ "failed") $ |#1|) "\\indented{1}{\\spad{rquo(x, \\spad{s)}} returns the exact right quotient} \\indented{1}{of \\spad{x} by \\spad{s}.} \\blankline \\spad{X} m1:=(x*y)$OFMONOID(Symbol) \\spad{X} div(m1,y)") (((|Union| $ "failed") $ $) "\\indented{1}{\\spad{rquo(x, \\spad{y)}} returns the exact right quotient of \\spad{x}} \\indented{1}{by \\spad{y} that is \\spad{q} such that \\spad{x = \\spad{q} * y},} \\indented{1}{\"failed\" if \\spad{x} is not of the form \\spad{q * y}.} \\blankline \\spad{X} m1:=(q*y^3)$OFMONOID(Symbol) \\spad{X} m2:=(y^2)$OFMONOID(Symbol) \\spad{X} lquo(m1,m2)")) (|lquo| (((|Union| $ "failed") $ |#1|) "\\indented{1}{\\spad{lquo(x, \\spad{s)}} returns the exact left quotient of \\spad{x}} \\indented{1}{by \\spad{s}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} lquo(m1,x)") (((|Union| $ "failed") $ $) "\\indented{1}{\\spad{lquo(x, \\spad{y)}} returns the exact left quotient of \\spad{x}} \\indented{2}{by \\spad{y} that is \\spad{q} such that \\spad{x = \\spad{y} * q},} \\indented{1}{\"failed\" if \\spad{x} is not of the form \\spad{y * q}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} m2:=(x*y)$OFMONOID(Symbol) \\spad{X} lquo(m1,m2)")) (|hcrf| (($ $ $) "\\indented{1}{\\spad{hcrf(x, \\spad{y)}} returns the highest common right} \\indented{1}{factor of \\spad{x} and \\spad{y},} \\indented{1}{that is the largest \\spad{d} such that \\spad{x = a \\spad{d}}} \\indented{1}{and \\spad{y = \\spad{b} d}.} \\blankline \\spad{X} m1:=(x*y*z)$OFMONOID(Symbol) \\spad{X} m2:=(y*z)$OFMONOID(Symbol) \\spad{X} hcrf(m1,m2)")) (|hclf| (($ $ $) "\\indented{1}{\\spad{hclf(x, \\spad{y)}} returns the highest common left factor} \\indented{1}{of \\spad{x} and \\spad{y},} \\indented{1}{that is the largest \\spad{d} such that \\spad{x = \\spad{d} a}} \\indented{1}{and \\spad{y = \\spad{d} b}.} \\blankline \\spad{X} m1:=(x*y*z)$OFMONOID(Symbol) \\spad{X} m2:=(x*y)$OFMONOID(Symbol) \\spad{X} hclf(m1,m2)")) (|lexico| (((|Boolean|) $ $) "\\indented{1}{\\spad{lexico(x,y)} returns \\spad{true}} \\indented{1}{iff \\spad{x} is smaller than \\spad{y}} \\indented{1}{w.r.t. the pure lexicographical ordering induced by \\spad{S}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} m2:=(x*y)$OFMONOID(Symbol) \\spad{X} lexico(m1,m2) \\spad{X} lexico(m2,m1)")) (|mirror| (($ $) "\\indented{1}{\\spad{mirror(x)} returns the reversed word of \\spad{x}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} mirror \\spad{m1}")) (|rest| (($ $) "\\indented{1}{\\spad{rest(x)} returns \\spad{x} except the first letter.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} rest \\spad{m1}")) (|first| ((|#1| $) "\\indented{1}{\\spad{first(x)} returns the first letter of \\spad{x}.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} first \\spad{m1}")) (** (($ |#1| (|NonNegativeInteger|)) "\\indented{1}{\\spad{s**n} returns the product of \\spad{s} by itself \\spad{n} times.} \\blankline \\spad{X} m1:=(y**3)$OFMONOID(Symbol)")) (* (($ $ |#1|) "\\indented{1}{\\spad{x*s} returns the product of \\spad{x} by \\spad{s} on the right.} \\blankline \\spad{X} m1:=(y**3)$OFMONOID(Symbol) \\spad{X} m1*x") (($ |#1| $) "\\indented{1}{\\spad{s*x} returns the product of \\spad{x} by \\spad{s} on the left.} \\blankline \\spad{X} m1:=(x*y*y*z)$OFMONOID(Symbol) \\spad{X} \\spad{x*m1}"))) 
 NIL 
 NIL 
-(-821) 
+(-842) 
 ((|constructor| (NIL "The category of ordered commutative integral domains, where ordering and the arithmetic operations are compatible"))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-822) 
+(-843) 
 ((|constructor| (NIL "\\spadtype{OpenMathConnection} provides low-level functions for handling connections to and from \\spadtype{OpenMathDevice}s.")) (|OMbindTCP| (((|Boolean|) $ (|SingleInteger|)) "\\spad{OMbindTCP}")) (|OMconnectTCP| (((|Boolean|) $ (|String|) (|SingleInteger|)) "\\spad{OMconnectTCP}")) (|OMconnOutDevice| (((|OpenMathDevice|) $) "\\spad{OMconnOutDevice:}")) (|OMconnInDevice| (((|OpenMathDevice|) $) "\\spad{OMconnInDevice:}")) (|OMcloseConn| (((|Void|) $) "\\spad{OMcloseConn}")) (|OMmakeConn| (($ (|SingleInteger|)) "\\spad{OMmakeConn}"))) 
 NIL 
 NIL 
-(-823) 
+(-844) 
 ((|constructor| (NIL "\\spadtype{OpenMathDevice} provides support for reading and writing openMath objects to files, strings etc. It also provides access to low-level operations from within the interpreter.")) (|OMgetType| (((|Symbol|) $) "\\spad{OMgetType(dev)} returns the type of the next object on \\axiom{dev}.")) (|OMgetSymbol| (((|Record| (|:| |cd| (|String|)) (|:| |name| (|String|))) $) "\\spad{OMgetSymbol(dev)} reads a symbol from \\axiom{dev}.")) (|OMgetString| (((|String|) $) "\\spad{OMgetString(dev)} reads a string from \\axiom{dev}.")) (|OMgetVariable| (((|Symbol|) $) "\\spad{OMgetVariable(dev)} reads a variable from \\axiom{dev}.")) (|OMgetFloat| (((|DoubleFloat|) $) "\\spad{OMgetFloat(dev)} reads a float from \\axiom{dev}.")) (|OMgetInteger| (((|Integer|) $) "\\spad{OMgetInteger(dev)} reads an integer from \\axiom{dev}.")) (|OMgetEndObject| (((|Void|) $) "\\spad{OMgetEndObject(dev)} reads an end object token from \\axiom{dev}.")) (|OMgetEndError| (((|Void|) $) "\\spad{OMgetEndError(dev)} reads an end error token from \\axiom{dev}.")) (|OMgetEndBVar| (((|Void|) $) "\\spad{OMgetEndBVar(dev)} reads an end bound variable list token from \\axiom{dev}.")) (|OMgetEndBind| (((|Void|) $) "\\spad{OMgetEndBind(dev)} reads an end binder token from \\axiom{dev}.")) (|OMgetEndAttr| (((|Void|) $) "\\spad{OMgetEndAttr(dev)} reads an end attribute token from \\axiom{dev}.")) (|OMgetEndAtp| (((|Void|) $) "\\spad{OMgetEndAtp(dev)} reads an end attribute pair token from \\axiom{dev}.")) (|OMgetEndApp| (((|Void|) $) "\\spad{OMgetEndApp(dev)} reads an end application token from \\axiom{dev}.")) (|OMgetObject| (((|Void|) $) "\\spad{OMgetObject(dev)} reads a begin object token from \\axiom{dev}.")) (|OMgetError| (((|Void|) $) "\\spad{OMgetError(dev)} reads a begin error token from \\axiom{dev}.")) (|OMgetBVar| (((|Void|) $) "\\spad{OMgetBVar(dev)} reads a begin bound variable list token from \\axiom{dev}.")) (|OMgetBind| (((|Void|) $) "\\spad{OMgetBind(dev)} reads a begin binder token from \\axiom{dev}.")) (|OMgetAttr| (((|Void|) $) "\\spad{OMgetAttr(dev)} reads a begin attribute token from \\axiom{dev}.")) (|OMgetAtp| (((|Void|) $) "\\spad{OMgetAtp(dev)} reads a begin attribute pair token from \\axiom{dev}.")) (|OMgetApp| (((|Void|) $) "\\spad{OMgetApp(dev)} reads a begin application token from \\axiom{dev}.")) (|OMputSymbol| (((|Void|) $ (|String|) (|String|)) "\\spad{OMputSymbol(dev,cd,s)} writes the symbol \\axiom{s} from \\spad{CD} \\axiom{cd} to \\axiom{dev}.")) (|OMputString| (((|Void|) $ (|String|)) "\\spad{OMputString(dev,i)} writes the string \\axiom{i} to \\axiom{dev}.")) (|OMputVariable| (((|Void|) $ (|Symbol|)) "\\spad{OMputVariable(dev,i)} writes the variable \\axiom{i} to \\axiom{dev}.")) (|OMputFloat| (((|Void|) $ (|DoubleFloat|)) "\\spad{OMputFloat(dev,i)} writes the float \\axiom{i} to \\axiom{dev}.")) (|OMputInteger| (((|Void|) $ (|Integer|)) "\\spad{OMputInteger(dev,i)} writes the integer \\axiom{i} to \\axiom{dev}.")) (|OMputEndObject| (((|Void|) $) "\\spad{OMputEndObject(dev)} writes an end object token to \\axiom{dev}.")) (|OMputEndError| (((|Void|) $) "\\spad{OMputEndError(dev)} writes an end error token to \\axiom{dev}.")) (|OMputEndBVar| (((|Void|) $) "\\spad{OMputEndBVar(dev)} writes an end bound variable list token to \\axiom{dev}.")) (|OMputEndBind| (((|Void|) $) "\\spad{OMputEndBind(dev)} writes an end binder token to \\axiom{dev}.")) (|OMputEndAttr| (((|Void|) $) "\\spad{OMputEndAttr(dev)} writes an end attribute token to \\axiom{dev}.")) (|OMputEndAtp| (((|Void|) $) "\\spad{OMputEndAtp(dev)} writes an end attribute pair token to \\axiom{dev}.")) (|OMputEndApp| (((|Void|) $) "\\spad{OMputEndApp(dev)} writes an end application token to \\axiom{dev}.")) (|OMputObject| (((|Void|) $) "\\spad{OMputObject(dev)} writes a begin object token to \\axiom{dev}.")) (|OMputError| (((|Void|) $) "\\spad{OMputError(dev)} writes a begin error token to \\axiom{dev}.")) (|OMputBVar| (((|Void|) $) "\\spad{OMputBVar(dev)} writes a begin bound variable list token to \\axiom{dev}.")) (|OMputBind| (((|Void|) $) "\\spad{OMputBind(dev)} writes a begin binder token to \\axiom{dev}.")) (|OMputAttr| (((|Void|) $) "\\spad{OMputAttr(dev)} writes a begin attribute token to \\axiom{dev}.")) (|OMputAtp| (((|Void|) $) "\\spad{OMputAtp(dev)} writes a begin attribute pair token to \\axiom{dev}.")) (|OMputApp| (((|Void|) $) "\\spad{OMputApp(dev)} writes a begin application token to \\axiom{dev}.")) (|OMsetEncoding| (((|Void|) $ (|OpenMathEncoding|)) "\\spad{OMsetEncoding(dev,enc)} sets the encoding used for reading or writing OpenMath objects to or from \\axiom{dev} to \\axiom{enc}.")) (|OMclose| (((|Void|) $) "\\spad{OMclose(dev)} closes \\axiom{dev}, flushing output if necessary.")) (|OMopenString| (($ (|String|) (|OpenMathEncoding|)) "\\spad{OMopenString(s,mode)} opens the string \\axiom{s} for reading or writing OpenMath objects in encoding \\axiom{enc}.")) (|OMopenFile| (($ (|String|) (|String|) (|OpenMathEncoding|)) "\\spad{OMopenFile(f,mode,enc)} opens file \\axiom{f} for reading or writing OpenMath objects (depending on \\axiom{mode} which can be \"r\", \\spad{\"w\"} or \"a\" for read, write and append respectively), in the encoding \\axiom{enc}."))) 
 NIL 
 NIL 
-(-824) 
+(-845) 
 ((|constructor| (NIL "\\spadtype{OpenMathEncoding} is the set of valid OpenMath encodings.")) (|OMencodingBinary| (($) "\\spad{OMencodingBinary()} is the constant for the OpenMath binary encoding.")) (|OMencodingSGML| (($) "\\spad{OMencodingSGML()} is the constant for the deprecated OpenMath SGML encoding.")) (|OMencodingXML| (($) "\\spad{OMencodingXML()} is the constant for the OpenMath \\spad{XML} encoding.")) (|OMencodingUnknown| (($) "\\spad{OMencodingUnknown()} is the constant for unknown encoding types. If this is used on an input device, the encoding will be autodetected. It is invalid to use it on an output device."))) 
 NIL 
 NIL 
-(-825) 
+(-846) 
 ((|constructor| (NIL "\\spadtype{OpenMathErrorKind} represents different kinds of OpenMath errors: specifically parse errors, unknown \\spad{CD} or symbol errors, and read errors.")) (|OMReadError?| (((|Boolean|) $) "\\spad{OMReadError?(u)} tests whether \\spad{u} is an OpenMath read error.")) (|OMUnknownSymbol?| (((|Boolean|) $) "\\spad{OMUnknownSymbol?(u)} tests whether \\spad{u} is an OpenMath unknown symbol error.")) (|OMUnknownCD?| (((|Boolean|) $) "\\spad{OMUnknownCD?(u)} tests whether \\spad{u} is an OpenMath unknown \\spad{CD} error.")) (|OMParseError?| (((|Boolean|) $) "\\spad{OMParseError?(u)} tests whether \\spad{u} is an OpenMath parsing error.")) (|coerce| (($ (|Symbol|)) "\\spad{coerce(u)} creates an OpenMath error object of an appropriate type if \\axiom{u} is one of \\axiom{OMParseError}, \\axiom{OMReadError}, \\axiom{OMUnknownCD} or \\axiom{OMUnknownSymbol}, otherwise it raises a runtime error."))) 
 NIL 
 NIL 
-(-826) 
+(-847) 
 ((|constructor| (NIL "\\spadtype{OpenMathError} is the domain of OpenMath errors.")) (|omError| (($ (|OpenMathErrorKind|) (|List| (|Symbol|))) "\\spad{omError(k,l)} creates an instance of OpenMathError.")) (|errorInfo| (((|List| (|Symbol|)) $) "\\spad{errorInfo(u)} returns information about the error u.")) (|errorKind| (((|OpenMathErrorKind|) $) "\\spad{errorKind(u)} returns the type of error which \\spad{u} represents."))) 
 NIL 
 NIL 
-(-827 R) 
+(-848 R) 
 ((|constructor| (NIL "\\spadtype{ExpressionToOpenMath} provides support for converting objects of type \\spadtype{Expression} into OpenMath."))) 
 NIL 
 NIL 
-(-828 P R) 
+(-849 P R) 
 ((|constructor| (NIL "This constructor creates the \\spadtype{MonogenicLinearOperator} domain which is ``opposite'' in the ring sense to \\spad{P.} That is, as sets \\spad{P = \\spad{$}} but \\spad{a * \\spad{b}} in \\spad{$} is equal to \\spad{b * a} in \\spad{P.}")) (|po| ((|#1| $) "\\spad{po(q)} creates a value in \\spad{P} equal to \\spad{q} in \\spad{$.}")) (|op| (($ |#1|) "\\spad{op(p)} creates a value in \\$ equal to \\spad{p} in \\spad{P.}"))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-227)))) 
-(-829) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-247)))) 
+(-850) 
 ((|constructor| (NIL "\\spadtype{OpenMath} provides operations for exporting an object in OpenMath format.")) (|OMwrite| (((|Void|) (|OpenMathDevice|) $ (|Boolean|)) "\\spad{OMwrite(dev, u, true)} writes the OpenMath form of \\axiom{u} to the OpenMath device \\axiom{dev} as a complete OpenMath object; OMwrite(dev, u, false) writes the object as an OpenMath fragment.") (((|Void|) (|OpenMathDevice|) $) "\\spad{OMwrite(dev, u)} writes the OpenMath form of \\axiom{u} to the OpenMath device \\axiom{dev} as a complete OpenMath object.") (((|String|) $ (|Boolean|)) "\\spad{OMwrite(u, true)} returns the OpenMath \\spad{XML} encoding of \\axiom{u} as a complete OpenMath object; OMwrite(u, false) returns the OpenMath \\spad{XML} encoding of \\axiom{u} as an OpenMath fragment.") (((|String|) $) "\\spad{OMwrite(u)} returns the OpenMath \\spad{XML} encoding of \\axiom{u} as a complete OpenMath object."))) 
 NIL 
 NIL 
-(-830) 
+(-851) 
 ((|constructor| (NIL "\\spadtype{OpenMathPackage} provides some simple utilities to make reading OpenMath objects easier.")) (|OMunhandledSymbol| (((|Exit|) (|String|) (|String|)) "\\spad{OMunhandledSymbol(s,cd)} raises an error if AXIOM reads a symbol which it is unable to handle. Note that this is different from an unexpected symbol.")) (|OMsupportsSymbol?| (((|Boolean|) (|String|) (|String|)) "\\spad{OMsupportsSymbol?(s,cd)} returns \\spad{true} if AXIOM supports symbol \\axiom{s} from \\spad{CD} \\axiom{cd}, \\spad{false} otherwise.")) (|OMsupportsCD?| (((|Boolean|) (|String|)) "\\spad{OMsupportsCD?(cd)} returns \\spad{true} if AXIOM supports \\axiom{cd}, \\spad{false} otherwise.")) (|OMlistSymbols| (((|List| (|String|)) (|String|)) "\\spad{OMlistSymbols(cd)} lists all the symbols in \\axiom{cd}.")) (|OMlistCDs| (((|List| (|String|))) "\\spad{OMlistCDs()} lists all the \\spad{CDs} supported by AXIOM.")) (|OMreadStr| (((|Any|) (|String|)) "\\spad{OMreadStr(f)} reads an OpenMath object from \\axiom{f} and passes it to AXIOM.")) (|OMreadFile| (((|Any|) (|String|)) "\\spad{OMreadFile(f)} reads an OpenMath object from \\axiom{f} and passes it to AXIOM.")) (|OMread| (((|Any|) (|OpenMathDevice|)) "\\spad{OMread(dev)} reads an OpenMath object from \\axiom{dev} and passes it to AXIOM."))) 
 NIL 
 NIL 
-(-831 S) 
+(-852 S) 
 ((|constructor| (NIL "to become an in order iterator")) (|min| ((|#1| $) "\\spad{min(u)} returns the smallest entry in the multiset aggregate u."))) 
-((-4602 . T) (-4592 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4615 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-832) 
+(-853) 
 ((|constructor| (NIL "\\spadtype{OpenMathServerPackage} provides the necessary operations to run AXIOM as an OpenMath server, reading/writing objects to/from a port. Please note the facilities available here are very basic. The idea is that a user calls \\spadignore{e.g.} \\axiom{Omserve(4000,60)} and then another process sends OpenMath objects to port 4000 and reads the result.")) (|OMserve| (((|Void|) (|SingleInteger|) (|SingleInteger|)) "\\spad{OMserve(portnum,timeout)} puts AXIOM into server mode on port number \\axiom{portnum}. The parameter \\axiom{timeout} specifies the \\spad{timeout} period for the connection.")) (|OMsend| (((|Void|) (|OpenMathConnection|) (|Any|)) "\\spad{OMsend(c,u)} attempts to output \\axiom{u} on \\axiom{c} in OpenMath.")) (|OMreceive| (((|Any|) (|OpenMathConnection|)) "\\spad{OMreceive(c)} reads an OpenMath object from connection \\axiom{c} and returns the appropriate AXIOM object."))) 
 NIL 
 NIL 
-(-833 R S) 
+(-854 R S) 
 ((|constructor| (NIL "Lifting of maps to one-point completions.")) (|map| (((|OnePointCompletion| |#2|) (|Mapping| |#2| |#1|) (|OnePointCompletion| |#1|) (|OnePointCompletion| |#2|)) "\\spad{map(f, \\spad{r,} i)} lifts \\spad{f} and applies it to \\spad{r,} assuming that f(infinity) = i.") (((|OnePointCompletion| |#2|) (|Mapping| |#2| |#1|) (|OnePointCompletion| |#1|)) "\\spad{map(f, \\spad{r)}} lifts \\spad{f} and applies it to \\spad{r,} assuming that f(infinity) = infinity."))) 
 NIL 
 NIL 
-(-834 R) 
+(-855 R) 
 ((|constructor| (NIL "Completion with infinity. Adjunction of a complex infinity to a set.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(x)} returns \\spad{x} as a finite rational number if it is one, \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(x)} returns \\spad{x} as a finite rational number. Error: if \\spad{x} is not a rational number.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(x)} tests if \\spad{x} is a finite rational number.")) (|infinite?| (((|Boolean|) $) "\\spad{infinite?(x)} tests if \\spad{x} is infinite.")) (|finite?| (((|Boolean|) $) "\\spad{finite?(x)} tests if \\spad{x} is finite.")) (|infinity| (($) "\\spad{infinity()} returns infinity."))) 
-((-4599 |has| |#1| (-846))) 
-((|HasCategory| |#1| (QUOTE (-846))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-554))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-846)))) (|HasCategory| |#1| (QUOTE (-21))) (-1841 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-846))))) 
-(-835 R) 
+((-4622 |has| |#1| (-867))) 
+((|HasCategory| |#1| (QUOTE (-867))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-574))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-867)))) (|HasCategory| |#1| (QUOTE (-21))) (-3836 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-867))))) 
+(-856 R) 
 ((|constructor| (NIL "Algebra of ADDITIVE operators over a ring."))) 
-((-4597 |has| |#1| (-174)) (-4596 |has| |#1| (-174)) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151)))) 
-(-836) 
+((-4620 |has| |#1| (-194)) (-4619 |has| |#1| (-194)) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171)))) 
+(-857) 
 ((|constructor| (NIL "This package exports tools to create AXIOM Library information databases.")) (|getDatabase| (((|Database| (|IndexCard|)) (|String|)) "\\spad{getDatabase(\"char\")} returns a list of appropriate entries in the browser database. The legal values for \\spad{\"char\"} are \"o\" (operations), \\spad{\"k\"} (constructors), \\spad{\"d\"} (domains), \\spad{\"c\"} (categories) or \\spad{\"p\"} (packages)."))) 
 NIL 
 NIL 
-(-837) 
+(-858) 
 ((|constructor| (NIL "\\axiomType{NumericalOptimizationCategory} is the \\axiom{category} for describing the set of Numerical Optimization \\axiom{domains} with \\axiomFun{measure} and \\axiomFun{optimize}.")) (|numericalOptimization| (((|Result|) (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) "\\spad{numericalOptimization(args)} performs the optimization of the function given the strategy or method returned by \\axiomFun{measure}.") (((|Result|) (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) "\\spad{numericalOptimization(args)} performs the optimization of the function given the strategy or method returned by \\axiomFun{measure}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|))) (|RoutinesTable|) (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) "\\spad{measure(R,args)} calculates an estimate of the ability of a particular method to solve an optimization problem. \\blankline This method may be either a specific NAG routine or a strategy (such as transforming the function from one which is difficult to one which is easier to solve). \\blankline It will call whichever agents are needed to perform analysis on the problem in order to calculate the measure. There is a parameter, labelled \\axiom{sofar}, which would contain the best compatibility found so far.") (((|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|))) (|RoutinesTable|) (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) "\\spad{measure(R,args)} calculates an estimate of the ability of a particular method to solve an optimization problem. \\blankline This method may be either a specific NAG routine or a strategy (such as transforming the function from one which is difficult to one which is easier to solve). \\blankline It will call whichever agents are needed to perform analysis on the problem in order to calculate the measure. There is a parameter, labelled \\axiom{sofar}, which would contain the best compatibility found so far."))) 
 NIL 
 NIL 
-(-838) 
+(-859) 
 ((|constructor| (NIL "\\axiomType{AnnaNumericalOptimizationPackage} is a \\axiom{package} of functions for the \\axiomType{NumericalOptimizationCategory} with \\axiom{measure} and \\axiom{optimize}.")) (|goodnessOfFit| (((|Result|) (|List| (|Expression| (|Float|))) (|List| (|Float|))) "\\spad{goodnessOfFit(lf,start)} is a top level ANNA function to check to goodness of fit of a least squares model \\spadignore{i.e.} the minimization of a set of functions, \\axiom{lf}, of one or more variables without constraints. \\blankline The parameter \\axiom{start} is a list of the initial guesses of the values of the variables. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}. It then calls the numerical routine \\axiomType{E04YCF} to get estimates of the variance-covariance matrix of the regression coefficients of the least-squares problem. \\blankline It thus returns both the results of the optimization and the variance-covariance calculation. goodnessOfFit(lf,start) is a top level function to iterate over the \\axiom{domains} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}. It then checks the goodness of fit of the least squares model.") (((|Result|) (|NumericalOptimizationProblem|)) "\\spad{goodnessOfFit(prob)} is a top level ANNA function to check to goodness of fit of a least squares model as defined within \\axiom{prob}. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}. It then calls the numerical routine \\axiomType{E04YCF} to get estimates of the variance-covariance matrix of the regression coefficients of the least-squares problem. \\blankline It thus returns both the results of the optimization and the variance-covariance calculation.")) (|optimize| (((|Result|) (|List| (|Expression| (|Float|))) (|List| (|Float|))) "\\spad{optimize(lf,start)} is a top level ANNA function to minimize a set of functions, \\axiom{lf}, of one or more variables without constraints \\spadignore{i.e.} a least-squares problem. \\blankline The parameter \\axiom{start} is a list of the initial guesses of the values of the variables. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Float|))) "\\spad{optimize(f,start)} is a top level ANNA function to minimize a function, \\axiom{f}, of one or more variables without constraints. \\blankline The parameter \\axiom{start} is a list of the initial guesses of the values of the variables. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Float|)) (|List| (|OrderedCompletion| (|Float|))) (|List| (|OrderedCompletion| (|Float|)))) "\\spad{optimize(f,start,lower,upper)} is a top level ANNA function to minimize a function, \\axiom{f}, of one or more variables with simple constraints. The bounds on the variables are defined in \\axiom{lower} and \\axiom{upper}. \\blankline The parameter \\axiom{start} is a list of the initial guesses of the values of the variables. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Float|)) (|List| (|OrderedCompletion| (|Float|))) (|List| (|Expression| (|Float|))) (|List| (|OrderedCompletion| (|Float|)))) "\\spad{optimize(f,start,lower,cons,upper)} is a top level ANNA function to minimize a function, \\axiom{f}, of one or more variables with the given constraints. \\blankline These constraints may be simple constraints on the variables in which case \\axiom{cons} would be an empty list and the bounds on those variables defined in \\axiom{lower} and \\axiom{upper}, or a mixture of simple, linear and non-linear constraints, where \\axiom{cons} contains the linear and non-linear constraints and the bounds on these are added to \\axiom{upper} and \\axiom{lower}. \\blankline The parameter \\axiom{start} is a list of the initial guesses of the values of the variables. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}.") (((|Result|) (|NumericalOptimizationProblem|)) "\\spad{optimize(prob)} is a top level ANNA function to minimize a function or a set of functions with any constraints as defined within \\axiom{prob}. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}.") (((|Result|) (|NumericalOptimizationProblem|) (|RoutinesTable|)) "\\spad{optimize(prob,routines)} is a top level ANNA function to minimize a function or a set of functions with any constraints as defined within \\axiom{prob}. \\blankline It iterates over the \\axiom{domains} listed in \\axiom{routines} of \\axiomType{NumericalOptimizationCategory} to get the name and other relevant information of the best \\axiom{measure} and then optimize the function on that \\axiom{domain}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|)))) (|NumericalOptimizationProblem|) (|RoutinesTable|)) "\\spad{measure(prob,R)} is a top level ANNA function for identifying the most appropriate numerical routine from those in the routines table provided for solving the numerical optimization problem defined by \\axiom{prob} by checking various attributes of the functions and calculating a measure of compatibility of each routine to these attributes. \\blankline It calls each \\axiom{domain} listed in \\axiom{R} of \\axiom{category} \\axiomType{NumericalOptimizationCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information.") (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|)))) (|NumericalOptimizationProblem|)) "\\spad{measure(prob)} is a top level ANNA function for identifying the most appropriate numerical routine from those in the routines table provided for solving the numerical optimization problem defined by \\axiom{prob} by checking various attributes of the functions and calculating a measure of compatibility of each routine to these attributes. \\blankline It calls each \\axiom{domain} of \\axiom{category} \\axiomType{NumericalOptimizationCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information."))) 
 NIL 
 NIL 
-(-839) 
+(-860) 
 ((|constructor| (NIL "\\axiomType{NumericalOptimizationProblem} is a \\axiom{domain} for the representation of Numerical Optimization problems for use by ANNA. \\blankline The representation is a Union of two record types - one for otimization of a single function of one or more variables: \\blankline \\axiomType{Record}(\\br fn:\\axiomType{Expression DoubleFloat},\\br init:\\axiomType{List DoubleFloat},\\br lb:\\axiomType{List OrderedCompletion DoubleFloat},\\br cf:\\axiomType{List Expression DoubleFloat},\\br ub:\\axiomType{List OrderedCompletion DoubleFloat}) \\blankline and one for least-squares problems \\spadignore{i.e.} optimization of a set of observations of a data set: \\blankline \\axiomType{Record}(lfn:\\axiomType{List Expression DoubleFloat},\\br init:\\axiomType{List DoubleFloat}).")) (|retract| (((|Union| (|:| |noa| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|:| |lsa| (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|)))))) $) "\\spad{retract(x)} is not documented")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(x)} is not documented") (($ (|Union| (|:| |noa| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|:| |lsa| (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))))) "\\spad{coerce(x)} is not documented") (($ (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) "\\spad{coerce(x)} is not documented") (($ (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) "\\spad{coerce(x)} is not documented"))) 
 NIL 
 NIL 
-(-840 R S) 
+(-861 R S) 
 ((|constructor| (NIL "Lifting of maps to ordered completions.")) (|map| (((|OrderedCompletion| |#2|) (|Mapping| |#2| |#1|) (|OrderedCompletion| |#1|) (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|)) "\\spad{map(f, \\spad{r,} \\spad{p,} \\spad{m)}} lifts \\spad{f} and applies it to \\spad{r,} assuming that f(plusInfinity) = \\spad{p} and that f(minusInfinity) = \\spad{m.}") (((|OrderedCompletion| |#2|) (|Mapping| |#2| |#1|) (|OrderedCompletion| |#1|)) "\\spad{map(f, \\spad{r)}} lifts \\spad{f} and applies it to \\spad{r,} assuming that f(plusInfinity) = plusInfinity and that f(minusInfinity) = minusInfinity."))) 
 NIL 
 NIL 
-(-841 R) 
+(-862 R) 
 ((|constructor| (NIL "Completion with + and - infinity. Adjunction of two real infinites quantities to a set.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(x)} returns \\spad{x} as a finite rational number if it is one and \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(x)} returns \\spad{x} as a finite rational number. Error: if \\spad{x} cannot be so converted.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(x)} tests if \\spad{x} is a finite rational number.")) (|whatInfinity| (((|SingleInteger|) $) "\\spad{whatInfinity(x)} returns 0 if \\spad{x} is finite, 1 if \\spad{x} is +infinity, and \\spad{-1} if \\spad{x} is -infinity.")) (|infinite?| (((|Boolean|) $) "\\spad{infinite?(x)} tests if \\spad{x} is +infinity or -infinity.")) (|finite?| (((|Boolean|) $) "\\spad{finite?(x)} tests if \\spad{x} is finite.")) (|minusInfinity| (($) "\\spad{minusInfinity()} returns -infinity.")) (|plusInfinity| (($) "\\spad{plusInfinity()} returns +infinity."))) 
-((-4599 |has| |#1| (-846))) 
-((|HasCategory| |#1| (QUOTE (-846))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-554))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-846)))) (|HasCategory| |#1| (QUOTE (-21))) (-1841 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-846))))) 
-(-842) 
+((-4622 |has| |#1| (-867))) 
+((|HasCategory| |#1| (QUOTE (-867))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-574))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-867)))) (|HasCategory| |#1| (QUOTE (-21))) (-3836 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-867))))) 
+(-863) 
 ((|constructor| (NIL "Ordered finite sets."))) 
 NIL 
 NIL 
-(-843 -3465 S) 
+(-864 -3832 S) 
 ((|constructor| (NIL "This package provides ordering functions on vectors which are suitable parameters for OrderedDirectProduct.")) (|reverseLex| (((|Boolean|) (|Vector| |#2|) (|Vector| |#2|)) "\\spad{reverseLex(v1,v2)} return \\spad{true} if the vector \\spad{v1} is less than the vector \\spad{v2} in the ordering which is total degree refined by the reverse lexicographic ordering.")) (|totalLex| (((|Boolean|) (|Vector| |#2|) (|Vector| |#2|)) "\\spad{totalLex(v1,v2)} return \\spad{true} if the vector \\spad{v1} is less than the vector \\spad{v2} in the ordering which is total degree refined by lexicographic ordering.")) (|pureLex| (((|Boolean|) (|Vector| |#2|) (|Vector| |#2|)) "\\spad{pureLex(v1,v2)} return \\spad{true} if the vector \\spad{v1} is less than the vector \\spad{v2} in the lexicographic ordering."))) 
 NIL 
 NIL 
-(-844) 
+(-865) 
 ((|constructor| (NIL "Ordered sets which are also monoids, such that multiplication preserves the ordering. \\blankline Axioms\\br \\tab{5}\\spad{x < \\spad{y} \\spad{=>} \\spad{x*z} < y*z}\\br \\tab{5}\\spad{x < \\spad{y} \\spad{=>} \\spad{z*x} < z*y}"))) 
 NIL 
 NIL 
-(-845 S) 
+(-866 S) 
 ((|constructor| (NIL "Ordered sets which are also rings, that is, domains where the ring operations are compatible with the ordering. \\blankline Axiom\\br \\tab{5}\\spad{0<a and \\spad{b<c} \\spad{=>} ab< ac}")) (|abs| (($ $) "\\spad{abs(x)} returns the absolute value of \\spad{x.}")) (|sign| (((|Integer|) $) "\\spad{sign(x)} is 1 if \\spad{x} is positive, \\spad{-1} if \\spad{x} is negative, 0 if \\spad{x} equals 0.")) (|negative?| (((|Boolean|) $) "\\spad{negative?(x)} tests whether \\spad{x} is strictly less than 0.")) (|positive?| (((|Boolean|) $) "\\spad{positive?(x)} tests whether \\spad{x} is strictly greater than 0."))) 
 NIL 
 NIL 
-(-846) 
+(-867) 
 ((|constructor| (NIL "Ordered sets which are also rings, that is, domains where the ring operations are compatible with the ordering. \\blankline Axiom\\br \\tab{5}\\spad{0<a and \\spad{b<c} \\spad{=>} ab< ac}")) (|abs| (($ $) "\\spad{abs(x)} returns the absolute value of \\spad{x.}")) (|sign| (((|Integer|) $) "\\spad{sign(x)} is 1 if \\spad{x} is positive, \\spad{-1} if \\spad{x} is negative, 0 if \\spad{x} equals 0.")) (|negative?| (((|Boolean|) $) "\\spad{negative?(x)} tests whether \\spad{x} is strictly less than 0.")) (|positive?| (((|Boolean|) $) "\\spad{positive?(x)} tests whether \\spad{x} is strictly greater than 0."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-847 S) 
+(-868 S) 
 ((|constructor| (NIL "The class of totally ordered sets, that is, sets such that for each pair of elements \\spad{(a,b)} exactly one of the following relations holds \\spad{a<b or a=b or b<a} and the relation is transitive, that is, \\spad{a<b and \\spad{b<c} \\spad{=>} a<c}.")) (|min| (($ $ $) "\\spad{min(x,y)} returns the minimum of \\spad{x} and \\spad{y} relative to \"<\".")) (|max| (($ $ $) "\\spad{max(x,y)} returns the maximum of \\spad{x} and \\spad{y} relative to \"<\".")) (<= (((|Boolean|) $ $) "\\spad{x \\spad{<=} \\spad{y}} is a less than or equal test.")) (>= (((|Boolean|) $ $) "\\spad{x \\spad{>=} \\spad{y}} is a greater than or equal test.")) (> (((|Boolean|) $ $) "\\spad{x > \\spad{y}} is a greater than test.")) (< (((|Boolean|) $ $) "\\spad{x < \\spad{y}} is a strict total ordering on the elements of the set."))) 
 NIL 
 NIL 
-(-848) 
+(-869) 
 ((|constructor| (NIL "The class of totally ordered sets, that is, sets such that for each pair of elements \\spad{(a,b)} exactly one of the following relations holds \\spad{a<b or a=b or b<a} and the relation is transitive, that is, \\spad{a<b and \\spad{b<c} \\spad{=>} a<c}.")) (|min| (($ $ $) "\\spad{min(x,y)} returns the minimum of \\spad{x} and \\spad{y} relative to \"<\".")) (|max| (($ $ $) "\\spad{max(x,y)} returns the maximum of \\spad{x} and \\spad{y} relative to \"<\".")) (<= (((|Boolean|) $ $) "\\spad{x \\spad{<=} \\spad{y}} is a less than or equal test.")) (>= (((|Boolean|) $ $) "\\spad{x \\spad{>=} \\spad{y}} is a greater than or equal test.")) (> (((|Boolean|) $ $) "\\spad{x > \\spad{y}} is a greater than test.")) (< (((|Boolean|) $ $) "\\spad{x < \\spad{y}} is a strict total ordering on the elements of the set."))) 
 NIL 
 NIL 
-(-849 S R) 
+(-870 S R) 
 ((|constructor| (NIL "This is the category of univariate skew polynomials over an Ore coefficient ring. The multiplication is given by \\spad{x a = \\sigma(a) \\spad{x} + \\delta a}. This category is an evolution of the types MonogenicLinearOperator, OppositeMonogenicLinearOperator, and NonCommutativeOperatorDivision")) (|leftLcm| (($ $ $) "\\spad{leftLcm(a,b)} computes the value \\spad{m} of lowest degree such that \\spad{m = aa*a = bb*b} for some values \\spad{aa} and \\spad{bb}. The value \\spad{m} is computed using right-division.")) (|rightExtendedGcd| (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{rightExtendedGcd(a,b)} returns \\spad{[c,d]} such that \\spad{g = \\spad{c} * a + \\spad{d} * \\spad{b} = rightGcd(a, b)}.")) (|rightGcd| (($ $ $) "\\spad{rightGcd(a,b)} computes the value \\spad{g} of highest degree such that \\indented{3}{\\spad{a = aa*g}} \\indented{3}{\\spad{b = bb*g}} for some values \\spad{aa} and \\spad{bb}. The value \\spad{g} is computed using right-division.")) (|rightExactQuotient| (((|Union| $ "failed") $ $) "\\spad{rightExactQuotient(a,b)} computes the value \\spad{q}, if it exists such that \\spad{a = q*b}.")) (|rightRemainder| (($ $ $) "\\spad{rightRemainder(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{r} is returned.")) (|rightQuotient| (($ $ $) "\\spad{rightQuotient(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{q} is returned.")) (|rightDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{rightDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``right division''.")) (|rightLcm| (($ $ $) "\\spad{rightLcm(a,b)} computes the value \\spad{m} of lowest degree such that \\spad{m = a*aa = b*bb} for some values \\spad{aa} and \\spad{bb}. The value \\spad{m} is computed using left-division.")) (|leftExtendedGcd| (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{leftExtendedGcd(a,b)} returns \\spad{[c,d]} such that \\spad{g = a * \\spad{c} + \\spad{b} * \\spad{d} = leftGcd(a, b)}.")) (|leftGcd| (($ $ $) "\\spad{leftGcd(a,b)} computes the value \\spad{g} of highest degree such that \\indented{3}{\\spad{a = g*aa}} \\indented{3}{\\spad{b = g*bb}} for some values \\spad{aa} and \\spad{bb}. The value \\spad{g} is computed using left-division.")) (|leftExactQuotient| (((|Union| $ "failed") $ $) "\\spad{leftExactQuotient(a,b)} computes the value \\spad{q}, if it exists, \\indented{1}{such that \\spad{a = b*q}.}")) (|leftRemainder| (($ $ $) "\\spad{leftRemainder(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{r} is returned.")) (|leftQuotient| (($ $ $) "\\spad{leftQuotient(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{q} is returned.")) (|leftDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{leftDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``left division''.")) (|primitivePart| (($ $) "\\spad{primitivePart(l)} returns \\spad{l0} such that \\spad{l = a * \\spad{l0}} for some a in \\spad{R,} and \\spad{content(l0) = 1}.")) (|content| ((|#2| $) "\\spad{content(l)} returns the \\spad{gcd} of all the coefficients of \\spad{l.}")) (|monicRightDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicRightDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``right division''.")) (|monicLeftDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicLeftDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``left division''.")) (|exquo| (((|Union| $ "failed") $ |#2|) "\\spad{exquo(l, a)} returns the exact quotient of \\spad{l} by a, returning \\axiom{\"failed\"} if this is not possible.")) (|apply| ((|#2| $ |#2| |#2|) "\\spad{apply(p, \\spad{c,} \\spad{m)}} returns \\spad{p(m)} where the action is given by \\spad{x \\spad{m} = \\spad{c} sigma(m) + delta(m)}.")) (|coefficients| (((|List| |#2|) $) "\\spad{coefficients(l)} returns the list of all the nonzero coefficients of \\spad{l.}")) (|monomial| (($ |#2| (|NonNegativeInteger|)) "\\spad{monomial(c,k)} produces \\spad{c} times the \\spad{k}-th power of the generating operator, \\spad{monomial(1,1)}.")) (|coefficient| ((|#2| $ (|NonNegativeInteger|)) "\\spad{coefficient(l,k)} is \\spad{a(k)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|reductum| (($ $) "\\spad{reductum(l)} is \\spad{l - monomial(a(n),n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|leadingCoefficient| ((|#2| $) "\\spad{leadingCoefficient(l)} is \\spad{a(n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|minimumDegree| (((|NonNegativeInteger|) $) "\\spad{minimumDegree(l)} is the smallest \\spad{k} such that \\spad{a(k) \\spad{^=} 0} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(l)} is \\spad{n} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174)))) 
-(-850 R) 
+((|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194)))) 
+(-871 R) 
 ((|constructor| (NIL "This is the category of univariate skew polynomials over an Ore coefficient ring. The multiplication is given by \\spad{x a = \\sigma(a) \\spad{x} + \\delta a}. This category is an evolution of the types MonogenicLinearOperator, OppositeMonogenicLinearOperator, and NonCommutativeOperatorDivision")) (|leftLcm| (($ $ $) "\\spad{leftLcm(a,b)} computes the value \\spad{m} of lowest degree such that \\spad{m = aa*a = bb*b} for some values \\spad{aa} and \\spad{bb}. The value \\spad{m} is computed using right-division.")) (|rightExtendedGcd| (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{rightExtendedGcd(a,b)} returns \\spad{[c,d]} such that \\spad{g = \\spad{c} * a + \\spad{d} * \\spad{b} = rightGcd(a, b)}.")) (|rightGcd| (($ $ $) "\\spad{rightGcd(a,b)} computes the value \\spad{g} of highest degree such that \\indented{3}{\\spad{a = aa*g}} \\indented{3}{\\spad{b = bb*g}} for some values \\spad{aa} and \\spad{bb}. The value \\spad{g} is computed using right-division.")) (|rightExactQuotient| (((|Union| $ "failed") $ $) "\\spad{rightExactQuotient(a,b)} computes the value \\spad{q}, if it exists such that \\spad{a = q*b}.")) (|rightRemainder| (($ $ $) "\\spad{rightRemainder(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{r} is returned.")) (|rightQuotient| (($ $ $) "\\spad{rightQuotient(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{q} is returned.")) (|rightDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{rightDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``right division''.")) (|rightLcm| (($ $ $) "\\spad{rightLcm(a,b)} computes the value \\spad{m} of lowest degree such that \\spad{m = a*aa = b*bb} for some values \\spad{aa} and \\spad{bb}. The value \\spad{m} is computed using left-division.")) (|leftExtendedGcd| (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{leftExtendedGcd(a,b)} returns \\spad{[c,d]} such that \\spad{g = a * \\spad{c} + \\spad{b} * \\spad{d} = leftGcd(a, b)}.")) (|leftGcd| (($ $ $) "\\spad{leftGcd(a,b)} computes the value \\spad{g} of highest degree such that \\indented{3}{\\spad{a = g*aa}} \\indented{3}{\\spad{b = g*bb}} for some values \\spad{aa} and \\spad{bb}. The value \\spad{g} is computed using left-division.")) (|leftExactQuotient| (((|Union| $ "failed") $ $) "\\spad{leftExactQuotient(a,b)} computes the value \\spad{q}, if it exists, \\indented{1}{such that \\spad{a = b*q}.}")) (|leftRemainder| (($ $ $) "\\spad{leftRemainder(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{r} is returned.")) (|leftQuotient| (($ $ $) "\\spad{leftQuotient(a,b)} computes the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{q} is returned.")) (|leftDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{leftDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``left division''.")) (|primitivePart| (($ $) "\\spad{primitivePart(l)} returns \\spad{l0} such that \\spad{l = a * \\spad{l0}} for some a in \\spad{R,} and \\spad{content(l0) = 1}.")) (|content| ((|#1| $) "\\spad{content(l)} returns the \\spad{gcd} of all the coefficients of \\spad{l.}")) (|monicRightDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicRightDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``right division''.")) (|monicLeftDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicLeftDivide(a,b)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``left division''.")) (|exquo| (((|Union| $ "failed") $ |#1|) "\\spad{exquo(l, a)} returns the exact quotient of \\spad{l} by a, returning \\axiom{\"failed\"} if this is not possible.")) (|apply| ((|#1| $ |#1| |#1|) "\\spad{apply(p, \\spad{c,} \\spad{m)}} returns \\spad{p(m)} where the action is given by \\spad{x \\spad{m} = \\spad{c} sigma(m) + delta(m)}.")) (|coefficients| (((|List| |#1|) $) "\\spad{coefficients(l)} returns the list of all the nonzero coefficients of \\spad{l.}")) (|monomial| (($ |#1| (|NonNegativeInteger|)) "\\spad{monomial(c,k)} produces \\spad{c} times the \\spad{k}-th power of the generating operator, \\spad{monomial(1,1)}.")) (|coefficient| ((|#1| $ (|NonNegativeInteger|)) "\\spad{coefficient(l,k)} is \\spad{a(k)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|reductum| (($ $) "\\spad{reductum(l)} is \\spad{l - monomial(a(n),n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(l)} is \\spad{a(n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|minimumDegree| (((|NonNegativeInteger|) $) "\\spad{minimumDegree(l)} is the smallest \\spad{k} such that \\spad{a(k) \\spad{^=} 0} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(l)} is \\spad{n} if \\indented{2}{\\spad{l = sum(monomial(a(i),i), \\spad{i} = 0..n)}.}"))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-851 R C) 
+(-872 R C) 
 ((|constructor| (NIL "\\spad{UnivariateSkewPolynomialCategoryOps} provides products and divisions of univariate skew polynomials.")) (|rightDivide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2| (|Automorphism| |#1|)) "\\spad{rightDivide(a, \\spad{b,} sigma)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``right division''. \\spad{\\sigma} is the morphism to use.")) (|leftDivide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2| (|Automorphism| |#1|)) "\\spad{leftDivide(a, \\spad{b,} sigma)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``left division''. \\spad{\\sigma} is the morphism to use.")) (|monicRightDivide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2| (|Automorphism| |#1|)) "\\spad{monicRightDivide(a, \\spad{b,} sigma)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{q*b} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``right division''. \\spad{\\sigma} is the morphism to use.")) (|monicLeftDivide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2| (|Automorphism| |#1|)) "\\spad{monicLeftDivide(a, \\spad{b,} sigma)} returns the pair \\spad{[q,r]} such that \\spad{a = \\spad{b*q} + \\spad{r}} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``left division''. \\spad{\\sigma} is the morphism to use.")) (|apply| ((|#1| |#2| |#1| |#1| (|Automorphism| |#1|) (|Mapping| |#1| |#1|)) "\\spad{apply(p, \\spad{c,} \\spad{m,} sigma, delta)} returns \\spad{p(m)} where the action is given by \\spad{x \\spad{m} = \\spad{c} sigma(m) + delta(m)}.")) (|times| ((|#2| |#2| |#2| (|Automorphism| |#1|) (|Mapping| |#1| |#1|)) "\\spad{times(p, \\spad{q,} sigma, delta)} returns \\spad{p * \\spad{q}.} \\spad{\\sigma} and \\spad{\\delta} are the maps to use."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) 
-(-852 R |sigma| -4363) 
+((|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) 
+(-873 R |sigma| -2026) 
 ((|constructor| (NIL "This is the domain of sparse univariate skew polynomials over an Ore coefficient field. The multiplication is given by \\spad{x a = \\sigma(a) \\spad{x} + \\delta a}.")) (|outputForm| (((|OutputForm|) $ (|OutputForm|)) "\\spad{outputForm(p, \\spad{x)}} returns the output form of \\spad{p} using \\spad{x} for the otherwise anonymous variable."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-853 |x| R |sigma| -4363) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-874 |x| R |sigma| -2026) 
 ((|constructor| (NIL "This is the domain of univariate skew polynomials over an Ore coefficient field in a named variable. The multiplication is given by \\spad{x a = \\sigma(a) \\spad{x} + \\delta a}.")) (|coerce| (($ (|Variable| |#1|)) "\\spad{coerce(x)} returns \\spad{x} as a skew-polynomial."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-368)))) 
-(-854 R) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-388)))) 
+(-875 R) 
 ((|constructor| (NIL "This package provides orthogonal polynomials as functions on a ring.")) (|legendreP| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{legendreP(n,x)} is the \\spad{n}-th Legendre polynomial, \\spad{P[n](x)}. These are defined by \\spad{1/sqrt(1-2*x*t+t**2) = sum(P[n](x)*t**n, \\spad{n} = 0..)}.")) (|laguerreL| ((|#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#1|) "\\spad{laguerreL(m,n,x)} is the associated Laguerre polynomial, \\spad{L<m>[n](x)}. This is the \\spad{m}-th derivative of \\spad{L[n](x)}.") ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{laguerreL(n,x)} is the \\spad{n}-th Laguerre polynomial, \\spad{L[n](x)}. These are defined by \\spad{exp(-t*x/(1-t))/(1-t) = sum(L[n](x)*t**n/n!, \\spad{n} = 0..)}.")) (|hermiteH| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{hermiteH(n,x)} is the \\spad{n}-th Hermite polynomial, \\spad{H[n](x)}. These are defined by \\spad{exp(2*t*x-t**2) = sum(H[n](x)*t**n/n!, \\spad{n} = 0..)}.")) (|chebyshevU| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{chebyshevU(n,x)} is the \\spad{n}-th Chebyshev polynomial of the second kind, \\spad{U[n](x)}. These are defined by \\spad{1/(1-2*t*x+t**2) = sum(T[n](x) *t**n, \\spad{n} = 0..)}.")) (|chebyshevT| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{chebyshevT(n,x)} is the \\spad{n}-th Chebyshev polynomial of the first kind, \\spad{T[n](x)}. These are defined by \\spad{(1-t*x)/(1-2*t*x+t**2) = sum(T[n](x) *t**n, \\spad{n} = 0..)}."))) 
 NIL 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) 
-(-855) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) 
+(-876) 
 ((|constructor| (NIL "A domain used in order to take the free R-module on the Integers I. This is actually the forgetful functor from OrderedRings to OrderedSets applied to \\spad{I}")) (|value| (((|Integer|) $) "\\spad{value(x)} returns the integer associated with \\spad{x}")) (|coerce| (($ (|Integer|)) "\\spad{coerce(i)} returns the element corresponding to \\spad{i}"))) 
 NIL 
 NIL 
-(-856) 
+(-877) 
 ((|constructor| (NIL "This domain is used to create and manipulate mathematical expressions for output. It is intended to provide an insulating layer between the expression rendering software (\\spadignore{e.g.} TeX, or Script) and the output coercions in the various domains.")) (SEGMENT (($ $) "\\spad{SEGMENT(x)} creates the prefix form: \\spad{x..}.") (($ $ $) "\\spad{SEGMENT(x,y)} creates the infix form: \\spad{x..y}.")) (|not| (($ $) "\\spad{not \\spad{f}} creates the equivalent prefix form.")) (|or| (($ $ $) "\\spad{f or \\spad{g}} creates the equivalent infix form.")) (|and| (($ $ $) "\\spad{f and \\spad{g}} creates the equivalent infix form.")) (|exquo| (($ $ $) "\\spad{exquo(f,g)} creates the equivalent infix form.")) (|quo| (($ $ $) "\\spad{f quo \\spad{g}} creates the equivalent infix form.")) (|rem| (($ $ $) "\\spad{f rem \\spad{g}} creates the equivalent infix form.")) (|div| (($ $ $) "\\spad{f div \\spad{g}} creates the equivalent infix form.")) (** (($ $ $) "\\spad{f \\spad{**} \\spad{g}} creates the equivalent infix form.")) (/ (($ $ $) "\\spad{f / \\spad{g}} creates the equivalent infix form.")) (* (($ $ $) "\\spad{f * \\spad{g}} creates the equivalent infix form.")) (- (($ $) "\\spad{- \\spad{f}} creates the equivalent prefix form.") (($ $ $) "\\spad{f - \\spad{g}} creates the equivalent infix form.")) (+ (($ $ $) "\\spad{f + \\spad{g}} creates the equivalent infix form.")) (>= (($ $ $) "\\spad{f \\spad{>=} \\spad{g}} creates the equivalent infix form.")) (<= (($ $ $) "\\spad{f \\spad{<=} \\spad{g}} creates the equivalent infix form.")) (> (($ $ $) "\\spad{f > \\spad{g}} creates the equivalent infix form.")) (< (($ $ $) "\\spad{f < \\spad{g}} creates the equivalent infix form.")) (^= (($ $ $) "\\spad{f \\spad{^=} \\spad{g}} creates the equivalent infix form.")) (= (($ $ $) "\\spad{f = \\spad{g}} creates the equivalent infix form.")) (|blankSeparate| (($ (|List| $)) "\\spad{blankSeparate(l)} creates the form separating the elements of \\spad{l} by blanks.")) (|semicolonSeparate| (($ (|List| $)) "\\spad{semicolonSeparate(l)} creates the form separating the elements of \\spad{l} by semicolons.")) (|commaSeparate| (($ (|List| $)) "\\spad{commaSeparate(l)} creates the form separating the elements of \\spad{l} by commas.")) (|pile| (($ (|List| $)) "\\spad{pile(l)} creates the form consisting of the elements of \\spad{l} which displays as a pile, \\spadignore{i.e.} the elements begin on a new line and are indented right to the same margin.")) (|paren| (($ (|List| $)) "\\spad{paren(lf)} creates the form separating the elements of \\spad{lf} by commas and encloses the result in parentheses.") (($ $) "\\spad{paren(f)} creates the form enclosing \\spad{f} in parentheses.")) (|bracket| (($ (|List| $)) "\\spad{bracket(lf)} creates the form separating the elements of \\spad{lf} by commas and encloses the result in square brackets.") (($ $) "\\spad{bracket(f)} creates the form enclosing \\spad{f} in square brackets.")) (|brace| (($ (|List| $)) "\\spad{brace(lf)} creates the form separating the elements of \\spad{lf} by commas and encloses the result in curly brackets.") (($ $) "\\spad{brace(f)} creates the form enclosing \\spad{f} in braces (curly brackets).")) (|int| (($ $ $ $) "\\spad{int(expr,lowerlimit,upperlimit)} creates the form prefixing \\spad{expr} by an integral sign with both a \\spad{lowerlimit} and upperlimit.") (($ $ $) "\\spad{int(expr,lowerlimit)} creates the form prefixing \\spad{expr} by an integral sign with a lowerlimit.") (($ $) "\\spad{int(expr)} creates the form prefixing \\spad{expr} with an integral sign.")) (|prod| (($ $ $ $) "\\spad{prod(expr,lowerlimit,upperlimit)} creates the form prefixing \\spad{expr} by a capital \\spad{pi} with both a \\spad{lowerlimit} and upperlimit.") (($ $ $) "\\spad{prod(expr,lowerlimit)} creates the form prefixing \\spad{expr} by a capital \\spad{pi} with a lowerlimit.") (($ $) "\\spad{prod(expr)} creates the form prefixing \\spad{expr} by a capital pi.")) (|sum| (($ $ $ $) "\\spad{sum(expr,lowerlimit,upperlimit)} creates the form prefixing \\spad{expr} by a capital sigma with both a \\spad{lowerlimit} and upperlimit.") (($ $ $) "\\spad{sum(expr,lowerlimit)} creates the form prefixing \\spad{expr} by a capital sigma with a lowerlimit.") (($ $) "\\spad{sum(expr)} creates the form prefixing \\spad{expr} by a capital sigma.")) (|overlabel| (($ $ $) "\\spad{overlabel(x,f)} creates the form \\spad{f} with \\spad{\"x} overbar\" over the top.")) (|overbar| (($ $) "\\spad{overbar(f)} creates the form \\spad{f} with an overbar.")) (|prime| (($ $ (|NonNegativeInteger|)) "\\spad{prime(f,n)} creates the form \\spad{f} followed by \\spad{n} primes.") (($ $) "\\spad{prime(f)} creates the form \\spad{f} followed by a suffix prime (single quote).")) (|dot| (($ $ (|NonNegativeInteger|)) "\\spad{dot(f,n)} creates the form \\spad{f} with \\spad{n} dots overhead.") (($ $) "\\spad{dot(f)} creates the form with a one dot overhead.")) (|quote| (($ $) "\\spad{quote(f)} creates the form \\spad{f} with a prefix quote.")) (|supersub| (($ $ (|List| $)) "\\spad{supersub(a,[sub1,super1,sub2,super2,...])} creates a form with each subscript aligned under each superscript.")) (|scripts| (($ $ (|List| $)) "\\spad{scripts(f, [sub, super, presuper, presub])} \\indented{1}{creates a form for \\spad{f} with scripts on all 4 corners.}")) (|presuper| (($ $ $) "\\spad{presuper(f,n)} creates a form for \\spad{f} presuperscripted by \\spad{n.}")) (|presub| (($ $ $) "\\spad{presub(f,n)} creates a form for \\spad{f} presubscripted by \\spad{n.}")) (|super| (($ $ $) "\\spad{super(f,n)} creates a form for \\spad{f} superscripted by \\spad{n.}")) (|sub| (($ $ $) "\\spad{sub(f,n)} creates a form for \\spad{f} subscripted by \\spad{n.}")) (|binomial| (($ $ $) "\\spad{binomial(n,m)} creates a form for the binomial coefficient of \\spad{n} and \\spad{m.}")) (|differentiate| (($ $ (|NonNegativeInteger|)) "\\spad{differentiate(f,n)} creates a form for the \\spad{n}th derivative of \\spad{f,} \\spadignore{e.g.} \\spad{f'}, \\spad{f''}, \\spad{f'''}, \\spad{\"f} super \\spad{iv}\".")) (|rarrow| (($ $ $) "\\spad{rarrow(f,g)} creates a form for the mapping \\spad{f \\spad{->} \\spad{g}.}")) (|assign| (($ $ $) "\\spad{assign(f,g)} creates a form for the assignment \\spad{f \\spad{:=} \\spad{g}.}")) (|slash| (($ $ $) "\\spad{slash(f,g)} creates a form for the horizontal fraction of \\spad{f} over \\spad{g.}")) (|over| (($ $ $) "\\spad{over(f,g)} creates a form for the vertical fraction of \\spad{f} over \\spad{g.}")) (|root| (($ $ $) "\\spad{root(f,n)} creates a form for the \\spad{n}th root of form \\spad{f.}") (($ $) "\\spad{root(f)} creates a form for the square root of form \\spad{f.}")) (|zag| (($ $ $) "\\spad{zag(f,g)} creates a form for the continued fraction form for \\spad{f} over \\spad{g.}")) (|matrix| (($ (|List| (|List| $))) "\\spad{matrix(llf)} makes \\spad{llf} (a list of lists of forms) into a form which displays as a matrix.")) (|box| (($ $) "\\spad{box(f)} encloses \\spad{f} in a box.")) (|label| (($ $ $) "\\spad{label(n,f)} gives form \\spad{f} an equation label \\spad{n.}")) (|string| (($ $) "\\spad{string(f)} creates \\spad{f} with string quotes.")) (|elt| (($ $ (|List| $)) "\\spad{elt(op,l)} creates a form for application of \\spad{op} to list of arguments \\spad{l.}")) (|infix?| (((|Boolean|) $) "\\spad{infix?(op)} returns \\spad{true} if \\spad{op} is an infix operator, and \\spad{false} otherwise.")) (|postfix| (($ $ $) "\\spad{postfix(op, a)} creates a form which prints as: a op.")) (|infix| (($ $ $ $) "\\spad{infix(op, a, \\spad{b)}} creates a form which prints as: a \\spad{op} \\spad{b.}") (($ $ (|List| $)) "\\spad{infix(f,l)} creates a form depicting the n-ary application of infix operation \\spad{f} to a tuple of arguments \\spad{l.}")) (|prefix| (($ $ (|List| $)) "\\spad{prefix(f,l)} creates a form depicting the n-ary prefix application of \\spad{f} to a tuple of arguments given by list \\spad{l.}")) (|vconcat| (($ (|List| $)) "\\spad{vconcat(u)} vertically concatenates all forms in list u.") (($ $ $) "\\spad{vconcat(f,g)} vertically concatenates forms \\spad{f} and \\spad{g.}")) (|hconcat| (($ (|List| $)) "\\spad{hconcat(u)} horizontally concatenates all forms in list u.") (($ $ $) "\\spad{hconcat(f,g)} horizontally concatenate forms \\spad{f} and \\spad{g.}")) (|center| (($ $) "\\spad{center(f)} centers form \\spad{f} in total space.") (($ $ (|Integer|)) "\\spad{center(f,n)} centers form \\spad{f} within space of width \\spad{n.}")) (|right| (($ $) "\\spad{right(f)} right-justifies form \\spad{f} in total space.") (($ $ (|Integer|)) "\\spad{right(f,n)} right-justifies form \\spad{f} within space of width \\spad{n.}")) (|left| (($ $) "\\spad{left(f)} left-justifies form \\spad{f} in total space.") (($ $ (|Integer|)) "\\spad{left(f,n)} left-justifies form \\spad{f} within space of width \\spad{n.}")) (|rspace| (($ (|Integer|) (|Integer|)) "\\spad{rspace(n,m)} creates rectangular white space, \\spad{n} wide by \\spad{m} high.")) (|vspace| (($ (|Integer|)) "\\spad{vspace(n)} creates white space of height \\spad{n.}")) (|hspace| (($ (|Integer|)) "\\spad{hspace(n)} creates white space of width \\spad{n.}")) (|superHeight| (((|Integer|) $) "\\spad{superHeight(f)} returns the height of form \\spad{f} above the base line.")) (|subHeight| (((|Integer|) $) "\\spad{subHeight(f)} returns the height of form \\spad{f} below the base line.")) (|height| (((|Integer|)) "\\spad{height()} returns the height of the display area (an integer).") (((|Integer|) $) "\\spad{height(f)} returns the height of form \\spad{f} (an integer).")) (|width| (((|Integer|)) "\\spad{width()} returns the width of the display area (an integer).") (((|Integer|) $) "\\spad{width(f)} returns the width of form \\spad{f} (an integer).")) (|empty| (($) "\\spad{empty()} creates an empty form.")) (|outputForm| (($ (|DoubleFloat|)) "\\spad{outputForm(sf)} creates an form for small float \\spad{sf.}") (($ (|String|)) "\\spad{outputForm(s)} creates an form for string \\spad{s.}") (($ (|Symbol|)) "\\spad{outputForm(s)} creates an form for symbol \\spad{s.}") (($ (|Integer|)) "\\spad{outputForm(n)} creates an form for integer \\spad{n.}")) (|messagePrint| (((|Void|) (|String|)) "\\spad{messagePrint(s)} prints \\spad{s} without string quotes. Note: \\spad{messagePrint(s)} is equivalent to \\spad{print message(s)}.")) (|message| (($ (|String|)) "\\spad{message(s)} creates an form with no string quotes from string \\spad{s.}")) (|print| (((|Void|) $) "\\spad{print(u)} prints the form u."))) 
 NIL 
 NIL 
-(-857) 
+(-878) 
 ((|constructor| (NIL "OutPackage allows pretty-printing from programs.")) (|outputList| (((|Void|) (|List| (|Any|))) "\\spad{outputList(l)} displays the concatenated components of the list \\spad{l} on the ``algebra output'' stream, as defined by \\spadsyscom{set output algebra}; quotes are stripped from strings.")) (|output| (((|Void|) (|String|) (|OutputForm|)) "\\spad{output(s,x)} displays the string \\spad{s} followed by the form \\spad{x} on the ``algebra output'' stream, as defined by \\spadsyscom{set output algebra}.") (((|Void|) (|OutputForm|)) "\\spad{output(x)} displays the output form \\spad{x} on the ``algebra output'' stream, as defined by \\spadsyscom{set output algebra}.") (((|Void|) (|String|)) "\\spad{output(s)} displays the string \\spad{s} on the ``algebra output'' stream, as defined by \\spadsyscom{set output algebra}."))) 
 NIL 
 NIL 
-(-858 |VariableList|) 
+(-879 |VariableList|) 
 ((|constructor| (NIL "This domain implements ordered variables")) (|variable| (((|Union| $ "failed") (|Symbol|)) "\\spad{variable(s)} returns a member of the variable set or failed"))) 
 NIL 
 NIL 
-(-859 R |vl| |wl| |wtlevel|) 
+(-880 R |vl| |wl| |wtlevel|) 
 ((|constructor| (NIL "This domain represents truncated weighted polynomials over the \"Polynomial\" type. The variables must be specified, as must the weights. The representation is sparse in the sense that only non-zero terms are represented.")) (|changeWeightLevel| (((|Void|) (|NonNegativeInteger|)) "\\spad{changeWeightLevel(n)} This changes the weight level to the new value given: \\spad{NB:} previously calculated terms are not affected")) (/ (((|Union| $ "failed") $ $) "\\spad{x/y} division (only works if minimum weight of divisor is zero, and if \\spad{R} is a Field)")) (|coerce| (($ (|Polynomial| |#1|)) "\\spad{coerce(p)} coerces a Polynomial(R) into Weighted form, applying weights and ignoring terms") (((|Polynomial| |#1|) $) "\\spad{coerce(p)} converts back into a Polynomial(R), ignoring weights"))) 
-((-4597 |has| |#1| (-174)) (-4596 |has| |#1| (-174)) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-860) 
+((-4620 |has| |#1| (-194)) (-4619 |has| |#1| (-194)) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-881) 
 ((|constructor| (NIL "This category exports the function for the domain PseudoAlgebraicClosureOfAlgExtOfRationalNumber which implement dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension \\spad{(T} : K_0, K_1, ..., K_i...,K_n) where \\spad{K_0} = \\spad{K} and for \\spad{i} =1,2,...,n, K_i is an extension of K_{i-1} of degree > 1 and defined by an irreducible polynomial p(Z) in K_{i-1}. Two towers (T_1: K_01, K_11,...,K_i1,...,K_n1) and (T_2: K_02, K_12,...,K_i2,...,K_n2) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} T_2), that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1,2,...,n1} (or i=1,2,...,n2). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-861 |downLevel|) 
+(-882 |downLevel|) 
 ((|constructor| (NIL "This domain implement dynamic extension over the PseudoAlgebraicClosureOfRationalNumber. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension \\spad{(T} : K_0, K_1, ..., K_i...,K_n) where \\spad{K_0} = \\spad{K} and for \\spad{i} =1,2,...,n, K_i is an extension of K_{i-1} of degree > 1 and defined by an irreducible polynomial p(Z) in K_{i-1}. Two towers (T_1: K_01, K_11,...,K_i1,...,K_n1) and (T_2: K_02, K_12,...,K_i2,...,K_n2) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} T_2), that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1,2,...,n1} (or i=1,2,...,n2). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-866) (QUOTE (-151))) (|HasCategory| (-866) (QUOTE (-149))) (|HasCategory| (-866) (QUOTE (-374))) (|HasCategory| (-413 (-572)) (QUOTE (-151))) (|HasCategory| (-413 (-572)) (QUOTE (-149))) (|HasCategory| (-413 (-572)) (QUOTE (-374))) (-1841 (|HasCategory| (-413 (-572)) (QUOTE (-149))) (|HasCategory| (-413 (-572)) (QUOTE (-374))) (|HasCategory| (-866) (QUOTE (-149))) (|HasCategory| (-866) (QUOTE (-374)))) (-1841 (|HasCategory| (-413 (-572)) (QUOTE (-374))) (|HasCategory| (-866) (QUOTE (-374))))) 
-(-862) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-887) (QUOTE (-171))) (|HasCategory| (-887) (QUOTE (-169))) (|HasCategory| (-887) (QUOTE (-394))) (|HasCategory| (-433 (-592)) (QUOTE (-171))) (|HasCategory| (-433 (-592)) (QUOTE (-169))) (|HasCategory| (-433 (-592)) (QUOTE (-394))) (-3836 (|HasCategory| (-433 (-592)) (QUOTE (-169))) (|HasCategory| (-433 (-592)) (QUOTE (-394))) (|HasCategory| (-887) (QUOTE (-169))) (|HasCategory| (-887) (QUOTE (-394)))) (-3836 (|HasCategory| (-433 (-592)) (QUOTE (-394))) (|HasCategory| (-887) (QUOTE (-394))))) 
+(-883) 
 ((|constructor| (NIL "This category exports the function for the domain PseudoAlgebraicClosureOfFiniteField which implement dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension \\spad{(T} : K_0, K_1, ..., K_i...,K_n) where \\spad{K_0} = \\spad{K} and for \\spad{i} =1,2,...,n, K_i is an extension of K_{i-1} of degree > 1 and defined by an irreducible polynomial p(Z) in K_{i-1}. Two towers (T_1: K_01, K_11,...,K_i1,...,K_n1) and (T_2: K_02, K_12,...,K_i2,...,K_n2) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} T_2), that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1,2,...,n1} (or i=1,2,...,n2). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-863 K) 
+(-884 K) 
 ((|constructor| (NIL "This domain implement dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension \\spad{(T} : K_0, K_1, ..., K_i...,K_n) where \\spad{K_0} = \\spad{K} and for \\spad{i} =1,2,...,n, K_i is an extension of K_{i-1} of degree > 1 and defined by an irreducible polynomial p(Z) in K_{i-1}. Two towers (T_1: K_01, K_11,...,K_i1,...,K_n1) and (T_2: K_02, K_12,...,K_i2,...,K_n2) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} T_2), that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1,2,...,n1} (or i=1,2,...,n2). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-374)))) 
-(-864) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-394)))) 
+(-885) 
 ((|constructor| (NIL "This category exports the function for domains which implement dynamic extension using the simple notion of tower extensions. \\spad{++} A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension \\spad{(T} : K_0, K_1, ..., K_i...,K_n) where \\spad{K_0} = \\spad{K} and for \\spad{i} =1,2,...,n, K_i is an extension of K_{i-1} of degree > 1 and defined by an irreducible polynomial p(Z) in K_{i-1}. Two towers (T_1: K_01, K_11,...,K_i1,...,K_n1) and (T_2: K_02, K_12,...,K_i2,...,K_n2) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} T_2), that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1,2,...,n1} (or i=1,2,...,n2). Any algebraic operations defined for several elements are only defined if all of the concerned elements are coming from a set of related tower extensions.")) (|previousTower| (($ $) "\\spad{previousTower(a)} returns the previous tower extension over which the element a is defined.")) (|extDegree| (((|PositiveInteger|) $) "\\spad{extDegree(a)} returns the extension degree of the extension tower over which the element is defined.")) (|maxTower| (($ (|List| $)) "\\spad{maxTower(l)} returns the tower in the list having the maximal extension degree over the ground field. It has no meaning if the towers are not related.")) (|distinguishedRootsOf| (((|List| $) (|SparseUnivariatePolynomial| $) $) "\\spad{distinguishedRootsOf(p,a)} returns a (distinguised) root for each irreducible factor of the polynomial \\spad{p} (factored over the field defined by the element a)."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-865) 
+(-886) 
 ((|constructor| (NIL "This category exports the function for the domain PseudoAlgebraicClosureOfRationalNumber which implement dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension \\spad{(T} : K_0, K_1, ..., K_i...,K_n) where \\spad{K_0} = \\spad{K} and for \\spad{i} =1,2,...,n, K_i is an extension of K_{i-1} of degree > 1 and defined by an irreducible polynomial p(Z) in K_{i-1}. Two towers (T_1: K_01, K_11,...,K_i1,...,K_n1) and (T_2: K_02, K_12,...,K_i2,...,K_n2) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} T_2), that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1,2,...,n1} (or i=1,2,...,n2). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-866) 
+(-887) 
 ((|constructor| (NIL "This domain implements dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension \\spad{(T} : K_0, K_1, ..., K_i...,K_n) where \\spad{K_0} = \\spad{K} and for \\spad{i} =1,2,...,n, K_i is an extension of K_{i-1} of degree > 1 and defined by an irreducible polynomial p(Z) in K_{i-1}. Two towers (T_1: K_01, K_11,...,K_i1,...,K_n1) and (T_2: K_02, K_12,...,K_i2,...,K_n2) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} T_2), that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1,2,...,n1} (or i=1,2,...,n2). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-413 (-572)) (QUOTE (-151))) (|HasCategory| (-413 (-572)) (QUOTE (-149))) (|HasCategory| (-413 (-572)) (QUOTE (-374))) (-1841 (|HasCategory| (-413 (-572)) (QUOTE (-149))) (|HasCategory| (-413 (-572)) (QUOTE (-374))))) 
-(-867 R PS UP) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-433 (-592)) (QUOTE (-171))) (|HasCategory| (-433 (-592)) (QUOTE (-169))) (|HasCategory| (-433 (-592)) (QUOTE (-394))) (-3836 (|HasCategory| (-433 (-592)) (QUOTE (-169))) (|HasCategory| (-433 (-592)) (QUOTE (-394))))) 
+(-888 R PS UP) 
 ((|constructor| (NIL "This package computes reliable Pad&ea. approximants using a generalized Viskovatov continued fraction algorithm.")) (|padecf| (((|Union| (|ContinuedFraction| |#3|) "failed") (|NonNegativeInteger|) (|NonNegativeInteger|) |#2| |#2|) "\\spad{padecf(nd,dd,ns,ds)} computes the approximant as a continued fraction of polynomials (if it exists) for arguments \\spad{nd} (numerator degree of approximant), \\spad{dd} (denominator degree of approximant), \\spad{ns} (numerator series of function), and \\spad{ds} (denominator series of function).")) (|pade| (((|Union| (|Fraction| |#3|) "failed") (|NonNegativeInteger|) (|NonNegativeInteger|) |#2| |#2|) "\\spad{pade(nd,dd,ns,ds)} computes the approximant as a quotient of polynomials (if it exists) for arguments \\spad{nd} (numerator degree of approximant), \\spad{dd} (denominator degree of approximant), \\spad{ns} (numerator series of function), and \\spad{ds} (denominator series of function)."))) 
 NIL 
 NIL 
-(-868 R |x| |pt|) 
+(-889 R |x| |pt|) 
 ((|constructor| (NIL "This package computes reliable Pad&ea. approximants using a generalized Viskovatov continued fraction algorithm.")) (|pade| (((|Union| (|Fraction| (|UnivariatePolynomial| |#2| |#1|)) "failed") (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateTaylorSeries| |#1| |#2| |#3|)) "\\spad{pade(nd,dd,s)} computes the quotient of polynomials (if it exists) with numerator degree at most \\spad{nd} and denominator degree at most \\spad{dd} which matches the series \\spad{s} to order \\spad{nd + dd}.") (((|Union| (|Fraction| (|UnivariatePolynomial| |#2| |#1|)) "failed") (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateTaylorSeries| |#1| |#2| |#3|) (|UnivariateTaylorSeries| |#1| |#2| |#3|)) "\\spad{pade(nd,dd,ns,ds)} computes the approximant as a quotient of polynomials (if it exists) for arguments \\spad{nd} (numerator degree of approximant), \\spad{dd} (denominator degree of approximant), \\spad{ns} (numerator series of function), and \\spad{ds} (denominator series of function)."))) 
 NIL 
 NIL 
-(-869 |p|) 
+(-890 |p|) 
 ((|constructor| (NIL "This is the category of stream-based representations of the p-adic integers.")) (|root| (($ (|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "\\spad{root(f,a)} returns a root of the polynomial \\spad{f}. Argument \\spad{a} must be a root of \\spad{f} \\spad{(mod p)}.")) (|sqrt| (($ $ (|Integer|)) "\\spad{sqrt(b,a)} returns a square root of \\spad{b.} Argument \\spad{a} is a square root of \\spad{b} \\spad{(mod p)}.")) (|approximate| (((|Integer|) $ (|Integer|)) "\\spad{approximate(x,n)} returns an integer \\spad{y} such that \\spad{y = \\spad{x} (mod p^n)} when \\spad{n} is positive, and 0 otherwise.")) (|quotientByP| (($ $) "\\spad{quotientByP(x)} returns \\spad{b,} where \\spad{x = a + \\spad{b} \\spad{p}.}")) (|moduloP| (((|Integer|) $) "\\spad{modulo(x)} returns a, where \\spad{x = a + \\spad{b} \\spad{p}.}")) (|modulus| (((|Integer|)) "\\spad{modulus()} returns the value of \\spad{p.}")) (|complete| (($ $) "\\spad{complete(x)} forces the computation of all digits.")) (|extend| (($ $ (|Integer|)) "\\spad{extend(x,n)} forces the computation of digits up to order \\spad{n.}")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(x)} returns the exponent of the highest power of \\spad{p} dividing \\spad{x.}")) (|digits| (((|Stream| (|Integer|)) $) "\\spad{digits(x)} returns a stream of p-adic digits of \\spad{x.}"))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-870 |p|) 
+(-891 |p|) 
 ((|constructor| (NIL "Stream-based implementation of \\spad{Zp:} p-adic numbers are represented as sum(i = 0.., a[i] * p^i), where the a[i] lie in 0,1,...,(p - 1)."))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-871 |p|) 
+(-892 |p|) 
 ((|constructor| (NIL "Stream-based implementation of \\spad{Qp:} numbers are represented as sum(i = k.., a[i] * p^i) where the a[i] lie in 0,1,...,(p - 1)."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-870 |#1|) (QUOTE (-910))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-870 |#1|) (QUOTE (-149))) (|HasCategory| (-870 |#1|) (QUOTE (-151))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-870 |#1|) (QUOTE (-1028))) (|HasCategory| (-870 |#1|) (QUOTE (-821))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-870 |#1|) (QUOTE (-1144))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| (-870 |#1|) (QUOTE (-227))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -527) (QUOTE (-1170)) (LIST (QUOTE -870) (|devaluate| |#1|)))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -305) (LIST (QUOTE -870) (|devaluate| |#1|)))) (|HasCategory| (-870 |#1|) (LIST (QUOTE -283) (LIST (QUOTE -870) (|devaluate| |#1|)) (LIST (QUOTE -870) (|devaluate| |#1|)))) (|HasCategory| (-870 |#1|) (QUOTE (-303))) (|HasCategory| (-870 |#1|) (QUOTE (-554))) (|HasCategory| (-870 |#1|) (QUOTE (-848))) (-1841 (|HasCategory| (-870 |#1|) (QUOTE (-821))) (|HasCategory| (-870 |#1|) (QUOTE (-848)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-870 |#1|) (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-870 |#1|) (QUOTE (-910)))) (|HasCategory| (-870 |#1|) (QUOTE (-149))))) 
-(-872 |p| PADIC) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-891 |#1|) (QUOTE (-931))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-891 |#1|) (QUOTE (-169))) (|HasCategory| (-891 |#1|) (QUOTE (-171))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-891 |#1|) (QUOTE (-1049))) (|HasCategory| (-891 |#1|) (QUOTE (-842))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-891 |#1|) (QUOTE (-1165))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| (-891 |#1|) (QUOTE (-247))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -547) (QUOTE (-1191)) (LIST (QUOTE -891) (|devaluate| |#1|)))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -325) (LIST (QUOTE -891) (|devaluate| |#1|)))) (|HasCategory| (-891 |#1|) (LIST (QUOTE -303) (LIST (QUOTE -891) (|devaluate| |#1|)) (LIST (QUOTE -891) (|devaluate| |#1|)))) (|HasCategory| (-891 |#1|) (QUOTE (-323))) (|HasCategory| (-891 |#1|) (QUOTE (-574))) (|HasCategory| (-891 |#1|) (QUOTE (-869))) (-3836 (|HasCategory| (-891 |#1|) (QUOTE (-842))) (|HasCategory| (-891 |#1|) (QUOTE (-869)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-891 |#1|) (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-891 |#1|) (QUOTE (-931)))) (|HasCategory| (-891 |#1|) (QUOTE (-169))))) 
+(-893 |p| PADIC) 
 ((|constructor| (NIL "This is the category of stream-based representations of \\spad{Qp.}")) (|removeZeroes| (($ (|Integer|) $) "\\spad{removeZeroes(n,x)} removes up to \\spad{n} leading zeroes from the p-adic rational \\spad{x}.") (($ $) "\\spad{removeZeroes(x)} removes leading zeroes from the representation of the p-adic rational \\spad{x}. A p-adic rational is represented by \\spad{(1)} an exponent and \\spad{(2)} a p-adic integer which may have leading zero digits. When the p-adic integer has a leading zero digit, a 'leading zero' is removed from the p-adic rational as follows: the number is rewritten by increasing the exponent by 1 and dividing the p-adic integer by \\spad{p.} Note: \\spad{removeZeroes(f)} removes all leading zeroes from \\spad{f.}")) (|continuedFraction| (((|ContinuedFraction| (|Fraction| (|Integer|))) $) "\\spad{continuedFraction(x)} converts the p-adic rational number \\spad{x} to a continued fraction.")) (|approximate| (((|Fraction| (|Integer|)) $ (|Integer|)) "\\spad{approximate(x,n)} returns a rational number \\spad{y} such that \\spad{y = \\spad{x} (mod p^n)}."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (QUOTE (-1028))) (|HasCategory| |#2| (QUOTE (-821))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1144))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-227))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -283) (|devaluate| |#2|) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-303))) (|HasCategory| |#2| (QUOTE (-554))) (|HasCategory| |#2| (QUOTE (-848))) (-1841 (|HasCategory| |#2| (QUOTE (-821))) (|HasCategory| |#2| (QUOTE (-848)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (|HasCategory| |#2| (QUOTE (-149))))) 
-(-873 K |symb| BLMET) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (QUOTE (-1049))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1165))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-247))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-323))) (|HasCategory| |#2| (QUOTE (-574))) (|HasCategory| |#2| (QUOTE (-869))) (-3836 (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-869)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (|HasCategory| |#2| (QUOTE (-169))))) 
+(-894 K |symb| BLMET) 
 ((|constructor| (NIL "A package that implements the Brill-Noether algorithm. Part of the PAFF package")) (|ZetaFunction| (((|UnivariateTaylorSeriesCZero| (|Integer|) |t|) (|PositiveInteger|)) "Returns the Zeta function of the curve in constant field extension. Calculated by using the L-Polynomial") (((|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) "Returns the Zeta function of the curve. Calculated by using the L-Polynomial")) (|numberPlacesDegExtDeg| (((|Integer|) (|PositiveInteger|) (|PositiveInteger|)) "numberRatPlacesExtDegExtDeg(d, \\spad{n)} returns the number of places of degree \\spad{d} in the constant field extension of degree \\spad{n}")) (|numberRatPlacesExtDeg| (((|Integer|) (|PositiveInteger|)) "\\spad{numberRatPlacesExtDeg(n)} returns the number of rational places in the constant field extenstion of degree \\spad{n}")) (|numberOfPlacesOfDegree| (((|Integer|) (|PositiveInteger|)) "returns the number of places of the given degree")) (|placesOfDegree| (((|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) (|PositiveInteger|)) "\\spad{placesOfDegree(d)} returns all places of degree \\spad{d} of the curve.")) (|classNumber| (((|Integer|)) "Returns the class number of the curve.")) (|LPolynomial| (((|SparseUnivariatePolynomial| (|Integer|)) (|PositiveInteger|)) "\\spad{LPolynomial(d)} returns the L-Polynomial of the curve in constant field extension of degree \\spad{d.}") (((|SparseUnivariatePolynomial| (|Integer|))) "Returns the L-Polynomial of the curve.")) (|adjunctionDivisor| (((|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|))) "\\spad{adjunctionDivisor computes} the adjunction divisor of the plane curve given by the polynomial defined by setCurve.")) (|intersectionDivisor| (((|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) (|DistributedMultivariatePolynomial| |#2| |#1|)) "\\spad{intersectionDivisor(pol)} compute the intersection divisor of the form \\spad{pol} with the curve. (If \\spad{pol} is not homogeneous an error message is issued).")) (|evalIfCan| (((|Union| |#1| "failed") (|Fraction| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{evalIfCan(u,pl)} evaluate the function \\spad{u} at the place \\spad{pl} (returns \"failed\" if it is a pole).") (((|Union| |#1| "failed") (|DistributedMultivariatePolynomial| |#2| |#1|) (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{evalIfCan(f,g,pl)} evaluate the function \\spad{f/g} at the place \\spad{pl} (returns \"failed\" if it is a pole).") (((|Union| |#1| "failed") (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{evalIfCan(f,pl)} evaluate \\spad{f} at the place \\spad{pl} (returns \"failed\" if it is a pole).")) (|eval| ((|#1| (|Fraction| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{eval(u,pl)} evaluate the function \\spad{u} at the place \\spad{pl.}") ((|#1| (|DistributedMultivariatePolynomial| |#2| |#1|) (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{eval(f,g,pl)} evaluate the function \\spad{f/g} at the place \\spad{pl.}") ((|#1| (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{eval(f,pl)} evaluate \\spad{f} at the place \\spad{pl.}")) (|interpolateForms| (((|List| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) (|NonNegativeInteger|)) "\\spad{interpolateForms(d,n)} returns a basis of the interpolate forms of degree \\spad{n} of the divisor \\spad{d.}")) (|lBasis| (((|Record| (|:| |num| (|List| (|DistributedMultivariatePolynomial| |#2| |#1|))) (|:| |den| (|DistributedMultivariatePolynomial| |#2| |#1|))) (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|))) "\\spad{lBasis computes} a basis associated to the specified divisor")) (|parametrize| (((|NeitherSparseOrDensePowerSeries| (|PseudoAlgebraicClosureOfFiniteField| |#1|)) (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{parametrize(f,pl)} returns a local parametrization of \\spad{f} at the place \\spad{pl.}")) (|singularPoints| (((|List| (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |#1|))) "rationalPoints() returns the singular points of the curve defined by the polynomial given to the package. If the singular points lie in an extension of the specified ground field an error message is issued specifying the extension degree needed to find all singular points.")) (|desingTree| (((|List| (|DesingTree| (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |#1| |#2| |#3|)))) "\\spad{desingTree returns} the desingularisation trees at all singular points of the curve defined by the polynomial given to the package.")) (|desingTreeWoFullParam| (((|List| (|DesingTree| (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |#1| |#2| |#3|)))) "\\spad{desingTreeWoFullParam returns} the desingularisation trees at all singular points of the curve defined by the polynomial given to the package. The local parametrizations are not computed.")) (|genus| (((|NonNegativeInteger|)) "\\spad{genus returns} the genus of the curve defined by the polynomial given to the package.")) (|theCurve| (((|DistributedMultivariatePolynomial| |#2| |#1|)) "\\spad{theCurve returns} the specified polynomial for the package.")) (|rationalPlaces| (((|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|))) "\\spad{rationalPlaces returns} all the rational places of the curve defined by the polynomial given to the package.")) (|pointDominateBy| (((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{pointDominateBy(pl)} returns the projective point dominated by the place \\spad{pl.}"))) 
 NIL 
-((|HasCategory| (-863 |#1|) (QUOTE (-374)))) 
-(-874 K |symb| BLMET) 
+((|HasCategory| (-884 |#1|) (QUOTE (-394)))) 
+(-895 K |symb| BLMET) 
 ((|constructor| (NIL "A package that implements the Brill-Noether algorithm. Part of the PAFF package")) (|ZetaFunction| (((|UnivariateTaylorSeriesCZero| (|Integer|) |t|) (|PositiveInteger|)) "Returns the Zeta function of the curve in constant field extension. Calculated by using the L-Polynomial") (((|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) "Returns the Zeta function of the curve. Calculated by using the L-Polynomial")) (|numberPlacesDegExtDeg| (((|Integer|) (|PositiveInteger|) (|PositiveInteger|)) "numberRatPlacesExtDegExtDeg(d, \\spad{n)} returns the number of places of degree \\spad{d} in the constant field extension of degree \\spad{n}")) (|numberRatPlacesExtDeg| (((|Integer|) (|PositiveInteger|)) "\\spad{numberRatPlacesExtDeg(n)} returns the number of rational places in the constant field extenstion of degree \\spad{n}")) (|numberOfPlacesOfDegree| (((|Integer|) (|PositiveInteger|)) "returns the number of places of the given degree")) (|placesOfDegree| (((|List| (|Places| |#1|)) (|PositiveInteger|)) "\\spad{placesOfDegree(d)} returns all places of degree \\spad{d} of the curve.")) (|classNumber| (((|Integer|)) "Returns the class number of the curve.")) (|LPolynomial| (((|SparseUnivariatePolynomial| (|Integer|)) (|PositiveInteger|)) "\\spad{LPolynomial(d)} returns the L-Polynomial of the curve in constant field extension of degree \\spad{d.}") (((|SparseUnivariatePolynomial| (|Integer|))) "Returns the L-Polynomial of the curve.")) (|adjunctionDivisor| (((|Divisor| (|Places| |#1|))) "\\spad{adjunctionDivisor computes} the adjunction divisor of the plane curve given by the polynomial set with the function setCurve.")) (|intersectionDivisor| (((|Divisor| (|Places| |#1|)) (|DistributedMultivariatePolynomial| |#2| |#1|)) "\\spad{intersectionDivisor(pol)} compute the intersection divisor (the Cartier divisor) of the form \\spad{pol} with the curve. If some intersection points lie in an extension of the ground field, an error message is issued specifying the extension degree needed to find all the intersection points. (If \\spad{pol} is not homogeneous an error message is issued).")) (|evalIfCan| (((|Union| |#1| "failed") (|Fraction| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|Places| |#1|)) "\\spad{evalIfCan(u,pl)} evaluate the function \\spad{u} at the place \\spad{pl} (returns \"failed\" if it is a pole).") (((|Union| |#1| "failed") (|DistributedMultivariatePolynomial| |#2| |#1|) (|DistributedMultivariatePolynomial| |#2| |#1|) (|Places| |#1|)) "\\spad{evalIfCan(f,g,pl)} evaluate the function \\spad{f/g} at the place \\spad{pl} (returns \"failed\" if it is a pole).") (((|Union| |#1| "failed") (|DistributedMultivariatePolynomial| |#2| |#1|) (|Places| |#1|)) "\\spad{evalIfCan(f,pl)} evaluate \\spad{f} at the place \\spad{pl} (returns \"failed\" if it is a pole).")) (|eval| ((|#1| (|Fraction| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|Places| |#1|)) "\\spad{eval(u,pl)} evaluate the function \\spad{u} at the place \\spad{pl.}") ((|#1| (|DistributedMultivariatePolynomial| |#2| |#1|) (|DistributedMultivariatePolynomial| |#2| |#1|) (|Places| |#1|)) "\\spad{eval(f,g,pl)} evaluate the function \\spad{f/g} at the place \\spad{pl.}") ((|#1| (|DistributedMultivariatePolynomial| |#2| |#1|) (|Places| |#1|)) "\\spad{eval(f,pl)} evaluate \\spad{f} at the place \\spad{pl.}")) (|interpolateForms| (((|List| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|Divisor| (|Places| |#1|)) (|NonNegativeInteger|)) "\\spad{interpolateForms(d,n)} returns a basis of the interpolate forms of degree \\spad{n} of the divisor \\spad{d.}")) (|lBasis| (((|Record| (|:| |num| (|List| (|DistributedMultivariatePolynomial| |#2| |#1|))) (|:| |den| (|DistributedMultivariatePolynomial| |#2| |#1|))) (|Divisor| (|Places| |#1|))) "\\spad{lBasis computes} a basis associated to the specified divisor")) (|parametrize| (((|NeitherSparseOrDensePowerSeries| |#1|) (|DistributedMultivariatePolynomial| |#2| |#1|) (|Places| |#1|)) "\\spad{parametrize(f,pl)} returns a local parametrization of \\spad{f} at the place \\spad{pl.}")) (|singularPoints| (((|List| (|ProjectivePlane| |#1|))) "rationalPoints() returns the singular points of the curve defined by the polynomial given to the package. If the singular points lie in an extension of the specified ground field an error message is issued specifying the extension degree needed to find all singular points.")) (|desingTree| (((|List| (|DesingTree| (|InfClsPt| |#1| |#2| |#3|)))) "\\spad{desingTree returns} the desingularisation trees at all singular points of the curve defined by the polynomial given to the package.")) (|desingTreeWoFullParam| (((|List| (|DesingTree| (|InfClsPt| |#1| |#2| |#3|)))) "\\spad{desingTreeWoFullParam returns} the desingularisation trees at all singular points of the curve defined by the polynomial given to the package. The local parametrizations are not computed.")) (|genus| (((|NonNegativeInteger|)) "\\spad{genus returns} the genus of the curve defined by the polynomial given to the package.")) (|theCurve| (((|DistributedMultivariatePolynomial| |#2| |#1|)) "\\spad{theCurve returns} the specified polynomial for the package.")) (|rationalPlaces| (((|List| (|Places| |#1|))) "\\spad{rationalPlaces returns} all the rational places of the curve defined by the polynomial given to the package.")) (|pointDominateBy| (((|ProjectivePlane| |#1|) (|Places| |#1|)) "\\spad{pointDominateBy(pl)} returns the projective point dominated by the place \\spad{pl.}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-374)))) 
-(-875) 
+((|HasCategory| |#1| (QUOTE (-394)))) 
+(-896) 
 ((|constructor| (NIL "This domain describes four groups of color shades (palettes).")) (|coerce| (($ (|Color|)) "\\spad{coerce(c)} sets the average shade for the palette to that of the indicated color \\spad{c.}")) (|shade| (((|Integer|) $) "\\spad{shade(p)} returns the shade index of the indicated palette \\spad{p.}")) (|hue| (((|Color|) $) "\\spad{hue(p)} returns the hue field of the indicated palette \\spad{p.}")) (|light| (($ (|Color|)) "\\spad{light(c)} sets the shade of a hue, \\spad{c,} to it's highest value.")) (|pastel| (($ (|Color|)) "\\spad{pastel(c)} sets the shade of a hue, \\spad{c,} above bright, but below light.")) (|bright| (($ (|Color|)) "\\spad{bright(c)} sets the shade of a hue, \\spad{c,} above dim, but below pastel.")) (|dim| (($ (|Color|)) "\\spad{dim(c)} sets the shade of a hue, \\spad{c,} above dark, but below bright.")) (|dark| (($ (|Color|)) "\\spad{dark(c)} sets the shade of the indicated hue of \\spad{c} to it's lowest value."))) 
 NIL 
 NIL 
-(-876) 
+(-897) 
 ((|constructor| (NIL "This package provides a coerce from polynomials over algebraic numbers to \\spadtype{Expression AlgebraicNumber}.")) (|coerce| (((|Expression| (|Integer|)) (|Fraction| (|Polynomial| (|AlgebraicNumber|)))) "\\spad{coerce(rf)} converts \\spad{rf}, a fraction of polynomial \\spad{p} with algebraic number coefficients to \\spadtype{Expression Integer}.") (((|Expression| (|Integer|)) (|Polynomial| (|AlgebraicNumber|))) "\\spad{coerce(p)} converts the polynomial \\spad{p} with algebraic number coefficients to \\spadtype{Expression Integer}."))) 
 NIL 
 NIL 
-(-877 K |symb| |PolyRing| E |ProjPt| PCS |Plc|) 
+(-898 K |symb| |PolyRing| E |ProjPt| PCS |Plc|) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|parametrize| ((|#6| |#3| |#7| (|Integer|)) "\\spad{parametrize(f,pl,n)} returns t**n * parametrize(f,p).") ((|#6| |#3| |#3| |#7|) "\\spad{parametrize(f,g,pl)} returns the local parametrization of the rational function \\spad{f/g} at the place \\spad{pl.} Note that local parametrization of the place must have first been compute and set. For simple point on a curve, this done with \\spad{pointToPlace}. The local parametrization places corresponding to a leaf in a desingularization tree are compute at the moment of their \"creation\". (See package \\spad{DesingTreePackage}.") ((|#6| |#3| |#7|) "\\spad{parametrize(f,pl)} returns the local parametrization of the polynomial function \\spad{f} at the place \\spad{pl.} Note that local parametrization of the place must have first been compute and set. For simple point on a curve, this done with \\spad{pointToPlace}. The local parametrization places corresponding to a leaf in a desingularization tree are compute at the moment of their \"creation\". (See package \\spad{DesingTreePackage}."))) 
 NIL 
 NIL 
-(-878 CF1 CF2) 
+(-899 CF1 CF2) 
 ((|constructor| (NIL "This package has no description")) (|map| (((|ParametricPlaneCurve| |#2|) (|Mapping| |#2| |#1|) (|ParametricPlaneCurve| |#1|)) "\\spad{map(f,x)} \\undocumented"))) 
 NIL 
 NIL 
-(-879 |ComponentFunction|) 
+(-900 |ComponentFunction|) 
 ((|constructor| (NIL "ParametricPlaneCurve is used for plotting parametric plane curves in the affine plane.")) (|coordinate| ((|#1| $ (|NonNegativeInteger|)) "\\spad{coordinate(c,i)} returns a coordinate function for \\spad{c} using 1-based indexing according to i. This indicates what the function for the coordinate component \\spad{i} of the plane curve is.")) (|curve| (($ |#1| |#1|) "\\spad{curve(c1,c2)} creates a plane curve from 2 component functions \\spad{c1} and \\spad{c2}."))) 
 NIL 
 NIL 
-(-880 CF1 CF2) 
+(-901 CF1 CF2) 
 ((|constructor| (NIL "This package has no description")) (|map| (((|ParametricSpaceCurve| |#2|) (|Mapping| |#2| |#1|) (|ParametricSpaceCurve| |#1|)) "\\spad{map(f,x)} \\undocumented"))) 
 NIL 
 NIL 
-(-881 |ComponentFunction|) 
+(-902 |ComponentFunction|) 
 ((|constructor| (NIL "ParametricSpaceCurve is used for plotting parametric space curves in affine 3-space.")) (|coordinate| ((|#1| $ (|NonNegativeInteger|)) "\\spad{coordinate(c,i)} returns a coordinate function of \\spad{c} using 1-based indexing according to i. This indicates what the function for the coordinate component, i, of the space curve is.")) (|curve| (($ |#1| |#1| |#1|) "\\spad{curve(c1,c2,c3)} creates a space curve from 3 component functions \\spad{c1}, \\spad{c2}, and \\spad{c3}."))) 
 NIL 
 NIL 
-(-882 CF1 CF2) 
+(-903 CF1 CF2) 
 ((|constructor| (NIL "This package has no description")) (|map| (((|ParametricSurface| |#2|) (|Mapping| |#2| |#1|) (|ParametricSurface| |#1|)) "\\spad{map(f,x)} \\undocumented"))) 
 NIL 
 NIL 
-(-883 |ComponentFunction|) 
+(-904 |ComponentFunction|) 
 ((|constructor| (NIL "ParametricSurface is used for plotting parametric surfaces in affine 3-space.")) (|coordinate| ((|#1| $ (|NonNegativeInteger|)) "\\spad{coordinate(s,i)} returns a coordinate function of \\spad{s} using 1-based indexing according to i. This indicates what the function for the coordinate component, i, of the surface is.")) (|surface| (($ |#1| |#1| |#1|) "\\spad{surface(c1,c2,c3)} creates a surface from 3 parametric component functions \\spad{c1}, \\spad{c2}, and \\spad{c3}."))) 
 NIL 
 NIL 
-(-884) 
+(-905) 
 ((|constructor| (NIL "PartitionsAndPermutations contains functions for generating streams of integer partitions, and streams of sequences of integers composed from a multi-set.")) (|permutations| (((|Stream| (|List| (|Integer|))) (|Integer|)) "\\spad{permutations(n)} is the stream of permutations \\indented{1}{formed from \\spad{1,2,3,...,n}.}")) (|sequences| (((|Stream| (|List| (|Integer|))) (|List| (|Integer|))) "\\spad{sequences([l0,l1,l2,..,ln])} is the set of \\indented{1}{all sequences formed from} \\spad{l0} 0's,\\spad{l1} 1's,\\spad{l2} 2's,...,\\spad{ln} n's.") (((|Stream| (|List| (|Integer|))) (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{sequences(l1,l2)} is the stream of all sequences that \\indented{1}{can be composed from the multiset defined from} \\indented{1}{two lists of integers \\spad{l1} and l2.} \\indented{1}{For example,the pair \\spad{([1,2,4],[2,3,5])} represents} \\indented{1}{multi-set with 1 \\spad{2}, 2 \\spad{3}'s, and 4 \\spad{5}'s.}")) (|shufflein| (((|Stream| (|List| (|Integer|))) (|List| (|Integer|)) (|Stream| (|List| (|Integer|)))) "\\spad{shufflein(l,st)} maps shuffle(l,u) on to all \\indented{1}{members \\spad{u} of \\spad{st,} concatenating the results.}")) (|shuffle| (((|Stream| (|List| (|Integer|))) (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{shuffle(l1,l2)} forms the stream of all shuffles of \\spad{l1} \\indented{1}{and \\spad{l2,} \\spadignore{i.e.} all sequences that can be formed from} \\indented{1}{merging \\spad{l1} and l2.}")) (|conjugates| (((|Stream| (|List| (|Integer|))) (|Stream| (|List| (|Integer|)))) "\\spad{conjugates(lp)} is the stream of conjugates of a stream \\indented{1}{of partitions lp.}")) (|conjugate| (((|List| (|Integer|)) (|List| (|Integer|))) "\\spad{conjugate(pt)} is the conjugate of the partition \\spad{pt.}")) (|partitions| (((|Stream| (|List| (|Integer|))) (|Integer|) (|Integer|)) "\\spad{partitions(p,l)} is the stream of all \\indented{1}{partitions whose number of} \\indented{1}{parts and largest part are no greater than \\spad{p} and \\spad{l.}}") (((|Stream| (|List| (|Integer|))) (|Integer|)) "\\spad{partitions(n)} is the stream of all partitions of \\spad{n.}") (((|Stream| (|List| (|Integer|))) (|Integer|) (|Integer|) (|Integer|)) "\\spad{partitions(p,l,n)} is the stream of partitions \\indented{1}{of \\spad{n} whose number of parts is no greater than \\spad{p}} \\indented{1}{and whose largest part is no greater than \\spad{l.}}"))) 
 NIL 
 NIL 
-(-885 R) 
+(-906 R) 
 ((|constructor| (NIL "Category of sets that can be converted to useful patterns An object \\spad{S} is Patternable over an object \\spad{R} if \\spad{S} can lift the conversions from \\spad{R} into \\spadtype{Pattern(Integer)} and \\spadtype{Pattern(Float)} to itself."))) 
 NIL 
 NIL 
-(-886 R S L) 
+(-907 R S L) 
 ((|constructor| (NIL "A PatternMatchListResult is an object internally returned by the pattern matcher when matching on lists. It is either a failed match, or a pair of PatternMatchResult, one for atoms (elements of the list), and one for lists.")) (|lists| (((|PatternMatchResult| |#1| |#3|) $) "\\spad{lists(r)} returns the list of matches that match lists.")) (|atoms| (((|PatternMatchResult| |#1| |#2|) $) "\\spad{atoms(r)} returns the list of matches that match atoms (elements of the lists).")) (|makeResult| (($ (|PatternMatchResult| |#1| |#2|) (|PatternMatchResult| |#1| |#3|)) "\\spad{makeResult(r1,r2)} makes the combined result [r1,r2].")) (|new| (($) "\\spad{new()} returns a new empty match result.")) (|failed| (($) "\\spad{failed()} returns a failed match.")) (|failed?| (((|Boolean|) $) "\\spad{failed?(r)} tests if \\spad{r} is a failed match."))) 
 NIL 
 NIL 
-(-887 S) 
+(-908 S) 
 ((|constructor| (NIL "A set \\spad{R} is PatternMatchable over \\spad{S} if elements of \\spad{R} can be matched to patterns over \\spad{S.}")) (|patternMatch| (((|PatternMatchResult| |#1| $) $ (|Pattern| |#1|) (|PatternMatchResult| |#1| $)) "\\spad{patternMatch(expr, pat, res)} matches the pattern \\spad{pat} to the expression expr. res contains the variables of \\spad{pat} which are already matched and their matches (necessary for recursion). Initially, res is just the result of \\spadfun{new} which is an empty list of matches."))) 
 NIL 
 NIL 
-(-888 |Base| |Subject| |Pat|) 
+(-909 |Base| |Subject| |Pat|) 
 ((|constructor| (NIL "This package provides the top-level pattern macthing functions.")) (|Is| (((|PatternMatchResult| |#1| |#2|) |#2| |#3|) "\\spad{Is(expr, pat)} matches the pattern pat on the expression \\spad{expr} and returns a match of the form \\spad{[v1 = e1,...,vn = en]}; returns an empty match if \\spad{expr} is exactly equal to pat. returns a \\spadfun{failed} match if pat does not match expr.") (((|List| (|Equation| (|Polynomial| |#2|))) |#2| |#3|) "\\spad{Is(expr, pat)} matches the pattern pat on the expression \\spad{expr} and returns a list of matches \\spad{[v1 = e1,...,vn = en]}; returns an empty list if either \\spad{expr} is exactly equal to pat or if pat does not match expr.") (((|List| (|Equation| |#2|)) |#2| |#3|) "\\spad{Is(expr, pat)} matches the pattern pat on the expression \\spad{expr} and returns a list of matches \\spad{[v1 = e1,...,vn = en]}; returns an empty list if either \\spad{expr} is exactly equal to pat or if pat does not match expr.") (((|PatternMatchListResult| |#1| |#2| (|List| |#2|)) (|List| |#2|) |#3|) "\\spad{Is([e1,...,en], pat)} matches the pattern pat on the list of expressions \\spad{[e1,...,en]} and returns the result.")) (|is?| (((|Boolean|) (|List| |#2|) |#3|) "\\spad{is?([e1,...,en], pat)} tests if the list of expressions \\spad{[e1,...,en]} matches the pattern pat.") (((|Boolean|) |#2| |#3|) "\\spad{is?(expr, pat)} tests if the expression \\spad{expr} matches the pattern pat."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170)))) (-12 (-2959 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170))))) (-2959 (|HasCategory| |#2| (QUOTE (-1054))))) (-12 (|HasCategory| |#2| (QUOTE (-1054))) (-2959 (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170))))))) 
-(-889 R A B) 
+((|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191)))) (-12 (-3252 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191))))) (-3252 (|HasCategory| |#2| (QUOTE (-1075))))) (-12 (|HasCategory| |#2| (QUOTE (-1075))) (-3252 (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191))))))) 
+(-910 R A B) 
 ((|constructor| (NIL "Lifts maps to pattern matching results.")) (|map| (((|PatternMatchResult| |#1| |#3|) (|Mapping| |#3| |#2|) (|PatternMatchResult| |#1| |#2|)) "\\spad{map(f, [(v1,a1),...,(vn,an)])} returns the matching result [(v1,f(a1)),...,(vn,f(an))]."))) 
 NIL 
 NIL 
-(-890 R S) 
+(-911 R S) 
 ((|constructor| (NIL "A PatternMatchResult is an object internally returned by the pattern matcher; It is either a failed match, or a list of matches of the form (var, expr) meaning that the variable var matches the expression expr.")) (|satisfy?| (((|Union| (|Boolean|) "failed") $ (|Pattern| |#1|)) "\\spad{satisfy?(r, \\spad{p)}} returns \\spad{true} if the matches satisfy the top-level predicate of \\spad{p,} \\spad{false} if they don't, and \"failed\" if not enough variables of \\spad{p} are matched in \\spad{r} to decide.")) (|construct| (($ (|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| |#2|)))) "\\spad{construct([v1,e1],...,[vn,en])} returns the match result containing the matches (v1,e1),...,(vn,en).")) (|destruct| (((|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| |#2|))) $) "\\spad{destruct(r)} returns the list of matches (var, expr) in \\spad{r.} Error: if \\spad{r} is a failed match.")) (|addMatchRestricted| (($ (|Pattern| |#1|) |#2| $ |#2|) "\\spad{addMatchRestricted(var, expr, \\spad{r,} val)} adds the match (var, expr) in \\spad{r,} provided that \\spad{expr} satisfies the predicates attached to var, that \\spad{var} is not matched to another expression already, and that either \\spad{var} is an optional pattern variable or that \\spad{expr} is not equal to val (usually an identity).")) (|insertMatch| (($ (|Pattern| |#1|) |#2| $) "\\spad{insertMatch(var, expr, \\spad{r)}} adds the match (var, expr) in \\spad{r,} without checking predicates or previous matches for var.")) (|addMatch| (($ (|Pattern| |#1|) |#2| $) "\\spad{addMatch(var, expr, \\spad{r)}} adds the match (var, expr) in \\spad{r,} provided that \\spad{expr} satisfies the predicates attached to var, and that \\spad{var} is not matched to another expression already.")) (|getMatch| (((|Union| |#2| "failed") (|Pattern| |#1|) $) "\\spad{getMatch(var, \\spad{r)}} returns the expression that \\spad{var} matches in the result \\spad{r,} and \"failed\" if \\spad{var} is not matched in \\spad{r.}")) (|union| (($ $ $) "\\spad{union(a, \\spad{b)}} makes the set-union of two match results.")) (|new| (($) "\\spad{new()} returns a new empty match result.")) (|failed| (($) "\\spad{failed()} returns a failed match.")) (|failed?| (((|Boolean|) $) "\\spad{failed?(r)} tests if \\spad{r} is a failed match."))) 
 NIL 
 NIL 
-(-891 R -1557) 
+(-912 R -1940) 
 ((|constructor| (NIL "Utilities for handling patterns")) (|badValues| (((|List| |#2|) (|Pattern| |#1|)) "\\spad{badValues(p)} returns the list of \"bad values\" for \\spad{p;} \\spad{p} is not allowed to match any of its \"bad values\".")) (|addBadValue| (((|Pattern| |#1|) (|Pattern| |#1|) |#2|) "\\spad{addBadValue(p, \\spad{v)}} adds \\spad{v} to the list of \"bad values\" for \\spad{p;} \\spad{p} is not allowed to match any of its \"bad values\".")) (|satisfy?| (((|Boolean|) (|List| |#2|) (|Pattern| |#1|)) "\\spad{satisfy?([v1,...,vn], \\spad{p)}} returns \\spad{f(v1,...,vn)} where \\spad{f} is the top-level predicate attached to \\spad{p.}") (((|Boolean|) |#2| (|Pattern| |#1|)) "\\spad{satisfy?(v, \\spad{p)}} returns f(v) where \\spad{f} is the predicate attached to \\spad{p.}")) (|predicate| (((|Mapping| (|Boolean|) |#2|) (|Pattern| |#1|)) "\\spad{predicate(p)} returns the predicate attached to \\spad{p,} the constant function \\spad{true} if \\spad{p} has no predicates attached to it.")) (|suchThat| (((|Pattern| |#1|) (|Pattern| |#1|) (|List| (|Symbol|)) (|Mapping| (|Boolean|) (|List| |#2|))) "\\spad{suchThat(p, [a1,...,an], \\spad{f)}} returns a copy of \\spad{p} with the top-level predicate set to \\spad{f(a1,...,an)}.") (((|Pattern| |#1|) (|Pattern| |#1|) (|List| (|Mapping| (|Boolean|) |#2|))) "\\spad{suchThat(p, [f1,...,fn])} makes a copy of \\spad{p} and adds the predicate \\spad{f1} and \\spad{...} and \\spad{fn} to the copy, which is returned.") (((|Pattern| |#1|) (|Pattern| |#1|) (|Mapping| (|Boolean|) |#2|)) "\\spad{suchThat(p, \\spad{f)}} makes a copy of \\spad{p} and adds the predicate \\spad{f} to the copy, which is returned."))) 
 NIL 
 NIL 
-(-892 R S) 
+(-913 R S) 
 ((|constructor| (NIL "Lifts maps to patterns")) (|map| (((|Pattern| |#2|) (|Mapping| |#2| |#1|) (|Pattern| |#1|)) "\\spad{map(f, \\spad{p)}} applies \\spad{f} to all the leaves of \\spad{p} and returns the result as a pattern over \\spad{S.}"))) 
 NIL 
 NIL 
-(-893 R) 
+(-914 R) 
 ((|constructor| (NIL "Patterns for use by the pattern matcher.")) (|optpair| (((|Union| (|List| $) "failed") (|List| $)) "\\spad{optpair(l)} returns \\spad{l} has the form \\spad{[a, \\spad{b]}} and a is optional, and \"failed\" otherwise.")) (|variables| (((|List| $) $) "\\spad{variables(p)} returns the list of matching variables appearing in \\spad{p.}")) (|getBadValues| (((|List| (|Any|)) $) "\\spad{getBadValues(p)} returns the list of \"bad values\" for \\spad{p.} Note: \\spad{p} is not allowed to match any of its \"bad values\".")) (|addBadValue| (($ $ (|Any|)) "\\spad{addBadValue(p, \\spad{v)}} adds \\spad{v} to the list of \"bad values\" for \\spad{p.} Note: \\spad{p} is not allowed to match any of its \"bad values\".")) (|resetBadValues| (($ $) "\\spad{resetBadValues(p)} initializes the list of \"bad values\" for \\spad{p} to \\spad{[]}. Note: \\spad{p} is not allowed to match any of its \"bad values\".")) (|hasTopPredicate?| (((|Boolean|) $) "\\spad{hasTopPredicate?(p)} tests if \\spad{p} has a top-level predicate.")) (|topPredicate| (((|Record| (|:| |var| (|List| (|Symbol|))) (|:| |pred| (|Any|))) $) "\\spad{topPredicate(x)} returns \\spad{[[a1,...,an], \\spad{f]}} where the top-level predicate of \\spad{x} is \\spad{f(a1,...,an)}. Note: \\spad{n} is 0 if \\spad{x} has no top-level predicate.")) (|setTopPredicate| (($ $ (|List| (|Symbol|)) (|Any|)) "\\spad{setTopPredicate(x, [a1,...,an], \\spad{f)}} returns \\spad{x} with the top-level predicate set to \\spad{f(a1,...,an)}.")) (|patternVariable| (($ (|Symbol|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\spad{patternVariable(x, \\spad{c?,} o?, m?)} creates a pattern variable \\spad{x,} which is constant if \\spad{c? = true}, optional if \\spad{o? = true}, and multiple if \\spad{m? = true}.")) (|withPredicates| (($ $ (|List| (|Any|))) "\\spad{withPredicates(p, [p1,...,pn])} makes a copy of \\spad{p} and attaches the predicate \\spad{p1} and \\spad{...} and \\spad{pn} to the copy, which is returned.")) (|setPredicates| (($ $ (|List| (|Any|))) "\\spad{setPredicates(p, [p1,...,pn])} attaches the predicate \\spad{p1} and \\spad{...} and \\spad{pn} to \\spad{p.}")) (|predicates| (((|List| (|Any|)) $) "\\spad{predicates(p)} returns \\spad{[p1,...,pn]} such that the predicate attached to \\spad{p} is \\spad{p1} and \\spad{...} and \\spad{pn.}")) (|hasPredicate?| (((|Boolean|) $) "\\spad{hasPredicate?(p)} tests if \\spad{p} has predicates attached to it.")) (|optional?| (((|Boolean|) $) "\\spad{optional?(p)} tests if \\spad{p} is a single matching variable which can match an identity.")) (|multiple?| (((|Boolean|) $) "\\spad{multiple?(p)} tests if \\spad{p} is a single matching variable allowing list matching or multiple term matching in a sum or product.")) (|generic?| (((|Boolean|) $) "\\spad{generic?(p)} tests if \\spad{p} is a single matching variable.")) (|constant?| (((|Boolean|) $) "\\spad{constant?(p)} tests if \\spad{p} contains no matching variables.")) (|symbol?| (((|Boolean|) $) "\\spad{symbol?(p)} tests if \\spad{p} is a symbol.")) (|quoted?| (((|Boolean|) $) "\\spad{quoted?(p)} tests if \\spad{p} is of the form \\spad{'s} for a symbol \\spad{s.}")) (|inR?| (((|Boolean|) $) "\\spad{inR?(p)} tests if \\spad{p} is an atom (\\spadignore{i.e.} an element of \\spad{R).}")) (|copy| (($ $) "\\spad{copy(p)} returns a recursive copy of \\spad{p.}")) (|convert| (($ (|List| $)) "\\spad{convert([a1,...,an])} returns the pattern \\spad{[a1,...,an]}.")) (|depth| (((|NonNegativeInteger|) $) "\\spad{depth(p)} returns the nesting level of \\spad{p.}")) (/ (($ $ $) "\\spad{a / \\spad{b}} returns the pattern \\spad{a / \\spad{b}.}")) (** (($ $ $) "\\spad{a \\spad{**} \\spad{b}} returns the pattern \\spad{a \\spad{**} \\spad{b}.}") (($ $ (|NonNegativeInteger|)) "\\spad{a \\spad{**} \\spad{n}} returns the pattern \\spad{a \\spad{**} \\spad{n}.}")) (* (($ $ $) "\\spad{a * \\spad{b}} returns the pattern \\spad{a * \\spad{b}.}")) (+ (($ $ $) "\\spad{a + \\spad{b}} returns the pattern \\spad{a + \\spad{b}.}")) (|elt| (($ (|BasicOperator|) (|List| $)) "\\spad{elt(op, [a1,...,an])} returns \\spad{op(a1,...,an)}.")) (|isPower| (((|Union| (|Record| (|:| |val| $) (|:| |exponent| $)) "failed") $) "\\spad{isPower(p)} returns \\spad{[a, \\spad{b]}} if \\spad{p = a \\spad{**} \\spad{b},} and \"failed\" otherwise.")) (|isList| (((|Union| (|List| $) "failed") $) "\\spad{isList(p)} returns \\spad{[a1,...,an]} if \\spad{p = [a1,...,an]}, \"failed\" otherwise.")) (|isQuotient| (((|Union| (|Record| (|:| |num| $) (|:| |den| $)) "failed") $) "\\spad{isQuotient(p)} returns \\spad{[a, \\spad{b]}} if \\spad{p = a / \\spad{b},} and \"failed\" otherwise.")) (|isExpt| (((|Union| (|Record| (|:| |val| $) (|:| |exponent| (|NonNegativeInteger|))) "failed") $) "\\spad{isExpt(p)} returns \\spad{[q, \\spad{n]}} if \\spad{n > 0} and \\spad{p = \\spad{q} \\spad{**} \\spad{n},} and \"failed\" otherwise.")) (|isOp| (((|Union| (|Record| (|:| |op| (|BasicOperator|)) (|:| |arg| (|List| $))) "failed") $) "\\spad{isOp(p)} returns \\spad{[op, [a1,...,an]]} if \\spad{p = op(a1,...,an)}, and \"failed\" otherwise.") (((|Union| (|List| $) "failed") $ (|BasicOperator|)) "\\spad{isOp(p, op)} returns \\spad{[a1,...,an]} if \\spad{p = op(a1,...,an)}, and \"failed\" otherwise.")) (|isTimes| (((|Union| (|List| $) "failed") $) "\\spad{isTimes(p)} returns \\spad{[a1,...,an]} if \\spad{n > 1} and \\spad{p = \\spad{a1} * \\spad{...} * an}, and \"failed\" otherwise.")) (|isPlus| (((|Union| (|List| $) "failed") $) "\\spad{isPlus(p)} returns \\spad{[a1,...,an]} if \\spad{n > 1} \\indented{1}{and \\spad{p = \\spad{a1} + \\spad{...} + an},} and \"failed\" otherwise.")) ((|One|) (($) "1")) ((|Zero|) (($) "0"))) 
 NIL 
 NIL 
-(-894 |VarSet|) 
+(-915 |VarSet|) 
 ((|constructor| (NIL "This domain provides the internal representation of polynomials in non-commutative variables written over the Poincare-Birkhoff-Witt basis. See the \\spadtype{XPBWPolynomial} domain constructor. See Free Lie Algebras by \\spad{C.} Reutenauer (Oxford science publications).")) (|varList| (((|List| |#1|) $) "\\spad{varList([l1]*[l2]*...[ln])} returns the list of variables in the word \\spad{l1*l2*...*ln}.")) (|retractable?| (((|Boolean|) $) "\\spad{retractable?([l1]*[l2]*...[ln])} returns \\spad{true} iff \\spad{n} equals \\spad{1}.")) (|rest| (($ $) "\\spad{rest([l1]*[l2]*...[ln])} returns the list \\spad{l2, .... ln}.")) (|listOfTerms| (((|List| (|LyndonWord| |#1|)) $) "\\spad{listOfTerms([l1]*[l2]*...[ln])} returns the list of words \\spad{l1, \\spad{l2,} .... ln}.")) (|length| (((|NonNegativeInteger|) $) "\\spad{length([l1]*[l2]*...[ln])} returns the length of the word \\spad{l1*l2*...*ln}.")) (|first| (((|LyndonWord| |#1|) $) "\\spad{first([l1]*[l2]*...[ln])} returns the Lyndon word \\spad{l1}.")) (|coerce| (($ |#1|) "\\spad{coerce(v)} return \\spad{v}") (((|OrderedFreeMonoid| |#1|) $) "\\spad{coerce([l1]*[l2]*...[ln])} returns the word \\spad{l1*l2*...*ln}, where \\spad{[l_i]} is the backeted form of the Lyndon word \\spad{l_i}.")) ((|One|) (($) "\\spad{1} returns the empty list."))) 
 NIL 
 NIL 
-(-895 UP R) 
+(-916 UP R) 
 ((|constructor| (NIL "Polynomial composition and decomposition functions\\br If \\spad{f} = \\spad{g} \\spad{o} \\spad{h} then g=leftFactor(f,h) and h=rightFactor(f,g)")) (|compose| ((|#1| |#1| |#1|) "\\spad{compose(p,q)} \\undocumented"))) 
 NIL 
 NIL 
-(-896) 
+(-917) 
 ((|constructor| (NIL "\\axiomType{PartialDifferentialEquationsSolverCategory} is the \\axiom{category} for describing the set of PDE solver \\axiom{domains} with \\axiomFun{measure} and \\axiomFun{PDEsolve}.")) (|PDESolve| (((|Result|) (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) "\\spad{PDESolve(args)} performs the integration of the function given the strategy or method returned by \\axiomFun{measure}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|))) (|RoutinesTable|) (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) "\\spad{measure(R,args)} calculates an estimate of the ability of a particular method to solve a problem. \\blankline This method may be either a specific NAG routine or a strategy (such as transforming the function from one which is difficult to one which is easier to solve). \\blankline It will call whichever agents are needed to perform analysis on the problem in order to calculate the measure. There is a parameter, labelled \\axiom{sofar}, which would contain the best compatibility found so far."))) 
 NIL 
 NIL 
-(-897 UP -3313) 
+(-918 UP -3958) 
 ((|constructor| (NIL "Polynomial composition and decomposition functions\\br If \\spad{f} = \\spad{g} \\spad{o} \\spad{h} then g=leftFactor(f,h) and h=rightFactor(f,g)")) (|rightFactorCandidate| ((|#1| |#1| (|NonNegativeInteger|)) "\\spad{rightFactorCandidate(p,n)} \\undocumented")) (|leftFactor| (((|Union| |#1| "failed") |#1| |#1|) "\\spad{leftFactor(p,q)} \\undocumented")) (|decompose| (((|Union| (|Record| (|:| |left| |#1|) (|:| |right| |#1|)) "failed") |#1| (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{decompose(up,m,n)} \\undocumented") (((|List| |#1|) |#1|) "\\spad{decompose(up)} \\undocumented"))) 
 NIL 
 NIL 
-(-898) 
+(-919) 
 ((|constructor| (NIL "AnnaPartialDifferentialEquationPackage is an uncompleted package for the interface to NAG PDE routines. It has been realised that a new approach to solving PDEs will need to be created.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|)))) (|NumericalPDEProblem|) (|RoutinesTable|)) "\\spad{measure(prob,R)} is a top level ANNA function for identifying the most appropriate numerical routine from those in the routines table provided for solving the numerical PDE problem defined by \\axiom{prob}. \\blankline It calls each \\axiom{domain} listed in \\axiom{R} of \\axiom{category} \\axiomType{PartialDifferentialEquationsSolverCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information. It predicts the likely most effective NAG numerical Library routine to solve the input set of PDEs by checking various attributes of the system of PDEs and calculating a measure of compatibility of each routine to these attributes.") (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|)))) (|NumericalPDEProblem|)) "\\spad{measure(prob)} is a top level ANNA function for identifying the most appropriate numerical routine from those in the routines table provided for solving the numerical PDE problem defined by \\axiom{prob}. \\blankline It calls each \\axiom{domain} of \\axiom{category} \\axiomType{PartialDifferentialEquationsSolverCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information. It predicts the likely most effective NAG numerical Library routine to solve the input set of PDEs by checking various attributes of the system of PDEs and calculating a measure of compatibility of each routine to these attributes.")) (|solve| (((|Result|) (|Float|) (|Float|) (|Float|) (|Float|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|List| (|Expression| (|Float|))) (|List| (|List| (|Expression| (|Float|)))) (|String|)) "\\spad{solve(xmin,ymin,xmax,ymax,ngx,ngy,pde,bounds,st)} is a top level ANNA function to solve numerically a system of partial differential equations. This is defined as a list of coefficients (\\axiom{pde}), a grid (\\axiom{xmin}, \\axiom{ymin}, \\axiom{xmax}, \\axiom{ymax}, \\axiom{ngx}, \\axiom{ngy}) and the boundary values (\\axiom{bounds}). A default value for tolerance is used. There is also a parameter (\\axiom{st}) which should contain the value \"elliptic\" if the PDE is known to be elliptic, or \"unknown\" if it is uncertain. This causes the routine to check whether the PDE is elliptic. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of PDE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine. \\blankline \\spad{**} At the moment, only Second Order Elliptic Partial Differential Equations are solved \\spad{**}") (((|Result|) (|Float|) (|Float|) (|Float|) (|Float|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|List| (|Expression| (|Float|))) (|List| (|List| (|Expression| (|Float|)))) (|String|) (|DoubleFloat|)) "\\spad{solve(xmin,ymin,xmax,ymax,ngx,ngy,pde,bounds,st,tol)} is a top level ANNA function to solve numerically a system of partial differential equations. This is defined as a list of coefficients (\\axiom{pde}), a grid (\\axiom{xmin}, \\axiom{ymin}, \\axiom{xmax}, \\axiom{ymax}, \\axiom{ngx}, \\axiom{ngy}), the boundary values (\\axiom{bounds}) and a tolerance requirement (\\axiom{tol}). There is also a parameter (\\axiom{st}) which should contain the value \"elliptic\" if the PDE is known to be elliptic, or \"unknown\" if it is uncertain. This causes the routine to check whether the PDE is elliptic. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of PDE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine. \\blankline \\spad{**} At the moment, only Second Order Elliptic Partial Differential Equations are solved \\spad{**}") (((|Result|) (|NumericalPDEProblem|) (|RoutinesTable|)) "\\spad{solve(PDEProblem,routines)} is a top level ANNA function to solve numerically a system of partial differential equations. \\blankline The method used to perform the numerical process will be one of the \\spad{routines} contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of PDE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine. \\blankline \\spad{**} At the moment, only Second Order Elliptic Partial Differential Equations are solved \\spad{**}") (((|Result|) (|NumericalPDEProblem|)) "\\spad{solve(PDEProblem)} is a top level ANNA function to solve numerically a system of partial differential equations. \\blankline The method used to perform the numerical process will be one of the routines contained in the NAG numerical Library. The function predicts the likely most effective routine by checking various attributes of the system of PDE's and calculating a measure of compatibility of each routine to these attributes. \\blankline It then calls the resulting `best' routine. \\blankline \\spad{**} At the moment, only Second Order Elliptic Partial Differential Equations are solved \\spad{**}"))) 
 NIL 
 NIL 
-(-899) 
+(-920) 
 ((|constructor| (NIL "\\axiomType{NumericalPDEProblem} is a \\axiom{domain} for the representation of Numerical PDE problems for use by ANNA. \\blankline The representation is of type: \\blankline \\axiomType{Record}(pde:\\axiomType{List Expression DoubleFloat}, \\spad{\\br} constraints:\\axiomType{List PDEC}, \\spad{\\br} f:\\axiomType{List List Expression DoubleFloat},\\br st:\\axiomType{String},\\br tol:\\axiomType{DoubleFloat}) \\blankline where \\axiomType{PDEC} is of type: \\blankline \\axiomType{Record}(start:\\axiomType{DoubleFloat}, \\spad{\\br} finish:\\axiomType{DoubleFloat},\\br grid:\\axiomType{NonNegativeInteger},\\br boundaryType:\\axiomType{Integer},\\br dStart:\\axiomType{Matrix DoubleFloat}, \\spad{\\br} dFinish:\\axiomType{Matrix DoubleFloat})")) (|retract| (((|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|))) $) "\\spad{retract(x)} is not documented")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(x)} is not documented") (($ (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) "\\spad{coerce(x)} is not documented"))) 
 NIL 
 NIL 
-(-900 A S) 
+(-921 A S) 
 ((|constructor| (NIL "A partial differential ring with differentiations indexed by a parameter type \\spad{S.} \\blankline Axioms\\br \\tab{5}\\spad{differentiate(x+y,e)=differentiate(x,e)+differentiate(y,e)}\\br \\tab{5}\\spad{differentiate(x*y,e)=x*differentiate(y,e)+differentiate(x,e)*y}")) (D (($ $ (|List| |#2|) (|List| (|NonNegativeInteger|))) "\\spad{D(x, [s1,...,sn], [n1,...,nn])} computes multiple partial derivatives, that is, \\spad{D(...D(x, \\spad{s1,} n1)..., \\spad{sn,} nn)}.") (($ $ |#2| (|NonNegativeInteger|)) "\\spad{D(x, \\spad{s,} \\spad{n)}} computes multiple partial derivatives, that is, \\spad{n}-th derivative of \\spad{x} with respect to \\spad{s.}") (($ $ (|List| |#2|)) "\\spad{D(x,[s1,...sn])} computes successive partial derivatives, that is, \\spad{D(...D(x, s1)..., sn)}.") (($ $ |#2|) "\\spad{D(x,v)} computes the partial derivative of \\spad{x} with respect to \\spad{v.}")) (|differentiate| (($ $ (|List| |#2|) (|List| (|NonNegativeInteger|))) "\\spad{differentiate(x, [s1,...,sn], [n1,...,nn])} computes multiple partial derivatives, that is, \\spad{D(...D(x, s1)..., sn)}.") (($ $ |#2| (|NonNegativeInteger|)) "\\spad{differentiate(x, \\spad{s,} \\spad{n)}} computes multiple partial derivatives, that is, \\spad{n}-th derivative of \\spad{x} with respect to \\spad{s.}") (($ $ (|List| |#2|)) "\\spad{differentiate(x,[s1,...sn])} computes successive partial derivatives, that is, \\spad{differentiate(...differentiate(x, s1)..., sn)}.") (($ $ |#2|) "\\spad{differentiate(x,v)} computes the partial derivative of \\spad{x} with respect to \\spad{v.}"))) 
 NIL 
 NIL 
-(-901 S) 
+(-922 S) 
 ((|constructor| (NIL "A partial differential ring with differentiations indexed by a parameter type \\spad{S.} \\blankline Axioms\\br \\tab{5}\\spad{differentiate(x+y,e)=differentiate(x,e)+differentiate(y,e)}\\br \\tab{5}\\spad{differentiate(x*y,e)=x*differentiate(y,e)+differentiate(x,e)*y}")) (D (($ $ (|List| |#1|) (|List| (|NonNegativeInteger|))) "\\spad{D(x, [s1,...,sn], [n1,...,nn])} computes multiple partial derivatives, that is, \\spad{D(...D(x, \\spad{s1,} n1)..., \\spad{sn,} nn)}.") (($ $ |#1| (|NonNegativeInteger|)) "\\spad{D(x, \\spad{s,} \\spad{n)}} computes multiple partial derivatives, that is, \\spad{n}-th derivative of \\spad{x} with respect to \\spad{s.}") (($ $ (|List| |#1|)) "\\spad{D(x,[s1,...sn])} computes successive partial derivatives, that is, \\spad{D(...D(x, s1)..., sn)}.") (($ $ |#1|) "\\spad{D(x,v)} computes the partial derivative of \\spad{x} with respect to \\spad{v.}")) (|differentiate| (($ $ (|List| |#1|) (|List| (|NonNegativeInteger|))) "\\spad{differentiate(x, [s1,...,sn], [n1,...,nn])} computes multiple partial derivatives, that is, \\spad{D(...D(x, s1)..., sn)}.") (($ $ |#1| (|NonNegativeInteger|)) "\\spad{differentiate(x, \\spad{s,} \\spad{n)}} computes multiple partial derivatives, that is, \\spad{n}-th derivative of \\spad{x} with respect to \\spad{s.}") (($ $ (|List| |#1|)) "\\spad{differentiate(x,[s1,...sn])} computes successive partial derivatives, that is, \\spad{differentiate(...differentiate(x, s1)..., sn)}.") (($ $ |#1|) "\\spad{differentiate(x,v)} computes the partial derivative of \\spad{x} with respect to \\spad{v.}"))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-902 S) 
+(-923 S) 
 ((|constructor| (NIL "A PendantTree(S) is either a leaf? and is an \\spad{S} or has a left and a right both PendantTree(S)'s")) (|coerce| (((|Tree| |#1|) $) "\\indented{1}{coerce(x) is not documented} \\blankline \\spad{X} t1:=ptree([1,2,3]) \\spad{X} t2:=ptree(t1,ptree([1,2,3])) \\spad{X} t2::Tree List PositiveInteger")) (|ptree| (($ $ $) "\\indented{1}{ptree(x,y) is not documented} \\blankline \\spad{X} t1:=ptree([1,2,3]) \\spad{X} ptree(t1,ptree([1,2,3]))") (($ |#1|) "\\indented{1}{ptree(s) is a leaf? pendant tree} \\blankline \\spad{X} t1:=ptree([1,2,3])"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-903 |n| R) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-924 |n| R) 
 ((|constructor| (NIL "Permanent implements the functions permanent, the permanent for square matrices.")) (|permanent| ((|#2| (|SquareMatrix| |#1| |#2|)) "\\spad{permanent(x)} computes the permanent of a square matrix \\spad{x.} The permanent is equivalent to the \\spadfun{determinant} except that coefficients have no change of sign. This function is much more difficult to compute than the determinant. The formula used is by H.J. Ryser, improved by [Nijenhuis and Wilf, \\spad{Ch.} 19]. Note that permanent(x) choose one of three algorithms, depending on the underlying ring \\spad{R} and on \\spad{n,} the number of rows (and columns) of x:\\br if 2 has an inverse in \\spad{R} we can use the algorithm of [Nijenhuis and Wilf, ch.19,p.158]; if 2 has no inverse, some modifications are necessary:\\br if \\spad{n} > 6 and \\spad{R} is an integral domain with characteristic different from 2 (the algorithm works if and only 2 is not a zero-divisor of \\spad{R} and characteristic()$R \\spad{^=} 2, but how to check that for any given \\spad{R} \\spad{?),} the local function \\spad{permanent2} is called;\\br else, the local function \\spad{permanent3} is called (works for all commutative rings \\spad{R).}"))) 
 NIL 
 NIL 
-(-904 S) 
+(-925 S) 
 ((|constructor| (NIL "PermutationCategory provides a categorial environment for subgroups of bijections of a set (that is, permutations)")) (< (((|Boolean|) $ $) "\\spad{p < \\spad{q}} is an order relation on permutations. Note that this order is only total if and only if \\spad{S} is totally ordered or \\spad{S} is finite.")) (|orbit| (((|Set| |#1|) $ |#1|) "\\spad{orbit(p, el)} returns the orbit of el under the permutation \\spad{p,} that is, the set which is given by applications of the powers of \\spad{p} to el.")) (|elt| ((|#1| $ |#1|) "\\spad{elt(p, el)} returns the image of el under the permutation \\spad{p.}")) (|eval| ((|#1| $ |#1|) "\\spad{eval(p, el)} returns the image of el under the permutation \\spad{p.}")) (|cycles| (($ (|List| (|List| |#1|))) "\\spad{cycles(lls)} coerces a list list of cycles \\spad{lls} to a permutation, each cycle being a list with not repetitions, is coerced to the permutation, which maps ls.i to ls.i+1, indices modulo the length of the list, then these permutations are mutiplied. Error: if repetitions occur in one cycle.")) (|cycle| (($ (|List| |#1|)) "\\spad{cycle(ls)} coerces a cycle \\spad{ls,} that is, a list with not repetitions to a permutation, which maps ls.i to ls.i+1, indices modulo the length of the list. Error: if repetitions occur."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-905 S) 
+(-926 S) 
 ((|constructor| (NIL "PermutationGroup implements permutation groups acting on a set \\spad{S,} \\spadignore{i.e.} all subgroups of the symmetric group of \\spad{S,} represented as a list of permutations (generators). Note that therefore the objects are not members of the Axiom category \\spadtype{Group}. Using the idea of base and strong generators by Sims, basic routines and algorithms are implemented so that the word problem for permutation groups can be solved.")) (|initializeGroupForWordProblem| (((|Void|) $ (|Integer|) (|Integer|)) "\\spad{initializeGroupForWordProblem(gp,m,n)} initializes the group \\spad{gp} for the word problem. Notes: \\spad{(1)} with a small integer you get shorter words, but the routine takes longer than the standard routine for longer words. \\spad{(2)} be careful: invoking this routine will destroy the possibly stored information about your group (but will recompute it again). \\spad{(3)} users need not call this function normally for the soultion of the word problem.") (((|Void|) $) "\\spad{initializeGroupForWordProblem(gp)} initializes the group \\spad{gp} for the word problem. Notes: it calls the other function of this name with parameters 0 and 1: initializeGroupForWordProblem(gp,0,1). Notes: \\spad{(1)} be careful: invoking this routine will destroy the possibly information about your group (but will recompute it again) \\spad{(2)} users need not call this function normally for the soultion of the word problem.")) (<= (((|Boolean|) $ $) "\\spad{gp1 \\spad{<=} gp2} returns \\spad{true} if and only if \\spad{gp1} is a subgroup of gp2. Note: because of a bug in the parser you have to call this function explicitly by \\spad{gp1} <=$(PERMGRP \\spad{S)} gp2.")) (< (((|Boolean|) $ $) "\\spad{gp1 < gp2} returns \\spad{true} if and only if \\spad{gp1} is a proper subgroup of gp2.")) (|movedPoints| (((|Set| |#1|) $) "\\spad{movedPoints(gp)} returns the points moved by the group \\spad{gp.}")) (|wordInGenerators| (((|List| (|NonNegativeInteger|)) (|Permutation| |#1|) $) "\\spad{wordInGenerators(p,gp)} returns the word for the permutation \\spad{p} in the original generators of the group \\spad{gp,} represented by the indices of the list, given by generators.")) (|wordInStrongGenerators| (((|List| (|NonNegativeInteger|)) (|Permutation| |#1|) $) "\\spad{wordInStrongGenerators(p,gp)} returns the word for the permutation \\spad{p} in the strong generators of the group \\spad{gp,} represented by the indices of the list, given by strongGenerators.")) (|member?| (((|Boolean|) (|Permutation| |#1|) $) "\\spad{member?(pp,gp)} answers the question, whether the permutation \\spad{pp} is in the group \\spad{gp} or not.")) (|orbits| (((|Set| (|Set| |#1|)) $) "\\spad{orbits(gp)} returns the orbits of the group \\spad{gp,} \\spadignore{i.e.} it partitions the (finite) of all moved points.")) (|orbit| (((|Set| (|List| |#1|)) $ (|List| |#1|)) "\\spad{orbit(gp,ls)} returns the orbit of the ordered list \\spad{ls} under the group \\spad{gp.} Note: return type is \\spad{L} \\spad{L} \\spad{S} temporarily because FSET \\spad{L} \\spad{S} has an error.") (((|Set| (|Set| |#1|)) $ (|Set| |#1|)) "\\spad{orbit(gp,els)} returns the orbit of the unordered set \\spad{els} under the group \\spad{gp.}") (((|Set| |#1|) $ |#1|) "\\spad{orbit(gp,el)} returns the orbit of the element \\spad{el} under the group \\spad{gp,} \\spadignore{i.e.} the set of all points gained by applying each group element to el.")) (|permutationGroup| (($ (|List| (|Permutation| |#1|))) "\\spad{permutationGroup(ls)} coerces a list of permutations \\spad{ls} to the group generated by this list.")) (|wordsForStrongGenerators| (((|List| (|List| (|NonNegativeInteger|))) $) "\\spad{wordsForStrongGenerators(gp)} returns the words for the strong generators of the group \\spad{gp} in the original generators of \\spad{gp,} represented by their indices in the list, given by generators.")) (|strongGenerators| (((|List| (|Permutation| |#1|)) $) "\\spad{strongGenerators(gp)} returns strong generators for the group \\spad{gp.}")) (|base| (((|List| |#1|) $) "\\spad{base(gp)} returns a base for the group \\spad{gp.}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(gp)} returns the number of points moved by all permutations of the group \\spad{gp.}")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(gp)} returns the order of the group \\spad{gp.}")) (|random| (((|Permutation| |#1|) $) "\\spad{random(gp)} returns a random product of maximal 20 generators of the group \\spad{gp.} Note: random(gp)=random(gp,20).") (((|Permutation| |#1|) $ (|Integer|)) "\\spad{random(gp,i)} returns a random product of maximal \\spad{i} generators of the group \\spad{gp.}")) (|elt| (((|Permutation| |#1|) $ (|NonNegativeInteger|)) "\\spad{elt(gp,i)} returns the \\spad{i}-th generator of the group \\spad{gp.}")) (|generators| (((|List| (|Permutation| |#1|)) $) "\\spad{generators(gp)} returns the generators of the group \\spad{gp.}")) (|coerce| (($ (|List| (|Permutation| |#1|))) "\\spad{coerce(ls)} coerces a list of permutations \\spad{ls} to the group generated by this list.") (((|List| (|Permutation| |#1|)) $) "\\spad{coerce(gp)} returns the generators of the group \\spad{gp.}"))) 
 NIL 
 NIL 
-(-906 S) 
+(-927 S) 
 ((|constructor| (NIL "Permutation(S) implements the group of all bijections on a set \\spad{S,} which move only a finite number of points. A permutation is considered as a map from \\spad{S} into \\spad{S.} In particular multiplication is defined as composition of maps:\\br \\spad{pi1} * \\spad{pi2} = \\spad{pi1} \\spad{o} pi2.\\br The internal representation of permuatations are two lists of equal length representing preimages and images.")) (|coerceImages| (($ (|List| |#1|)) "\\spad{coerceImages(ls)} coerces the list \\spad{ls} to a permutation whose image is given by \\spad{ls} and the preimage is fixed to be [1,...,n]. Note: {coerceImages(ls)=coercePreimagesImages([1,...,n],ls)}. We assume that both preimage and image do not contain repetitions.")) (|fixedPoints| (((|Set| |#1|) $) "\\indented{1}{fixedPoints(p) returns the points fixed by the permutation \\spad{p.}} \\spad{X} \\spad{p} \\spad{:=} coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4 \\spad{X} fixedPoints \\spad{p}")) (|sort| (((|List| $) (|List| $)) "\\spad{sort(lp)} sorts a list of permutations \\spad{lp} according to cycle structure first according to length of cycles, second, if \\spad{S} has \\spadtype{Finite} or \\spad{S} has \\spadtype{OrderedSet} according to lexicographical order of entries in cycles of equal length.")) (|odd?| (((|Boolean|) $) "\\spad{odd?(p)} returns \\spad{true} if and only if \\spad{p} is an odd permutation \\spadignore{i.e.} sign(p) is \\spad{-1.}")) (|even?| (((|Boolean|) $) "\\indented{1}{even?(p) returns \\spad{true} if and only if \\spad{p} is an even permutation,} \\indented{1}{\\spadignore{i.e.} sign(p) is 1.} \\blankline \\spad{X} \\spad{p} \\spad{:=} coercePreimagesImages([[1,2,3],[1,2,3]]) \\spad{X} even? \\spad{p}")) (|sign| (((|Integer|) $) "\\spad{sign(p)} returns the signum of the permutation \\spad{p,} \\spad{+1} or \\spad{-1.}")) (|numberOfCycles| (((|NonNegativeInteger|) $) "\\spad{numberOfCycles(p)} returns the number of non-trivial cycles of the permutation \\spad{p.}")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(p)} returns the order of a permutation \\spad{p} as a group element.")) (|cyclePartition| (((|Partition|) $) "\\spad{cyclePartition(p)} returns the cycle structure of a permutation \\spad{p} including cycles of length 1 only if \\spad{S} is finite.")) (|movedPoints| (((|Set| |#1|) $) "\\indented{1}{movedPoints(p) returns the set of points moved by the permutation \\spad{p.}} \\blankline \\spad{X} \\spad{p} \\spad{:=} coercePreimagesImages([[1,2,3],[1,2,3]]) \\spad{X} movedPoints \\spad{p}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(p)} retuns the number of points moved by the permutation \\spad{p.}")) (|coerceListOfPairs| (($ (|List| (|List| |#1|))) "\\spad{coerceListOfPairs(lls)} coerces a list of pairs \\spad{lls} to a permutation. Error: if not consistent, \\spadignore{i.e.} the set of the first elements coincides with the set of second elements. coerce(p) generates output of the permutation \\spad{p} with domain OutputForm.")) (|coerce| (($ (|List| |#1|)) "\\spad{coerce(ls)} coerces a cycle \\spad{ls,} \\spadignore{i.e.} a list with not repetitions to a permutation, which maps ls.i to ls.i+1, indices modulo the length of the list. Error: if repetitions occur.") (($ (|List| (|List| |#1|))) "\\spad{coerce(lls)} coerces a list of cycles \\spad{lls} to a permutation, each cycle being a list with no repetitions, is coerced to the permutation, which maps ls.i to ls.i+1, indices modulo the length of the list, then these permutations are mutiplied. Error: if repetitions occur in one cycle.")) (|coercePreimagesImages| (($ (|List| (|List| |#1|))) "\\indented{1}{coercePreimagesImages(lls) coerces the representation lls} \\indented{1}{of a permutation as a list of preimages and images to a permutation.} \\indented{1}{We assume that both preimage and image do not contain repetitions.} \\blankline \\spad{X} \\spad{p} \\spad{:=} coercePreimagesImages([[1,2,3],[1,2,3]]) \\spad{X} \\spad{q} \\spad{:=} coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4")) (|listRepresentation| (((|Record| (|:| |preimage| (|List| |#1|)) (|:| |image| (|List| |#1|))) $) "\\spad{listRepresentation(p)} produces a representation rep of the permutation \\spad{p} as a list of preimages and images, i.e \\spad{p} maps (rep.preimage).k to (rep.image).k for all indices \\spad{k.} Elements of \\spad{S} not in (rep.preimage).k are fixed points, and these are the only fixed points of the permutation."))) 
-((-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-848))))) 
-(-907 R E |VarSet| S) 
+((-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-869))))) 
+(-928 R E |VarSet| S) 
 ((|constructor| (NIL "PolynomialFactorizationByRecursion(R,E,VarSet,S) is used for factorization of sparse univariate polynomials over a domain \\spad{S} of multivariate polynomials over \\spad{R.}")) (|factorSFBRlcUnit| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|List| |#3|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factorSFBRlcUnit(p)} returns the square free factorization of polynomial \\spad{p} (see \\spadfun{factorSquareFreeByRecursion}{PolynomialFactorizationByRecursionUnivariate}) in the case where the leading coefficient of \\spad{p} is a unit.")) (|bivariateSLPEBR| (((|Union| (|List| (|SparseUnivariatePolynomial| |#4|)) "failed") (|List| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|) |#3|) "\\spad{bivariateSLPEBR(lp,p,v)} implements the bivariate case of solveLinearPolynomialEquationByRecursion its implementation depends on \\spad{R}")) (|randomR| ((|#1|) "\\spad{randomR produces} a random element of \\spad{R}")) (|factorSquareFreeByRecursion| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factorSquareFreeByRecursion(p)} returns the square free factorization of \\spad{p.} This functions performs the recursion step for factorSquareFreePolynomial, as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{factorSquareFreePolynomial}).")) (|factorByRecursion| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factorByRecursion(p)} factors polynomial \\spad{p.} This function performs the recursion step for factorPolynomial, as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{factorPolynomial})")) (|solveLinearPolynomialEquationByRecursion| (((|Union| (|List| (|SparseUnivariatePolynomial| |#4|)) "failed") (|List| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{solveLinearPolynomialEquationByRecursion([p1,...,pn],p)} returns the list of polynomials \\spad{[q1,...,qn]} such that \\spad{sum qi/pi = \\spad{p} / prod pi}, a recursion step for solveLinearPolynomialEquation as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{solveLinearPolynomialEquation}). If no such list of \\spad{qi} exists, then \"failed\" is returned."))) 
 NIL 
 NIL 
-(-908 R S) 
+(-929 R S) 
 ((|constructor| (NIL "PolynomialFactorizationByRecursionUnivariate \\spad{R} is a \\spadfun{PolynomialFactorizationExplicit} domain, \\spad{S} is univariate polynomials over \\spad{R} We are interested in handling SparseUnivariatePolynomials over \\spad{S,} is a variable we shall call \\spad{z}")) (|factorSFBRlcUnit| (((|Factored| (|SparseUnivariatePolynomial| |#2|)) (|SparseUnivariatePolynomial| |#2|)) "\\spad{factorSFBRlcUnit(p)} returns the square free factorization of polynomial \\spad{p} (see \\spadfun{factorSquareFreeByRecursion}{PolynomialFactorizationByRecursionUnivariate}) in the case where the leading coefficient of \\spad{p} is a unit.")) (|randomR| ((|#1|) "\\spad{randomR()} produces a random element of \\spad{R}")) (|factorSquareFreeByRecursion| (((|Factored| (|SparseUnivariatePolynomial| |#2|)) (|SparseUnivariatePolynomial| |#2|)) "\\spad{factorSquareFreeByRecursion(p)} returns the square free factorization of \\spad{p.} This functions performs the recursion step for factorSquareFreePolynomial, as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{factorSquareFreePolynomial}).")) (|factorByRecursion| (((|Factored| (|SparseUnivariatePolynomial| |#2|)) (|SparseUnivariatePolynomial| |#2|)) "\\spad{factorByRecursion(p)} factors polynomial \\spad{p.} This function performs the recursion step for factorPolynomial, as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{factorPolynomial})")) (|solveLinearPolynomialEquationByRecursion| (((|Union| (|List| (|SparseUnivariatePolynomial| |#2|)) "failed") (|List| (|SparseUnivariatePolynomial| |#2|)) (|SparseUnivariatePolynomial| |#2|)) "\\spad{solveLinearPolynomialEquationByRecursion([p1,...,pn],p)} returns the list of polynomials \\spad{[q1,...,qn]} such that \\spad{sum qi/pi = \\spad{p} / prod pi}, a recursion step for solveLinearPolynomialEquation as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{solveLinearPolynomialEquation}). If no such list of \\spad{qi} exists, then \"failed\" is returned."))) 
 NIL 
 NIL 
-(-909 S) 
+(-930 S) 
 ((|constructor| (NIL "This is the category of domains that know \"enough\" about themselves in order to factor univariate polynomials over themselves. This will be used in future releases for supporting factorization over finitely generated coefficient fields, it is not yet available in the current release of axiom.")) (|charthRoot| (((|Union| $ "failed") $) "\\spad{charthRoot(r)} returns the \\spad{p}-th root of \\spad{r,} or \"failed\" if none exists in the domain.")) (|conditionP| (((|Union| (|Vector| $) "failed") (|Matrix| $)) "\\spad{conditionP(m)} returns a vector of elements, not all zero, whose \\spad{p}-th powers \\spad{(p} is the characteristic of the domain) are a solution of the homogenous linear system represented by \\spad{m,} or \"failed\" is there is no such vector.")) (|solveLinearPolynomialEquation| (((|Union| (|List| (|SparseUnivariatePolynomial| $)) "failed") (|List| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{solveLinearPolynomialEquation([f1, ..., fn], \\spad{g)}} (where the \\spad{fi} are relatively prime to each other) returns a list of \\spad{ai} such that \\spad{g/prod \\spad{fi} = sum ai/fi} or returns \"failed\" if no such list of ai's exists.")) (|gcdPolynomial| (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $)) "\\spad{gcdPolynomial(p,q)} returns the \\spad{gcd} of the univariate polynomials \\spad{p} \\spad{qnd} \\spad{q.}")) (|factorSquareFreePolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{factorSquareFreePolynomial(p)} factors the univariate polynomial \\spad{p} into irreducibles where \\spad{p} is known to be square free and primitive with respect to its main variable.")) (|factorPolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{factorPolynomial(p)} returns the factorization into irreducibles of the univariate polynomial \\spad{p.}")) (|squareFreePolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{squareFreePolynomial(p)} returns the square-free factorization of the univariate polynomial \\spad{p.}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-149)))) 
-(-910) 
+((|HasCategory| |#1| (QUOTE (-169)))) 
+(-931) 
 ((|constructor| (NIL "This is the category of domains that know \"enough\" about themselves in order to factor univariate polynomials over themselves. This will be used in future releases for supporting factorization over finitely generated coefficient fields, it is not yet available in the current release of axiom.")) (|charthRoot| (((|Union| $ "failed") $) "\\spad{charthRoot(r)} returns the \\spad{p}-th root of \\spad{r,} or \"failed\" if none exists in the domain.")) (|conditionP| (((|Union| (|Vector| $) "failed") (|Matrix| $)) "\\spad{conditionP(m)} returns a vector of elements, not all zero, whose \\spad{p}-th powers \\spad{(p} is the characteristic of the domain) are a solution of the homogenous linear system represented by \\spad{m,} or \"failed\" is there is no such vector.")) (|solveLinearPolynomialEquation| (((|Union| (|List| (|SparseUnivariatePolynomial| $)) "failed") (|List| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{solveLinearPolynomialEquation([f1, ..., fn], \\spad{g)}} (where the \\spad{fi} are relatively prime to each other) returns a list of \\spad{ai} such that \\spad{g/prod \\spad{fi} = sum ai/fi} or returns \"failed\" if no such list of ai's exists.")) (|gcdPolynomial| (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $)) "\\spad{gcdPolynomial(p,q)} returns the \\spad{gcd} of the univariate polynomials \\spad{p} \\spad{qnd} \\spad{q.}")) (|factorSquareFreePolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{factorSquareFreePolynomial(p)} factors the univariate polynomial \\spad{p} into irreducibles where \\spad{p} is known to be square free and primitive with respect to its main variable.")) (|factorPolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{factorPolynomial(p)} returns the factorization into irreducibles of the univariate polynomial \\spad{p.}")) (|squareFreePolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{squareFreePolynomial(p)} returns the square-free factorization of the univariate polynomial \\spad{p.}"))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-911 |p|) 
+(-932 |p|) 
 ((|constructor| (NIL "PrimeField(p) implements the field with \\spad{p} elements if \\spad{p} is a prime number."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| $ (QUOTE (-151))) (|HasCategory| $ (QUOTE (-149))) (|HasCategory| $ (QUOTE (-374)))) 
-(-912 R0 -3313 UP UPUP R) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| $ (QUOTE (-171))) (|HasCategory| $ (QUOTE (-169))) (|HasCategory| $ (QUOTE (-394)))) 
+(-933 R0 -3958 UP UPUP R) 
 ((|constructor| (NIL "This package provides function for testing whether a divisor on a curve is a torsion divisor.")) (|torsionIfCan| (((|Union| (|Record| (|:| |order| (|NonNegativeInteger|)) (|:| |function| |#5|)) "failed") (|FiniteDivisor| |#2| |#3| |#4| |#5|)) "\\spad{torsionIfCan(f)}\\ undocumented")) (|torsion?| (((|Boolean|) (|FiniteDivisor| |#2| |#3| |#4| |#5|)) "\\spad{torsion?(f)} \\undocumented")) (|order| (((|Union| (|NonNegativeInteger|) "failed") (|FiniteDivisor| |#2| |#3| |#4| |#5|)) "\\spad{order(f)} \\undocumented"))) 
 NIL 
 NIL 
-(-913 UP UPUP R) 
+(-934 UP UPUP R) 
 ((|constructor| (NIL "This package provides function for testing whether a divisor on a curve is a torsion divisor.")) (|torsionIfCan| (((|Union| (|Record| (|:| |order| (|NonNegativeInteger|)) (|:| |function| |#3|)) "failed") (|FiniteDivisor| (|Fraction| (|Integer|)) |#1| |#2| |#3|)) "\\spad{torsionIfCan(f)} \\undocumented")) (|torsion?| (((|Boolean|) (|FiniteDivisor| (|Fraction| (|Integer|)) |#1| |#2| |#3|)) "\\spad{torsion?(f)} \\undocumented")) (|order| (((|Union| (|NonNegativeInteger|) "failed") (|FiniteDivisor| (|Fraction| (|Integer|)) |#1| |#2| |#3|)) "\\spad{order(f)} \\undocumented"))) 
 NIL 
 NIL 
-(-914 R |PolyRing| E -3465) 
+(-935 R |PolyRing| E -3832) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|degreeOfMinimalForm| (((|NonNegativeInteger|) |#2|) "\\spad{degreeOfMinimalForm does} what it says")) (|listAllMono| (((|List| |#2|) (|NonNegativeInteger|)) "\\spad{listAllMono(l)} returns all the monomials of degree \\spad{l}")) (|listAllMonoExp| (((|List| |#3|) (|Integer|)) "\\spad{listAllMonoExp(l)} returns all the exponents of degree \\spad{l}")) (|homogenize| ((|#2| |#2| (|Integer|)) "\\spad{homogenize(pol,n)} returns the homogenized polynomial of \\spad{pol} with respect to the \\spad{n}-th variable.")) (|constant| ((|#1| |#2|) "\\spad{constant(pol)} returns the constant term of the polynomial.")) (|degOneCoef| ((|#1| |#2| (|PositiveInteger|)) "\\spad{degOneCoef(pol,n)} returns the coefficient in front of the monomial specified by the positive integer.")) (|translate| ((|#2| |#2| (|List| |#1|)) "\\spad{translate(pol,[a,b,c])} apply to \\spad{pol} the linear change of coordinates, x->x+a, y->y+b, z->z+c") ((|#2| |#2| (|List| |#1|) (|Integer|)) "\\spad{translate(pol,[a,b,c],3)} apply to \\spad{pol} the linear change of coordinates, x->x+a, y->y+b, z->1.")) (|replaceVarByOne| ((|#2| |#2| (|Integer|)) "\\spad{replaceVarByOne(pol,a)} evaluate to one the variable in \\spad{pol} specified by the integer a.")) (|replaceVarByZero| ((|#2| |#2| (|Integer|)) "\\spad{replaceVarByZero(pol,a)} evaluate to zero the variable in \\spad{pol} specified by the integer a.")) (|firstExponent| ((|#3| |#2|) "\\spad{firstExponent(pol)} returns the exponent of the first term in the representation of pol. Not to be confused with the leadingExponent \\indented{1}{which is the highest exponent according to the order} over the monomial.")) (|minimalForm| ((|#2| |#2|) "\\spad{minimalForm(pol)} returns the minimal forms of the polynomial pol."))) 
 NIL 
 NIL 
-(-915 UP UPUP) 
+(-936 UP UPUP) 
 ((|constructor| (NIL "Utilities for PFOQ and PFO")) (|polyred| ((|#2| |#2|) "\\spad{polyred(u)} \\undocumented")) (|doubleDisc| (((|Integer|) |#2|) "\\spad{doubleDisc(u)} \\undocumented")) (|mix| (((|Integer|) (|List| (|Record| (|:| |den| (|Integer|)) (|:| |gcdnum| (|Integer|))))) "\\spad{mix(l)} \\undocumented")) (|badNum| (((|Integer|) |#2|) "\\spad{badNum(u)} \\undocumented") (((|Record| (|:| |den| (|Integer|)) (|:| |gcdnum| (|Integer|))) |#1|) "\\spad{badNum(p)} \\undocumented")) (|getGoodPrime| (((|PositiveInteger|) (|Integer|)) "\\spad{getGoodPrime \\spad{n}} returns the smallest prime not dividing \\spad{n}"))) 
 NIL 
 NIL 
-(-916 R) 
+(-937 R) 
 ((|constructor| (NIL "The domain \\spadtype{PartialFraction} implements partial fractions over a euclidean domain \\spad{R}. This requirement on the argument domain allows us to normalize the fractions. Of particular interest are the 2 forms for these fractions. The ``compact'' form has only one fractional term per prime in the denominator, while the ``p-adic'' form expands each numerator p-adically via the prime \\spad{p} in the denominator. For computational efficiency, the compact form is used, though the p-adic form may be gotten by calling the function padicFraction}. For a general euclidean domain, it is not known how to factor the denominator. Thus the function partialFraction takes as its second argument an element of \\spadtype{Factored(R)}.")) (|wholePart| ((|#1| $) "\\indented{1}{wholePart(p) extracts the whole part of the partial fraction} \\indented{1}{\\spad{p}.} \\blankline \\spad{X} a:=(74/13)::PFR(INT) \\spad{X} wholePart(a)")) (|partialFraction| (($ |#1| (|Factored| |#1|)) "\\indented{1}{partialFraction(numer,denom) is the main function for} \\indented{1}{constructing partial fractions. The second argument is the} \\indented{1}{denominator and should be factored.} \\blankline \\spad{X} partialFraction(1,factorial 10)")) (|padicFraction| (($ $) "\\indented{1}{padicFraction(q) expands the fraction p-adically in the primes} \\indented{1}{\\spad{p} in the denominator of \\spad{q}. For example,} \\indented{1}{\\spad{padicFraction(3/(2**2)) = 1/2 + 1/(2**2)}.} \\indented{1}{Use compactFraction from PartialFraction to} \\indented{1}{return to compact form.} \\blankline \\spad{X} a:=partialFraction(1,factorial 10) \\spad{X} padicFraction(a)")) (|padicallyExpand| (((|SparseUnivariatePolynomial| |#1|) |#1| |#1|) "\\spad{padicallyExpand(p,x)} is a utility function that expands the second argument \\spad{x} ``p-adically'' in the first.")) (|numberOfFractionalTerms| (((|Integer|) $) "\\indented{1}{numberOfFractionalTerms(p) computes the number of fractional} \\indented{1}{terms in \\spad{p}. This returns 0 if there is no fractional} \\indented{1}{part.} \\blankline \\spad{X} a:=partialFraction(1,factorial 10) \\spad{X} b:=padicFraction(a) \\spad{X} numberOfFractionalTerms(b)")) (|nthFractionalTerm| (($ $ (|Integer|)) "\\indented{1}{nthFractionalTerm(p,n) extracts the \\spad{n}th fractional term from} \\indented{1}{the partial fraction \\spad{p}.\\space{2}This returns 0 if the index} \\indented{1}{\\spad{n} is out of range.} \\blankline \\spad{X} a:=partialFraction(1,factorial 10) \\spad{X} b:=padicFraction(a) \\spad{X} nthFractionalTerm(b,3)")) (|firstNumer| ((|#1| $) "\\indented{1}{firstNumer(p) extracts the numerator of the first fractional} \\indented{1}{term. This returns 0 if there is no fractional part (use} \\indented{1}{wholePart from PartialFraction to get the whole part).} \\blankline \\spad{X} a:=partialFraction(1,factorial 10) \\spad{X} firstNumer(a)")) (|firstDenom| (((|Factored| |#1|) $) "\\indented{1}{firstDenom(p) extracts the denominator of the first fractional} \\indented{1}{term. This returns 1 if there is no fractional part (use} \\indented{1}{wholePart from PartialFraction to get the whole part).} \\blankline \\spad{X} a:=partialFraction(1,factorial 10) \\spad{X} firstDenom(a)")) (|compactFraction| (($ $) "\\indented{1}{compactFraction(p) normalizes the partial fraction \\spad{p}} \\indented{1}{to the compact representation. In this form, the partial} \\indented{1}{fraction has only one fractional term per prime in the} \\indented{1}{denominator.} \\blankline \\spad{X} a:=partialFraction(1,factorial 10) \\spad{X} b:=padicFraction(a) \\spad{X} compactFraction(b)")) (|coerce| (($ (|Fraction| (|Factored| |#1|))) "\\indented{1}{coerce(f) takes a fraction with numerator and denominator in} \\indented{1}{factored form and creates a partial fraction.\\space{2}It is} \\indented{1}{necessary for the parts to be factored because it is not} \\indented{1}{known in general how to factor elements of \\spad{R} and} \\indented{1}{this is needed to decompose into partial fractions.} \\blankline \\spad{X} (13/74)::PFR(INT)") (((|Fraction| |#1|) $) "\\indented{1}{coerce(p) sums up the components of the partial fraction and} \\indented{1}{returns a single fraction.} \\blankline \\spad{X} a:=(13/74)::PFR(INT) \\spad{X} a::FRAC(INT)"))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-917 R) 
+(-938 R) 
 ((|constructor| (NIL "The package \\spadtype{PartialFractionPackage} gives an easier to use interfact the domain \\spadtype{PartialFraction}. The user gives a fraction of polynomials, and a variable and the package converts it to the proper datatype for the \\spadtype{PartialFraction} domain.")) (|partialFraction| (((|Any|) (|Polynomial| |#1|) (|Factored| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{partialFraction(num, facdenom, var)} returns the partial fraction decomposition of the rational function whose numerator is \\spad{num} and whose factored denominator is \\spad{facdenom} with respect to the variable var.") (((|Any|) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\indented{1}{partialFraction(rf, var) returns the partial fraction decomposition} \\indented{1}{of the rational function \\spad{rf} with respect to the variable var.} \\blankline \\spad{X} a:=x+1/(y+1) \\spad{X} partialFraction(a,y)$PFRPAC(INT)"))) 
 NIL 
 NIL 
-(-918 E OV R P) 
-((|constructor| (NIL "This package computes multivariate polynomial gcd's using a hensel lifting strategy. The contraint on the coefficient domain is imposed by the lifting strategy. It is assumed that the coefficient domain has the property that almost all specializations preserve the degree of the gcd.")) (|gcdPrimitive| ((|#4| (|List| |#4|)) "\\spad{gcdPrimitive \\spad{lp}} computes the \\spad{gcd} of the list of primitive polynomials \\spad{lp.}") (((|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{gcdPrimitive(p,q)} computes the \\spad{gcd} of the primitive polynomials \\spad{p} and \\spad{q.}") ((|#4| |#4| |#4|) "\\spad{gcdPrimitive(p,q)} computes the \\spad{gcd} of the primitive polynomials \\spad{p} and \\spad{q.}")) (|gcd| (((|SparseUnivariatePolynomial| |#4|) (|List| (|SparseUnivariatePolynomial| |#4|))) "\\spad{gcd(lp)} computes the \\spad{gcd} of the list of polynomials \\spad{lp.}") (((|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{gcd(p,q)} computes the \\spad{gcd} of the two polynomials \\spad{p} and \\spad{q.}") ((|#4| (|List| |#4|)) "\\spad{gcd(lp)} computes the \\spad{gcd} of the list of polynomials \\spad{lp.}") ((|#4| |#4| |#4|) "\\spad{gcd(p,q)} computes the \\spad{gcd} of the two polynomials \\spad{p} and \\spad{q.}"))) 
+(-939 E OV R P) 
+((|constructor| (NIL "This package computes multivariate polynomial gcd's using a hensel lifting strategy. The constraint on the coefficient domain is imposed by the lifting strategy. It is assumed that the coefficient domain has the property that almost all specializations preserve the degree of the gcd.")) (|gcdPrimitive| ((|#4| (|List| |#4|)) "\\spad{gcdPrimitive \\spad{lp}} computes the \\spad{gcd} of the list of primitive polynomials \\spad{lp.}") (((|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{gcdPrimitive(p,q)} computes the \\spad{gcd} of the primitive polynomials \\spad{p} and \\spad{q.}") ((|#4| |#4| |#4|) "\\spad{gcdPrimitive(p,q)} computes the \\spad{gcd} of the primitive polynomials \\spad{p} and \\spad{q.}")) (|gcd| (((|SparseUnivariatePolynomial| |#4|) (|List| (|SparseUnivariatePolynomial| |#4|))) "\\spad{gcd(lp)} computes the \\spad{gcd} of the list of polynomials \\spad{lp.}") (((|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{gcd(p,q)} computes the \\spad{gcd} of the two polynomials \\spad{p} and \\spad{q.}") ((|#4| (|List| |#4|)) "\\spad{gcd(lp)} computes the \\spad{gcd} of the list of polynomials \\spad{lp.}") ((|#4| |#4| |#4|) "\\indented{1}{gcd(p,q) computes the \\spad{gcd} of the two polynomials \\spad{p} and \\spad{q.}} \\blankline \\spad{X} p1:=(x+1)*(x+6) \\spad{X} p2:=(x+1)*(x-6) \\spad{X} gcd(p1,p2)"))) 
 NIL 
 NIL 
-(-919) 
+(-940) 
 ((|constructor| (NIL "PermutationGroupExamples provides permutation groups for some classes of groups: symmetric, alternating, dihedral, cyclic, direct products of cyclic, which are in fact the finite abelian groups of symmetric groups called Young subgroups. Furthermore, Rubik's group as permutation group of 48 integers and a list of sporadic simple groups derived from the atlas of finite groups.")) (|youngGroup| (((|PermutationGroup| (|Integer|)) (|Partition|)) "\\spad{youngGroup(lambda)} constructs the direct product of the symmetric groups given by the parts of the partition lambda.") (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{youngGroup([n1,...,nk])} constructs the direct product of the symmetric groups Sn1,...,Snk.")) (|rubiksGroup| (((|PermutationGroup| (|Integer|))) "\\spad{rubiksGroup constructs} the permutation group representing Rubic's Cube acting on integers 10*i+j for 1 \\spad{<=} \\spad{i} \\spad{<=} 6, 1 \\spad{<=} \\spad{j} \\spad{<=} 8. The faces of Rubik's Cube are labelled in the obvious way Front, Right, Up, Down, Left, Back and numbered from 1 to 6 in this given ordering, the pieces on each face (except the unmoveable center piece) are clockwise numbered from 1 to 8 starting with the piece in the upper left corner. The moves of the cube are represented as permutations on these pieces, represented as a two digit integer ij where \\spad{i} is the numer of theface \\spad{(1} to 6) and \\spad{j} is the number of the piece on this face. The remaining ambiguities are resolved by looking at the 6 generators, which represent a 90 degree turns of the faces, or from the following pictorial description. Permutation group representing Rubic's Cube acting on integers 10*i+j for 1 \\spad{<=} \\spad{i} \\spad{<=} 6, 1 \\spad{<=} \\spad{j} <=8. \\blankline\\begin{verbatim}Rubik's Cube:   +-----+ +-- B   where: marks Side # :               / U   /|/              /     / |         F(ront)    <->    1      L -->  +-----+ R|         R(ight)    <->    2             |     |  +         U(p)       <->    3             |  F  | /          D(own)     <->    4             |     |/           L(eft)     <->    5             +-----+            B(ack)     <->    6                ^                |                DThe Cube's surface:                               The pieces on each side            +---+              (except the unmoveable center            |567|              piece) are clockwise numbered            |4U8|              from 1 to 8 starting with the            |321|              piece in the upper left        +---+---+---+          corner (see figure on the        |781|123|345|          left).  The moves of the cube        |6L2|8F4|2R6|          are represented as        |543|765|187|          permutations on these pieces.        +---+---+---+          Each of the pieces is            |123|              represented as a two digit            |8D4|              integer ij where i is the            |765|              # of the side ( 1 to 6 for            +---+              F to B (see table above ))            |567|              and j is the # of the piece.            |4B8|            |321|            +---+\\end{verbatim}")) (|janko2| (((|PermutationGroup| (|Integer|))) "\\spad{janko2 constructs} the janko group acting on the integers 1,...,100.") (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{janko2(li)} constructs the janko group acting on the 100 integers given in the list li. Note that duplicates in the list will be removed. Error: if \\spad{li} has less or more than 100 different entries")) (|mathieu24| (((|PermutationGroup| (|Integer|))) "\\spad{mathieu24 constructs} the mathieu group acting on the integers 1,...,24.") (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{mathieu24(li)} constructs the mathieu group acting on the 24 integers given in the list li. Note that duplicates in the list will be removed. Error: if \\spad{li} has less or more than 24 different entries.")) (|mathieu23| (((|PermutationGroup| (|Integer|))) "\\spad{mathieu23 constructs} the mathieu group acting on the integers 1,...,23.") (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{mathieu23(li)} constructs the mathieu group acting on the 23 integers given in the list li. Note that duplicates in the list will be removed. Error: if \\spad{li} has less or more than 23 different entries.")) (|mathieu22| (((|PermutationGroup| (|Integer|))) "\\spad{mathieu22 constructs} the mathieu group acting on the integers 1,...,22.") (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{mathieu22(li)} constructs the mathieu group acting on the 22 integers given in the list li. Note that duplicates in the list will be removed. Error: if \\spad{li} has less or more than 22 different entries.")) (|mathieu12| (((|PermutationGroup| (|Integer|))) "\\spad{mathieu12 constructs} the mathieu group acting on the integers 1,...,12.") (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{mathieu12(li)} constructs the mathieu group acting on the 12 integers given in the list li. Note that duplicates in the list will be removed Error: if \\spad{li} has less or more than 12 different entries.")) (|mathieu11| (((|PermutationGroup| (|Integer|))) "\\spad{mathieu11 constructs} the mathieu group acting on the integers 1,...,11.") (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{mathieu11(li)} constructs the mathieu group acting on the 11 integers given in the list li. Note that duplicates in the list will be removed. error, if \\spad{li} has less or more than 11 different entries.")) (|dihedralGroup| (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{dihedralGroup([i1,...,ik])} constructs the dihedral group of order 2k acting on the integers out of i1,...,ik. Note that duplicates in the list will be removed.") (((|PermutationGroup| (|Integer|)) (|PositiveInteger|)) "\\spad{dihedralGroup(n)} constructs the dihedral group of order 2n acting on integers 1,...,N.")) (|cyclicGroup| (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{cyclicGroup([i1,...,ik])} constructs the cyclic group of order \\spad{k} acting on the integers i1,...,ik. Note that duplicates in the list will be removed.") (((|PermutationGroup| (|Integer|)) (|PositiveInteger|)) "\\spad{cyclicGroup(n)} constructs the cyclic group of order \\spad{n} acting on the integers 1,...,n.")) (|abelianGroup| (((|PermutationGroup| (|Integer|)) (|List| (|PositiveInteger|))) "\\spad{abelianGroup([n1,...,nk])} constructs the abelian group that is the direct product of cyclic groups with order ni.")) (|alternatingGroup| (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{alternatingGroup(li)} constructs the alternating group acting on the integers in the list li, generators are in general the n-2-cycle (li.3,...,li.n) and the 3-cycle (li.1,li.2,li.3), if \\spad{n} is odd and product of the 2-cycle (li.1,li.2) with n-2-cycle (li.3,...,li.n) and the 3-cycle (li.1,li.2,li.3), if \\spad{n} is even. Note that duplicates in the list will be removed.") (((|PermutationGroup| (|Integer|)) (|PositiveInteger|)) "\\spad{alternatingGroup(n)} constructs the alternating group An acting on the integers 1,...,n, generators are in general the n-2-cycle (3,...,n) and the 3-cycle (1,2,3) if \\spad{n} is odd and the product of the 2-cycle (1,2) with n-2-cycle (3,...,n) and the 3-cycle (1,2,3) if \\spad{n} is even.")) (|symmetricGroup| (((|PermutationGroup| (|Integer|)) (|List| (|Integer|))) "\\spad{symmetricGroup(li)} constructs the symmetric group acting on the integers in the list li, generators are the cycle given by \\spad{li} and the 2-cycle (li.1,li.2). Note that duplicates in the list will be removed.") (((|PermutationGroup| (|Integer|)) (|PositiveInteger|)) "\\spad{symmetricGroup(n)} constructs the symmetric group \\spad{Sn} acting on the integers 1,...,n, generators are the n-cycle (1,...,n) and the 2-cycle (1,2)."))) 
 NIL 
 NIL 
-(-920 -3313) 
+(-941 -3958) 
 ((|constructor| (NIL "Groebner functions for \\spad{P} \\spad{F} This package is an interface package to the groebner basis package which allows you to compute groebner bases for polynomials in either lexicographic ordering or total degree ordering refined by reverse lex. The input is the ordinary polynomial type which is internally converted to a type with the required ordering. The resulting grobner basis is converted back to ordinary polynomials. The ordering among the variables is controlled by an explicit list of variables which is passed as a second argument. The coefficient domain is allowed to be any \\spad{gcd} domain, but the groebner basis is computed as if the polynomials were over a field.")) (|totalGroebner| (((|List| (|Polynomial| |#1|)) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|))) "\\spad{totalGroebner(lp,lv)} computes Groebner basis for the list of polynomials \\spad{lp} with the terms ordered first by total degree and then refined by reverse lexicographic ordering. The variables are ordered by their position in the list \\spad{lv.}")) (|lexGroebner| (((|List| (|Polynomial| |#1|)) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|))) "\\spad{lexGroebner(lp,lv)} computes Groebner basis for the list of polynomials \\spad{lp} in lexicographic order. The variables are ordered by their position in the list \\spad{lv.}"))) 
 NIL 
 NIL 
-(-921 R) 
+(-942 R) 
 ((|constructor| (NIL "Provides a coercion from the symbolic fractions in \\%pi with integer coefficients to any Expression type.")) (|coerce| (((|Expression| |#1|) (|Pi|)) "\\spad{coerce(f)} returns \\spad{f} as an Expression(R)."))) 
 NIL 
 NIL 
-(-922) 
+(-943) 
 ((|constructor| (NIL "The category of constructive principal ideal domains, \\spadignore{i.e.} where a single generator can be constructively found for any ideal given by a finite set of generators. Note that this constructive definition only implies that finitely generated ideals are principal. It is not clear what we would mean by an infinitely generated ideal.")) (|expressIdealMember| (((|Union| (|List| $) "failed") (|List| $) $) "\\spad{expressIdealMember([f1,...,fn],h)} returns a representation of \\spad{h} as a linear combination of the \\spad{fi} or \"failed\" if \\spad{h} is not in the ideal generated by the fi.")) (|principalIdeal| (((|Record| (|:| |coef| (|List| $)) (|:| |generator| $)) (|List| $)) "\\spad{principalIdeal([f1,...,fn])} returns a record whose generator component is a generator of the ideal generated by \\spad{[f1,...,fn]} whose coef component satisfies \\spad{generator = sum (input.i * coef.i)}"))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-923) 
+(-944) 
 ((|constructor| (NIL "\\spadtype{PositiveInteger} provides functions for positive integers.")) (|commutative| ((|attribute| "*") "\\spad{commutative(\"*\")} means multiplication is commutative : x*y = \\spad{y*x}")) (|gcd| (($ $ $) "\\spad{gcd(a,b)} computes the greatest common divisor of two positive integers \\spad{a} and \\spad{b.}"))) 
-(((-4604 "*") . T)) 
+(((-4627 "*") . T)) 
 NIL 
-(-924 -3313 P) 
+(-945 -3958 P) 
 ((|constructor| (NIL "This package exports interpolation algorithms")) (|LagrangeInterpolation| ((|#2| (|List| |#1|) (|List| |#1|)) "\\spad{LagrangeInterpolation(l1,l2)} \\undocumented"))) 
 NIL 
 NIL 
-(-925 |xx| -3313) 
+(-946 |xx| -3958) 
 ((|constructor| (NIL "This package exports interpolation algorithms")) (|interpolate| (((|SparseUnivariatePolynomial| |#2|) (|List| |#2|) (|List| |#2|)) "\\spad{interpolate(lf,lg)} \\undocumented") (((|UnivariatePolynomial| |#1| |#2|) (|UnivariatePolynomial| |#1| |#2|) (|List| |#2|) (|List| |#2|)) "\\spad{interpolate(u,lf,lg)} \\undocumented"))) 
 NIL 
 NIL 
-(-926 K PCS) 
+(-947 K PCS) 
 ((|constructor| (NIL "This is part of the PAFF package, related to projective space.")) (|elt| ((|#1| $ (|Integer|)) "\\spad{elt returns} the value of a specified coordinates if the places correspnd to a simple point")) (|setFoundPlacesToEmpty| (((|List| $)) "\\spad{setFoundPlacesToEmpty()} does what it says. (this should not be used)!!!")) (|foundPlaces| (((|List| $)) "\\spad{foundPlaces()} returns the list of all \"created\" places up to now.")) (|leaf?| (((|Boolean|) $) "\\spad{leaf?(pl)} test if the place \\spad{pl} correspond to a leaf of a desingularisation tree.")) (|setDegree!| (((|Void|) $ (|PositiveInteger|)) "\\spad{setDegree!(pl,ls)} set the degree.")) (|setParam!| (((|Void|) $ (|List| |#2|)) "\\spad{setParam!(pl,ls)} set the local parametrization of \\spad{pl} to \\spad{ls.}")) (|localParam| (((|List| |#2|) $) "\\spad{localParam(pl)} returns the local parametrization associated to the place \\spad{pl.}"))) 
 NIL 
 NIL 
-(-927 K) 
+(-948 K) 
 ((|constructor| (NIL "The following is part of the PAFF package"))) 
 NIL 
 NIL 
-(-928 K) 
+(-949 K) 
 ((|constructor| (NIL "The following is part of the PAFF package"))) 
 NIL 
 NIL 
-(-929 K PCS) 
+(-950 K PCS) 
 ((|constructor| (NIL "The following is part of the PAFF package"))) 
 NIL 
 NIL 
-(-930 R |Var| |Expon| GR) 
+(-951 R |Var| |Expon| GR) 
 ((|constructor| (NIL "This package completely solves a parametric linear system of equations by decomposing the set of all parametric values for which the linear system is consistent into a union of quasi-algebraic sets (which need not be irredundant, but most of the time is). Each quasi-algebraic set is described by a list of polynomials that vanish on the set, and a list of polynomials that vanish at no point of the set. For each quasi-algebraic set, the solution of the linear system is given, as a particular solution and a basis of the homogeneous system. \\blankline The parametric linear system should be given in matrix form, with a coefficient matrix and a right hand side vector. The entries of the coefficient matrix and right hand side vector should be polynomials in the parametric variables, over a Euclidean domain of characteristic zero. \\blankline If the system is homogeneous, the right hand side need not be given. The right hand side can also be replaced by an indeterminate vector, in which case, the conditions required for consistency will also be given. \\blankline The package has other facilities for saving results to external files, as well as solving the system for a specified minimum rank. Altogether there are 12 mode maps for psolve, as explained below.")) (|inconsistent?| (((|Boolean|) (|List| (|Polynomial| |#1|))) "inconsistant?(pl) returns \\spad{true} if the system of equations \\spad{p} = 0 for \\spad{p} in \\spad{pl} is inconsistent. It is assumed that \\spad{pl} is a groebner basis.") (((|Boolean|) (|List| |#4|)) "inconsistant?(pl) returns \\spad{true} if the system of equations \\spad{p} = 0 for \\spad{p} in \\spad{pl} is inconsistent. It is assumed that \\spad{pl} is a groebner basis.")) (|sqfree| ((|#4| |#4|) "\\spad{sqfree(p)} returns the product of square free factors of \\spad{p}")) (|regime| (((|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|)))))))) (|Record| (|:| |det| |#4|) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))) (|Matrix| |#4|) (|List| (|Fraction| (|Polynomial| |#1|))) (|List| (|List| |#4|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|Integer|)) "\\spad{regime(y,c, \\spad{w,} \\spad{p,} \\spad{r,} \\spad{rm,} \\spad{m)}} returns a regime, a list of polynomials specifying the consistency conditions, a particular solution and basis representing the general solution of the parametric linear system \\spad{c} \\spad{z} = \\spad{w} on that regime. The regime returned depends on the subdeterminant y.det and the row and column indices. The solutions are simplified using the assumption that the system has rank \\spad{r} and maximum rank \\spad{rm.} The list \\spad{p} represents a list of list of factors of polynomials in a groebner basis of the ideal generated by higher order subdeterminants, and ius used for the simplification. The mode \\spad{m} distinguishes the cases when the system is homogeneous, or the right hand side is arbitrary, or when there is no new right hand side variables.")) (|redmat| (((|Matrix| |#4|) (|Matrix| |#4|) (|List| |#4|)) "\\spad{redmat(m,g)} returns a matrix whose entries are those of \\spad{m} modulo the ideal generated by the groebner basis \\spad{g}")) (|ParCond| (((|List| (|Record| (|:| |det| |#4|) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|))))) (|Matrix| |#4|) (|NonNegativeInteger|)) "\\spad{ParCond(m,k)} returns the list of all \\spad{k} by \\spad{k} subdeterminants in the matrix \\spad{m}")) (|overset?| (((|Boolean|) (|List| |#4|) (|List| (|List| |#4|))) "\\spad{overset?(s,sl)} returns \\spad{true} if \\spad{s} properly a sublist of a member of \\spad{sl;} otherwise it returns \\spad{false}")) (|nextSublist| (((|List| (|List| (|Integer|))) (|Integer|) (|Integer|)) "\\spad{nextSublist(n,k)} returns a list of k-subsets of \\spad{{1,} ..., \\spad{n}.}")) (|minset| (((|List| (|List| |#4|)) (|List| (|List| |#4|))) "\\spad{minset(sl)} returns the sublist of \\spad{sl} consisting of the minimal lists (with respect to inclusion) in the list \\spad{sl} of lists")) (|minrank| (((|NonNegativeInteger|) (|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| |#4|) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| |#4|))))) "\\spad{minrank(r)} returns the minimum rank in the list \\spad{r} of regimes")) (|maxrank| (((|NonNegativeInteger|) (|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| |#4|) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| |#4|))))) "\\spad{maxrank(r)} returns the maximum rank in the list \\spad{r} of regimes")) (|factorset| (((|List| |#4|) |#4|) "\\spad{factorset(p)} returns the set of irreducible factors of \\spad{p.}")) (|B1solve| (((|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|)))))) (|Record| (|:| |mat| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|:| |vec| (|List| (|Fraction| (|Polynomial| |#1|)))) (|:| |rank| (|NonNegativeInteger|)) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|))))) "\\spad{B1solve(s)} solves the system (s.mat) \\spad{z} = s.vec for the variables given by the column indices of s.cols in terms of the other variables and the right hand side s.vec by assuming that the rank is s.rank, that the system is consistent, with the linearly independent equations indexed by the given row indices s.rows; the coefficients in s.mat involving parameters are treated as polynomials. B1solve(s) returns a particular solution to the system and a basis of the homogeneous system (s.mat) \\spad{z} = 0.")) (|redpps| (((|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|)))))) (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|)))))) (|List| |#4|)) "\\spad{redpps(s,g)} returns the simplified form of \\spad{s} after reducing modulo a groebner basis \\spad{g}")) (|ParCondList| (((|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| |#4|) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| |#4|)))) (|Matrix| |#4|) (|NonNegativeInteger|)) "\\spad{ParCondList(c,r)} computes a list of subdeterminants of each rank \\spad{>=} \\spad{r} of the matrix \\spad{c} and returns a groebner basis for the ideal they generate")) (|hasoln| (((|Record| (|:| |sysok| (|Boolean|)) (|:| |z0| (|List| |#4|)) (|:| |n0| (|List| |#4|))) (|List| |#4|) (|List| |#4|)) "\\spad{hasoln(g, \\spad{l)}} tests whether the quasi-algebraic set defined by \\spad{p} = 0 for \\spad{p} in \\spad{g} and \\spad{q} \\spad{^=} 0 for \\spad{q} in \\spad{l} is empty or not and returns a simplified definition of the quasi-algebraic set")) (|pr2dmp| ((|#4| (|Polynomial| |#1|)) "\\spad{pr2dmp(p)} converts \\spad{p} to target domain")) (|se2rfi| (((|List| (|Fraction| (|Polynomial| |#1|))) (|List| (|Symbol|))) "\\spad{se2rfi(l)} converts \\spad{l} to target domain")) (|dmp2rfi| (((|List| (|Fraction| (|Polynomial| |#1|))) (|List| |#4|)) "\\spad{dmp2rfi(l)} converts \\spad{l} to target domain") (((|Matrix| (|Fraction| (|Polynomial| |#1|))) (|Matrix| |#4|)) "\\spad{dmp2rfi(m)} converts \\spad{m} to target domain") (((|Fraction| (|Polynomial| |#1|)) |#4|) "\\spad{dmp2rfi(p)} converts \\spad{p} to target domain")) (|bsolve| (((|Record| (|:| |rgl| (|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|)))))))))) (|:| |rgsz| (|Integer|))) (|Matrix| |#4|) (|List| (|Fraction| (|Polynomial| |#1|))) (|NonNegativeInteger|) (|String|) (|Integer|)) "\\spad{bsolve(c, \\spad{w,} \\spad{r,} \\spad{s,} \\spad{m)}} returns a list of regimes and solutions of the system \\spad{c} \\spad{z} = \\spad{w} for ranks at least \\spad{r;} depending on the mode \\spad{m} chosen, it writes the output to a file given by the string \\spad{s.}")) (|rdregime| (((|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|))))))))) (|String|)) "\\spad{rdregime(s)} reads in a list from a file with name \\spad{s}")) (|wrregime| (((|Integer|) (|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|))))))))) (|String|)) "\\spad{wrregime(l,s)} writes a list of regimes to a file named \\spad{s} and returns the number of regimes written")) (|psolve| (((|Integer|) (|Matrix| |#4|) (|PositiveInteger|) (|String|)) "\\spad{psolve(c,k,s)} solves \\spad{c} \\spad{z} = 0 for all possible ranks \\spad{>=} \\spad{k} of the matrix \\spad{c,} writes the results to a file named \\spad{s,} and returns the number of regimes") (((|Integer|) (|Matrix| |#4|) (|List| (|Symbol|)) (|PositiveInteger|) (|String|)) "\\spad{psolve(c,w,k,s)} solves \\spad{c} \\spad{z} = \\spad{w} for all possible ranks \\spad{>=} \\spad{k} of the matrix \\spad{c} and indeterminate right hand side \\spad{w,} writes the results to a file named \\spad{s,} and returns the number of regimes") (((|Integer|) (|Matrix| |#4|) (|List| |#4|) (|PositiveInteger|) (|String|)) "\\spad{psolve(c,w,k,s)} solves \\spad{c} \\spad{z} = \\spad{w} for all possible ranks \\spad{>=} \\spad{k} of the matrix \\spad{c} and given right hand side \\spad{w,} writes the results to a file named \\spad{s,} and returns the number of regimes") (((|Integer|) (|Matrix| |#4|) (|String|)) "\\spad{psolve(c,s)} solves \\spad{c} \\spad{z} = 0 for all possible ranks of the matrix \\spad{c} and given right hand side vector \\spad{w,} writes the results to a file named \\spad{s,} and returns the number of regimes") (((|Integer|) (|Matrix| |#4|) (|List| (|Symbol|)) (|String|)) "\\spad{psolve(c,w,s)} solves \\spad{c} \\spad{z} = \\spad{w} for all possible ranks of the matrix \\spad{c} and indeterminate right hand side \\spad{w,} writes the results to a file named \\spad{s,} and returns the number of regimes") (((|Integer|) (|Matrix| |#4|) (|List| |#4|) (|String|)) "\\spad{psolve(c,w,s)} solves \\spad{c} \\spad{z} = \\spad{w} for all possible ranks of the matrix \\spad{c} and given right hand side vector \\spad{w,} writes the results to a file named \\spad{s,} and returns the number of regimes") (((|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|))))))))) (|Matrix| |#4|) (|PositiveInteger|)) "\\spad{psolve(c)} solves the homogeneous linear system \\spad{c} \\spad{z} = 0 for all possible ranks \\spad{>=} \\spad{k} of the matrix \\spad{c}") (((|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|))))))))) (|Matrix| |#4|) (|List| (|Symbol|)) (|PositiveInteger|)) "\\spad{psolve(c,w,k)} solves \\spad{c} \\spad{z} = \\spad{w} for all possible ranks \\spad{>=} \\spad{k} of the matrix \\spad{c} and indeterminate right hand side \\spad{w}") (((|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|))))))))) (|Matrix| |#4|) (|List| |#4|) (|PositiveInteger|)) "\\spad{psolve(c,w,k)} solves \\spad{c} \\spad{z} = \\spad{w} for all possible ranks \\spad{>=} \\spad{k} of the matrix \\spad{c} and given right hand side vector \\spad{w}") (((|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|))))))))) (|Matrix| |#4|)) "\\spad{psolve(c)} solves the homogeneous linear system \\spad{c} \\spad{z} = 0 for all possible ranks of the matrix \\spad{c}") (((|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|))))))))) (|Matrix| |#4|) (|List| (|Symbol|))) "\\spad{psolve(c,w)} solves \\spad{c} \\spad{z} = \\spad{w} for all possible ranks of the matrix \\spad{c} and indeterminate right hand side \\spad{w}") (((|List| (|Record| (|:| |eqzro| (|List| |#4|)) (|:| |neqzro| (|List| |#4|)) (|:| |wcond| (|List| (|Polynomial| |#1|))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| |#1|)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| |#1|))))))))) (|Matrix| |#4|) (|List| |#4|)) "\\spad{psolve(c,w)} solves \\spad{c} \\spad{z} = \\spad{w} for all possible ranks of the matrix \\spad{c} and given right hand side vector \\spad{w}"))) 
 NIL 
 NIL 
-(-931 S) 
+(-952 S) 
 ((|constructor| (NIL "\\spad{PlotFunctions1} provides facilities for plotting curves where functions \\spad{SF} \\spad{->} \\spad{SF} are specified by giving an expression")) (|plotPolar| (((|Plot|) |#1| (|Symbol|)) "\\spad{plotPolar(f,theta)} plots the graph of \\spad{r = f(theta)} as \\spad{theta} ranges from 0 to 2 \\spad{pi}") (((|Plot|) |#1| (|Symbol|) (|Segment| (|DoubleFloat|))) "\\spad{plotPolar(f,theta,seg)} plots the graph of \\spad{r = f(theta)} as \\spad{theta} ranges over an interval")) (|plot| (((|Plot|) |#1| |#1| (|Symbol|) (|Segment| (|DoubleFloat|))) "\\spad{plot(f,g,t,seg)} plots the graph of \\spad{x = f(t)}, \\spad{y = g(t)} as \\spad{t} ranges over an interval.") (((|Plot|) |#1| (|Symbol|) (|Segment| (|DoubleFloat|))) "\\spad{plot(fcn,x,seg)} plots the graph of \\spad{y = f(x)} on a interval"))) 
 NIL 
 NIL 
-(-932) 
+(-953) 
 ((|constructor| (NIL "Plot3D supports parametric plots defined over a real number system. A real number system is a model for the real numbers and as such may be an approximation. For example, floating point numbers and infinite continued fractions are real number systems. The facilities at this point are limited to 3-dimensional parametric plots.")) (|debug3D| (((|Boolean|) (|Boolean|)) "\\spad{debug3D(true)} turns debug mode on; debug3D(false) turns debug mode off.")) (|numFunEvals3D| (((|Integer|)) "\\spad{numFunEvals3D()} returns the number of points computed.")) (|setAdaptive3D| (((|Boolean|) (|Boolean|)) "\\spad{setAdaptive3D(true)} turns adaptive plotting on; setAdaptive3D(false) turns adaptive plotting off.")) (|adaptive3D?| (((|Boolean|)) "\\spad{adaptive3D?()} determines whether plotting be done adaptively.")) (|setScreenResolution3D| (((|Integer|) (|Integer|)) "\\spad{setScreenResolution3D(i)} sets the screen resolution for a 3d graph to i.")) (|screenResolution3D| (((|Integer|)) "\\spad{screenResolution3D()} returns the screen resolution for a 3d graph.")) (|setMaxPoints3D| (((|Integer|) (|Integer|)) "\\spad{setMaxPoints3D(i)} sets the maximum number of points in a plot to i.")) (|maxPoints3D| (((|Integer|)) "\\spad{maxPoints3D()} returns the maximum number of points in a plot.")) (|setMinPoints3D| (((|Integer|) (|Integer|)) "\\spad{setMinPoints3D(i)} sets the minimum number of points in a plot to i.")) (|minPoints3D| (((|Integer|)) "\\spad{minPoints3D()} returns the minimum number of points in a plot.")) (|tValues| (((|List| (|List| (|DoubleFloat|))) $) "\\spad{tValues(p)} returns a list of lists of the values of the parameter for which a point is computed, one list for each curve in the plot \\spad{p.}")) (|tRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{tRange(p)} returns the range of the parameter in a parametric plot \\spad{p.}")) (|refine| (($ $) "\\spad{refine(x)} is not documented") (($ $ (|Segment| (|DoubleFloat|))) "\\spad{refine(x,r)} is not documented")) (|zoom| (($ $ (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{zoom(x,r,s,t)} is not documented")) (|plot| (($ $ (|Segment| (|DoubleFloat|))) "\\spad{plot(x,r)} is not documented") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{plot(f1,f2,f3,f4,x,y,z,w)} is not documented") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{plot(f,g,h,a..b)} plots {/emx = f(t), \\spad{y} = g(t), \\spad{z} = h(t)} as \\spad{t} ranges over {/em[a,b]}.")) (|pointPlot| (($ (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{pointPlot(f,x,y,z,w)} is not documented") (($ (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{pointPlot(f,g,h,a..b)} plots {/emx = f(t), \\spad{y} = g(t), \\spad{z} = h(t)} as \\spad{t} ranges over {/em[a,b]}."))) 
 NIL 
 NIL 
-(-933) 
+(-954) 
 ((|constructor| (NIL "The Plot domain supports plotting of functions defined over a real number system. A real number system is a model for the real numbers and as such may be an approximation. For example floating point numbers and infinite continued fractions. The facilities at this point are limited to 2-dimensional plots or either a single function or a parametric function.")) (|debug| (((|Boolean|) (|Boolean|)) "\\spad{debug(true)} turns debug mode on \\spad{debug(false)} turns debug mode off")) (|numFunEvals| (((|Integer|)) "\\spad{numFunEvals()} returns the number of points computed")) (|setAdaptive| (((|Boolean|) (|Boolean|)) "\\spad{setAdaptive(true)} turns adaptive plotting on \\spad{setAdaptive(false)} turns adaptive plotting off")) (|adaptive?| (((|Boolean|)) "\\spad{adaptive?()} determines whether plotting be done adaptively")) (|setScreenResolution| (((|Integer|) (|Integer|)) "\\spad{setScreenResolution(i)} sets the screen resolution to \\spad{i}")) (|screenResolution| (((|Integer|)) "\\spad{screenResolution()} returns the screen resolution")) (|setMaxPoints| (((|Integer|) (|Integer|)) "\\spad{setMaxPoints(i)} sets the maximum number of points in a plot to \\spad{i}")) (|maxPoints| (((|Integer|)) "\\spad{maxPoints()} returns the maximum number of points in a plot")) (|setMinPoints| (((|Integer|) (|Integer|)) "\\spad{setMinPoints(i)} sets the minimum number of points in a plot to \\spad{i}")) (|minPoints| (((|Integer|)) "\\spad{minPoints()} returns the minimum number of points in a plot")) (|tRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{tRange(p)} returns the range of the parameter in a parametric plot \\spad{p}")) (|refine| (($ $) "\\spad{refine(p)} performs a refinement on the plot \\spad{p}") (($ $ (|Segment| (|DoubleFloat|))) "\\spad{refine(x,r)} is not documented")) (|zoom| (($ $ (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{zoom(x,r,s)} is not documented") (($ $ (|Segment| (|DoubleFloat|))) "\\spad{zoom(x,r)} is not documented")) (|parametric?| (((|Boolean|) $) "\\spad{parametric? determines} whether it is a parametric plot?")) (|plotPolar| (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) "\\spad{plotPolar(f)} plots the polar curve \\spad{r = f(theta)} as theta ranges over the interval \\spad{[0,2*\\%pi]}; this is the same as the parametric curve \\spad{x = f(t)*cos(t)}, \\spad{y = f(t)*sin(t)}.") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{plotPolar(f,a..b)} plots the polar curve \\spad{r = f(theta)} as theta ranges over the interval \\spad{[a,b]}; this is the same as the parametric curve \\spad{x = f(t)*cos(t)}, \\spad{y = f(t)*sin(t)}.")) (|pointPlot| (($ (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{pointPlot(t \\spad{+->} (f(t),g(t)),a..b,c..d,e..f)} plots the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)} as \\spad{t} ranges over the interval \\spad{[a,b]}; x-range of \\spad{[c,d]} and y-range of \\spad{[e,f]} are noted in Plot object.") (($ (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{pointPlot(t \\spad{+->} (f(t),g(t)),a..b)} plots the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)} as \\spad{t} ranges over the interval \\spad{[a,b]}.")) (|plot| (($ $ (|Segment| (|DoubleFloat|))) "\\spad{plot(x,r)} is not documented") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{plot(f,g,a..b,c..d,e..f)} plots the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)} as \\spad{t} ranges over the interval \\spad{[a,b]}; x-range of \\spad{[c,d]} and y-range of \\spad{[e,f]} are noted in Plot object.") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{plot(f,g,a..b)} plots the parametric curve \\spad{x = f(t)}, \\spad{y = g(t)} as \\spad{t} ranges over the interval \\spad{[a,b]}.") (($ (|List| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{plot([f1,...,fm],a..b,c..d)} plots the functions \\spad{y = f1(x)},..., \\spad{y = fm(x)} on the interval \\spad{a..b}; y-range of \\spad{[c,d]} is noted in Plot object.") (($ (|List| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|DoubleFloat|))) "\\spad{plot([f1,...,fm],a..b)} plots the functions \\spad{y = f1(x)},..., \\spad{y = fm(x)} on the interval \\spad{a..b}.") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\spad{plot(f,a..b,c..d)} plots the function \\spad{f(x)} on the interval \\spad{[a,b]}; y-range of \\spad{[c,d]} is noted in Plot object.") (($ (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|DoubleFloat|))) "\\indented{1}{plot(f,a..b) plots the function \\spad{f(x)}} \\indented{1}{on the interval \\spad{[a,b]}.} \\blankline \\spad{X} fp:=(t:DFLOAT):DFLOAT \\spad{+->} sin(t) \\spad{X} plot(fp,-1.0..1.0)$PLOT"))) 
 NIL 
 NIL 
-(-934) 
+(-955) 
 ((|constructor| (NIL "This package exports plotting tools")) (|calcRanges| (((|List| (|Segment| (|DoubleFloat|))) (|List| (|List| (|Point| (|DoubleFloat|))))) "\\spad{calcRanges(l)} \\undocumented"))) 
 NIL 
 NIL 
-(-935 K |PolyRing| E -3465 |ProjPt|) 
+(-956 K |PolyRing| E -3832 |ProjPt|) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|multiplicity| (((|NonNegativeInteger|) |#2| |#5| (|Integer|)) "\\spad{multiplicity returns} the multiplicity of the polynomial at given point.") (((|NonNegativeInteger|) |#2| |#5|) "\\spad{multiplicity returns} the multiplicity of the polynomial at given point.")) (|minimalForm| ((|#2| |#2| |#5| (|Integer|)) "\\spad{minimalForm returns} the minimal form after translation to the origin.") ((|#2| |#2| |#5|) "\\spad{minimalForm returns} the minimal form after translation to the origin.")) (|translateToOrigin| ((|#2| |#2| |#5|) "\\spad{translateToOrigin translate} the polynomial from the given point to the origin") ((|#2| |#2| |#5| (|Integer|)) "\\spad{translateToOrigin translate} the polynomial from the given point to the origin")) (|eval| ((|#1| |#2| |#5|) "\\spad{eval returns} the value at given point.")) (|pointInIdeal?| (((|Boolean|) (|List| |#2|) |#5|) "\\spad{pointInIdeal? test} if the given point is in the algebraic set defined by the given list of polynomials."))) 
 NIL 
 NIL 
-(-936 R -3313) 
+(-957 R -3958) 
 ((|constructor| (NIL "Attaching assertions to symbols for pattern matching.")) (|multiple| ((|#2| |#2|) "\\spad{multiple(x)} tells the pattern matcher that \\spad{x} should preferably match a multi-term quantity in a sum or product. For matching on lists, multiple(x) tells the pattern matcher that \\spad{x} should match a list instead of an element of a list. Error: if \\spad{x} is not a symbol.")) (|optional| ((|#2| |#2|) "\\spad{optional(x)} tells the pattern matcher that \\spad{x} can match an identity \\spad{(0} in a sum, 1 in a product or exponentiation). Error: if \\spad{x} is not a symbol.")) (|constant| ((|#2| |#2|) "\\spad{constant(x)} tells the pattern matcher that \\spad{x} should match only the symbol \\spad{'x} and no other quantity. Error: if \\spad{x} is not a symbol.")) (|assert| ((|#2| |#2| (|String|)) "\\spad{assert(x, \\spad{s)}} makes the assertion \\spad{s} about \\spad{x.} Error: if \\spad{x} is not a symbol."))) 
 NIL 
 NIL 
-(-937) 
+(-958) 
 ((|constructor| (NIL "Attaching assertions to symbols for pattern matching.")) (|multiple| (((|Expression| (|Integer|)) (|Symbol|)) "\\spad{multiple(x)} tells the pattern matcher that \\spad{x} should preferably match a multi-term quantity in a sum or product. For matching on lists, multiple(x) tells the pattern matcher that \\spad{x} should match a list instead of an element of a list.")) (|optional| (((|Expression| (|Integer|)) (|Symbol|)) "\\spad{optional(x)} tells the pattern matcher that \\spad{x} can match an identity \\spad{(0} in a sum, 1 in a product or exponentiation)..")) (|constant| (((|Expression| (|Integer|)) (|Symbol|)) "\\spad{constant(x)} tells the pattern matcher that \\spad{x} should match only the symbol \\spad{'x} and no other quantity.")) (|assert| (((|Expression| (|Integer|)) (|Symbol|) (|String|)) "\\spad{assert(x, \\spad{s)}} makes the assertion \\spad{s} about \\spad{x.}"))) 
 NIL 
 NIL 
-(-938 S A B) 
+(-959 S A B) 
 ((|constructor| (NIL "This packages provides tools for matching recursively in type towers.")) (|patternMatch| (((|PatternMatchResult| |#1| |#3|) |#2| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#3|)) "\\spad{patternMatch(expr, pat, res)} matches the pattern \\spad{pat} to the expression expr; res contains the variables of \\spad{pat} which are already matched and their matches. Note that this function handles type towers by changing the predicates and calling the matching function provided by \\spad{A}.")) (|fixPredicate| (((|Mapping| (|Boolean|) |#2|) (|Mapping| (|Boolean|) |#3|)) "\\spad{fixPredicate(f)} returns \\spad{g} defined by g(a) = f(a::B)."))) 
 NIL 
 NIL 
-(-939 S R -3313) 
+(-960 S R -3958) 
 ((|constructor| (NIL "This package provides pattern matching functions on function spaces.")) (|patternMatch| (((|PatternMatchResult| |#1| |#3|) |#3| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#3|)) "\\spad{patternMatch(expr, pat, res)} matches the pattern \\spad{pat} to the expression expr; res contains the variables of \\spad{pat} which are already matched and their matches."))) 
 NIL 
 NIL 
-(-940 I) 
+(-961 I) 
 ((|constructor| (NIL "This package provides pattern matching functions on integers.")) (|patternMatch| (((|PatternMatchResult| (|Integer|) |#1|) |#1| (|Pattern| (|Integer|)) (|PatternMatchResult| (|Integer|) |#1|)) "\\spad{patternMatch(n, pat, res)} matches the pattern \\spad{pat} to the integer \\spad{n;} res contains the variables of \\spad{pat} which are already matched and their matches."))) 
 NIL 
 NIL 
-(-941 S E) 
+(-962 S E) 
 ((|constructor| (NIL "This package provides pattern matching functions on kernels.")) (|patternMatch| (((|PatternMatchResult| |#1| |#2|) (|Kernel| |#2|) (|Pattern| |#1|) (|PatternMatchResult| |#1| |#2|)) "\\spad{patternMatch(f(e1,...,en), pat, res)} matches the pattern \\spad{pat} to \\spad{f(e1,...,en)}; res contains the variables of \\spad{pat} which are already matched and their matches."))) 
 NIL 
 NIL 
-(-942 S R L) 
+(-963 S R L) 
 ((|constructor| (NIL "This package provides pattern matching functions on lists.")) (|patternMatch| (((|PatternMatchListResult| |#1| |#2| |#3|) |#3| (|Pattern| |#1|) (|PatternMatchListResult| |#1| |#2| |#3|)) "\\spad{patternMatch(l, pat, res)} matches the pattern \\spad{pat} to the list \\spad{l;} res contains the variables of \\spad{pat} which are already matched and their matches."))) 
 NIL 
 NIL 
-(-943 S E V R P) 
+(-964 S E V R P) 
 ((|constructor| (NIL "This package provides pattern matching functions on polynomials.")) (|patternMatch| (((|PatternMatchResult| |#1| |#5|) |#5| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#5|)) "\\spad{patternMatch(p, pat, res)} matches the pattern \\spad{pat} to the polynomial \\spad{p;} res contains the variables of \\spad{pat} which are already matched and their matches.") (((|PatternMatchResult| |#1| |#5|) |#5| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#5|) (|Mapping| (|PatternMatchResult| |#1| |#5|) |#3| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#5|))) "\\spad{patternMatch(p, pat, res, vmatch)} matches the pattern \\spad{pat} to the polynomial \\spad{p.} \\spad{res} contains the variables of \\spad{pat} which are already matched and their matches; vmatch is the matching function to use on the variables."))) 
 NIL 
-((|HasCategory| |#3| (LIST (QUOTE -887) (|devaluate| |#1|)))) 
-(-944 R -3313 -1557) 
+((|HasCategory| |#3| (LIST (QUOTE -908) (|devaluate| |#1|)))) 
+(-965 R -3958 -1940) 
 ((|constructor| (NIL "Attaching predicates to symbols for pattern matching.")) (|suchThat| ((|#2| |#2| (|List| (|Mapping| (|Boolean|) |#3|))) "\\spad{suchThat(x, [f1, \\spad{f2,} ..., fn])} attaches the predicate \\spad{f1} and \\spad{f2} and \\spad{...} and \\spad{fn} to \\spad{x.} Error: if \\spad{x} is not a symbol.") ((|#2| |#2| (|Mapping| (|Boolean|) |#3|)) "\\spad{suchThat(x, foo)} attaches the predicate foo to \\spad{x;} error if \\spad{x} is not a symbol."))) 
 NIL 
 NIL 
-(-945 -1557) 
+(-966 -1940) 
 ((|constructor| (NIL "Attaching predicates to symbols for pattern matching.")) (|suchThat| (((|Expression| (|Integer|)) (|Symbol|) (|List| (|Mapping| (|Boolean|) |#1|))) "\\spad{suchThat(x, [f1, \\spad{f2,} ..., fn])} attaches the predicate \\spad{f1} and \\spad{f2} and \\spad{...} and \\spad{fn} to \\spad{x.}") (((|Expression| (|Integer|)) (|Symbol|) (|Mapping| (|Boolean|) |#1|)) "\\spad{suchThat(x, foo)} attaches the predicate foo to \\spad{x.}"))) 
 NIL 
 NIL 
-(-946 S R Q) 
+(-967 S R Q) 
 ((|constructor| (NIL "This package provides pattern matching functions on quotients.")) (|patternMatch| (((|PatternMatchResult| |#1| |#3|) |#3| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#3|)) "\\spad{patternMatch(a/b, pat, res)} matches the pattern \\spad{pat} to the quotient a/b; res contains the variables of \\spad{pat} which are already matched and their matches."))) 
 NIL 
 NIL 
-(-947 S) 
+(-968 S) 
 ((|constructor| (NIL "This package provides pattern matching functions on symbols.")) (|patternMatch| (((|PatternMatchResult| |#1| (|Symbol|)) (|Symbol|) (|Pattern| |#1|) (|PatternMatchResult| |#1| (|Symbol|))) "\\spad{patternMatch(expr, pat, res)} matches the pattern \\spad{pat} to the expression expr; res contains the variables of \\spad{pat} which are already matched and their matches (necessary for recursion)."))) 
 NIL 
 NIL 
-(-948 S R P) 
+(-969 S R P) 
 ((|constructor| (NIL "This package provides tools for the pattern matcher.")) (|patternMatchTimes| (((|PatternMatchResult| |#1| |#3|) (|List| |#3|) (|List| (|Pattern| |#1|)) (|PatternMatchResult| |#1| |#3|) (|Mapping| (|PatternMatchResult| |#1| |#3|) |#3| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#3|))) "\\spad{patternMatchTimes(lsubj, lpat, res, match)} matches the product of patterns \\spad{reduce(*,lpat)} to the product of subjects \\spad{reduce(*,lsubj)}; \\spad{r} contains the previous matches and match is a pattern-matching function on \\spad{P.}")) (|patternMatch| (((|PatternMatchResult| |#1| |#3|) (|List| |#3|) (|List| (|Pattern| |#1|)) (|Mapping| |#3| (|List| |#3|)) (|PatternMatchResult| |#1| |#3|) (|Mapping| (|PatternMatchResult| |#1| |#3|) |#3| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#3|))) "\\spad{patternMatch(lsubj, lpat, op, res, match)} matches the list of patterns \\spad{lpat} to the list of subjects lsubj, allowing for commutativity; \\spad{op} is the operator such that op(lpat) should match op(lsubj) at the end, \\spad{r} contains the previous matches, and match is a pattern-matching function on \\spad{P.}"))) 
 NIL 
 NIL 
-(-949) 
+(-970) 
 ((|constructor| (NIL "This package provides various polynomial number theoretic functions over the integers.")) (|legendre| (((|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{legendre(n)} returns the \\spad{n}th Legendre polynomial \\spad{P[n](x)}. Note that Legendre polynomials, denoted \\spad{P[n](x)}, are computed from the two term recurrence. The generating function is: \\spad{1/sqrt(1-2*t*x+t**2) = sum(P[n](x)*t**n, n=0..infinity)}.")) (|laguerre| (((|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "\\spad{laguerre(n)} returns the \\spad{n}th Laguerre polynomial \\spad{L[n](x)}. Note that Laguerre polynomials, denoted \\spad{L[n](x)}, are computed from the two term recurrence. The generating function is: \\spad{exp(x*t/(t-1))/(1-t) = sum(L[n](x)*t**n/n!, n=0..infinity)}.")) (|hermite| (((|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "\\spad{hermite(n)} returns the \\spad{n}th Hermite polynomial \\spad{H[n](x)}. Note that Hermite polynomials, denoted \\spad{H[n](x)}, are computed from the two term recurrence. The generating function is: \\spad{exp(2*t*x-t**2) = sum(H[n](x)*t**n/n!, n=0..infinity)}.")) (|fixedDivisor| (((|Integer|) (|SparseUnivariatePolynomial| (|Integer|))) "\\spad{fixedDivisor(a)} for \\spad{a(x)} in \\spad{Z[x]} is the largest integer \\spad{f} such that \\spad{f} divides \\spad{a(x=k)} for all integers \\spad{k.} Note that fixed divisor of \\spad{a} is \\spad{reduce(gcd,[a(x=k) for \\spad{k} in 0..degree(a)])}.")) (|euler| (((|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{euler(n)} returns the \\spad{n}th Euler polynomial \\spad{E[n](x)}. Note that Euler polynomials denoted \\spad{E(n,x)} computed by solving the differential equation \\spad{differentiate(E(n,x),x) = \\spad{n} E(n-1,x)} where \\spad{E(0,x) = 1} and initial condition comes from \\spad{E(n) = 2**n E(n,1/2)}.")) (|cyclotomic| (((|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "\\spad{cyclotomic(n)} returns the \\spad{n}th cyclotomic polynomial \\spad{phi[n](x)}. Note that \\spad{phi[n](x)} is the factor of \\spad{x**n - 1} whose roots are the primitive \\spad{n}th roots of unity.")) (|chebyshevU| (((|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "\\spad{chebyshevU(n)} returns the \\spad{n}th Chebyshev polynomial \\spad{U[n](x)}. Note that Chebyshev polynomials of the second kind, denoted \\spad{U[n](x)}, computed from the two term recurrence. The generating function \\spad{1/(1-2*t*x+t**2) = sum(T[n](x)*t**n, n=0..infinity)}.")) (|chebyshevT| (((|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "\\spad{chebyshevT(n)} returns the \\spad{n}th Chebyshev polynomial \\spad{T[n](x)}. Note that Chebyshev polynomials of the first kind, denoted \\spad{T[n](x)}, computed from the two term recurrence. The generating function \\spad{(1-t*x)/(1-2*t*x+t**2) = sum(T[n](x)*t**n, n=0..infinity)}.")) (|bernoulli| (((|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|Integer|)) "\\spad{bernoulli(n)} returns the \\spad{n}th Bernoulli polynomial \\spad{B[n](x)}. Bernoulli polynomials denoted \\spad{B(n,x)} computed by solving the differential equation \\spad{differentiate(B(n,x),x) = \\spad{n} B(n-1,x)} where \\spad{B(0,x) = 1} and initial condition comes from \\spad{B(n) = B(n,0)}."))) 
 NIL 
 NIL 
-(-950 R) 
+(-971 R) 
 ((|constructor| (NIL "This domain implements points in coordinate space"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-722))) (|HasCategory| |#1| (QUOTE (-1054))) (-12 (|HasCategory| |#1| (QUOTE (-1009))) (|HasCategory| |#1| (QUOTE (-1054)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-951 |lv| R) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-743))) (|HasCategory| |#1| (QUOTE (-1075))) (-12 (|HasCategory| |#1| (QUOTE (-1030))) (|HasCategory| |#1| (QUOTE (-1075)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-972 |lv| R) 
 ((|constructor| (NIL "Package with the conversion functions among different kind of polynomials")) (|pToDmp| (((|DistributedMultivariatePolynomial| |#1| |#2|) (|Polynomial| |#2|)) "\\spad{pToDmp(p)} converts \\spad{p} from a \\spadtype{POLY} to a \\spadtype{DMP}.")) (|dmpToP| (((|Polynomial| |#2|) (|DistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{dmpToP(p)} converts \\spad{p} from a \\spadtype{DMP} to a \\spadtype{POLY}.")) (|hdmpToP| (((|Polynomial| |#2|) (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{hdmpToP(p)} converts \\spad{p} from a \\spadtype{HDMP} to a \\spadtype{POLY}.")) (|pToHdmp| (((|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|) (|Polynomial| |#2|)) "\\spad{pToHdmp(p)} converts \\spad{p} from a \\spadtype{POLY} to a \\spadtype{HDMP}.")) (|hdmpToDmp| (((|DistributedMultivariatePolynomial| |#1| |#2|) (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{hdmpToDmp(p)} converts \\spad{p} from a \\spadtype{HDMP} to a \\spadtype{DMP}.")) (|dmpToHdmp| (((|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|) (|DistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{dmpToHdmp(p)} converts \\spad{p} from a \\spadtype{DMP} to a \\spadtype{HDMP}."))) 
 NIL 
 NIL 
-(-952 |TheField| |ThePols|) 
+(-973 |TheField| |ThePols|) 
 ((|constructor| (NIL "\\axiomType{RealPolynomialUtilitiesPackage} provides common functions used by interval coding.")) (|lazyVariations| (((|NonNegativeInteger|) (|List| |#1|) (|Integer|) (|Integer|)) "\\axiom{lazyVariations(l,s1,sn)} is the number of sign variations in the list of non null numbers [s1::l]@sn.")) (|sturmVariationsOf| (((|NonNegativeInteger|) (|List| |#1|)) "\\axiom{sturmVariationsOf(l)} is the number of sign variations in the list of numbers \\spad{l,} note that the first term counts as a sign")) (|boundOfCauchy| ((|#1| |#2|) "\\axiom{boundOfCauchy(p)} bounds the roots of \\spad{p}")) (|sturmSequence| (((|List| |#2|) |#2|) "\\axiom{sturmSequence(p) = sylvesterSequence(p,p')}")) (|sylvesterSequence| (((|List| |#2|) |#2| |#2|) "\\axiom{sylvesterSequence(p,q)} is the negated remainder sequence of \\spad{p} and \\spad{q} divided by the last computed term"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-846)))) 
-(-953 R S) 
+((|HasCategory| |#1| (QUOTE (-867)))) 
+(-974 R S) 
 ((|constructor| (NIL "This package takes a mapping between coefficient rings, and lifts it to a mapping between polynomials over those rings.")) (|map| (((|Polynomial| |#2|) (|Mapping| |#2| |#1|) (|Polynomial| |#1|)) "\\spad{map(f, \\spad{p)}} produces a new polynomial as a result of applying the function \\spad{f} to every coefficient of the polynomial \\spad{p.}"))) 
 NIL 
 NIL 
-(-954 |x| R) 
+(-975 |x| R) 
 ((|constructor| (NIL "This package is primarily to help the interpreter do coercions. It allows you to view a polynomial as a univariate polynomial in one of its variables with coefficients which are again a polynomial in all the other variables.")) (|univariate| (((|UnivariatePolynomial| |#1| (|Polynomial| |#2|)) (|Polynomial| |#2|) (|Variable| |#1|)) "\\spad{univariate(p, \\spad{x)}} converts the polynomial \\spad{p} to a one of type \\spad{UnivariatePolynomial(x,Polynomial(R))}, ie. as a member of \\spad{R[...][x]}."))) 
 NIL 
 NIL 
-(-955 S R E |VarSet|) 
+(-976 S R E |VarSet|) 
 ((|constructor| (NIL "The category for general multi-variate polynomials over a ring \\spad{R,} in variables from VarSet, with exponents from the \\spadtype{OrderedAbelianMonoidSup}.")) (|canonicalUnitNormal| ((|attribute|) "we can choose a unique representative for each associate class. This normalization is chosen to be normalization of leading coefficient (by default).")) (|squareFreePart| (($ $) "\\spad{squareFreePart(p)} returns product of all the irreducible factors of polynomial \\spad{p} each taken with multiplicity one.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(p)} returns the square free factorization of the polynomial \\spad{p.}")) (|primitivePart| (($ $ |#4|) "\\spad{primitivePart(p,v)} returns the unitCanonical associate of the polynomial \\spad{p} with its content with respect to the variable \\spad{v} divided out.") (($ $) "\\spad{primitivePart(p)} returns the unitCanonical associate of the polynomial \\spad{p} with its content divided out.")) (|content| (($ $ |#4|) "\\spad{content(p,v)} is the \\spad{gcd} of the coefficients of the polynomial \\spad{p} when \\spad{p} is viewed as a univariate polynomial with respect to the variable \\spad{v.} Thus, for polynomial 7*x**2*y + 14*x*y**2, the \\spad{gcd} of the coefficients with respect to \\spad{x} is 7*y.")) (|discriminant| (($ $ |#4|) "\\spad{discriminant(p,v)} returns the disriminant of the polynomial \\spad{p} with respect to the variable \\spad{v.}")) (|resultant| (($ $ $ |#4|) "\\spad{resultant(p,q,v)} returns the resultant of the polynomials \\spad{p} and \\spad{q} with respect to the variable \\spad{v.}")) (|primitiveMonomials| (((|List| $) $) "\\spad{primitiveMonomials(p)} gives the list of monomials of the polynomial \\spad{p} with their coefficients removed. Note that \\spad{primitiveMonomials(sum(a_(i) X^(i))) = [X^(1),...,X^(n)]}.")) (|variables| (((|List| |#4|) $) "\\spad{variables(p)} returns the list of those variables actually appearing in the polynomial \\spad{p.}")) (|totalDegree| (((|NonNegativeInteger|) $ (|List| |#4|)) "\\spad{totalDegree(p, lv)} returns the maximum sum (over all monomials of polynomial \\spad{p)} of the variables in the list \\spad{lv.}") (((|NonNegativeInteger|) $) "\\spad{totalDegree(p)} returns the largest sum over all monomials of all exponents of a monomial.")) (|isExpt| (((|Union| (|Record| (|:| |var| |#4|) (|:| |exponent| (|NonNegativeInteger|))) "failed") $) "\\spad{isExpt(p)} returns \\spad{[x, \\spad{n]}} if polynomial \\spad{p} has the form \\spad{x**n} and \\spad{n > 0}.")) (|isTimes| (((|Union| (|List| $) "failed") $) "\\spad{isTimes(p)} returns \\spad{[a1,...,an]} if polynomial \\spad{p = \\spad{a1} \\spad{...} an} and \\spad{n \\spad{>=} 2}, and, for each i, \\spad{ai} is either a nontrivial constant in \\spad{R} or else of the form \\spad{x**e}, where \\spad{e > 0} is an integer and \\spad{x} in a member of VarSet.")) (|isPlus| (((|Union| (|List| $) "failed") $) "\\spad{isPlus(p)} returns \\spad{[m1,...,mn]} if polynomial \\spad{p = \\spad{m1} + \\spad{...} + \\spad{mn}} and \\spad{n \\spad{>=} 2} and each \\spad{mi} is a nonzero monomial.")) (|multivariate| (($ (|SparseUnivariatePolynomial| $) |#4|) "\\spad{multivariate(sup,v)} converts an anonymous univariable polynomial \\spad{sup} to a polynomial in the variable \\spad{v.}") (($ (|SparseUnivariatePolynomial| |#2|) |#4|) "\\spad{multivariate(sup,v)} converts an anonymous univariable polynomial \\spad{sup} to a polynomial in the variable \\spad{v.}")) (|monomial| (($ $ (|List| |#4|) (|List| (|NonNegativeInteger|))) "\\spad{monomial(a,[v1..vn],[e1..en])} returns \\spad{a*prod(vi**ei)}.") (($ $ |#4| (|NonNegativeInteger|)) "\\spad{monomial(a,x,n)} creates the monomial \\spad{a*x**n} where \\spad{a} is a polynomial, \\spad{x} is a variable and \\spad{n} is a nonnegative integer.")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $ |#4|) "\\spad{monicDivide(a,b,v)} divides the polynomial a by the polynomial \\spad{b,} with each viewed as a univariate polynomial in \\spad{v} returning both the quotient and remainder. Error: if \\spad{b} is not monic with respect to \\spad{v.}")) (|minimumDegree| (((|List| (|NonNegativeInteger|)) $ (|List| |#4|)) "\\spad{minimumDegree(p, lv)} gives the list of minimum degrees of the polynomial \\spad{p} with respect to each of the variables in the list \\spad{lv}") (((|NonNegativeInteger|) $ |#4|) "\\spad{minimumDegree(p,v)} gives the minimum degree of polynomial \\spad{p} with respect to \\spad{v,} \\spadignore{i.e.} viewed a univariate polynomial in \\spad{v}")) (|mainVariable| (((|Union| |#4| "failed") $) "\\spad{mainVariable(p)} returns the biggest variable which actually occurs in the polynomial \\spad{p,} or \"failed\" if no variables are present. fails precisely if polynomial satisfies ground?")) (|univariate| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{univariate(p)} converts the multivariate polynomial \\spad{p,} which should actually involve only one variable, into a univariate polynomial in that variable, whose coefficients are in the ground ring. Error: if polynomial is genuinely multivariate") (((|SparseUnivariatePolynomial| $) $ |#4|) "\\spad{univariate(p,v)} converts the multivariate polynomial \\spad{p} into a univariate polynomial in \\spad{v,} whose coefficients are still multivariate polynomials (in all the other variables).")) (|monomials| (((|List| $) $) "\\spad{monomials(p)} returns the list of non-zero monomials of polynomial \\spad{p,} \\spadignore{i.e.} \\spad{monomials(sum(a_(i) X^(i))) = [a_(1) X^(1),...,a_(n) X^(n)]}.")) (|coefficient| (($ $ (|List| |#4|) (|List| (|NonNegativeInteger|))) "\\spad{coefficient(p, \\spad{lv,} ln)} views the polynomial \\spad{p} as a polynomial in the variables of \\spad{lv} and returns the coefficient of the term \\spad{lv**ln}, \\spadignore{i.e.} \\spad{prod(lv_i \\spad{**} ln_i)}.") (($ $ |#4| (|NonNegativeInteger|)) "\\spad{coefficient(p,v,n)} views the polynomial \\spad{p} as a univariate polynomial in \\spad{v} and returns the coefficient of the \\spad{v**n} term.")) (|degree| (((|List| (|NonNegativeInteger|)) $ (|List| |#4|)) "\\spad{degree(p,lv)} gives the list of degrees of polynomial \\spad{p} with respect to each of the variables in the list \\spad{lv.}") (((|NonNegativeInteger|) $ |#4|) "\\spad{degree(p,v)} gives the degree of polynomial \\spad{p} with respect to the variable \\spad{v.}"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasAttribute| |#2| (QUOTE -4600)) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#4| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#4| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#4| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#4| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#4| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (QUOTE (-848)))) 
-(-956 R E |VarSet|) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasAttribute| |#2| (QUOTE -4623)) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#4| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#4| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#4| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#4| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#4| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (QUOTE (-869)))) 
+(-977 R E |VarSet|) 
 ((|constructor| (NIL "The category for general multi-variate polynomials over a ring \\spad{R,} in variables from VarSet, with exponents from the \\spadtype{OrderedAbelianMonoidSup}.")) (|canonicalUnitNormal| ((|attribute|) "we can choose a unique representative for each associate class. This normalization is chosen to be normalization of leading coefficient (by default).")) (|squareFreePart| (($ $) "\\spad{squareFreePart(p)} returns product of all the irreducible factors of polynomial \\spad{p} each taken with multiplicity one.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(p)} returns the square free factorization of the polynomial \\spad{p.}")) (|primitivePart| (($ $ |#3|) "\\spad{primitivePart(p,v)} returns the unitCanonical associate of the polynomial \\spad{p} with its content with respect to the variable \\spad{v} divided out.") (($ $) "\\spad{primitivePart(p)} returns the unitCanonical associate of the polynomial \\spad{p} with its content divided out.")) (|content| (($ $ |#3|) "\\spad{content(p,v)} is the \\spad{gcd} of the coefficients of the polynomial \\spad{p} when \\spad{p} is viewed as a univariate polynomial with respect to the variable \\spad{v.} Thus, for polynomial 7*x**2*y + 14*x*y**2, the \\spad{gcd} of the coefficients with respect to \\spad{x} is 7*y.")) (|discriminant| (($ $ |#3|) "\\spad{discriminant(p,v)} returns the disriminant of the polynomial \\spad{p} with respect to the variable \\spad{v.}")) (|resultant| (($ $ $ |#3|) "\\spad{resultant(p,q,v)} returns the resultant of the polynomials \\spad{p} and \\spad{q} with respect to the variable \\spad{v.}")) (|primitiveMonomials| (((|List| $) $) "\\spad{primitiveMonomials(p)} gives the list of monomials of the polynomial \\spad{p} with their coefficients removed. Note that \\spad{primitiveMonomials(sum(a_(i) X^(i))) = [X^(1),...,X^(n)]}.")) (|variables| (((|List| |#3|) $) "\\spad{variables(p)} returns the list of those variables actually appearing in the polynomial \\spad{p.}")) (|totalDegree| (((|NonNegativeInteger|) $ (|List| |#3|)) "\\spad{totalDegree(p, lv)} returns the maximum sum (over all monomials of polynomial \\spad{p)} of the variables in the list \\spad{lv.}") (((|NonNegativeInteger|) $) "\\spad{totalDegree(p)} returns the largest sum over all monomials of all exponents of a monomial.")) (|isExpt| (((|Union| (|Record| (|:| |var| |#3|) (|:| |exponent| (|NonNegativeInteger|))) "failed") $) "\\spad{isExpt(p)} returns \\spad{[x, \\spad{n]}} if polynomial \\spad{p} has the form \\spad{x**n} and \\spad{n > 0}.")) (|isTimes| (((|Union| (|List| $) "failed") $) "\\spad{isTimes(p)} returns \\spad{[a1,...,an]} if polynomial \\spad{p = \\spad{a1} \\spad{...} an} and \\spad{n \\spad{>=} 2}, and, for each i, \\spad{ai} is either a nontrivial constant in \\spad{R} or else of the form \\spad{x**e}, where \\spad{e > 0} is an integer and \\spad{x} in a member of VarSet.")) (|isPlus| (((|Union| (|List| $) "failed") $) "\\spad{isPlus(p)} returns \\spad{[m1,...,mn]} if polynomial \\spad{p = \\spad{m1} + \\spad{...} + \\spad{mn}} and \\spad{n \\spad{>=} 2} and each \\spad{mi} is a nonzero monomial.")) (|multivariate| (($ (|SparseUnivariatePolynomial| $) |#3|) "\\spad{multivariate(sup,v)} converts an anonymous univariable polynomial \\spad{sup} to a polynomial in the variable \\spad{v.}") (($ (|SparseUnivariatePolynomial| |#1|) |#3|) "\\spad{multivariate(sup,v)} converts an anonymous univariable polynomial \\spad{sup} to a polynomial in the variable \\spad{v.}")) (|monomial| (($ $ (|List| |#3|) (|List| (|NonNegativeInteger|))) "\\spad{monomial(a,[v1..vn],[e1..en])} returns \\spad{a*prod(vi**ei)}.") (($ $ |#3| (|NonNegativeInteger|)) "\\spad{monomial(a,x,n)} creates the monomial \\spad{a*x**n} where \\spad{a} is a polynomial, \\spad{x} is a variable and \\spad{n} is a nonnegative integer.")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $ |#3|) "\\spad{monicDivide(a,b,v)} divides the polynomial a by the polynomial \\spad{b,} with each viewed as a univariate polynomial in \\spad{v} returning both the quotient and remainder. Error: if \\spad{b} is not monic with respect to \\spad{v.}")) (|minimumDegree| (((|List| (|NonNegativeInteger|)) $ (|List| |#3|)) "\\spad{minimumDegree(p, lv)} gives the list of minimum degrees of the polynomial \\spad{p} with respect to each of the variables in the list \\spad{lv}") (((|NonNegativeInteger|) $ |#3|) "\\spad{minimumDegree(p,v)} gives the minimum degree of polynomial \\spad{p} with respect to \\spad{v,} \\spadignore{i.e.} viewed a univariate polynomial in \\spad{v}")) (|mainVariable| (((|Union| |#3| "failed") $) "\\spad{mainVariable(p)} returns the biggest variable which actually occurs in the polynomial \\spad{p,} or \"failed\" if no variables are present. fails precisely if polynomial satisfies ground?")) (|univariate| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{univariate(p)} converts the multivariate polynomial \\spad{p,} which should actually involve only one variable, into a univariate polynomial in that variable, whose coefficients are in the ground ring. Error: if polynomial is genuinely multivariate") (((|SparseUnivariatePolynomial| $) $ |#3|) "\\spad{univariate(p,v)} converts the multivariate polynomial \\spad{p} into a univariate polynomial in \\spad{v,} whose coefficients are still multivariate polynomials (in all the other variables).")) (|monomials| (((|List| $) $) "\\spad{monomials(p)} returns the list of non-zero monomials of polynomial \\spad{p,} \\spadignore{i.e.} \\spad{monomials(sum(a_(i) X^(i))) = [a_(1) X^(1),...,a_(n) X^(n)]}.")) (|coefficient| (($ $ (|List| |#3|) (|List| (|NonNegativeInteger|))) "\\spad{coefficient(p, \\spad{lv,} ln)} views the polynomial \\spad{p} as a polynomial in the variables of \\spad{lv} and returns the coefficient of the term \\spad{lv**ln}, \\spadignore{i.e.} \\spad{prod(lv_i \\spad{**} ln_i)}.") (($ $ |#3| (|NonNegativeInteger|)) "\\spad{coefficient(p,v,n)} views the polynomial \\spad{p} as a univariate polynomial in \\spad{v} and returns the coefficient of the \\spad{v**n} term.")) (|degree| (((|List| (|NonNegativeInteger|)) $ (|List| |#3|)) "\\spad{degree(p,lv)} gives the list of degrees of polynomial \\spad{p} with respect to each of the variables in the list \\spad{lv.}") (((|NonNegativeInteger|) $ |#3|) "\\spad{degree(p,v)} gives the degree of polynomial \\spad{p} with respect to the variable \\spad{v.}"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
 NIL 
-(-957 E V R P -3313) 
+(-978 E V R P -3958) 
 ((|constructor| (NIL "Manipulations on polynomial quotients This package transforms multivariate polynomials or fractions into univariate polynomials or fractions, and back.")) (|isPower| (((|Union| (|Record| (|:| |val| |#5|) (|:| |exponent| (|Integer|))) "failed") |#5|) "\\spad{isPower(p)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0}, \"failed\" otherwise.")) (|isExpt| (((|Union| (|Record| (|:| |var| |#2|) (|:| |exponent| (|Integer|))) "failed") |#5|) "\\spad{isExpt(p)} returns \\spad{[x, \\spad{n]}} if \\spad{p = x**n} and \\spad{n \\spad{<>} 0}, \"failed\" otherwise.")) (|isTimes| (((|Union| (|List| |#5|) "failed") |#5|) "\\spad{isTimes(p)} returns \\spad{[a1,...,an]} if \\spad{p = \\spad{a1} \\spad{...} an} and \\spad{n > 1}, \"failed\" otherwise.")) (|isPlus| (((|Union| (|List| |#5|) "failed") |#5|) "\\spad{isPlus(p)} returns [m1,...,mn] if \\spad{p = \\spad{m1} + \\spad{...} + \\spad{mn}} and \\spad{n > 1}, \"failed\" otherwise.")) (|multivariate| ((|#5| (|Fraction| (|SparseUnivariatePolynomial| |#5|)) |#2|) "\\spad{multivariate(f, \\spad{v)}} applies both the numerator and denominator of \\spad{f} to \\spad{v.}")) (|univariate| (((|SparseUnivariatePolynomial| |#5|) |#5| |#2| (|SparseUnivariatePolynomial| |#5|)) "\\spad{univariate(f, \\spad{x,} \\spad{p)}} returns \\spad{f} viewed as a univariate polynomial in \\spad{x,} using the side-condition \\spad{p(x) = 0}.") (((|Fraction| (|SparseUnivariatePolynomial| |#5|)) |#5| |#2|) "\\spad{univariate(f, \\spad{v)}} returns \\spad{f} viewed as a univariate rational function in \\spad{v.}")) (|mainVariable| (((|Union| |#2| "failed") |#5|) "\\spad{mainVariable(f)} returns the highest variable appearing in the numerator or the denominator of \\spad{f,} \"failed\" if \\spad{f} has no variables.")) (|variables| (((|List| |#2|) |#5|) "\\spad{variables(f)} returns the list of variables appearing in the numerator or the denominator of \\spad{f.}"))) 
 NIL 
 NIL 
-(-958 E |Vars| R P S) 
+(-979 E |Vars| R P S) 
 ((|constructor| (NIL "This package provides a very general map function, which given a set \\spad{S} and polynomials over \\spad{R} with maps from the variables into \\spad{S} and the coefficients into \\spad{S,} maps polynomials into \\spad{S.} \\spad{S} is assumed to support \\spad{+}, \\spad{*} and \\spad{**}.")) (|map| ((|#5| (|Mapping| |#5| |#2|) (|Mapping| |#5| |#3|) |#4|) "\\spad{map(varmap, coefmap, \\spad{p)}} takes a varmap, a mapping from the variables of polynomial \\spad{p} into \\spad{S,} coefmap, a mapping from coefficients of \\spad{p} into \\spad{S,} and \\spad{p,} and produces a member of \\spad{S} using the corresponding arithmetic. in \\spad{S}"))) 
 NIL 
 NIL 
-(-959 R) 
+(-980 R) 
 ((|constructor| (NIL "This type is the basic representation of sparse recursive multivariate polynomials whose variables are arbitrary symbols. The ordering is alphabetic determined by the Symbol type. The coefficient ring may be non commutative, but the variables are assumed to commute.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(p,x)} computes the integral of \\spad{p*dx}, \\spadignore{i.e.} integrates the polynomial \\spad{p} with respect to the variable \\spad{x.}"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1170) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-1170) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-1170) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-1170) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-1170) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-960 E V R P -3313) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1191) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-1191) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-1191) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-1191) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-1191) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-981 E V R P -3958) 
 ((|constructor| (NIL "Computes \\spad{n}-th roots of quotients of multivariate polynomials")) (|nthr| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#4|) (|:| |radicand| (|List| |#4|))) |#4| (|NonNegativeInteger|)) "\\spad{nthr(p,n)} should be local but conditional")) (|froot| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#5|) (|:| |radicand| |#5|)) |#5| (|NonNegativeInteger|)) "\\spad{froot(f, \\spad{n)}} returns \\spad{[m,c,r]} such that \\spad{f**(1/n) = \\spad{c} * r**(1/m)}.")) (|qroot| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#5|) (|:| |radicand| |#5|)) (|Fraction| (|Integer|)) (|NonNegativeInteger|)) "\\spad{qroot(f, \\spad{n)}} returns \\spad{[m,c,r]} such that \\spad{f**(1/n) = \\spad{c} * r**(1/m)}.")) (|rroot| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#5|) (|:| |radicand| |#5|)) |#3| (|NonNegativeInteger|)) "\\spad{rroot(f, \\spad{n)}} returns \\spad{[m,c,r]} such that \\spad{f**(1/n) = \\spad{c} * r**(1/m)}.")) (|coerce| (($ |#4|) "\\spad{coerce(p)} \\undocumented")) (|denom| ((|#4| $) "\\spad{denom(x)} \\undocumented")) (|numer| ((|#4| $) "\\spad{numer(x)} \\undocumented"))) 
 NIL 
-((|HasCategory| |#3| (QUOTE (-457)))) 
-(-961) 
+((|HasCategory| |#3| (QUOTE (-477)))) 
+(-982) 
 ((|constructor| (NIL "This is a low-level package which implements operations on vectors treated as univariate modular polynomials. Most operations takes modulus as parameter. Modulus is machine sized prime which should be small enough to avoid overflow in intermediate calculations.")) (|resultant| (((|Integer|) (|U32Vector|) (|U32Vector|) (|Integer|)) "\\spad{resultant(v1, \\spad{v2,} \\spad{p)}} computes resultant of \\spad{v1} and \\spad{v2} modulo \\spad{p.}")) (|extendedgcd| (((|List| (|U32Vector|)) (|U32Vector|) (|U32Vector|) (|Integer|)) "extended_gcd(v1, \\spad{v2,} \\spad{p)} gives \\spad{[g,} \\spad{c1,} \\spad{c2]} such that \\spad{g} is \\spad{gcd(v1, \\spad{v2,} p)}, \\spad{g = \\spad{c1*v1} + c2*v2} and degree(c1) < max(degree(v2) - degree(g), 0) and degree(c2) < max(degree(v1) - degree(g), 1)")) (|degree| (((|Integer|) (|U32Vector|)) "\\spad{degree(v)} is degree of \\spad{v} treated as polynomial")) (|lcm| (((|U32Vector|) (|PrimitiveArray| (|U32Vector|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{lcm(a, lo, hi, \\spad{p)}} computes \\spad{lcm} of elements a(lo), a(lo+1), ..., a(hi).")) (|gcd| (((|U32Vector|) (|PrimitiveArray| (|U32Vector|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{gcd(a, lo, hi, \\spad{p)}} computes \\spad{gcd} of elements a(lo), a(lo+1), ..., a(hi).") (((|U32Vector|) (|U32Vector|) (|U32Vector|) (|Integer|)) "\\spad{gcd(v1, \\spad{v2,} \\spad{p)}} computes monic \\spad{gcd} of \\spad{v1} and \\spad{v2} modulo \\spad{p.}")) (|tomodpa| (((|U32Vector|) (|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "to_mod_pa(s, \\spad{p)} reduces coefficients of polynomial \\spad{s} modulo prime \\spad{p} and converts the result to vector")) (|vectorcombination| (((|Void|) (|U32Vector|) (|Integer|) (|U32Vector|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "vector_combination(v1, \\spad{c1,} \\spad{v2,} \\spad{c2,} \\spad{n,} delta, \\spad{p)} replaces first \\spad{n} + 1 entires of \\spad{v1} by corresponding entries of \\spad{c1*v1+c2*x^delta*v2} mod \\spad{p.}")) (|remainder!| (((|Void|) (|U32Vector|) (|U32Vector|) (|Integer|)) "Polynomial remainder")) (|divide!| (((|Void|) (|U32Vector|) (|U32Vector|) (|U32Vector|) (|Integer|)) "Polynomial division.")) (|differentiate| (((|U32Vector|) (|U32Vector|) (|NonNegativeInteger|) (|Integer|)) "Polynomial differentiation.") (((|U32Vector|) (|U32Vector|) (|Integer|)) "Polynomial differentiation.")) (|pow| (((|U32Vector|) (|U32Vector|) (|PositiveInteger|) (|NonNegativeInteger|) (|Integer|)) "\\spad{pow(u, \\spad{n,} \\spad{d,} \\spad{p)}} returns u^n truncated after degree \\spad{d,} except if n=1, in which case \\spad{u} itself is returned")) (|truncatedmuladd| (((|Void|) (|U32Vector|) (|U32Vector|) (|U32Vector|) (|Integer|) (|Integer|)) "truncated_mul_add(x, \\spad{y,} \\spad{z,} \\spad{d,} \\spad{p)} adds to \\spad{z} the produce x*y truncated after degree \\spad{d}")) (|truncatedmultiplication| (((|U32Vector|) (|U32Vector|) (|U32Vector|) (|Integer|) (|Integer|)) "truncated_multiplication(x, \\spad{y,} \\spad{d,} \\spad{p)} computes x*y truncated after degree \\spad{d}")) (|mul| (((|U32Vector|) (|U32Vector|) (|U32Vector|) (|Integer|)) "Polynomial multiplication.")) (|mulbyscalar| (((|Void|) (|U32Vector|) (|Integer|) (|Integer|) (|Integer|)) "mul_by_scalar(v, deg, \\spad{c,} \\spad{p)} treats \\spad{v} as coefficients of polynomial of degree deg and multiplies in place this polynomial by scalar \\spad{c}")) (|mulbybinomial| (((|Void|) (|U32Vector|) (|Integer|) (|Integer|) (|Integer|)) "mul_by_binomial(v, deg, \\spad{pt,} \\spad{p)} treats \\spad{v} as coefficients of polynomial of degree deg and multiplies in place this polynomial by binomial \\spad{(x} + pt). Highest coefficient of product is ignored.") (((|Void|) (|U32Vector|) (|Integer|) (|Integer|)) "mul_by_binomial(v, \\spad{pt,} \\spad{p)} treats \\spad{v} a polynomial and multiplies in place this polynomial by binomial \\spad{(x} + pt). Highest coefficient of product is ignored.")) (|vectoraddmul| (((|Void|) (|U32Vector|) (|U32Vector|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "vector_add_mul(v1, \\spad{v2,} \\spad{m,} \\spad{n,} \\spad{c,} \\spad{p)} sets v1(m), ..., v1(n) to corresponding extries in \\spad{v1} + \\spad{c*v2} modulo \\spad{p.}")) (|evalat| (((|Integer|) (|U32Vector|) (|Integer|) (|Integer|) (|Integer|)) "\\indented{1}{eval_at(v, deg, \\spad{pt,} \\spad{p)} treats \\spad{v} as coefficients of} \\indented{1}{polynomial of degree deg and evaluates the} \\indented{1}{polynomial at point \\spad{pt} modulo \\spad{p}} \\blankline \\spad{X} a:=new(3,1)$U32VEC \\spad{X} \\spad{a.1:=2} \\spad{X} eval_at(a,2,3,1024) \\spad{X} eval_at(a,2,2,8) \\spad{X} eval_at(a,2,3,10)")) (|copyslice| (((|Void|) (|U32Vector|) (|U32Vector|) (|Integer|) (|Integer|)) "copy_first(v1, \\spad{v2,} \\spad{m,} \\spad{n)} copies the slice of \\spad{v2} starting at \\spad{m} elements and having \\spad{n} elements into corresponding positions in \\spad{v1.}")) (|copyfirst| (((|Void|) (|U32Vector|) (|U32Vector|) (|Integer|)) "copy_first(v1, \\spad{v2,} \\spad{n)} copies first \\spad{n} elements of \\spad{v2} into \\spad{n} first positions in \\spad{v1.}"))) 
 NIL 
 NIL 
-(-962) 
+(-983) 
 ((|constructor| (NIL "\\indented{1}{Author: Clifton \\spad{J.} Williamson} Date Created: 11 January 1990 Date Last Updated: 15 June 1990 Description:")) (|yRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{yRange(c)} returns the range of the y-coordinates of the points on the curve \\spad{c.}")) (|xRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{xRange(c)} returns the range of the x-coordinates of the points on the curve \\spad{c.}")) (|listBranches| (((|List| (|List| (|Point| (|DoubleFloat|)))) $) "\\spad{listBranches(c)} returns a list of lists of points, representing the branches of the curve \\spad{c.}"))) 
 NIL 
 NIL 
-(-963 R L) 
+(-984 R L) 
 ((|constructor| (NIL "\\spadtype{PrecomputedAssociatedEquations} stores some generic precomputations which speed up the computations of the associated equations needed for factoring operators.")) (|firstUncouplingMatrix| (((|Union| (|Matrix| |#1|) "failed") |#2| (|PositiveInteger|)) "\\spad{firstUncouplingMatrix(op, \\spad{m)}} returns the matrix A such that \\spad{A \\spad{w} = (W',W'',...,W^N)} in the corresponding associated equations for right-factors of order \\spad{m} of op. Returns \"failed\" if the matrix A has not been precomputed for the particular combination \\spad{degree(L), \\spad{m}.}"))) 
 NIL 
 NIL 
-(-964 A B) 
+(-985 A B) 
 ((|constructor| (NIL "This package provides tools for operating on primitive arrays with unary and binary functions involving different underlying types")) (|map| (((|PrimitiveArray| |#2|) (|Mapping| |#2| |#1|) (|PrimitiveArray| |#1|)) "\\indented{1}{map(f,a) applies function \\spad{f} to each member of primitive array} \\indented{1}{\\spad{a} resulting in a new primitive array over a} \\indented{1}{possibly different underlying domain.} \\blankline \\spad{X} T1:=PrimitiveArrayFunctions2(Integer,Integer) \\spad{X} map(x+->x+2,[i for \\spad{i} in 1..10])$T1")) (|reduce| ((|#2| (|Mapping| |#2| |#1| |#2|) (|PrimitiveArray| |#1|) |#2|) "\\indented{1}{reduce(f,a,r) applies function \\spad{f} to each} \\indented{1}{successive element of the} \\indented{1}{primitive array \\spad{a} and an accumulant initialized to \\spad{r.}} \\indented{1}{For example, \\spad{reduce(_+$Integer,[1,2,3],0)}} \\indented{1}{does \\spad{3+(2+(1+0))}. Note that third argument \\spad{r}} \\indented{1}{may be regarded as the identity element for the function \\spad{f.}} \\blankline \\spad{X} T1:=PrimitiveArrayFunctions2(Integer,Integer) \\spad{X} adder(a:Integer,b:Integer):Integer \\spad{==} a+b \\spad{X} reduce(adder,[i for \\spad{i} in 1..10],0)$T1")) (|scan| (((|PrimitiveArray| |#2|) (|Mapping| |#2| |#1| |#2|) (|PrimitiveArray| |#1|) |#2|) "\\indented{1}{scan(f,a,r) successively applies} \\indented{1}{\\spad{reduce(f,x,r)} to more and more leading sub-arrays} \\indented{1}{x of primitive array \\spad{a}.} \\indented{1}{More precisely, if \\spad{a} is \\spad{[a1,a2,...]}, then} \\indented{1}{\\spad{scan(f,a,r)} returns} \\indented{1}{\\spad{[reduce(f,[a1],r),reduce(f,[a1,a2],r),...]}.} \\blankline \\spad{X} T1:=PrimitiveArrayFunctions2(Integer,Integer) \\spad{X} adder(a:Integer,b:Integer):Integer \\spad{==} a+b \\spad{X} scan(adder,[i for \\spad{i} in 1..10],0)$T1"))) 
 NIL 
 NIL 
-(-965 S) 
+(-986 S) 
 ((|constructor| (NIL "This provides a fast array type with no bound checking on elt's. Minimum index is 0 in this type, cannot be changed"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-966) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-987) 
 ((|constructor| (NIL "Category for the functions defined by integrals.")) (|integral| (($ $ (|SegmentBinding| $)) "\\spad{integral(f, \\spad{x} = a..b)} returns the formal definite integral of \\spad{f} \\spad{dx} for \\spad{x} between \\spad{a} and \\spad{b.}") (($ $ (|Symbol|)) "\\spad{integral(f, \\spad{x)}} returns the formal integral of \\spad{f} \\spad{dx.}"))) 
 NIL 
 NIL 
-(-967 -3313) 
+(-988 -3958) 
 ((|constructor| (NIL "PrimitiveElement provides functions to compute primitive elements in algebraic extensions.")) (|primitiveElement| (((|Record| (|:| |coef| (|List| (|Integer|))) (|:| |poly| (|List| (|SparseUnivariatePolynomial| |#1|))) (|:| |prim| (|SparseUnivariatePolynomial| |#1|))) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|)) (|Symbol|)) "\\spad{primitiveElement([p1,...,pn], [a1,...,an], a)} returns \\spad{[[c1,...,cn], [q1,...,qn], \\spad{q]}} such that then \\spad{k(a1,...,an) = k(a)}, where \\spad{a = \\spad{a1} \\spad{c1} + \\spad{...} + an cn}, \\spad{ai = qi(a)}, and \\spad{q(a) = 0}. The pi's are the defining polynomials for the ai's. This operation uses the technique of \\spadglossSee{groebner bases}{Groebner basis}.") (((|Record| (|:| |coef| (|List| (|Integer|))) (|:| |poly| (|List| (|SparseUnivariatePolynomial| |#1|))) (|:| |prim| (|SparseUnivariatePolynomial| |#1|))) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|))) "\\spad{primitiveElement([p1,...,pn], [a1,...,an])} returns \\spad{[[c1,...,cn], [q1,...,qn], \\spad{q]}} such that then \\spad{k(a1,...,an) = k(a)}, where \\spad{a = \\spad{a1} \\spad{c1} + \\spad{...} + an cn}, \\spad{ai = qi(a)}, and \\spad{q(a) = 0}. The pi's are the defining polynomials for the ai's. This operation uses the technique of \\spadglossSee{groebner bases}{Groebner basis}.") (((|Record| (|:| |coef1| (|Integer|)) (|:| |coef2| (|Integer|)) (|:| |prim| (|SparseUnivariatePolynomial| |#1|))) (|Polynomial| |#1|) (|Symbol|) (|Polynomial| |#1|) (|Symbol|)) "\\spad{primitiveElement(p1, a1, \\spad{p2,} a2)} returns \\spad{[c1, \\spad{c2,} \\spad{q]}} such that \\spad{k(a1, a2) = k(a)} where \\spad{a = \\spad{c1} \\spad{a1} + \\spad{c2} a2, and q(a) = 0}. The pi's are the defining polynomials for the ai's. The \\spad{p2} may involve a1, but \\spad{p1} must not involve a2. This operation uses \\spadfun{resultant}."))) 
 NIL 
 NIL 
-(-968 I) 
+(-989 I) 
 ((|constructor| (NIL "The \\spadtype{IntegerPrimesPackage} implements a modification of Rabin's probabilistic primality test and the utility functions \\spadfun{nextPrime}, \\spadfun{prevPrime} and \\spadfun{primes}.")) (|primes| (((|List| |#1|) |#1| |#1|) "\\spad{primes(a,b)} returns a list of all primes \\spad{p} with \\spad{a \\spad{<=} \\spad{p} \\spad{<=} \\spad{b}}")) (|prevPrime| ((|#1| |#1|) "\\spad{prevPrime(n)} returns the largest prime strictly smaller than \\spad{n}")) (|nextPrime| ((|#1| |#1|) "\\spad{nextPrime(n)} returns the smallest prime strictly larger than \\spad{n}")) (|prime?| (((|Boolean|) |#1|) "\\spad{prime?(n)} returns \\spad{true} if \\spad{n} is prime and \\spad{false} if not. The algorithm used is Rabin's probabilistic primality test (reference: Knuth Volume 2 Semi Numerical Algorithms). If \\spad{prime? \\spad{n}} returns false, \\spad{n} is proven composite. If \\spad{prime? \\spad{n}} returns true, prime? may be in error however, the probability of error is very low. and is zero below 25*10**9 (due to a result of Pomerance et al), below 10**12 and 10**13 due to results of Pinch, and below 341550071728321 due to a result of Jaeschke. Specifically, this implementation does at least 10 pseudo prime tests and so the probability of error is \\spad{< 4**(-10)}. The running time of this method is cubic in the length of the input \\spad{n,} that is \\spad{O( (log \\spad{n)**3} \\spad{)},} for n<10**20. beyond that, the algorithm is quartic, \\spad{O( (log \\spad{n)**4} \\spad{)}.} Two improvements due to Davenport have been incorporated which catches some trivial strong pseudo-primes, such as [Jaeschke, 1991] 1377161253229053 * 413148375987157, which the original algorithm regards as prime"))) 
 NIL 
 NIL 
-(-969) 
+(-990) 
 ((|constructor| (NIL "PrintPackage provides a print function for output forms.")) (|print| (((|Void|) (|OutputForm|)) "\\spad{print(o)} writes the output form \\spad{o} on standard output using the two-dimensional formatter."))) 
 NIL 
 NIL 
-(-970 K |symb| |PolyRing| E |ProjPt|) 
+(-991 K |symb| |PolyRing| E |ProjPt|) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|rationalPoints| (((|List| |#5|) |#3| (|PositiveInteger|)) "\\axiom{rationalPoints(f,d)} returns all points on the curve \\axiom{f} in the extension of the ground field of degree \\axiom{d}. For \\axiom{d > 1} this only works if \\axiom{K} is a \\axiomType{LocallyAlgebraicallyClosedField}")) (|algebraicSet| (((|List| |#5|) (|List| |#3|)) "\\spad{algebraicSet returns} the algebraic set if finite (dimension 0).")) (|singularPoints| (((|List| |#5|) |#3|) "\\spad{singularPoints retourne} les points singulier")) (|singularPointsWithRestriction| (((|List| |#5|) |#3| (|List| |#3|)) "return the singular points that anhilate"))) 
 NIL 
 NIL 
-(-971 R E) 
+(-992 R E) 
 ((|constructor| (NIL "This domain represents generalized polynomials with coefficients (from a not necessarily commutative ring), and terms indexed by their exponents (from an arbitrary ordered abelian monoid). This type is used, for example, by the \\spadtype{DistributedMultivariatePolynomial} domain where the exponent domain is a direct product of non negative integers.")) (|canonicalUnitNormal| ((|attribute|) "canonicalUnitNormal guarantees that the function unitCanonical returns the same representative for all associates of any particular element.")) (|fmecg| (($ $ |#2| |#1| $) "\\spad{fmecg(p1,e,r,p2)} finds \\spad{x} : \\spad{p1} - \\spad{r} * x**e * \\spad{p2}"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (-12 (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-138)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#1| (QUOTE -4600))) 
-(-972 A B) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (-12 (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-158)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#1| (QUOTE -4623))) 
+(-993 A B) 
 ((|constructor| (NIL "This domain implements cartesian product")) (|selectsecond| ((|#2| $) "\\spad{selectsecond(x)} is not documented")) (|selectfirst| ((|#1| $) "\\spad{selectfirst(x)} is not documented")) (|makeprod| (($ |#1| |#2|) "\\indented{1}{makeprod(a,b) computes the product of two functions} \\blankline \\spad{X} f:=(x:INT):INT \\spad{+->} 3*x \\spad{X} g:=(x:INT):INT \\spad{+->} \\spad{x^3} \\spad{X} h(x:INT):Product(INT,INT) \\spad{==} makeprod(f \\spad{x,} \\spad{g} \\spad{x)} \\spad{X} h(3)"))) 
-((-4599 -12 (|has| |#2| (-482)) (|has| |#1| (-482)))) 
-((-12 (|HasCategory| |#1| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#2| (QUOTE (-482)))) (-12 (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#2| (QUOTE (-374)))) (-12 (|HasCategory| |#1| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-722)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#2| (QUOTE (-482)))) (-12 (|HasCategory| |#1| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-722))))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-138)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#1| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-794))))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#1| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-794))))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-138))) (|HasCategory| |#2| (QUOTE (-138)))) (-12 (|HasCategory| |#1| (QUOTE (-482))) (|HasCategory| |#2| (QUOTE (-482)))) (-12 (|HasCategory| |#1| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-722)))) (-12 (|HasCategory| |#1| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-794))))) (-12 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-848)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-794))) (|HasCategory| |#2| (QUOTE (-794)))) (-12 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-848)))))) 
-(-973 K) 
+((-4622 -12 (|has| |#2| (-502)) (|has| |#1| (-502)))) 
+((-12 (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#2| (QUOTE (-502)))) (-12 (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#2| (QUOTE (-394)))) (-12 (|HasCategory| |#1| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-743)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#2| (QUOTE (-502)))) (-12 (|HasCategory| |#1| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-743))))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-158)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-815))))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-815))))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-158))) (|HasCategory| |#2| (QUOTE (-158)))) (-12 (|HasCategory| |#1| (QUOTE (-502))) (|HasCategory| |#2| (QUOTE (-502)))) (-12 (|HasCategory| |#1| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-743)))) (-12 (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-815))))) (-12 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-869)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-869)))))) 
+(-994 K) 
 ((|constructor| (NIL "This is part of the PAFF package, related to projective space."))) 
 NIL 
 NIL 
-(-974 K) 
+(-995 K) 
 ((|constructor| (NIL "This is part of the PAFF package, related to projective space."))) 
 NIL 
 NIL 
-(-975 -3465 K) 
+(-996 -3832 K) 
 ((|constructor| (NIL "This is part of the PAFF package, related to projective space."))) 
 NIL 
 NIL 
-(-976 S) 
+(-997 S) 
 ((|constructor| (NIL "A priority queue is a bag of items from an ordered set where the item extracted is always the maximum element.")) (|merge!| (($ $ $) "\\spad{merge!(q,q1)} destructively changes priority queue \\spad{q} to include the values from priority queue \\spad{q1.}")) (|merge| (($ $ $) "\\spad{merge(q1,q2)} returns combines priority queues \\spad{q1} and \\spad{q2} to return a single priority queue \\spad{q.}")) (|max| ((|#1| $) "\\spad{max(q)} returns the maximum element of priority queue \\spad{q.}"))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-977 R |polR|) 
+(-998 R |polR|) 
 ((|constructor| (NIL "This package contains some functions: discriminant, resultant, subResultantGcd, chainSubResultants, degreeSubResultant, lastSubResultant, resultantEuclidean, subResultantGcdEuclidean, semiSubResultantGcdEuclidean1, semiSubResultantGcdEuclidean2\\br These procedures come from improvements of the subresultants algorithm.")) (|semiResultantEuclideannaif| (((|Record| (|:| |coef2| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{resultantEuclidean_naif(P,Q)} returns the semi-extended resultant of \\axiom{P} and \\axiom{Q} computed by means of the naive algorithm.")) (|resultantEuclideannaif| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{resultantEuclidean_naif(P,Q)} returns the extended resultant of \\axiom{P} and \\axiom{Q} computed by means of the naive algorithm.")) (|resultantnaif| ((|#1| |#2| |#2|) "\\axiom{resultantEuclidean_naif(P,Q)} returns the resultant of \\axiom{P} and \\axiom{Q} computed by means of the naive algorithm.")) (|nextsousResultant2| ((|#2| |#2| |#2| |#2| |#1|) "\\axiom{nextsousResultant2(P, \\spad{Q,} \\spad{Z,} \\spad{s)}} returns the subresultant \\axiom{S_{e-1}} where \\axiom{P ~ S_d, \\spad{Q} = S_{d-1}, \\spad{Z} = S_e, \\spad{s} = lc(S_d)}")) (|Lazard2| ((|#2| |#2| |#1| |#1| (|NonNegativeInteger|)) "\\axiom{Lazard2(F, \\spad{x,} \\spad{y,} \\spad{n)}} computes \\axiom{(x/y)**(n-1) * \\spad{F}}")) (|Lazard| ((|#1| |#1| |#1| (|NonNegativeInteger|)) "\\axiom{Lazard(x, \\spad{y,} \\spad{n)}} computes \\axiom{x**n/y**(n-1)}")) (|divide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2|) "\\axiom{divide(F,G)} computes quotient and rest of the exact euclidean division of \\axiom{F} by \\axiom{G}.")) (|pseudoDivide| (((|Record| (|:| |coef| |#1|) (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2|) "\\axiom{pseudoDivide(P,Q)} computes the pseudoDivide of \\axiom{P} by \\axiom{Q}.")) (|exquo| (((|Vector| |#2|) (|Vector| |#2|) |#1|) "\\axiom{v exquo \\spad{r}} computes the exact quotient of \\axiom{v} by \\axiom{r}")) (* (((|Vector| |#2|) |#1| (|Vector| |#2|)) "\\axiom{r * \\spad{v}} computes the product of \\axiom{r} and \\axiom{v}")) (|gcd| ((|#2| |#2| |#2|) "\\axiom{gcd(P, \\spad{Q)}} returns the \\spad{gcd} of \\axiom{P} and \\axiom{Q}.")) (|semiResultantReduitEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |resultantReduit| |#1|)) |#2| |#2|) "\\axiom{semiResultantReduitEuclidean(P,Q)} returns the \"reduce resultant\" and carries out the equality \\axiom{...P + coef2*Q = resultantReduit(P,Q)}.")) (|resultantReduitEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |resultantReduit| |#1|)) |#2| |#2|) "\\axiom{resultantReduitEuclidean(P,Q)} returns the \"reduce resultant\" and carries out the equality \\axiom{coef1*P + coef2*Q = resultantReduit(P,Q)}.")) (|resultantReduit| ((|#1| |#2| |#2|) "\\axiom{resultantReduit(P,Q)} returns the \"reduce resultant\" of \\axiom{P} and \\axiom{Q}.")) (|schema| (((|List| (|NonNegativeInteger|)) |#2| |#2|) "\\axiom{schema(P,Q)} returns the list of degrees of non zero subresultants of \\axiom{P} and \\axiom{Q}.")) (|chainSubResultants| (((|List| |#2|) |#2| |#2|) "\\axiom{chainSubResultants(P, \\spad{Q)}} computes the list of non zero subresultants of \\axiom{P} and \\axiom{Q}.")) (|semiDiscriminantEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |discriminant| |#1|)) |#2|) "\\axiom{discriminantEuclidean(P)} carries out the equality \\axiom{...P + \\spad{coef2} * D(P) = discriminant(P)}. Warning. \\axiom{degree(P) \\spad{>=} degree(Q)}.")) (|discriminantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |discriminant| |#1|)) |#2|) "\\axiom{discriminantEuclidean(P)} carries out the equality \\axiom{coef1 * \\spad{P} + \\spad{coef2} * D(P) = discriminant(P)}.")) (|discriminant| ((|#1| |#2|) "\\axiom{discriminant(P, \\spad{Q)}} returns the discriminant of \\axiom{P} and \\axiom{Q}.")) (|semiSubResultantGcdEuclidean1| (((|Record| (|:| |coef1| |#2|) (|:| |gcd| |#2|)) |#2| |#2|) "\\axiom{semiSubResultantGcdEuclidean1(P,Q)} carries out the equality \\axiom{coef1*P + ? \\spad{Q} = \\spad{+/-} S_i(P,Q)} where the degree (not the indice) of the subresultant \\axiom{S_i(P,Q)} is the smaller as possible.")) (|semiSubResultantGcdEuclidean2| (((|Record| (|:| |coef2| |#2|) (|:| |gcd| |#2|)) |#2| |#2|) "\\axiom{semiSubResultantGcdEuclidean2(P,Q)} carries out the equality \\axiom{...P + coef2*Q = \\spad{+/-} S_i(P,Q)} where the degree (not the indice) of the subresultant \\axiom{S_i(P,Q)} is the smaller as possible. Warning. \\axiom{degree(P) \\spad{>=} degree(Q)}.")) (|subResultantGcdEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |gcd| |#2|)) |#2| |#2|) "\\axiom{subResultantGcdEuclidean(P,Q)} carries out the equality \\axiom{coef1*P + coef2*Q = \\spad{+/-} S_i(P,Q)} where the degree (not the indice) of the subresultant \\axiom{S_i(P,Q)} is the smaller as possible.")) (|subResultantGcd| ((|#2| |#2| |#2|) "\\axiom{subResultantGcd(P, \\spad{Q)}} returns the \\spad{gcd} of two primitive polynomials \\axiom{P} and \\axiom{Q}.")) (|semiLastSubResultantEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) "\\axiom{semiLastSubResultantEuclidean(P, \\spad{Q)}} computes the last non zero subresultant \\axiom{S} and carries out the equality \\axiom{...P + coef2*Q = \\spad{S}.} Warning. \\axiom{degree(P) \\spad{>=} degree(Q)}.")) (|lastSubResultantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) "\\axiom{lastSubResultantEuclidean(P, \\spad{Q)}} computes the last non zero subresultant \\axiom{S} and carries out the equality \\axiom{coef1*P + coef2*Q = \\spad{S}.}")) (|lastSubResultant| ((|#2| |#2| |#2|) "\\axiom{lastSubResultant(P, \\spad{Q)}} computes the last non zero subresultant of \\axiom{P} and \\axiom{Q}")) (|semiDegreeSubResultantEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (|NonNegativeInteger|)) "\\axiom{indiceSubResultant(P, \\spad{Q,} i)} returns a subresultant \\axiom{S} of degree \\axiom{d} and carries out the equality \\axiom{...P + coef2*Q = S_i}. Warning. \\axiom{degree(P) \\spad{>=} degree(Q)}.")) (|degreeSubResultantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (|NonNegativeInteger|)) "\\axiom{indiceSubResultant(P, \\spad{Q,} i)} returns a subresultant \\axiom{S} of degree \\axiom{d} and carries out the equality \\axiom{coef1*P + coef2*Q = S_i}.")) (|degreeSubResultant| ((|#2| |#2| |#2| (|NonNegativeInteger|)) "\\axiom{degreeSubResultant(P, \\spad{Q,} \\spad{d)}} computes a subresultant of degree \\axiom{d}.")) (|semiIndiceSubResultantEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (|NonNegativeInteger|)) "\\axiom{semiIndiceSubResultantEuclidean(P, \\spad{Q,} i)} returns the subresultant \\axiom{S_i(P,Q)} and carries out the equality \\axiom{...P + coef2*Q = S_i(P,Q)} Warning. \\axiom{degree(P) \\spad{>=} degree(Q)}.")) (|indiceSubResultantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (|NonNegativeInteger|)) "\\axiom{indiceSubResultant(P, \\spad{Q,} i)} returns the subresultant \\axiom{S_i(P,Q)} and carries out the equality \\axiom{coef1*P + coef2*Q = S_i(P,Q)}")) (|indiceSubResultant| ((|#2| |#2| |#2| (|NonNegativeInteger|)) "\\axiom{indiceSubResultant(P, \\spad{Q,} i)} returns the subresultant of indice \\axiom{i}")) (|semiResultantEuclidean1| (((|Record| (|:| |coef1| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{semiResultantEuclidean1(P,Q)} carries out the equality \\axiom{coef1.P + ? \\spad{Q} = resultant(P,Q)}.")) (|semiResultantEuclidean2| (((|Record| (|:| |coef2| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{semiResultantEuclidean2(P,Q)} carries out the equality \\axiom{...P + coef2*Q = resultant(P,Q)}. Warning. \\axiom{degree(P) \\spad{>=} degree(Q)}.")) (|resultantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{resultantEuclidean(P,Q)} carries out the equality \\axiom{coef1*P + coef2*Q = resultant(P,Q)}")) (|resultant| ((|#1| |#2| |#2|) "\\axiom{resultant(P, \\spad{Q)}} returns the resultant of \\axiom{P} and \\axiom{Q}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-457)))) 
-(-978 K) 
+((|HasCategory| |#1| (QUOTE (-477)))) 
+(-999 K) 
 ((|constructor| (NIL "This is part of the PAFF package, related to projective space.")) (|pointValue| (((|List| |#1|) $) "\\spad{pointValue returns} the coordinates of the point or of the point of origin that represent an infinitly close point")) (|setelt| ((|#1| $ (|Integer|) |#1|) "\\spad{setelt sets} the value of a specified coordinates")) (|elt| ((|#1| $ (|Integer|)) "\\spad{elt returns} the value of a specified coordinates")) (|list| (((|List| |#1|) $) "\\spad{list returns} the list of the coordinates")) (|lastNonNull| (((|Integer|) $) "\\spad{lastNonNull returns} the integer corresponding to the last non null coordinates.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(p)} test if the point is rational according to the characteristic of the ground field.") (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{rational?(p,n)} test if the point is rational according to \\spad{n.}")) (|removeConjugate| (((|List| $) (|List| $)) "\\spad{removeConjugate(lp)} returns removeConjugate(lp,n) where \\spad{n} is the characteristic of the ground field.") (((|List| $) (|List| $) (|NonNegativeInteger|)) "\\spad{removeConjugate(lp,n)} returns a list of points such that no points in the list is the conjugate (according to \\spad{n)} of another point.")) (|conjugate| (($ $) "\\spad{conjugate(p)} returns conjugate(p,n) where \\spad{n} is the characteristic of the ground field.") (($ $ (|NonNegativeInteger|)) "\\spad{conjugate(p,n)} returns p**n, that is all the coordinates of \\spad{p} to the power of \\spad{n}")) (|orbit| (((|List| $) $ (|NonNegativeInteger|)) "\\spad{orbit(p,n)} returns the orbit of the point \\spad{p} according to \\spad{n,} that is orbit(p,n) = \\spad{\\{} \\spad{p,} p**n, p**(n**2), p**(n**3), ..... \\spad{\\}}") (((|List| $) $) "\\spad{orbit(p)} returns the orbit of the point \\spad{p} according to the characteristic of \\spad{K,} that is, for \\spad{q=} char \\spad{K,} orbit(p) = \\spad{\\{} \\spad{p,} p**q, p**(q**2), p**(q**3), ..... \\spad{\\}}")) (|coerce| (($ (|List| |#1|)) "\\spad{coerce a} list of \\spad{K} to a projective point.") (((|List| |#1|) $) "\\spad{coerce a} a projective point list of \\spad{K}")) (|projectivePoint| (($ (|List| |#1|)) "\\spad{projectivePoint creates} a projective point from a list")) (|homogenize| (($ $) "\\spad{homogenize(pt)} the point according to the coordinate which is the last non null.") (($ $ (|Integer|)) "\\spad{homogenize the} point according to the coordinate specified by the integer"))) 
 NIL 
 NIL 
-(-979) 
+(-1000) 
 ((|constructor| (NIL "Domain for partitions of positive integers Partition is an OrderedCancellationAbelianMonoid which is used as the basis for symmetric polynomial representation of the sums of powers in SymmetricPolynomial. Thus, \\spad{(5 2 2 1)} will represent \\spad{s5 * \\spad{s2**2} * s1}.")) (|coerce| (((|List| (|Integer|)) $) "\\spad{coerce(p)} coerces a partition into a list of integers")) (|conjugate| (($ $) "\\spad{conjugate(p)} returns the conjugate partition of a partition \\spad{p}")) (|pdct| (((|Integer|) $) "\\spad{pdct(a1**n1 \\spad{a2**n2} ...)} returns \\spad{n1! * \\spad{a1**n1} * \\spad{n2!} * \\spad{a2**n2} * ...}. This function is used in the package \\spadtype{CycleIndicators}.")) (|powers| (((|List| (|List| (|Integer|))) (|List| (|Integer|))) "\\spad{powers(li)} returns a list of 2-element lists. For each 2-element list, the first element is an entry of \\spad{li} and the second element is the multiplicity with which the first element occurs in li. There is a 2-element list for each value occurring in \\spad{l.}")) (|partition| (($ (|List| (|Integer|))) "\\spad{partition(li)} converts a list of integers \\spad{li} to a partition"))) 
 NIL 
 NIL 
-(-980 S |Coef| |Expon| |Var|) 
+(-1001 S |Coef| |Expon| |Var|) 
 ((|constructor| (NIL "\\spadtype{PowerSeriesCategory} is the most general power series category with exponents in an ordered abelian monoid.")) (|complete| (($ $) "\\spad{complete(f)} causes all terms of \\spad{f} to be computed. Note that this results in an infinite loop if \\spad{f} has infinitely many terms.")) (|pole?| (((|Boolean|) $) "\\spad{pole?(f)} determines if the power series \\spad{f} has a pole.")) (|variables| (((|List| |#4|) $) "\\spad{variables(f)} returns a list of the variables occuring in the power series \\spad{f.}")) (|degree| ((|#3| $) "\\spad{degree(f)} returns the exponent of the lowest order term of \\spad{f}.")) (|leadingCoefficient| ((|#2| $) "\\spad{leadingCoefficient(f)} returns the coefficient of the lowest order term of \\spad{f}")) (|leadingMonomial| (($ $) "\\spad{leadingMonomial(f)} returns the monomial of \\spad{f} of lowest order.")) (|monomial| (($ $ (|List| |#4|) (|List| |#3|)) "\\spad{monomial(a,[x1,..,xk],[n1,..,nk])} computes \\spad{a * \\spad{x1**n1} * \\spad{..} * xk**nk}.") (($ $ |#4| |#3|) "\\spad{monomial(a,x,n)} computes \\spad{a*x**n}."))) 
 NIL 
 NIL 
-(-981 |Coef| |Expon| |Var|) 
+(-1002 |Coef| |Expon| |Var|) 
 ((|constructor| (NIL "\\spadtype{PowerSeriesCategory} is the most general power series category with exponents in an ordered abelian monoid.")) (|complete| (($ $) "\\spad{complete(f)} causes all terms of \\spad{f} to be computed. Note that this results in an infinite loop if \\spad{f} has infinitely many terms.")) (|pole?| (((|Boolean|) $) "\\spad{pole?(f)} determines if the power series \\spad{f} has a pole.")) (|variables| (((|List| |#3|) $) "\\spad{variables(f)} returns a list of the variables occuring in the power series \\spad{f.}")) (|degree| ((|#2| $) "\\spad{degree(f)} returns the exponent of the lowest order term of \\spad{f}.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(f)} returns the coefficient of the lowest order term of \\spad{f}")) (|leadingMonomial| (($ $) "\\spad{leadingMonomial(f)} returns the monomial of \\spad{f} of lowest order.")) (|monomial| (($ $ (|List| |#3|) (|List| |#2|)) "\\spad{monomial(a,[x1,..,xk],[n1,..,nk])} computes \\spad{a * \\spad{x1**n1} * \\spad{..} * xk**nk}.") (($ $ |#3| |#2|) "\\spad{monomial(a,x,n)} computes \\spad{a*x**n}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-982) 
+(-1003) 
 ((|constructor| (NIL "PlottableSpaceCurveCategory is the category of curves in 3-space which may be plotted via the graphics facilities. Functions are provided for obtaining lists of lists of points, representing the branches of the curve, and for determining the ranges of the \\spad{x-,} \\spad{y-,} and z-coordinates of the points on the curve.")) (|zRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{zRange(c)} returns the range of the z-coordinates of the points on the curve \\spad{c.}")) (|yRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{yRange(c)} returns the range of the y-coordinates of the points on the curve \\spad{c.}")) (|xRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{xRange(c)} returns the range of the x-coordinates of the points on the curve \\spad{c.}")) (|listBranches| (((|List| (|List| (|Point| (|DoubleFloat|)))) $) "\\spad{listBranches(c)} returns a list of lists of points, representing the branches of the curve \\spad{c.}"))) 
 NIL 
 NIL 
-(-983 S R E |VarSet| P) 
+(-1004 S R E |VarSet| P) 
 ((|constructor| (NIL "A category for finite subsets of a polynomial ring. Such a set is only regarded as a set of polynomials and not identified to the ideal it generates. So two distinct sets may generate the same the ideal. Furthermore, for \\spad{R} being an integral domain, a set of polynomials may be viewed as a representation of the ideal it generates in the polynomial ring \\spad{(R)^(-1) \\spad{P},} or the set of its zeros (described for instance by the radical of the previous ideal, or a split of the associated affine variety) and so on. So this category provides operations about those different notions.")) (|triangular?| (((|Boolean|) $) "\\axiom{triangular?(ps)} returns \\spad{true} iff \\axiom{ps} is a triangular set, \\spadignore{i.e.} two distinct polynomials have distinct main variables and no constant lies in \\axiom{ps}.")) (|rewriteIdealWithRemainder| (((|List| |#5|) (|List| |#5|) $) "\\axiom{rewriteIdealWithRemainder(lp,cs)} returns \\axiom{lr} such that every polynomial in \\axiom{lr} is fully reduced in the sense of Groebner bases w.r.t. \\axiom{cs} and \\axiom{(lp,cs)} and \\axiom{(lr,cs)} generate the same ideal in \\axiom{(R)^(-1) \\spad{P}.}")) (|rewriteIdealWithHeadRemainder| (((|List| |#5|) (|List| |#5|) $) "\\axiom{rewriteIdealWithHeadRemainder(lp,cs)} returns \\axiom{lr} such that the leading monomial of every polynomial in \\axiom{lr} is reduced in the sense of Groebner bases w.r.t. \\axiom{cs} and \\axiom{(lp,cs)} and \\axiom{(lr,cs)} generate the same ideal in \\axiom{(R)^(-1) \\spad{P}.}")) (|remainder| (((|Record| (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| $) "\\axiom{remainder(a,ps)} returns \\axiom{[c,b,r]} such that \\axiom{b} is fully reduced in the sense of Groebner bases w.r.t. \\axiom{ps}, \\axiom{r*a - c*b} lies in the ideal generated by \\axiom{ps}. Furthermore, if \\axiom{R} is a gcd-domain, \\axiom{b} is primitive.")) (|headRemainder| (((|Record| (|:| |num| |#5|) (|:| |den| |#2|)) |#5| $) "\\axiom{headRemainder(a,ps)} returns \\axiom{[b,r]} such that the leading monomial of \\axiom{b} is reduced in the sense of Groebner bases w.r.t. \\axiom{ps} and \\axiom{r*a - \\spad{b}} lies in the ideal generated by \\axiom{ps}.")) (|roughUnitIdeal?| (((|Boolean|) $) "\\axiom{roughUnitIdeal?(ps)} returns \\spad{true} iff \\axiom{ps} contains \\indented{1}{some non null element lying in the base ring \\axiom{R}.}")) (|roughEqualIdeals?| (((|Boolean|) $ $) "\\axiom{roughEqualIdeals?(ps1,ps2)} returns \\spad{true} iff it can proved that \\axiom{ps1} and \\axiom{ps2} generate the same ideal in \\axiom{(R)^(-1) \\spad{P}} without computing Groebner bases.")) (|roughSubIdeal?| (((|Boolean|) $ $) "\\axiom{roughSubIdeal?(ps1,ps2)} returns \\spad{true} iff it can proved that all polynomials in \\axiom{ps1} lie in the ideal generated by \\axiom{ps2} in \\axiom{\\axiom{(R)^(-1) \\spad{P}}} without computing Groebner bases.")) (|roughBase?| (((|Boolean|) $) "\\axiom{roughBase?(ps)} returns \\spad{true} iff for every pair \\axiom{{p,q}} of polynomials in \\axiom{ps} their leading monomials are relatively prime.")) (|trivialIdeal?| (((|Boolean|) $) "\\axiom{trivialIdeal?(ps)} returns \\spad{true} iff \\axiom{ps} does not contain non-zero elements.")) (|sort| (((|Record| (|:| |under| $) (|:| |floor| $) (|:| |upper| $)) $ |#4|) "\\axiom{sort(v,ps)} returns \\axiom{us,vs,ws} such that \\axiom{us} is \\axiom{collectUnder(ps,v)}, \\axiom{vs} is \\axiom{collect(ps,v)} and \\axiom{ws} is \\axiom{collectUpper(ps,v)}.")) (|collectUpper| (($ $ |#4|) "\\axiom{collectUpper(ps,v)} returns the set consisting of the polynomials of \\axiom{ps} with main variable greater than \\axiom{v}.")) (|collect| (($ $ |#4|) "\\axiom{collect(ps,v)} returns the set consisting of the polynomials of \\axiom{ps} with \\axiom{v} as main variable.")) (|collectUnder| (($ $ |#4|) "\\axiom{collectUnder(ps,v)} returns the set consisting of the polynomials of \\axiom{ps} with main variable less than \\axiom{v}.")) (|mainVariable?| (((|Boolean|) |#4| $) "\\axiom{mainVariable?(v,ps)} returns \\spad{true} iff \\axiom{v} is the main variable of some polynomial in \\axiom{ps}.")) (|mainVariables| (((|List| |#4|) $) "\\axiom{mainVariables(ps)} returns the decreasingly sorted list of the variables which are main variables of some polynomial in \\axiom{ps}.")) (|variables| (((|List| |#4|) $) "\\axiom{variables(ps)} returns the decreasingly sorted list of the variables which are variables of some polynomial in \\axiom{ps}.")) (|mvar| ((|#4| $) "\\axiom{mvar(ps)} returns the main variable of the non constant polynomial with the greatest main variable, if any, else an error is returned.")) (|retract| (($ (|List| |#5|)) "\\axiom{retract(lp)} returns an element of the domain whose elements are the members of \\axiom{lp} if such an element exists, otherwise an error is produced.")) (|retractIfCan| (((|Union| $ "failed") (|List| |#5|)) "\\axiom{retractIfCan(lp)} returns an element of the domain whose elements are the members of \\axiom{lp} if such an element exists, otherwise \\axiom{\"failed\"} is returned."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-562)))) 
-(-984 R E |VarSet| P) 
+((|HasCategory| |#2| (QUOTE (-582)))) 
+(-1005 R E |VarSet| P) 
 ((|constructor| (NIL "A category for finite subsets of a polynomial ring. Such a set is only regarded as a set of polynomials and not identified to the ideal it generates. So two distinct sets may generate the same the ideal. Furthermore, for \\spad{R} being an integral domain, a set of polynomials may be viewed as a representation of the ideal it generates in the polynomial ring \\spad{(R)^(-1) \\spad{P},} or the set of its zeros (described for instance by the radical of the previous ideal, or a split of the associated affine variety) and so on. So this category provides operations about those different notions.")) (|triangular?| (((|Boolean|) $) "\\axiom{triangular?(ps)} returns \\spad{true} iff \\axiom{ps} is a triangular set, \\spadignore{i.e.} two distinct polynomials have distinct main variables and no constant lies in \\axiom{ps}.")) (|rewriteIdealWithRemainder| (((|List| |#4|) (|List| |#4|) $) "\\axiom{rewriteIdealWithRemainder(lp,cs)} returns \\axiom{lr} such that every polynomial in \\axiom{lr} is fully reduced in the sense of Groebner bases w.r.t. \\axiom{cs} and \\axiom{(lp,cs)} and \\axiom{(lr,cs)} generate the same ideal in \\axiom{(R)^(-1) \\spad{P}.}")) (|rewriteIdealWithHeadRemainder| (((|List| |#4|) (|List| |#4|) $) "\\axiom{rewriteIdealWithHeadRemainder(lp,cs)} returns \\axiom{lr} such that the leading monomial of every polynomial in \\axiom{lr} is reduced in the sense of Groebner bases w.r.t. \\axiom{cs} and \\axiom{(lp,cs)} and \\axiom{(lr,cs)} generate the same ideal in \\axiom{(R)^(-1) \\spad{P}.}")) (|remainder| (((|Record| (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) "\\axiom{remainder(a,ps)} returns \\axiom{[c,b,r]} such that \\axiom{b} is fully reduced in the sense of Groebner bases w.r.t. \\axiom{ps}, \\axiom{r*a - c*b} lies in the ideal generated by \\axiom{ps}. Furthermore, if \\axiom{R} is a gcd-domain, \\axiom{b} is primitive.")) (|headRemainder| (((|Record| (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) "\\axiom{headRemainder(a,ps)} returns \\axiom{[b,r]} such that the leading monomial of \\axiom{b} is reduced in the sense of Groebner bases w.r.t. \\axiom{ps} and \\axiom{r*a - \\spad{b}} lies in the ideal generated by \\axiom{ps}.")) (|roughUnitIdeal?| (((|Boolean|) $) "\\axiom{roughUnitIdeal?(ps)} returns \\spad{true} iff \\axiom{ps} contains \\indented{1}{some non null element lying in the base ring \\axiom{R}.}")) (|roughEqualIdeals?| (((|Boolean|) $ $) "\\axiom{roughEqualIdeals?(ps1,ps2)} returns \\spad{true} iff it can proved that \\axiom{ps1} and \\axiom{ps2} generate the same ideal in \\axiom{(R)^(-1) \\spad{P}} without computing Groebner bases.")) (|roughSubIdeal?| (((|Boolean|) $ $) "\\axiom{roughSubIdeal?(ps1,ps2)} returns \\spad{true} iff it can proved that all polynomials in \\axiom{ps1} lie in the ideal generated by \\axiom{ps2} in \\axiom{\\axiom{(R)^(-1) \\spad{P}}} without computing Groebner bases.")) (|roughBase?| (((|Boolean|) $) "\\axiom{roughBase?(ps)} returns \\spad{true} iff for every pair \\axiom{{p,q}} of polynomials in \\axiom{ps} their leading monomials are relatively prime.")) (|trivialIdeal?| (((|Boolean|) $) "\\axiom{trivialIdeal?(ps)} returns \\spad{true} iff \\axiom{ps} does not contain non-zero elements.")) (|sort| (((|Record| (|:| |under| $) (|:| |floor| $) (|:| |upper| $)) $ |#3|) "\\axiom{sort(v,ps)} returns \\axiom{us,vs,ws} such that \\axiom{us} is \\axiom{collectUnder(ps,v)}, \\axiom{vs} is \\axiom{collect(ps,v)} and \\axiom{ws} is \\axiom{collectUpper(ps,v)}.")) (|collectUpper| (($ $ |#3|) "\\axiom{collectUpper(ps,v)} returns the set consisting of the polynomials of \\axiom{ps} with main variable greater than \\axiom{v}.")) (|collect| (($ $ |#3|) "\\axiom{collect(ps,v)} returns the set consisting of the polynomials of \\axiom{ps} with \\axiom{v} as main variable.")) (|collectUnder| (($ $ |#3|) "\\axiom{collectUnder(ps,v)} returns the set consisting of the polynomials of \\axiom{ps} with main variable less than \\axiom{v}.")) (|mainVariable?| (((|Boolean|) |#3| $) "\\axiom{mainVariable?(v,ps)} returns \\spad{true} iff \\axiom{v} is the main variable of some polynomial in \\axiom{ps}.")) (|mainVariables| (((|List| |#3|) $) "\\axiom{mainVariables(ps)} returns the decreasingly sorted list of the variables which are main variables of some polynomial in \\axiom{ps}.")) (|variables| (((|List| |#3|) $) "\\axiom{variables(ps)} returns the decreasingly sorted list of the variables which are variables of some polynomial in \\axiom{ps}.")) (|mvar| ((|#3| $) "\\axiom{mvar(ps)} returns the main variable of the non constant polynomial with the greatest main variable, if any, else an error is returned.")) (|retract| (($ (|List| |#4|)) "\\axiom{retract(lp)} returns an element of the domain whose elements are the members of \\axiom{lp} if such an element exists, otherwise an error is produced.")) (|retractIfCan| (((|Union| $ "failed") (|List| |#4|)) "\\axiom{retractIfCan(lp)} returns an element of the domain whose elements are the members of \\axiom{lp} if such an element exists, otherwise \\axiom{\"failed\"} is returned."))) 
-((-4602 . T) (-3389 . T)) 
+((-4625 . T) (-2623 . T)) 
 NIL 
-(-985 R E V P) 
+(-1006 R E V P) 
 ((|constructor| (NIL "This package provides modest routines for polynomial system solving. The aim of many of the operations of this package is to remove certain factors in some polynomials in order to avoid unnecessary computations in algorithms involving splitting techniques by partial factorization.")) (|removeIrreducibleRedundantFactors| (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeIrreducibleRedundantFactors(lp,lq)} returns the same as \\axiom{irreducibleFactors(concat(lp,lq))} assuming that \\axiom{irreducibleFactors(lp)} returns \\axiom{lp} up to replacing some polynomial \\axiom{pj} in \\axiom{lp} by some polynomial \\axiom{qj} associated to \\axiom{pj}.")) (|lazyIrreducibleFactors| (((|List| |#4|) (|List| |#4|)) "\\axiom{lazyIrreducibleFactors(lp)} returns \\axiom{lf} such that if \\axiom{lp = [p1,...,pn]} and \\axiom{lf = [f1,...,fm]} then \\axiom{p1*p2*...*pn=0} means \\axiom{f1*f2*...*fm=0}, and the \\axiom{fi} are irreducible over \\axiom{R} and are pairwise distinct. The algorithm tries to avoid factorization into irreducible factors as far as possible and makes previously use of \\spad{gcd} techniques over \\axiom{R}.")) (|irreducibleFactors| (((|List| |#4|) (|List| |#4|)) "\\axiom{irreducibleFactors(lp)} returns \\axiom{lf} such that if \\axiom{lp = [p1,...,pn]} and \\axiom{lf = [f1,...,fm]} then \\axiom{p1*p2*...*pn=0} means \\axiom{f1*f2*...*fm=0}, and the \\axiom{fi} are irreducible over \\axiom{R} and are pairwise distinct.")) (|removeRedundantFactorsInPols| (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRedundantFactorsInPols(lp,lf)} returns \\axiom{newlp} where \\axiom{newlp} is obtained from \\axiom{lp} by removing in every polynomial \\axiom{p} of \\axiom{lp} any non trivial factor of any polynomial \\axiom{f} in \\axiom{lf}. Moreover, squares over \\axiom{R} are first removed in every polynomial \\axiom{lp}.")) (|removeRedundantFactorsInContents| (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRedundantFactorsInContents(lp,lf)} returns \\axiom{newlp} where \\axiom{newlp} is obtained from \\axiom{lp} by removing in the content of every polynomial of \\axiom{lp} any non trivial factor of any polynomial \\axiom{f} in \\axiom{lf}. Moreover, squares over \\axiom{R} are first removed in the content of every polynomial of \\axiom{lp}.")) (|removeRoughlyRedundantFactorsInContents| (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRoughlyRedundantFactorsInContents(lp,lf)} returns \\axiom{newlp}where \\axiom{newlp} is obtained from \\axiom{lp} by removing in the content of every polynomial of \\axiom{lp} any occurence of a polynomial \\axiom{f} in \\axiom{lf}. Moreover, squares over \\axiom{R} are first removed in the content of every polynomial of \\axiom{lp}.")) (|univariatePolynomialsGcds| (((|List| |#4|) (|List| |#4|) (|Boolean|)) "\\axiom{univariatePolynomialsGcds(lp,opt)} returns the same as \\axiom{univariatePolynomialsGcds(lp)} if \\axiom{opt} is \\axiom{false} and if the previous operation does not return any non null and constant polynomial, else return \\axiom{[1]}.") (((|List| |#4|) (|List| |#4|)) "\\axiom{univariatePolynomialsGcds(lp)} returns \\axiom{lg} where \\axiom{lg} is a list of the gcds of every pair in \\axiom{lp} of univariate polynomials in the same main variable.")) (|squareFreeFactors| (((|List| |#4|) |#4|) "\\axiom{squareFreeFactors(p)} returns the square-free factors of \\axiom{p} over \\axiom{R}")) (|rewriteIdealWithQuasiMonicGenerators| (((|List| |#4|) (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{rewriteIdealWithQuasiMonicGenerators(lp,redOp?,redOp)} returns \\axiom{lq} where \\axiom{lq} and \\axiom{lp} generate the same ideal in \\axiom{R^(-1) \\spad{P}} and \\axiom{lq} has rank not higher than the one of \\axiom{lp}. Moreover, \\axiom{lq} is computed by reducing \\axiom{lp} w.r.t. some basic set of the ideal generated by the quasi-monic polynomials in \\axiom{lp}.")) (|rewriteSetByReducingWithParticularGenerators| (((|List| |#4|) (|List| |#4|) (|Mapping| (|Boolean|) |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{rewriteSetByReducingWithParticularGenerators(lp,pred?,redOp?,redOp)} returns \\axiom{lq} where \\axiom{lq} is computed by the following algorithm. Chose a basic set w.r.t. the reduction-test \\axiom{redOp?} among the polynomials satisfying property \\axiom{pred?}, if it is empty then leave, else reduce the other polynomials by this basic set w.r.t. the reduction-operation \\axiom{redOp}. Repeat while another basic set with smaller rank can be computed. See code. If \\axiom{pred?} is \\axiom{quasiMonic?} the ideal is unchanged.")) (|crushedSet| (((|List| |#4|) (|List| |#4|)) "\\axiom{crushedSet(lp)} returns \\axiom{lq} such that \\axiom{lp} and and \\axiom{lq} generate the same ideal and no rough basic sets reduce (in the sense of Groebner bases) the other polynomials in \\axiom{lq}.")) (|roughBasicSet| (((|Union| (|Record| (|:| |bas| (|GeneralTriangularSet| |#1| |#2| |#3| |#4|)) (|:| |top| (|List| |#4|))) "failed") (|List| |#4|)) "\\axiom{roughBasicSet(lp)} returns the smallest (with Ritt-Wu ordering) triangular set contained in \\axiom{lp}.")) (|interReduce| (((|List| |#4|) (|List| |#4|)) "\\axiom{interReduce(lp)} returns \\axiom{lq} such that \\axiom{lp} and \\axiom{lq} generate the same ideal and no polynomial in \\axiom{lq} is reducuble by the others in the sense of Groebner bases. Since no assumptions are required the result may depend on the ordering the reductions are performed.")) (|removeRoughlyRedundantFactorsInPol| ((|#4| |#4| (|List| |#4|)) "\\axiom{removeRoughlyRedundantFactorsInPol(p,lf)} returns the same as removeRoughlyRedundantFactorsInPols([p],lf,true)")) (|removeRoughlyRedundantFactorsInPols| (((|List| |#4|) (|List| |#4|) (|List| |#4|) (|Boolean|)) "\\axiom{removeRoughlyRedundantFactorsInPols(lp,lf,opt)} returns the same as \\axiom{removeRoughlyRedundantFactorsInPols(lp,lf)} if \\axiom{opt} is \\axiom{false} and if the previous operation does not return any non null and constant polynomial, else return \\axiom{[1]}.") (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRoughlyRedundantFactorsInPols(lp,lf)} returns \\axiom{newlp}where \\axiom{newlp} is obtained from \\axiom{lp} by removing in every polynomial \\axiom{p} of \\axiom{lp} any occurence of a polynomial \\axiom{f} in \\axiom{lf}. This may involve a lot of exact-quotients computations.")) (|bivariatePolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| |#4|)) "\\axiom{bivariatePolynomials(lp)} returns \\axiom{bps,nbps} where \\axiom{bps} is a list of the bivariate polynomials, and \\axiom{nbps} are the other ones.")) (|bivariate?| (((|Boolean|) |#4|) "\\axiom{bivariate?(p)} returns \\spad{true} iff \\axiom{p} involves two and only two variables.")) (|linearPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| |#4|)) "\\axiom{linearPolynomials(lp)} returns \\axiom{lps,nlps} where \\axiom{lps} is a list of the linear polynomials in \\spad{lp,} and \\axiom{nlps} are the other ones.")) (|linear?| (((|Boolean|) |#4|) "\\axiom{linear?(p)} returns \\spad{true} iff \\axiom{p} does not lie in the base ring \\axiom{R} and has main degree \\axiom{1}.")) (|univariatePolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| |#4|)) "\\axiom{univariatePolynomials(lp)} returns \\axiom{ups,nups} where \\axiom{ups} is a list of the univariate polynomials, and \\axiom{nups} are the other ones.")) (|univariate?| (((|Boolean|) |#4|) "\\axiom{univariate?(p)} returns \\spad{true} iff \\axiom{p} involves one and only one variable.")) (|quasiMonicPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| |#4|)) "\\axiom{quasiMonicPolynomials(lp)} returns \\axiom{qmps,nqmps} where \\axiom{qmps} is a list of the quasi-monic polynomials in \\axiom{lp} and \\axiom{nqmps} are the other ones.")) (|selectAndPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| (|Mapping| (|Boolean|) |#4|)) (|List| |#4|)) "\\axiom{selectAndPolynomials(lpred?,ps)} returns \\axiom{gps,bps} where \\axiom{gps} is a list of the polynomial \\axiom{p} in \\axiom{ps} such that \\axiom{pred?(p)} holds for every \\axiom{pred?} in \\axiom{lpred?} and \\axiom{bps} are the other ones.")) (|selectOrPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| (|Mapping| (|Boolean|) |#4|)) (|List| |#4|)) "\\axiom{selectOrPolynomials(lpred?,ps)} returns \\axiom{gps,bps} where \\axiom{gps} is a list of the polynomial \\axiom{p} in \\axiom{ps} such that \\axiom{pred?(p)} holds for some \\axiom{pred?} in \\axiom{lpred?} and \\axiom{bps} are the other ones.")) (|selectPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|Mapping| (|Boolean|) |#4|) (|List| |#4|)) "\\axiom{selectPolynomials(pred?,ps)} returns \\axiom{gps,bps} where \\axiom{gps} is a list of the polynomial \\axiom{p} in \\axiom{ps} such that \\axiom{pred?(p)} holds and \\axiom{bps} are the other ones.")) (|probablyZeroDim?| (((|Boolean|) (|List| |#4|)) "\\axiom{probablyZeroDim?(lp)} returns \\spad{true} iff the number of polynomials in \\axiom{lp} is not smaller than the number of variables occurring in these polynomials.")) (|possiblyNewVariety?| (((|Boolean|) (|List| |#4|) (|List| (|List| |#4|))) "\\axiom{possiblyNewVariety?(newlp,llp)} returns \\spad{true} iff for every \\axiom{lp} in \\axiom{llp} certainlySubVariety?(newlp,lp) does not hold.")) (|certainlySubVariety?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{certainlySubVariety?(newlp,lp)} returns \\spad{true} iff for every \\axiom{p} in \\axiom{lp} the remainder of \\axiom{p} by \\axiom{newlp} using the division algorithm of Groebner techniques is zero.")) (|unprotectedRemoveRedundantFactors| (((|List| |#4|) |#4| |#4|) "\\axiom{unprotectedRemoveRedundantFactors(p,q)} returns the same as \\axiom{removeRedundantFactors(p,q)} but does assume that neither \\axiom{p} nor \\axiom{q} lie in the base ring \\axiom{R} and assumes that \\axiom{infRittWu?(p,q)} holds. Moreover, if \\axiom{R} is gcd-domain, then \\axiom{p} and \\axiom{q} are assumed to be square free.")) (|removeSquaresIfCan| (((|List| |#4|) (|List| |#4|)) "\\axiom{removeSquaresIfCan(lp)} returns \\axiom{removeDuplicates [squareFreePart(p)$P for \\spad{p} in lp]} if \\axiom{R} is gcd-domain else returns \\axiom{lp}.")) (|removeRedundantFactors| (((|List| |#4|) (|List| |#4|) (|List| |#4|) (|Mapping| (|List| |#4|) (|List| |#4|))) "\\axiom{removeRedundantFactors(lp,lq,remOp)} returns the same as \\axiom{concat(remOp(removeRoughlyRedundantFactorsInPols(lp,lq)),lq)} assuming that \\axiom{remOp(lq)} returns \\axiom{lq} up to similarity.") (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRedundantFactors(lp,lq)} returns the same as \\axiom{removeRedundantFactors(concat(lp,lq))} assuming that \\axiom{removeRedundantFactors(lp)} returns \\axiom{lp} up to replacing some polynomial \\axiom{pj} in \\axiom{lp} by some polynomial \\axiom{qj} associated to \\axiom{pj}.") (((|List| |#4|) (|List| |#4|) |#4|) "\\axiom{removeRedundantFactors(lp,q)} returns the same as \\axiom{removeRedundantFactors(cons(q,lp))} assuming that \\axiom{removeRedundantFactors(lp)} returns \\axiom{lp} up to replacing some polynomial \\axiom{pj} in \\axiom{lp} by some some polynomial \\axiom{qj} associated to \\axiom{pj}.") (((|List| |#4|) |#4| |#4|) "\\axiom{removeRedundantFactors(p,q)} returns the same as \\axiom{removeRedundantFactors([p,q])}") (((|List| |#4|) (|List| |#4|)) "\\axiom{removeRedundantFactors(lp)} returns \\axiom{lq} such that if \\axiom{lp = [p1,...,pn]} and \\axiom{lq = [q1,...,qm]} then the product \\axiom{p1*p2*...*pn} vanishes iff the product \\axiom{q1*q2*...*qm} vanishes, and the product of degrees of the \\axiom{qi} is not greater than the one of the \\axiom{pj}, and no polynomial in \\axiom{lq} divides another polynomial in \\axiom{lq}. In particular, polynomials lying in the base ring \\axiom{R} are removed. Moreover, \\axiom{lq} is sorted w.r.t \\axiom{infRittWu?}. Furthermore, if \\spad{R} is gcd-domain, the polynomials in \\axiom{lq} are pairwise without common non trivial factor."))) 
 NIL 
-((-12 (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-303)))) (|HasCategory| |#1| (QUOTE (-457)))) 
-(-986 K) 
+((-12 (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-323)))) (|HasCategory| |#1| (QUOTE (-477)))) 
+(-1007 K) 
 ((|constructor| (NIL "PseudoLinearNormalForm provides a function for computing a block-companion form for pseudo-linear operators.")) (|companionBlocks| (((|List| (|Record| (|:| C (|Matrix| |#1|)) (|:| |g| (|Vector| |#1|)))) (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{companionBlocks(m, \\spad{v)}} returns \\spad{[[C_1, g_1],...,[C_k, g_k]]} such that each \\spad{C_i} is a companion block and \\spad{m = diagonal(C_1,...,C_k)}.")) (|changeBase| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Automorphism| |#1|) (|Mapping| |#1| |#1|)) "\\spad{changeBase(M, A, sig, der)}: computes the new matrix of a pseudo-linear transform given by the matrix \\spad{M} under the change of base A")) (|normalForm| (((|Record| (|:| R (|Matrix| |#1|)) (|:| A (|Matrix| |#1|)) (|:| |Ainv| (|Matrix| |#1|))) (|Matrix| |#1|) (|Automorphism| |#1|) (|Mapping| |#1| |#1|)) "\\spad{normalForm(M, sig, der)} returns \\spad{[R, A, A^{-1}]} such that the pseudo-linear operator whose matrix in the basis \\spad{y} is \\spad{M} had matrix \\spad{R} in the basis \\spad{z = A \\spad{y}.} \\spad{der} is a \\spad{sig}-derivation."))) 
 NIL 
 NIL 
-(-987 |VarSet| E RC P) 
+(-1008 |VarSet| E RC P) 
 ((|constructor| (NIL "This package computes square-free decomposition of multivariate polynomials over a coefficient ring which is an arbitrary \\spad{gcd} domain. The requirement on the coefficient domain guarantees that the \\spadfun{content} can be removed so that factors will be primitive as well as square-free. Over an infinite ring of finite characteristic,it may not be possible to guarantee that the factors are square-free.")) (|squareFree| (((|Factored| |#4|) |#4|) "\\spad{squareFree(p)} returns the square-free factorization of the polynomial \\spad{p.} Each factor has no repeated roots, and the factors are pairwise relatively prime."))) 
 NIL 
 NIL 
-(-988 R) 
+(-1009 R) 
 ((|constructor| (NIL "PointCategory is the category of points in space which may be plotted via the graphics facilities. Functions are provided for defining points and handling elements of points.")) (|extend| (($ $ (|List| |#1|)) "\\spad{extend(x,l,r)} \\undocumented")) (|cross| (($ $ $) "\\spad{cross(p,q)} computes the cross product of the two points \\spad{p} and \\spad{q}. Error if the \\spad{p} and \\spad{q} are not 3 dimensional")) (|convert| (($ (|List| |#1|)) "\\spad{convert(l)} takes a list of elements, \\spad{l,} from the domain Ring and returns the form of point category.")) (|dimension| (((|PositiveInteger|) $) "\\spad{dimension(s)} returns the dimension of the point category \\spad{s.}")) (|point| (($ (|List| |#1|)) "\\spad{point(l)} returns a point category defined by a list \\spad{l} of elements from the domain \\spad{R.}"))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-989 R1 R2) 
+(-1010 R1 R2) 
 ((|constructor| (NIL "This package has no description")) (|map| (((|Point| |#2|) (|Mapping| |#2| |#1|) (|Point| |#1|)) "\\spad{map(f,p)} \\undocumented"))) 
 NIL 
 NIL 
-(-990 R) 
+(-1011 R) 
 ((|constructor| (NIL "This package has no description")) (|shade| ((|#1| (|Point| |#1|)) "\\spad{shade(pt)} returns the fourth element of the two dimensional point, \\spad{pt,} although no assumptions are made with regards as to how the components of higher dimensional points are interpreted. This function is defined for the convenience of the user using specifically, shade to express a fourth dimension.")) (|hue| ((|#1| (|Point| |#1|)) "\\spad{hue(pt)} returns the third element of the two dimensional point, \\spad{pt,} although no assumptions are made with regards as to how the components of higher dimensional points are interpreted. This function is defined for the convenience of the user using specifically, hue to express a third dimension.")) (|color| ((|#1| (|Point| |#1|)) "\\spad{color(pt)} returns the fourth element of the point, \\spad{pt,} although no assumptions are made with regards as to how the components of higher dimensional points are interpreted. This function is defined for the convenience of the user using specifically, color to express a fourth dimension.")) (|phiCoord| ((|#1| (|Point| |#1|)) "\\spad{phiCoord(pt)} returns the third element of the point, \\spad{pt,} although no assumptions are made as to the coordinate system being used. This function is defined for the convenience of the user dealing with a spherical coordinate system.")) (|thetaCoord| ((|#1| (|Point| |#1|)) "\\spad{thetaCoord(pt)} returns the second element of the point, \\spad{pt,} although no assumptions are made as to the coordinate system being used. This function is defined for the convenience of the user dealing with a spherical or a cylindrical coordinate system.")) (|rCoord| ((|#1| (|Point| |#1|)) "\\spad{rCoord(pt)} returns the first element of the point, \\spad{pt,} although no assumptions are made as to the coordinate system being used. This function is defined for the convenience of the user dealing with a spherical or a cylindrical coordinate system.")) (|zCoord| ((|#1| (|Point| |#1|)) "\\spad{zCoord(pt)} returns the third element of the point, \\spad{pt,} although no assumptions are made as to the coordinate system being used. This function is defined for the convenience of the user dealing with a Cartesian or a cylindrical coordinate system.")) (|yCoord| ((|#1| (|Point| |#1|)) "\\spad{yCoord(pt)} returns the second element of the point, \\spad{pt,} although no assumptions are made as to the coordinate system being used. This function is defined for the convenience of the user dealing with a Cartesian coordinate system.")) (|xCoord| ((|#1| (|Point| |#1|)) "\\spad{xCoord(pt)} returns the first element of the point, \\spad{pt,} although no assumptions are made as to the coordinate system being used. This function is defined for the convenience of the user dealing with a Cartesian coordinate system."))) 
 NIL 
 NIL 
-(-991 K) 
+(-1012 K) 
 ((|constructor| (NIL "A package which provides partial transcendental functions, for example, functions which return an answer or \"failed\" This is the description of any package which provides partial functions on a domain belonging to TranscendentalFunctionCategory.")) (|acschIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{acschIfCan(z)} returns acsch(z) if possible, and \"failed\" otherwise.")) (|asechIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{asechIfCan(z)} returns asech(z) if possible, and \"failed\" otherwise.")) (|acothIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{acothIfCan(z)} returns acoth(z) if possible, and \"failed\" otherwise.")) (|atanhIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{atanhIfCan(z)} returns atanh(z) if possible, and \"failed\" otherwise.")) (|acoshIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{acoshIfCan(z)} returns acosh(z) if possible, and \"failed\" otherwise.")) (|asinhIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{asinhIfCan(z)} returns asinh(z) if possible, and \"failed\" otherwise.")) (|cschIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{cschIfCan(z)} returns csch(z) if possible, and \"failed\" otherwise.")) (|sechIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{sechIfCan(z)} returns sech(z) if possible, and \"failed\" otherwise.")) (|cothIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{cothIfCan(z)} returns coth(z) if possible, and \"failed\" otherwise.")) (|tanhIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{tanhIfCan(z)} returns tanh(z) if possible, and \"failed\" otherwise.")) (|coshIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{coshIfCan(z)} returns cosh(z) if possible, and \"failed\" otherwise.")) (|sinhIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{sinhIfCan(z)} returns sinh(z) if possible, and \"failed\" otherwise.")) (|acscIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{acscIfCan(z)} returns acsc(z) if possible, and \"failed\" otherwise.")) (|asecIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{asecIfCan(z)} returns asec(z) if possible, and \"failed\" otherwise.")) (|acotIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{acotIfCan(z)} returns acot(z) if possible, and \"failed\" otherwise.")) (|atanIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{atanIfCan(z)} returns atan(z) if possible, and \"failed\" otherwise.")) (|acosIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{acosIfCan(z)} returns acos(z) if possible, and \"failed\" otherwise.")) (|asinIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{asinIfCan(z)} returns asin(z) if possible, and \"failed\" otherwise.")) (|cscIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{cscIfCan(z)} returns csc(z) if possible, and \"failed\" otherwise.")) (|secIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{secIfCan(z)} returns sec(z) if possible, and \"failed\" otherwise.")) (|cotIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{cotIfCan(z)} returns cot(z) if possible, and \"failed\" otherwise.")) (|tanIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{tanIfCan(z)} returns tan(z) if possible, and \"failed\" otherwise.")) (|cosIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{cosIfCan(z)} returns cos(z) if possible, and \"failed\" otherwise.")) (|sinIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{sinIfCan(z)} returns sin(z) if possible, and \"failed\" otherwise.")) (|logIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{logIfCan(z)} returns log(z) if possible, and \"failed\" otherwise.")) (|expIfCan| (((|Union| |#1| "failed") |#1|) "\\spad{expIfCan(z)} returns exp(z) if possible, and \"failed\" otherwise.")) (|nthRootIfCan| (((|Union| |#1| "failed") |#1| (|NonNegativeInteger|)) "\\spad{nthRootIfCan(z,n)} returns the \\spad{n}th root of \\spad{z} if possible, and \"failed\" otherwise."))) 
 NIL 
 NIL 
-(-992 R E OV PPR) 
+(-1013 R E OV PPR) 
 ((|constructor| (NIL "This package has no description")) (|map| ((|#4| (|Mapping| |#4| (|Polynomial| |#1|)) |#4|) "\\spad{map(f,p)} \\undocumented{}")) (|pushup| ((|#4| |#4| (|List| |#3|)) "\\spad{pushup(p,lv)} \\undocumented{}") ((|#4| |#4| |#3|) "\\spad{pushup(p,v)} \\undocumented{}")) (|pushdown| ((|#4| |#4| (|List| |#3|)) "\\spad{pushdown(p,lv)} \\undocumented{}") ((|#4| |#4| |#3|) "\\spad{pushdown(p,v)} \\undocumented{}")) (|variable| (((|Union| $ "failed") (|Symbol|)) "\\spad{variable(s)} makes an element from symbol \\spad{s} or fails")) (|convert| (((|Symbol|) $) "\\spad{convert(x)} converts \\spad{x} to a symbol"))) 
 NIL 
 NIL 
-(-993 K R UP -3313) 
+(-1014 K R UP -3958) 
 ((|constructor| (NIL "In this package \\spad{K} is a finite field, \\spad{R} is a ring of univariate polynomials over \\spad{K,} and \\spad{F} is a monogenic algebra over \\spad{R.} We require that \\spad{F} is monogenic, \\spadignore{i.e.} that \\spad{F = K[x,y]/(f(x,y))}, because the integral basis algorithm used will factor the polynomial \\spad{f(x,y)}. The package provides a function to compute the integral closure of \\spad{R} in the quotient field of \\spad{F} as well as a function to compute a \"local integral basis\" at a specific prime.")) (|reducedDiscriminant| ((|#2| |#3|) "\\spad{reducedDiscriminant(up)} \\undocumented")) (|localIntegralBasis| (((|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|))) |#2|) "\\spad{integralBasis(p)} returns a record \\spad{[basis,basisDen,basisInv] } containing information regarding the local integral closure of \\spad{R} at the prime \\spad{p} in the quotient field of the framed algebra \\spad{F.} \\spad{F} is a framed algebra with R-module basis \\spad{w1,w2,...,wn}. If 'basis' is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then the \\spad{i}th element of the local integral basis is \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of 'basis' contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix 'basisInv' contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if 'basisInv' is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}.")) (|integralBasis| (((|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|)))) "\\spad{integralBasis()} returns a record \\spad{[basis,basisDen,basisInv] } containing information regarding the integral closure of \\spad{R} in the quotient field of the framed algebra \\spad{F.} \\spad{F} is a framed algebra with R-module basis \\spad{w1,w2,...,wn}. If 'basis' is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then the \\spad{i}th element of the integral basis is \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of 'basis' contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix 'basisInv' contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if 'basisInv' is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}."))) 
 NIL 
 NIL 
-(-994 |vl| |nv|) 
+(-1015 |vl| |nv|) 
 ((|constructor| (NIL "\\spadtype{QuasiAlgebraicSet2} adds a function \\spadfun{radicalSimplify} which uses \\spadtype{IdealDecompositionPackage} to simplify the representation of a quasi-algebraic set. A quasi-algebraic set is the intersection of a Zariski closed set, defined as the common zeros of a given list of polynomials (the defining polynomials for equations), and a principal Zariski open set, defined as the complement of the common zeros of a polynomial \\spad{f} (the defining polynomial for the inequation). Quasi-algebraic sets are implemented in the domain \\spadtype{QuasiAlgebraicSet}, where two simplification routines are provided: \\spadfun{idealSimplify} and \\spadfun{simplify}. The function \\spadfun{radicalSimplify} is added for comparison study only. Because the domain \\spadtype{IdealDecompositionPackage} provides facilities for computing with radical ideals, it is necessary to restrict the ground ring to the domain \\spadtype{Fraction Integer}, and the polynomial ring to be of type \\spadtype{DistributedMultivariatePolynomial}. The routine \\spadfun{radicalSimplify} uses these to compute groebner basis of radical ideals and is inefficient and restricted when compared to the two in \\spadtype{QuasiAlgebraicSet}.")) (|radicalSimplify| (((|QuasiAlgebraicSet| (|Fraction| (|Integer|)) (|OrderedVariableList| |#1|) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|)))) (|QuasiAlgebraicSet| (|Fraction| (|Integer|)) (|OrderedVariableList| |#1|) (|DirectProduct| |#2| (|NonNegativeInteger|)) (|DistributedMultivariatePolynomial| |#1| (|Fraction| (|Integer|))))) "\\spad{radicalSimplify(s)} returns a different and presumably simpler representation of \\spad{s} with the defining polynomials for the equations forming a groebner basis, and the defining polynomial for the inequation reduced with respect to the basis, using using groebner basis of radical ideals"))) 
 NIL 
 NIL 
-(-995 R |Var| |Expon| |Dpoly|) 
+(-1016 R |Var| |Expon| |Dpoly|) 
 ((|constructor| (NIL "\\spadtype{QuasiAlgebraicSet} constructs a domain representing quasi-algebraic sets, which is the intersection of a Zariski closed set, defined as the common zeros of a given list of polynomials (the defining polynomials for equations), and a principal Zariski open set, defined as the complement of the common zeros of a polynomial \\spad{f} (the defining polynomial for the inequation). This domain provides simplification of a user-given representation using groebner basis computations. There are two simplification routines: the first function \\spadfun{idealSimplify} uses groebner basis of ideals alone, while the second, \\spadfun{simplify} uses both groebner basis and factorization. The resulting defining equations \\spad{L} always form a groebner basis, and the resulting defining inequation \\spad{f} is always reduced. The function \\spadfun{simplify} may be applied several times if desired. A third simplification routine \\spadfun{radicalSimplify} is provided in \\spadtype{QuasiAlgebraicSet2} for comparison study only, as it is inefficient compared to the other two, as well as is restricted to only certain coefficient domains. For detail analysis and a comparison of the three methods, please consult the reference cited. \\blankline A polynomial function \\spad{q} defined on the quasi-algebraic set is equivalent to its reduced form with respect to \\spad{L.} While this may be obtained using the usual normal form algorithm, there is no canonical form for \\spad{q.} \\blankline The ordering in groebner basis computation is determined by the data type of the input polynomials. If it is possible we suggest to use refinements of total degree orderings.")) (|simplify| (($ $) "\\spad{simplify(s)} returns a different and presumably simpler representation of \\spad{s} with the defining polynomials for the equations forming a groebner basis, and the defining polynomial for the inequation reduced with respect to the basis, using a heuristic algorithm based on factoring.")) (|idealSimplify| (($ $) "\\spad{idealSimplify(s)} returns a different and presumably simpler representation of \\spad{s} with the defining polynomials for the equations forming a groebner basis, and the defining polynomial for the inequation reduced with respect to the basis, using Buchberger's algorithm.")) (|definingInequation| ((|#4| $) "\\spad{definingInequation(s)} returns a single defining polynomial for the inequation, that is, the Zariski open part of \\spad{s.}")) (|definingEquations| (((|List| |#4|) $) "\\spad{definingEquations(s)} returns a list of defining polynomials for equations, that is, for the Zariski closed part of \\spad{s.}")) (|empty?| (((|Boolean|) $) "\\spad{empty?(s)} returns \\spad{true} if the quasialgebraic set \\spad{s} has no points, and \\spad{false} otherwise.")) (|setStatus| (($ $ (|Union| (|Boolean|) "failed")) "\\spad{setStatus(s,t)} returns the same representation for \\spad{s,} but asserts the following: if \\spad{t} is true, then \\spad{s} is empty, if \\spad{t} is false, then \\spad{s} is non-empty, and if \\spad{t} = \"failed\", then no assertion is made (that is, \"don't know\"). Note: for internal use only, with care.")) (|status| (((|Union| (|Boolean|) "failed") $) "\\spad{status(s)} returns \\spad{true} if the quasi-algebraic set is empty, \\spad{false} if it is not, and \"failed\" if not yet known")) (|quasiAlgebraicSet| (($ (|List| |#4|) |#4|) "\\spad{quasiAlgebraicSet(pl,q)} returns the quasi-algebraic set with defining equations \\spad{p} = 0 for \\spad{p} belonging to the list \\spad{pl,} and defining inequation \\spad{q} \\spad{^=} 0.")) (|empty| (($) "\\spad{empty()} returns the empty quasi-algebraic set"))) 
 NIL 
-((-12 (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-303))))) 
-(-996 R E V P TS) 
+((-12 (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-323))))) 
+(-1017 R E V P TS) 
 ((|constructor| (NIL "A package for removing redundant quasi-components and redundant branches when decomposing a variety by means of quasi-components of regular triangular sets.")) (|branchIfCan| (((|Union| (|Record| (|:| |eq| (|List| |#4|)) (|:| |tower| |#5|) (|:| |ineq| (|List| |#4|))) "failed") (|List| |#4|) |#5| (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{branchIfCan(leq,ts,lineq,b1,b2,b3,b4,b5)} is an internal subroutine, exported only for developement.")) (|prepareDecompose| (((|List| (|Record| (|:| |eq| (|List| |#4|)) (|:| |tower| |#5|) (|:| |ineq| (|List| |#4|)))) (|List| |#4|) (|List| |#5|) (|Boolean|) (|Boolean|)) "\\axiom{prepareDecompose(lp,lts,b1,b2)} is an internal subroutine, exported only for developement.")) (|removeSuperfluousCases| (((|List| (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|))) (|List| (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|)))) "\\axiom{removeSuperfluousCases(llpwt)} is an internal subroutine, exported only for developement.")) (|subCase?| (((|Boolean|) (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|)) (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|))) "\\axiom{subCase?(lpwt1,lpwt2)} is an internal subroutine, exported only for developement.")) (|removeSuperfluousQuasiComponents| (((|List| |#5|) (|List| |#5|)) "\\axiom{removeSuperfluousQuasiComponents(lts)} removes from \\axiom{lts} any \\spad{ts} such that \\axiom{subQuasiComponent?(ts,us)} holds for another \\spad{us} in \\axiom{lts}.")) (|subQuasiComponent?| (((|Boolean|) |#5| (|List| |#5|)) "\\axiom{subQuasiComponent?(ts,lus)} returns \\spad{true} iff \\axiom{subQuasiComponent?(ts,us)} holds for one \\spad{us} in \\spad{lus}.") (((|Boolean|) |#5| |#5|) "\\axiom{subQuasiComponent?(ts,us)} returns \\spad{true} iff internalSubQuasiComponent? returs true.")) (|internalSubQuasiComponent?| (((|Union| (|Boolean|) "failed") |#5| |#5|) "\\axiom{internalSubQuasiComponent?(ts,us)} returns a boolean \\spad{b} value if the fact that the regular zero set of \\axiom{us} contains that of \\axiom{ts} can be decided (and in that case \\axiom{b} gives this inclusion) otherwise returns \\axiom{\"failed\"}.")) (|infRittWu?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{infRittWu?(lp1,lp2)} is an internal subroutine, exported only for developement.")) (|internalInfRittWu?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{internalInfRittWu?(lp1,lp2)} is an internal subroutine, exported only for developement.")) (|internalSubPolSet?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{internalSubPolSet?(lp1,lp2)} returns \\spad{true} iff \\axiom{lp1} is a sub-set of \\axiom{lp2} assuming that these lists are sorted increasingly w.r.t. infRittWu? from RecursivePolynomialCategory.")) (|subPolSet?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{subPolSet?(lp1,lp2)} returns \\spad{true} iff \\axiom{lp1} is a sub-set of \\axiom{lp2}.")) (|subTriSet?| (((|Boolean|) |#5| |#5|) "\\axiom{subTriSet?(ts,us)} returns \\spad{true} iff \\axiom{ts} is a sub-set of \\axiom{us}.")) (|moreAlgebraic?| (((|Boolean|) |#5| |#5|) "\\axiom{moreAlgebraic?(ts,us)} returns \\spad{false} iff \\axiom{ts} and \\axiom{us} are both empty, or \\axiom{ts} has less elements than \\axiom{us}, or some variable is algebraic w.r.t. \\axiom{us} and is not w.r.t. \\axiom{ts}.")) (|algebraicSort| (((|List| |#5|) (|List| |#5|)) "\\axiom{algebraicSort(lts)} sorts \\axiom{lts} w.r.t supDimElseRittWu?")) (|supDimElseRittWu?| (((|Boolean|) |#5| |#5|) "\\axiom{supDimElseRittWu(ts,us)} returns \\spad{true} iff \\axiom{ts} has less elements than \\axiom{us} otherwise if \\axiom{ts} has higher rank than \\axiom{us} w.r.t. Riit and Wu ordering.")) (|stopTable!| (((|Void|)) "\\axiom{stopTableGcd!()} is an internal subroutine, exported only for developement.")) (|startTable!| (((|Void|) (|String|) (|String|) (|String|)) "\\axiom{startTableGcd!(s1,s2,s3)} is an internal subroutine, exported only for developement."))) 
 NIL 
 NIL 
-(-997) 
+(-1018) 
 ((|constructor| (NIL "This domain implements simple database queries")) (|value| (((|String|) $) "\\spad{value(q)} returns the value (\\spadignore{i.e.} right hand side) of \\axiom{q}.")) (|variable| (((|Symbol|) $) "\\spad{variable(q)} returns the variable (\\spadignore{i.e.} left hand side) of \\axiom{q}.")) (|equation| (($ (|Symbol|) (|String|)) "\\spad{equation(s,\"a\")} creates a new equation."))) 
 NIL 
 NIL 
-(-998 A B R S) 
+(-1019 A B R S) 
 ((|constructor| (NIL "This package extends a function between integral domains to a mapping between their quotient fields.")) (|map| ((|#4| (|Mapping| |#2| |#1|) |#3|) "\\spad{map(func,frac)} applies the function \\spad{func} to the numerator and denominator of frac."))) 
 NIL 
 NIL 
-(-999 A S) 
+(-1020 A S) 
 ((|constructor| (NIL "QuotientField(S) is the category of fractions of an Integral Domain \\spad{S.}")) (|floor| ((|#2| $) "\\spad{floor(x)} returns the largest integral element below \\spad{x.}")) (|ceiling| ((|#2| $) "\\spad{ceiling(x)} returns the smallest integral element above \\spad{x.}")) (|random| (($) "\\spad{random()} returns a random fraction.")) (|fractionPart| (($ $) "\\spad{fractionPart(x)} returns the fractional part of \\spad{x.} \\spad{x} = wholePart(x) + fractionPart(x)")) (|wholePart| ((|#2| $) "\\spad{wholePart(x)} returns the whole part of the fraction \\spad{x} \\spadignore{i.e.} the truncated quotient of the numerator by the denominator.")) (|denominator| (($ $) "\\spad{denominator(x)} is the denominator of the fraction \\spad{x} converted to \\spad{%.}")) (|numerator| (($ $) "\\spad{numerator(x)} is the numerator of the fraction \\spad{x} converted to \\spad{%.}")) (|denom| ((|#2| $) "\\spad{denom(x)} returns the denominator of the fraction \\spad{x.}")) (|numer| ((|#2| $) "\\spad{numer(x)} returns the numerator of the fraction \\spad{x.}")) (/ (($ |#2| |#2|) "\\spad{d1 / \\spad{d2}} returns the fraction \\spad{d1} divided by \\spad{d2.}"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (QUOTE (-554))) (|HasCategory| |#2| (QUOTE (-303))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (QUOTE (-1028))) (|HasCategory| |#2| (QUOTE (-821))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-1144)))) 
-(-1000 S) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (QUOTE (-574))) (|HasCategory| |#2| (QUOTE (-323))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (QUOTE (-1049))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-1165)))) 
+(-1021 S) 
 ((|constructor| (NIL "QuotientField(S) is the category of fractions of an Integral Domain \\spad{S.}")) (|floor| ((|#1| $) "\\spad{floor(x)} returns the largest integral element below \\spad{x.}")) (|ceiling| ((|#1| $) "\\spad{ceiling(x)} returns the smallest integral element above \\spad{x.}")) (|random| (($) "\\spad{random()} returns a random fraction.")) (|fractionPart| (($ $) "\\spad{fractionPart(x)} returns the fractional part of \\spad{x.} \\spad{x} = wholePart(x) + fractionPart(x)")) (|wholePart| ((|#1| $) "\\spad{wholePart(x)} returns the whole part of the fraction \\spad{x} \\spadignore{i.e.} the truncated quotient of the numerator by the denominator.")) (|denominator| (($ $) "\\spad{denominator(x)} is the denominator of the fraction \\spad{x} converted to \\spad{%.}")) (|numerator| (($ $) "\\spad{numerator(x)} is the numerator of the fraction \\spad{x} converted to \\spad{%.}")) (|denom| ((|#1| $) "\\spad{denom(x)} returns the denominator of the fraction \\spad{x.}")) (|numer| ((|#1| $) "\\spad{numer(x)} returns the numerator of the fraction \\spad{x.}")) (/ (($ |#1| |#1|) "\\spad{d1 / \\spad{d2}} returns the fraction \\spad{d1} divided by \\spad{d2.}"))) 
-((-3389 . T) (-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-2623 . T) (-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1001 |n| K) 
+(-1022 |n| K) 
 ((|constructor| (NIL "This domain provides modest support for quadratic forms.")) (|elt| ((|#2| $ (|DirectProduct| |#1| |#2|)) "\\spad{elt(qf,v)} evaluates the quadratic form \\spad{qf} on the vector \\spad{v,} producing a scalar.")) (|matrix| (((|SquareMatrix| |#1| |#2|) $) "\\spad{matrix(qf)} creates a square matrix from the quadratic form \\spad{qf.}")) (|quadraticForm| (($ (|SquareMatrix| |#1| |#2|)) "\\spad{quadraticForm(m)} creates a quadratic form from a symmetric, square matrix \\spad{m.}"))) 
 NIL 
 NIL 
-(-1002 S) 
+(-1023 S) 
 ((|constructor| (NIL "A queue is a bag where the first item inserted is the first item extracted.")) (|back| ((|#1| $) "\\spad{back(q)} returns the element at the back of the queue. The queue \\spad{q} is unchanged by this operation. Error: if \\spad{q} is empty.")) (|front| ((|#1| $) "\\spad{front(q)} returns the element at the front of the queue. The queue \\spad{q} is unchanged by this operation. Error: if \\spad{q} is empty.")) (|length| (((|NonNegativeInteger|) $) "\\spad{length(q)} returns the number of elements in the queue. Note that \\axiom{length(q) = \\#q}.")) (|rotate!| (($ $) "\\spad{rotate! \\spad{q}} rotates queue \\spad{q} so that the element at the front of the queue goes to the back of the queue. Note that rotate! \\spad{q} is equivalent to enqueue!(dequeue!(q)).")) (|dequeue!| ((|#1| $) "\\spad{dequeue! \\spad{s}} destructively extracts the first (top) element from queue \\spad{q.} The element previously second in the queue becomes the first element. Error: if \\spad{q} is empty.")) (|enqueue!| ((|#1| |#1| $) "\\spad{enqueue!(x,q)} inserts \\spad{x} into the queue \\spad{q} at the back end."))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-1003 S R) 
+(-1024 S R) 
 ((|constructor| (NIL "\\spadtype{QuaternionCategory} describes the category of quaternions and implements functions that are not representation specific.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(q)} returns \\spad{q} as a rational number, or \"failed\" if this is not possible. Note that if \\spad{rational?(q)} is true, the conversion can be done and the rational number will be returned.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(q)} tries to convert \\spad{q} into a rational number. Error: if this is not possible. If \\spad{rational?(q)} is true, the conversion will be done and the rational number returned.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(q)} returns {\\it true} if all the imaginary parts of \\spad{q} are zero and the real part can be converted into a rational number, and {\\it false} otherwise.")) (|abs| ((|#2| $) "\\spad{abs(q)} computes the absolute value of quaternion \\spad{q} (sqrt of norm).")) (|real| ((|#2| $) "\\spad{real(q)} extracts the real part of quaternion \\spad{q}.")) (|quatern| (($ |#2| |#2| |#2| |#2|) "\\spad{quatern(r,i,j,k)} constructs a quaternion from scalars.")) (|norm| ((|#2| $) "\\spad{norm(q)} computes the norm of \\spad{q} (the sum of the squares of the components).")) (|imagK| ((|#2| $) "\\spad{imagK(q)} extracts the imaginary \\spad{k} part of quaternion \\spad{q}.")) (|imagJ| ((|#2| $) "\\spad{imagJ(q)} extracts the imaginary \\spad{j} part of quaternion \\spad{q}.")) (|imagI| ((|#2| $) "\\spad{imagI(q)} extracts the imaginary \\spad{i} part of quaternion \\spad{q}.")) (|conjugate| (($ $) "\\spad{conjugate(q)} negates the imaginary parts of quaternion \\spad{q}."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-554))) (|HasCategory| |#2| (QUOTE (-1063))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-287)))) 
-(-1004 R) 
+((|HasCategory| |#2| (QUOTE (-574))) (|HasCategory| |#2| (QUOTE (-1084))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-307)))) 
+(-1025 R) 
 ((|constructor| (NIL "\\spadtype{QuaternionCategory} describes the category of quaternions and implements functions that are not representation specific.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(q)} returns \\spad{q} as a rational number, or \"failed\" if this is not possible. Note that if \\spad{rational?(q)} is true, the conversion can be done and the rational number will be returned.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(q)} tries to convert \\spad{q} into a rational number. Error: if this is not possible. If \\spad{rational?(q)} is true, the conversion will be done and the rational number returned.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(q)} returns {\\it true} if all the imaginary parts of \\spad{q} are zero and the real part can be converted into a rational number, and {\\it false} otherwise.")) (|abs| ((|#1| $) "\\spad{abs(q)} computes the absolute value of quaternion \\spad{q} (sqrt of norm).")) (|real| ((|#1| $) "\\spad{real(q)} extracts the real part of quaternion \\spad{q}.")) (|quatern| (($ |#1| |#1| |#1| |#1|) "\\spad{quatern(r,i,j,k)} constructs a quaternion from scalars.")) (|norm| ((|#1| $) "\\spad{norm(q)} computes the norm of \\spad{q} (the sum of the squares of the components).")) (|imagK| ((|#1| $) "\\spad{imagK(q)} extracts the imaginary \\spad{k} part of quaternion \\spad{q}.")) (|imagJ| ((|#1| $) "\\spad{imagJ(q)} extracts the imaginary \\spad{j} part of quaternion \\spad{q}.")) (|imagI| ((|#1| $) "\\spad{imagI(q)} extracts the imaginary \\spad{i} part of quaternion \\spad{q}.")) (|conjugate| (($ $) "\\spad{conjugate(q)} negates the imaginary parts of quaternion \\spad{q}."))) 
-((-4595 |has| |#1| (-287)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 |has| |#1| (-307)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1005 QR R QS S) 
+(-1026 QR R QS S) 
 ((|constructor| (NIL "\\spadtype{QuaternionCategoryFunctions2} implements functions between two quaternion domains. The function \\spadfun{map} is used by the system interpreter to coerce between quaternion types.")) (|map| ((|#3| (|Mapping| |#4| |#2|) |#1|) "\\indented{1}{map(f,u) maps \\spad{f} onto the component parts of the quaternion u.} \\indented{1}{to convert an expression in Quaterion(R) to Quaternion(S)} \\blankline \\spad{X} f(a:FRAC(INT)):COMPLEX(FRAC(INT)) \\spad{==} a::COMPLEX(FRAC(INT)) \\spad{X} q:=quatern(2/11,-8,3/4,1) \\spad{X} map(f,q)"))) 
 NIL 
 NIL 
-(-1006 R) 
+(-1027 R) 
 ((|constructor| (NIL "\\spadtype{Quaternion} implements quaternions over a commutative ring. The main constructor function is \\spadfun{quatern} which takes 4 arguments: the real part, the \\spad{i} imaginary part, the \\spad{j} imaginary part and the \\spad{k} imaginary part."))) 
-((-4595 |has| |#1| (-287)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-287))) (-1841 (|HasCategory| |#1| (QUOTE (-287))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -283) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-1063))) (|HasCategory| |#1| (QUOTE (-554))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368))))) 
-(-1007 S) 
+((-4618 |has| |#1| (-307)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-307))) (-3836 (|HasCategory| |#1| (QUOTE (-307))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-1084))) (|HasCategory| |#1| (QUOTE (-574))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388))))) 
+(-1028 S) 
 ((|constructor| (NIL "Linked List implementation of a Queue")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} member?(3,a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} count(4,a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} count(x+->(x>2),a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} any?(x+->(x=4),a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} every?(x+->(x=4),a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} b:Queue INT:= queue [1,2,3,4,5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} map!(x+->x+10,a) \\spad{X} a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} map(x+->x+10,a) \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} eq?(a,b)")) (|copy| (($ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} copy a")) (|sample| (($) "\\blankline \\spad{X} sample()$Queue(INT)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()$(Queue INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} empty? a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,2,3,4,5])$Queue(INT)")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} size?(a,5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} more?(a,9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} less?(a,9)")) (|length| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} length a")) (|rotate!| (($ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} rotate! a")) (|back| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} back a")) (|front| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} front a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} insert! (8,a) \\spad{X} a")) (|enqueue!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} enqueue! (9,a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} extract! a \\spad{X} a")) (|dequeue!| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,2,3,4,5] \\spad{X} dequeue! a \\spad{X} a")) (|queue| (($ (|List| |#1|)) "\\indented{1}{queue([x,y,...,z]) creates a queue with first (top)} \\indented{1}{element \\spad{x,} second element y,...,and last (bottom) element \\spad{z.}} \\blankline \\spad{E} e:Queue INT:= queue [1,2,3,4,5]"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-1008 S) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-1029 S) 
 ((|constructor| (NIL "Description:")) (** (($ $ (|Fraction| (|Integer|))) "\\spad{x \\spad{**} \\spad{y}} is the rational exponentiation of \\spad{x} by the power \\spad{y.}")) (|nthRoot| (($ $ (|Integer|)) "\\spad{nthRoot(x,n)} returns the \\spad{n}th root of \\spad{x.}")) (|sqrt| (($ $) "\\spad{sqrt(x)} returns the square root of \\spad{x.}"))) 
 NIL 
 NIL 
-(-1009) 
+(-1030) 
 ((|constructor| (NIL "Description:")) (** (($ $ (|Fraction| (|Integer|))) "\\spad{x \\spad{**} \\spad{y}} is the rational exponentiation of \\spad{x} by the power \\spad{y.}")) (|nthRoot| (($ $ (|Integer|)) "\\spad{nthRoot(x,n)} returns the \\spad{n}th root of \\spad{x.}")) (|sqrt| (($ $) "\\spad{sqrt(x)} returns the square root of \\spad{x.}"))) 
 NIL 
 NIL 
-(-1010 -3313 UP UPUP |radicnd| |n|) 
+(-1031 -3958 UP UPUP |radicnd| |n|) 
 ((|constructor| (NIL "Function field defined by y**n = f(x)."))) 
-((-4595 |has| (-413 |#2|) (-368)) (-4600 |has| (-413 |#2|) (-368)) (-4594 |has| (-413 |#2|) (-368)) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-413 |#2|) (QUOTE (-149))) (|HasCategory| (-413 |#2|) (QUOTE (-151))) (|HasCategory| (-413 |#2|) (QUOTE (-353))) (|HasCategory| (-413 |#2|) (QUOTE (-368))) (-1841 (|HasCategory| (-413 |#2|) (QUOTE (-368))) (|HasCategory| (-413 |#2|) (QUOTE (-353)))) (|HasCategory| (-413 |#2|) (QUOTE (-374))) (|HasCategory| (-413 |#2|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| (-413 |#2|) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-413 |#2|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-374))) (-1841 (|HasCategory| (-413 |#2|) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (-12 (|HasCategory| (-413 |#2|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (-1841 (-12 (|HasCategory| (-413 |#2|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (-12 (|HasCategory| (-413 |#2|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-413 |#2|) (QUOTE (-353))))) (-12 (|HasCategory| (-413 |#2|) (QUOTE (-227))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (-1841 (-12 (|HasCategory| (-413 |#2|) (QUOTE (-227))) (|HasCategory| (-413 |#2|) (QUOTE (-368)))) (|HasCategory| (-413 |#2|) (QUOTE (-353))))) 
-(-1011 |bb|) 
+((-4618 |has| (-433 |#2|) (-388)) (-4623 |has| (-433 |#2|) (-388)) (-4617 |has| (-433 |#2|) (-388)) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-433 |#2|) (QUOTE (-169))) (|HasCategory| (-433 |#2|) (QUOTE (-171))) (|HasCategory| (-433 |#2|) (QUOTE (-373))) (|HasCategory| (-433 |#2|) (QUOTE (-388))) (-3836 (|HasCategory| (-433 |#2|) (QUOTE (-388))) (|HasCategory| (-433 |#2|) (QUOTE (-373)))) (|HasCategory| (-433 |#2|) (QUOTE (-394))) (|HasCategory| (-433 |#2|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| (-433 |#2|) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-433 |#2|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-394))) (-3836 (|HasCategory| (-433 |#2|) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (-12 (|HasCategory| (-433 |#2|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (-3836 (-12 (|HasCategory| (-433 |#2|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (-12 (|HasCategory| (-433 |#2|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-433 |#2|) (QUOTE (-373))))) (-12 (|HasCategory| (-433 |#2|) (QUOTE (-247))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (-3836 (-12 (|HasCategory| (-433 |#2|) (QUOTE (-247))) (|HasCategory| (-433 |#2|) (QUOTE (-388)))) (|HasCategory| (-433 |#2|) (QUOTE (-373))))) 
+(-1032 |bb|) 
 ((|constructor| (NIL "This domain allows rational numbers to be presented as repeating decimal expansions or more generally as repeating expansions in any base.")) (|fractRadix| (($ (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{fractRadix(pre,cyc)} creates a fractional radix expansion from a list of prefix ragits and a list of cyclic ragits. \\spadignore{e.g.} \\spad{fractRadix([1],[6])} will return \\spad{0.16666666...}.")) (|wholeRadix| (($ (|List| (|Integer|))) "\\spad{wholeRadix(l)} creates an integral radix expansion from a list of ragits. For example, \\spad{wholeRadix([1,3,4])} will return \\spad{134}.")) (|cycleRagits| (((|List| (|Integer|)) $) "\\spad{cycleRagits(rx)} returns the cyclic part of the ragits of the fractional part of a radix expansion. For example, if \\spad{x = 3/28 = 0.10 714285 714285 ...}, then \\spad{cycleRagits(x) = [7,1,4,2,8,5]}.")) (|prefixRagits| (((|List| (|Integer|)) $) "\\spad{prefixRagits(rx)} returns the non-cyclic part of the ragits of the fractional part of a radix expansion. For example, if \\spad{x = 3/28 = 0.10 714285 714285 ...}, then \\spad{prefixRagits(x)=[1,0]}.")) (|fractRagits| (((|Stream| (|Integer|)) $) "\\spad{fractRagits(rx)} returns the ragits of the fractional part of a radix expansion.")) (|wholeRagits| (((|List| (|Integer|)) $) "\\spad{wholeRagits(rx)} returns the ragits of the integer part of a radix expansion.")) (|fractionPart| (((|Fraction| (|Integer|)) $) "\\spad{fractionPart(rx)} returns the fractional part of a radix expansion.")) (|coerce| (((|Fraction| (|Integer|)) $) "\\spad{coerce(rx)} converts a radix expansion to a rational number."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-572) (QUOTE (-910))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| (-572) (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-151))) (|HasCategory| (-572) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-572) (QUOTE (-1028))) (|HasCategory| (-572) (QUOTE (-821))) (|HasCategory| (-572) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1144))) (|HasCategory| (-572) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| (-572) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| (-572) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| (-572) (QUOTE (-227))) (|HasCategory| (-572) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| (-572) (LIST (QUOTE -527) (QUOTE (-1170)) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (LIST (QUOTE -283) (QUOTE (-572)) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-303))) (|HasCategory| (-572) (QUOTE (-554))) (|HasCategory| (-572) (QUOTE (-848))) (-1841 (|HasCategory| (-572) (QUOTE (-821))) (|HasCategory| (-572) (QUOTE (-848)))) (|HasCategory| (-572) (LIST (QUOTE -634) (QUOTE (-572)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-572) (QUOTE (-910)))) (|HasCategory| (-572) (QUOTE (-149))))) 
-(-1012) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-592) (QUOTE (-931))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| (-592) (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-171))) (|HasCategory| (-592) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-592) (QUOTE (-1049))) (|HasCategory| (-592) (QUOTE (-842))) (|HasCategory| (-592) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1165))) (|HasCategory| (-592) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| (-592) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| (-592) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| (-592) (QUOTE (-247))) (|HasCategory| (-592) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| (-592) (LIST (QUOTE -547) (QUOTE (-1191)) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (LIST (QUOTE -303) (QUOTE (-592)) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-323))) (|HasCategory| (-592) (QUOTE (-574))) (|HasCategory| (-592) (QUOTE (-869))) (-3836 (|HasCategory| (-592) (QUOTE (-842))) (|HasCategory| (-592) (QUOTE (-869)))) (|HasCategory| (-592) (LIST (QUOTE -654) (QUOTE (-592)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-592) (QUOTE (-931)))) (|HasCategory| (-592) (QUOTE (-169))))) 
+(-1033) 
 ((|constructor| (NIL "This package provides tools for creating radix expansions.")) (|radix| (((|Any|) (|Fraction| (|Integer|)) (|Integer|)) "\\spad{radix(x,b)} converts \\spad{x} to a radix expansion in base \\spad{b.}"))) 
 NIL 
 NIL 
-(-1013) 
+(-1034) 
 ((|constructor| (NIL "Random number generators. All random numbers used in the system should originate from the same generator. This package is intended to be the source.")) (|seed| (((|Integer|)) "\\spad{seed()} returns the current seed value.")) (|reseed| (((|Void|) (|Integer|)) "\\spad{reseed(n)} restarts the random number generator at \\spad{n.}")) (|size| (((|Integer|)) "\\spad{size()} is the base of the random number generator")) (|randnum| (((|Integer|) (|Integer|)) "\\spad{randnum(n)} is a random number between 0 and \\spad{n.}") (((|Integer|)) "\\spad{randnum()} is a random number between 0 and size()."))) 
 NIL 
 NIL 
-(-1014 RP) 
+(-1035 RP) 
 ((|constructor| (NIL "Factorization of extended polynomials with rational coefficients. This package implements factorization of extended polynomials whose coefficients are rational numbers. It does this by taking the \\spad{lcm} of the coefficients of the polynomial and creating a polynomial with integer coefficients. The algorithm in \\spadtype{GaloisGroupFactorizer} is then used to factor the integer polynomial. The result is normalized with respect to the original \\spad{lcm} of the denominators.")) (|factorSquareFree| (((|Factored| |#1|) |#1|) "\\spad{factorSquareFree(p)} factors an extended squareFree polynomial \\spad{p} over the rational numbers.")) (|factor| (((|Factored| |#1|) |#1|) "\\spad{factor(p)} factors an extended polynomial \\spad{p} over the rational numbers."))) 
 NIL 
 NIL 
-(-1015 S) 
+(-1036 S) 
 ((|constructor| (NIL "Rational number testing and retraction functions.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") |#1|) "\\spad{rationalIfCan(x)} returns \\spad{x} as a rational number, \"failed\" if \\spad{x} is not a rational number.")) (|rational?| (((|Boolean|) |#1|) "\\spad{rational?(x)} returns \\spad{true} if \\spad{x} is a rational number, \\spad{false} otherwise.")) (|rational| (((|Fraction| (|Integer|)) |#1|) "\\spad{rational(x)} returns \\spad{x} as a rational number; error if \\spad{x} is not a rational number."))) 
 NIL 
 NIL 
-(-1016 A S) 
+(-1037 A S) 
 ((|constructor| (NIL "A recursive aggregate over a type \\spad{S} is a model for a a directed graph containing values of type \\spad{S.} Recursively, a recursive aggregate is a node consisting of a \\spadfun{value} from \\spad{S} and 0 or more \\spadfun{children} which are recursive aggregates. A node with no children is called a \\spadfun{leaf} node. A recursive aggregate may be cyclic for which some operations as noted may go into an infinite loop.")) (|setvalue!| ((|#2| $ |#2|) "\\spad{setvalue!(u,x)} sets the value of node \\spad{u} to \\spad{x.}")) (|setelt| ((|#2| $ "value" |#2|) "\\spad{setelt(a,\"value\",x)} (also written \\axiom{a . value \\spad{:=} \\spad{x})} is equivalent to \\axiom{setvalue!(a,x)}")) (|setchildren!| (($ $ (|List| $)) "\\spad{setchildren!(u,v)} replaces the current children of node \\spad{u} with the members of \\spad{v} in left-to-right order.")) (|node?| (((|Boolean|) $ $) "\\spad{node?(u,v)} tests if node \\spad{u} is contained in node \\spad{v} (either as a child, a child of a child, etc.).")) (|child?| (((|Boolean|) $ $) "\\spad{child?(u,v)} tests if node \\spad{u} is a child of node \\spad{v.}")) (|distance| (((|Integer|) $ $) "\\spad{distance(u,v)} returns the path length (an integer) from node \\spad{u} to \\spad{v.}")) (|leaves| (((|List| |#2|) $) "\\spad{leaves(t)} returns the list of values in obtained by visiting the nodes of tree \\axiom{t} in left-to-right order.")) (|cyclic?| (((|Boolean|) $) "\\spad{cyclic?(u)} tests if \\spad{u} has a cycle.")) (|elt| ((|#2| $ "value") "\\spad{elt(u,\"value\")} (also written: \\axiom{a. value}) is equivalent to \\axiom{value(a)}.")) (|value| ((|#2| $) "\\spad{value(u)} returns the value of the node u.")) (|leaf?| (((|Boolean|) $) "\\spad{leaf?(u)} tests if \\spad{u} is a terminal node.")) (|nodes| (((|List| $) $) "\\spad{nodes(u)} returns a list of all of the nodes of aggregate u.")) (|children| (((|List| $) $) "\\spad{children(u)} returns a list of the children of aggregate u."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4603)) (|HasCategory| |#2| (QUOTE (-1098)))) 
-(-1017 S) 
+((|HasAttribute| |#1| (QUOTE -4626)) (|HasCategory| |#2| (QUOTE (-1119)))) 
+(-1038 S) 
 ((|constructor| (NIL "A recursive aggregate over a type \\spad{S} is a model for a a directed graph containing values of type \\spad{S.} Recursively, a recursive aggregate is a node consisting of a \\spadfun{value} from \\spad{S} and 0 or more \\spadfun{children} which are recursive aggregates. A node with no children is called a \\spadfun{leaf} node. A recursive aggregate may be cyclic for which some operations as noted may go into an infinite loop.")) (|setvalue!| ((|#1| $ |#1|) "\\spad{setvalue!(u,x)} sets the value of node \\spad{u} to \\spad{x.}")) (|setelt| ((|#1| $ "value" |#1|) "\\spad{setelt(a,\"value\",x)} (also written \\axiom{a . value \\spad{:=} \\spad{x})} is equivalent to \\axiom{setvalue!(a,x)}")) (|setchildren!| (($ $ (|List| $)) "\\spad{setchildren!(u,v)} replaces the current children of node \\spad{u} with the members of \\spad{v} in left-to-right order.")) (|node?| (((|Boolean|) $ $) "\\spad{node?(u,v)} tests if node \\spad{u} is contained in node \\spad{v} (either as a child, a child of a child, etc.).")) (|child?| (((|Boolean|) $ $) "\\spad{child?(u,v)} tests if node \\spad{u} is a child of node \\spad{v.}")) (|distance| (((|Integer|) $ $) "\\spad{distance(u,v)} returns the path length (an integer) from node \\spad{u} to \\spad{v.}")) (|leaves| (((|List| |#1|) $) "\\spad{leaves(t)} returns the list of values in obtained by visiting the nodes of tree \\axiom{t} in left-to-right order.")) (|cyclic?| (((|Boolean|) $) "\\spad{cyclic?(u)} tests if \\spad{u} has a cycle.")) (|elt| ((|#1| $ "value") "\\spad{elt(u,\"value\")} (also written: \\axiom{a. value}) is equivalent to \\axiom{value(a)}.")) (|value| ((|#1| $) "\\spad{value(u)} returns the value of the node u.")) (|leaf?| (((|Boolean|) $) "\\spad{leaf?(u)} tests if \\spad{u} is a terminal node.")) (|nodes| (((|List| $) $) "\\spad{nodes(u)} returns a list of all of the nodes of aggregate u.")) (|children| (((|List| $) $) "\\spad{children(u)} returns a list of the children of aggregate u."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-1018 S) 
+(-1039 S) 
 ((|constructor| (NIL "\\axiomType{RealClosedField} provides common access functions for all real closed fields. provides computations with generic real roots of polynomials")) (|approximate| (((|Fraction| (|Integer|)) $ $) "\\axiom{approximate(n,p)} gives an approximation of \\axiom{n} that has precision \\axiom{p}")) (|rename| (($ $ (|OutputForm|)) "\\axiom{rename(x,name)} gives a new number that prints as name")) (|rename!| (($ $ (|OutputForm|)) "\\axiom{rename!(x,name)} changes the way \\axiom{x} is printed")) (|sqrt| (($ (|Integer|)) "\\axiom{sqrt(x)} is \\axiom{x \\spad{**} (1/2)}") (($ (|Fraction| (|Integer|))) "\\axiom{sqrt(x)} is \\axiom{x \\spad{**} (1/2)}") (($ $) "\\axiom{sqrt(x)} is \\axiom{x \\spad{**} (1/2)}") (($ $ (|NonNegativeInteger|)) "\\axiom{sqrt(x,n)} is \\axiom{x \\spad{**} (1/n)}")) (|allRootsOf| (((|List| $) (|Polynomial| (|Integer|))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|Polynomial| $)) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| (|Integer|))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| $)) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely")) (|rootOf| (((|Union| $ "failed") (|SparseUnivariatePolynomial| $) (|PositiveInteger|)) "\\axiom{rootOf(pol,n)} creates the \\spad{n}th root for the order of \\axiom{pol} and gives it unique name") (((|Union| $ "failed") (|SparseUnivariatePolynomial| $) (|PositiveInteger|) (|OutputForm|)) "\\axiom{rootOf(pol,n,name)} creates the \\spad{n}th root for the order of \\axiom{pol} and names it \\axiom{name}")) (|mainValue| (((|Union| (|SparseUnivariatePolynomial| $) "failed") $) "\\axiom{mainValue(x)} is the expression of \\axiom{x} in terms of \\axiom{SparseUnivariatePolynomial($)}")) (|mainDefiningPolynomial| (((|Union| (|SparseUnivariatePolynomial| $) "failed") $) "\\axiom{mainDefiningPolynomial(x)} is the defining polynomial for the main algebraic quantity of \\axiom{x}")) (|mainForm| (((|Union| (|OutputForm|) "failed") $) "\\axiom{mainForm(x)} is the main algebraic quantity name of \\axiom{x}"))) 
 NIL 
 NIL 
-(-1019) 
+(-1040) 
 ((|constructor| (NIL "\\axiomType{RealClosedField} provides common access functions for all real closed fields. provides computations with generic real roots of polynomials")) (|approximate| (((|Fraction| (|Integer|)) $ $) "\\axiom{approximate(n,p)} gives an approximation of \\axiom{n} that has precision \\axiom{p}")) (|rename| (($ $ (|OutputForm|)) "\\axiom{rename(x,name)} gives a new number that prints as name")) (|rename!| (($ $ (|OutputForm|)) "\\axiom{rename!(x,name)} changes the way \\axiom{x} is printed")) (|sqrt| (($ (|Integer|)) "\\axiom{sqrt(x)} is \\axiom{x \\spad{**} (1/2)}") (($ (|Fraction| (|Integer|))) "\\axiom{sqrt(x)} is \\axiom{x \\spad{**} (1/2)}") (($ $) "\\axiom{sqrt(x)} is \\axiom{x \\spad{**} (1/2)}") (($ $ (|NonNegativeInteger|)) "\\axiom{sqrt(x,n)} is \\axiom{x \\spad{**} (1/n)}")) (|allRootsOf| (((|List| $) (|Polynomial| (|Integer|))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|Polynomial| $)) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| (|Integer|))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| $)) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely")) (|rootOf| (((|Union| $ "failed") (|SparseUnivariatePolynomial| $) (|PositiveInteger|)) "\\axiom{rootOf(pol,n)} creates the \\spad{n}th root for the order of \\axiom{pol} and gives it unique name") (((|Union| $ "failed") (|SparseUnivariatePolynomial| $) (|PositiveInteger|) (|OutputForm|)) "\\axiom{rootOf(pol,n,name)} creates the \\spad{n}th root for the order of \\axiom{pol} and names it \\axiom{name}")) (|mainValue| (((|Union| (|SparseUnivariatePolynomial| $) "failed") $) "\\axiom{mainValue(x)} is the expression of \\axiom{x} in terms of \\axiom{SparseUnivariatePolynomial($)}")) (|mainDefiningPolynomial| (((|Union| (|SparseUnivariatePolynomial| $) "failed") $) "\\axiom{mainDefiningPolynomial(x)} is the defining polynomial for the main algebraic quantity of \\axiom{x}")) (|mainForm| (((|Union| (|OutputForm|) "failed") $) "\\axiom{mainForm(x)} is the main algebraic quantity name of \\axiom{x}"))) 
-((-4595 . T) (-4600 . T) (-4594 . T) (-4597 . T) (-4596 . T) ((-4604 "*") . T) (-4599 . T)) 
+((-4618 . T) (-4623 . T) (-4617 . T) (-4620 . T) (-4619 . T) ((-4627 "*") . T) (-4622 . T)) 
 NIL 
-(-1020 R -3313) 
+(-1041 R -3958) 
 ((|constructor| (NIL "Risch differential equation, elementary case.")) (|rischDE| (((|Record| (|:| |ans| |#2|) (|:| |right| |#2|) (|:| |sol?| (|Boolean|))) (|Integer|) |#2| |#2| (|Symbol|) (|Mapping| (|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (|List| |#2|)) (|Mapping| (|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) "\\spad{rischDE(n, \\spad{f,} \\spad{g,} \\spad{x,} lim, ext)} returns \\spad{[y, \\spad{h,} \\spad{b]}} such that \\spad{dy/dx + \\spad{n} df/dx \\spad{y} = \\spad{h}} and \\spad{b \\spad{:=} \\spad{h} = \\spad{g}.} The equation \\spad{dy/dx + \\spad{n} df/dx \\spad{y} = \\spad{g}} has no solution if \\spad{h \\~~= \\spad{g}} (y is a partial solution in that case). Notes: \\spad{lim} is a limited integration function, and ext is an extended integration function."))) 
 NIL 
 NIL 
-(-1021 R -3313) 
+(-1042 R -3958) 
 ((|constructor| (NIL "Risch differential equation, elementary case.")) (|rischDEsys| (((|Union| (|List| |#2|) "failed") (|Integer|) |#2| |#2| |#2| (|Symbol|) (|Mapping| (|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (|List| |#2|)) (|Mapping| (|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) "\\spad{rischDEsys(n, \\spad{f,} g_1, g_2, x,lim,ext)} returns \\spad{y_1.y_2} such that \\spad{(dy1/dx,dy2/dx) + ((0, - \\spad{n} df/dx),(n df/dx,0)) (y1,y2) = (g1,g2)} if \\spad{y_1,y_2} exist, \"failed\" otherwise. \\spad{lim} is a limited integration function, \\spad{ext} is an extended integration function."))) 
 NIL 
 NIL 
-(-1022 -3313 UP) 
+(-1043 -3958 UP) 
 ((|constructor| (NIL "Risch differential equation, transcendental case.")) (|polyRDE| (((|Union| (|:| |ans| (|Record| (|:| |ans| |#2|) (|:| |nosol| (|Boolean|)))) (|:| |eq| (|Record| (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (|Integer|)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (|Integer|) (|Mapping| |#2| |#2|)) "\\spad{polyRDE(a, \\spad{B,} \\spad{C,} \\spad{n,} \\spad{D)}} returns either: 1. \\spad{[Q, \\spad{b]}} such that \\spad{degree(Q) \\spad{<=} \\spad{n}} and \\indented{3}{\\spad{a \\spad{Q'+} \\spad{B} \\spad{Q} = \\spad{C}} if \\spad{b = true}, \\spad{Q} is a partial solution} \\indented{3}{otherwise.} 2. \\spad{[B1, \\spad{C1,} \\spad{m,} \\alpha, \\beta]} such that any polynomial solution \\indented{3}{of degree at most \\spad{n} of \\spad{A \\spad{Q'} + \\spad{BQ} = \\spad{C}} must be of the form} \\indented{3}{\\spad{Q = \\alpha \\spad{H} + \\beta} where \\spad{degree(H) \\spad{<=} \\spad{m}} and} \\indented{3}{H satisfies \\spad{H' + \\spad{B1} \\spad{H} = C1}.} \\spad{D} is the derivation to use.")) (|baseRDE| (((|Record| (|:| |ans| (|Fraction| |#2|)) (|:| |nosol| (|Boolean|))) (|Fraction| |#2|) (|Fraction| |#2|)) "\\spad{baseRDE(f, \\spad{g)}} returns a \\spad{[y, \\spad{b]}} such that \\spad{y' + fy = \\spad{g}} if \\spad{b = true}, \\spad{y} is a partial solution otherwise (no solution in that case). \\spad{D} is the derivation to use.")) (|monomRDE| (((|Union| (|Record| (|:| |a| |#2|) (|:| |b| (|Fraction| |#2|)) (|:| |c| (|Fraction| |#2|)) (|:| |t| |#2|)) "failed") (|Fraction| |#2|) (|Fraction| |#2|) (|Mapping| |#2| |#2|)) "\\spad{monomRDE(f,g,D)} returns \\spad{[A, \\spad{B,} \\spad{C,} \\spad{T]}} such that \\spad{y' + \\spad{f} \\spad{y} = \\spad{g}} has a solution if and only if \\spad{y = \\spad{Q} / \\spad{T},} where \\spad{Q} satisfies \\spad{A \\spad{Q'} + \\spad{B} \\spad{Q} = \\spad{C}} and has no normal pole. A and \\spad{T} are polynomials and \\spad{B} and \\spad{C} have no normal poles. \\spad{D} is the derivation to use."))) 
 NIL 
 NIL 
-(-1023 -3313 UP) 
+(-1044 -3958 UP) 
 ((|constructor| (NIL "Risch differential equation system, transcendental case.")) (|baseRDEsys| (((|Union| (|List| (|Fraction| |#2|)) "failed") (|Fraction| |#2|) (|Fraction| |#2|) (|Fraction| |#2|)) "\\spad{baseRDEsys(f, \\spad{g1,} g2)} returns fractions \\spad{y_1.y_2} such that \\spad{(y1', y2') + ((0, -f), \\spad{(f,} 0)) (y1,y2) = (g1,g2)} if \\spad{y_1,y_2} exist, \"failed\" otherwise.")) (|monomRDEsys| (((|Union| (|Record| (|:| |a| |#2|) (|:| |b| (|Fraction| |#2|)) (|:| |h| |#2|) (|:| |c1| (|Fraction| |#2|)) (|:| |c2| (|Fraction| |#2|)) (|:| |t| |#2|)) "failed") (|Fraction| |#2|) (|Fraction| |#2|) (|Fraction| |#2|) (|Mapping| |#2| |#2|)) "\\spad{monomRDEsys(f,g1,g2,D)} returns \\spad{[A, \\spad{B,} \\spad{H,} \\spad{C1,} \\spad{C2,} \\spad{T]}} such that \\spad{(y1', y2') + ((0, -f), \\spad{(f,} 0)) (y1,y2) = (g1,g2)} has a solution if and only if \\spad{y1 = \\spad{Q1} / \\spad{T,} \\spad{y2} = \\spad{Q2} / \\spad{T},} where \\spad{B,C1,C2,Q1,Q2} have no normal poles and satisfy A \\spad{(Q1', Q2') + ((H, -B), \\spad{(B,} \\spad{H))} (Q1,Q2) = (C1,C2)} \\spad{D} is the derivation to use."))) 
 NIL 
 NIL 
-(-1024 S) 
+(-1045 S) 
 ((|constructor| (NIL "This package exports random distributions")) (|rdHack1| (((|Mapping| |#1|) (|Vector| |#1|) (|Vector| (|Integer|)) (|Integer|)) "\\spad{rdHack1(v,u,n)} \\undocumented")) (|weighted| (((|Mapping| |#1|) (|List| (|Record| (|:| |value| |#1|) (|:| |weight| (|Integer|))))) "\\spad{weighted(l)} \\undocumented")) (|uniform| (((|Mapping| |#1|) (|Set| |#1|)) "\\spad{uniform(s)} \\undocumented"))) 
 NIL 
 NIL 
-(-1025 F1 UP UPUP R F2) 
+(-1046 F1 UP UPUP R F2) 
 ((|constructor| (NIL "Finds the order of a divisor over a finite field")) (|order| (((|NonNegativeInteger|) (|FiniteDivisor| |#1| |#2| |#3| |#4|) |#3| (|Mapping| |#5| |#1|)) "\\spad{order(f,u,g)} \\undocumented"))) 
 NIL 
 NIL 
-(-1026 |Pol|) 
+(-1047 |Pol|) 
 ((|constructor| (NIL "This package provides functions for finding the real zeros of univariate polynomials over the integers to arbitrary user-specified precision. The results are returned as a list of isolating intervals which are expressed as records with \"left\" and \"right\" rational number components.")) (|midpoints| (((|List| (|Fraction| (|Integer|))) (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) "\\spad{midpoints(isolist)} returns the list of midpoints for the list of intervals isolist.")) (|midpoint| (((|Fraction| (|Integer|)) (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) "\\spad{midpoint(int)} returns the midpoint of the interval int.")) (|refine| (((|Union| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) "failed") |#1| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) "\\spad{refine(pol, int, range)} takes a univariate polynomial \\spad{pol} and and isolating interval \\spad{int} containing exactly one real root of pol; the operation returns an isolating interval which is contained within range, or \"failed\" if no such isolating interval exists.") (((|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) |#1| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) (|Fraction| (|Integer|))) "\\spad{refine(pol, int, eps)} refines the interval \\spad{int} containing exactly one root of the univariate polynomial \\spad{pol} to size less than the rational number eps.")) (|realZeros| (((|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) |#1| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) (|Fraction| (|Integer|))) "\\spad{realZeros(pol, int, eps)} returns a list of intervals of length less than the rational number eps for all the real roots of the polynomial \\spad{pol} which lie in the interval expressed by the record int.") (((|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) |#1| (|Fraction| (|Integer|))) "\\spad{realZeros(pol, eps)} returns a list of intervals of length less than the rational number eps for all the real roots of the polynomial pol.") (((|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) |#1| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) "\\spad{realZeros(pol, range)} returns a list of isolating intervals for all the real zeros of the univariate polynomial \\spad{pol} which lie in the interval expressed by the record range.") (((|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) |#1|) "\\spad{realZeros(pol)} returns a list of isolating intervals for all the real zeros of the univariate polynomial pol."))) 
 NIL 
 NIL 
-(-1027 |Pol|) 
+(-1048 |Pol|) 
 ((|constructor| (NIL "This package provides functions for finding the real zeros of univariate polynomials over the rational numbers to arbitrary user-specified precision. The results are returned as a list of isolating intervals, expressed as records with \"left\" and \"right\" rational number components.")) (|refine| (((|Union| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) "failed") |#1| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) "\\spad{refine(pol, int, range)} takes a univariate polynomial \\spad{pol} and and isolating interval \\spad{int} which must contain exactly one real root of pol, and returns an isolating interval which is contained within range, or \"failed\" if no such isolating interval exists.") (((|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) |#1| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) (|Fraction| (|Integer|))) "\\spad{refine(pol, int, eps)} refines the interval \\spad{int} containing exactly one root of the univariate polynomial \\spad{pol} to size less than the rational number eps.")) (|realZeros| (((|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) |#1| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))) (|Fraction| (|Integer|))) "\\spad{realZeros(pol, int, eps)} returns a list of intervals of length less than the rational number eps for all the real roots of the polynomial \\spad{pol} which lie in the interval expressed by the record int.") (((|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) |#1| (|Fraction| (|Integer|))) "\\spad{realZeros(pol, eps)} returns a list of intervals of length less than the rational number eps for all the real roots of the polynomial pol.") (((|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) |#1| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) "\\spad{realZeros(pol, range)} returns a list of isolating intervals for all the real zeros of the univariate polynomial \\spad{pol} which lie in the interval expressed by the record range.") (((|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) |#1|) "\\spad{realZeros(pol)} returns a list of isolating intervals for all the real zeros of the univariate polynomial pol."))) 
 NIL 
 NIL 
-(-1028) 
+(-1049) 
 ((|constructor| (NIL "The category of real numeric domains, that is, convertible to floats."))) 
 NIL 
 NIL 
-(-1029) 
+(-1050) 
 ((|constructor| (NIL "This package provides numerical solutions of systems of polynomial equations for use in ACPLOT")) (|realSolve| (((|List| (|List| (|Float|))) (|List| (|Polynomial| (|Integer|))) (|List| (|Symbol|)) (|Float|)) "\\indented{1}{realSolve(lp,lv,eps) = compute the list of the real} \\indented{1}{solutions of the list \\spad{lp} of polynomials with integer} \\indented{1}{coefficients with respect to the variables in lv,} \\indented{1}{with precision eps.} \\blankline \\spad{X} \\spad{p1} \\spad{:=} x**2*y*z + \\spad{y*z} \\spad{X} \\spad{p2} \\spad{:=} x**2*y**2*z + \\spad{x} + \\spad{z} \\spad{X} \\spad{p3} \\spad{:=} \\spad{x**2*y**2*z**2} + \\spad{z} + 1 \\spad{X} \\spad{lp} \\spad{:=} [p1, \\spad{p2,} \\spad{p3]} \\spad{X} realSolve(lp,[x,y,z],0.01)")) (|solve| (((|List| (|Float|)) (|Polynomial| (|Integer|)) (|Float|)) "\\indented{1}{solve(p,eps) finds the real zeroes of a univariate} \\indented{1}{integer polynomial \\spad{p} with precision eps.} \\blankline \\spad{X} \\spad{p} \\spad{:=} 4*x^3 - 3*x^2 + 2*x - 4 \\spad{X} solve(p,0.01)$REALSOLV") (((|List| (|Float|)) (|Polynomial| (|Fraction| (|Integer|))) (|Float|)) "\\indented{1}{solve(p,eps) finds the real zeroes of a} \\indented{1}{univariate rational polynomial \\spad{p} with precision eps.} \\blankline \\spad{X} \\spad{p} \\spad{:=} 4*x^3 - 3*x^2 + 2*x - 4 \\spad{X} solve(p::POLY(FRAC(INT)),0.01)$REALSOLV"))) 
 NIL 
 NIL 
-(-1030 |TheField|) 
+(-1051 |TheField|) 
 ((|constructor| (NIL "This domain implements the real closure of an ordered field.")) (|relativeApprox| (((|Fraction| (|Integer|)) $ $) "\\axiom{relativeApprox(n,p)} gives a relative approximation of \\axiom{n} that has precision \\axiom{p}")) (|mainCharacterization| (((|Union| (|RightOpenIntervalRootCharacterization| $ (|SparseUnivariatePolynomial| $)) "failed") $) "\\axiom{mainCharacterization(x)} is the main algebraic quantity of \\axiom{x} (\\axiom{SEG})")) (|algebraicOf| (($ (|RightOpenIntervalRootCharacterization| $ (|SparseUnivariatePolynomial| $)) (|OutputForm|)) "\\axiom{algebraicOf(char)} is the external number"))) 
-((-4595 . T) (-4600 . T) (-4594 . T) (-4597 . T) (-4596 . T) ((-4604 "*") . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-413 (-572)) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-413 (-572)) (LIST (QUOTE -1044) (QUOTE (-572)))) (-1841 (|HasCategory| (-413 (-572)) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))))) 
-(-1031 R -3313) 
+((-4618 . T) (-4623 . T) (-4617 . T) (-4620 . T) (-4619 . T) ((-4627 "*") . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-433 (-592)) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-433 (-592)) (LIST (QUOTE -1065) (QUOTE (-592)))) (-3836 (|HasCategory| (-433 (-592)) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))))) 
+(-1052 R -3958) 
 ((|constructor| (NIL "This package provides an operator for the \\spad{n}-th term of a recurrence and an operator for the coefficient of \\spad{x^n} in a function specified by a functional equation.")) (|getOp| (((|BasicOperator|) |#2|) "\\spad{getOp \\spad{f},} if \\spad{f} represents the coefficient of a recurrence or ADE, returns the operator representing the solution")) (|getEq| ((|#2| |#2|) "\\spad{getEq \\spad{f}} returns the defining equation, if \\spad{f} represents the coefficient of an ADE or a recurrence.")) (|evalADE| ((|#2| (|BasicOperator|) (|Symbol|) |#2| |#2| |#2| (|List| |#2|)) "\\spad{evalADE(f, dummy, \\spad{x,} \\spad{n,} eq, values)} creates an expression that stands for the coefficient of \\spad{x^n} in the Taylor expansion of f(x), where f(x) is given by the functional equation eq. However, for technical reasons the variable \\spad{x} has to be replaced by a \\spad{dummy} variable \\spad{dummy} in eq. The argument values specifies the first few Taylor coefficients.")) (|evalRec| ((|#2| (|BasicOperator|) (|Symbol|) |#2| |#2| |#2| (|List| |#2|)) "\\spad{evalRec(u, dummy, \\spad{n,} \\spad{n0,} eq, values)} creates an expression that stands for u(n0), where u(n) is given by the equation eq. However, for technical reasons the variable \\spad{n} has to be replaced by a \\spad{dummy} variable \\spad{dummy} in eq. The argument values specifies the initial values of the recurrence u(0), u(1),... For the moment we don't allow recursions that contain \\spad{u} inside of another operator."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-1054)))) 
-(-1032 -3313 L) 
+((|HasCategory| |#1| (QUOTE (-1075)))) 
+(-1053 -3958 L) 
 ((|constructor| (NIL "\\spadtype{ReductionOfOrder} provides functions for reducing the order of linear ordinary differential equations once some solutions are known.")) (|ReduceOrder| (((|Record| (|:| |eq| |#2|) (|:| |op| (|List| |#1|))) |#2| (|List| |#1|)) "\\spad{ReduceOrder(op, [f1,...,fk])} returns \\spad{[op1,[g1,...,gk]]} such that for any solution \\spad{z} of \\spad{op1 \\spad{z} = 0}, \\spad{y = \\spad{gk} \\int(g_{k-1} \\int(... \\int(g1 \\int z)...)} is a solution of \\spad{op \\spad{y} = 0}. Each \\spad{fi} must satisfy \\spad{op \\spad{fi} = 0}.") ((|#2| |#2| |#1|) "\\spad{ReduceOrder(op, \\spad{s)}} returns \\spad{op1} such that for any solution \\spad{z} of \\spad{op1 \\spad{z} = 0}, \\spad{y = \\spad{s} \\int \\spad{z}} is a solution of \\spad{op \\spad{y} = 0}. \\spad{s} must satisfy \\spad{op \\spad{s} = 0}."))) 
 NIL 
 NIL 
-(-1033 S) 
+(-1054 S) 
 ((|constructor| (NIL "\\spadtype{Reference} is for making a changeable instance of something.")) (= (((|Boolean|) $ $) "\\spad{a=b} tests if \\spad{a} and \\spad{b} are equal.")) (|setref| ((|#1| $ |#1|) "\\spad{setref(n,m)} same as \\spad{setelt(n,m)}.")) (|deref| ((|#1| $) "\\spad{deref(n)} is equivalent to \\spad{elt(n)}.")) (|setelt| ((|#1| $ |#1|) "\\spad{setelt(n,m)} changes the value of the object \\spad{n} to \\spad{m.}")) (|elt| ((|#1| $) "\\spad{elt(n)} returns the object \\spad{n.}")) (|ref| (($ |#1|) "\\spad{ref(n)} creates a pointer (reference) to the object \\spad{n.}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-1098)))) 
-(-1034 R E V P) 
+((|HasCategory| |#1| (QUOTE (-1119)))) 
+(-1055 R E V P) 
 ((|constructor| (NIL "This domain provides an implementation of regular chains. Moreover, the operation zeroSetSplit is an implementation of a new algorithm for solving polynomial systems by means of regular chains.")) (|preprocess| (((|Record| (|:| |val| (|List| |#4|)) (|:| |towers| (|List| $))) (|List| |#4|) (|Boolean|) (|Boolean|)) "\\axiom{pre_process(lp,b1,b2)} is an internal subroutine, exported only for developement.")) (|internalZeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{internalZeroSetSplit(lp,b1,b2,b3)} is an internal subroutine, exported only for developement.")) (|zeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{zeroSetSplit(lp,b1,b2.b3,b4)} is an internal subroutine, exported only for developement.") (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|)) "\\axiom{zeroSetSplit(lp,clos?,info?)} has the same specifications as zeroSetSplit from RegularTriangularSetCategory. Moreover, if \\axiom{clos?} then solves in the sense of the Zariski closure else solves in the sense of the regular zeros. If \\axiom{info?} then do print messages during the computations.")) (|internalAugment| (((|List| $) |#4| $ (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{internalAugment(p,ts,b1,b2,b3,b4,b5)} is an internal subroutine, exported only for developement."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#4| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#4| (QUOTE (-1098))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#3| (QUOTE (-374)))) 
-(-1035 R) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#4| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#4| (QUOTE (-1119))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#3| (QUOTE (-394)))) 
+(-1056 R) 
 ((|constructor| (NIL "\\spad{RepresentationPackage1} provides functions for representation theory for finite groups and algebras. The package creates permutation representations and uses tensor products and its symmetric and antisymmetric components to create new representations of larger degree from given ones. Note that instead of having parameters from \\spadtype{Permutation} this package allows list notation of permutations as well: \\spadignore{e.g.} \\spad{[1,4,3,2]} denotes permutes 2 and 4 and fixes 1 and 3.")) (|permutationRepresentation| (((|List| (|Matrix| (|Integer|))) (|List| (|List| (|Integer|)))) "\\spad{permutationRepresentation([pi1,...,pik],n)} returns the list of matrices [(deltai,pi1(i)),...,(deltai,pik(i))] if the permutations pi1,...,pik are in list notation and are permuting {1,2,...,n}.") (((|List| (|Matrix| (|Integer|))) (|List| (|Permutation| (|Integer|))) (|Integer|)) "\\spad{permutationRepresentation([pi1,...,pik],n)} returns the list of matrices [(deltai,pi1(i)),...,(deltai,pik(i))] (Kronecker delta) for the permutations pi1,...,pik of {1,2,...,n}.") (((|Matrix| (|Integer|)) (|List| (|Integer|))) "\\spad{permutationRepresentation(pi,n)} returns the matrix (deltai,pi(i)) (Kronecker delta) if the permutation \\spad{pi} is in list notation and permutes {1,2,...,n}.") (((|Matrix| (|Integer|)) (|Permutation| (|Integer|)) (|Integer|)) "\\spad{permutationRepresentation(pi,n)} returns the matrix (deltai,pi(i)) (Kronecker delta) for a permutation \\spad{pi} of {1,2,...,n}.")) (|tensorProduct| (((|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) "\\spad{tensorProduct([a1,...ak])} calculates the list of Kronecker products of each matrix \\spad{ai} with itself for \\spad{{1} \\spad{<=} \\spad{i} \\spad{<=} \\spad{k}.} Note that if the list of matrices corresponds to a group representation (repr. of generators) of one group, then these matrices correspond to the tensor product of the representation with itself.") (((|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{tensorProduct(a)} calculates the Kronecker product of the matrix a with itself.") (((|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) "\\spad{tensorProduct([a1,...,ak],[b1,...,bk])} calculates the list of Kronecker products of the matrices \\spad{ai} and \\spad{bi} for \\spad{{1} \\spad{<=} \\spad{i} \\spad{<=} \\spad{k}.} Note that if each list of matrices corresponds to a group representation (repr. of generators) of one group, then these matrices correspond to the tensor product of the two representations.") (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{tensorProduct(a,b)} calculates the Kronecker product of the matrices a and \\spad{b.} Note that if each matrix corresponds to a group representation (repr. of generators) of one group, then these matrices correspond to the tensor product of the two representations.")) (|symmetricTensors| (((|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|PositiveInteger|)) "\\spad{symmetricTensors(la,n)} applies to each m-by-m square matrix in the list \\spad{la} the irreducible, polynomial representation of the general linear group \\spad{GLm} which corresponds to the partition (n,0,...,0) of \\spad{n.} Error: if the matrices in \\spad{la} are not square matrices. Note that this corresponds to the symmetrization of the representation with the trivial representation of the symmetric group \\spad{Sn.} The carrier spaces of the representation are the symmetric tensors of the n-fold tensor product.") (((|Matrix| |#1|) (|Matrix| |#1|) (|PositiveInteger|)) "\\spad{symmetricTensors(a,n)} applies to the m-by-m square matrix a the irreducible, polynomial representation of the general linear group \\spad{GLm} which corresponds to the partition (n,0,...,0) of \\spad{n.} Error: if a is not a square matrix. Note that this corresponds to the symmetrization of the representation with the trivial representation of the symmetric group \\spad{Sn.} The carrier spaces of the representation are the symmetric tensors of the n-fold tensor product.")) (|createGenericMatrix| (((|Matrix| (|Polynomial| |#1|)) (|NonNegativeInteger|)) "\\spad{createGenericMatrix(m)} creates a square matrix of dimension \\spad{k} whose entry at the \\spad{i}-th row and \\spad{j}-th column is the indeterminate x[i,j] (double subscripted).")) (|antisymmetricTensors| (((|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|PositiveInteger|)) "\\spad{antisymmetricTensors(la,n)} applies to each m-by-m square matrix in the list \\spad{la} the irreducible, polynomial representation of the general linear group \\spad{GLm} which corresponds to the partition (1,1,...,1,0,0,...,0) of \\spad{n.} Error: if \\spad{n} is greater than \\spad{m.} Note that this corresponds to the symmetrization of the representation with the sign representation of the symmetric group \\spad{Sn.} The carrier spaces of the representation are the antisymmetric tensors of the n-fold tensor product.") (((|Matrix| |#1|) (|Matrix| |#1|) (|PositiveInteger|)) "\\spad{antisymmetricTensors(a,n)} applies to the square matrix a the irreducible, polynomial representation of the general linear group GLm, where \\spad{m} is the number of rows of a, which corresponds to the partition (1,1,...,1,0,0,...,0) of \\spad{n.} Error: if \\spad{n} is greater than \\spad{m.} Note that this corresponds to the symmetrization of the representation with the sign representation of the symmetric group \\spad{Sn.} The carrier spaces of the representation are the antisymmetric tensors of the n-fold tensor product."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE (-4604 "*")))) 
-(-1036 R) 
+((|HasAttribute| |#1| (QUOTE (-4627 "*")))) 
+(-1057 R) 
 ((|constructor| (NIL "\\spad{RepresentationPackage2} provides functions for working with modular representations of finite groups and algebra. The routines in this package are created, using ideas of \\spad{R.} Parker, (the meat-Axe) to get smaller representations from bigger ones, \\spadignore{i.e.} finding sub- and factormodules, or to show, that such the representations are irreducible. Note that most functions are randomized functions of Las Vegas type \\spadignore{i.e.} every answer is correct, but with small probability the algorithm fails to get an answer.")) (|scanOneDimSubspaces| (((|Vector| |#1|) (|List| (|Vector| |#1|)) (|Integer|)) "\\spad{scanOneDimSubspaces(basis,n)} gives a canonical representative of the \\spad{n}-th one-dimensional subspace of the vector space generated by the elements of basis, all from R**n. The coefficients of the representative are of shape (0,...,0,1,*,...,*), * in \\spad{R.} If the size of \\spad{R} is \\spad{q,} then there are (q**n-1)/(q-1) of them. We first reduce \\spad{n} modulo this number, then find the largest \\spad{i} such that +/[q**i for \\spad{i} in 0..i-1] \\spad{<=} \\spad{n.} Subtracting this sum of powers from \\spad{n} results in an i-digit number to \\spad{basis} \\spad{q.} This fills the positions of the stars.")) (|meatAxe| (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|PositiveInteger|)) "\\spad{meatAxe(aG, numberOfTries)} calls meatAxe(aG,true,numberOfTries,7). Notes: 7 covers the case of three-dimensional kernels over the field with 2 elements.") (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|Boolean|)) "\\spad{meatAxe(aG, randomElements)} calls meatAxe(aG,false,6,7), only using Parker's fingerprints, if randomElemnts is false. If it is true, it calls meatAxe(aG,true,25,7), only using random elements. Note that the choice of 25 was rather arbitrary. Also, 7 covers the case of three-dimensional kernels over the field with 2 elements.") (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|))) "\\spad{meatAxe(aG)} calls meatAxe(aG,false,25,7) returns a 2-list of representations as follows. All matrices of argument \\spad{aG} are assumed to be square and of equal size. Then \\spad{aG} generates a subalgebra, say \\spad{A}, of the algebra of all square matrices of dimension \\spad{n.} \\spad{V} \\spad{R} is an A-module in the usual way. meatAxe(aG) creates at most 25 random elements of the algebra, tests them for singularity. If singular, it tries at most 7 elements of its kernel to generate a proper submodule. If successful a list which contains first the list of the representations of the submodule, then a list of the representations of the factor module is returned. Otherwise, if we know that all the kernel is already scanned, Norton's irreducibility test can be used either to prove irreducibility or to find the splitting. Notes: the first 6 tries use Parker's fingerprints. Also, 7 covers the case of three-dimensional kernels over the field with 2 elements.") (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|Boolean|) (|Integer|) (|Integer|)) "\\spad{meatAxe(aG,randomElements,numberOfTries, maxTests)} returns a 2-list of representations as follows. All matrices of argument \\spad{aG} are assumed to be square and of equal size. Then \\spad{aG} generates a subalgebra, say \\spad{A}, of the algebra of all square matrices of dimension \\spad{n.} \\spad{V} \\spad{R} is an A-module in the usual way. meatAxe(aG,numberOfTries, maxTests) creates at most \\spad{numberOfTries} random elements of the algebra, tests them for singularity. If singular, it tries at most maxTests elements of its kernel to generate a proper submodule. If successful, a 2-list is returned: first, a list containing first the list of the representations of the submodule, then a list of the representations of the factor module. Otherwise, if we know that all the kernel is already scanned, Norton's irreducibility test can be used either to prove irreducibility or to find the splitting. If \\spad{randomElements} is false, the first 6 tries use Parker's fingerprints.")) (|split| (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|Vector| (|Vector| |#1|))) "\\spad{split(aG,submodule)} uses a proper \\spad{submodule} of R**n to create the representations of the \\spad{submodule} and of the factor module.") (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|Vector| |#1|)) "\\spad{split(aG, vector)} returns a subalgebra \\spad{A} of all square matrix of dimension \\spad{n} as a list of list of matrices, generated by the list of matrices aG, where \\spad{n} denotes both the size of vector as well as the dimension of each of the square matrices. \\spad{V} \\spad{R} is an A-module in the natural way. split(aG, vector) then checks whether the cyclic submodule generated by vector is a proper submodule of \\spad{V} \\spad{R.} If successful, it returns a two-element list, which contains first the list of the representations of the submodule, then the list of the representations of the factor module. If the vector generates the whole module, a one-element list of the old representation is given. Note that a later version this should call the other split.")) (|isAbsolutelyIrreducible?| (((|Boolean|) (|List| (|Matrix| |#1|))) "\\spad{isAbsolutelyIrreducible?(aG)} calls isAbsolutelyIrreducible?(aG,25). Note that the choice of 25 was rather arbitrary.") (((|Boolean|) (|List| (|Matrix| |#1|)) (|Integer|)) "\\spad{isAbsolutelyIrreducible?(aG, numberOfTries)} uses Norton's irreducibility test to check for absolute irreduciblity, assuming if a one-dimensional kernel is found. As no field extension changes create \"new\" elements in a one-dimensional space, the criterium stays \\spad{true} for every extension. The method looks for one-dimensionals only by creating random elements (no fingerprints) since a run of meatAxe would have proved absolute irreducibility anyway.")) (|areEquivalent?| (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|Integer|)) "\\spad{areEquivalent?(aG0,aG1,numberOfTries)} calls areEquivalent?(aG0,aG1,true,25). Note that the choice of 25 was rather arbitrary.") (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) "\\spad{areEquivalent?(aG0,aG1)} calls areEquivalent?(aG0,aG1,true,25). Note that the choice of 25 was rather arbitrary.") (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|Boolean|) (|Integer|)) "\\spad{areEquivalent?(aG0,aG1,randomelements,numberOfTries)} tests whether the two lists of matrices, all assumed of same square shape, can be simultaneously conjugated by a non-singular matrix. If these matrices represent the same group generators, the representations are equivalent. The algorithm tries \\spad{numberOfTries} times to create elements in the generated algebras in the same fashion. If their ranks differ, they are not equivalent. If an isomorphism is assumed, then the kernel of an element of the first algebra is mapped to the kernel of the corresponding element in the second algebra. Now consider the one-dimensional ones. If they generate the whole space (\\spadignore{e.g.} irreducibility \\spad{!)} we use standardBasisOfCyclicSubmodule to create the only possible transition matrix. The method checks whether the matrix conjugates all corresponding matrices from aGi. The way to choose the singular matrices is as in meatAxe. If the two representations are equivalent, this routine returns the transformation matrix \\spad{TM} with aG0.i * \\spad{TM} = \\spad{TM} * aG1.i for all i. If the representations are not equivalent, a small 0-matrix is returned. Note that the case with different sets of group generators cannot be handled.")) (|standardBasisOfCyclicSubmodule| (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|Vector| |#1|)) "\\spad{standardBasisOfCyclicSubmodule(lm,v)} returns a matrix as follows. It is assumed that the size \\spad{n} of the vector equals the number of rows and columns of the matrices. Then the matrices generate a subalgebra, say \\spad{A}, of the algebra of all square matrices of dimension \\spad{n.} \\spad{V} \\spad{R} is an \\spad{A}-module in the natural way. standardBasisOfCyclicSubmodule(lm,v) calculates a matrix whose non-zero column vectors are the R-Basis of Av achieved in the way as described in section 6 of \\spad{R.} A. Parker's \"The Meat-Axe\". Note that in contrast to cyclicSubmodule, the result is not in echelon form.")) (|cyclicSubmodule| (((|Vector| (|Vector| |#1|)) (|List| (|Matrix| |#1|)) (|Vector| |#1|)) "\\spad{cyclicSubmodule(lm,v)} generates a basis as follows. It is assumed that the size \\spad{n} of the vector equals the number of rows and columns of the matrices. Then the matrices generate a subalgebra, say \\spad{A}, of the algebra of all square matrices of dimension \\spad{n.} \\spad{V} \\spad{R} is an \\spad{A}-module in the natural way. cyclicSubmodule(lm,v) generates the R-Basis of Av as described in section 6 of \\spad{R.} A. Parker's \"The Meat-Axe\". Note that in contrast to the description in \"The Meat-Axe\" and to standardBasisOfCyclicSubmodule the result is in echelon form.")) (|createRandomElement| (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|Matrix| |#1|)) "\\spad{createRandomElement(aG,x)} creates a random element of the group algebra generated by aG.")) (|completeEchelonBasis| (((|Matrix| |#1|) (|Vector| (|Vector| |#1|))) "\\spad{completeEchelonBasis(lv)} completes the basis \\spad{lv} assumed to be in echelon form of a subspace of R**n \\spad{(n} the length of all the vectors in \\spad{lv} with unit vectors to a basis of R**n. It is assumed that the argument is not an empty vector and that it is not the basis of the 0-subspace. Note that the rows of the result correspond to the vectors of the basis."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-374)))) (|HasCategory| |#1| (QUOTE (-303)))) 
-(-1037 S) 
+((|HasCategory| |#1| (QUOTE (-388))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-394)))) (|HasCategory| |#1| (QUOTE (-323)))) 
+(-1058 S) 
 ((|constructor| (NIL "Implements multiplication by repeated addition")) (|double| ((|#1| (|PositiveInteger|) |#1|) "\\spad{double(i, \\spad{r)}} multiplies \\spad{r} by \\spad{i} using repeated doubling.")) (+ (($ $ $) "\\spad{x+y} returns the sum of \\spad{x} and \\spad{y}"))) 
 NIL 
 NIL 
-(-1038) 
+(-1059) 
 ((|constructor| (NIL "Package for the computation of eigenvalues and eigenvectors. This package works for matrices with coefficients which are rational functions over the integers. (see \\spadtype{Fraction Polynomial Integer}). The eigenvalues and eigenvectors are expressed in terms of radicals.")) (|orthonormalBasis| (((|List| (|Matrix| (|Expression| (|Integer|)))) (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{orthonormalBasis(m)} returns the orthogonal matrix \\spad{b} such that \\spad{b*m*(inverse \\spad{b)}} is diagonal. Error: if \\spad{m} is not a symmetric matrix.")) (|gramschmidt| (((|List| (|Matrix| (|Expression| (|Integer|)))) (|List| (|Matrix| (|Expression| (|Integer|))))) "\\spad{gramschmidt(lv)} converts the list of column vectors \\spad{lv} into a set of orthogonal column vectors of euclidean length 1 using the Gram-Schmidt algorithm.")) (|normalise| (((|Matrix| (|Expression| (|Integer|))) (|Matrix| (|Expression| (|Integer|)))) "\\spad{normalise(v)} returns the column vector \\spad{v} divided by its euclidean norm; when possible, the vector \\spad{v} is expressed in terms of radicals.")) (|eigenMatrix| (((|Union| (|Matrix| (|Expression| (|Integer|))) "failed") (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{eigenMatrix(m)} returns the matrix \\spad{b} such that \\spad{b*m*(inverse \\spad{b)}} is diagonal, or \"failed\" if no such \\spad{b} exists.")) (|radicalEigenvalues| (((|List| (|Expression| (|Integer|))) (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{radicalEigenvalues(m)} computes the eigenvalues of the matrix \\spad{m;} when possible, the eigenvalues are expressed in terms of radicals.")) (|radicalEigenvector| (((|List| (|Matrix| (|Expression| (|Integer|)))) (|Expression| (|Integer|)) (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{radicalEigenvector(c,m)} computes the eigenvector(s) of the matrix \\spad{m} corresponding to the eigenvalue \\spad{c;} when possible, values are expressed in terms of radicals.")) (|radicalEigenvectors| (((|List| (|Record| (|:| |radval| (|Expression| (|Integer|))) (|:| |radmult| (|Integer|)) (|:| |radvect| (|List| (|Matrix| (|Expression| (|Integer|))))))) (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) "\\spad{radicalEigenvectors(m)} computes the eigenvalues and the corresponding eigenvectors of the matrix \\spad{m;} when possible, values are expressed in terms of radicals."))) 
 NIL 
 NIL 
-(-1039 S) 
+(-1060 S) 
 ((|constructor| (NIL "Implements exponentiation by repeated squaring")) (|expt| ((|#1| |#1| (|PositiveInteger|)) "\\spad{expt(r, i)} computes r**i by repeated squaring")) (* (($ $ $) "\\spad{x*y} returns the product of \\spad{x} and \\spad{y}"))) 
 NIL 
 NIL 
-(-1040 S) 
+(-1061 S) 
 ((|constructor| (NIL "This package provides coercions for the special types \\spadtype{Exit} and \\spadtype{Void}.")) (|coerce| ((|#1| (|Exit|)) "\\spad{coerce(e)} is never really evaluated. This coercion is used for formal type correctness when a function will not return directly to its caller.") (((|Void|) |#1|) "\\spad{coerce(s)} throws all information about \\spad{s} away. This coercion allows values of any type to appear in contexts where they will not be used. For example, it allows the resolution of different types in the \\spad{then} and \\spad{else} branches when an \\spad{if} is in a context where the resulting value is not used."))) 
 NIL 
 NIL 
-(-1041 -3313 |Expon| |VarSet| |FPol| |LFPol|) 
+(-1062 -3958 |Expon| |VarSet| |FPol| |LFPol|) 
 ((|constructor| (NIL "ResidueRing is the quotient of a polynomial ring by an ideal. The ideal is given as a list of generators. The elements of the domain are equivalence classes expressed in terms of reduced elements")) (|lift| ((|#4| $) "\\spad{lift(x)} return the canonical representative of the equivalence class \\spad{x}")) (|coerce| (($ |#4|) "\\spad{coerce(f)} produces the equivalence class of \\spad{f} in the residue ring")) (|reduce| (($ |#4|) "\\spad{reduce(f)} produces the equivalence class of \\spad{f} in the residue ring"))) 
-(((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1042) 
+(-1063) 
 ((|constructor| (NIL "A domain used to return the results from a call to the NAG Library. It prints as a list of names and types, though the user may choose to display values automatically if he or she wishes.")) (|showArrayValues| (((|Boolean|) (|Boolean|)) "\\spad{showArrayValues(true)} forces the values of array components to be \\indented{1}{displayed rather than just their types.}")) (|showScalarValues| (((|Boolean|) (|Boolean|)) "\\spad{showScalarValues(true)} forces the values of scalar components to be \\indented{1}{displayed rather than just their types.}"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (QUOTE (-1170))) (LIST (QUOTE |:|) (QUOTE -4320) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (QUOTE (-1098)))) (|HasCategory| (-1170) (QUOTE (-848))) (|HasCategory| (-57) (QUOTE (-1098))) (-1841 (|HasCategory| (-57) (QUOTE (-1098))) (|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (QUOTE (-1098)))) (-12 (|HasCategory| (-57) (LIST (QUOTE -305) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1098))))) 
-(-1043 A S) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (QUOTE (-1191))) (LIST (QUOTE |:|) (QUOTE -3552) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (QUOTE (-1119)))) (|HasCategory| (-1191) (QUOTE (-869))) (|HasCategory| (-57) (QUOTE (-1119))) (-3836 (|HasCategory| (-57) (QUOTE (-1119))) (|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (QUOTE (-1119)))) (-12 (|HasCategory| (-57) (LIST (QUOTE -325) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1119))))) 
+(-1064 A S) 
 ((|constructor| (NIL "A is retractable to \\spad{B} means that some elements if A can be converted into elements of \\spad{B} and any element of \\spad{B} can be converted into an element of A.")) (|retract| ((|#2| $) "\\spad{retract(a)} transforms a into an element of \\spad{S} if possible. Error: if a cannot be made into an element of \\spad{S.}")) (|retractIfCan| (((|Union| |#2| "failed") $) "\\spad{retractIfCan(a)} transforms a into an element of \\spad{S} if possible. Returns \"failed\" if a cannot be made into an element of \\spad{S.}")) (|coerce| (($ |#2|) "\\spad{coerce(a)} transforms a into an element of \\spad{%.}"))) 
 NIL 
 NIL 
-(-1044 S) 
+(-1065 S) 
 ((|constructor| (NIL "A is retractable to \\spad{B} means that some elements if A can be converted into elements of \\spad{B} and any element of \\spad{B} can be converted into an element of A.")) (|retract| ((|#1| $) "\\spad{retract(a)} transforms a into an element of \\spad{S} if possible. Error: if a cannot be made into an element of \\spad{S.}")) (|retractIfCan| (((|Union| |#1| "failed") $) "\\spad{retractIfCan(a)} transforms a into an element of \\spad{S} if possible. Returns \"failed\" if a cannot be made into an element of \\spad{S.}")) (|coerce| (($ |#1|) "\\spad{coerce(a)} transforms a into an element of \\spad{%.}"))) 
 NIL 
 NIL 
-(-1045 Q R) 
+(-1066 Q R) 
 ((|constructor| (NIL "RetractSolvePackage is an interface to \\spadtype{SystemSolvePackage} that attempts to retract the coefficients of the equations before solving.")) (|solveRetract| (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#2|))))) (|List| (|Polynomial| |#2|)) (|List| (|Symbol|))) "\\spad{solveRetract(lp,lv)} finds the solutions of the list \\spad{lp} of rational functions with respect to the list of symbols \\spad{lv.} The function tries to retract all the coefficients of the equations to \\spad{Q} before solving if possible."))) 
 NIL 
 NIL 
-(-1046) 
+(-1067) 
 ((|t| (((|Mapping| (|Float|)) (|NonNegativeInteger|)) "\\spad{t(n)} \\undocumented")) (F (((|Mapping| (|Float|)) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{F(n,m)} \\undocumented")) (|Beta| (((|Mapping| (|Float|)) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{Beta(n,m)} \\undocumented")) (|chiSquare| (((|Mapping| (|Float|)) (|NonNegativeInteger|)) "\\spad{chiSquare(n)} \\undocumented")) (|exponential| (((|Mapping| (|Float|)) (|Float|)) "\\spad{exponential(f)} \\undocumented")) (|normal| (((|Mapping| (|Float|)) (|Float|) (|Float|)) "\\spad{normal(f,g)} \\undocumented")) (|uniform| (((|Mapping| (|Float|)) (|Float|) (|Float|)) "\\spad{uniform(f,g)} \\undocumented")) (|chiSquare1| (((|Float|) (|NonNegativeInteger|)) "\\spad{chiSquare1(n)} \\undocumented")) (|exponential1| (((|Float|)) "\\spad{exponential1()} \\undocumented")) (|normal01| (((|Float|)) "\\spad{normal01()} \\undocumented")) (|uniform01| (((|Float|)) "\\spad{uniform01()} \\undocumented"))) 
 NIL 
 NIL 
-(-1047 UP) 
+(-1068 UP) 
 ((|constructor| (NIL "Factorization of univariate polynomials with coefficients which are rational functions with integer coefficients.")) (|factor| (((|Factored| |#1|) |#1|) "\\spad{factor(p)} returns a prime factorisation of \\spad{p.}"))) 
 NIL 
 NIL 
-(-1048 R) 
+(-1069 R) 
 ((|constructor| (NIL "\\spadtype{RationalFunctionFactorizer} contains the factor function (called factorFraction) which factors fractions of polynomials by factoring the numerator and denominator. Since any non zero fraction is a unit the usual factor operation will just return the original fraction.")) (|factorFraction| (((|Fraction| (|Factored| (|Polynomial| |#1|))) (|Fraction| (|Polynomial| |#1|))) "\\spad{factorFraction(r)} factors the numerator and the denominator of the polynomial fraction \\spad{r.}"))) 
 NIL 
 NIL 
-(-1049 R) 
+(-1070 R) 
 ((|constructor| (NIL "Utilities that provide the same top-level manipulations on fractions than on polynomials.")) (|coerce| (((|Fraction| (|Polynomial| |#1|)) |#1|) "\\spad{coerce(r)} returns \\spad{r} viewed as a rational function over \\spad{R.}")) (|eval| (((|Fraction| (|Polynomial| |#1|)) (|Fraction| (|Polynomial| |#1|)) (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) "\\spad{eval(f, \\spad{[v1} = g1,...,vn = gn])} returns \\spad{f} with each \\spad{vi} replaced by \\spad{gi} in parallel, \\spadignore{i.e.} vi's appearing inside the gi's are not replaced. Error: if any \\spad{vi} is not a symbol.") (((|Fraction| (|Polynomial| |#1|)) (|Fraction| (|Polynomial| |#1|)) (|Equation| (|Fraction| (|Polynomial| |#1|)))) "\\spad{eval(f, \\spad{v} = \\spad{g)}} returns \\spad{f} with \\spad{v} replaced by \\spad{g.} Error: if \\spad{v} is not a symbol.") (((|Fraction| (|Polynomial| |#1|)) (|Fraction| (|Polynomial| |#1|)) (|List| (|Symbol|)) (|List| (|Fraction| (|Polynomial| |#1|)))) "\\spad{eval(f, [v1,...,vn], [g1,...,gn])} returns \\spad{f} with each \\spad{vi} replaced by \\spad{gi} in parallel, \\spadignore{i.e.} vi's appearing inside the gi's are not replaced.") (((|Fraction| (|Polynomial| |#1|)) (|Fraction| (|Polynomial| |#1|)) (|Symbol|) (|Fraction| (|Polynomial| |#1|))) "\\spad{eval(f, \\spad{v,} \\spad{g)}} returns \\spad{f} with \\spad{v} replaced by \\spad{g.}")) (|multivariate| (((|Fraction| (|Polynomial| |#1|)) (|Fraction| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|)))) (|Symbol|)) "\\spad{multivariate(f, \\spad{v)}} applies both the numerator and denominator of \\spad{f} to \\spad{v.}")) (|univariate| (((|Fraction| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|)))) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{univariate(f, \\spad{v)}} returns \\spad{f} viewed as a univariate rational function in \\spad{v.}")) (|mainVariable| (((|Union| (|Symbol|) "failed") (|Fraction| (|Polynomial| |#1|))) "\\spad{mainVariable(f)} returns the highest variable appearing in the numerator or the denominator of \\spad{f,} \"failed\" if \\spad{f} has no variables.")) (|variables| (((|List| (|Symbol|)) (|Fraction| (|Polynomial| |#1|))) "\\spad{variables(f)} returns the list of variables appearing in the numerator or the denominator of \\spad{f.}"))) 
 NIL 
 NIL 
-(-1050 K) 
+(-1071 K) 
 ((|constructor| (NIL "This pacackage finds all the roots of a polynomial. If the constant field is not large enough then it returns the list of found zeros and the degree of the extension need to find the other roots missing. If the return degree is 1 then all the roots have been found. If 0 is return for the extension degree then there are an infinite number of zeros, that is you ask for the zeroes of 0. In the case of infinite field a list of all found zeros is kept and for each other call of a function that finds zeroes, a check is made on that list; this is to keep a kind of \"canonical\" representation of the elements.")) (|setFoundZeroes| (((|List| |#1|) (|List| |#1|)) "\\spad{setFoundZeroes sets} the list of foundZeroes to the given one.")) (|foundZeroes| (((|List| |#1|)) "\\spad{foundZeroes returns} the list of already found zeros by the functions distinguishedRootsOf and distinguishedCommonRootsOf.")) (|distinguishedCommonRootsOf| (((|Record| (|:| |zeros| (|List| |#1|)) (|:| |extDegree| (|Integer|))) (|List| (|SparseUnivariatePolynomial| |#1|)) |#1|) "\\spad{distinguishedCommonRootsOf returns} the common zeros of a list of polynomial. It returns a record as in distinguishedRootsOf. If 0 is returned as extension degree then there are an infinite number of common zeros (in this case, the polynomial 0 was given in the list of input polynomials).")) (|distinguishedRootsOf| (((|Record| (|:| |zeros| (|List| |#1|)) (|:| |extDegree| (|Integer|))) (|SparseUnivariatePolynomial| |#1|) |#1|) "\\spad{distinguishedRootsOf returns} a record consisting of a list of zeros of the input polynomial followed by the smallest extension degree needed to find all the zeros. If \\spad{K} has \\spad{PseudoAlgebraicClosureOfFiniteFieldCategory} or \\spad{PseudoAlgebraicClosureOfRationalNumberCategory} then a root is created for each irreducible factor, and only these roots are returns and not their conjugate."))) 
 NIL 
 NIL 
-(-1051 R |ls|) 
+(-1072 R |ls|) 
 ((|constructor| (NIL "A domain for regular chains (\\spadignore{i.e.} regular triangular sets) over a Gcd-Domain and with a fix list of variables. This is just a front-end for the \\spadtype{RegularTriangularSet} domain constructor.")) (|zeroSetSplit| (((|List| $) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|) (|Boolean|)) "\\spad{zeroSetSplit(lp,clos?,info?)} returns a list \\spad{lts} of regular chains such that the union of the closures of their regular zero sets equals the affine variety associated with \\spad{lp}. Moreover, if \\spad{clos?} is \\spad{false} then the union of the regular zero set of the \\spad{ts} (for \\spad{ts} in \\spad{lts}) equals this variety. If \\spad{info?} is \\spad{true} then some information is displayed during the computations. See zeroSetSplit from RegularTriangularSet."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-781 |#1| (-858 |#2|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-781 |#1| (-858 |#2|)) (QUOTE (-1098))) (-12 (|HasCategory| (-781 |#1| (-858 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -781) (|devaluate| |#1|) (LIST (QUOTE -858) (|devaluate| |#2|))))) (|HasCategory| (-781 |#1| (-858 |#2|)) (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| (-858 |#2|) (QUOTE (-374)))) 
-(-1052) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-802 |#1| (-879 |#2|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-802 |#1| (-879 |#2|)) (QUOTE (-1119))) (-12 (|HasCategory| (-802 |#1| (-879 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -802) (|devaluate| |#1|) (LIST (QUOTE -879) (|devaluate| |#2|))))) (|HasCategory| (-802 |#1| (-879 |#2|)) (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| (-879 |#2|) (QUOTE (-394)))) 
+(-1073) 
 ((|constructor| (NIL "This package exports integer distributions")) (|ridHack1| (((|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{ridHack1(i,j,k,l)} \\undocumented")) (|geometric| (((|Mapping| (|Integer|)) |RationalNumber|) "\\spad{geometric(f)} \\undocumented")) (|poisson| (((|Mapping| (|Integer|)) |RationalNumber|) "\\spad{poisson(f)} \\undocumented")) (|binomial| (((|Mapping| (|Integer|)) (|Integer|) |RationalNumber|) "\\spad{binomial(n,f)} \\undocumented")) (|uniform| (((|Mapping| (|Integer|)) (|Segment| (|Integer|))) "\\spad{uniform(s)} as \\indented{4}{l + \\spad{u0} + \\spad{w*u1} + \\spad{w**2*u2} +...+ \\spad{w**(n-1)*u-1} + w**n*m} where \\indented{4}{s = a..b} \\indented{4}{l = min(a,b)} \\indented{4}{m = abs(b-a) + 1} \\indented{4}{w**n < \\spad{m} < w**(n+1)} \\indented{4}{u0,...,un-1\\space{2}are uniform on\\space{2}0..w-1} \\indented{4}{m\\space{12}is\\space{2}uniform on\\space{2}0..(m quo w**n)-1}"))) 
 NIL 
 NIL 
-(-1053 S) 
+(-1074 S) 
 ((|constructor| (NIL "The category of rings with unity, always associative, but not necessarily commutative.")) (|unitsKnown| ((|attribute|) "recip truly yields reciprocal or \"failed\" if not a unit. Note that \\spad{recip(0) = \"failed\"}.")) (|coerce| (($ (|Integer|)) "\\spad{coerce(i)} converts the integer \\spad{i} to a member of the given domain.")) (|characteristic| (((|NonNegativeInteger|)) "\\spad{characteristic()} returns the characteristic of the ring this is the smallest positive integer \\spad{n} such that \\spad{n*x=0} for all \\spad{x} in the ring, or zero if no such \\spad{n} exists."))) 
 NIL 
 NIL 
-(-1054) 
+(-1075) 
 ((|constructor| (NIL "The category of rings with unity, always associative, but not necessarily commutative.")) (|unitsKnown| ((|attribute|) "recip truly yields reciprocal or \"failed\" if not a unit. Note that \\spad{recip(0) = \"failed\"}.")) (|coerce| (($ (|Integer|)) "\\spad{coerce(i)} converts the integer \\spad{i} to a member of the given domain.")) (|characteristic| (((|NonNegativeInteger|)) "\\spad{characteristic()} returns the characteristic of the ring this is the smallest positive integer \\spad{n} such that \\spad{n*x=0} for all \\spad{x} in the ring, or zero if no such \\spad{n} exists."))) 
-((-4599 . T)) 
+((-4622 . T)) 
 NIL 
-(-1055 |xx| -3313) 
+(-1076 |xx| -3958) 
 ((|constructor| (NIL "This package exports rational interpolation algorithms"))) 
 NIL 
 NIL 
-(-1056 S |m| |n| R |Row| |Col|) 
+(-1077 S |m| |n| R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{RectangularMatrixCategory} is a category of matrices of fixed dimensions. The dimensions of the matrix will be parameters of the domain. Domains in this category will be R-modules and will be non-mutable.")) (|nullSpace| (((|List| |#6|) $) "\\spad{nullSpace(m)}+ returns a basis for the null space of the matrix \\spad{m.}")) (|nullity| (((|NonNegativeInteger|) $) "\\spad{nullity(m)} returns the nullity of the matrix \\spad{m.} This is the dimension of the null space of the matrix \\spad{m.}")) (|rank| (((|NonNegativeInteger|) $) "\\spad{rank(m)} returns the rank of the matrix \\spad{m.}")) (|rowEchelon| (($ $) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m.}")) (/ (($ $ |#4|) "\\spad{m/r} divides the elements of \\spad{m} by \\spad{r.} Error: if \\spad{r = 0}.")) (|exquo| (((|Union| $ "failed") $ |#4|) "\\spad{exquo(m,r)} computes the exact quotient of the elements of \\spad{m} by \\spad{r,} returning \\axiom{\"failed\"} if this is not possible.")) (|map| (($ (|Mapping| |#4| |#4| |#4|) $ $) "\\spad{map(f,a,b)} returns \\spad{c,} where \\spad{c} is such that \\spad{c(i,j) = f(a(i,j),b(i,j))} for all \\spad{i}, \\spad{j.}") (($ (|Mapping| |#4| |#4|) $) "\\spad{map(f,a)} returns \\spad{b,} where \\spad{b(i,j) = a(i,j)} for all i, \\spad{j.}")) (|column| ((|#6| $ (|Integer|)) "\\spad{column(m,j)} returns the \\spad{j}th column of the matrix \\spad{m.} Error: if the index outside the proper range.")) (|row| ((|#5| $ (|Integer|)) "\\spad{row(m,i)} returns the \\spad{i}th row of the matrix \\spad{m.} Error: if the index is outside the proper range.")) (|qelt| ((|#4| $ (|Integer|) (|Integer|)) "\\spad{qelt(m,i,j)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m.} Note that there is NO error check to determine if indices are in the proper ranges.")) (|elt| ((|#4| $ (|Integer|) (|Integer|) |#4|) "\\spad{elt(m,i,j,r)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m,} if \\spad{m} has an \\spad{i}th row and a \\spad{j}th column, and returns \\spad{r} otherwise.") ((|#4| $ (|Integer|) (|Integer|)) "\\spad{elt(m,i,j)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m.} Error: if indices are outside the proper ranges.")) (|listOfLists| (((|List| (|List| |#4|)) $) "\\spad{listOfLists(m)} returns the rows of the matrix \\spad{m} as a list of lists.")) (|ncols| (((|NonNegativeInteger|) $) "\\spad{ncols(m)} returns the number of columns in the matrix \\spad{m.}")) (|nrows| (((|NonNegativeInteger|) $) "\\spad{nrows(m)} returns the number of rows in the matrix \\spad{m.}")) (|maxColIndex| (((|Integer|) $) "\\spad{maxColIndex(m)} returns the index of the 'last' column of the matrix \\spad{m.}")) (|minColIndex| (((|Integer|) $) "\\spad{minColIndex(m)} returns the index of the 'first' column of the matrix \\spad{m.}")) (|maxRowIndex| (((|Integer|) $) "\\spad{maxRowIndex(m)} returns the index of the 'last' row of the matrix \\spad{m.}")) (|minRowIndex| (((|Integer|) $) "\\spad{minRowIndex(m)} returns the index of the 'first' row of the matrix \\spad{m.}")) (|antisymmetric?| (((|Boolean|) $) "\\spad{antisymmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and antisymmetric. That is, \\spad{m[i,j] = -m[j,i]} for all \\spad{i} and \\spad{j} and \\spad{false} otherwise.")) (|symmetric?| (((|Boolean|) $) "\\spad{symmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and symmetric (that is, \\spad{m[i,j] = m[j,i]} for all \\spad{i} and \\spad{j)} and \\spad{false} otherwise.")) (|diagonal?| (((|Boolean|) $) "\\spad{diagonal?(m)} returns \\spad{true} if the matrix \\spad{m} is square and diagonal (that is, all entries of \\spad{m} not on the diagonal are zero) and \\spad{false} otherwise.")) (|square?| (((|Boolean|) $) "\\spad{square?(m)} returns \\spad{true} if \\spad{m} is a square matrix (that is, if \\spad{m} has the same number of rows as columns) and \\spad{false} otherwise.")) (|matrix| (($ (|List| (|List| |#4|))) "\\spad{matrix(l)} converts the list of lists \\spad{l} to a matrix, where the list of lists is viewed as a list of the rows of the matrix.")) (|finiteAggregate| ((|attribute|) "matrices are finite"))) 
 NIL 
-((|HasCategory| |#4| (QUOTE (-303))) (|HasCategory| |#4| (QUOTE (-368))) (|HasCategory| |#4| (QUOTE (-562))) (|HasCategory| |#4| (QUOTE (-174)))) 
-(-1057 |m| |n| R |Row| |Col|) 
+((|HasCategory| |#4| (QUOTE (-323))) (|HasCategory| |#4| (QUOTE (-388))) (|HasCategory| |#4| (QUOTE (-582))) (|HasCategory| |#4| (QUOTE (-194)))) 
+(-1078 |m| |n| R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{RectangularMatrixCategory} is a category of matrices of fixed dimensions. The dimensions of the matrix will be parameters of the domain. Domains in this category will be R-modules and will be non-mutable.")) (|nullSpace| (((|List| |#5|) $) "\\spad{nullSpace(m)}+ returns a basis for the null space of the matrix \\spad{m.}")) (|nullity| (((|NonNegativeInteger|) $) "\\spad{nullity(m)} returns the nullity of the matrix \\spad{m.} This is the dimension of the null space of the matrix \\spad{m.}")) (|rank| (((|NonNegativeInteger|) $) "\\spad{rank(m)} returns the rank of the matrix \\spad{m.}")) (|rowEchelon| (($ $) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m.}")) (/ (($ $ |#3|) "\\spad{m/r} divides the elements of \\spad{m} by \\spad{r.} Error: if \\spad{r = 0}.")) (|exquo| (((|Union| $ "failed") $ |#3|) "\\spad{exquo(m,r)} computes the exact quotient of the elements of \\spad{m} by \\spad{r,} returning \\axiom{\"failed\"} if this is not possible.")) (|map| (($ (|Mapping| |#3| |#3| |#3|) $ $) "\\spad{map(f,a,b)} returns \\spad{c,} where \\spad{c} is such that \\spad{c(i,j) = f(a(i,j),b(i,j))} for all \\spad{i}, \\spad{j.}") (($ (|Mapping| |#3| |#3|) $) "\\spad{map(f,a)} returns \\spad{b,} where \\spad{b(i,j) = a(i,j)} for all i, \\spad{j.}")) (|column| ((|#5| $ (|Integer|)) "\\spad{column(m,j)} returns the \\spad{j}th column of the matrix \\spad{m.} Error: if the index outside the proper range.")) (|row| ((|#4| $ (|Integer|)) "\\spad{row(m,i)} returns the \\spad{i}th row of the matrix \\spad{m.} Error: if the index is outside the proper range.")) (|qelt| ((|#3| $ (|Integer|) (|Integer|)) "\\spad{qelt(m,i,j)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m.} Note that there is NO error check to determine if indices are in the proper ranges.")) (|elt| ((|#3| $ (|Integer|) (|Integer|) |#3|) "\\spad{elt(m,i,j,r)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m,} if \\spad{m} has an \\spad{i}th row and a \\spad{j}th column, and returns \\spad{r} otherwise.") ((|#3| $ (|Integer|) (|Integer|)) "\\spad{elt(m,i,j)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m.} Error: if indices are outside the proper ranges.")) (|listOfLists| (((|List| (|List| |#3|)) $) "\\spad{listOfLists(m)} returns the rows of the matrix \\spad{m} as a list of lists.")) (|ncols| (((|NonNegativeInteger|) $) "\\spad{ncols(m)} returns the number of columns in the matrix \\spad{m.}")) (|nrows| (((|NonNegativeInteger|) $) "\\spad{nrows(m)} returns the number of rows in the matrix \\spad{m.}")) (|maxColIndex| (((|Integer|) $) "\\spad{maxColIndex(m)} returns the index of the 'last' column of the matrix \\spad{m.}")) (|minColIndex| (((|Integer|) $) "\\spad{minColIndex(m)} returns the index of the 'first' column of the matrix \\spad{m.}")) (|maxRowIndex| (((|Integer|) $) "\\spad{maxRowIndex(m)} returns the index of the 'last' row of the matrix \\spad{m.}")) (|minRowIndex| (((|Integer|) $) "\\spad{minRowIndex(m)} returns the index of the 'first' row of the matrix \\spad{m.}")) (|antisymmetric?| (((|Boolean|) $) "\\spad{antisymmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and antisymmetric. That is, \\spad{m[i,j] = -m[j,i]} for all \\spad{i} and \\spad{j} and \\spad{false} otherwise.")) (|symmetric?| (((|Boolean|) $) "\\spad{symmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and symmetric (that is, \\spad{m[i,j] = m[j,i]} for all \\spad{i} and \\spad{j)} and \\spad{false} otherwise.")) (|diagonal?| (((|Boolean|) $) "\\spad{diagonal?(m)} returns \\spad{true} if the matrix \\spad{m} is square and diagonal (that is, all entries of \\spad{m} not on the diagonal are zero) and \\spad{false} otherwise.")) (|square?| (((|Boolean|) $) "\\spad{square?(m)} returns \\spad{true} if \\spad{m} is a square matrix (that is, if \\spad{m} has the same number of rows as columns) and \\spad{false} otherwise.")) (|matrix| (($ (|List| (|List| |#3|))) "\\spad{matrix(l)} converts the list of lists \\spad{l} to a matrix, where the list of lists is viewed as a list of the rows of the matrix.")) (|finiteAggregate| ((|attribute|) "matrices are finite"))) 
-((-4602 . T) (-3389 . T) (-4597 . T) (-4596 . T)) 
+((-4625 . T) (-2623 . T) (-4620 . T) (-4619 . T)) 
 NIL 
-(-1058 |m| |n| R) 
+(-1079 |m| |n| R) 
 ((|constructor| (NIL "\\spadtype{RectangularMatrix} is a matrix domain where the number of rows and the number of columns are parameters of the domain.")) (|coerce| (((|Matrix| |#3|) $) "\\spad{coerce(m)} converts a matrix of type \\spadtype{RectangularMatrix} to a matrix of type \\spad{Matrix}.")) (|rectangularMatrix| (($ (|Matrix| |#3|)) "\\spad{rectangularMatrix(m)} converts a matrix of type \\spadtype{Matrix} to a matrix of type \\spad{RectangularMatrix}."))) 
-((-4602 . T) (-4597 . T) (-4596 . T)) 
-((|HasCategory| |#3| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-1098))) (|HasCategory| |#3| (QUOTE (-303))) (|HasCategory| |#3| (QUOTE (-562))) (|HasCategory| |#3| (QUOTE (-174))) (-1841 (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-368)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-174)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-368)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1098)))))) 
-(-1059 |m| |n| R1 |Row1| |Col1| M1 R2 |Row2| |Col2| M2) 
+((-4625 . T) (-4620 . T) (-4619 . T)) 
+((|HasCategory| |#3| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-1119))) (|HasCategory| |#3| (QUOTE (-323))) (|HasCategory| |#3| (QUOTE (-582))) (|HasCategory| |#3| (QUOTE (-194))) (-3836 (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-388)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-194)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-388)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1119)))))) 
+(-1080 |m| |n| R1 |Row1| |Col1| M1 R2 |Row2| |Col2| M2) 
 ((|constructor| (NIL "\\spadtype{RectangularMatrixCategoryFunctions2} provides functions between two matrix domains. The functions provided are \\spadfun{map} and \\spadfun{reduce}.")) (|reduce| ((|#7| (|Mapping| |#7| |#3| |#7|) |#6| |#7|) "\\spad{reduce(f,m,r)} returns a matrix \\spad{n} where \\spad{n[i,j] = f(m[i,j],r)} for all indices spad{i} and \\spad{j}.")) (|map| ((|#10| (|Mapping| |#7| |#3|) |#6|) "\\spad{map(f,m)} applies the function \\spad{f} to the elements of the matrix \\spad{m}."))) 
 NIL 
 NIL 
-(-1060 R) 
+(-1081 R) 
 ((|constructor| (NIL "The category of right modules over an \\spad{rng} (ring not necessarily with unit). This is an abelian group which supports right multiplication by elements of the rng. \\blankline Axioms\\br \\tab{5}\\spad{x*(a*b) = (x*a)*b}\\br \\tab{5}\\spad{x*(a+b) = (x*a)+(x*b)}\\br \\tab{5}\\spad{(x+y)*x = (x*a)+(y*a)}")) (* (($ $ |#1|) "\\spad{x*r} returns the right multiplication of the module element \\spad{x} by the ring element \\spad{r.}"))) 
 NIL 
 NIL 
-(-1061) 
+(-1082) 
 ((|constructor| (NIL "The category of associative rings, not necessarily commutative, and not necessarily with a 1. This is a combination of an abelian group and a semigroup, with multiplication distributing over addition. \\blankline Axioms\\br \\tab{5}\\spad{ x*(y+z) = x*y + x*z}\\br \\tab{5}\\spad{ (x+y)*z = \\spad{x*z} + \\spad{y*z} } \\blankline Conditional attributes\\br \\tab{5}noZeroDivisors\\tab{5}\\spad{ ab = 0 \\spad{=>} \\spad{a=0} or b=0}"))) 
 NIL 
 NIL 
-(-1062 S) 
+(-1083 S) 
 ((|constructor| (NIL "The real number system category is intended as a model for the real numbers. The real numbers form an ordered normed field. Note that we have purposely not included \\spadtype{DifferentialRing} or the elementary functions (see \\spadtype{TranscendentalFunctionCategory}) in the definition.")) (|abs| (($ $) "\\spad{abs \\spad{x}} returns the absolute value of \\spad{x.}")) (|round| (($ $) "\\spad{round \\spad{x}} computes the integer closest to \\spad{x.}")) (|truncate| (($ $) "\\spad{truncate \\spad{x}} returns the integer between \\spad{x} and 0 closest to \\spad{x.}")) (|fractionPart| (($ $) "\\spad{fractionPart \\spad{x}} returns the fractional part of \\spad{x.}")) (|wholePart| (((|Integer|) $) "\\spad{wholePart \\spad{x}} returns the integer part of \\spad{x.}")) (|floor| (($ $) "\\spad{floor \\spad{x}} returns the largest integer \\spad{<= \\spad{x}.}")) (|ceiling| (($ $) "\\spad{ceiling \\spad{x}} returns the small integer \\spad{>= \\spad{x}.}")) (|norm| (($ $) "\\spad{norm \\spad{x}} returns the same as absolute value."))) 
 NIL 
 NIL 
-(-1063) 
+(-1084) 
 ((|constructor| (NIL "The real number system category is intended as a model for the real numbers. The real numbers form an ordered normed field. Note that we have purposely not included \\spadtype{DifferentialRing} or the elementary functions (see \\spadtype{TranscendentalFunctionCategory}) in the definition.")) (|abs| (($ $) "\\spad{abs \\spad{x}} returns the absolute value of \\spad{x.}")) (|round| (($ $) "\\spad{round \\spad{x}} computes the integer closest to \\spad{x.}")) (|truncate| (($ $) "\\spad{truncate \\spad{x}} returns the integer between \\spad{x} and 0 closest to \\spad{x.}")) (|fractionPart| (($ $) "\\spad{fractionPart \\spad{x}} returns the fractional part of \\spad{x.}")) (|wholePart| (((|Integer|) $) "\\spad{wholePart \\spad{x}} returns the integer part of \\spad{x.}")) (|floor| (($ $) "\\spad{floor \\spad{x}} returns the largest integer \\spad{<= \\spad{x}.}")) (|ceiling| (($ $) "\\spad{ceiling \\spad{x}} returns the small integer \\spad{>= \\spad{x}.}")) (|norm| (($ $) "\\spad{norm \\spad{x}} returns the same as absolute value."))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1064 |TheField| |ThePolDom|) 
+(-1085 |TheField| |ThePolDom|) 
 ((|constructor| (NIL "\\axiomType{RightOpenIntervalRootCharacterization} provides work with interval root coding.")) (|relativeApprox| ((|#1| |#2| $ |#1|) "\\axiom{relativeApprox(exp,c,p) = a} is relatively close to exp as a polynomial in \\spad{c} ip to precision \\spad{p}")) (|mightHaveRoots| (((|Boolean|) |#2| $) "\\axiom{mightHaveRoots(p,r)} is \\spad{false} if \\axiom{p.r} is not 0")) (|refine| (($ $) "\\axiom{refine(rootChar)} shrinks isolating interval around \\axiom{rootChar}")) (|middle| ((|#1| $) "\\axiom{middle(rootChar)} is the middle of the isolating interval")) (|size| ((|#1| $) "The size of the isolating interval")) (|right| ((|#1| $) "\\axiom{right(rootChar)} is the right bound of the isolating interval")) (|left| ((|#1| $) "\\axiom{left(rootChar)} is the left bound of the isolating interval"))) 
 NIL 
 NIL 
-(-1065) 
+(-1086) 
 ((|constructor| (NIL "\\spadtype{RomanNumeral} provides functions for converting integers to roman numerals.")) (|roman| (($ (|Integer|)) "\\spad{roman(n)} creates a roman numeral for \\spad{n.}") (($ (|Symbol|)) "\\spad{roman(n)} creates a roman numeral for symbol \\spad{n.}")) (|convert| (($ (|Symbol|)) "\\spad{convert(n)} creates a roman numeral for symbol \\spad{n.}")) (|noetherian| ((|attribute|) "ascending chain condition on ideals.")) (|canonicalsClosed| ((|attribute|) "two positives multiply to give positive.")) (|canonical| ((|attribute|) "mathematical equality is data structure equality."))) 
-((-4590 . T) (-4594 . T) (-4589 . T) (-4600 . T) (-4601 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4613 . T) (-4617 . T) (-4612 . T) (-4623 . T) (-4624 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1066) 
+(-1087) 
 ((|constructor| (NIL "\\axiomType{RoutinesTable} implements a database and associated tuning mechanisms for a set of known NAG routines")) (|recoverAfterFail| (((|Union| (|String|) "failed") $ (|String|) (|Integer|)) "\\spad{recoverAfterFail(routs,routineName,ifailValue)} acts on the instructions given by the ifail list")) (|showTheRoutinesTable| (($) "\\spad{showTheRoutinesTable()} returns the current table of NAG routines.")) (|deleteRoutine!| (($ $ (|Symbol|)) "\\spad{deleteRoutine!(R,s)} destructively deletes the given routine from the current database of NAG routines")) (|getExplanations| (((|List| (|String|)) $ (|String|)) "\\spad{getExplanations(R,s)} gets the explanations of the output parameters for the given NAG routine.")) (|getMeasure| (((|Float|) $ (|Symbol|)) "\\spad{getMeasure(R,s)} gets the current value of the maximum measure for the given NAG routine.")) (|changeMeasure| (($ $ (|Symbol|) (|Float|)) "\\spad{changeMeasure(R,s,newValue)} changes the maximum value for a measure of the given NAG routine.")) (|changeThreshhold| (($ $ (|Symbol|) (|Float|)) "\\spad{changeThreshhold(R,s,newValue)} changes the value below which, given a NAG routine generating a higher measure, the routines will make no attempt to generate a measure.")) (|selectMultiDimensionalRoutines| (($ $) "\\spad{selectMultiDimensionalRoutines(R)} chooses only those routines from the database which are designed for use with multi-dimensional expressions")) (|selectNonFiniteRoutines| (($ $) "\\spad{selectNonFiniteRoutines(R)} chooses only those routines from the database which are designed for use with non-finite expressions.")) (|selectSumOfSquaresRoutines| (($ $) "\\spad{selectSumOfSquaresRoutines(R)} chooses only those routines from the database which are designed for use with sums of squares")) (|selectFiniteRoutines| (($ $) "\\spad{selectFiniteRoutines(R)} chooses only those routines from the database which are designed for use with finite expressions")) (|selectODEIVPRoutines| (($ $) "\\spad{selectODEIVPRoutines(R)} chooses only those routines from the database which are for the solution of ODE's")) (|selectPDERoutines| (($ $) "\\spad{selectPDERoutines(R)} chooses only those routines from the database which are for the solution of PDE's")) (|selectOptimizationRoutines| (($ $) "\\spad{selectOptimizationRoutines(R)} chooses only those routines from the database which are for integration")) (|selectIntegrationRoutines| (($ $) "\\spad{selectIntegrationRoutines(R)} chooses only those routines from the database which are for integration")) (|routines| (($) "\\spad{routines()} initialises a database of known NAG routines")) (|concat| (($ $ $) "\\spad{concat(x,y)} merges two tables \\spad{x} and \\spad{y}"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (QUOTE (-1170))) (LIST (QUOTE |:|) (QUOTE -4320) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (QUOTE (-1098)))) (|HasCategory| (-1170) (QUOTE (-848))) (|HasCategory| (-57) (QUOTE (-1098))) (-1841 (|HasCategory| (-57) (QUOTE (-1098))) (|HasCategory| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (QUOTE (-1098)))) (-12 (|HasCategory| (-57) (LIST (QUOTE -305) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1098))))) 
-(-1067 S R E V) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (QUOTE (-1191))) (LIST (QUOTE |:|) (QUOTE -3552) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (QUOTE (-1119)))) (|HasCategory| (-1191) (QUOTE (-869))) (|HasCategory| (-57) (QUOTE (-1119))) (-3836 (|HasCategory| (-57) (QUOTE (-1119))) (|HasCategory| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (QUOTE (-1119)))) (-12 (|HasCategory| (-57) (LIST (QUOTE -325) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1119))))) 
+(-1088 S R E V) 
 ((|constructor| (NIL "\\indented{1}{Author: Marc Moreno Maza} Date Created: 04/22/1994 Date Last Updated: 14/12/1998 Description:")) (|mainSquareFreePart| (($ $) "\\axiom{mainSquareFreePart(p)} returns the square free part of \\axiom{p} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{R}.")) (|mainPrimitivePart| (($ $) "\\axiom{mainPrimitivePart(p)} returns the primitive part of \\axiom{p} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{R}.")) (|mainContent| (($ $) "\\axiom{mainContent(p)} returns the content of \\axiom{p} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{R}.")) (|primitivePart!| (($ $) "\\axiom{primitivePart!(p)} replaces \\axiom{p} by its primitive part.")) (|gcd| ((|#2| |#2| $) "\\axiom{gcd(r,p)} returns the \\spad{gcd} of \\axiom{r} and the content of \\axiom{p}.")) (|nextsubResultant2| (($ $ $ $ $) "\\axiom{nextsubResultant2(p,q,z,s)} is the multivariate version of the operation \\spad{next_sousResultant2} from PseudoRemainderSequence from the \\axiomType{PseudoRemainderSequence} constructor.")) (|LazardQuotient2| (($ $ $ $ (|NonNegativeInteger|)) "\\axiom{LazardQuotient2(p,a,b,n)} returns \\axiom{(a**(n-1) * \\spad{p)} exquo b**(n-1)} assuming that this quotient does not fail.")) (|LazardQuotient| (($ $ $ (|NonNegativeInteger|)) "\\axiom{LazardQuotient(a,b,n)} returns \\axiom{a**n exquo b**(n-1)} assuming that this quotient does not fail.")) (|lastSubResultant| (($ $ $) "\\axiom{lastSubResultant(a,b)} returns the last non-zero subresultant of \\axiom{a} and \\axiom{b} where \\axiom{a} and \\axiom{b} are assumed to have the same main variable \\axiom{v} and are viewed as univariate polynomials in \\axiom{v}.")) (|subResultantChain| (((|List| $) $ $) "\\axiom{subResultantChain(a,b)}, where \\axiom{a} and \\axiom{b} are not contant polynomials with the same main variable, returns the subresultant chain of \\axiom{a} and \\axiom{b}.")) (|resultant| (($ $ $) "\\axiom{resultant(a,b)} computes the resultant of \\axiom{a} and \\axiom{b} where \\axiom{a} and \\axiom{b} are assumed to have the same main variable \\axiom{v} and are viewed as univariate polynomials in \\axiom{v}.")) (|halfExtendedSubResultantGcd2| (((|Record| (|:| |gcd| $) (|:| |coef2| $)) $ $) "\\axiom{halfExtendedSubResultantGcd2(a,b)} returns \\axiom{[g,cb]} if \\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[g,ca,cb]} otherwise produces an error.")) (|halfExtendedSubResultantGcd1| (((|Record| (|:| |gcd| $) (|:| |coef1| $)) $ $) "\\axiom{halfExtendedSubResultantGcd1(a,b)} returns \\axiom{[g,ca]} if \\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[g,ca,cb]} otherwise produces an error.")) (|extendedSubResultantGcd| (((|Record| (|:| |gcd| $) (|:| |coef1| $) (|:| |coef2| $)) $ $) "\\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[ca,cb,r]} such that \\axiom{r} is \\axiom{subResultantGcd(a,b)} and we have \\axiom{ca * a + \\spad{cb} * \\spad{cb} = \\spad{r}} .")) (|subResultantGcd| (($ $ $) "\\axiom{subResultantGcd(a,b)} computes a \\spad{gcd} of \\axiom{a} and \\axiom{b} where \\axiom{a} and \\axiom{b} are assumed to have the same main variable \\axiom{v} and are viewed as univariate polynomials in \\axiom{v} with coefficients in the fraction field of the polynomial ring generated by their other variables over \\axiom{R}.")) (|exactQuotient!| (($ $ $) "\\axiom{exactQuotient!(a,b)} replaces \\axiom{a} by \\axiom{exactQuotient(a,b)}") (($ $ |#2|) "\\axiom{exactQuotient!(p,r)} replaces \\axiom{p} by \\axiom{exactQuotient(p,r)}.")) (|exactQuotient| (($ $ $) "\\axiom{exactQuotient(a,b)} computes the exact quotient of \\axiom{a} by \\axiom{b}, which is assumed to be a divisor of \\axiom{a}. No error is returned if this exact quotient fails!") (($ $ |#2|) "\\axiom{exactQuotient(p,r)} computes the exact quotient of \\axiom{p} by \\axiom{r}, which is assumed to be a divisor of \\axiom{p}. No error is returned if this exact quotient fails!")) (|primPartElseUnitCanonical!| (($ $) "\\axiom{primPartElseUnitCanonical!(p)} replaces \\axiom{p} by \\axiom{primPartElseUnitCanonical(p)}.")) (|primPartElseUnitCanonical| (($ $) "\\axiom{primPartElseUnitCanonical(p)} returns \\axiom{primitivePart(p)} if \\axiom{R} is a gcd-domain, otherwise \\axiom{unitCanonical(p)}.")) (|convert| (($ (|Polynomial| |#2|)) "\\axiom{convert(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}, otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{convert(p)} returns the same as \\axiom{retract(p)}.") (($ (|Polynomial| (|Integer|))) "\\axiom{convert(p)} returns the same as \\axiom{retract(p)}") (($ (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{convert(p)} returns the same as \\axiom{retract(p)}.")) (|retract| (($ (|Polynomial| |#2|)) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| |#2|)) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| |#2|)) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.")) (|retractIfCan| (((|Union| $ "failed") (|Polynomial| |#2|)) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| |#2|)) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| |#2|)) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.")) (|initiallyReduce| (($ $ $) "\\axiom{initiallyReduce(a,b)} returns a polynomial \\axiom{r} such that \\axiom{initiallyReduced?(r,b)} holds and there exists an integer \\axiom{e} such that \\axiom{init(b)^e a - \\spad{r}} is zero modulo \\axiom{b}.")) (|headReduce| (($ $ $) "\\axiom{headReduce(a,b)} returns a polynomial \\axiom{r} such that \\axiom{headReduced?(r,b)} holds and there exists an integer \\axiom{e} such that \\axiom{init(b)^e a - \\spad{r}} is zero modulo \\axiom{b}.")) (|lazyResidueClass| (((|Record| (|:| |polnum| $) (|:| |polden| $) (|:| |power| (|NonNegativeInteger|))) $ $) "\\axiom{lazyResidueClass(a,b)} returns \\axiom{[p,q,n]} where \\axiom{p / q**n} represents the residue class of \\axiom{a} modulo \\axiom{b} and \\axiom{p} is reduced w.r.t. \\axiom{b} and \\axiom{q} is \\axiom{init(b)}.")) (|monicModulo| (($ $ $) "\\axiom{monicModulo(a,b)} computes \\axiom{a mod \\spad{b},} if \\axiom{b} is monic as univariate polynomial in its main variable.")) (|pseudoDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{pseudoDivide(a,b)} computes \\axiom{[pquo(a,b),prem(a,b)]}, both polynomials viewed as univariate polynomials in the main variable of \\axiom{b}, if \\axiom{b} is not a constant polynomial.")) (|lazyPseudoDivide| (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $ |#4|) "\\axiom{lazyPseudoDivide(a,b,v)} returns \\axiom{[c,g,q,r]} such that \\axiom{r = lazyPrem(a,b,v)}, \\axiom{(c**g)*r = prem(a,b,v)} and \\axiom{q} is the pseudo-quotient computed in this lazy pseudo-division.") (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{lazyPseudoDivide(a,b)} returns \\axiom{[c,g,q,r]} such that \\axiom{[c,g,r] = lazyPremWithDefault(a,b)} and \\axiom{q} is the pseudo-quotient computed in this lazy pseudo-division.")) (|lazyPremWithDefault| (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| $)) $ $ |#4|) "\\axiom{lazyPremWithDefault(a,b,v)} returns \\axiom{[c,g,r]} such that \\axiom{r = lazyPrem(a,b,v)} and \\axiom{(c**g)*r = prem(a,b,v)}.") (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| $)) $ $) "\\axiom{lazyPremWithDefault(a,b)} returns \\axiom{[c,g,r]} such that \\axiom{r = lazyPrem(a,b)} and \\axiom{(c**g)*r = prem(a,b)}.")) (|lazyPquo| (($ $ $ |#4|) "\\axiom{lazyPquo(a,b,v)} returns the polynomial \\axiom{q} such that \\axiom{lazyPseudoDivide(a,b,v)} returns \\axiom{[c,g,q,r]}.") (($ $ $) "\\axiom{lazyPquo(a,b)} returns the polynomial \\axiom{q} such that \\axiom{lazyPseudoDivide(a,b)} returns \\axiom{[c,g,q,r]}.")) (|lazyPrem| (($ $ $ |#4|) "\\axiom{lazyPrem(a,b,v)} returns the polynomial \\axiom{r} reduced w.r.t. \\axiom{b} viewed as univariate polynomials in the variable \\axiom{v} such that \\axiom{b} divides \\axiom{init(b)^e a - \\spad{r}} where \\axiom{e} is the number of steps of this pseudo-division.") (($ $ $) "\\axiom{lazyPrem(a,b)} returns the polynomial \\axiom{r} reduced w.r.t. \\axiom{b} and such that \\axiom{b} divides \\axiom{init(b)^e a - \\spad{r}} where \\axiom{e} is the number of steps of this pseudo-division.")) (|pquo| (($ $ $ |#4|) "\\axiom{pquo(a,b,v)} computes the pseudo-quotient of \\axiom{a} by \\axiom{b}, both viewed as univariate polynomials in \\axiom{v}.") (($ $ $) "\\axiom{pquo(a,b)} computes the pseudo-quotient of \\axiom{a} by \\axiom{b}, both viewed as univariate polynomials in the main variable of \\axiom{b}.")) (|prem| (($ $ $ |#4|) "\\axiom{prem(a,b,v)} computes the pseudo-remainder of \\axiom{a} by \\axiom{b}, both viewed as univariate polynomials in \\axiom{v}.") (($ $ $) "\\axiom{prem(a,b)} computes the pseudo-remainder of \\axiom{a} by \\axiom{b}, both viewed as univariate polynomials in the main variable of \\axiom{b}.")) (|normalized?| (((|Boolean|) $ (|List| $)) "\\axiom{normalized?(q,lp)} returns \\spad{true} iff \\axiom{normalized?(q,p)} holds for every \\axiom{p} in \\axiom{lp}.") (((|Boolean|) $ $) "\\axiom{normalized?(a,b)} returns \\spad{true} iff \\axiom{a} and its iterated initials have degree zero w.r.t. the main variable of \\axiom{b}")) (|initiallyReduced?| (((|Boolean|) $ (|List| $)) "\\axiom{initiallyReduced?(q,lp)} returns \\spad{true} iff \\axiom{initiallyReduced?(q,p)} holds for every \\axiom{p} in \\axiom{lp}.") (((|Boolean|) $ $) "\\axiom{initiallyReduced?(a,b)} returns \\spad{false} iff there exists an iterated initial of \\axiom{a} which is not reduced w.r.t \\axiom{b}.")) (|headReduced?| (((|Boolean|) $ (|List| $)) "\\axiom{headReduced?(q,lp)} returns \\spad{true} iff \\axiom{headReduced?(q,p)} holds for every \\axiom{p} in \\axiom{lp}.") (((|Boolean|) $ $) "\\axiom{headReduced?(a,b)} returns \\spad{true} iff \\axiom{degree(head(a),mvar(b)) < mdeg(b)}.")) (|reduced?| (((|Boolean|) $ (|List| $)) "\\axiom{reduced?(q,lp)} returns \\spad{true} iff \\axiom{reduced?(q,p)} holds for every \\axiom{p} in \\axiom{lp}.") (((|Boolean|) $ $) "\\axiom{reduced?(a,b)} returns \\spad{true} iff \\axiom{degree(a,mvar(b)) < mdeg(b)}.")) (|supRittWu?| (((|Boolean|) $ $) "\\axiom{supRittWu?(a,b)} returns \\spad{true} if \\axiom{a} is greater than \\axiom{b} w.r.t. the Ritt and Wu Wen Tsun ordering using the refinement of Lazard.")) (|infRittWu?| (((|Boolean|) $ $) "\\axiom{infRittWu?(a,b)} returns \\spad{true} if \\axiom{a} is less than \\axiom{b} w.r.t. the Ritt and Wu Wen Tsun ordering using the refinement of Lazard.")) (|RittWuCompare| (((|Union| (|Boolean|) "failed") $ $) "\\axiom{RittWuCompare(a,b)} returns \\axiom{\"failed\"} if \\axiom{a} and \\axiom{b} have same rank w.r.t. Ritt and Wu Wen Tsun ordering using the refinement of Lazard, otherwise returns \\axiom{infRittWu?(a,b)}.")) (|mainMonomials| (((|List| $) $) "\\axiom{mainMonomials(p)} returns an error if \\axiom{p} is \\axiom{O}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns [1], otherwise returns the list of the monomials of \\axiom{p}, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|mainCoefficients| (((|List| $) $) "\\axiom{mainCoefficients(p)} returns an error if \\axiom{p} is \\axiom{O}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns [p], otherwise returns the list of the coefficients of \\axiom{p}, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|leastMonomial| (($ $) "\\axiom{leastMonomial(p)} returns an error if \\axiom{p} is \\axiom{O}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns \\axiom{1}, otherwise, the monomial of \\axiom{p} with lowest degree, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|mainMonomial| (($ $) "\\axiom{mainMonomial(p)} returns an error if \\axiom{p} is \\axiom{O}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns \\axiom{1}, otherwise, \\axiom{mvar(p)} raised to the power \\axiom{mdeg(p)}.")) (|quasiMonic?| (((|Boolean|) $) "\\axiom{quasiMonic?(p)} returns \\spad{false} if \\axiom{p} belongs to \\axiom{R}, otherwise returns \\spad{true} iff the initial of \\axiom{p} lies in the base ring \\axiom{R}.")) (|monic?| (((|Boolean|) $) "\\axiom{monic?(p)} returns \\spad{false} if \\axiom{p} belongs to \\axiom{R}, otherwise returns \\spad{true} iff \\axiom{p} is monic as a univariate polynomial in its main variable.")) (|reductum| (($ $ |#4|) "\\axiom{reductum(p,v)} returns the reductum of \\axiom{p}, where \\axiom{p} is viewed as a univariate polynomial in \\axiom{v}.")) (|leadingCoefficient| (($ $ |#4|) "\\axiom{leadingCoefficient(p,v)} returns the leading coefficient of \\axiom{p}, where \\axiom{p} is viewed as A univariate polynomial in \\axiom{v}.")) (|deepestInitial| (($ $) "\\axiom{deepestInitial(p)} returns an error if \\axiom{p} belongs to \\axiom{R}, otherwise returns the last term of \\axiom{iteratedInitials(p)}.")) (|iteratedInitials| (((|List| $) $) "\\axiom{iteratedInitials(p)} returns \\axiom{[]} if \\axiom{p} belongs to \\axiom{R}, otherwise returns the list of the iterated initials of \\axiom{p}.")) (|deepestTail| (($ $) "\\axiom{deepestTail(p)} returns \\axiom{0} if \\axiom{p} belongs to \\axiom{R}, otherwise returns tail(p), if \\axiom{tail(p)} belongs to \\axiom{R} or \\axiom{mvar(tail(p)) < mvar(p)}, otherwise returns \\axiom{deepestTail(tail(p))}.")) (|tail| (($ $) "\\axiom{tail(p)} returns its reductum, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|head| (($ $) "\\axiom{head(p)} returns \\axiom{p} if \\axiom{p} belongs to \\axiom{R}, otherwise returns its leading term (monomial in the AXIOM sense), where \\axiom{p} is viewed as a univariate polynomial \\indented{1}{in its main variable.}")) (|init| (($ $) "\\axiom{init(p)} returns an error if \\axiom{p} belongs to \\axiom{R}, otherwise returns its leading coefficient, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|mdeg| (((|NonNegativeInteger|) $) "\\axiom{mdeg(p)} returns an error if \\axiom{p} is \\axiom{0}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns \\axiom{0}, otherwise, returns the degree of \\axiom{p} in its main variable.")) (|mvar| ((|#4| $) "\\axiom{mvar(p)} returns an error if \\axiom{p} belongs to \\axiom{R}, otherwise returns its main variable \\spad{w.} \\spad{r.} \\spad{t.} to the total ordering on the elements in \\axiom{V}."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-554))) (|HasCategory| |#2| (LIST (QUOTE -43) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1000) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#4| (LIST (QUOTE -613) (QUOTE (-1170))))) 
-(-1068 R E V) 
+((|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-574))) (|HasCategory| |#2| (LIST (QUOTE -43) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1021) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#4| (LIST (QUOTE -633) (QUOTE (-1191))))) 
+(-1089 R E V) 
 ((|constructor| (NIL "\\indented{1}{Author: Marc Moreno Maza} Date Created: 04/22/1994 Date Last Updated: 14/12/1998 Description:")) (|mainSquareFreePart| (($ $) "\\axiom{mainSquareFreePart(p)} returns the square free part of \\axiom{p} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{R}.")) (|mainPrimitivePart| (($ $) "\\axiom{mainPrimitivePart(p)} returns the primitive part of \\axiom{p} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{R}.")) (|mainContent| (($ $) "\\axiom{mainContent(p)} returns the content of \\axiom{p} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{R}.")) (|primitivePart!| (($ $) "\\axiom{primitivePart!(p)} replaces \\axiom{p} by its primitive part.")) (|gcd| ((|#1| |#1| $) "\\axiom{gcd(r,p)} returns the \\spad{gcd} of \\axiom{r} and the content of \\axiom{p}.")) (|nextsubResultant2| (($ $ $ $ $) "\\axiom{nextsubResultant2(p,q,z,s)} is the multivariate version of the operation \\spad{next_sousResultant2} from PseudoRemainderSequence from the \\axiomType{PseudoRemainderSequence} constructor.")) (|LazardQuotient2| (($ $ $ $ (|NonNegativeInteger|)) "\\axiom{LazardQuotient2(p,a,b,n)} returns \\axiom{(a**(n-1) * \\spad{p)} exquo b**(n-1)} assuming that this quotient does not fail.")) (|LazardQuotient| (($ $ $ (|NonNegativeInteger|)) "\\axiom{LazardQuotient(a,b,n)} returns \\axiom{a**n exquo b**(n-1)} assuming that this quotient does not fail.")) (|lastSubResultant| (($ $ $) "\\axiom{lastSubResultant(a,b)} returns the last non-zero subresultant of \\axiom{a} and \\axiom{b} where \\axiom{a} and \\axiom{b} are assumed to have the same main variable \\axiom{v} and are viewed as univariate polynomials in \\axiom{v}.")) (|subResultantChain| (((|List| $) $ $) "\\axiom{subResultantChain(a,b)}, where \\axiom{a} and \\axiom{b} are not contant polynomials with the same main variable, returns the subresultant chain of \\axiom{a} and \\axiom{b}.")) (|resultant| (($ $ $) "\\axiom{resultant(a,b)} computes the resultant of \\axiom{a} and \\axiom{b} where \\axiom{a} and \\axiom{b} are assumed to have the same main variable \\axiom{v} and are viewed as univariate polynomials in \\axiom{v}.")) (|halfExtendedSubResultantGcd2| (((|Record| (|:| |gcd| $) (|:| |coef2| $)) $ $) "\\axiom{halfExtendedSubResultantGcd2(a,b)} returns \\axiom{[g,cb]} if \\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[g,ca,cb]} otherwise produces an error.")) (|halfExtendedSubResultantGcd1| (((|Record| (|:| |gcd| $) (|:| |coef1| $)) $ $) "\\axiom{halfExtendedSubResultantGcd1(a,b)} returns \\axiom{[g,ca]} if \\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[g,ca,cb]} otherwise produces an error.")) (|extendedSubResultantGcd| (((|Record| (|:| |gcd| $) (|:| |coef1| $) (|:| |coef2| $)) $ $) "\\axiom{extendedSubResultantGcd(a,b)} returns \\axiom{[ca,cb,r]} such that \\axiom{r} is \\axiom{subResultantGcd(a,b)} and we have \\axiom{ca * a + \\spad{cb} * \\spad{cb} = \\spad{r}} .")) (|subResultantGcd| (($ $ $) "\\axiom{subResultantGcd(a,b)} computes a \\spad{gcd} of \\axiom{a} and \\axiom{b} where \\axiom{a} and \\axiom{b} are assumed to have the same main variable \\axiom{v} and are viewed as univariate polynomials in \\axiom{v} with coefficients in the fraction field of the polynomial ring generated by their other variables over \\axiom{R}.")) (|exactQuotient!| (($ $ $) "\\axiom{exactQuotient!(a,b)} replaces \\axiom{a} by \\axiom{exactQuotient(a,b)}") (($ $ |#1|) "\\axiom{exactQuotient!(p,r)} replaces \\axiom{p} by \\axiom{exactQuotient(p,r)}.")) (|exactQuotient| (($ $ $) "\\axiom{exactQuotient(a,b)} computes the exact quotient of \\axiom{a} by \\axiom{b}, which is assumed to be a divisor of \\axiom{a}. No error is returned if this exact quotient fails!") (($ $ |#1|) "\\axiom{exactQuotient(p,r)} computes the exact quotient of \\axiom{p} by \\axiom{r}, which is assumed to be a divisor of \\axiom{p}. No error is returned if this exact quotient fails!")) (|primPartElseUnitCanonical!| (($ $) "\\axiom{primPartElseUnitCanonical!(p)} replaces \\axiom{p} by \\axiom{primPartElseUnitCanonical(p)}.")) (|primPartElseUnitCanonical| (($ $) "\\axiom{primPartElseUnitCanonical(p)} returns \\axiom{primitivePart(p)} if \\axiom{R} is a gcd-domain, otherwise \\axiom{unitCanonical(p)}.")) (|convert| (($ (|Polynomial| |#1|)) "\\axiom{convert(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}, otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{convert(p)} returns the same as \\axiom{retract(p)}.") (($ (|Polynomial| (|Integer|))) "\\axiom{convert(p)} returns the same as \\axiom{retract(p)}") (($ (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{convert(p)} returns the same as \\axiom{retract(p)}.")) (|retract| (($ (|Polynomial| |#1|)) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| |#1|)) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| |#1|)) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.") (($ (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{retract(p)} returns \\axiom{p} as an element of the current domain if \\axiom{retractIfCan(p)} does not return \"failed\", otherwise an error is produced.")) (|retractIfCan| (((|Union| $ "failed") (|Polynomial| |#1|)) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| |#1|)) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| |#1|)) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.") (((|Union| $ "failed") (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{retractIfCan(p)} returns \\axiom{p} as an element of the current domain if all its variables belong to \\axiom{V}.")) (|initiallyReduce| (($ $ $) "\\axiom{initiallyReduce(a,b)} returns a polynomial \\axiom{r} such that \\axiom{initiallyReduced?(r,b)} holds and there exists an integer \\axiom{e} such that \\axiom{init(b)^e a - \\spad{r}} is zero modulo \\axiom{b}.")) (|headReduce| (($ $ $) "\\axiom{headReduce(a,b)} returns a polynomial \\axiom{r} such that \\axiom{headReduced?(r,b)} holds and there exists an integer \\axiom{e} such that \\axiom{init(b)^e a - \\spad{r}} is zero modulo \\axiom{b}.")) (|lazyResidueClass| (((|Record| (|:| |polnum| $) (|:| |polden| $) (|:| |power| (|NonNegativeInteger|))) $ $) "\\axiom{lazyResidueClass(a,b)} returns \\axiom{[p,q,n]} where \\axiom{p / q**n} represents the residue class of \\axiom{a} modulo \\axiom{b} and \\axiom{p} is reduced w.r.t. \\axiom{b} and \\axiom{q} is \\axiom{init(b)}.")) (|monicModulo| (($ $ $) "\\axiom{monicModulo(a,b)} computes \\axiom{a mod \\spad{b},} if \\axiom{b} is monic as univariate polynomial in its main variable.")) (|pseudoDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{pseudoDivide(a,b)} computes \\axiom{[pquo(a,b),prem(a,b)]}, both polynomials viewed as univariate polynomials in the main variable of \\axiom{b}, if \\axiom{b} is not a constant polynomial.")) (|lazyPseudoDivide| (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $ |#3|) "\\axiom{lazyPseudoDivide(a,b,v)} returns \\axiom{[c,g,q,r]} such that \\axiom{r = lazyPrem(a,b,v)}, \\axiom{(c**g)*r = prem(a,b,v)} and \\axiom{q} is the pseudo-quotient computed in this lazy pseudo-division.") (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{lazyPseudoDivide(a,b)} returns \\axiom{[c,g,q,r]} such that \\axiom{[c,g,r] = lazyPremWithDefault(a,b)} and \\axiom{q} is the pseudo-quotient computed in this lazy pseudo-division.")) (|lazyPremWithDefault| (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| $)) $ $ |#3|) "\\axiom{lazyPremWithDefault(a,b,v)} returns \\axiom{[c,g,r]} such that \\axiom{r = lazyPrem(a,b,v)} and \\axiom{(c**g)*r = prem(a,b,v)}.") (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| $)) $ $) "\\axiom{lazyPremWithDefault(a,b)} returns \\axiom{[c,g,r]} such that \\axiom{r = lazyPrem(a,b)} and \\axiom{(c**g)*r = prem(a,b)}.")) (|lazyPquo| (($ $ $ |#3|) "\\axiom{lazyPquo(a,b,v)} returns the polynomial \\axiom{q} such that \\axiom{lazyPseudoDivide(a,b,v)} returns \\axiom{[c,g,q,r]}.") (($ $ $) "\\axiom{lazyPquo(a,b)} returns the polynomial \\axiom{q} such that \\axiom{lazyPseudoDivide(a,b)} returns \\axiom{[c,g,q,r]}.")) (|lazyPrem| (($ $ $ |#3|) "\\axiom{lazyPrem(a,b,v)} returns the polynomial \\axiom{r} reduced w.r.t. \\axiom{b} viewed as univariate polynomials in the variable \\axiom{v} such that \\axiom{b} divides \\axiom{init(b)^e a - \\spad{r}} where \\axiom{e} is the number of steps of this pseudo-division.") (($ $ $) "\\axiom{lazyPrem(a,b)} returns the polynomial \\axiom{r} reduced w.r.t. \\axiom{b} and such that \\axiom{b} divides \\axiom{init(b)^e a - \\spad{r}} where \\axiom{e} is the number of steps of this pseudo-division.")) (|pquo| (($ $ $ |#3|) "\\axiom{pquo(a,b,v)} computes the pseudo-quotient of \\axiom{a} by \\axiom{b}, both viewed as univariate polynomials in \\axiom{v}.") (($ $ $) "\\axiom{pquo(a,b)} computes the pseudo-quotient of \\axiom{a} by \\axiom{b}, both viewed as univariate polynomials in the main variable of \\axiom{b}.")) (|prem| (($ $ $ |#3|) "\\axiom{prem(a,b,v)} computes the pseudo-remainder of \\axiom{a} by \\axiom{b}, both viewed as univariate polynomials in \\axiom{v}.") (($ $ $) "\\axiom{prem(a,b)} computes the pseudo-remainder of \\axiom{a} by \\axiom{b}, both viewed as univariate polynomials in the main variable of \\axiom{b}.")) (|normalized?| (((|Boolean|) $ (|List| $)) "\\axiom{normalized?(q,lp)} returns \\spad{true} iff \\axiom{normalized?(q,p)} holds for every \\axiom{p} in \\axiom{lp}.") (((|Boolean|) $ $) "\\axiom{normalized?(a,b)} returns \\spad{true} iff \\axiom{a} and its iterated initials have degree zero w.r.t. the main variable of \\axiom{b}")) (|initiallyReduced?| (((|Boolean|) $ (|List| $)) "\\axiom{initiallyReduced?(q,lp)} returns \\spad{true} iff \\axiom{initiallyReduced?(q,p)} holds for every \\axiom{p} in \\axiom{lp}.") (((|Boolean|) $ $) "\\axiom{initiallyReduced?(a,b)} returns \\spad{false} iff there exists an iterated initial of \\axiom{a} which is not reduced w.r.t \\axiom{b}.")) (|headReduced?| (((|Boolean|) $ (|List| $)) "\\axiom{headReduced?(q,lp)} returns \\spad{true} iff \\axiom{headReduced?(q,p)} holds for every \\axiom{p} in \\axiom{lp}.") (((|Boolean|) $ $) "\\axiom{headReduced?(a,b)} returns \\spad{true} iff \\axiom{degree(head(a),mvar(b)) < mdeg(b)}.")) (|reduced?| (((|Boolean|) $ (|List| $)) "\\axiom{reduced?(q,lp)} returns \\spad{true} iff \\axiom{reduced?(q,p)} holds for every \\axiom{p} in \\axiom{lp}.") (((|Boolean|) $ $) "\\axiom{reduced?(a,b)} returns \\spad{true} iff \\axiom{degree(a,mvar(b)) < mdeg(b)}.")) (|supRittWu?| (((|Boolean|) $ $) "\\axiom{supRittWu?(a,b)} returns \\spad{true} if \\axiom{a} is greater than \\axiom{b} w.r.t. the Ritt and Wu Wen Tsun ordering using the refinement of Lazard.")) (|infRittWu?| (((|Boolean|) $ $) "\\axiom{infRittWu?(a,b)} returns \\spad{true} if \\axiom{a} is less than \\axiom{b} w.r.t. the Ritt and Wu Wen Tsun ordering using the refinement of Lazard.")) (|RittWuCompare| (((|Union| (|Boolean|) "failed") $ $) "\\axiom{RittWuCompare(a,b)} returns \\axiom{\"failed\"} if \\axiom{a} and \\axiom{b} have same rank w.r.t. Ritt and Wu Wen Tsun ordering using the refinement of Lazard, otherwise returns \\axiom{infRittWu?(a,b)}.")) (|mainMonomials| (((|List| $) $) "\\axiom{mainMonomials(p)} returns an error if \\axiom{p} is \\axiom{O}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns [1], otherwise returns the list of the monomials of \\axiom{p}, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|mainCoefficients| (((|List| $) $) "\\axiom{mainCoefficients(p)} returns an error if \\axiom{p} is \\axiom{O}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns [p], otherwise returns the list of the coefficients of \\axiom{p}, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|leastMonomial| (($ $) "\\axiom{leastMonomial(p)} returns an error if \\axiom{p} is \\axiom{O}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns \\axiom{1}, otherwise, the monomial of \\axiom{p} with lowest degree, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|mainMonomial| (($ $) "\\axiom{mainMonomial(p)} returns an error if \\axiom{p} is \\axiom{O}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns \\axiom{1}, otherwise, \\axiom{mvar(p)} raised to the power \\axiom{mdeg(p)}.")) (|quasiMonic?| (((|Boolean|) $) "\\axiom{quasiMonic?(p)} returns \\spad{false} if \\axiom{p} belongs to \\axiom{R}, otherwise returns \\spad{true} iff the initial of \\axiom{p} lies in the base ring \\axiom{R}.")) (|monic?| (((|Boolean|) $) "\\axiom{monic?(p)} returns \\spad{false} if \\axiom{p} belongs to \\axiom{R}, otherwise returns \\spad{true} iff \\axiom{p} is monic as a univariate polynomial in its main variable.")) (|reductum| (($ $ |#3|) "\\axiom{reductum(p,v)} returns the reductum of \\axiom{p}, where \\axiom{p} is viewed as a univariate polynomial in \\axiom{v}.")) (|leadingCoefficient| (($ $ |#3|) "\\axiom{leadingCoefficient(p,v)} returns the leading coefficient of \\axiom{p}, where \\axiom{p} is viewed as A univariate polynomial in \\axiom{v}.")) (|deepestInitial| (($ $) "\\axiom{deepestInitial(p)} returns an error if \\axiom{p} belongs to \\axiom{R}, otherwise returns the last term of \\axiom{iteratedInitials(p)}.")) (|iteratedInitials| (((|List| $) $) "\\axiom{iteratedInitials(p)} returns \\axiom{[]} if \\axiom{p} belongs to \\axiom{R}, otherwise returns the list of the iterated initials of \\axiom{p}.")) (|deepestTail| (($ $) "\\axiom{deepestTail(p)} returns \\axiom{0} if \\axiom{p} belongs to \\axiom{R}, otherwise returns tail(p), if \\axiom{tail(p)} belongs to \\axiom{R} or \\axiom{mvar(tail(p)) < mvar(p)}, otherwise returns \\axiom{deepestTail(tail(p))}.")) (|tail| (($ $) "\\axiom{tail(p)} returns its reductum, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|head| (($ $) "\\axiom{head(p)} returns \\axiom{p} if \\axiom{p} belongs to \\axiom{R}, otherwise returns its leading term (monomial in the AXIOM sense), where \\axiom{p} is viewed as a univariate polynomial \\indented{1}{in its main variable.}")) (|init| (($ $) "\\axiom{init(p)} returns an error if \\axiom{p} belongs to \\axiom{R}, otherwise returns its leading coefficient, where \\axiom{p} is viewed as a univariate polynomial in its main variable.")) (|mdeg| (((|NonNegativeInteger|) $) "\\axiom{mdeg(p)} returns an error if \\axiom{p} is \\axiom{0}, otherwise, if \\axiom{p} belongs to \\axiom{R} returns \\axiom{0}, otherwise, returns the degree of \\axiom{p} in its main variable.")) (|mvar| ((|#3| $) "\\axiom{mvar(p)} returns an error if \\axiom{p} belongs to \\axiom{R}, otherwise returns its main variable \\spad{w.} \\spad{r.} \\spad{t.} to the total ordering on the elements in \\axiom{V}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
 NIL 
-(-1069 S |TheField| |ThePols|) 
+(-1090 S |TheField| |ThePols|) 
 ((|constructor| (NIL "\\axiomType{RealRootCharacterizationCategory} provides common access functions for all real roots of polynomials")) (|relativeApprox| ((|#2| |#3| $ |#2|) "\\axiom{approximate(term,root,prec)} gives an approximation of \\axiom{term} over \\axiom{root} with precision \\axiom{prec}")) (|approximate| ((|#2| |#3| $ |#2|) "\\axiom{approximate(term,root,prec)} gives an approximation of \\axiom{term} over \\axiom{root} with precision \\axiom{prec}")) (|rootOf| (((|Union| $ "failed") |#3| (|PositiveInteger|)) "\\axiom{rootOf(pol,n)} gives the \\spad{n}th root for the order of the Real Closure")) (|allRootsOf| (((|List| $) |#3|) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} in the Real Closure, assumed in order.")) (|definingPolynomial| ((|#3| $) "\\axiom{definingPolynomial(aRoot)} gives a polynomial such that \\axiom{definingPolynomial(aRoot).aRoot = 0}")) (|recip| (((|Union| |#3| "failed") |#3| $) "\\axiom{recip(pol,aRoot)} tries to inverse \\axiom{pol} interpreted as \\axiom{aRoot}")) (|positive?| (((|Boolean|) |#3| $) "\\axiom{positive?(pol,aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is positive")) (|negative?| (((|Boolean|) |#3| $) "\\axiom{negative?(pol,aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is negative")) (|zero?| (((|Boolean|) |#3| $) "\\axiom{zero?(pol,aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is \\axiom{0}")) (|sign| (((|Integer|) |#3| $) "\\axiom{sign(pol,aRoot)} gives the sign of \\axiom{pol} interpreted as \\axiom{aRoot}"))) 
 NIL 
 NIL 
-(-1070 |TheField| |ThePols|) 
+(-1091 |TheField| |ThePols|) 
 ((|constructor| (NIL "\\axiomType{RealRootCharacterizationCategory} provides common access functions for all real roots of polynomials")) (|relativeApprox| ((|#1| |#2| $ |#1|) "\\axiom{approximate(term,root,prec)} gives an approximation of \\axiom{term} over \\axiom{root} with precision \\axiom{prec}")) (|approximate| ((|#1| |#2| $ |#1|) "\\axiom{approximate(term,root,prec)} gives an approximation of \\axiom{term} over \\axiom{root} with precision \\axiom{prec}")) (|rootOf| (((|Union| $ "failed") |#2| (|PositiveInteger|)) "\\axiom{rootOf(pol,n)} gives the \\spad{n}th root for the order of the Real Closure")) (|allRootsOf| (((|List| $) |#2|) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} in the Real Closure, assumed in order.")) (|definingPolynomial| ((|#2| $) "\\axiom{definingPolynomial(aRoot)} gives a polynomial such that \\axiom{definingPolynomial(aRoot).aRoot = 0}")) (|recip| (((|Union| |#2| "failed") |#2| $) "\\axiom{recip(pol,aRoot)} tries to inverse \\axiom{pol} interpreted as \\axiom{aRoot}")) (|positive?| (((|Boolean|) |#2| $) "\\axiom{positive?(pol,aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is positive")) (|negative?| (((|Boolean|) |#2| $) "\\axiom{negative?(pol,aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is negative")) (|zero?| (((|Boolean|) |#2| $) "\\axiom{zero?(pol,aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is \\axiom{0}")) (|sign| (((|Integer|) |#2| $) "\\axiom{sign(pol,aRoot)} gives the sign of \\axiom{pol} interpreted as \\axiom{aRoot}"))) 
 NIL 
 NIL 
-(-1071 R E V P TS) 
+(-1092 R E V P TS) 
 ((|constructor| (NIL "A package providing a new algorithm for solving polynomial systems by means of regular chains. Two ways of solving are proposed: in the sense of Zariski closure (like in Kalkbrener's algorithm) or in the sense of the regular zeros (like in Wu, Wang or Lazard methods). This algorithm is valid for any type of regular set. It does not care about the way a polynomial is added in an regular set, or how two quasi-components are compared (by an inclusion-test), or how the invertibility test is made in the tower of simple extensions associated with a regular set. These operations are realized respectively by the domain \\spad{TS} and the packages \\axiomType{QCMPACK}(R,E,V,P,TS) and \\axiomType{RSETGCD}(R,E,V,P,TS). The same way it does not care about the way univariate polynomial \\spad{gcd} (with coefficients in the tower of simple extensions associated with a regular set) are computed. The only requirement is that these \\spad{gcd} need to have invertible initials (normalized or not). WARNING. There is no need for a user to call directly any operation of this package since they can be accessed by the domain \\axiom{TS}. Thus, the operations of this package are not documented."))) 
 NIL 
 NIL 
-(-1072 S R E V P) 
+(-1093 S R E V P) 
 ((|constructor| (NIL "The category of regular triangular sets, introduced under the name regular chains in \\spad{[1]} (and other papers). In \\spad{[3]} it is proved that regular triangular sets and towers of simple extensions of a field are equivalent notions. In the following definitions, all polynomials and ideals are taken from the polynomial ring \\spad{k[x1,...,xn]} where \\spad{k} is the fraction field of \\spad{R}. The triangular set \\spad{[t1,...,tm]} is regular iff for every \\spad{i} the initial of \\spad{ti+1} is invertible in the tower of simple extensions associated with \\spad{[t1,...,ti]}. A family \\spad{[T1,...,Ts]} of regular triangular sets is a split of Kalkbrener of a given ideal \\spad{I} iff the radical of \\spad{I} is equal to the intersection of the radical ideals generated by the saturated ideals of the \\spad{[T1,...,Ti]}. A family \\spad{[T1,...,Ts]} of regular triangular sets is a split of Kalkbrener of a given triangular set \\spad{T} iff it is a split of Kalkbrener of the saturated ideal of \\spad{T}. Let \\spad{K} be an algebraic closure of \\spad{k}. Assume that \\spad{V} is finite with cardinality \\spad{n} and let \\spad{A} be the affine space \\spad{K^n}. For a regular triangular set \\spad{T} let denote by \\spad{W(T)} the set of regular zeros of \\spad{T}. A family \\spad{[T1,...,Ts]} of regular triangular sets is a split of Lazard of a given subset \\spad{S} of \\spad{A} iff the union of the \\spad{W(Ti)} contains \\spad{S} and is contained in the closure of \\spad{S} (w.r.t. Zariski topology). A family \\spad{[T1,...,Ts]} of regular triangular sets is a split of Lazard of a given triangular set \\spad{T} if it is a split of Lazard of \\spad{W(T)}. Note that if \\spad{[T1,...,Ts]} is a split of Lazard of \\spad{T} then it is also a split of Kalkbrener of \\spad{T}. The converse is false. This category provides operations related to both kinds of splits, the former being related to ideals decomposition whereas the latter deals with varieties decomposition. See the example illustrating the RegularTriangularSet constructor for more explanations about decompositions by means of regular triangular sets.")) (|zeroSetSplit| (((|List| $) (|List| |#5|) (|Boolean|)) "\\spad{zeroSetSplit(lp,clos?)} returns \\spad{lts} a split of Kalkbrener of the radical ideal associated with \\spad{lp}. If \\spad{clos?} is false, it is also a decomposition of the variety associated with \\spad{lp} into the regular zero set of the \\spad{ts} in \\spad{lts} (or, in other words, a split of Lazard of this variety). See the example illustrating the \\spadtype{RegularTriangularSet} constructor for more explanations about decompositions by means of regular triangular sets.")) (|extend| (((|List| $) (|List| |#5|) (|List| $)) "\\spad{extend(lp,lts)} returns the same as \\spad{concat([extend(lp,ts) for \\spad{ts} in lts])|}") (((|List| $) (|List| |#5|) $) "\\spad{extend(lp,ts)} returns \\spad{ts} if \\spad{empty? \\spad{lp}} \\spad{extend(p,ts)} if \\spad{lp = [p]} else \\spad{extend(first \\spad{lp,} extend(rest \\spad{lp,} ts))}") (((|List| $) |#5| (|List| $)) "\\spad{extend(p,lts)} returns the same as \\spad{concat([extend(p,ts) for \\spad{ts} in lts])|}") (((|List| $) |#5| $) "\\spad{extend(p,ts)} assumes that \\spad{p} is a non-constant polynomial whose main variable is greater than any variable of \\spad{ts}. Then it returns a split of Kalkbrener of \\spad{ts+p}. This may not be \\spad{ts+p} itself, if for instance \\spad{ts+p} is not a regular triangular set.")) (|internalAugment| (($ (|List| |#5|) $) "\\spad{internalAugment(lp,ts)} returns \\spad{ts} if \\spad{lp} is empty otherwise returns \\spad{internalAugment(rest \\spad{lp,} internalAugment(first \\spad{lp,} ts))}") (($ |#5| $) "\\spad{internalAugment(p,ts)} assumes that \\spad{augment(p,ts)} returns a singleton and returns it.")) (|augment| (((|List| $) (|List| |#5|) (|List| $)) "\\spad{augment(lp,lts)} returns the same as \\spad{concat([augment(lp,ts) for \\spad{ts} in lts])}") (((|List| $) (|List| |#5|) $) "\\spad{augment(lp,ts)} returns \\spad{ts} if \\spad{empty? lp}, \\spad{augment(p,ts)} if \\spad{lp = [p]}, otherwise \\spad{augment(first \\spad{lp,} augment(rest \\spad{lp,} ts))}") (((|List| $) |#5| (|List| $)) "\\spad{augment(p,lts)} returns the same as \\spad{concat([augment(p,ts) for \\spad{ts} in lts])}") (((|List| $) |#5| $) "\\spad{augment(p,ts)} assumes that \\spad{p} is a non-constant polynomial whose main variable is greater than any variable of \\spad{ts}. This operation assumes also that if \\spad{p} is added to \\spad{ts} the resulting set, say \\spad{ts+p}, is a regular triangular set. Then it returns a split of Kalkbrener of \\spad{ts+p}. This may not be \\spad{ts+p} itself, if for instance \\spad{ts+p} is required to be square-free.")) (|intersect| (((|List| $) |#5| (|List| $)) "\\spad{intersect(p,lts)} returns the same as \\spad{intersect([p],lts)}") (((|List| $) (|List| |#5|) (|List| $)) "\\spad{intersect(lp,lts)} returns the same as \\spad{concat([intersect(lp,ts) for \\spad{ts} in lts])|}") (((|List| $) (|List| |#5|) $) "\\spad{intersect(lp,ts)} returns \\spad{lts} a split of Lazard of the intersection of the affine variety associated with \\spad{lp} and the regular zero set of \\spad{ts}.") (((|List| $) |#5| $) "\\spad{intersect(p,ts)} returns the same as \\spad{intersect([p],ts)}")) (|squareFreePart| (((|List| (|Record| (|:| |val| |#5|) (|:| |tower| $))) |#5| $) "\\spad{squareFreePart(p,ts)} returns \\spad{lpwt} such that \\spad{lpwt.i.val} is a square-free polynomial w.r.t. \\spad{lpwt.i.tower}, this polynomial being associated with \\spad{p} modulo \\spad{lpwt.i.tower}, for every \\spad{i}. Moreover, the list of the \\spad{lpwt.i.tower} is a split of Kalkbrener of \\spad{ts}. WARNING: This assumes that \\spad{p} is a non-constant polynomial such that if \\spad{p} is added to \\spad{ts}, then the resulting set is a regular triangular set.")) (|lastSubResultant| (((|List| (|Record| (|:| |val| |#5|) (|:| |tower| $))) |#5| |#5| $) "\\spad{lastSubResultant(p1,p2,ts)} returns \\spad{lpwt} such that \\spad{lpwt.i.val} is a quasi-monic \\spad{gcd} of \\spad{p1} and \\spad{p2} w.r.t. \\spad{lpwt.i.tower}, for every \\spad{i}, and such that the list of the \\spad{lpwt.i.tower} is a split of Kalkbrener of \\spad{ts}. Moreover, if \\spad{p1} and \\spad{p2} do not have a non-trivial \\spad{gcd} w.r.t. \\spad{lpwt.i.tower} then \\spad{lpwt.i.val} is the resultant of these polynomials w.r.t. \\spad{lpwt.i.tower}. This assumes that \\spad{p1} and \\spad{p2} have the same main variable and that this variable is greater that any variable occurring in \\spad{ts}.")) (|lastSubResultantElseSplit| (((|Union| |#5| (|List| $)) |#5| |#5| $) "\\spad{lastSubResultantElseSplit(p1,p2,ts)} returns either \\spad{g} a quasi-monic \\spad{gcd} of \\spad{p1} and \\spad{p2} w.r.t. the \\spad{ts} or a split of Kalkbrener of \\spad{ts}. This assumes that \\spad{p1} and \\spad{p2} have the same maim variable and that this variable is greater that any variable occurring in \\spad{ts}.")) (|invertibleSet| (((|List| $) |#5| $) "\\spad{invertibleSet(p,ts)} returns a split of Kalkbrener of the quotient ideal of the ideal \\axiom{I} by \\spad{p} where \\spad{I} is the radical of saturated of \\spad{ts}.")) (|invertible?| (((|Boolean|) |#5| $) "\\spad{invertible?(p,ts)} returns \\spad{true} iff \\spad{p} is invertible in the tower associated with \\spad{ts}.") (((|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| $))) |#5| $) "\\spad{invertible?(p,ts)} returns \\spad{lbwt} where \\spad{lbwt.i} is the result of \\spad{invertibleElseSplit?(p,lbwt.i.tower)} and the list of the \\spad{(lqrwt.i).tower} is a split of Kalkbrener of \\spad{ts}.")) (|invertibleElseSplit?| (((|Union| (|Boolean|) (|List| $)) |#5| $) "\\spad{invertibleElseSplit?(p,ts)} returns \\spad{true} (resp. \\spad{false}) if \\spad{p} is invertible in the tower associated with \\spad{ts} or returns a split of Kalkbrener of \\spad{ts}.")) (|purelyAlgebraicLeadingMonomial?| (((|Boolean|) |#5| $) "\\spad{purelyAlgebraicLeadingMonomial?(p,ts)} returns \\spad{true} iff the main variable of any non-constant iterarted initial of \\spad{p} is algebraic w.r.t. \\spad{ts}.")) (|algebraicCoefficients?| (((|Boolean|) |#5| $) "\\spad{algebraicCoefficients?(p,ts)} returns \\spad{true} iff every variable of \\spad{p} which is not the main one of \\spad{p} is algebraic w.r.t. \\spad{ts}.")) (|purelyTranscendental?| (((|Boolean|) |#5| $) "\\spad{purelyTranscendental?(p,ts)} returns \\spad{true} iff every variable of \\spad{p} is not algebraic w.r.t. \\spad{ts}")) (|purelyAlgebraic?| (((|Boolean|) $) "\\spad{purelyAlgebraic?(ts)} returns \\spad{true} iff for every algebraic variable \\spad{v} of \\spad{ts} we have \\spad{algebraicCoefficients?(t_v,ts_v_-)} where \\spad{ts_v} is select from TriangularSetCategory(ts,v) and \\spad{ts_v_-} is collectUnder from TriangularSetCategory(ts,v).") (((|Boolean|) |#5| $) "\\spad{purelyAlgebraic?(p,ts)} returns \\spad{true} iff every variable of \\spad{p} is algebraic w.r.t. \\spad{ts}."))) 
 NIL 
 NIL 
-(-1073 R E V P) 
+(-1094 R E V P) 
 ((|constructor| (NIL "The category of regular triangular sets, introduced under the name regular chains in \\spad{[1]} (and other papers). In \\spad{[3]} it is proved that regular triangular sets and towers of simple extensions of a field are equivalent notions. In the following definitions, all polynomials and ideals are taken from the polynomial ring \\spad{k[x1,...,xn]} where \\spad{k} is the fraction field of \\spad{R}. The triangular set \\spad{[t1,...,tm]} is regular iff for every \\spad{i} the initial of \\spad{ti+1} is invertible in the tower of simple extensions associated with \\spad{[t1,...,ti]}. A family \\spad{[T1,...,Ts]} of regular triangular sets is a split of Kalkbrener of a given ideal \\spad{I} iff the radical of \\spad{I} is equal to the intersection of the radical ideals generated by the saturated ideals of the \\spad{[T1,...,Ti]}. A family \\spad{[T1,...,Ts]} of regular triangular sets is a split of Kalkbrener of a given triangular set \\spad{T} iff it is a split of Kalkbrener of the saturated ideal of \\spad{T}. Let \\spad{K} be an algebraic closure of \\spad{k}. Assume that \\spad{V} is finite with cardinality \\spad{n} and let \\spad{A} be the affine space \\spad{K^n}. For a regular triangular set \\spad{T} let denote by \\spad{W(T)} the set of regular zeros of \\spad{T}. A family \\spad{[T1,...,Ts]} of regular triangular sets is a split of Lazard of a given subset \\spad{S} of \\spad{A} iff the union of the \\spad{W(Ti)} contains \\spad{S} and is contained in the closure of \\spad{S} (w.r.t. Zariski topology). A family \\spad{[T1,...,Ts]} of regular triangular sets is a split of Lazard of a given triangular set \\spad{T} if it is a split of Lazard of \\spad{W(T)}. Note that if \\spad{[T1,...,Ts]} is a split of Lazard of \\spad{T} then it is also a split of Kalkbrener of \\spad{T}. The converse is false. This category provides operations related to both kinds of splits, the former being related to ideals decomposition whereas the latter deals with varieties decomposition. See the example illustrating the RegularTriangularSet constructor for more explanations about decompositions by means of regular triangular sets.")) (|zeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|)) "\\spad{zeroSetSplit(lp,clos?)} returns \\spad{lts} a split of Kalkbrener of the radical ideal associated with \\spad{lp}. If \\spad{clos?} is false, it is also a decomposition of the variety associated with \\spad{lp} into the regular zero set of the \\spad{ts} in \\spad{lts} (or, in other words, a split of Lazard of this variety). See the example illustrating the \\spadtype{RegularTriangularSet} constructor for more explanations about decompositions by means of regular triangular sets.")) (|extend| (((|List| $) (|List| |#4|) (|List| $)) "\\spad{extend(lp,lts)} returns the same as \\spad{concat([extend(lp,ts) for \\spad{ts} in lts])|}") (((|List| $) (|List| |#4|) $) "\\spad{extend(lp,ts)} returns \\spad{ts} if \\spad{empty? \\spad{lp}} \\spad{extend(p,ts)} if \\spad{lp = [p]} else \\spad{extend(first \\spad{lp,} extend(rest \\spad{lp,} ts))}") (((|List| $) |#4| (|List| $)) "\\spad{extend(p,lts)} returns the same as \\spad{concat([extend(p,ts) for \\spad{ts} in lts])|}") (((|List| $) |#4| $) "\\spad{extend(p,ts)} assumes that \\spad{p} is a non-constant polynomial whose main variable is greater than any variable of \\spad{ts}. Then it returns a split of Kalkbrener of \\spad{ts+p}. This may not be \\spad{ts+p} itself, if for instance \\spad{ts+p} is not a regular triangular set.")) (|internalAugment| (($ (|List| |#4|) $) "\\spad{internalAugment(lp,ts)} returns \\spad{ts} if \\spad{lp} is empty otherwise returns \\spad{internalAugment(rest \\spad{lp,} internalAugment(first \\spad{lp,} ts))}") (($ |#4| $) "\\spad{internalAugment(p,ts)} assumes that \\spad{augment(p,ts)} returns a singleton and returns it.")) (|augment| (((|List| $) (|List| |#4|) (|List| $)) "\\spad{augment(lp,lts)} returns the same as \\spad{concat([augment(lp,ts) for \\spad{ts} in lts])}") (((|List| $) (|List| |#4|) $) "\\spad{augment(lp,ts)} returns \\spad{ts} if \\spad{empty? lp}, \\spad{augment(p,ts)} if \\spad{lp = [p]}, otherwise \\spad{augment(first \\spad{lp,} augment(rest \\spad{lp,} ts))}") (((|List| $) |#4| (|List| $)) "\\spad{augment(p,lts)} returns the same as \\spad{concat([augment(p,ts) for \\spad{ts} in lts])}") (((|List| $) |#4| $) "\\spad{augment(p,ts)} assumes that \\spad{p} is a non-constant polynomial whose main variable is greater than any variable of \\spad{ts}. This operation assumes also that if \\spad{p} is added to \\spad{ts} the resulting set, say \\spad{ts+p}, is a regular triangular set. Then it returns a split of Kalkbrener of \\spad{ts+p}. This may not be \\spad{ts+p} itself, if for instance \\spad{ts+p} is required to be square-free.")) (|intersect| (((|List| $) |#4| (|List| $)) "\\spad{intersect(p,lts)} returns the same as \\spad{intersect([p],lts)}") (((|List| $) (|List| |#4|) (|List| $)) "\\spad{intersect(lp,lts)} returns the same as \\spad{concat([intersect(lp,ts) for \\spad{ts} in lts])|}") (((|List| $) (|List| |#4|) $) "\\spad{intersect(lp,ts)} returns \\spad{lts} a split of Lazard of the intersection of the affine variety associated with \\spad{lp} and the regular zero set of \\spad{ts}.") (((|List| $) |#4| $) "\\spad{intersect(p,ts)} returns the same as \\spad{intersect([p],ts)}")) (|squareFreePart| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| $))) |#4| $) "\\spad{squareFreePart(p,ts)} returns \\spad{lpwt} such that \\spad{lpwt.i.val} is a square-free polynomial w.r.t. \\spad{lpwt.i.tower}, this polynomial being associated with \\spad{p} modulo \\spad{lpwt.i.tower}, for every \\spad{i}. Moreover, the list of the \\spad{lpwt.i.tower} is a split of Kalkbrener of \\spad{ts}. WARNING: This assumes that \\spad{p} is a non-constant polynomial such that if \\spad{p} is added to \\spad{ts}, then the resulting set is a regular triangular set.")) (|lastSubResultant| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| $))) |#4| |#4| $) "\\spad{lastSubResultant(p1,p2,ts)} returns \\spad{lpwt} such that \\spad{lpwt.i.val} is a quasi-monic \\spad{gcd} of \\spad{p1} and \\spad{p2} w.r.t. \\spad{lpwt.i.tower}, for every \\spad{i}, and such that the list of the \\spad{lpwt.i.tower} is a split of Kalkbrener of \\spad{ts}. Moreover, if \\spad{p1} and \\spad{p2} do not have a non-trivial \\spad{gcd} w.r.t. \\spad{lpwt.i.tower} then \\spad{lpwt.i.val} is the resultant of these polynomials w.r.t. \\spad{lpwt.i.tower}. This assumes that \\spad{p1} and \\spad{p2} have the same main variable and that this variable is greater that any variable occurring in \\spad{ts}.")) (|lastSubResultantElseSplit| (((|Union| |#4| (|List| $)) |#4| |#4| $) "\\spad{lastSubResultantElseSplit(p1,p2,ts)} returns either \\spad{g} a quasi-monic \\spad{gcd} of \\spad{p1} and \\spad{p2} w.r.t. the \\spad{ts} or a split of Kalkbrener of \\spad{ts}. This assumes that \\spad{p1} and \\spad{p2} have the same maim variable and that this variable is greater that any variable occurring in \\spad{ts}.")) (|invertibleSet| (((|List| $) |#4| $) "\\spad{invertibleSet(p,ts)} returns a split of Kalkbrener of the quotient ideal of the ideal \\axiom{I} by \\spad{p} where \\spad{I} is the radical of saturated of \\spad{ts}.")) (|invertible?| (((|Boolean|) |#4| $) "\\spad{invertible?(p,ts)} returns \\spad{true} iff \\spad{p} is invertible in the tower associated with \\spad{ts}.") (((|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| $))) |#4| $) "\\spad{invertible?(p,ts)} returns \\spad{lbwt} where \\spad{lbwt.i} is the result of \\spad{invertibleElseSplit?(p,lbwt.i.tower)} and the list of the \\spad{(lqrwt.i).tower} is a split of Kalkbrener of \\spad{ts}.")) (|invertibleElseSplit?| (((|Union| (|Boolean|) (|List| $)) |#4| $) "\\spad{invertibleElseSplit?(p,ts)} returns \\spad{true} (resp. \\spad{false}) if \\spad{p} is invertible in the tower associated with \\spad{ts} or returns a split of Kalkbrener of \\spad{ts}.")) (|purelyAlgebraicLeadingMonomial?| (((|Boolean|) |#4| $) "\\spad{purelyAlgebraicLeadingMonomial?(p,ts)} returns \\spad{true} iff the main variable of any non-constant iterarted initial of \\spad{p} is algebraic w.r.t. \\spad{ts}.")) (|algebraicCoefficients?| (((|Boolean|) |#4| $) "\\spad{algebraicCoefficients?(p,ts)} returns \\spad{true} iff every variable of \\spad{p} which is not the main one of \\spad{p} is algebraic w.r.t. \\spad{ts}.")) (|purelyTranscendental?| (((|Boolean|) |#4| $) "\\spad{purelyTranscendental?(p,ts)} returns \\spad{true} iff every variable of \\spad{p} is not algebraic w.r.t. \\spad{ts}")) (|purelyAlgebraic?| (((|Boolean|) $) "\\spad{purelyAlgebraic?(ts)} returns \\spad{true} iff for every algebraic variable \\spad{v} of \\spad{ts} we have \\spad{algebraicCoefficients?(t_v,ts_v_-)} where \\spad{ts_v} is select from TriangularSetCategory(ts,v) and \\spad{ts_v_-} is collectUnder from TriangularSetCategory(ts,v).") (((|Boolean|) |#4| $) "\\spad{purelyAlgebraic?(p,ts)} returns \\spad{true} iff every variable of \\spad{p} is algebraic w.r.t. \\spad{ts}."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-1074 R E V P TS) 
+(-1095 R E V P TS) 
 ((|constructor| (NIL "An internal package for computing gcds and resultants of univariate polynomials with coefficients in a tower of simple extensions of a field.")) (|toseSquareFreePart| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#5|) "\\axiom{toseSquareFreePart(p,ts)} has the same specifications as squareFreePart from RegularTriangularSetCategory.")) (|toseInvertibleSet| (((|List| |#5|) |#4| |#5|) "\\axiom{toseInvertibleSet(p1,p2,ts)} has the same specifications as invertibleSet from RegularTriangularSetCategory.")) (|toseInvertible?| (((|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| |#5|))) |#4| |#5|) "\\axiom{toseInvertible?(p1,p2,ts)} has the same specifications as invertible? from RegularTriangularSetCategory.") (((|Boolean|) |#4| |#5|) "\\axiom{toseInvertible?(p1,p2,ts)} has the same specifications as invertible? from RegularTriangularSetCategory.")) (|toseLastSubResultant| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#4| |#5|) "\\axiom{toseLastSubResultant(p1,p2,ts)} has the same specifications as lastSubResultant from RegularTriangularSetCategory.")) (|integralLastSubResultant| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#4| |#5|) "\\axiom{integralLastSubResultant(p1,p2,ts)} is an internal subroutine, exported only for developement.")) (|internalLastSubResultant| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) (|List| (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|))) |#3| (|Boolean|)) "\\axiom{internalLastSubResultant(lpwt,v,flag)} is an internal subroutine, exported only for developement.") (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#4| |#5| (|Boolean|) (|Boolean|)) "\\axiom{internalLastSubResultant(p1,p2,ts,inv?,break?)} is an internal subroutine, exported only for developement.")) (|prepareSubResAlgo| (((|List| (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|))) |#4| |#4| |#5|) "\\axiom{prepareSubResAlgo(p1,p2,ts)} is an internal subroutine, exported only for developement.")) (|stopTableInvSet!| (((|Void|)) "\\axiom{stopTableInvSet!()} is an internal subroutine, exported only for developement.")) (|startTableInvSet!| (((|Void|) (|String|) (|String|) (|String|)) "\\axiom{startTableInvSet!(s1,s2,s3)} is an internal subroutine, exported only for developement.")) (|stopTableGcd!| (((|Void|)) "\\axiom{stopTableGcd!()} is an internal subroutine, exported only for developement.")) (|startTableGcd!| (((|Void|) (|String|) (|String|) (|String|)) "\\axiom{startTableGcd!(s1,s2,s3)} is an internal subroutine, exported only for developement."))) 
 NIL 
 NIL 
-(-1075 |f|) 
+(-1096 |f|) 
 ((|constructor| (NIL "This domain implements named rules")) (|name| (((|Symbol|) $) "\\spad{name(x)} returns the symbol"))) 
 NIL 
 NIL 
-(-1076 |Base| R -3313) 
+(-1097 |Base| R -3958) 
 ((|constructor| (NIL "Rules for the pattern matcher")) (|quotedOperators| (((|List| (|Symbol|)) $) "\\spad{quotedOperators(r)} returns the list of operators on the right hand side of \\spad{r} that are considered quoted, that is they are not evaluated during any rewrite, but just applied formally to their arguments.")) (|elt| ((|#3| $ |#3| (|PositiveInteger|)) "\\spad{elt(r,f,n)} or r(f, \\spad{n)} applies the rule \\spad{r} to \\spad{f} at most \\spad{n} times.")) (|rhs| ((|#3| $) "\\spad{rhs(r)} returns the right hand side of the rule \\spad{r.}")) (|lhs| ((|#3| $) "\\spad{lhs(r)} returns the left hand side of the rule \\spad{r.}")) (|pattern| (((|Pattern| |#1|) $) "\\spad{pattern(r)} returns the pattern corresponding to the left hand side of the rule \\spad{r.}")) (|suchThat| (($ $ (|List| (|Symbol|)) (|Mapping| (|Boolean|) (|List| |#3|))) "\\spad{suchThat(r, [a1,...,an], \\spad{f)}} returns the rewrite rule \\spad{r} with the predicate \\spad{f(a1,...,an)} attached to it.")) (|rule| (($ |#3| |#3| (|List| (|Symbol|))) "\\spad{rule(f, \\spad{g,} [f1,...,fn])} creates the rewrite rule \\spad{f \\spad{==} eval(eval(g, \\spad{g} is \\spad{f),} [f1,...,fn])}, that is a rule with left-hand side \\spad{f} and right-hand side \\spad{g;} The symbols f1,...,fn are the operators that are considered quoted, that is they are not evaluated during any rewrite, but just applied formally to their arguments.") (($ |#3| |#3|) "\\indented{1}{rule(f, \\spad{g)} creates the rewrite rule: \\spad{f \\spad{==} eval(g, \\spad{g} is f)},} \\indented{1}{with left-hand side \\spad{f} and right-hand side \\spad{g.}} \\blankline \\spad{X} logrule \\spad{:=} rule log(x) + log(y) \\spad{==} log(x*y) \\spad{X} \\spad{f} \\spad{:=} log(sin(x)) + log(x) \\spad{X} logrule \\spad{f}"))) 
 NIL 
 NIL 
-(-1077 |Base| R -3313) 
+(-1098 |Base| R -3958) 
 ((|constructor| (NIL "Sets of rules for the pattern matcher. A ruleset is a set of pattern matching rules grouped together.")) (|elt| ((|#3| $ |#3| (|PositiveInteger|)) "\\spad{elt(r,f,n)} or r(f, \\spad{n)} applies all the rules of \\spad{r} to \\spad{f} at most \\spad{n} times.")) (|rules| (((|List| (|RewriteRule| |#1| |#2| |#3|)) $) "\\spad{rules(r)} returns the rules contained in \\spad{r.}")) (|ruleset| (($ (|List| (|RewriteRule| |#1| |#2| |#3|))) "\\spad{ruleset([r1,...,rn])} creates the rule set \\spad{{r1,...,rn}}."))) 
 NIL 
 NIL 
-(-1078 R |ls|) 
+(-1099 R |ls|) 
 ((|constructor| (NIL "A package for computing the rational univariate representation of a zero-dimensional algebraic variety given by a regular triangular set. This package is essentially an interface for the \\spadtype{InternalRationalUnivariateRepresentationPackage} constructor. It is used in the \\spadtype{ZeroDimensionalSolvePackage} for solving polynomial systems with finitely many solutions.")) (|rur| (((|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| |#1|)) (|:| |coordinates| (|List| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|)) (|Boolean|) (|Boolean|)) "\\spad{rur(lp,univ?,check?)} returns the same as \\spad{rur(lp,true)}. Moreover, if \\spad{check?} is \\spad{true} then the result is checked.") (((|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| |#1|)) (|:| |coordinates| (|List| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|))) "\\spad{rur(lp)} returns the same as \\spad{rur(lp,true)}") (((|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| |#1|)) (|:| |coordinates| (|List| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|)) (|Boolean|)) "\\spad{rur(lp,univ?)} returns a rational univariate representation of \\spad{lp}. This assumes that \\spad{lp} defines a regular triangular \\spad{ts} whose associated variety is zero-dimensional over \\spad{R}. \\spad{rur(lp,univ?)} returns a list of items \\spad{[u,lc]} where \\spad{u} is an irreducible univariate polynomial and each \\spad{c} in \\spad{lc} involves two variables: one from \\spad{ls}, called the coordinate of \\spad{c}, and an extra variable which represents any root of \\spad{u}. Every root of \\spad{u} leads to a tuple of values for the coordinates of \\spad{lc}. Moreover, a point \\spad{x} belongs to the variety associated with \\spad{lp} iff there exists an item \\spad{[u,lc]} in \\spad{rur(lp,univ?)} and a root \\spad{r} of \\spad{u} such that \\spad{x} is given by the tuple of values for the coordinates of \\spad{lc} evaluated at \\spad{r}. If \\spad{univ?} is \\spad{true} then each polynomial \\spad{c} will have a constant leading coefficient w.r.t. its coordinate. See the example which illustrates the \\spadtype{ZeroDimensionalSolvePackage} package constructor."))) 
 NIL 
 NIL 
-(-1079 UP SAE UPA) 
+(-1100 UP SAE UPA) 
 ((|constructor| (NIL "Factorization of univariate polynomials with coefficients in an algebraic extension of the rational numbers (\\spadtype{Fraction Integer}).")) (|factor| (((|Factored| |#3|) |#3|) "\\spad{factor(p)} returns a prime factorisation of \\spad{p.}"))) 
 NIL 
 NIL 
-(-1080 R UP M) 
+(-1101 R UP M) 
 ((|constructor| (NIL "Algebraic extension of a ring by a single polynomial. Domain which represents simple algebraic extensions of arbitrary rings. The first argument to the domain, \\spad{R,} is the underlying ring, the second argument is a domain of univariate polynomials over \\spad{K,} while the last argument specifies the defining minimal polynomial. The elements of the domain are canonically represented as polynomials of degree less than that of the minimal polynomial with coefficients in \\spad{R.} The second argument is both the type of the third argument and the underlying representation used by \\spadtype{SAE} itself."))) 
-((-4595 |has| |#1| (-368)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-353))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-353)))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-353))))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-353))))) 
-(-1081 UP SAE UPA) 
+((-4618 |has| |#1| (-388)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-373))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-373)))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-373))))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-373))))) 
+(-1102 UP SAE UPA) 
 ((|constructor| (NIL "Factorization of univariate polynomials with coefficients in an algebraic extension of \\spadtype{Fraction Polynomial Integer}.")) (|factor| (((|Factored| |#3|) |#3|) "\\spad{factor(p)} returns a prime factorisation of \\spad{p.}"))) 
 NIL 
 NIL 
-(-1082) 
+(-1103) 
 ((|constructor| (NIL "This trivial domain lets us build Univariate Polynomials in an anonymous variable"))) 
 NIL 
 NIL 
-(-1083 S) 
+(-1104 S) 
 ((|constructor| (NIL "A sorted cache of a cachable set \\spad{S} is a dynamic structure that keeps the elements of \\spad{S} sorted and assigns an integer to each element of \\spad{S} once it is in the cache. This way, equality and ordering on \\spad{S} are tested directly on the integers associated with the elements of \\spad{S,} once they have been entered in the cache.")) (|enterInCache| ((|#1| |#1| (|Mapping| (|Integer|) |#1| |#1|)) "\\spad{enterInCache(x, \\spad{f)}} enters \\spad{x} in the cache, calling \\spad{f(x, \\spad{y)}} to determine whether \\spad{x < \\spad{y} (f(x,y) < 0), \\spad{x} = \\spad{y} (f(x,y) = 0)}, or \\spad{x > \\spad{y} (f(x,y) > 0)}. It returns \\spad{x} with an integer associated with it.") ((|#1| |#1| (|Mapping| (|Boolean|) |#1|)) "\\spad{enterInCache(x, \\spad{f)}} enters \\spad{x} in the cache, calling \\spad{f(y)} to determine whether \\spad{x} is equal to \\spad{y.} It returns \\spad{x} with an integer associated with it.")) (|cache| (((|List| |#1|)) "\\spad{cache()} returns the current cache as a list.")) (|clearCache| (((|Void|)) "\\spad{clearCache()} empties the cache."))) 
 NIL 
 NIL 
-(-1084 R) 
+(-1105 R) 
 ((|constructor| (NIL "StructuralConstantsPackage provides functions creating structural constants from a multiplication tables or a basis of a matrix algebra and other useful functions in this context.")) (|coordinates| (((|Vector| |#1|) (|Matrix| |#1|) (|List| (|Matrix| |#1|))) "\\spad{coordinates(a,[v1,...,vn])} returns the coordinates of \\spad{a} with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}.")) (|structuralConstants| (((|Vector| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) "\\spad{structuralConstants(basis)} takes the \\spad{basis} of a matrix algebra, \\spadignore{e.g.} the result of \\spadfun{basisOfCentroid} and calculates the structural constants. Note, that the it is not checked, whether \\spad{basis} really is a \\spad{basis} of a matrix algebra.") (((|Vector| (|Matrix| (|Polynomial| |#1|))) (|List| (|Symbol|)) (|Matrix| (|Polynomial| |#1|))) "\\spad{structuralConstants(ls,mt)} determines the structural constants of an algebra with generators \\spad{ls} and multiplication table \\spad{mt,} the entries of which must be given as linear polynomials in the indeterminates given by \\spad{ls.} The result is in particular useful \\indented{1}{as fourth argument for \\spadtype{AlgebraGivenByStructuralConstants}} \\indented{1}{and \\spadtype{GenericNonAssociativeAlgebra}.}") (((|Vector| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|List| (|Symbol|)) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{structuralConstants(ls,mt)} determines the structural constants of an algebra with generators \\spad{ls} and multiplication table \\spad{mt,} the entries of which must be given as linear polynomials in the indeterminates given by \\spad{ls.} The result is in particular useful \\indented{1}{as fourth argument for \\spadtype{AlgebraGivenByStructuralConstants}} \\indented{1}{and \\spadtype{GenericNonAssociativeAlgebra}.}"))) 
 NIL 
 NIL 
-(-1085 R) 
+(-1106 R) 
 ((|constructor| (NIL "A basic implementation of StochasticDifferential(R) using the associated domain BasicStochasticDifferential in the underlying representation as sparse multivariate polynomials. The domain is a module over Expression(R), and is a ring without identity (AXIOM term is \"Rng\"). Note that separate instances, for example using R=Integer and R=Float, have different hidden structure (multiplication and drift tables).")) (|uncorrelated?| (((|Boolean|) (|List| (|List| $))) "\\spad{uncorrelated?(ll)} checks whether its argument is a list of lists of stochastic differentials of zero inter-list quadratic co-variation.") (((|Boolean|) (|List| $) (|List| $)) "\\spad{uncorrelated?(l1,l2)} checks whether its two arguments are lists of stochastic differentials of zero inter-list quadratic co-variation.") (((|Boolean|) $ $) "\\spad{uncorrelated?(dx,dy)} checks whether its two arguments have zero quadratic co-variation.")) (|statusIto| (((|OutputForm|)) "\\indented{1}{statusIto() displays the current state of \\axiom{setBSD},} \\indented{1}{\\axiom{tableDrift}, and \\axiom{tableQuadVar}. Question} \\indented{1}{marks are printed instead of undefined entries} \\blankline \\spad{X} dt:=introduce!(t,dt) \\spad{X} dX:=introduce!(X,dX) \\spad{X} dY:=introduce!(Y,dY) \\spad{X} copyBSD() \\spad{X} copyIto() \\spad{X} copyhQuadVar() \\spad{X} statusIto()")) (^ (($ $ (|PositiveInteger|)) "\\spad{dx^n} is \\spad{dx} multiplied by itself \\spad{n} times.")) (** (($ $ (|PositiveInteger|)) "\\spad{dx**n} is \\spad{dx} multiplied by itself \\spad{n} times.")) (/ (($ $ (|Expression| |#1|)) "\\spad{dx/y} divides the stochastic differential \\spad{dx} by the previsible function \\spad{y.}")) (|copyQuadVar| (((|Table| $ $)) "\\spad{copyQuadVar returns} private multiplication table of basic stochastic differentials for inspection")) (|copyDrift| (((|Table| $ $)) "\\spad{copyDrift returns} private table of drifts of basic stochastic differentials for inspection")) (|equation| (((|Union| (|Equation| $) "failed") |#1| $) "\\spad{equation(0,dx)} allows \\spad{LHS} of Equation \\% to be zero") (((|Union| (|Equation| $) "failed") $ |#1|) "\\spad{equation(dx,0)} allows \\spad{RHS} of Equation \\% to be zero")) (|listSD| (((|List| (|BasicStochasticDifferential|)) $) "\\spad{listSD(dx)} returns a list of all \\axiom{BSD} involved in the generation of \\axiom{dx} as a module element")) (|coefficient| (((|Expression| |#1|) $ (|BasicStochasticDifferential|)) "\\spad{coefficient(sd,dX)} returns the coefficient of \\axiom{dX} in the stochastic differential \\axiom{sd}")) (|freeOf?| (((|Boolean|) $ (|BasicStochasticDifferential|)) "\\spad{freeOf?(sd,dX)} checks whether \\axiom{dX} occurs in \\axiom{sd} as a module element")) (|drift| (($ $) "\\spad{drift(dx)} returns the drift of \\axiom{dx}")) (|alterDrift!| (((|Union| $ "failed") (|BasicStochasticDifferential|) $) "\\spad{alterDrift! adds} drift formula for a stochastic differential to a private table. Failure occurs if \\indented{1}{(a) first arguments is not basic} \\indented{1}{(b) second argument is not exactly of first degree}")) (|alterQuadVar!| (((|Union| $ "failed") (|BasicStochasticDifferential|) (|BasicStochasticDifferential|) $) "\\spad{alterQuadVar! adds} multiplication formula for a pair of stochastic differentials to a private table. Failure occurs if \\indented{1}{(a) either of first or second arguments is not basic} \\indented{1}{(b) third argument is not exactly of first degree}"))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-1086 R) 
+(-1107 R) 
 ((|constructor| (NIL "\\spadtype{SequentialDifferentialPolynomial} implements an ordinary differential polynomial ring in arbitrary number of differential indeterminates, with coefficients in a ring. The ranking on the differential indeterminate is sequential."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1087 (-1170)) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-1087 (-1170)) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-1087 (-1170)) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-1087 (-1170)) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-1087 (-1170)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-227))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-1087 S) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1108 (-1191)) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-1108 (-1191)) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-1108 (-1191)) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-1108 (-1191)) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-1108 (-1191)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-247))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-1108 S) 
 ((|constructor| (NIL "\\spadtype{OrderlyDifferentialVariable} adds a commonly used sequential ranking to the set of derivatives of an ordered list of differential indeterminates. A sequential ranking is a ranking \\spadfun{<} of the derivatives with the property that for any derivative \\spad{v,} there are only a finite number of derivatives \\spad{u} with \\spad{u} \\spadfun{<} \\spad{v.} This domain belongs to \\spadtype{DifferentialVariableCategory}. It defines \\spadfun{weight} to be just \\spadfun{order}, and it defines a sequential ranking \\spadfun{<} on derivatives \\spad{u} by the lexicographic order on the pair (\\spadfun{variable}(u), \\spadfun{order}(u))."))) 
 NIL 
 NIL 
-(-1088 R S) 
+(-1109 R S) 
 ((|constructor| (NIL "This package provides operations for mapping functions onto segments.")) (|map| (((|List| |#2|) (|Mapping| |#2| |#1|) (|Segment| |#1|)) "\\spad{map(f,s)} expands the segment \\spad{s,} applying \\spad{f} to each value. For example, if \\spad{s = l..h by \\spad{k},} then the list \\spad{[f(l), f(l+k),..., f(lN)]} is computed, where \\spad{lN \\spad{<=} \\spad{h} < lN+k}.") (((|Segment| |#2|) (|Mapping| |#2| |#1|) (|Segment| |#1|)) "\\spad{map(f,l..h)} returns a new segment \\spad{f(l)..f(h)}."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-846)))) 
-(-1089 R S) 
+((|HasCategory| |#1| (QUOTE (-867)))) 
+(-1110 R S) 
 ((|constructor| (NIL "This package provides operations for mapping functions onto \\spadtype{SegmentBinding}s.")) (|map| (((|SegmentBinding| |#2|) (|Mapping| |#2| |#1|) (|SegmentBinding| |#1|)) "\\spad{map(f,v=a..b)} returns the value given by \\spad{v=f(a)..f(b)}."))) 
 NIL 
 NIL 
-(-1090 S) 
+(-1111 S) 
 ((|constructor| (NIL "This domain is used to provide the function argument syntax \\spad{v=a..b}. This is used, for example, by the top-level \\spadfun{draw} functions.")) (|segment| (((|Segment| |#1|) $) "\\spad{segment(segb)} returns the segment from the right hand side of the \\spadtype{SegmentBinding}. For example, if \\spad{segb} is \\spad{v=a..b}, then \\spad{segment(segb)} returns \\spad{a..b}.")) (|variable| (((|Symbol|) $) "\\spad{variable(segb)} returns the variable from the left hand side of the \\spadtype{SegmentBinding}. For example, if \\spad{segb} is \\spad{v=a..b}, then \\spad{variable(segb)} returns \\spad{v}.")) (|equation| (($ (|Symbol|) (|Segment| |#1|)) "\\spad{equation(v,a..b)} creates a segment binding value with variable \\spad{v} and segment \\spad{a..b}. Note that the interpreter parses \\spad{v=a..b} to this form."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-1098)))) 
-(-1091 S) 
+((|HasCategory| |#1| (QUOTE (-1119)))) 
+(-1112 S) 
 ((|constructor| (NIL "This category provides operations on ranges, or segments as they are called.")) (|convert| (($ |#1|) "\\spad{convert(i)} creates the segment \\spad{i..i}.")) (|segment| (($ |#1| |#1|) "\\spad{segment(i,j)} is an alternate way to create the segment \\spad{i..j}.")) (|incr| (((|Integer|) $) "\\spad{incr(s)} returns \\spad{n}, where \\spad{s} is a segment in which every \\spad{n}-th element is used. Note that \\spad{incr(l..h by \\spad{n)} = \\spad{n}.}")) (|high| ((|#1| $) "\\spad{high(s)} returns the second endpoint of \\spad{s.} Note that \\spad{high(l..h) = \\spad{h}.}")) (|low| ((|#1| $) "\\spad{low(s)} returns the first endpoint of \\spad{s.} Note that \\spad{low(l..h) = \\spad{l}.}")) (|hi| ((|#1| $) "\\spad{hi(s)} returns the second endpoint of \\spad{s.} Note that \\spad{hi(l..h) = \\spad{h}.}")) (|lo| ((|#1| $) "\\spad{lo(s)} returns the first endpoint of \\spad{s.} Note that \\spad{lo(l..h) = \\spad{l}.}")) (BY (($ $ (|Integer|)) "\\spad{s by \\spad{n}} creates a new segment in which only every \\spad{n}-th element is used.")) (SEGMENT (($ |#1| |#1|) "\\spad{l..h} creates a segment with \\spad{l} and \\spad{h} as the endpoints."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-1092 S) 
+(-1113 S) 
 ((|constructor| (NIL "This type is used to specify a range of values from type \\spad{S}."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-846))) (|HasCategory| |#1| (QUOTE (-1098)))) 
-(-1093 S L) 
+((|HasCategory| |#1| (QUOTE (-867))) (|HasCategory| |#1| (QUOTE (-1119)))) 
+(-1114 S L) 
 ((|constructor| (NIL "This category provides an interface for expanding segments to a stream of elements.")) (|map| ((|#2| (|Mapping| |#1| |#1|) $) "\\spad{map(f,l..h by \\spad{k)}} produces a value of type \\spad{L} by applying \\spad{f} to each of the succesive elements of the segment, that is, \\spad{[f(l), f(l+k), ..., f(lN)]}, where \\spad{lN \\spad{<=} \\spad{h} < lN+k}.")) (|expand| ((|#2| $) "\\spad{expand(l..h by \\spad{k)}} creates value of type \\spad{L} with elements \\spad{l, l+k, \\spad{...} \\spad{lN}} where \\spad{lN \\spad{<=} \\spad{h} < lN+k}. For example, \\spad{expand(1..5 by 2) = [1,3,5]}.") ((|#2| (|List| $)) "\\spad{expand(l)} creates a new value of type \\spad{L} in which each segment \\spad{l..h by \\spad{k}} is replaced with \\spad{l, l+k, \\spad{...} lN}, where \\spad{lN \\spad{<=} \\spad{h} < lN+k}. For example, \\spad{expand [1..4, 7..9] = [1,2,3,4,7,8,9]}."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-1094 A S) 
+(-1115 A S) 
 ((|constructor| (NIL "A set category lists a collection of set-theoretic operations useful for both finite sets and multisets. Note however that finite sets are distinct from multisets. Although the operations defined for set categories are common to both, the relationship between the two cannot be described by inclusion or inheritance.")) (|union| (($ |#2| $) "\\spad{union(x,u)} returns the set aggregate \\spad{u} with the element \\spad{x} added. If \\spad{u} already contains \\spad{x,} \\axiom{union(x,u)} returns a copy of u.") (($ $ |#2|) "\\spad{union(u,x)} returns the set aggregate \\spad{u} with the element \\spad{x} added. If \\spad{u} already contains \\spad{x,} \\axiom{union(u,x)} returns a copy of u.") (($ $ $) "\\spad{union(u,v)} returns the set aggregate of elements which are members of either set aggregate \\spad{u} or \\spad{v.}")) (|subset?| (((|Boolean|) $ $) "\\spad{subset?(u,v)} tests if \\spad{u} is a subset of \\spad{v.} Note that equivalent to \\axiom{reduce(and,{member?(x,v) for \\spad{x} in u},true,false)}.")) (|symmetricDifference| (($ $ $) "\\spad{symmetricDifference(u,v)} returns the set aggregate of elements \\spad{x} which are members of set aggregate \\spad{u} or set aggregate \\spad{v} but not both. If \\spad{u} and \\spad{v} have no elements in common, \\axiom{symmetricDifference(u,v)} returns a copy of u. Note that \\axiom{symmetricDifference(u,v) = \\indented{1}{union(difference(u,v),difference(v,u))}}")) (|difference| (($ $ |#2|) "\\spad{difference(u,x)} returns the set aggregate \\spad{u} with element \\spad{x} removed. If \\spad{u} does not contain \\spad{x,} a copy of \\spad{u} is returned. Note that \\axiom{difference(s, \\spad{x)} = difference(s, {x})}.") (($ $ $) "\\spad{difference(u,v)} returns the set aggregate \\spad{w} consisting of elements in set aggregate \\spad{u} but not in set aggregate \\spad{v.} If \\spad{u} and \\spad{v} have no elements in common, \\axiom{difference(u,v)} returns a copy of u. Note that equivalent to the notation (not currently supported) \\axiom{{x for \\spad{x} in \\spad{u} | not member?(x,v)}}.")) (|intersect| (($ $ $) "\\spad{intersect(u,v)} returns the set aggregate \\spad{w} consisting of elements common to both set aggregates \\spad{u} and \\spad{v.} Note that equivalent to the notation (not currently supported) \\spad{{x} for \\spad{x} in \\spad{u} | member?(x,v)}.")) (|set| (($ (|List| |#2|)) "\\spad{set([x,y,...,z])} creates a set aggregate containing items x,y,...,z.") (($) "\\spad{set()}$D creates an empty set aggregate of type \\spad{D.}")) (|brace| (($ (|List| |#2|)) "\\spad{brace([x,y,...,z])} creates a set aggregate containing items x,y,...,z. This form is considered obsolete. Use \\axiomFun{set} instead.") (($) "\\spad{brace()}$D (otherwise written {}$D) creates an empty set aggregate of type \\spad{D.} This form is considered obsolete. Use \\axiomFun{set} instead.")) (< (((|Boolean|) $ $) "\\spad{s < \\spad{t}} returns \\spad{true} if all elements of set aggregate \\spad{s} are also elements of set aggregate \\spad{t.}"))) 
 NIL 
 NIL 
-(-1095 S) 
+(-1116 S) 
 ((|constructor| (NIL "A set category lists a collection of set-theoretic operations useful for both finite sets and multisets. Note however that finite sets are distinct from multisets. Although the operations defined for set categories are common to both, the relationship between the two cannot be described by inclusion or inheritance.")) (|union| (($ |#1| $) "\\spad{union(x,u)} returns the set aggregate \\spad{u} with the element \\spad{x} added. If \\spad{u} already contains \\spad{x,} \\axiom{union(x,u)} returns a copy of u.") (($ $ |#1|) "\\spad{union(u,x)} returns the set aggregate \\spad{u} with the element \\spad{x} added. If \\spad{u} already contains \\spad{x,} \\axiom{union(u,x)} returns a copy of u.") (($ $ $) "\\spad{union(u,v)} returns the set aggregate of elements which are members of either set aggregate \\spad{u} or \\spad{v.}")) (|subset?| (((|Boolean|) $ $) "\\spad{subset?(u,v)} tests if \\spad{u} is a subset of \\spad{v.} Note that equivalent to \\axiom{reduce(and,{member?(x,v) for \\spad{x} in u},true,false)}.")) (|symmetricDifference| (($ $ $) "\\spad{symmetricDifference(u,v)} returns the set aggregate of elements \\spad{x} which are members of set aggregate \\spad{u} or set aggregate \\spad{v} but not both. If \\spad{u} and \\spad{v} have no elements in common, \\axiom{symmetricDifference(u,v)} returns a copy of u. Note that \\axiom{symmetricDifference(u,v) = \\indented{1}{union(difference(u,v),difference(v,u))}}")) (|difference| (($ $ |#1|) "\\spad{difference(u,x)} returns the set aggregate \\spad{u} with element \\spad{x} removed. If \\spad{u} does not contain \\spad{x,} a copy of \\spad{u} is returned. Note that \\axiom{difference(s, \\spad{x)} = difference(s, {x})}.") (($ $ $) "\\spad{difference(u,v)} returns the set aggregate \\spad{w} consisting of elements in set aggregate \\spad{u} but not in set aggregate \\spad{v.} If \\spad{u} and \\spad{v} have no elements in common, \\axiom{difference(u,v)} returns a copy of u. Note that equivalent to the notation (not currently supported) \\axiom{{x for \\spad{x} in \\spad{u} | not member?(x,v)}}.")) (|intersect| (($ $ $) "\\spad{intersect(u,v)} returns the set aggregate \\spad{w} consisting of elements common to both set aggregates \\spad{u} and \\spad{v.} Note that equivalent to the notation (not currently supported) \\spad{{x} for \\spad{x} in \\spad{u} | member?(x,v)}.")) (|set| (($ (|List| |#1|)) "\\spad{set([x,y,...,z])} creates a set aggregate containing items x,y,...,z.") (($) "\\spad{set()}$D creates an empty set aggregate of type \\spad{D.}")) (|brace| (($ (|List| |#1|)) "\\spad{brace([x,y,...,z])} creates a set aggregate containing items x,y,...,z. This form is considered obsolete. Use \\axiomFun{set} instead.") (($) "\\spad{brace()}$D (otherwise written {}$D) creates an empty set aggregate of type \\spad{D.} This form is considered obsolete. Use \\axiomFun{set} instead.")) (< (((|Boolean|) $ $) "\\spad{s < \\spad{t}} returns \\spad{true} if all elements of set aggregate \\spad{s} are also elements of set aggregate \\spad{t.}"))) 
-((-4592 . T) (-3389 . T)) 
+((-4615 . T) (-2623 . T)) 
 NIL 
-(-1096) 
+(-1117) 
 ((|constructor| (NIL "This is part of the PAFF package, related to projective space."))) 
 NIL 
 NIL 
-(-1097 S) 
+(-1118 S) 
 ((|constructor| (NIL "\\spadtype{SetCategory} is the basic category for describing a collection of elements with \\spadop{=} (equality) and \\spadfun{coerce} to output form. \\blankline Conditional Attributes\\br \\tab{5}canonical\\tab{5}data structure equality is the same as \\spadop{=}")) (|latex| (((|String|) $) "\\spad{latex(s)} returns a LaTeX-printable output representation of \\spad{s.}")) (|hash| (((|SingleInteger|) $) "\\spad{hash(s)} calculates a hash code for \\spad{s.}"))) 
 NIL 
 NIL 
-(-1098) 
+(-1119) 
 ((|constructor| (NIL "\\spadtype{SetCategory} is the basic category for describing a collection of elements with \\spadop{=} (equality) and \\spadfun{coerce} to output form. \\blankline Conditional Attributes\\br \\tab{5}canonical\\tab{5}data structure equality is the same as \\spadop{=}")) (|latex| (((|String|) $) "\\spad{latex(s)} returns a LaTeX-printable output representation of \\spad{s.}")) (|hash| (((|SingleInteger|) $) "\\spad{hash(s)} calculates a hash code for \\spad{s.}"))) 
 NIL 
 NIL 
-(-1099 |m| |n|) 
+(-1120 |m| |n|) 
 ((|constructor| (NIL "\\spadtype{SetOfMIntegersInOneToN} implements the subsets of \\spad{M} integers in the interval \\spad{[1..n]}")) (|delta| (((|NonNegativeInteger|) $ (|PositiveInteger|) (|PositiveInteger|)) "\\spad{delta(S,k,p)} returns the number of elements of \\spad{S} which are strictly between \\spad{p} and the k^{th} element of \\spad{S.}")) (|member?| (((|Boolean|) (|PositiveInteger|) $) "\\spad{member?(p, \\spad{s)}} returns \\spad{true} is \\spad{p} is in \\spad{s,} \\spad{false} otherwise.")) (|enumerate| (((|Vector| $)) "\\spad{enumerate()} returns a vector of all the sets of \\spad{M} integers in \\spad{1..n}.")) (|setOfMinN| (($ (|List| (|PositiveInteger|))) "\\spad{setOfMinN([a_1,...,a_m])} returns the set {a_1,...,a_m}. Error if {a_1,...,a_m} is not a set of \\spad{M} integers in \\spad{1..n}.")) (|elements| (((|List| (|PositiveInteger|)) $) "\\spad{elements(S)} returns the list of the elements of \\spad{S} in increasing order.")) (|replaceKthElement| (((|Union| $ "failed") $ (|PositiveInteger|) (|PositiveInteger|)) "\\spad{replaceKthElement(S,k,p)} replaces the k^{th} element of \\spad{S} by \\spad{p,} and returns \"failed\" if the result is not a set of \\spad{M} integers in \\spad{1..n} any more.")) (|incrementKthElement| (((|Union| $ "failed") $ (|PositiveInteger|)) "\\spad{incrementKthElement(S,k)} increments the k^{th} element of \\spad{S,} and returns \"failed\" if the result is not a set of \\spad{M} integers in \\spad{1..n} any more."))) 
 NIL 
 NIL 
-(-1100 S) 
+(-1121 S) 
 ((|constructor| (NIL "A set over a domain \\spad{D} models the usual mathematical notion of a finite set of elements from \\spad{D.} Sets are unordered collections of distinct elements (that is, order and duplication does not matter). The notation \\spad{set [a,b,c]} can be used to create a set and the usual operations such as union and intersection are available to form new sets. In our implementation, \\Language{} maintains the entries in sorted order. Specifically, the parts function returns the entries as a list in ascending order and the extract operation returns the maximum entry. Given two sets \\spad{s} and \\spad{t} where \\spad{\\#s = \\spad{m}} and \\spad{\\#t = \\spad{n},} the complexity of\\br \\tab{5}\\spad{s = \\spad{t}} is \\spad{O(min(n,m))}\\br \\tab{5}\\spad{s < \\spad{t}} is \\spad{O(max(n,m))}\\br \\tab{5}\\spad{union(s,t)}, \\spad{intersect(s,t)}, \\spad{minus(s,t)},\\br \\tab{10 \\spad{symmetricDifference(s,t)} is \\spad{O(max(n,m))}\\br \\tab{5}\\spad{member(x,t)} is \\spad{O(n log n)}\\br \\tab{5}\\spad{insert(x,t)} and \\spad{remove(x,t)} is \\spad{O(n)}"))) 
-((-4602 . T) (-4592 . T) (-4603 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-374))) (|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (QUOTE (-848))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-374)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-1101 |Str| |Sym| |Int| |Flt| |Expr|) 
+((-4625 . T) (-4615 . T) (-4626 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-394))) (|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (QUOTE (-869))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-394)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-1122 |Str| |Sym| |Int| |Flt| |Expr|) 
 ((|constructor| (NIL "This category allows the manipulation of Lisp values while keeping the grunge fairly localized.")) (|elt| (($ $ (|List| (|Integer|))) "\\spad{elt((a1,...,an), [i1,...,im])} returns \\spad{(a_i1,...,a_im)}.") (($ $ (|Integer|)) "\\spad{elt((a1,...,an), i)} returns \\spad{ai}.")) (|#| (((|Integer|) $) "\\spad{\\#((a1,...,an))} returns \\spad{n.}")) (|cdr| (($ $) "\\spad{cdr((a1,...,an))} returns \\spad{(a2,...,an)}.")) (|car| (($ $) "\\spad{car((a1,...,an))} returns a1.")) (|convert| (($ |#5|) "\\spad{convert(x)} returns the Lisp atom \\spad{x.}") (($ |#4|) "\\spad{convert(x)} returns the Lisp atom \\spad{x.}") (($ |#3|) "\\spad{convert(x)} returns the Lisp atom \\spad{x.}") (($ |#2|) "\\spad{convert(x)} returns the Lisp atom \\spad{x.}") (($ |#1|) "\\spad{convert(x)} returns the Lisp atom \\spad{x;}") (($ (|List| $)) "\\spad{convert([a1,...,an])} returns an S-expression \\spad{(a1,...,an)}.")) (|expr| ((|#5| $) "\\spad{expr(s)} returns \\spad{s} as an element of Expr; Error: if \\spad{s} is not an atom that also belongs to Expr.")) (|float| ((|#4| $) "\\spad{float(s)} returns \\spad{s} as an element of Flt; Error: if \\spad{s} is not an atom that also belongs to Flt.")) (|integer| ((|#3| $) "\\spad{integer(s)} returns \\spad{s} as an element of Int. Error: if \\spad{s} is not an atom that also belongs to Int.")) (|symbol| ((|#2| $) "\\spad{symbol(s)} returns \\spad{s} as an element of Sym. Error: if \\spad{s} is not an atom that also belongs to Sym.")) (|string| ((|#1| $) "\\spad{string(s)} returns \\spad{s} as an element of Str. Error: if \\spad{s} is not an atom that also belongs to Str.")) (|destruct| (((|List| $) $) "\\spad{destruct((a1,...,an))} returns the list [a1,...,an].")) (|float?| (((|Boolean|) $) "\\spad{float?(s)} is \\spad{true} if \\spad{s} is an atom and belong to Flt.")) (|integer?| (((|Boolean|) $) "\\spad{integer?(s)} is \\spad{true} if \\spad{s} is an atom and belong to Int.")) (|symbol?| (((|Boolean|) $) "\\spad{symbol?(s)} is \\spad{true} if \\spad{s} is an atom and belong to Sym.")) (|string?| (((|Boolean|) $) "\\spad{string?(s)} is \\spad{true} if \\spad{s} is an atom and belong to Str.")) (|list?| (((|Boolean|) $) "\\spad{list?(s)} is \\spad{true} if \\spad{s} is a Lisp list, possibly \\spad{().}")) (|pair?| (((|Boolean|) $) "\\spad{pair?(s)} is \\spad{true} if \\spad{s} has is a non-null Lisp list.")) (|atom?| (((|Boolean|) $) "\\spad{atom?(s)} is \\spad{true} if \\spad{s} is a Lisp atom.")) (|null?| (((|Boolean|) $) "\\spad{null?(s)} is \\spad{true} if \\spad{s} is the S-expression \\spad{().}")) (|eq| (((|Boolean|) $ $) "\\spad{eq(s, \\spad{t)}} is \\spad{true} if EQ(s,t) is \\spad{true} in Lisp."))) 
 NIL 
 NIL 
-(-1102) 
+(-1123) 
 ((|constructor| (NIL "This domain allows the manipulation of the usual Lisp values."))) 
 NIL 
 NIL 
-(-1103 |Str| |Sym| |Int| |Flt| |Expr|) 
+(-1124 |Str| |Sym| |Int| |Flt| |Expr|) 
 ((|constructor| (NIL "This domain allows the manipulation of Lisp values over arbitrary atomic types."))) 
 NIL 
 NIL 
-(-1104 R FS) 
+(-1125 R FS) 
 ((|constructor| (NIL "\\axiomType{SimpleFortranProgram(f,type)} provides a simple model of some FORTRAN subprograms, making it possible to coerce objects of various domains into a FORTRAN subprogram called \\axiom{f}. These can then be translated into legal FORTRAN code.")) (|fortran| (($ (|Symbol|) (|FortranScalarType|) |#2|) "\\spad{fortran(fname,ftype,body)} builds an object of type \\axiomType{FortranProgramCategory}. The three arguments specify the name, the type and the \\spad{body} of the program."))) 
 NIL 
 NIL 
-(-1105 R E V P TS) 
+(-1126 R E V P TS) 
 ((|constructor| (NIL "A internal package for removing redundant quasi-components and redundant branches when decomposing a variety by means of quasi-components of regular triangular sets.")) (|branchIfCan| (((|Union| (|Record| (|:| |eq| (|List| |#4|)) (|:| |tower| |#5|) (|:| |ineq| (|List| |#4|))) "failed") (|List| |#4|) |#5| (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{branchIfCan(leq,ts,lineq,b1,b2,b3,b4,b5)} is an internal subroutine, exported only for developement.")) (|prepareDecompose| (((|List| (|Record| (|:| |eq| (|List| |#4|)) (|:| |tower| |#5|) (|:| |ineq| (|List| |#4|)))) (|List| |#4|) (|List| |#5|) (|Boolean|) (|Boolean|)) "\\axiom{prepareDecompose(lp,lts,b1,b2)} is an internal subroutine, exported only for developement.")) (|removeSuperfluousCases| (((|List| (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|))) (|List| (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|)))) "\\axiom{removeSuperfluousCases(llpwt)} is an internal subroutine, exported only for developement.")) (|subCase?| (((|Boolean|) (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|)) (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|))) "\\axiom{subCase?(lpwt1,lpwt2)} is an internal subroutine, exported only for developement.")) (|removeSuperfluousQuasiComponents| (((|List| |#5|) (|List| |#5|)) "\\axiom{removeSuperfluousQuasiComponents(lts)} removes from \\axiom{lts} any \\spad{ts} such that \\axiom{subQuasiComponent?(ts,us)} holds for another \\spad{us} in \\axiom{lts}.")) (|subQuasiComponent?| (((|Boolean|) |#5| (|List| |#5|)) "\\axiom{subQuasiComponent?(ts,lus)} returns \\spad{true} iff \\axiom{subQuasiComponent?(ts,us)} holds for one \\spad{us} in \\spad{lus}.") (((|Boolean|) |#5| |#5|) "\\axiom{subQuasiComponent?(ts,us)} returns \\spad{true} iff internalSubQuasiComponent?(ts,us) from QuasiComponentPackage returns true.")) (|internalSubQuasiComponent?| (((|Union| (|Boolean|) "failed") |#5| |#5|) "\\axiom{internalSubQuasiComponent?(ts,us)} returns a boolean \\spad{b} value if the fact the regular zero set of \\axiom{us} contains that of \\axiom{ts} can be decided (and in that case \\axiom{b} gives this inclusion) otherwise returns \\axiom{\"failed\"}.")) (|infRittWu?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{infRittWu?(lp1,lp2)} is an internal subroutine, exported only for developement.")) (|internalInfRittWu?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{internalInfRittWu?(lp1,lp2)} is an internal subroutine, exported only for developement.")) (|internalSubPolSet?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{internalSubPolSet?(lp1,lp2)} returns \\spad{true} iff \\axiom{lp1} is a sub-set of \\axiom{lp2} assuming that these lists are sorted increasingly w.r.t. infRittWu? from RecursivePolynomialCategory.")) (|subPolSet?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{subPolSet?(lp1,lp2)} returns \\spad{true} iff \\axiom{lp1} is a sub-set of \\axiom{lp2}.")) (|subTriSet?| (((|Boolean|) |#5| |#5|) "\\axiom{subTriSet?(ts,us)} returns \\spad{true} iff \\axiom{ts} is a sub-set of \\axiom{us}.")) (|moreAlgebraic?| (((|Boolean|) |#5| |#5|) "\\axiom{moreAlgebraic?(ts,us)} returns \\spad{false} iff \\axiom{ts} and \\axiom{us} are both empty, or \\axiom{ts} has less elements than \\axiom{us}, or some variable is algebraic w.r.t. \\axiom{us} and is not w.r.t. \\axiom{ts}.")) (|algebraicSort| (((|List| |#5|) (|List| |#5|)) "\\axiom{algebraicSort(lts)} sorts \\axiom{lts} w.r.t supDimElseRittWu from QuasiComponentPackage.")) (|supDimElseRittWu?| (((|Boolean|) |#5| |#5|) "\\axiom{supDimElseRittWu(ts,us)} returns \\spad{true} iff \\axiom{ts} has less elements than \\axiom{us} otherwise if \\axiom{ts} has higher rank than \\axiom{us} w.r.t. Riit and Wu ordering.")) (|stopTable!| (((|Void|)) "\\axiom{stopTableGcd!()} is an internal subroutine, exported only for developement.")) (|startTable!| (((|Void|) (|String|) (|String|) (|String|)) "\\axiom{startTableGcd!(s1,s2,s3)} is an internal subroutine, exported only for developement."))) 
 NIL 
 NIL 
-(-1106 R E V P TS) 
+(-1127 R E V P TS) 
 ((|constructor| (NIL "A internal package for computing gcds and resultants of univariate polynomials with coefficients in a tower of simple extensions of a field. There is no need to use directly this package since its main operations are available from \\spad{TS}."))) 
 NIL 
 NIL 
-(-1107 R E V P) 
+(-1128 R E V P) 
 ((|constructor| (NIL "The category of square-free regular triangular sets. A regular triangular set \\spad{ts} is square-free if the \\spad{gcd} of any polynomial \\spad{p} in \\spad{ts} and differentiate(p,mvar(p)) w.r.t. collectUnder(ts,mvar(p)) has degree zero w.r.t. \\spad{mvar(p)}. Thus any square-free regular set defines a tower of square-free simple extensions."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-1108) 
+(-1129) 
 ((|constructor| (NIL "SymmetricGroupCombinatoricFunctions contains combinatoric functions concerning symmetric groups and representation theory: list young tableaus, improper partitions, subsets bijection of Coleman.")) (|unrankImproperPartitions1| (((|List| (|Integer|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{unrankImproperPartitions1(n,m,k)} computes the \\spad{k}-th improper partition of nonnegative \\spad{n} in at most \\spad{m} nonnegative parts ordered as follows: first, in reverse lexicographically according to their non-zero parts, then according to their positions (\\spadignore{i.e.} lexicographical order using subSet: [3,0,0] < [0,3,0] < [0,0,3] < [2,1,0] < [2,0,1] < [0,2,1] < [1,2,0] < [1,0,2] < [0,1,2] < [1,1,1]. Note that counting of subtrees is done by numberOfImproperPartitionsInternal.")) (|unrankImproperPartitions0| (((|List| (|Integer|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{unrankImproperPartitions0(n,m,k)} computes the \\spad{k}-th improper partition of nonnegative \\spad{n} in \\spad{m} nonnegative parts in reverse lexicographical order. Example: [0,0,3] < [0,1,2] < [0,2,1] < [0,3,0] < [1,0,2] < [1,1,1] < [1,2,0] < [2,0,1] < [2,1,0] < [3,0,0]. Error: if \\spad{k} is negative or too big. Note that counting of subtrees is done by numberOfImproperPartitions")) (|subSet| (((|List| (|Integer|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{subSet(n,m,k)} calculates the \\spad{k}-th m-subset of the set 0,1,...,(n-1) in the lexicographic order considered as a decreasing map from 0,...,(m-1) into 0,...,(n-1). See S.G. Williamson: Theorem 1.60. Error: if not \\spad{(0} \\spad{<=} \\spad{m} \\spad{<=} \\spad{n} and 0 < = \\spad{k} < \\spad{(n} choose m)).")) (|numberOfImproperPartitions| (((|Integer|) (|Integer|) (|Integer|)) "\\spad{numberOfImproperPartitions(n,m)} computes the number of partitions of the nonnegative integer \\spad{n} in \\spad{m} nonnegative parts with regarding the order (improper partitions). Example: numberOfImproperPartitions (3,3) is 10, since [0,0,3], [0,1,2], [0,2,1], [0,3,0], [1,0,2], [1,1,1], [1,2,0], [2,0,1], [2,1,0], [3,0,0] are the possibilities. Note that this operation has a recursive implementation.")) (|nextPartition| (((|Vector| (|Integer|)) (|List| (|Integer|)) (|Vector| (|Integer|)) (|Integer|)) "\\spad{nextPartition(gamma,part,number)} generates the partition of \\spad{number} which follows \\spad{part} according to the right-to-left lexicographical order. The partition has the property that its components do not exceed the corresponding components of gamma. the first partition is achieved by part=[]. Also, \\spad{[]} indicates that \\spad{part} is the last partition.") (((|Vector| (|Integer|)) (|Vector| (|Integer|)) (|Vector| (|Integer|)) (|Integer|)) "\\spad{nextPartition(gamma,part,number)} generates the partition of \\spad{number} which follows \\spad{part} according to the right-to-left lexicographical order. The partition has the property that its components do not exceed the corresponding components of gamma. The first partition is achieved by part=[]. Also, \\spad{[]} indicates that \\spad{part} is the last partition.")) (|nextLatticePermutation| (((|List| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|)) (|Boolean|)) "\\spad{nextLatticePermutation(lambda,lattP,constructNotFirst)} generates the lattice permutation according to the proper partition \\spad{lambda} succeeding the lattice permutation \\spad{lattP} in lexicographical order as long as \\spad{constructNotFirst} is true. If \\spad{constructNotFirst} is false, the first lattice permutation is returned. The result nil indicates that \\spad{lattP} has no successor.")) (|nextColeman| (((|Matrix| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|)) (|Matrix| (|Integer|))) "\\spad{nextColeman(alpha,beta,C)} generates the next Coleman matrix of column sums \\spad{alpha} and row sums \\spad{beta} according to the lexicographical order from bottom-to-top. The first Coleman matrix is achieved by C=new(1,1,0). Also, new(1,1,0) indicates that \\spad{C} is the last Coleman matrix.")) (|makeYoungTableau| (((|Matrix| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{makeYoungTableau(lambda,gitter)} computes for a given lattice permutation \\spad{gitter} and for an improper partition \\spad{lambda} the corresponding standard tableau of shape lambda. Notes: see listYoungTableaus. The entries are from 0,...,n-1.")) (|listYoungTableaus| (((|List| (|Matrix| (|Integer|))) (|List| (|Integer|))) "\\spad{listYoungTableaus(lambda)} where \\spad{lambda} is a proper partition generates the list of all standard tableaus of shape \\spad{lambda} by means of lattice permutations. The numbers of the lattice permutation are interpreted as column labels. Hence the contents of these lattice permutations are the conjugate of lambda. Notes: the functions nextLatticePermutation and makeYoungTableau are used. The entries are from 0,...,n-1.")) (|inverseColeman| (((|List| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|)) (|Matrix| (|Integer|))) "\\spad{inverseColeman(alpha,beta,C)}: there is a bijection from the set of matrices having nonnegative entries and row sums alpha, column sums \\spad{beta} to the set of Salpha - Sbeta double cosets of the symmetric group \\spad{Sn.} (Salpha is the Young subgroup corresponding to the improper partition alpha). For such a matrix \\spad{C,} inverseColeman(alpha,beta,C) calculates the lexicographical smallest \\spad{pi} in the corresponding double coset. Note that the resulting permutation \\spad{pi} of {1,2,...,n} is given in list form. Notes: the inverse of this map is coleman. For details, see James/Kerber.")) (|coleman| (((|Matrix| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{coleman(alpha,beta,pi)}: there is a bijection from the set of matrices having nonnegative entries and row sums alpha, column sums \\spad{beta} to the set of Salpha - Sbeta double cosets of the symmetric group \\spad{Sn.} (Salpha is the Young subgroup corresponding to the improper partition alpha). For a representing element \\spad{pi} of such a double coset, coleman(alpha,beta,pi) generates the Coleman-matrix corresponding to alpha, beta, pi. Note that The permutation \\spad{pi} of {1,2,...,n} has to be given in list form. Note that the inverse of this map is inverseColeman (if \\spad{pi} is the lexicographical smallest permutation in the coset). For details see James/Kerber."))) 
 NIL 
 NIL 
-(-1109 S) 
+(-1130 S) 
 ((|constructor| (NIL "the class of all multiplicative semigroups, that is, a set with an associative operation \\spadop{*}. \\blankline Axioms\\br \\tab{5}\\spad{associative(\"*\":(\\%,\\%)->\\%)}\\tab{5}\\spad{(x*y)*z = x*(y*z)} \\blankline Conditional attributes\\br \\tab{5}\\spad{commutative(\"*\":(\\%,\\%)->\\%)}\\tab{5}\\spad{x*y = y*x}")) (^ (($ $ (|PositiveInteger|)) "\\spad{x^n} returns the repeated product of \\spad{x} \\spad{n} times, exponentiation.")) (** (($ $ (|PositiveInteger|)) "\\spad{x**n} returns the repeated product of \\spad{x} \\spad{n} times, exponentiation.")) (* (($ $ $) "\\spad{x*y} returns the product of \\spad{x} and \\spad{y.}"))) 
 NIL 
 NIL 
-(-1110) 
+(-1131) 
 ((|constructor| (NIL "the class of all multiplicative semigroups, that is, a set with an associative operation \\spadop{*}. \\blankline Axioms\\br \\tab{5}\\spad{associative(\"*\":(\\%,\\%)->\\%)}\\tab{5}\\spad{(x*y)*z = x*(y*z)} \\blankline Conditional attributes\\br \\tab{5}\\spad{commutative(\"*\":(\\%,\\%)->\\%)}\\tab{5}\\spad{x*y = y*x}")) (^ (($ $ (|PositiveInteger|)) "\\spad{x^n} returns the repeated product of \\spad{x} \\spad{n} times, exponentiation.")) (** (($ $ (|PositiveInteger|)) "\\spad{x**n} returns the repeated product of \\spad{x} \\spad{n} times, exponentiation.")) (* (($ $ $) "\\spad{x*y} returns the product of \\spad{x} and \\spad{y.}"))) 
 NIL 
 NIL 
-(-1111 |dimtot| |dim1| S) 
+(-1132 |dimtot| |dim1| S) 
 ((|constructor| (NIL "This type represents the finite direct or cartesian product of an underlying ordered component type. The vectors are ordered as if they were split into two blocks. The \\spad{dim1} parameter specifies the length of the first block. The ordering is lexicographic between the blocks but acts like \\spadtype{HomogeneousDirectProduct} within each block. This type is a suitable third argument for \\spadtype{GeneralDistributedMultivariatePolynomial}."))) 
-((-4596 |has| |#3| (-1054)) (-4597 |has| |#3| (-1054)) (-4599 |has| |#3| (-6 -4599)) ((-4604 "*") |has| |#3| (-174)) (-4602 . T)) 
-((|HasCategory| |#3| (QUOTE (-1098))) (|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-1054))) (|HasCategory| |#3| (QUOTE (-794))) (|HasCategory| |#3| (QUOTE (-846))) (-1841 (|HasCategory| |#3| (QUOTE (-794))) (|HasCategory| |#3| (QUOTE (-846)))) (|HasCategory| |#3| (QUOTE (-722))) (|HasCategory| |#3| (QUOTE (-174))) (-1841 (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-1054)))) (-1841 (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-368)))) (-1841 (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-1054)))) (|HasCategory| |#3| (QUOTE (-374))) (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-227))) (-1841 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-1054)))) (-1841 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-1054)))) (|HasCategory| (-572) (QUOTE (-848))) (-12 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1098)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-1098)))) (|HasAttribute| |#3| (QUOTE -4599)) (|HasCategory| |#3| (QUOTE (-138))) (-1841 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-138))) (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-1054)))) (|HasCategory| |#3| (QUOTE (-25))) (-1841 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-138))) (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-374))) (|HasCategory| |#3| (QUOTE (-722))) (|HasCategory| |#3| (QUOTE (-794))) (|HasCategory| |#3| (QUOTE (-846))) (|HasCategory| |#3| (QUOTE (-1054))) (|HasCategory| |#3| (QUOTE (-1098)))) (-1841 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-138))) (|HasCategory| |#3| (QUOTE (-174))) (|HasCategory| |#3| (QUOTE (-227))) (|HasCategory| |#3| (QUOTE (-368))) (|HasCategory| |#3| (QUOTE (-1054)))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-138)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-174)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-227)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-368)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-374)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-722)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-794)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-846)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#3| (QUOTE (-1098))))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-138)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-174)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-227)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-368)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-374)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-722)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-794)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-846)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#3| (QUOTE (-1098))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -901) (QUOTE (-1170))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-138)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-174)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-227)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-368)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-374)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-722)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-794)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-846)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1054)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -305) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1098)))))) 
-(-1112 R |x|) 
+((-4619 |has| |#3| (-1075)) (-4620 |has| |#3| (-1075)) (-4622 |has| |#3| (-6 -4622)) ((-4627 "*") |has| |#3| (-194)) (-4625 . T)) 
+((|HasCategory| |#3| (QUOTE (-1119))) (|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-1075))) (|HasCategory| |#3| (QUOTE (-815))) (|HasCategory| |#3| (QUOTE (-867))) (-3836 (|HasCategory| |#3| (QUOTE (-815))) (|HasCategory| |#3| (QUOTE (-867)))) (|HasCategory| |#3| (QUOTE (-743))) (|HasCategory| |#3| (QUOTE (-194))) (-3836 (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-1075)))) (-3836 (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-388)))) (-3836 (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-1075)))) (|HasCategory| |#3| (QUOTE (-394))) (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-247))) (-3836 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-1075)))) (-3836 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-1075)))) (|HasCategory| (-592) (QUOTE (-869))) (-12 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1119)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-1119)))) (|HasAttribute| |#3| (QUOTE -4622)) (|HasCategory| |#3| (QUOTE (-158))) (-3836 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-158))) (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-1075)))) (|HasCategory| |#3| (QUOTE (-25))) (-3836 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-158))) (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-394))) (|HasCategory| |#3| (QUOTE (-743))) (|HasCategory| |#3| (QUOTE (-815))) (|HasCategory| |#3| (QUOTE (-867))) (|HasCategory| |#3| (QUOTE (-1075))) (|HasCategory| |#3| (QUOTE (-1119)))) (-3836 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-158))) (|HasCategory| |#3| (QUOTE (-194))) (|HasCategory| |#3| (QUOTE (-247))) (|HasCategory| |#3| (QUOTE (-388))) (|HasCategory| |#3| (QUOTE (-1075)))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-158)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-194)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-247)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-388)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-394)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-743)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-815)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-867)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#3| (QUOTE (-1119))))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-158)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-194)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-247)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-388)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-394)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-743)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-815)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-867)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#3| (QUOTE (-1119))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -922) (QUOTE (-1191))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-158)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-194)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-247)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-388)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-394)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-743)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-815)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-867)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1075)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -325) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1119)))))) 
+(-1133 R |x|) 
 ((|constructor| (NIL "This package produces functions for counting etc. real roots of univariate polynomials in \\spad{x} over \\spad{R,} which must be an OrderedIntegralDomain")) (|countRealRootsMultiple| (((|Integer|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{countRealRootsMultiple(p)} says how many real roots \\spad{p} has, counted with multiplicity")) (|SturmHabichtMultiple| (((|Integer|) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{SturmHabichtMultiple(p1,p2)} computes c_{+}-c_{-} where c_{+} is the number of real roots of \\spad{p1} with \\spad{p2>0} and c_{-} is the number of real roots of \\spad{p1} with p2<0. If \\spad{p2=1} what you get is the number of real roots of \\spad{p1.}")) (|countRealRoots| (((|Integer|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{countRealRoots(p)} says how many real roots \\spad{p} has")) (|SturmHabicht| (((|Integer|) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{SturmHabicht(p1,p2)} computes c_{+}-c_{-} where c_{+} is the number of real roots of \\spad{p1} with \\spad{p2>0} and c_{-} is the number of real roots of \\spad{p1} with p2<0. If \\spad{p2=1} what you get is the number of real roots of \\spad{p1.}")) (|SturmHabichtCoefficients| (((|List| |#1|) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{SturmHabichtCoefficients(p1,p2)} computes the principal Sturm-Habicht coefficients of \\spad{p1} and \\spad{p2}")) (|SturmHabichtSequence| (((|List| (|UnivariatePolynomial| |#2| |#1|)) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{SturmHabichtSequence(p1,p2)} computes the Sturm-Habicht sequence of \\spad{p1} and \\spad{p2}")) (|subresultantSequence| (((|List| (|UnivariatePolynomial| |#2| |#1|)) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{subresultantSequence(p1,p2)} computes the (standard) subresultant sequence of \\spad{p1} and \\spad{p2}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-457)))) 
-(-1113 R -3313) 
+((|HasCategory| |#1| (QUOTE (-477)))) 
+(-1134 R -3958) 
 ((|constructor| (NIL "This package provides functions to determine the sign of an elementary function around a point or infinity.")) (|sign| (((|Union| (|Integer|) "failed") |#2| (|Symbol|) |#2| (|String|)) "\\spad{sign(f, \\spad{x,} a, \\spad{s)}} returns the sign of \\spad{f} as \\spad{x} nears \\spad{a} from below if \\spad{s} is \"left\", or above if \\spad{s} is \"right\".") (((|Union| (|Integer|) "failed") |#2| (|Symbol|) (|OrderedCompletion| |#2|)) "\\spad{sign(f, \\spad{x,} a)} returns the sign of \\spad{f} as \\spad{x} nears \\spad{a}, from both sides if \\spad{a} is finite.") (((|Union| (|Integer|) "failed") |#2|) "\\spad{sign(f)} returns the sign of \\spad{f} if it is constant everywhere."))) 
 NIL 
 NIL 
-(-1114 R) 
+(-1135 R) 
 ((|constructor| (NIL "Find the sign of a rational function around a point or infinity.")) (|sign| (((|Union| (|Integer|) "failed") (|Fraction| (|Polynomial| |#1|)) (|Symbol|) (|Fraction| (|Polynomial| |#1|)) (|String|)) "\\spad{sign(f, \\spad{x,} a, \\spad{s)}} returns the sign of \\spad{f} as \\spad{x} nears \\spad{a} from the left (below) if \\spad{s} is the string \\spad{\"left\"}, or from the right (above) if \\spad{s} is the string \\spad{\"right\"}.") (((|Union| (|Integer|) "failed") (|Fraction| (|Polynomial| |#1|)) (|Symbol|) (|OrderedCompletion| (|Fraction| (|Polynomial| |#1|)))) "\\spad{sign(f, \\spad{x,} a)} returns the sign of \\spad{f} as \\spad{x} approaches \\spad{a}, from both sides if \\spad{a} is finite.") (((|Union| (|Integer|) "failed") (|Fraction| (|Polynomial| |#1|))) "\\spad{sign \\spad{f}} returns the sign of \\spad{f} if it is constant everywhere."))) 
 NIL 
 NIL 
-(-1115) 
+(-1136) 
 ((|constructor| (NIL "Package to allow simplify to be called on AlgebraicNumbers by converting to EXPR(INT)")) (|simplify| (((|Expression| (|Integer|)) (|AlgebraicNumber|)) "\\spad{simplify(an)} applies simplifications to \\spad{an}"))) 
 NIL 
 NIL 
-(-1116) 
+(-1137) 
 ((|constructor| (NIL "SingleInteger is intended to support machine integer arithmetic.")) (|Or| (($ $ $) "\\spad{Or(n,m)} returns the bit-by-bit logical or of the single integers \\spad{n} and \\spad{m.}")) (|And| (($ $ $) "\\spad{And(n,m)} returns the bit-by-bit logical and of the single integers \\spad{n} and \\spad{m.}")) (|Not| (($ $) "\\spad{Not(n)} returns the bit-by-bit logical not of the single integer \\spad{n.}")) (|xor| (($ $ $) "\\spad{xor(n,m)} returns the bit-by-bit logical xor of the single integers \\spad{n} and \\spad{m.}")) (|\\/| (($ $ $) "\\spad{n} \\spad{\\/} \\spad{m} returns the bit-by-bit logical or of the single integers \\spad{n} and \\spad{m.}")) (|/\\| (($ $ $) "\\spad{n} \\spad{/\\} \\spad{m} returns the bit-by-bit logical and of the single integers \\spad{n} and \\spad{m.}")) (~ (($ $) "\\spad{~ \\spad{n}} returns the bit-by-bit logical not of the single integer \\spad{n.}")) (|not| (($ $) "\\spad{not(n)} returns the bit-by-bit logical not of the single integer \\spad{n.}")) (|min| (($) "\\spad{min()} returns the smallest single integer.")) (|max| (($) "\\spad{max()} returns the largest single integer.")) (|noetherian| ((|attribute|) "\\spad{noetherian} all ideals are finitely generated (in fact principal).")) (|canonicalsClosed| ((|attribute|) "\\spad{canonicalClosed} means two positives multiply to give positive.")) (|canonical| ((|attribute|) "\\spad{canonical} means that mathematical equality is implied by data structure equality."))) 
-((-4590 . T) (-4594 . T) (-4589 . T) (-4600 . T) (-4601 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4613 . T) (-4617 . T) (-4612 . T) (-4623 . T) (-4624 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1117 S) 
+(-1138 S) 
 ((|constructor| (NIL "A stack is a bag where the last item inserted is the first item extracted.")) (|depth| (((|NonNegativeInteger|) $) "\\spad{depth(s)} returns the number of elements of stack \\spad{s.} \\indented{1}{Note that \\axiom{depth(s) = \\#s}.} \\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} depth a")) (|top| ((|#1| $) "\\spad{top(s)} returns the top element \\spad{x} from \\spad{s;} \\spad{s} remains unchanged. \\indented{1}{Note that Use \\axiom{pop!(s)} to obtain \\spad{x} and remove it from \\spad{s.}} \\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} top a")) (|pop!| ((|#1| $) "\\spad{pop!(s)} returns the top element \\spad{x,} destructively removing \\spad{x} from \\spad{s.} \\indented{1}{Note that Use \\axiom{top(s)} to obtain \\spad{x} without removing it from \\spad{s.}} \\indented{1}{Error: if \\spad{s} is empty.} \\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} pop! a \\spad{X} a")) (|push!| ((|#1| |#1| $) "\\spad{push!(x,s)} pushes \\spad{x} onto stack \\spad{s,} that is, destructively changing \\spad{s} \\indented{1}{so as to have a new first (top) element \\spad{x.}} \\indented{1}{Afterwards, pop!(s) produces \\spad{x} and pop!(s) produces the original \\spad{s.}} \\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} push! a \\spad{X} a"))) 
-((-4602 . T) (-4603 . T) (-3389 . T)) 
+((-4625 . T) (-4626 . T) (-2623 . T)) 
 NIL 
-(-1118 S |ndim| R |Row| |Col|) 
+(-1139 S |ndim| R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{SquareMatrixCategory} is a general square matrix category which allows different representations and indexing schemes. Rows and columns may be extracted with rows returned as objects of type Row and colums returned as objects of type Col.")) (** (($ $ (|Integer|)) "\\spad{m**n} computes an integral power of the matrix \\spad{m.} Error: if the matrix is not invertible.")) (|inverse| (((|Union| $ "failed") $) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m,} if that matrix is invertible and returns \"failed\" otherwise.")) (|minordet| ((|#3| $) "\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using minors.")) (|determinant| ((|#3| $) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m.}")) (* ((|#4| |#4| $) "\\spad{r * \\spad{x}} is the product of the row vector \\spad{r} and the matrix \\spad{x.} Error: if the dimensions are incompatible.") ((|#5| $ |#5|) "\\spad{x * \\spad{c}} is the product of the matrix \\spad{x} and the column vector \\spad{c.} Error: if the dimensions are incompatible.")) (|diagonalProduct| ((|#3| $) "\\spad{diagonalProduct(m)} returns the product of the elements on the diagonal of the matrix \\spad{m.}")) (|trace| ((|#3| $) "\\spad{trace(m)} returns the trace of the matrix \\spad{m.} this is the sum of the elements on the diagonal of the matrix \\spad{m.}")) (|diagonal| ((|#4| $) "\\spad{diagonal(m)} returns a row consisting of the elements on the diagonal of the matrix \\spad{m.}")) (|diagonalMatrix| (($ (|List| |#3|)) "\\spad{diagonalMatrix(l)} returns a diagonal matrix with the elements of \\spad{l} on the diagonal.")) (|scalarMatrix| (($ |#3|) "\\spad{scalarMatrix(r)} returns an n-by-n matrix with \\spad{r's} on the diagonal and zeroes elsewhere."))) 
 NIL 
-((|HasCategory| |#3| (QUOTE (-368))) (|HasAttribute| |#3| (QUOTE (-4604 "*"))) (|HasCategory| |#3| (QUOTE (-174)))) 
-(-1119 |ndim| R |Row| |Col|) 
+((|HasCategory| |#3| (QUOTE (-388))) (|HasAttribute| |#3| (QUOTE (-4627 "*"))) (|HasCategory| |#3| (QUOTE (-194)))) 
+(-1140 |ndim| R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{SquareMatrixCategory} is a general square matrix category which allows different representations and indexing schemes. Rows and columns may be extracted with rows returned as objects of type Row and colums returned as objects of type Col.")) (** (($ $ (|Integer|)) "\\spad{m**n} computes an integral power of the matrix \\spad{m.} Error: if the matrix is not invertible.")) (|inverse| (((|Union| $ "failed") $) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m,} if that matrix is invertible and returns \"failed\" otherwise.")) (|minordet| ((|#2| $) "\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using minors.")) (|determinant| ((|#2| $) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m.}")) (* ((|#3| |#3| $) "\\spad{r * \\spad{x}} is the product of the row vector \\spad{r} and the matrix \\spad{x.} Error: if the dimensions are incompatible.") ((|#4| $ |#4|) "\\spad{x * \\spad{c}} is the product of the matrix \\spad{x} and the column vector \\spad{c.} Error: if the dimensions are incompatible.")) (|diagonalProduct| ((|#2| $) "\\spad{diagonalProduct(m)} returns the product of the elements on the diagonal of the matrix \\spad{m.}")) (|trace| ((|#2| $) "\\spad{trace(m)} returns the trace of the matrix \\spad{m.} this is the sum of the elements on the diagonal of the matrix \\spad{m.}")) (|diagonal| ((|#3| $) "\\spad{diagonal(m)} returns a row consisting of the elements on the diagonal of the matrix \\spad{m.}")) (|diagonalMatrix| (($ (|List| |#2|)) "\\spad{diagonalMatrix(l)} returns a diagonal matrix with the elements of \\spad{l} on the diagonal.")) (|scalarMatrix| (($ |#2|) "\\spad{scalarMatrix(r)} returns an n-by-n matrix with \\spad{r's} on the diagonal and zeroes elsewhere."))) 
-((-3389 . T) (-4602 . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-2623 . T) (-4625 . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1120 R |Row| |Col| M) 
+(-1141 R |Row| |Col| M) 
 ((|constructor| (NIL "\\spadtype{SmithNormalForm} is a package which provides some standard canonical forms for matrices.")) (|diophantineSystem| (((|Record| (|:| |particular| (|Union| |#3| "failed")) (|:| |basis| (|List| |#3|))) |#4| |#3|) "\\spad{diophantineSystem(A,B)} returns a particular integer solution and an integer basis of the equation \\spad{AX = \\spad{B}.}")) (|completeSmith| (((|Record| (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|) "\\spad{completeSmith} returns a record that contains the Smith normal form \\spad{H} of the matrix and the left and right equivalence matrices \\spad{U} and \\spad{V} such that U*m*v = \\spad{H}")) (|smith| ((|#4| |#4|) "\\spad{smith(m)} returns the Smith Normal form of the matrix \\spad{m.}")) (|completeHermite| (((|Record| (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|) "\\spad{completeHermite} returns a record that contains the Hermite normal form \\spad{H} of the matrix and the equivalence matrix \\spad{U} such that U*m = \\spad{H}")) (|hermite| ((|#4| |#4|) "\\spad{hermite(m)} returns the Hermite normal form of the matrix \\spad{m.}"))) 
 NIL 
 NIL 
-(-1121 R |VarSet|) 
+(-1142 R |VarSet|) 
 ((|constructor| (NIL "This type is the basic representation of sparse recursive multivariate polynomials. It is parameterized by the coefficient ring and the variable set which may be infinite. The variable ordering is determined by the variable set parameter. The coefficient ring may be non-commutative, but the variables are assumed to commute."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-1122 |Coef| |Var| SMP) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-1143 |Coef| |Var| SMP) 
 ((|constructor| (NIL "This domain provides multivariate Taylor series with variables from an arbitrary ordered set. A Taylor series is represented by a stream of polynomials from the polynomial domain SMP. The \\spad{n}th element of the stream is a form of degree \\spad{n.} SMTS is an internal domain.")) (|fintegrate| (($ (|Mapping| $) |#2| |#1|) "\\spad{fintegrate(f,v,c)} is the integral of \\spad{f()} with respect \\indented{1}{to \\spad{v} and having \\spad{c} as the constant of integration.} \\indented{1}{The evaluation of \\spad{f()} is delayed.}")) (|integrate| (($ $ |#2| |#1|) "\\spad{integrate(s,v,c)} is the integral of \\spad{s} with respect \\indented{1}{to \\spad{v} and having \\spad{c} as the constant of integration.}")) (|csubst| (((|Mapping| (|Stream| |#3|) |#3|) (|List| |#2|) (|List| (|Stream| |#3|))) "\\spad{csubst(a,b)} is for internal use only")) (* (($ |#3| $) "\\spad{smp*ts} multiplies a TaylorSeries by a monomial SMP.")) (|coerce| (($ |#3|) "\\spad{coerce(poly)} regroups the terms by total degree and forms a series.") (($ |#2|) "\\spad{coerce(var)} converts a variable to a Taylor series")) (|coefficient| ((|#3| $ (|NonNegativeInteger|)) "\\indented{1}{\\spad{coefficient(s, \\spad{n)}} gives the terms of total degree \\spad{n.}} \\blankline \\spad{X} xts:=x::TaylorSeries Fraction Integer \\spad{X} t1:=sin(xts) \\spad{X} coefficient(t1,3)"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-562))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-1123 R E V P) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-582))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-1144 R E V P) 
 ((|constructor| (NIL "The category of square-free and normalized triangular sets. Thus, up to the primitivity axiom of [1], these sets are Lazard triangular sets."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-1124 UP -3313) 
+(-1145 UP -3958) 
 ((|constructor| (NIL "This package factors the formulas out of the general solve code, allowing their recursive use over different domains. Care is taken to introduce few radicals so that radical extension domains can more easily simplify the results.")) (|aQuartic| ((|#2| |#2| |#2| |#2| |#2| |#2|) "\\spad{aQuartic(f,g,h,i,k)} \\undocumented")) (|aCubic| ((|#2| |#2| |#2| |#2| |#2|) "\\spad{aCubic(f,g,h,j)} \\undocumented")) (|aQuadratic| ((|#2| |#2| |#2| |#2|) "\\spad{aQuadratic(f,g,h)} \\undocumented")) (|aLinear| ((|#2| |#2| |#2|) "\\spad{aLinear(f,g)} \\undocumented")) (|quartic| (((|List| |#2|) |#2| |#2| |#2| |#2| |#2|) "\\spad{quartic(f,g,h,i,j)} \\undocumented") (((|List| |#2|) |#1|) "\\spad{quartic(u)} \\undocumented")) (|cubic| (((|List| |#2|) |#2| |#2| |#2| |#2|) "\\spad{cubic(f,g,h,i)} \\undocumented") (((|List| |#2|) |#1|) "\\spad{cubic(u)} \\undocumented")) (|quadratic| (((|List| |#2|) |#2| |#2| |#2|) "\\spad{quadratic(f,g,h)} \\undocumented") (((|List| |#2|) |#1|) "\\spad{quadratic(u)} \\undocumented")) (|linear| (((|List| |#2|) |#2| |#2|) "\\spad{linear(f,g)} \\undocumented") (((|List| |#2|) |#1|) "\\spad{linear(u)} \\undocumented")) (|mapSolve| (((|Record| (|:| |solns| (|List| |#2|)) (|:| |maps| (|List| (|Record| (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (|Mapping| |#2| |#2|)) "\\spad{mapSolve(u,f)} \\undocumented")) (|particularSolution| ((|#2| |#1|) "\\spad{particularSolution(u)} \\undocumented")) (|solve| (((|List| |#2|) |#1|) "\\spad{solve(u)} \\undocumented"))) 
 NIL 
 NIL 
-(-1125 R) 
+(-1146 R) 
 ((|constructor| (NIL "This package tries to find solutions expressed in terms of radicals for systems of equations of rational functions with coefficients in an integral domain \\spad{R.}")) (|contractSolve| (((|SuchThat| (|List| (|Expression| |#1|)) (|List| (|Equation| (|Expression| |#1|)))) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{contractSolve(rf,x)} finds the solutions expressed in terms of radicals of the equation \\spad{rf} = 0 with respect to the symbol \\spad{x,} where \\spad{rf} is a rational function. The result contains new symbols for common subexpressions in order to reduce the size of the output. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} contractSolve(b,x)") (((|SuchThat| (|List| (|Expression| |#1|)) (|List| (|Equation| (|Expression| |#1|)))) (|Equation| (|Fraction| (|Polynomial| |#1|))) (|Symbol|)) "\\spad{contractSolve(eq,x)} finds the solutions expressed in terms of radicals of the equation of rational functions \\spad{eq} with respect to the symbol \\spad{x.} The result contains new symbols for common subexpressions in order to reduce the size of the output. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} contractSolve(b=0,x)")) (|radicalRoots| (((|List| (|List| (|Expression| |#1|))) (|List| (|Fraction| (|Polynomial| |#1|))) (|List| (|Symbol|))) "\\spad{radicalRoots(lrf,lvar)} finds the roots expressed in terms of radicals of the list of rational functions \\spad{lrf} with respect to the list of symbols lvar. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} c:Fraction(Polynomial(Integer)):=(y^2+4)/(y+1) \\spad{X} radicalRoots([b,c],[x,y])") (((|List| (|Expression| |#1|)) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{radicalRoots(rf,x)} finds the roots expressed in terms of radicals of the rational function \\spad{rf} with respect to the symbol \\spad{x.} \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} radicalRoots(b,x)")) (|radicalSolve| (((|List| (|List| (|Equation| (|Expression| |#1|)))) (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) "\\spad{radicalSolve(leq)} finds the solutions expressed in terms of radicals of the system of equations of rational functions \\spad{leq} with respect to the unique symbol \\spad{x} appearing in leq. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} c:Fraction(Polynomial(Integer)):=(y^2+4)/(y+1) \\spad{X} radicalSolve([b=0,c=0])") (((|List| (|List| (|Equation| (|Expression| |#1|)))) (|List| (|Equation| (|Fraction| (|Polynomial| |#1|)))) (|List| (|Symbol|))) "\\spad{radicalSolve(leq,lvar)} finds the solutions expressed in terms of radicals of the system of equations of rational functions \\spad{leq} with respect to the list of symbols lvar. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} c:Fraction(Polynomial(Integer)):=(y^2+4)/(y+1) \\spad{X} radicalSolve([b=0,c=0],[x,y])") (((|List| (|List| (|Equation| (|Expression| |#1|)))) (|List| (|Fraction| (|Polynomial| |#1|)))) "\\spad{radicalSolve(lrf)} finds the solutions expressed in terms of radicals of the system of equations \\spad{lrf} = 0, where \\spad{lrf} is a system of univariate rational functions. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} c:Fraction(Polynomial(Integer)):=(y^2+4)/(y+1) \\spad{X} radicalSolve([b,c])") (((|List| (|List| (|Equation| (|Expression| |#1|)))) (|List| (|Fraction| (|Polynomial| |#1|))) (|List| (|Symbol|))) "\\spad{radicalSolve(lrf,lvar)} finds the solutions expressed in terms of radicals of the system of equations \\spad{lrf} = 0 with respect to the list of symbols lvar, \\indented{1}{where \\spad{lrf} is a list of rational functions.} \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} c:Fraction(Polynomial(Integer)):=(y^2+4)/(y+1) \\spad{X} radicalSolve([b,c],[x,y])") (((|List| (|Equation| (|Expression| |#1|))) (|Equation| (|Fraction| (|Polynomial| |#1|)))) "\\spad{radicalSolve(eq)} finds the solutions expressed in terms of radicals of the equation of rational functions \\spad{eq} with respect to the unique symbol \\spad{x} appearing in eq. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} radicalSolve(b=0)") (((|List| (|Equation| (|Expression| |#1|))) (|Equation| (|Fraction| (|Polynomial| |#1|))) (|Symbol|)) "\\spad{radicalSolve(eq,x)} finds the solutions expressed in terms of radicals of the equation of rational functions \\spad{eq} with respect to the symbol \\spad{x.} \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} radicalSolve(b=0,x)") (((|List| (|Equation| (|Expression| |#1|))) (|Fraction| (|Polynomial| |#1|))) "\\spad{radicalSolve(rf)} finds the solutions expressed in terms of radicals of the equation \\spad{rf} = 0, where \\spad{rf} is a univariate rational function. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} radicalSolve(b)") (((|List| (|Equation| (|Expression| |#1|))) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{radicalSolve(rf,x)} finds the solutions expressed in terms of radicals of the equation \\spad{rf} = 0 with respect to the symbol \\spad{x,} where \\spad{rf} is a rational function. \\blankline \\spad{X} b:Fraction(Polynomial(Integer)):=(3*x^3+7)/(5*x^2-13) \\spad{X} radicalSolve(b,x)"))) 
 NIL 
 NIL 
-(-1126 R) 
+(-1147 R) 
 ((|constructor| (NIL "This package finds the function \\spad{func3} where \\spad{func1} and \\spad{func2} are given and \\spad{func1} = func3(func2) . If there is no solution then function \\spad{func1} will be returned. An example would be \\spad{func1:= 8*X**3+32*X**2-14*X ::EXPR INT} and \\spad{func2:=2*X ::EXPR INT} convert them via univariate to FRAC SUP EXPR INT and then the solution is \\spad{func3:=X**3+X**2-X} of type FRAC SUP EXPR INT")) (|unvectorise| (((|Fraction| (|SparseUnivariatePolynomial| (|Expression| |#1|))) (|Vector| (|Expression| |#1|)) (|Fraction| (|SparseUnivariatePolynomial| (|Expression| |#1|))) (|Integer|)) "\\spad{unvectorise(vect, var, \\spad{n)}} returns \\spad{vect(1) + vect(2)*var + \\spad{...} + vect(n+1)*var**(n)} where \\spad{vect} is the vector of the coefficients of the polynomail ,{} \\spad{var} the new variable and \\spad{n} the degree.")) (|decomposeFunc| (((|Fraction| (|SparseUnivariatePolynomial| (|Expression| |#1|))) (|Fraction| (|SparseUnivariatePolynomial| (|Expression| |#1|))) (|Fraction| (|SparseUnivariatePolynomial| (|Expression| |#1|))) (|Fraction| (|SparseUnivariatePolynomial| (|Expression| |#1|)))) "\\spad{decomposeFunc(func1, func2, newvar)} returns a function \\spad{func3} where \\spad{func1} = func3(func2) and expresses it in the new variable newvar. If there is no solution then \\spad{func1} will be returned."))) 
 NIL 
 NIL 
-(-1127 R) 
+(-1148 R) 
 ((|constructor| (NIL "This package tries to find solutions of equations of type Expression(R). This means expressions involving transcendental, exponential, logarithmic and nthRoot functions. After trying to transform different kernels to one kernel by applying several rules, it calls zerosOf for the SparseUnivariatePolynomial in the remaining kernel. For example the expression \\spad{sin(x)*cos(x)-2} will be transformed to \\spad{-2 \\spad{tan(x/2)**4} \\spad{-2} \\spad{tan(x/2)**3} \\spad{-4} \\spad{tan(x/2)**2} \\spad{+2} tan(x/2) \\spad{-2}} by using the function normalize and then to \\spad{-2 \\spad{tan(x)**2} + tan(x) \\spad{-2}} with help of subsTan. This function tries to express the given function in terms of \\spad{tan(x/2)} to express in terms of \\spad{tan(x)} . Other examples are the expressions \\spad{sqrt(x+1)+sqrt(x+7)+1} or \\spad{sqrt(sin(x))+1} .")) (|solve| (((|List| (|List| (|Equation| (|Expression| |#1|)))) (|List| (|Equation| (|Expression| |#1|))) (|List| (|Symbol|))) "\\spad{solve(leqs, lvar)} returns a list of solutions to the list of equations \\spad{leqs} with respect to the list of symbols lvar.") (((|List| (|Equation| (|Expression| |#1|))) (|Expression| |#1|) (|Symbol|)) "\\indented{1}{solve(expr,x) finds the solutions of the equation expr = 0} \\indented{1}{with respect to the symbol \\spad{x} where expr is a function} \\indented{1}{of type Expression(R).} \\blankline \\spad{X} solve(1/2*v*v*cos(theta+phi)*cos(theta+phi)+g*l*cos(phi)=g*l,phi) \\spad{X} definingPolynomial \\spad{%phi0} \\spad{X} definingPolynomial \\spad{%phi1}") (((|List| (|Equation| (|Expression| |#1|))) (|Equation| (|Expression| |#1|)) (|Symbol|)) "\\spad{solve(eq,x)} finds the solutions of the equation \\spad{eq} where \\spad{eq} is an equation of functions of type Expression(R) with respect to the symbol \\spad{x.}") (((|List| (|Equation| (|Expression| |#1|))) (|Equation| (|Expression| |#1|))) "\\spad{solve(eq)} finds the solutions of the equation \\spad{eq} where \\spad{eq} is an equation of functions of type Expression(R) with respect to the unique symbol \\spad{x} appearing in eq.") (((|List| (|Equation| (|Expression| |#1|))) (|Expression| |#1|)) "\\spad{solve(expr)} finds the solutions of the equation \\spad{expr} = 0 where \\spad{expr} is a function of type Expression(R) with respect to the unique symbol \\spad{x} appearing in eq."))) 
 NIL 
 NIL 
-(-1128 S A) 
+(-1149 S A) 
 ((|constructor| (NIL "This package exports sorting algorithnms")) (|insertionSort!| ((|#2| |#2|) "\\spad{insertionSort! }\\undocumented") ((|#2| |#2| (|Mapping| (|Boolean|) |#1| |#1|)) "\\spad{insertionSort!(a,f)} \\undocumented")) (|bubbleSort!| ((|#2| |#2|) "\\spad{bubbleSort!(a)} \\undocumented") ((|#2| |#2| (|Mapping| (|Boolean|) |#1| |#1|)) "\\spad{bubbleSort!(a,f)} \\undocumented"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-848)))) 
-(-1129 R) 
+((|HasCategory| |#1| (QUOTE (-869)))) 
+(-1150 R) 
 ((|constructor| (NIL "The domain ThreeSpace is used for creating three dimensional objects using functions for defining points, curves, polygons, constructs and the subspaces containing them."))) 
 NIL 
 NIL 
-(-1130 R) 
+(-1151 R) 
 ((|constructor| (NIL "The category ThreeSpaceCategory is used for creating three dimensional objects using functions for defining points, curves, polygons, constructs and the subspaces containing them.")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(s)} returns the \\spadtype{ThreeSpace} \\spad{s} to Output format.")) (|subspace| (((|SubSpace| 3 |#1|) $) "\\spad{subspace(s)} returns the \\spadtype{SubSpace} which holds all the point information in the \\spadtype{ThreeSpace}, \\spad{s.}")) (|check| (($ $) "\\spad{check(s)} returns lllpt, list of lists of lists of point information about the \\spadtype{ThreeSpace} \\spad{s.}")) (|objects| (((|Record| (|:| |points| (|NonNegativeInteger|)) (|:| |curves| (|NonNegativeInteger|)) (|:| |polygons| (|NonNegativeInteger|)) (|:| |constructs| (|NonNegativeInteger|))) $) "\\spad{objects(s)} returns the \\spadtype{ThreeSpace}, \\spad{s,} in the form of a 3D object record containing information on the number of points, curves, polygons and constructs comprising the \\spadtype{ThreeSpace}..")) (|lprop| (((|List| (|SubSpaceComponentProperty|)) $) "\\spad{lprop(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a list of subspace component properties, and if so, returns the list; An error is signaled otherwise.")) (|llprop| (((|List| (|List| (|SubSpaceComponentProperty|))) $) "\\spad{llprop(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a list of curves which are lists of the subspace component properties of the curves, and if so, returns the list of lists; An error is signaled otherwise.")) (|lllp| (((|List| (|List| (|List| (|Point| |#1|)))) $) "\\spad{lllp(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a list of components, which are lists of curves, which are lists of points, and if so, returns the list of lists of lists; An error is signaled otherwise.")) (|lllip| (((|List| (|List| (|List| (|NonNegativeInteger|)))) $) "\\spad{lllip(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a list of components, which are lists of curves, which are lists of indices to points, and if so, returns the list of lists of lists; An error is signaled otherwise.")) (|lp| (((|List| (|Point| |#1|)) $) "\\spad{lp(s)} returns the list of points component which the \\spadtype{ThreeSpace}, \\spad{s,} contains; these points are used by reference, that is, the component holds indices referring to the points rather than the points themselves. This allows for sharing of the points.")) (|mesh?| (((|Boolean|) $) "\\spad{mesh?(s)} returns \\spad{true} if the \\spadtype{ThreeSpace} \\spad{s} is composed of one component, a mesh comprising a list of curves which are lists of points, or returns \\spad{false} if otherwise")) (|mesh| (((|List| (|List| (|Point| |#1|))) $) "\\spad{mesh(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a single surface component defined by a list curves which contain lists of points, and if so, returns the list of lists of points; An error is signaled otherwise.") (($ (|List| (|List| (|Point| |#1|))) (|Boolean|) (|Boolean|)) "\\spad{mesh([[p0],[p1],...,[pn]], close1, close2)} creates a surface defined over a list of curves, \\spad{p0} through \\spad{pn,} which are lists of points; the booleans \\spad{close1} and \\spad{close2} indicate how the surface is to be closed: \\spad{close1} set to \\spad{true} means that each individual list (a curve) is to be closed (that is, the last point of the list is to be connected to the first point); \\spad{close2} set to \\spad{true} means that the boundary at one end of the surface is to be connected to the boundary at the other end (the boundaries are defined as the first list of points (curve) and the last list of points (curve)); the \\spadtype{ThreeSpace} containing this surface is returned.") (($ (|List| (|List| (|Point| |#1|)))) "\\spad{mesh([[p0],[p1],...,[pn]])} creates a surface defined by a list of curves which are lists, \\spad{p0} through \\spad{pn,} of points, and returns a \\spadtype{ThreeSpace} whose component is the surface.") (($ $ (|List| (|List| (|List| |#1|))) (|Boolean|) (|Boolean|)) "\\spad{mesh(s, LLLR, close1, close2)} where \\spad{LLLR} is of the form [[[r10]...,[r1m]],[[r20]...,[r2m]],...,[[rn0]...,[rnm]]], adds a surface component to the \\spadtype{ThreeSpace} \\spad{s,} which is defined over a rectangular domain of size \\spad{WxH} where \\spad{W} is the number of lists of points from the domain \\spad{PointDomain(R)} and \\spad{H} is the number of elements in each of those lists; the booleans \\spad{close1} and \\spad{close2} indicate how the surface is to be closed: if \\spad{close1} is \\spad{true} this means that each individual list (a curve) is to be closed (that is, the last point of the list is to be connected to the first point); if \\spad{close2} is true, this means that the boundary at one end of the surface is to be connected to the boundary at the other end (the boundaries are defined as the first list of points (curve) and the last list of points (curve)).") (($ $ (|List| (|List| (|Point| |#1|))) (|Boolean|) (|Boolean|)) "\\spad{mesh(s, LLP, close1, close2)} where \\spad{LLP} is of the form [[p0],[p1],...,[pn]] adds a surface component to the \\spadtype{ThreeSpace}, which is defined over a list of curves, in which each of these curves is a list of points. The boolean arguments \\spad{close1} and \\spad{close2} indicate how the surface is to be closed. Argument \\spad{close1} equal \\spad{true} means that each individual list (a curve) is to be closed, that is, the last point of the list is to be connected to the first point. Argument \\spad{close2} equal \\spad{true} means that the boundary at one end of the surface is to be connected to the boundary at the other end, that is, the boundaries are defined as the first list of points (curve) and the last list of points (curve).") (($ $ (|List| (|List| (|List| |#1|))) (|List| (|SubSpaceComponentProperty|)) (|SubSpaceComponentProperty|)) "\\spad{mesh(s, LLLR, [props], prop)} where \\spad{LLLR} is of the form: [[[r10]...,[r1m]],[[r20]...,[r2m]],...,[[rn0]...,[rnm]]], adds a surface component to the \\spadtype{ThreeSpace} \\spad{s,} which is defined over a rectangular domain of size \\spad{WxH} where \\spad{W} is the number of lists of points from the domain \\spad{PointDomain(R)} and \\spad{H} is the number of elements in each of those lists; lprops is the list of the subspace component properties for each curve list, and prop is the subspace component property by which the points are defined.") (($ $ (|List| (|List| (|Point| |#1|))) (|List| (|SubSpaceComponentProperty|)) (|SubSpaceComponentProperty|)) "\\spad{mesh(s,[[p0],[p1],...,[pn]],[props],prop)} adds a surface component, defined over a list curves which contains lists of points, to the \\spadtype{ThreeSpace} \\spad{s;} props is a list which contains the subspace component properties for each surface parameter, and \\spad{prop} is the subspace component property by which the points are defined.")) (|polygon?| (((|Boolean|) $) "\\spad{polygon?(s)} returns \\spad{true} if the \\spadtype{ThreeSpace} \\spad{s} contains a single polygon component, or \\spad{false} otherwise.")) (|polygon| (((|List| (|Point| |#1|)) $) "\\spad{polygon(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a single polygon component defined by a list of points, and if so, returns the list of points; An error is signaled otherwise.") (($ (|List| (|Point| |#1|))) "\\spad{polygon([p0,p1,...,pn])} creates a polygon defined by a list of points, \\spad{p0} through \\spad{pn,} and returns a \\spadtype{ThreeSpace} whose component is the polygon.") (($ $ (|List| (|List| |#1|))) "\\spad{polygon(s,[[r0],[r1],...,[rn]])} adds a polygon component defined by a list of points \\spad{r0} through \\spad{rn}, which are lists of elements from the domain \\spad{PointDomain(m,R)} to the \\spadtype{ThreeSpace} \\spad{s,} where \\spad{m} is the dimension of the points and \\spad{R} is the \\spadtype{Ring} over which the points are defined.") (($ $ (|List| (|Point| |#1|))) "\\spad{polygon(s,[p0,p1,...,pn])} adds a polygon component defined by a list of points, \\spad{p0} throught \\spad{pn,} to the \\spadtype{ThreeSpace} \\spad{s.}")) (|closedCurve?| (((|Boolean|) $) "\\spad{closedCurve?(s)} returns \\spad{true} if the \\spadtype{ThreeSpace} \\spad{s} contains a single closed curve component, that is, the first element of the curve is also the last element, or \\spad{false} otherwise.")) (|closedCurve| (((|List| (|Point| |#1|)) $) "\\spad{closedCurve(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a single closed curve component defined by a list of points in which the first point is also the last point, all of which are from the domain \\spad{PointDomain(m,R)} and if so, returns the list of points. An error is signaled otherwise.") (($ (|List| (|Point| |#1|))) "\\spad{closedCurve(lp)} sets a list of points defined by the first element of \\spad{lp} through the last element of \\spad{lp} and back to the first elelment again and returns a \\spadtype{ThreeSpace} whose component is the closed curve defined by \\spad{lp.}") (($ $ (|List| (|List| |#1|))) "\\spad{closedCurve(s,[[lr0],[lr1],...,[lrn],[lr0]])} adds a closed curve component defined by a list of points \\spad{lr0} through \\spad{lrn}, which are lists of elements from the domain \\spad{PointDomain(m,R)}, where \\spad{R} is the \\spadtype{Ring} over which the point elements are defined and \\spad{m} is the dimension of the points, in which the last element of the list of points contains a copy of the first element list, lr0. The closed curve is added to the \\spadtype{ThreeSpace}, \\spad{s.}") (($ $ (|List| (|Point| |#1|))) "\\spad{closedCurve(s,[p0,p1,...,pn,p0])} adds a closed curve component which is a list of points defined by the first element \\spad{p0} through the last element \\spad{pn} and back to the first element \\spad{p0} again, to the \\spadtype{ThreeSpace} \\spad{s.}")) (|curve?| (((|Boolean|) $) "\\spad{curve?(s)} queries whether the \\spadtype{ThreeSpace}, \\spad{s,} is a curve, that is, has one component, a list of list of points, and returns \\spad{true} if it is, or \\spad{false} otherwise.")) (|curve| (((|List| (|Point| |#1|)) $) "\\spad{curve(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a single curve defined by a list of points and if so, returns the curve, that is, list of points. An error is signaled otherwise.") (($ (|List| (|Point| |#1|))) "\\spad{curve([p0,p1,p2,...,pn])} creates a space curve defined by the list of points \\spad{p0} through \\spad{pn}, and returns the \\spadtype{ThreeSpace} whose component is the curve.") (($ $ (|List| (|List| |#1|))) "\\spad{curve(s,[[p0],[p1],...,[pn]])} adds a space curve which is a list of points \\spad{p0} through \\spad{pn} defined by lists of elements from the domain \\spad{PointDomain(m,R)}, where \\spad{R} is the \\spadtype{Ring} over which the point elements are defined and \\spad{m} is the dimension of the points, to the \\spadtype{ThreeSpace} \\spad{s.}") (($ $ (|List| (|Point| |#1|))) "\\spad{curve(s,[p0,p1,...,pn])} adds a space curve component defined by a list of points \\spad{p0} through \\spad{pn}, to the \\spadtype{ThreeSpace} \\spad{s.}")) (|point?| (((|Boolean|) $) "\\spad{point?(s)} queries whether the \\spadtype{ThreeSpace}, \\spad{s,} is composed of a single component which is a point and returns the boolean result.")) (|point| (((|Point| |#1|) $) "\\spad{point(s)} checks to see if the \\spadtype{ThreeSpace}, \\spad{s,} is composed of only a single point and if so, returns the point. An error is signaled otherwise.") (($ (|Point| |#1|)) "\\spad{point(p)} returns a \\spadtype{ThreeSpace} object which is composed of one component, the point \\spad{p.}") (($ $ (|NonNegativeInteger|)) "\\spad{point(s,i)} adds a point component which is placed into a component list of the \\spadtype{ThreeSpace}, \\spad{s,} at the index given by i.") (($ $ (|List| |#1|)) "\\spad{point(s,[x,y,z])} adds a point component defined by a list of elements which are from the \\spad{PointDomain(R)} to the \\spadtype{ThreeSpace}, \\spad{s,} where \\spad{R} is the \\spadtype{Ring} over which the point elements are defined.") (($ $ (|Point| |#1|)) "\\spad{point(s,p)} adds a point component defined by the point, \\spad{p,} specified as a list from \\spad{List(R)}, to the \\spadtype{ThreeSpace}, \\spad{s,} where \\spad{R} is the \\spadtype{Ring} over which the point is defined.")) (|modifyPointData| (($ $ (|NonNegativeInteger|) (|Point| |#1|)) "\\spad{modifyPointData(s,i,p)} changes the point at the indexed location \\spad{i} in the \\spadtype{ThreeSpace}, \\spad{s,} to that of point \\spad{p.} This is useful for making changes to a point which has been transformed.")) (|enterPointData| (((|NonNegativeInteger|) $ (|List| (|Point| |#1|))) "\\spad{enterPointData(s,[p0,p1,...,pn])} adds a list of points from \\spad{p0} through \\spad{pn} to the \\spadtype{ThreeSpace}, \\spad{s,} and returns the index, to the starting point of the list.")) (|copy| (($ $) "\\spad{copy(s)} returns a new \\spadtype{ThreeSpace} that is an exact copy of \\spad{s.}")) (|composites| (((|List| $) $) "\\spad{composites(s)} takes the \\spadtype{ThreeSpace} \\spad{s,} and creates a list containing a unique \\spadtype{ThreeSpace} for each single composite of \\spad{s.} If \\spad{s} has no composites defined (composites need to be explicitly created), the list returned is empty. Note that not all the components need to be part of a composite.")) (|components| (((|List| $) $) "\\spad{components(s)} takes the \\spadtype{ThreeSpace} \\spad{s,} and creates a list containing a unique \\spadtype{ThreeSpace} for each single component of \\spad{s.} If \\spad{s} has no components defined, the list returned is empty.")) (|composite| (($ (|List| $)) "\\spad{composite([s1,s2,...,sn])} will create a new \\spadtype{ThreeSpace} that is a union of all the components from each \\spadtype{ThreeSpace} in the parameter list, grouped as a composite.")) (|merge| (($ $ $) "\\spad{merge(s1,s2)} will create a new \\spadtype{ThreeSpace} that has the components of \\spad{s1} and \\spad{s2}; Groupings of components into composites are maintained.") (($ (|List| $)) "\\spad{merge([s1,s2,...,sn])} will create a new \\spadtype{ThreeSpace} that has the components of all the ones in the list; Groupings of components into composites are maintained.")) (|numberOfComposites| (((|NonNegativeInteger|) $) "\\spad{numberOfComposites(s)} returns the number of supercomponents, or composites, in the \\spadtype{ThreeSpace}, \\spad{s;} Composites are arbitrary groupings of otherwise distinct and unrelated components; A \\spadtype{ThreeSpace} need not have any composites defined at all and, outside of the requirement that no component can belong to more than one composite at a time, the definition and interpretation of composites are unrestricted.")) (|numberOfComponents| (((|NonNegativeInteger|) $) "\\spad{numberOfComponents(s)} returns the number of distinct object components in the indicated \\spadtype{ThreeSpace}, \\spad{s,} such as points, curves, polygons, and constructs.")) (|create3Space| (($ (|SubSpace| 3 |#1|)) "\\spad{create3Space(s)} creates a \\spadtype{ThreeSpace} object containing objects pre-defined within some \\spadtype{SubSpace} \\spad{s.}") (($) "\\spad{create3Space()} creates a \\spadtype{ThreeSpace} object capable of holding point, curve, mesh components and any combination."))) 
 NIL 
 NIL 
-(-1131) 
+(-1152) 
 ((|constructor| (NIL "SpecialOutputPackage allows FORTRAN, Tex and Script Formula Formatter output from programs.")) (|outputAsTex| (((|Void|) (|List| (|OutputForm|))) "\\spad{outputAsTex(l)} sends (for each expression in the list \\spad{l)} output in Tex format to the destination as defined by \\spadsyscom{set output tex}.") (((|Void|) (|OutputForm|)) "\\spad{outputAsTex(o)} sends output \\spad{o} in Tex format to the destination defined by \\spadsyscom{set output tex}.")) (|outputAsScript| (((|Void|) (|List| (|OutputForm|))) "\\spad{outputAsScript(l)} sends (for each expression in the list \\spad{l)} output in Script Formula Formatter format to the destination defined. by \\spadsyscom{set output forumula}.") (((|Void|) (|OutputForm|)) "\\spad{outputAsScript(o)} sends output \\spad{o} in Script Formula Formatter format to the destination defined by \\spadsyscom{set output formula}.")) (|outputAsFortran| (((|Void|) (|List| (|OutputForm|))) "\\spad{outputAsFortran(l)} sends (for each expression in the list \\spad{l)} output in FORTRAN format to the destination defined by \\spadsyscom{set output fortran}.") (((|Void|) (|OutputForm|)) "\\spad{outputAsFortran(o)} sends output \\spad{o} in FORTRAN format.") (((|Void|) (|String|) (|OutputForm|)) "\\spad{outputAsFortran(v,o)} sends output \\spad{v} = \\spad{o} in FORTRAN format to the destination defined by \\spadsyscom{set output fortran}."))) 
 NIL 
 NIL 
-(-1132) 
+(-1153) 
 ((|constructor| (NIL "Category for the other special functions.")) (|airyBi| (($ $) "\\spad{airyBi(x)} is the Airy function \\spad{Bi(x)}.")) (|airyAi| (($ $) "\\spad{airyAi(x)} is the Airy function \\spad{Ai(x)}.")) (|besselK| (($ $ $) "\\spad{besselK(v,z)} is the modified Bessel function of the second kind.")) (|besselI| (($ $ $) "\\spad{besselI(v,z)} is the modified Bessel function of the first kind.")) (|besselY| (($ $ $) "\\spad{besselY(v,z)} is the Bessel function of the second kind.")) (|besselJ| (($ $ $) "\\spad{besselJ(v,z)} is the Bessel function of the first kind.")) (|polygamma| (($ $ $) "\\spad{polygamma(k,x)} is the \\spad{k-th} derivative of \\spad{digamma(x)}, (often written \\spad{psi(k,x)} in the literature).")) (|digamma| (($ $) "\\spad{digamma(x)} is the logarithmic derivative of \\spad{Gamma(x)} (often written \\spad{psi(x)} in the literature).")) (|Beta| (($ $ $) "\\spad{Beta(x,y)} is \\spad{Gamma(x) * Gamma(y)/Gamma(x+y)}.")) (|Gamma| (($ $ $) "\\spad{Gamma(a,x)} is the incomplete Gamma function.") (($ $) "\\spad{Gamma(x)} is the Euler Gamma function.")) (|abs| (($ $) "\\spad{abs(x)} returns the absolute value of \\spad{x.}"))) 
 NIL 
 NIL 
-(-1133 V C) 
+(-1154 V C) 
 ((|constructor| (NIL "This domain exports a modest implementation for the vertices of splitting trees. These vertices are called here splitting nodes. Every of these nodes store 3 informations. The first one is its value, that is the current expression to evaluate. The second one is its condition, that is the hypothesis under which the value has to be evaluated. The last one is its status, that is a boolean flag which is \\spad{true} iff the value is the result of its evaluation under its condition. Two splitting vertices are equal iff they have the sane values and the same conditions (so their status do not matter).")) (|subNode?| (((|Boolean|) $ $ (|Mapping| (|Boolean|) |#2| |#2|)) "\\axiom{subNode?(n1,n2,o2)} returns \\spad{true} iff \\axiom{value(n1) = value(n2)} and \\axiom{o2(condition(n1),condition(n2))}")) (|infLex?| (((|Boolean|) $ $ (|Mapping| (|Boolean|) |#1| |#1|) (|Mapping| (|Boolean|) |#2| |#2|)) "\\axiom{infLex?(n1,n2,o1,o2)} returns \\spad{true} iff \\axiom{o1(value(n1),value(n2))} or \\axiom{value(n1) = value(n2)} and \\axiom{o2(condition(n1),condition(n2))}.")) (|setEmpty!| (($ $) "\\axiom{setEmpty!(n)} replaces \\spad{n} by \\axiom{empty()$\\%}.")) (|setStatus!| (($ $ (|Boolean|)) "\\axiom{setStatus!(n,b)} returns \\spad{n} whose status has been replaced by \\spad{b} if it is not empty, else an error is produced.")) (|setCondition!| (($ $ |#2|) "\\axiom{setCondition!(n,t)} returns \\spad{n} whose condition has been replaced by \\spad{t} if it is not empty, else an error is produced.")) (|setValue!| (($ $ |#1|) "\\axiom{setValue!(n,v)} returns \\spad{n} whose value has been replaced by \\spad{v} if it is not empty, else an error is produced.")) (|copy| (($ $) "\\axiom{copy(n)} returns a copy of \\spad{n.}")) (|construct| (((|List| $) |#1| (|List| |#2|)) "\\axiom{construct(v,lt)} returns the same as \\axiom{[construct(v,t) for \\spad{t} in lt]}") (((|List| $) (|List| (|Record| (|:| |val| |#1|) (|:| |tower| |#2|)))) "\\axiom{construct(lvt)} returns the same as \\axiom{[construct(vt.val,vt.tower) for \\spad{vt} in lvt]}") (($ (|Record| (|:| |val| |#1|) (|:| |tower| |#2|))) "\\axiom{construct(vt)} returns the same as \\axiom{construct(vt.val,vt.tower)}") (($ |#1| |#2|) "\\axiom{construct(v,t)} returns the same as \\axiom{construct(v,t,false)}") (($ |#1| |#2| (|Boolean|)) "\\axiom{construct(v,t,b)} returns the non-empty node with value \\spad{v,} condition \\spad{t} and flag \\spad{b}")) (|status| (((|Boolean|) $) "\\axiom{status(n)} returns the status of the node \\spad{n.}")) (|condition| ((|#2| $) "\\axiom{condition(n)} returns the condition of the node \\spad{n.}")) (|value| ((|#1| $) "\\axiom{value(n)} returns the value of the node \\spad{n.}")) (|empty?| (((|Boolean|) $) "\\axiom{empty?(n)} returns \\spad{true} iff the node \\spad{n} is \\axiom{empty()$\\%}.")) (|empty| (($) "\\axiom{empty()} returns the same as \\axiom{[empty()$V,empty()$C,false]$\\%}"))) 
 NIL 
 NIL 
-(-1134 V C) 
+(-1155 V C) 
 ((|constructor| (NIL "This domain exports a modest implementation of splitting trees. Spliiting trees are needed when the evaluation of some quantity under some hypothesis requires to split the hypothesis into sub-cases. For instance by adding some new hypothesis on one hand and its negation on another hand. The computations are terminated is a splitting tree \\axiom{a} when \\axiom{status(value(a))} is \\axiom{true}. Thus, if for the splitting tree \\axiom{a} the flag \\axiom{status(value(a))} is \\axiom{true}, then \\axiom{status(value(d))} is \\axiom{true} for any subtree \\axiom{d} of \\axiom{a}. This property of splitting trees is called the termination condition. If no vertex in a splitting tree \\axiom{a} is equal to another, \\axiom{a} is said to satisfy the no-duplicates condition. The splitting tree \\axiom{a} will satisfy this condition if nodes are added to \\axiom{a} by mean of \\axiom{splitNodeOf!} and if \\axiom{construct} is only used to create the root of \\axiom{a} with no children.")) (|splitNodeOf!| (($ $ $ (|List| (|SplittingNode| |#1| |#2|)) (|Mapping| (|Boolean|) |#2| |#2|)) "\\axiom{splitNodeOf!(l,a,ls,sub?)} returns \\axiom{a} where the children list of \\axiom{l} has been set to \\axiom{[[s]$% for \\spad{s} in \\spad{ls} | not subNodeOf?(s,a,sub?)]}. Thus, if \\axiom{l} is not a node of \\axiom{a}, this latter splitting tree is unchanged.") (($ $ $ (|List| (|SplittingNode| |#1| |#2|))) "\\axiom{splitNodeOf!(l,a,ls)} returns \\axiom{a} where the children list of \\axiom{l} has been set to \\axiom{[[s]$% for \\spad{s} in \\spad{ls} | not nodeOf?(s,a)]}. Thus, if \\axiom{l} is not a node of \\axiom{a}, this latter splitting tree is unchanged.")) (|remove!| (($ (|SplittingNode| |#1| |#2|) $) "\\axiom{remove!(s,a)} replaces a by remove(s,a)")) (|remove| (($ (|SplittingNode| |#1| |#2|) $) "\\axiom{remove(s,a)} returns the splitting tree obtained from a by removing every sub-tree \\axiom{b} such that \\axiom{value(b)} and \\axiom{s} have the same value, condition and status.")) (|subNodeOf?| (((|Boolean|) (|SplittingNode| |#1| |#2|) $ (|Mapping| (|Boolean|) |#2| |#2|)) "\\axiom{subNodeOf?(s,a,sub?)} returns \\spad{true} iff for some node \\axiom{n} in \\axiom{a} we have \\axiom{s = \\spad{n}} or \\axiom{status(n)} and \\axiom{subNode?(s,n,sub?)}.")) (|nodeOf?| (((|Boolean|) (|SplittingNode| |#1| |#2|) $) "\\axiom{nodeOf?(s,a)} returns \\spad{true} iff some node of \\axiom{a} is equal to \\axiom{s}")) (|result| (((|List| (|Record| (|:| |val| |#1|) (|:| |tower| |#2|))) $) "\\axiom{result(a)} where \\axiom{ls} is the leaves list of \\axiom{a} returns \\axiom{[[value(s),condition(s)]$VT for \\spad{s} in ls]} if the computations are terminated in \\axiom{a} else an error is produced.")) (|conditions| (((|List| |#2|) $) "\\axiom{conditions(a)} returns the list of the conditions of the leaves of a")) (|construct| (($ |#1| |#2| |#1| (|List| |#2|)) "\\axiom{construct(v1,t,v2,lt)} creates a splitting tree with value (\\spadignore{i.e.} root vertex) given by \\axiom{[v,t]$S} and with children list given by \\axiom{[[[v,t]$S]$% for \\spad{s} in ls]}.") (($ |#1| |#2| (|List| (|SplittingNode| |#1| |#2|))) "\\axiom{construct(v,t,ls)} creates a splitting tree with value (\\spadignore{i.e.} root vertex) given by \\axiom{[v,t]$S} and with children list given by \\axiom{[[s]$% for \\spad{s} in ls]}.") (($ |#1| |#2| (|List| $)) "\\axiom{construct(v,t,la)} creates a splitting tree with value (\\spadignore{i.e.} root vertex) given by \\axiom{[v,t]$S} and with \\axiom{la} as children list.") (($ (|SplittingNode| |#1| |#2|)) "\\axiom{construct(s)} creates a splitting tree with value (\\spadignore{i.e.} root vertex) given by \\axiom{s} and no children. Thus, if the status of \\axiom{s} is false, \\axiom{[s]} represents the starting point of the evaluation \\axiom{value(s)} under the hypothesis \\axiom{condition(s)}.")) (|updateStatus!| (($ $) "\\axiom{updateStatus!(a)} returns a where the status of the vertices are updated to satisfy the \"termination condition\".")) (|extractSplittingLeaf| (((|Union| $ "failed") $) "\\axiom{extractSplittingLeaf(a)} returns the left most leaf (as a tree) whose status is \\spad{false} if any, else \"failed\" is returned."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-1133 |#1| |#2|) (QUOTE (-1098))) (-12 (|HasCategory| (-1133 |#1| |#2|) (LIST (QUOTE -305) (LIST (QUOTE -1133) (|devaluate| |#1|) (|devaluate| |#2|)))) (|HasCategory| (-1133 |#1| |#2|) (QUOTE (-1098))))) 
-(-1135 |ndim| R) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-1154 |#1| |#2|) (QUOTE (-1119))) (-12 (|HasCategory| (-1154 |#1| |#2|) (LIST (QUOTE -325) (LIST (QUOTE -1154) (|devaluate| |#1|) (|devaluate| |#2|)))) (|HasCategory| (-1154 |#1| |#2|) (QUOTE (-1119))))) 
+(-1156 |ndim| R) 
 ((|constructor| (NIL "\\spadtype{SquareMatrix} is a matrix domain of square matrices, where the number of rows \\spad{(=} number of columns) is a parameter of the type.")) (|unitsKnown| ((|attribute|) "the invertible matrices are simply the matrices whose determinants are units in the Ring \\spad{R.}")) (|central| ((|attribute|) "the elements of the Ring \\spad{R,} viewed as diagonal matrices, commute with all matrices and, indeed, are the only matrices which commute with all matrices.")) (|coerce| (((|Matrix| |#2|) $) "\\spad{coerce(m)} converts a matrix of type \\spadtype{SquareMatrix} to a matrix of type \\spadtype{Matrix}.")) (|squareMatrix| (($ (|Matrix| |#2|)) "\\spad{squareMatrix(m)} converts a matrix of type \\spadtype{Matrix} to a matrix of type \\spadtype{SquareMatrix}.")) (|transpose| (($ $) "\\spad{transpose(m)} returns the transpose of the matrix \\spad{m.}"))) 
-((-4599 . T) (-4591 |has| |#2| (-6 (-4604 "*"))) (-4602 . T) (-4596 . T) (-4597 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227))) (|HasAttribute| |#2| (QUOTE (-4604 "*"))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (QUOTE (-303))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-368))) (-1841 (|HasAttribute| |#2| (QUOTE (-4604 "*"))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-227)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098))))) (|HasCategory| |#2| (QUOTE (-174)))) 
-(-1136 S) 
+((-4622 . T) (-4614 |has| |#2| (-6 (-4627 "*"))) (-4625 . T) (-4619 . T) (-4620 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247))) (|HasAttribute| |#2| (QUOTE (-4627 "*"))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (QUOTE (-323))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-388))) (-3836 (|HasAttribute| |#2| (QUOTE (-4627 "*"))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-247)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119))))) (|HasCategory| |#2| (QUOTE (-194)))) 
+(-1157 S) 
 ((|constructor| (NIL "A string aggregate is a category for strings, that is, one dimensional arrays of characters.")) (|elt| (($ $ $) "\\spad{elt(s,t)} returns the concatenation of \\spad{s} and \\spad{t.} It is provided to allow juxtaposition of strings to work as concatenation. For example, \\axiom{\"smoo\" \"shed\"} returns \\axiom{\"smooshed\"}.")) (|rightTrim| (($ $ (|CharacterClass|)) "\\spad{rightTrim(s,cc)} returns \\spad{s} with all trailing occurences of characters in \\spad{cc} deleted. For example, \\axiom{rightTrim(\"(abc)\", charClass \"()\")} returns \\axiom{\"(abc\"}.") (($ $ (|Character|)) "\\spad{rightTrim(s,c)} returns \\spad{s} with all trailing occurrences of \\spad{c} deleted. For example, \\axiom{rightTrim(\" abc \\spad{\",} char \" \\spad{\")}} returns \\axiom{\" abc\"}.")) (|leftTrim| (($ $ (|CharacterClass|)) "\\spad{leftTrim(s,cc)} returns \\spad{s} with all leading characters in \\spad{cc} deleted. For example, \\axiom{leftTrim(\"(abc)\", charClass \"()\")} returns \\axiom{\"abc)\"}.") (($ $ (|Character|)) "\\spad{leftTrim(s,c)} returns \\spad{s} with all leading characters \\spad{c} deleted. For example, \\axiom{leftTrim(\" abc \\spad{\",} char \" \\spad{\")}} returns \\axiom{\"abc \\spad{\"}.}")) (|trim| (($ $ (|CharacterClass|)) "\\spad{trim(s,cc)} returns \\spad{s} with all characters in \\spad{cc} deleted from right and left ends. For example, \\axiom{trim(\"(abc)\", charClass \"()\")} returns \\axiom{\"abc\"}.") (($ $ (|Character|)) "\\spad{trim(s,c)} returns \\spad{s} with all characters \\spad{c} deleted from right and left ends. For example, \\axiom{trim(\" abc \\spad{\",} char \" \\spad{\")}} returns \\axiom{\"abc\"}.")) (|split| (((|List| $) $ (|CharacterClass|)) "\\spad{split(s,cc)} returns a list of substrings delimited by characters in \\spad{cc.}") (((|List| $) $ (|Character|)) "\\spad{split(s,c)} returns a list of substrings delimited by character \\spad{c.}")) (|coerce| (($ (|Character|)) "\\spad{coerce(c)} returns \\spad{c} as a string \\spad{s} with the character \\spad{c.}")) (|position| (((|Integer|) (|CharacterClass|) $ (|Integer|)) "\\spad{position(cc,t,i)} returns the position \\axiom{j \\spad{>=} i} in \\spad{t} of the first character belonging to \\spad{cc.}") (((|Integer|) $ $ (|Integer|)) "\\spad{position(s,t,i)} returns the position \\spad{j} of the substring \\spad{s} in string \\spad{t,} where \\axiom{j \\spad{>=} i} is required.")) (|replace| (($ $ (|UniversalSegment| (|Integer|)) $) "\\spad{replace(s,i..j,t)} replaces the substring \\axiom{s(i..j)} of \\spad{s} by string \\spad{t.}")) (|match?| (((|Boolean|) $ $ (|Character|)) "\\spad{match?(s,t,c)} tests if \\spad{s} matches \\spad{t} except perhaps for multiple and consecutive occurrences of character \\spad{c.} Typically \\spad{c} is the blank character.")) (|match| (((|NonNegativeInteger|) $ $ (|Character|)) "\\spad{match(p,s,wc)} tests if pattern \\axiom{p} matches subject \\axiom{s} where \\axiom{wc} is a wild card character. If no match occurs, the index \\axiom{0} is returned; otheriwse, the value returned is the first index of the first character in the subject matching the subject (excluding that matched by an initial wild-card). For example, \\axiom{match(\"*to*\",\"yorktown\",\"*\")} returns \\axiom{5} indicating a successful match starting at index \\axiom{5} of \\axiom{\"yorktown\"}.")) (|substring?| (((|Boolean|) $ $ (|Integer|)) "\\spad{substring?(s,t,i)} tests if \\spad{s} is a substring of \\spad{t} beginning at index i. Note that \\axiom{substring?(s,t,0) = prefix?(s,t)}.")) (|suffix?| (((|Boolean|) $ $) "\\spad{suffix?(s,t)} tests if the string \\spad{s} is the final substring of \\spad{t.} Note that \\axiom{suffix?(s,t) \\spad{==} \\indented{1}{reduce(and,[s.i = t.(n - \\spad{m} + i) for \\spad{i} in 0..maxIndex s])}} where \\spad{m} and \\spad{n} denote the maxIndex of \\spad{s} and \\spad{t} respectively.")) (|prefix?| (((|Boolean|) $ $) "\\spad{prefix?(s,t)} tests if the string \\spad{s} is the initial substring of \\spad{t.} Note that \\axiom{prefix?(s,t) \\spad{==} \\indented{2}{reduce(and,[s.i = t.i for \\spad{i} in 0..maxIndex s])}.}")) (|upperCase!| (($ $) "\\spad{upperCase!(s)} destructively replaces the alphabetic characters in \\spad{s} by upper case characters.")) (|upperCase| (($ $) "\\spad{upperCase(s)} returns the string with all characters in upper case.")) (|lowerCase!| (($ $) "\\spad{lowerCase!(s)} destructively replaces the alphabetic characters in \\spad{s} by lower case.")) (|lowerCase| (($ $) "\\spad{lowerCase(s)} returns the string with all characters in lower case."))) 
 NIL 
 NIL 
-(-1137) 
+(-1158) 
 ((|constructor| (NIL "A string aggregate is a category for strings, that is, one dimensional arrays of characters.")) (|elt| (($ $ $) "\\spad{elt(s,t)} returns the concatenation of \\spad{s} and \\spad{t.} It is provided to allow juxtaposition of strings to work as concatenation. For example, \\axiom{\"smoo\" \"shed\"} returns \\axiom{\"smooshed\"}.")) (|rightTrim| (($ $ (|CharacterClass|)) "\\spad{rightTrim(s,cc)} returns \\spad{s} with all trailing occurences of characters in \\spad{cc} deleted. For example, \\axiom{rightTrim(\"(abc)\", charClass \"()\")} returns \\axiom{\"(abc\"}.") (($ $ (|Character|)) "\\spad{rightTrim(s,c)} returns \\spad{s} with all trailing occurrences of \\spad{c} deleted. For example, \\axiom{rightTrim(\" abc \\spad{\",} char \" \\spad{\")}} returns \\axiom{\" abc\"}.")) (|leftTrim| (($ $ (|CharacterClass|)) "\\spad{leftTrim(s,cc)} returns \\spad{s} with all leading characters in \\spad{cc} deleted. For example, \\axiom{leftTrim(\"(abc)\", charClass \"()\")} returns \\axiom{\"abc)\"}.") (($ $ (|Character|)) "\\spad{leftTrim(s,c)} returns \\spad{s} with all leading characters \\spad{c} deleted. For example, \\axiom{leftTrim(\" abc \\spad{\",} char \" \\spad{\")}} returns \\axiom{\"abc \\spad{\"}.}")) (|trim| (($ $ (|CharacterClass|)) "\\spad{trim(s,cc)} returns \\spad{s} with all characters in \\spad{cc} deleted from right and left ends. For example, \\axiom{trim(\"(abc)\", charClass \"()\")} returns \\axiom{\"abc\"}.") (($ $ (|Character|)) "\\spad{trim(s,c)} returns \\spad{s} with all characters \\spad{c} deleted from right and left ends. For example, \\axiom{trim(\" abc \\spad{\",} char \" \\spad{\")}} returns \\axiom{\"abc\"}.")) (|split| (((|List| $) $ (|CharacterClass|)) "\\spad{split(s,cc)} returns a list of substrings delimited by characters in \\spad{cc.}") (((|List| $) $ (|Character|)) "\\spad{split(s,c)} returns a list of substrings delimited by character \\spad{c.}")) (|coerce| (($ (|Character|)) "\\spad{coerce(c)} returns \\spad{c} as a string \\spad{s} with the character \\spad{c.}")) (|position| (((|Integer|) (|CharacterClass|) $ (|Integer|)) "\\spad{position(cc,t,i)} returns the position \\axiom{j \\spad{>=} i} in \\spad{t} of the first character belonging to \\spad{cc.}") (((|Integer|) $ $ (|Integer|)) "\\spad{position(s,t,i)} returns the position \\spad{j} of the substring \\spad{s} in string \\spad{t,} where \\axiom{j \\spad{>=} i} is required.")) (|replace| (($ $ (|UniversalSegment| (|Integer|)) $) "\\spad{replace(s,i..j,t)} replaces the substring \\axiom{s(i..j)} of \\spad{s} by string \\spad{t.}")) (|match?| (((|Boolean|) $ $ (|Character|)) "\\spad{match?(s,t,c)} tests if \\spad{s} matches \\spad{t} except perhaps for multiple and consecutive occurrences of character \\spad{c.} Typically \\spad{c} is the blank character.")) (|match| (((|NonNegativeInteger|) $ $ (|Character|)) "\\spad{match(p,s,wc)} tests if pattern \\axiom{p} matches subject \\axiom{s} where \\axiom{wc} is a wild card character. If no match occurs, the index \\axiom{0} is returned; otheriwse, the value returned is the first index of the first character in the subject matching the subject (excluding that matched by an initial wild-card). For example, \\axiom{match(\"*to*\",\"yorktown\",\"*\")} returns \\axiom{5} indicating a successful match starting at index \\axiom{5} of \\axiom{\"yorktown\"}.")) (|substring?| (((|Boolean|) $ $ (|Integer|)) "\\spad{substring?(s,t,i)} tests if \\spad{s} is a substring of \\spad{t} beginning at index i. Note that \\axiom{substring?(s,t,0) = prefix?(s,t)}.")) (|suffix?| (((|Boolean|) $ $) "\\spad{suffix?(s,t)} tests if the string \\spad{s} is the final substring of \\spad{t.} Note that \\axiom{suffix?(s,t) \\spad{==} \\indented{1}{reduce(and,[s.i = t.(n - \\spad{m} + i) for \\spad{i} in 0..maxIndex s])}} where \\spad{m} and \\spad{n} denote the maxIndex of \\spad{s} and \\spad{t} respectively.")) (|prefix?| (((|Boolean|) $ $) "\\spad{prefix?(s,t)} tests if the string \\spad{s} is the initial substring of \\spad{t.} Note that \\axiom{prefix?(s,t) \\spad{==} \\indented{2}{reduce(and,[s.i = t.i for \\spad{i} in 0..maxIndex s])}.}")) (|upperCase!| (($ $) "\\spad{upperCase!(s)} destructively replaces the alphabetic characters in \\spad{s} by upper case characters.")) (|upperCase| (($ $) "\\spad{upperCase(s)} returns the string with all characters in upper case.")) (|lowerCase!| (($ $) "\\spad{lowerCase!(s)} destructively replaces the alphabetic characters in \\spad{s} by lower case.")) (|lowerCase| (($ $) "\\spad{lowerCase(s)} returns the string with all characters in lower case."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-1138 R E V P TS) 
+(-1159 R E V P TS) 
 ((|constructor| (NIL "A package providing a new algorithm for solving polynomial systems by means of regular chains. Two ways of solving are provided: in the sense of Zariski closure (like in Kalkbrener's algorithm) or in the sense of the regular zeros (like in Wu, Wang or Lazard- Moreno methods). This algorithm is valid for any type of regular set. It does not care about the way a polynomial is added in an regular set, or how two quasi-components are compared (by an inclusion-test), or how the invertibility test is made in the tower of simple extensions associated with a regular set. These operations are realized respectively by the domain \\spad{TS} and the packages \\spad{QCMPPK(R,E,V,P,TS)} and \\spad{RSETGCD(R,E,V,P,TS)}. The same way it does not care about the way univariate polynomial gcds (with coefficients in the tower of simple extensions associated with a regular set) are computed. The only requirement is that these gcds need to have invertible initials (normalized or not). WARNING. There is no need for a user to call directly any operation of this package since they can be accessed by the domain \\axiomType{TS}. Thus, the operations of this package are not documented."))) 
 NIL 
 NIL 
-(-1139 R E V P) 
+(-1160 R E V P) 
 ((|constructor| (NIL "This domain provides an implementation of square-free regular chains. Moreover, the operation zeroSetSplit is an implementation of a new algorithm for solving polynomial systems by means of regular chains.")) (|preprocess| (((|Record| (|:| |val| (|List| |#4|)) (|:| |towers| (|List| $))) (|List| |#4|) (|Boolean|) (|Boolean|)) "\\axiom{pre_process(lp,b1,b2)} is an internal subroutine, exported only for developement.")) (|internalZeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{internalZeroSetSplit(lp,b1,b2,b3)} is an internal subroutine, exported only for developement.")) (|zeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{zeroSetSplit(lp,b1,b2.b3,b4)} is an internal subroutine, exported only for developement.") (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|)) "\\axiom{zeroSetSplit(lp,clos?,info?)} has the same specifications as zeroSetSplit from RegularTriangularSetCategory from \\spadtype{RegularTriangularSetCategory} Moreover, if clos? then solves in the sense of the Zariski closure else solves in the sense of the regular zeros. If \\axiom{info?} then do print messages during the computations.")) (|internalAugment| (((|List| $) |#4| $ (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{internalAugment(p,ts,b1,b2,b3,b4,b5)} is an internal subroutine, exported only for developement."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#4| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#4| (QUOTE (-1098))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#3| (QUOTE (-374)))) 
-(-1140 S) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#4| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#4| (QUOTE (-1119))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#3| (QUOTE (-394)))) 
+(-1161 S) 
 ((|constructor| (NIL "Linked List implementation of a Stack")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} member?(3,a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} count(4,a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} count(x+->(x>2),a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} any?(x+->(x=4),a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} every?(x+->(x=4),a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} b:Stack INT:= stack [1,2,3,4,5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} map!(x+->x+10,a) \\spad{X} a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} map(x+->x+10,a) \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} b:=copy a \\spad{X} eq?(a,b)")) (|copy| (($ $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} copy a")) (|sample| (($) "\\blankline \\spad{X} sample()$Stack(INT)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()$(Stack INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} empty? a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,2,3,4,5])$Stack(INT)")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} size?(a,5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} more?(a,9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} less?(a,9)")) (|depth| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} depth a")) (|top| ((|#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} top a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} insert!(8,a) \\spad{X} a")) (|push!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} push!(9,a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} extract! a \\spad{X} a")) (|pop!| ((|#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5] \\spad{X} pop! a \\spad{X} a")) (|stack| (($ (|List| |#1|)) "\\indented{1}{stack([x,y,...,z]) creates a stack with first (top)} \\indented{1}{element \\spad{x,} second element y,...,and last element \\spad{z.}} \\blankline \\spad{X} a:Stack INT:= stack [1,2,3,4,5]"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-1141 A S) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-1162 A S) 
 ((|constructor| (NIL "A stream aggregate is a linear aggregate which possibly has an infinite number of elements. A basic domain constructor which builds stream aggregates is \\spadtype{Stream}. From streams, a number of infinite structures such power series can be built. A stream aggregate may also be infinite since it may be cyclic. For example, see \\spadtype{DecimalExpansion}.")) (|possiblyInfinite?| (((|Boolean|) $) "\\spad{possiblyInfinite?(s)} tests if the stream \\spad{s} could possibly have an infinite number of elements. Note that for many datatypes, \\axiom{possiblyInfinite?(s) = not explictlyFinite?(s)}.")) (|explicitlyFinite?| (((|Boolean|) $) "\\spad{explicitlyFinite?(s)} tests if the stream has a finite number of elements, and \\spad{false} otherwise. Note that for many datatypes, \\axiom{explicitlyFinite?(s) = not possiblyInfinite?(s)}."))) 
 NIL 
 NIL 
-(-1142 S) 
+(-1163 S) 
 ((|constructor| (NIL "A stream aggregate is a linear aggregate which possibly has an infinite number of elements. A basic domain constructor which builds stream aggregates is \\spadtype{Stream}. From streams, a number of infinite structures such power series can be built. A stream aggregate may also be infinite since it may be cyclic. For example, see \\spadtype{DecimalExpansion}.")) (|possiblyInfinite?| (((|Boolean|) $) "\\spad{possiblyInfinite?(s)} tests if the stream \\spad{s} could possibly have an infinite number of elements. Note that for many datatypes, \\axiom{possiblyInfinite?(s) = not explictlyFinite?(s)}.")) (|explicitlyFinite?| (((|Boolean|) $) "\\spad{explicitlyFinite?(s)} tests if the stream has a finite number of elements, and \\spad{false} otherwise. Note that for many datatypes, \\axiom{explicitlyFinite?(s) = not possiblyInfinite?(s)}."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-1143 |Key| |Ent| |dent|) 
+(-1164 |Key| |Ent| |dent|) 
 ((|constructor| (NIL "A sparse table has a default entry, which is returned if no other value has been explicitly stored for a key."))) 
-((-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098)))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098)))) (-1841 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-1098))))) 
-(-1144) 
+((-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119)))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119)))) (-3836 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-1119))))) 
+(-1165) 
 ((|constructor| (NIL "A class of objects which can be 'stepped through'. Repeated applications of \\spadfun{nextItem} is guaranteed never to return duplicate items and only return \"failed\" after exhausting all elements of the domain. This assumes that the sequence starts with \\spad{init()}. For infinite domains, repeated application of \\spadfun{nextItem} is not required to reach all possible domain elements starting from any initial element. \\blankline Conditional attributes\\br \\tab{5}infinite\\tab{5}repeated nextItem's are never \"failed\".")) (|nextItem| (((|Union| $ "failed") $) "\\spad{nextItem(x)} returns the next item, or \"failed\" if domain is exhausted.")) (|init| (($) "\\spad{init()} chooses an initial object for stepping."))) 
 NIL 
 NIL 
-(-1145 |Coef|) 
+(-1166 |Coef|) 
 ((|constructor| (NIL "This package computes infinite products of Taylor series over an integral domain of characteristic 0. Here Taylor series are represented by streams of Taylor coefficients.")) (|generalInfiniteProduct| (((|Stream| |#1|) (|Stream| |#1|) (|Integer|) (|Integer|)) "\\spad{generalInfiniteProduct(f(x),a,d)} computes \\spad{product(n=a,a+d,a+2*d,...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|oddInfiniteProduct| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{oddInfiniteProduct(f(x))} computes \\spad{product(n=1,3,5...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|evenInfiniteProduct| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{evenInfiniteProduct(f(x))} computes \\spad{product(n=2,4,6...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1.")) (|infiniteProduct| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{infiniteProduct(f(x))} computes \\spad{product(n=1,2,3...,f(x**n))}. The series \\spad{f(x)} should have constant coefficient 1."))) 
 NIL 
 NIL 
-(-1146 R) 
+(-1167 R) 
 ((|constructor| (NIL "This package has no description")) (|tensorMap| (((|Stream| |#1|) (|Stream| |#1|) (|Mapping| (|List| |#1|) |#1|)) "\\spad{tensorMap([s1, \\spad{s2,} ...], \\spad{f)}} returns the stream consisting of all elements of f(s1) followed by all elements of f(s2) and so on."))) 
 NIL 
 NIL 
-(-1147 S) 
+(-1168 S) 
 ((|constructor| (NIL "Functions defined on streams with entries in one set.")) (|concat| (((|Stream| |#1|) (|Stream| (|Stream| |#1|))) "\\indented{1}{concat(u) returns the left-to-right concatentation of the} \\indented{1}{streams in u. Note that \\spad{concat(u) = reduce(concat,u)}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 10..] \\spad{X} n:=[j for \\spad{j} in 1.. | prime? \\spad{j]} \\spad{X} p:=[m,n]::Stream(Stream(PositiveInteger)) \\spad{X} concat(p)"))) 
 NIL 
 NIL 
-(-1148 A B) 
+(-1169 A B) 
 ((|constructor| (NIL "Functions defined on streams with entries in two sets.")) (|reduce| ((|#2| |#2| (|Mapping| |#2| |#1| |#2|) (|Stream| |#1|)) "\\indented{1}{reduce(b,f,u), where \\spad{u} is a finite stream \\spad{[x0,x1,...,xn]},} \\indented{1}{returns the value \\spad{r(n)} computed as follows:} \\indented{1}{\\spad{r0 = f(x0,b),} \\indented{1}{r1 = f(x1,r0),...,} \\indented{1}{r(n) = f(xn,r(n-1))}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..300]::Stream(Integer) \\spad{X} f(i:Integer,j:Integer):Integer==i+j \\spad{X} reduce(1,f,m)")) (|scan| (((|Stream| |#2|) |#2| (|Mapping| |#2| |#1| |#2|) (|Stream| |#1|)) "\\indented{1}{scan(b,h,[x0,x1,x2,...]) returns \\spad{[y0,y1,y2,...]}, where} \\indented{1}{\\spad{y0 = h(x0,b)},} \\indented{1}{\\spad{y1 = h(x1,y0)},\\spad{...}} \\indented{1}{\\spad{yn = h(xn,y(n-1))}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..]::Stream(Integer) \\spad{X} f(i:Integer,j:Integer):Integer==i+j \\spad{X} scan(1,f,m)")) (|map| (((|Stream| |#2|) (|Mapping| |#2| |#1|) (|Stream| |#1|)) "\\indented{1}{map(f,s) returns a stream whose elements are the function \\spad{f} applied} \\indented{1}{to the corresponding elements of \\spad{s.}} \\indented{1}{Note that \\spad{map(f,[x0,x1,x2,...]) = [f(x0),f(x1),f(x2),..]}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..] \\spad{X} \\spad{f(i:PositiveInteger):PositiveInteger==i**2} \\spad{X} map(f,m)"))) 
 NIL 
 NIL 
-(-1149 A B C) 
+(-1170 A B C) 
 ((|constructor| (NIL "Functions defined on streams with entries in three sets.")) (|map| (((|Stream| |#3|) (|Mapping| |#3| |#1| |#2|) (|Stream| |#1|) (|Stream| |#2|)) "\\indented{1}{map(f,st1,st2) returns the stream whose elements are the} \\indented{1}{function \\spad{f} applied to the corresponding elements of \\spad{st1} and st2.} \\indented{1}{\\spad{map(f,[x0,x1,x2,..],[y0,y1,y2,..]) = [f(x0,y0),f(x1,y1),..]}.} \\blankline \\spad{S} \\spad{X} m:=[i for \\spad{i} in 1..]::Stream(Integer) \\spad{X} n:=[i for \\spad{i} in 1..]::Stream(Integer) \\spad{X} f(i:Integer,j:Integer):Integer \\spad{==} i+j \\spad{X} map(f,m,n)"))) 
 NIL 
 NIL 
-(-1150 S) 
+(-1171 S) 
 ((|constructor| (NIL "A stream is an implementation of an infinite sequence using a list of terms that have been computed and a function closure to compute additional terms when needed.")) (|filterUntil| (($ (|Mapping| (|Boolean|) |#1|) $) "\\indented{1}{filterUntil(p,s) returns \\spad{[x0,x1,...,x(n)]} where} \\indented{1}{\\spad{s = [x0,x1,x2,..]} and} \\indented{1}{n is the smallest index such that \\spad{p(xn) = true}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..] \\spad{X} f(x:PositiveInteger):Boolean \\spad{==} \\spad{x} < 5 \\spad{X} filterUntil(f,m)")) (|filterWhile| (($ (|Mapping| (|Boolean|) |#1|) $) "\\indented{1}{filterWhile(p,s) returns \\spad{[x0,x1,...,x(n-1)]} where} \\indented{1}{\\spad{s = [x0,x1,x2,..]} and} \\indented{1}{n is the smallest index such that \\spad{p(xn) = false}.} \\blankline \\spad{X} m:=[i for \\spad{i} in 1..] \\spad{X} f(x:PositiveInteger):Boolean \\spad{==} \\spad{x} < 5 \\spad{X} filterWhile(f,m)")) (|generate| (($ (|Mapping| |#1| |#1|) |#1|) "\\indented{1}{generate(f,x) creates an infinite stream whose first element is} \\indented{1}{x and whose \\spad{n}th element (\\spad{n > 1}) is \\spad{f} applied to the previous} \\indented{1}{element. Note: \\spad{generate(f,x) = [x,f(x),f(f(x)),...]}.} \\blankline \\spad{X} f(x:Integer):Integer \\spad{==} \\spad{x+10} \\spad{X} generate(f,10)") (($ (|Mapping| |#1|)) "\\indented{1}{generate(f) creates an infinite stream all of whose elements are} \\indented{1}{equal to \\spad{f()}.} \\indented{1}{Note: \\spad{generate(f) = [f(),f(),f(),...]}.} \\blankline \\spad{X} f():Integer \\spad{==} 1 \\spad{X} generate(f)")) (|setrest!| (($ $ (|Integer|) $) "\\indented{1}{setrest!(x,n,y) sets rest(x,n) to \\spad{y.} The function will expand} \\indented{1}{cycles if necessary.} \\blankline \\spad{X} p:=[i for \\spad{i} in 1..] \\spad{X} q:=[i for \\spad{i} in 9..] \\spad{X} setrest!(p,4,q) \\spad{X} \\spad{p}")) (|showAll?| (((|Boolean|)) "\\spad{showAll?()} returns \\spad{true} if all computed entries of streams will be displayed.")) (|showAllElements| (((|OutputForm|) $) "\\indented{1}{showAllElements(s) creates an output form which displays all} \\indented{1}{computed elements.} \\blankline \\spad{X} m:=[1,2,3,4,5,6,7,8,9,10,11,12] \\spad{X} n:=m::Stream(PositiveInteger) \\spad{X} showAllElements \\spad{n}")) (|output| (((|Void|) (|Integer|) $) "\\indented{1}{output(n,st) computes and displays the first \\spad{n} entries} \\indented{1}{of st.} \\blankline \\spad{X} m:=[1,2,3] \\spad{X} n:=repeating(m) \\spad{X} output(5,n)")) (|cons| (($ |#1| $) "\\indented{1}{cons(a,s) returns a stream whose \\spad{first} is \\spad{a}} \\indented{1}{and whose \\spad{rest} is \\spad{s.}} \\indented{1}{Note: \\spad{cons(a,s) = concat(a,s)}.} \\blankline \\spad{X} m:=[1,2,3] \\spad{X} n:=repeating(m) \\spad{X} cons(4,n)")) (|delay| (($ (|Mapping| $)) "\\spad{delay(f)} creates a stream with a lazy evaluation defined by function \\spad{f.} Caution: This function can only be called in compiled code.")) (|findCycle| (((|Record| (|:| |cycle?| (|Boolean|)) (|:| |prefix| (|NonNegativeInteger|)) (|:| |period| (|NonNegativeInteger|))) (|NonNegativeInteger|) $) "\\indented{1}{findCycle(n,st) determines if st is periodic within \\spad{n.}} \\blankline \\spad{X} m:=[1,2,3] \\spad{X} n:=repeating(m) \\spad{X} findCycle(3,n) \\spad{X} findCycle(2,n)")) (|repeating?| (((|Boolean|) (|List| |#1|) $) "\\indented{1}{repeating?(l,s) returns \\spad{true} if a stream \\spad{s} is periodic} \\indented{1}{with period \\spad{l,} and \\spad{false} otherwise.} \\blankline \\spad{X} m:=[1,2,3] \\spad{X} n:=repeating(m) \\spad{X} repeating?(m,n)")) (|repeating| (($ (|List| |#1|)) "\\indented{1}{repeating(l) is a repeating stream whose period is the list \\spad{l.}} \\blankline \\spad{X} m:=repeating([-1,0,1,2,3])")) (|coerce| (($ (|List| |#1|)) "\\indented{1}{coerce(l) converts a list \\spad{l} to a stream.} \\blankline \\spad{X} m:=[1,2,3,4,5,6,7,8,9,10,11,12] \\spad{X} coerce(m)@Stream(Integer) \\spad{X} m::Stream(Integer)")) (|shallowlyMutable| ((|attribute|) "one may destructively alter a stream by assigning new values to its entries."))) 
-((-4603 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-572) (QUOTE (-848)))) 
-(-1151) 
+((-4626 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-592) (QUOTE (-869)))) 
+(-1172) 
 ((|constructor| (NIL "A category for string-like objects")) (|string| (($ (|Integer|)) "\\spad{string(i)} returns the decimal representation of \\spad{i} in a string"))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-1152) 
+(-1173) 
 ((|constructor| (NIL "This is the domain of character strings. Strings are 1 based."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-148) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-148) (QUOTE (-848))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-148) (QUOTE (-1098))) (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-848)))) (-12 (|HasCategory| (-148) (LIST (QUOTE -305) (QUOTE (-148)))) (|HasCategory| (-148) (QUOTE (-1098)))))) 
-(-1153 |Entry|) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-168) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-168) (QUOTE (-869))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-168) (QUOTE (-1119))) (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-869)))) (-12 (|HasCategory| (-168) (LIST (QUOTE -325) (QUOTE (-168)))) (|HasCategory| (-168) (QUOTE (-1119)))))) 
+(-1174 |Entry|) 
 ((|constructor| (NIL "This domain provides tables where the keys are strings. A specialized hash function for strings is used."))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (QUOTE (-1152))) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (QUOTE (-1098)))) (|HasCategory| (-1152) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098))) (-1841 (|HasCategory| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (QUOTE (-1098))) (|HasCategory| |#1| (QUOTE (-1098)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-1154 A) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (QUOTE (-1173))) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (QUOTE (-1119)))) (|HasCategory| (-1173) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119))) (-3836 (|HasCategory| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (QUOTE (-1119))) (|HasCategory| |#1| (QUOTE (-1119)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-1175 A) 
 ((|constructor| (NIL "StreamTaylorSeriesOperations implements Taylor series arithmetic, where a Taylor series is represented by a stream of its coefficients.")) (|power| (((|Stream| |#1|) |#1| (|Stream| |#1|)) "\\spad{power(a,f)} returns the power series \\spad{f} raised to the power \\spad{a}.")) (|lazyGintegrate| (((|Stream| |#1|) (|Mapping| |#1| (|Integer|)) |#1| (|Mapping| (|Stream| |#1|))) "\\spad{lazyGintegrate(f,r,g)} is used for fixed point computations.")) (|mapdiv| (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{mapdiv([a0,a1,..],[b0,b1,..])} returns \\spad{[a0/b0,a1/b1,..]}.")) (|powern| (((|Stream| |#1|) (|Fraction| (|Integer|)) (|Stream| |#1|)) "\\spad{powern(r,f)} raises power series \\spad{f} to the power \\spad{r.}")) (|nlde| (((|Stream| |#1|) (|Stream| (|Stream| |#1|))) "\\spad{nlde(u)} solves a first order non-linear differential equation described by \\spad{u} of the form \\spad{[[b<0,0>,b<0,1>,...],[b<1,0>,b<1,1>,.],...]}. the differential equation has the form \\spad{y'=sum(i=0 to \\spad{infinity,j=0} to infinity,b<i,j>*(x**i)*(y**j))}.")) (|lazyIntegrate| (((|Stream| |#1|) |#1| (|Mapping| (|Stream| |#1|))) "\\spad{lazyIntegrate(r,f)} is a local function used for fixed point computations.")) (|integrate| (((|Stream| |#1|) |#1| (|Stream| |#1|)) "\\spad{integrate(r,a)} returns the integral of the power series \\spad{a} with respect to the power series variableintegration where \\spad{r} denotes the constant of integration. Thus \\spad{integrate(a,[a0,a1,a2,...]) = [a,a0,a1/2,a2/3,...]}.")) (|invmultisect| (((|Stream| |#1|) (|Integer|) (|Integer|) (|Stream| |#1|)) "\\spad{invmultisect(a,b,st)} substitutes \\spad{x**((a+b)*n)} for \\spad{x**n} and multiplies by \\spad{x**b}.")) (|multisect| (((|Stream| |#1|) (|Integer|) (|Integer|) (|Stream| |#1|)) "\\spad{multisect(a,b,st)} selects the coefficients of \\spad{x**((a+b)*n+a)}, and changes them to \\spad{x**n}.")) (|generalLambert| (((|Stream| |#1|) (|Stream| |#1|) (|Integer|) (|Integer|)) "\\spad{generalLambert(f(x),a,d)} returns \\spad{f(x**a) + f(x**(a + \\spad{d))} + f(x**(a + 2 \\spad{d))} + ...}. \\spad{f(x)} should have zero constant coefficient and \\spad{a} and \\spad{d} should be positive.")) (|evenlambert| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{evenlambert(st)} computes \\spad{f(x**2) + f(x**4) + f(x**6) + ...} if \\spad{st} is a stream representing \\spad{f(x)}. This function is used for computing infinite products. If \\spad{f(x)} is a power series with constant coefficient 1, then \\spad{prod(f(x**(2*n)),n=1..infinity) = exp(evenlambert(log(f(x))))}.")) (|oddlambert| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{oddlambert(st)} computes \\spad{f(x) + f(x**3) + f(x**5) + ...} if \\spad{st} is a stream representing \\spad{f(x)}. This function is used for computing infinite products. If f(x) is a power series with constant coefficient 1 then \\spad{prod(f(x**(2*n-1)),n=1..infinity) = exp(oddlambert(log(f(x))))}.")) (|lambert| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{lambert(st)} computes \\spad{f(x) + f(x**2) + f(x**3) + ...} if \\spad{st} is a stream representing \\spad{f(x)}. This function is used for computing infinite products. If \\spad{f(x)} is a power series with constant coefficient 1 then \\spad{prod(f(x**n),n = 1..infinity) = exp(lambert(log(f(x))))}.")) (|addiag| (((|Stream| |#1|) (|Stream| (|Stream| |#1|))) "\\spad{addiag(x)} performs diagonal addition of a stream of streams. if \\spad{x} = \\spad{[[a<0,0>,a<0,1>,..],[a<1,0>,a<1,1>,..],[a<2,0>,a<2,1>,..],..]} and \\spad{addiag(x) = [b<0,b<1>,...], then b<k> = sum(i+j=k,a<i,j>)}.")) (|revert| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{revert(a)} computes the inverse of a power series \\spad{a} with respect to composition. the series should have constant coefficient 0 and first order coefficient 1.")) (|lagrange| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{lagrange(g)} produces the power series for \\spad{f} where \\spad{f} is implicitly defined as \\spad{f(z) = z*g(f(z))}.")) (|compose| (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{compose(a,b)} composes the power series \\spad{a} with the power series \\spad{b.}")) (|eval| (((|Stream| |#1|) (|Stream| |#1|) |#1|) "\\spad{eval(a,r)} returns a stream of partial sums of the power series \\spad{a} evaluated at the power series variable equal to \\spad{r.}")) (|coerce| (((|Stream| |#1|) |#1|) "\\spad{coerce(r)} converts a ring element \\spad{r} to a stream with one element.")) (|gderiv| (((|Stream| |#1|) (|Mapping| |#1| (|Integer|)) (|Stream| |#1|)) "\\spad{gderiv(f,[a0,a1,a2,..])} returns \\spad{[f(0)*a0,f(1)*a1,f(2)*a2,..]}.")) (|deriv| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{deriv(a)} returns the derivative of the power series with respect to the power series variable. Thus \\spad{deriv([a0,a1,a2,...])} returns \\spad{[a1,2 \\spad{a2,3} a3,...]}.")) (|mapmult| (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{mapmult([a0,a1,..],[b0,b1,..])} returns \\spad{[a0*b0,a1*b1,..]}.")) (|int| (((|Stream| |#1|) |#1|) "\\spad{int(r)} returns [r,r+1,r+2,...], where \\spad{r} is a ring element.")) (|oddintegers| (((|Stream| (|Integer|)) (|Integer|)) "\\spad{oddintegers(n)} returns \\spad{[n,n+2,n+4,...]}.")) (|integers| (((|Stream| (|Integer|)) (|Integer|)) "\\spad{integers(n)} returns \\spad{[n,n+1,n+2,...]}.")) (|monom| (((|Stream| |#1|) |#1| (|Integer|)) "\\spad{monom(deg,coef)} is a monomial of degree \\spad{deg} with coefficient coef.")) (|recip| (((|Union| (|Stream| |#1|) "failed") (|Stream| |#1|)) "\\spad{recip(a)} returns the power series reciprocal of \\spad{a}, or \"failed\" if not possible.")) (/ (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{a / \\spad{b}} returns the power series quotient of \\spad{a} by \\spad{b.} An error message is returned if \\spad{b} is not invertible. This function is used in fixed point computations.")) (|exquo| (((|Union| (|Stream| |#1|) "failed") (|Stream| |#1|) (|Stream| |#1|)) "\\spad{exquo(a,b)} returns the power series quotient of \\spad{a} by \\spad{b,} if the quotient exists, and \"failed\" otherwise")) (* (((|Stream| |#1|) (|Stream| |#1|) |#1|) "\\spad{a * \\spad{r}} returns the power series scalar multiplication of \\spad{a} by \\spad{r:} \\spad{[a0,a1,...] * \\spad{r} = \\spad{[a0} * \\spad{r,a1} * r,...]}") (((|Stream| |#1|) |#1| (|Stream| |#1|)) "\\spad{r * a} returns the power series scalar multiplication of \\spad{r} by \\spad{a}: \\spad{r * [a0,a1,...] = \\spad{[r} * a0,r * a1,...]}") (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{a * \\spad{b}} returns the power series (Cauchy) product of \\spad{a} and \\spad{b:} \\spad{[a0,a1,...] * [b0,b1,...] = [c0,c1,...]} where \\spad{ck = sum(i + \\spad{j} = k,ai * bk)}.")) (- (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{- a} returns the power series negative of \\spad{a}: \\spad{- [a0,a1,...] = \\spad{[-} a0,- a1,...]}") (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{a - \\spad{b}} returns the power series difference of \\spad{a} and \\spad{b}: \\spad{[a0,a1,..] - [b0,b1,..] = \\spad{[a0} - \\spad{b0,a1} - b1,..]}")) (+ (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{a + \\spad{b}} returns the power series sum of \\spad{a} and \\spad{b}: \\spad{[a0,a1,..] + [b0,b1,..] = \\spad{[a0} + \\spad{b0,a1} + b1,..]}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) 
-(-1155 |Coef|) 
+((|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) 
+(-1176 |Coef|) 
 ((|constructor| (NIL "StreamTranscendentalFunctionsNonCommutative implements transcendental functions on Taylor series over a non-commutative ring, where a Taylor series is represented by a stream of its coefficients.")) (|acsch| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acsch(st)} computes the inverse hyperbolic cosecant of a power series \\spad{st.}")) (|asech| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{asech(st)} computes the inverse hyperbolic secant of a power series \\spad{st.}")) (|acoth| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acoth(st)} computes the inverse hyperbolic cotangent of a power series \\spad{st.}")) (|atanh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{atanh(st)} computes the inverse hyperbolic tangent of a power series \\spad{st.}")) (|acosh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acosh(st)} computes the inverse hyperbolic cosine of a power series \\spad{st.}")) (|asinh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{asinh(st)} computes the inverse hyperbolic sine of a power series \\spad{st.}")) (|csch| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{csch(st)} computes the hyperbolic cosecant of a power series \\spad{st.}")) (|sech| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{sech(st)} computes the hyperbolic secant of a power series \\spad{st.}")) (|coth| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{coth(st)} computes the hyperbolic cotangent of a power series \\spad{st.}")) (|tanh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{tanh(st)} computes the hyperbolic tangent of a power series \\spad{st.}")) (|cosh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{cosh(st)} computes the hyperbolic cosine of a power series \\spad{st.}")) (|sinh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{sinh(st)} computes the hyperbolic sine of a power series \\spad{st.}")) (|acsc| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acsc(st)} computes arccosecant of a power series \\spad{st.}")) (|asec| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{asec(st)} computes arcsecant of a power series \\spad{st.}")) (|acot| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acot(st)} computes arccotangent of a power series \\spad{st.}")) (|atan| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{atan(st)} computes arctangent of a power series \\spad{st.}")) (|acos| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acos(st)} computes arccosine of a power series \\spad{st.}")) (|asin| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{asin(st)} computes arcsine of a power series \\spad{st.}")) (|csc| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{csc(st)} computes cosecant of a power series \\spad{st.}")) (|sec| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{sec(st)} computes secant of a power series \\spad{st.}")) (|cot| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{cot(st)} computes cotangent of a power series \\spad{st.}")) (|tan| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{tan(st)} computes tangent of a power series \\spad{st.}")) (|cos| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{cos(st)} computes cosine of a power series \\spad{st.}")) (|sin| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{sin(st)} computes sine of a power series \\spad{st.}")) (** (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{st1 \\spad{**} st2} computes the power of a power series \\spad{st1} by another power series st2.")) (|log| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{log(st)} computes the log of a power series.")) (|exp| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{exp(st)} computes the exponential of a power series \\spad{st.}"))) 
 NIL 
 NIL 
-(-1156 |Coef|) 
+(-1177 |Coef|) 
 ((|constructor| (NIL "StreamTranscendentalFunctions implements transcendental functions on Taylor series, where a Taylor series is represented by a stream of its coefficients.")) (|acsch| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acsch(st)} computes the inverse hyperbolic cosecant of a power series \\spad{st.}")) (|asech| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{asech(st)} computes the inverse hyperbolic secant of a power series \\spad{st.}")) (|acoth| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acoth(st)} computes the inverse hyperbolic cotangent of a power series \\spad{st.}")) (|atanh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{atanh(st)} computes the inverse hyperbolic tangent of a power series \\spad{st.}")) (|acosh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acosh(st)} computes the inverse hyperbolic cosine of a power series \\spad{st.}")) (|asinh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{asinh(st)} computes the inverse hyperbolic sine of a power series \\spad{st.}")) (|csch| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{csch(st)} computes the hyperbolic cosecant of a power series \\spad{st.}")) (|sech| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{sech(st)} computes the hyperbolic secant of a power series \\spad{st.}")) (|coth| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{coth(st)} computes the hyperbolic cotangent of a power series \\spad{st.}")) (|tanh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{tanh(st)} computes the hyperbolic tangent of a power series \\spad{st.}")) (|cosh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{cosh(st)} computes the hyperbolic cosine of a power series \\spad{st.}")) (|sinh| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{sinh(st)} computes the hyperbolic sine of a power series \\spad{st.}")) (|sinhcosh| (((|Record| (|:| |sinh| (|Stream| |#1|)) (|:| |cosh| (|Stream| |#1|))) (|Stream| |#1|)) "\\spad{sinhcosh(st)} returns a record containing the hyperbolic sine and cosine of a power series \\spad{st.}")) (|acsc| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acsc(st)} computes arccosecant of a power series \\spad{st.}")) (|asec| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{asec(st)} computes arcsecant of a power series \\spad{st.}")) (|acot| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acot(st)} computes arccotangent of a power series \\spad{st.}")) (|atan| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{atan(st)} computes arctangent of a power series \\spad{st.}")) (|acos| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{acos(st)} computes arccosine of a power series \\spad{st.}")) (|asin| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{asin(st)} computes arcsine of a power series \\spad{st.}")) (|csc| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{csc(st)} computes cosecant of a power series \\spad{st.}")) (|sec| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{sec(st)} computes secant of a power series \\spad{st.}")) (|cot| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{cot(st)} computes cotangent of a power series \\spad{st.}")) (|tan| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{tan(st)} computes tangent of a power series \\spad{st.}")) (|cos| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{cos(st)} computes cosine of a power series \\spad{st.}")) (|sin| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{sin(st)} computes sine of a power series \\spad{st.}")) (|sincos| (((|Record| (|:| |sin| (|Stream| |#1|)) (|:| |cos| (|Stream| |#1|))) (|Stream| |#1|)) "\\spad{sincos(st)} returns a record containing the sine and cosine of a power series \\spad{st.}")) (** (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{st1 \\spad{**} st2} computes the power of a power series \\spad{st1} by another power series st2.")) (|log| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{log(st)} computes the log of a power series.")) (|exp| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{exp(st)} computes the exponential of a power series \\spad{st.}"))) 
 NIL 
 NIL 
-(-1157 R UP) 
+(-1178 R UP) 
 ((|constructor| (NIL "This package computes the subresultants of two polynomials which is needed for the `Lazard Rioboo' enhancement to Tragers integrations formula For efficiency reasons this has been rewritten to call Lionel Ducos package which is currently the best one.")) (|primitivePart| ((|#2| |#2| |#1|) "\\spad{primitivePart(p, \\spad{q)}} reduces the coefficient of \\spad{p} modulo \\spad{q,} takes the primitive part of the result, and ensures that the leading coefficient of that result is monic.")) (|subresultantVector| (((|PrimitiveArray| |#2|) |#2| |#2|) "\\spad{subresultantVector(p, \\spad{q)}} returns \\spad{[p0,...,pn]} where \\spad{pi} is the \\spad{i}-th subresultant of \\spad{p} and \\spad{q.} In particular, \\spad{p0 = resultant(p, q)}."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-303)))) 
-(-1158 |n| R) 
+((|HasCategory| |#1| (QUOTE (-323)))) 
+(-1179 |n| R) 
 ((|constructor| (NIL "This domain is not documented")) (|pointData| (((|List| (|Point| |#2|)) $) "\\spad{pointData(s)} returns the list of points from the point data field of the 3 dimensional subspace \\spad{s.}")) (|parent| (($ $) "\\spad{parent(s)} returns the subspace which is the parent of the indicated 3 dimensional subspace \\spad{s.} If \\spad{s} is the top level subspace an error message is returned.")) (|level| (((|NonNegativeInteger|) $) "\\spad{level(s)} returns a non negative integer which is the current level field of the indicated 3 dimensional subspace \\spad{s.}")) (|extractProperty| (((|SubSpaceComponentProperty|) $) "\\spad{extractProperty(s)} returns the property of domain \\spadtype{SubSpaceComponentProperty} of the indicated 3 dimensional subspace \\spad{s.}")) (|extractClosed| (((|Boolean|) $) "\\spad{extractClosed(s)} returns the \\spadtype{Boolean} value of the closed property for the indicated 3 dimensional subspace \\spad{s.} If the property is closed, \\spad{True} is returned, otherwise \\spad{False} is returned.")) (|extractIndex| (((|NonNegativeInteger|) $) "\\spad{extractIndex(s)} returns a non negative integer which is the current index of the 3 dimensional subspace \\spad{s.}")) (|extractPoint| (((|Point| |#2|) $) "\\spad{extractPoint(s)} returns the point which is given by the current index location into the point data field of the 3 dimensional subspace \\spad{s.}")) (|traverse| (($ $ (|List| (|NonNegativeInteger|))) "\\spad{traverse(s,li)} follows the branch list of the 3 dimensional subspace, \\spad{s,} along the path dictated by the list of non negative integers, li, which points to the component which has been traversed to. The subspace, \\spad{s,} is returned, where \\spad{s} is now the subspace pointed to by li.")) (|defineProperty| (($ $ (|List| (|NonNegativeInteger|)) (|SubSpaceComponentProperty|)) "\\spad{defineProperty(s,li,p)} defines the component property in the 3 dimensional subspace, \\spad{s,} to be that of \\spad{p,} where \\spad{p} is of the domain \\spadtype{SubSpaceComponentProperty}. The list of non negative integers, li, dictates the path to follow, or, to look at it another way, points to the component whose property is being defined. The subspace, \\spad{s,} is returned with the component property definition.")) (|closeComponent| (($ $ (|List| (|NonNegativeInteger|)) (|Boolean|)) "\\spad{closeComponent(s,li,b)} sets the property of the component in the 3 dimensional subspace, \\spad{s,} to be closed if \\spad{b} is true, or open if \\spad{b} is false. The list of non negative integers, li, dictates the path to follow, or, to look at it another way, points to the component whose closed property is to be set. The subspace, \\spad{s,} is returned with the component property modification.")) (|modifyPoint| (($ $ (|NonNegativeInteger|) (|Point| |#2|)) "\\spad{modifyPoint(s,ind,p)} modifies the point referenced by the index location, ind, by replacing it with the point, \\spad{p} in the 3 dimensional subspace, \\spad{s.} An error message occurs if \\spad{s} is empty, otherwise the subspace \\spad{s} is returned with the point modification.") (($ $ (|List| (|NonNegativeInteger|)) (|NonNegativeInteger|)) "\\spad{modifyPoint(s,li,i)} replaces an existing point in the 3 dimensional subspace, \\spad{s,} with the 4 dimensional point indicated by the index location, i. The list of non negative integers, li, dictates the path to follow, or, to look at it another way, points to the component in which the existing point is to be modified. An error message occurs if \\spad{s} is empty, otherwise the subspace \\spad{s} is returned with the point modification.") (($ $ (|List| (|NonNegativeInteger|)) (|Point| |#2|)) "\\spad{modifyPoint(s,li,p)} replaces an existing point in the 3 dimensional subspace, \\spad{s,} with the 4 dimensional point, \\spad{p.} The list of non negative integers, li, dictates the path to follow, or, to look at it another way, points to the component in which the existing point is to be modified. An error message occurs if \\spad{s} is empty, otherwise the subspace \\spad{s} is returned with the point modification.")) (|addPointLast| (($ $ $ (|Point| |#2|) (|NonNegativeInteger|)) "\\spad{addPointLast(s,s2,li,p)} adds the 4 dimensional point, \\spad{p,} to the 3 dimensional subspace, \\spad{s.} \\spad{s2} point to the end of the subspace \\spad{s.} \\spad{n} is the path in the \\spad{s2} component. The subspace \\spad{s} is returned with the additional point.")) (|addPoint2| (($ $ (|Point| |#2|)) "\\spad{addPoint2(s,p)} adds the 4 dimensional point, \\spad{p,} to the 3 dimensional subspace, \\spad{s.} The subspace \\spad{s} is returned with the additional point.")) (|addPoint| (((|NonNegativeInteger|) $ (|Point| |#2|)) "\\spad{addPoint(s,p)} adds the point, \\spad{p,} to the 3 dimensional subspace, \\spad{s,} and returns the new total number of points in \\spad{s.}") (($ $ (|List| (|NonNegativeInteger|)) (|NonNegativeInteger|)) "\\spad{addPoint(s,li,i)} adds the 4 dimensional point indicated by the index location, i, to the 3 dimensional subspace, \\spad{s.} The list of non negative integers, li, dictates the path to follow, or, to look at it another way, points to the component in which the point is to be added. It's length should range from 0 to \\spad{n - 1} where \\spad{n} is the dimension of the subspace. If the length is \\spad{n - 1}, then a specific lowest level component is being referenced. If it is less than \\spad{n - 1}, then some higher level component \\spad{(0} indicates top level component) is being referenced and a component of that level with the desired point is created. The subspace \\spad{s} is returned with the additional point.") (($ $ (|List| (|NonNegativeInteger|)) (|Point| |#2|)) "\\spad{addPoint(s,li,p)} adds the 4 dimensional point, \\spad{p,} to the 3 dimensional subspace, \\spad{s.} The list of non negative integers, li, dictates the path to follow, or, to look at it another way, points to the component in which the point is to be added. It's length should range from 0 to \\spad{n - 1} where \\spad{n} is the dimension of the subspace. If the length is \\spad{n - 1}, then a specific lowest level component is being referenced. If it is less than \\spad{n - 1}, then some higher level component \\spad{(0} indicates top level component) is being referenced and a component of that level with the desired point is created. The subspace \\spad{s} is returned with the additional point.")) (|separate| (((|List| $) $) "\\spad{separate(s)} makes each of the components of the \\spadtype{SubSpace}, \\spad{s,} into a list of separate and distinct subspaces and returns the list.")) (|merge| (($ (|List| $)) "\\spad{merge(ls)} a list of subspaces, \\spad{ls,} into one subspace.") (($ $ $) "\\spad{merge(s1,s2)} the subspaces \\spad{s1} and \\spad{s2} into a single subspace.")) (|deepCopy| (($ $) "\\spad{deepCopy(x)} is not documented")) (|shallowCopy| (($ $) "\\spad{shallowCopy(x)} is not documented")) (|numberOfChildren| (((|NonNegativeInteger|) $) "\\spad{numberOfChildren(x)} is not documented")) (|children| (((|List| $) $) "\\spad{children(x)} is not documented")) (|child| (($ $ (|NonNegativeInteger|)) "\\spad{child(x,n)} is not documented")) (|birth| (($ $) "\\spad{birth(x)} is not documented")) (|subspace| (($) "\\spad{subspace()} is not documented")) (|new| (($) "\\spad{new()} is not documented")) (|internal?| (((|Boolean|) $) "\\spad{internal?(x)} is not documented")) (|root?| (((|Boolean|) $) "\\spad{root?(x)} is not documented")) (|leaf?| (((|Boolean|) $) "\\spad{leaf?(x)} is not documented"))) 
 NIL 
 NIL 
-(-1159 S1 S2) 
+(-1180 S1 S2) 
 ((|constructor| (NIL "This domain implements \"such that\" forms")) (|rhs| ((|#2| $) "\\spad{rhs(f)} returns the right side of \\spad{f}")) (|lhs| ((|#1| $) "\\spad{lhs(f)} returns the left side of \\spad{f}")) (|construct| (($ |#1| |#2|) "\\spad{construct(s,t)} makes a form \\spad{s:t}"))) 
 NIL 
 NIL 
-(-1160 |Coef| |var| |cen|) 
+(-1181 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Sparse Laurent series in one variable \\spadtype{SparseUnivariateLaurentSeries} is a domain representing Laurent series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring, the power series variable, and the center of the power series expansion. For example, \\spad{SparseUnivariateLaurentSeries(Integer,x,3)} represents Laurent series in \\spad{(x - 3)} with integer coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Laurent series."))) 
-(((-4604 "*") -1841 (-4028 (|has| |#1| (-368)) (|has| (-1168 |#1| |#2| |#3|) (-821))) (|has| |#1| (-174)) (-4028 (|has| |#1| (-368)) (|has| (-1168 |#1| |#2| |#3|) (-910)))) (-4595 -1841 (-4028 (|has| |#1| (-368)) (|has| (-1168 |#1| |#2| |#3|) (-821))) (|has| |#1| (-562)) (-4028 (|has| |#1| (-368)) (|has| (-1168 |#1| |#2| |#3|) (-910)))) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| (-572) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-151)))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|)))))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-227))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|))))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-1028))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-1144))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -283) (LIST (QUOTE -1168) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1168) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -305) (LIST (QUOTE -1168) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -527) (QUOTE (-1170)) (LIST (QUOTE -1168) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-910))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-149))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-149)))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-174)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-368))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -283) (LIST (QUOTE -1168) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1168) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -305) (LIST (QUOTE -1168) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -527) (QUOTE (-1170)) (LIST (QUOTE -1168) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-1028))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-1144))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|)))))) (-1841 (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1168 |#1| |#2| |#3|) (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-1161 R -3313) 
+(((-4627 "*") -3836 (-1732 (|has| |#1| (-388)) (|has| (-1189 |#1| |#2| |#3|) (-842))) (|has| |#1| (-194)) (-1732 (|has| |#1| (-388)) (|has| (-1189 |#1| |#2| |#3|) (-931)))) (-4618 -3836 (-1732 (|has| |#1| (-388)) (|has| (-1189 |#1| |#2| |#3|) (-842))) (|has| |#1| (-582)) (-1732 (|has| |#1| (-388)) (|has| (-1189 |#1| |#2| |#3|) (-931)))) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| (-592) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-171)))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|)))))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-247))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|))))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-1049))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-1165))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1189) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1189) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -325) (LIST (QUOTE -1189) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -547) (QUOTE (-1191)) (LIST (QUOTE -1189) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-931))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-169))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-169)))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-194)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-388))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1189) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1189) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -325) (LIST (QUOTE -1189) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -547) (QUOTE (-1191)) (LIST (QUOTE -1189) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-1049))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-1165))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|)))))) (-3836 (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1189 |#1| |#2| |#3|) (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-1182 R -3958) 
 ((|constructor| (NIL "Computes sums of top-level expressions")) (|sum| ((|#2| |#2| (|SegmentBinding| |#2|)) "\\spad{sum(f(n), \\spad{n} = a..b)} returns f(a) + f(a+1) + \\spad{...} + f(b).") ((|#2| |#2| (|Symbol|)) "\\spad{sum(a(n), \\spad{n)}} returns A(n) such that A(n+1) - A(n) = a(n)."))) 
 NIL 
 NIL 
-(-1162 R) 
+(-1183 R) 
 ((|constructor| (NIL "Computes sums of rational functions.")) (|sum| (((|Union| (|Fraction| (|Polynomial| |#1|)) (|Expression| |#1|)) (|Fraction| (|Polynomial| |#1|)) (|SegmentBinding| (|Fraction| (|Polynomial| |#1|)))) "\\indented{1}{sum(f(n), \\spad{n} = a..b) returns \\spad{f(a) + f(a+1) + \\spad{...} f(b)}.} \\blankline \\spad{X} sum(i::Fraction(Polynomial(Integer)),i=1..n)") (((|Fraction| (|Polynomial| |#1|)) (|Polynomial| |#1|) (|SegmentBinding| (|Polynomial| |#1|))) "\\indented{1}{sum(f(n), \\spad{n} = a..b) returns \\spad{f(a) + f(a+1) + \\spad{...} f(b)}.} \\blankline \\spad{X} sum(i,i=1..n)") (((|Union| (|Fraction| (|Polynomial| |#1|)) (|Expression| |#1|)) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\indented{1}{sum(a(n), \\spad{n)} returns \\spad{A} which} \\indented{1}{is the indefinite sum of \\spad{a} with respect to} \\indented{1}{upward difference on \\spad{n}, \\spadignore{i.e.} \\spad{A(n+1) - A(n) = a(n)}.} \\blankline \\spad{X} sum(i::Fraction(Polynomial(Integer)),i::Symbol)") (((|Fraction| (|Polynomial| |#1|)) (|Polynomial| |#1|) (|Symbol|)) "\\indented{1}{sum(a(n), \\spad{n)} returns \\spad{A} which} \\indented{1}{is the indefinite sum of \\spad{a} with respect to} \\indented{1}{upward difference on \\spad{n}, \\spadignore{i.e.} \\spad{A(n+1) - A(n) = a(n)}.} \\blankline \\spad{X} sum(i::Polynomial(Integer),variable(i=1..n))"))) 
 NIL 
 NIL 
-(-1163 R S) 
+(-1184 R S) 
 ((|constructor| (NIL "This package lifts a mapping from coefficient rings \\spad{R} to \\spad{S} to a mapping from sparse univariate polynomial over \\spad{R} to a sparse univariate polynomial over \\spad{S.} Note that the mapping is assumed to send zero to zero, since it will only be applied to the non-zero coefficients of the polynomial.")) (|map| (((|SparseUnivariatePolynomial| |#2|) (|Mapping| |#2| |#1|) (|SparseUnivariatePolynomial| |#1|)) "\\spad{map(func, poly)} creates a new polynomial by applying \\spad{func} to every non-zero coefficient of the polynomial poly."))) 
 NIL 
 NIL 
-(-1164 R) 
+(-1185 R) 
 ((|constructor| (NIL "This domain has no description"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4598 |has| |#1| (-368)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-1144))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-1190))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasCategory| |#1| (QUOTE (-227))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-1165 E OV R P) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4621 |has| |#1| (-388)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-1165))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-1211))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasCategory| |#1| (QUOTE (-247))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-1186 E OV R P) 
 ((|constructor| (NIL "SupFractionFactorize contains the factor function for univariate polynomials over the quotient field of a ring \\spad{S} such that the package MultivariateFactorize works for \\spad{S}")) (|squareFree| (((|Factored| (|SparseUnivariatePolynomial| (|Fraction| |#4|))) (|SparseUnivariatePolynomial| (|Fraction| |#4|))) "\\spad{squareFree(p)} returns the square-free factorization of the univariate polynomial \\spad{p} with coefficients which are fractions of polynomials over \\spad{R.} Each factor has no repeated roots and the factors are pairwise relatively prime.")) (|factor| (((|Factored| (|SparseUnivariatePolynomial| (|Fraction| |#4|))) (|SparseUnivariatePolynomial| (|Fraction| |#4|))) "\\spad{factor(p)} factors the univariate polynomial \\spad{p} with coefficients which are fractions of polynomials over \\spad{R.}"))) 
 NIL 
 NIL 
-(-1166 R) 
+(-1187 R) 
 ((|constructor| (NIL "This domain represents univariate polynomials over arbitrary (not necessarily commutative) coefficient rings. The variable is unspecified so that the variable displays as \\spad{?} on output. If it is necessary to specify the variable name, use type \\spadtype{UnivariatePolynomial}. The representation is sparse in the sense that only non-zero terms are represented. Note that if the coefficient ring is a field, this domain forms a euclidean domain.")) (|fmecg| (($ $ (|NonNegativeInteger|) |#1| $) "\\spad{fmecg(p1,e,r,p2)} finds \\spad{x} : \\spad{p1} - \\spad{r} * x**e * \\spad{p2}")) (|outputForm| (((|OutputForm|) $ (|OutputForm|)) "\\spad{outputForm(p,var)} converts the SparseUnivariatePolynomial \\spad{p} to an output form (see \\spadtype{OutputForm}) printed as a polynomial in the output form variable."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4598 |has| |#1| (-368)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-1144))) (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasCategory| |#1| (QUOTE (-227))) (|HasAttribute| |#1| (QUOTE -4600)) (|HasCategory| |#1| (QUOTE (-457))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (|HasCategory| |#1| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-1167 |Coef| |var| |cen|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4621 |has| |#1| (-388)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-1165))) (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasCategory| |#1| (QUOTE (-247))) (|HasAttribute| |#1| (QUOTE -4623)) (|HasCategory| |#1| (QUOTE (-477))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (|HasCategory| |#1| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-1188 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Sparse Puiseux series in one variable \\spadtype{SparseUnivariatePuiseuxSeries} is a domain representing Puiseux series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring, the power series variable, and the center of the power series expansion. For example, \\spad{SparseUnivariatePuiseuxSeries(Integer,x,3)} represents Puiseux series in \\spad{(x - 3)} with \\spadtype{Integer} coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Puiseux series."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|))))) (|HasCategory| (-413 (-572)) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-1168 |Coef| |var| |cen|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|))))) (|HasCategory| (-433 (-592)) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-1189 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Sparse Taylor series in one variable \\spadtype{SparseUnivariateTaylorSeries} is a domain representing Taylor series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring, the power series variable, and the center of the power series expansion. For example, \\spadtype{SparseUnivariateTaylorSeries}(Integer,x,3) represents Taylor series in \\spad{(x - 3)} with \\spadtype{Integer} coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x),x)} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),x)} computes the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|univariatePolynomial| (((|UnivariatePolynomial| |#2| |#1|) $ (|NonNegativeInteger|)) "\\spad{univariatePolynomial(f,k)} returns a univariate polynomial \\indented{1}{consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.}")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a \\indented{1}{Taylor series.}") (($ (|UnivariatePolynomial| |#2| |#1|)) "\\spad{coerce(p)} converts a univariate polynomial \\spad{p} in the variable \\spad{var} to a univariate Taylor series in \\spad{var}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-769)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-769)) (|devaluate| |#1|))))) (|HasCategory| (-769) (QUOTE (-1110))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-769))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-769))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-1169) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-790)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-790)) (|devaluate| |#1|))))) (|HasCategory| (-790) (QUOTE (-1131))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-790))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-790))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-1190) 
 ((|constructor| (NIL "This domain builds representations of boolean expressions for use with the \\axiomType{FortranCode} domain.")) (NOT (($ $) "\\spad{NOT(x)} returns the \\axiomType{Switch} expression representing \\spad{\\~~x}.") (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{NOT(x)} returns the \\axiomType{Switch} expression representing \\spad{\\~~x}.")) (AND (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{AND(x,y)} returns the \\axiomType{Switch} expression representing \\spad{x and \\spad{y}.}")) (EQ (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{EQ(x,y)} returns the \\axiomType{Switch} expression representing \\spad{x = \\spad{y}.}")) (OR (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{OR(x,y)} returns the \\axiomType{Switch} expression representing \\spad{x or \\spad{y}.}")) (GE (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{GE(x,y)} returns the \\axiomType{Switch} expression representing \\spad{x>=y}.")) (LE (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{LE(x,y)} returns the \\axiomType{Switch} expression representing \\spad{x<=y}.")) (GT (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{GT(x,y)} returns the \\axiomType{Switch} expression representing \\spad{x>y}.")) (LT (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{LT(x,y)} returns the \\axiomType{Switch} expression representing \\spad{x<y}.")) (|coerce| (($ (|Symbol|)) "\\spad{coerce(s)} is not documented"))) 
 NIL 
 NIL 
-(-1170) 
+(-1191) 
 ((|constructor| (NIL "Basic and scripted symbols.")) (|sample| (($) "\\spad{sample()} returns a sample of \\%")) (|list| (((|List| $) $) "\\spad{list(sy)} takes a scripted symbol and produces a list of the name followed by the scripts.")) (|string| (((|String|) $) "\\spad{string(s)} converts the symbol \\spad{s} to a string. Error: if the symbol is subscripted.")) (|elt| (($ $ (|List| (|OutputForm|))) "\\spad{elt(s,[a1,...,an])} or s([a1,...,an]) returns \\spad{s} subscripted by \\spad{[a1,...,an]}.")) (|argscript| (($ $ (|List| (|OutputForm|))) "\\spad{argscript(s, [a1,...,an])} returns \\spad{s} arg-scripted by \\spad{[a1,...,an]}.")) (|superscript| (($ $ (|List| (|OutputForm|))) "\\spad{superscript(s, [a1,...,an])} returns \\spad{s} superscripted by \\spad{[a1,...,an]}.")) (|subscript| (($ $ (|List| (|OutputForm|))) "\\spad{subscript(s, [a1,...,an])} returns \\spad{s} subscripted by \\spad{[a1,...,an]}.")) (|script| (($ $ (|Record| (|:| |sub| (|List| (|OutputForm|))) (|:| |sup| (|List| (|OutputForm|))) (|:| |presup| (|List| (|OutputForm|))) (|:| |presub| (|List| (|OutputForm|))) (|:| |args| (|List| (|OutputForm|))))) "\\spad{script(s, [a,b,c,d,e])} returns \\spad{s} with subscripts a, superscripts \\spad{b,} pre-superscripts \\spad{c,} pre-subscripts \\spad{d,} and argument-scripts e.") (($ $ (|List| (|List| (|OutputForm|)))) "\\spad{script(s, [a,b,c,d,e])} returns \\spad{s} with subscripts a, superscripts \\spad{b,} pre-superscripts \\spad{c,} pre-subscripts \\spad{d,} and argument-scripts e. Omitted components are taken to be empty. For example, \\spad{script(s, [a,b,c])} is equivalent to \\spad{script(s,[a,b,c,[],[]])}.")) (|scripts| (((|Record| (|:| |sub| (|List| (|OutputForm|))) (|:| |sup| (|List| (|OutputForm|))) (|:| |presup| (|List| (|OutputForm|))) (|:| |presub| (|List| (|OutputForm|))) (|:| |args| (|List| (|OutputForm|)))) $) "\\spad{scripts(s)} returns all the scripts of \\spad{s.}")) (|scripted?| (((|Boolean|) $) "\\spad{scripted?(s)} is \\spad{true} if \\spad{s} has been given any scripts.")) (|name| (($ $) "\\spad{name(s)} returns \\spad{s} without its scripts.")) (|coerce| (($ (|String|)) "\\spad{coerce(s)} converts the string \\spad{s} to a symbol.")) (|resetNew| (((|Void|)) "\\spad{resetNew()} resets the internals counters that new() and new(s) use to return distinct symbols every time.")) (|new| (($ $) "\\spad{new(s)} returns a new symbol whose name starts with \\spad{%s.}") (($) "\\spad{new()} returns a new symbol whose name starts with \\spad{%.}"))) 
 NIL 
 NIL 
-(-1171 R) 
+(-1192 R) 
 ((|constructor| (NIL "Computes all the symmetric functions in \\spad{n} variables.")) (|symFunc| (((|Vector| |#1|) |#1| (|PositiveInteger|)) "\\spad{symFunc(r, \\spad{n)}} returns the vector of the elementary symmetric functions in \\spad{[r,r,...,r]} \\spad{n} times.") (((|Vector| |#1|) (|List| |#1|)) "\\spad{symFunc([r1,...,rn])} returns the vector of the elementary symmetric functions in the \\spad{ri's}: \\spad{[r1 + \\spad{...} + \\spad{rn,} \\spad{r1} \\spad{r2} + \\spad{...} + r(n-1) \\spad{rn,} ..., \\spad{r1} \\spad{r2} \\spad{...} rn]}."))) 
 NIL 
 NIL 
-(-1172 R) 
+(-1193 R) 
 ((|constructor| (NIL "This domain implements symmetric polynomial"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-6 -4600)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-457))) (-12 (|HasCategory| (-979) (QUOTE (-138))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasAttribute| |#1| (QUOTE -4600))) 
-(-1173) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-6 -4623)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-477))) (-12 (|HasCategory| (-1000) (QUOTE (-158))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasAttribute| |#1| (QUOTE -4623))) 
+(-1194) 
 ((|constructor| (NIL "Creates and manipulates one global symbol table for FORTRAN code generation, containing details of types, dimensions, and argument lists.")) (|symbolTableOf| (((|SymbolTable|) (|Symbol|) $) "\\spad{symbolTableOf(f,tab)} returns the symbol table of \\spad{f}")) (|argumentListOf| (((|List| (|Symbol|)) (|Symbol|) $) "\\spad{argumentListOf(f,tab)} returns the argument list of \\spad{f}")) (|returnTypeOf| (((|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void")) (|Symbol|) $) "\\spad{returnTypeOf(f,tab)} returns the type of the object returned by \\spad{f}")) (|empty| (($) "\\spad{empty()} creates a new, empty symbol table.")) (|printTypes| (((|Void|) (|Symbol|)) "\\spad{printTypes(tab)} produces FORTRAN type declarations from tab, on the current FORTRAN output stream")) (|printHeader| (((|Void|)) "\\spad{printHeader()} produces the FORTRAN header for the current subprogram in the global symbol table on the current FORTRAN output stream.") (((|Void|) (|Symbol|)) "\\spad{printHeader(f)} produces the FORTRAN header for subprogram \\spad{f} in the global symbol table on the current FORTRAN output stream.") (((|Void|) (|Symbol|) $) "\\spad{printHeader(f,tab)} produces the FORTRAN header for subprogram \\spad{f} in symbol table \\spad{tab} on the current FORTRAN output stream.")) (|returnType!| (((|Void|) (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) "\\spad{returnType!(t)} declares that the return type of he current subprogram in the global symbol table is \\spad{t.}") (((|Void|) (|Symbol|) (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) "\\spad{returnType!(f,t)} declares that the return type of subprogram \\spad{f} in the global symbol table is \\spad{t.}") (((|Void|) (|Symbol|) (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void")) $) "\\spad{returnType!(f,t,tab)} declares that the return type of subprogram \\spad{f} in symbol table \\spad{tab} is \\spad{t.}")) (|argumentList!| (((|Void|) (|List| (|Symbol|))) "\\spad{argumentList!(l)} declares that the argument list for the current subprogram in the global symbol table is \\spad{l.}") (((|Void|) (|Symbol|) (|List| (|Symbol|))) "\\spad{argumentList!(f,l)} declares that the argument list for subprogram \\spad{f} in the global symbol table is \\spad{l.}") (((|Void|) (|Symbol|) (|List| (|Symbol|)) $) "\\spad{argumentList!(f,l,tab)} declares that the argument list for subprogram \\spad{f} in symbol table \\spad{tab} is \\spad{l.}")) (|endSubProgram| (((|Symbol|)) "\\spad{endSubProgram()} asserts that we are no longer processing the current subprogram.")) (|currentSubProgram| (((|Symbol|)) "\\spad{currentSubProgram()} returns the name of the current subprogram being processed")) (|newSubProgram| (((|Void|) (|Symbol|)) "\\spad{newSubProgram(f)} asserts that from now on type declarations are part of subprogram \\spad{f.}")) (|declare!| (((|FortranType|) (|Symbol|) (|FortranType|) (|Symbol|)) "\\spad{declare!(u,t,asp)} declares the parameter \\spad{u} to have type \\spad{t} in asp.") (((|FortranType|) (|Symbol|) (|FortranType|)) "\\spad{declare!(u,t)} declares the parameter \\spad{u} to have type \\spad{t} in the current level of the symbol table.") (((|FortranType|) (|List| (|Symbol|)) (|FortranType|) (|Symbol|) $) "\\spad{declare!(u,t,asp,tab)} declares the parameters \\spad{u} of subprogram \\spad{asp} to have type \\spad{t} in symbol table tab.") (((|FortranType|) (|Symbol|) (|FortranType|) (|Symbol|) $) "\\spad{declare!(u,t,asp,tab)} declares the parameter \\spad{u} of subprogram \\spad{asp} to have type \\spad{t} in symbol table tab.")) (|clearTheSymbolTable| (((|Void|) (|Symbol|)) "\\spad{clearTheSymbolTable(x)} removes the symbol \\spad{x} from the table") (((|Void|)) "\\spad{clearTheSymbolTable()} clears the current symbol table.")) (|showTheSymbolTable| (($) "\\spad{showTheSymbolTable()} returns the current symbol table."))) 
 NIL 
 NIL 
-(-1174) 
+(-1195) 
 ((|constructor| (NIL "Create and manipulate a symbol table for generated FORTRAN code")) (|symbolTable| (($ (|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| (|FortranType|))))) "\\spad{symbolTable(l)} creates a symbol table from the elements of \\spad{l.}")) (|printTypes| (((|Void|) $) "\\spad{printTypes(tab)} produces FORTRAN type declarations from tab, on the current FORTRAN output stream")) (|newTypeLists| (((|SExpression|) $) "\\spad{newTypeLists(x)} is not documented")) (|typeLists| (((|List| (|List| (|Union| (|:| |name| (|Symbol|)) (|:| |bounds| (|List| (|Union| (|:| S (|Symbol|)) (|:| P (|Polynomial| (|Integer|))))))))) $) "\\spad{typeLists(tab)} returns a list of lists of types of objects in \\spad{tab}")) (|externalList| (((|List| (|Symbol|)) $) "\\spad{externalList(tab)} returns a list of all the external symbols in \\spad{tab}")) (|typeList| (((|List| (|Union| (|:| |name| (|Symbol|)) (|:| |bounds| (|List| (|Union| (|:| S (|Symbol|)) (|:| P (|Polynomial| (|Integer|)))))))) (|FortranScalarType|) $) "\\spad{typeList(t,tab)} returns a list of all the objects of type \\spad{t} in \\spad{tab}")) (|parametersOf| (((|List| (|Symbol|)) $) "\\spad{parametersOf(tab)} returns a list of all the symbols declared in \\spad{tab}")) (|fortranTypeOf| (((|FortranType|) (|Symbol|) $) "\\spad{fortranTypeOf(u,tab)} returns the type of \\spad{u} in \\spad{tab}")) (|declare!| (((|FortranType|) (|Symbol|) (|FortranType|) $) "\\spad{declare!(u,t,tab)} creates a new entry in tab, declaring \\spad{u} to be of type \\spad{t}") (((|FortranType|) (|List| (|Symbol|)) (|FortranType|) $) "\\spad{declare!(l,t,tab)} creates new entrys in tab, declaring each of \\spad{l} to be of type \\spad{t}")) (|empty| (($) "\\spad{empty()} returns a new, empty symbol table")) (|coerce| (((|Table| (|Symbol|) (|FortranType|)) $) "\\spad{coerce(x)} returns a table view of \\spad{x}"))) 
 NIL 
 NIL 
-(-1175 R) 
+(-1196 R) 
 ((|constructor| (NIL "Symbolic solver for systems of rational functions with coefficients in an integral domain \\spad{R.} The systems are solved in the field of rational functions over \\spad{R.} Solutions are exact of the form variable = value when the value is a member of the coefficient domain \\spad{R.} Otherwise the solutions are implicitly expressed as roots of univariate polynomial equations over \\spad{R.} Care is taken to guarantee that the denominators of the input equations do not vanish on the solution sets. The arguments to solve can either be given as equations or as rational functions interpreted as equal to zero. The user can specify an explicit list of symbols to be solved for, treating all other symbols appearing as parameters or omit the list of symbols in which case the system tries to solve with respect to all symbols appearing in the input.")) (|triangularSystems| (((|List| (|List| (|Polynomial| |#1|))) (|List| (|Fraction| (|Polynomial| |#1|))) (|List| (|Symbol|))) "\\spad{triangularSystems(lf,lv)} solves the system of equations defined by \\spad{lf} with respect to the list of symbols \\spad{lv;} the system of equations is obtaining by equating to zero the list of rational functions \\spad{lf.} The output is a list of solutions where each solution is expressed as a \"reduced\" triangular system of polynomials.")) (|solve| (((|List| (|Equation| (|Fraction| (|Polynomial| |#1|)))) (|Equation| (|Fraction| (|Polynomial| |#1|)))) "\\spad{solve(eq)} finds the solutions of the equation \\spad{eq} with respect to the unique variable appearing in eq.") (((|List| (|Equation| (|Fraction| (|Polynomial| |#1|)))) (|Fraction| (|Polynomial| |#1|))) "\\spad{solve(p)} finds the solution of a rational function \\spad{p} = 0 with respect to the unique variable appearing in \\spad{p.}") (((|List| (|Equation| (|Fraction| (|Polynomial| |#1|)))) (|Equation| (|Fraction| (|Polynomial| |#1|))) (|Symbol|)) "\\spad{solve(eq,v)} finds the solutions of the equation \\spad{eq} with respect to the variable \\spad{v.}") (((|List| (|Equation| (|Fraction| (|Polynomial| |#1|)))) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{solve(p,v)} solves the equation p=0, where \\spad{p} is a rational function with respect to the variable \\spad{v.}") (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) "\\spad{solve(le)} finds the solutions of the list \\spad{le} of equations of rational functions with respect to all symbols appearing in le.") (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) (|List| (|Fraction| (|Polynomial| |#1|)))) "\\spad{solve(lp)} finds the solutions of the list \\spad{lp} of rational functions with respect to all symbols appearing in \\spad{lp.}") (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) (|List| (|Equation| (|Fraction| (|Polynomial| |#1|)))) (|List| (|Symbol|))) "\\spad{solve(le,lv)} finds the solutions of the list \\spad{le} of equations of rational functions with respect to the list of symbols \\spad{lv.}") (((|List| (|List| (|Equation| (|Fraction| (|Polynomial| |#1|))))) (|List| (|Fraction| (|Polynomial| |#1|))) (|List| (|Symbol|))) "\\spad{solve(lp,lv)} finds the solutions of the list \\spad{lp} of rational functions with respect to the list of symbols \\spad{lv.}"))) 
 NIL 
 NIL 
-(-1176 S) 
+(-1197 S) 
 ((|constructor| (NIL "TableauBumpers implements the Schenstead-Knuth correspondence between sequences and pairs of Young tableaux. The 2 Young tableaux are represented as a single tableau with pairs as components.")) (|mr| (((|Record| (|:| |f1| (|List| |#1|)) (|:| |f2| (|List| (|List| (|List| |#1|)))) (|:| |f3| (|List| (|List| |#1|))) (|:| |f4| (|List| (|List| (|List| |#1|))))) (|List| (|List| (|List| |#1|)))) "\\spad{mr(t)} is an auxiliary function which finds the position of the maximum element of a tableau \\spad{t} which is in the lowest row, producing a record of results")) (|maxrow| (((|Record| (|:| |f1| (|List| |#1|)) (|:| |f2| (|List| (|List| (|List| |#1|)))) (|:| |f3| (|List| (|List| |#1|))) (|:| |f4| (|List| (|List| (|List| |#1|))))) (|List| |#1|) (|List| (|List| (|List| |#1|))) (|List| (|List| |#1|)) (|List| (|List| (|List| |#1|))) (|List| (|List| (|List| |#1|))) (|List| (|List| (|List| |#1|)))) "\\spad{maxrow(a,b,c,d,e)} is an auxiliary function for \\spad{mr}")) (|inverse| (((|List| |#1|) (|List| |#1|)) "\\spad{inverse(ls)} forms the inverse of a sequence \\spad{ls}")) (|slex| (((|List| (|List| |#1|)) (|List| |#1|)) "\\spad{slex(ls)} sorts the argument sequence \\spad{ls,} then zips (see map) the original argument sequence with the sorted result to a list of pairs")) (|lex| (((|List| (|List| |#1|)) (|List| (|List| |#1|))) "\\spad{lex(ls)} sorts a list of pairs to lexicographic order")) (|tab| (((|Tableau| (|List| |#1|)) (|List| |#1|)) "\\spad{tab(ls)} creates a tableau from \\spad{ls} by first creating a list of pairs using slex, then creating a tableau using tab1.")) (|tab1| (((|List| (|List| (|List| |#1|))) (|List| (|List| |#1|))) "\\spad{tab1(lp)} creates a tableau from a list of pairs \\spad{lp}")) (|bat| (((|List| (|List| |#1|)) (|Tableau| (|List| |#1|))) "\\spad{bat(ls)} unbumps a tableau \\spad{ls}")) (|bat1| (((|List| (|List| |#1|)) (|List| (|List| (|List| |#1|)))) "\\spad{bat1(llp)} unbumps a tableau llp. Operation \\spad{bat1} is the inverse of tab1.")) (|untab| (((|List| (|List| |#1|)) (|List| (|List| |#1|)) (|List| (|List| (|List| |#1|)))) "\\spad{untab(lp,llp)} is an auxiliary function which unbumps a tableau llp, using \\spad{lp} to accumulate pairs")) (|bumptab1| (((|List| (|List| (|List| |#1|))) (|List| |#1|) (|List| (|List| (|List| |#1|)))) "\\spad{bumptab1(pr,t)} bumps a tableau \\spad{t} with a pair \\spad{pr} using comparison function \\spadfun{<}, returning a new tableau")) (|bumptab| (((|List| (|List| (|List| |#1|))) (|Mapping| (|Boolean|) |#1| |#1|) (|List| |#1|) (|List| (|List| (|List| |#1|)))) "\\spad{bumptab(cf,pr,t)} bumps a tableau \\spad{t} with a pair \\spad{pr} using comparison function \\spad{cf,} returning a new tableau")) (|bumprow| (((|Record| (|:| |fs| (|Boolean|)) (|:| |sd| (|List| |#1|)) (|:| |td| (|List| (|List| |#1|)))) (|Mapping| (|Boolean|) |#1| |#1|) (|List| |#1|) (|List| (|List| |#1|))) "\\spad{bumprow(cf,pr,r)} is an auxiliary function which bumps a row \\spad{r} with a pair \\spad{pr} using comparison function \\spad{cf,} and returns a record"))) 
 NIL 
 NIL 
-(-1177 S) 
+(-1198 S) 
 ((|constructor| (NIL "The tableau domain is for printing Young tableaux, and coercions to and from List List \\spad{S} where \\spad{S} is a set.")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(t)} converts a tableau \\spad{t} to an output form.")) (|listOfLists| (((|List| (|List| |#1|)) $) "\\spad{listOfLists \\spad{t}} converts a tableau \\spad{t} to a list of lists.")) (|tableau| (($ (|List| (|List| |#1|))) "\\spad{tableau(ll)} converts a list of lists \\spad{ll} to a tableau."))) 
 NIL 
 NIL 
-(-1178 |Key| |Entry|) 
+(-1199 |Key| |Entry|) 
 ((|constructor| (NIL "This is the general purpose table type. The keys are hashed to look up the entries. This creates a \\spadtype{HashTable} if equal for the Key domain is consistent with Lisp EQUAL otherwise an \\spadtype{AssociationList}"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (-12 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (LIST (QUOTE -305) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -4111) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4320) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#2| (QUOTE (-1098))) (-1841 (|HasCategory| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (QUOTE (-1098))) (|HasCategory| |#2| (QUOTE (-1098)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1098))))) 
-(-1179 R) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (-12 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (LIST (QUOTE -325) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -1350) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -3552) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#2| (QUOTE (-1119))) (-3836 (|HasCategory| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (QUOTE (-1119))) (|HasCategory| |#2| (QUOTE (-1119)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1119))))) 
+(-1200 R) 
 ((|constructor| (NIL "Expands tangents of sums and scalar products.")) (|tanNa| ((|#1| |#1| (|Integer|)) "\\spad{tanNa(a, \\spad{n)}} returns \\spad{f(a)} such that if \\spad{a = tan(u)} then \\spad{f(a) = tan(n * u)}.")) (|tanAn| (((|SparseUnivariatePolynomial| |#1|) |#1| (|PositiveInteger|)) "\\spad{tanAn(a, \\spad{n)}} returns \\spad{P(x)} such that if \\spad{a = tan(u)} then \\spad{P(tan(u/n)) = 0}.")) (|tanSum| ((|#1| (|List| |#1|)) "\\spad{tanSum([a1,...,an])} returns \\spad{f(a1,...,an)} such that if \\spad{ai = tan(ui)} then \\spad{f(a1,...,an) = \\spad{tan(u1} + \\spad{...} + un)}."))) 
 NIL 
 NIL 
-(-1180 S |Key| |Entry|) 
+(-1201 S |Key| |Entry|) 
 ((|constructor| (NIL "A table aggregate is a model of a table, that is, a discrete many-to-one mapping from keys to entries.")) (|map| (($ (|Mapping| |#3| |#3| |#3|) $ $) "\\spad{map(fn,t1,t2)} creates a new table \\spad{t} from given tables \\spad{t1} and \\spad{t2} with elements fn(x,y) where \\spad{x} and \\spad{y} are corresponding elements from \\spad{t1} and \\spad{t2} respectively.")) (|table| (($ (|List| (|Record| (|:| |key| |#2|) (|:| |entry| |#3|)))) "\\spad{table([x,y,...,z])} creates a table consisting of entries \\axiom{x,y,...,z}.") (($) "\\spad{table()}$T creates an empty table of type \\spad{T.} \\blankline \\spad{E} Data:=Record(age:Integer,gender:String) \\spad{E} a1:AssociationList(String,Data):=table() \\spad{E} a1.\"tim\":=[55,\"male\"]$Data")) (|setelt| ((|#3| $ |#2| |#3|) "\\spad{setelt(t,k,e)} (also written \\axiom{t.k \\spad{:=} e}) is equivalent to \\axiom{(insert([k,e],t); e)}."))) 
 NIL 
 NIL 
-(-1181 |Key| |Entry|) 
+(-1202 |Key| |Entry|) 
 ((|constructor| (NIL "A table aggregate is a model of a table, that is, a discrete many-to-one mapping from keys to entries.")) (|map| (($ (|Mapping| |#2| |#2| |#2|) $ $) "\\spad{map(fn,t1,t2)} creates a new table \\spad{t} from given tables \\spad{t1} and \\spad{t2} with elements fn(x,y) where \\spad{x} and \\spad{y} are corresponding elements from \\spad{t1} and \\spad{t2} respectively.")) (|table| (($ (|List| (|Record| (|:| |key| |#1|) (|:| |entry| |#2|)))) "\\spad{table([x,y,...,z])} creates a table consisting of entries \\axiom{x,y,...,z}.") (($) "\\spad{table()}$T creates an empty table of type \\spad{T.} \\blankline \\spad{E} Data:=Record(age:Integer,gender:String) \\spad{E} a1:AssociationList(String,Data):=table() \\spad{E} a1.\"tim\":=[55,\"male\"]$Data")) (|setelt| ((|#2| $ |#1| |#2|) "\\spad{setelt(t,k,e)} (also written \\axiom{t.k \\spad{:=} e}) is equivalent to \\axiom{(insert([k,e],t); e)}."))) 
-((-4603 . T) (-3389 . T)) 
+((-4626 . T) (-2623 . T)) 
 NIL 
-(-1182 |Key| |Entry|) 
+(-1203 |Key| |Entry|) 
 ((|constructor| (NIL "\\axiom{TabulatedComputationPackage(Key ,Entry)} provides some modest support for dealing with operations with type \\axiom{Key \\spad{->} Entry}. The result of such operations can be stored and retrieved with this package by using a hash-table. The user does not need to worry about the management of this hash-table. However, onnly one hash-table is built by calling \\axiom{TabulatedComputationPackage(Key ,Entry)}.")) (|insert!| (((|Void|) |#1| |#2|) "\\axiom{insert!(x,y)} stores the item whose key is \\axiom{x} and whose entry is \\axiom{y}.")) (|extractIfCan| (((|Union| |#2| "failed") |#1|) "\\axiom{extractIfCan(x)} searches the item whose key is \\axiom{x}.")) (|makingStats?| (((|Boolean|)) "\\axiom{makingStats?()} returns \\spad{true} iff the statisitics process is running.")) (|printingInfo?| (((|Boolean|)) "\\axiom{printingInfo?()} returns \\spad{true} iff messages are printed when manipulating items from the hash-table.")) (|usingTable?| (((|Boolean|)) "\\axiom{usingTable?()} returns \\spad{true} iff the hash-table is used")) (|clearTable!| (((|Void|)) "\\axiom{clearTable!()} clears the hash-table and assumes that it will no longer be used.")) (|printStats!| (((|Void|)) "\\axiom{printStats!()} prints the statistics.")) (|startStats!| (((|Void|) (|String|)) "\\axiom{startStats!(x)} initializes the statisitics process and sets the comments to display when statistics are printed")) (|printInfo!| (((|Void|) (|String|) (|String|)) "\\axiom{printInfo!(x,y)} initializes the mesages to be printed when manipulating items from the hash-table. If a key is retrieved then \\axiom{x} is displayed. If an item is stored then \\axiom{y} is displayed.")) (|initTable!| (((|Void|)) "\\axiom{initTable!()} initializes the hash-table."))) 
 NIL 
 NIL 
-(-1183) 
+(-1204) 
 ((|constructor| (NIL "This package provides functions for template manipulation")) (|stripCommentsAndBlanks| (((|String|) (|String|)) "\\spad{stripCommentsAndBlanks(s)} treats \\spad{s} as a piece of AXIOM input, and removes comments, and leading and trailing blanks.")) (|interpretString| (((|Any|) (|String|)) "\\spad{interpretString(s)} treats a string as a piece of AXIOM input, by parsing and interpreting it."))) 
 NIL 
 NIL 
-(-1184 S) 
+(-1205 S) 
 ((|constructor| (NIL "\\spadtype{TexFormat1} provides a utility coercion for changing to TeX format anything that has a coercion to the standard output format.")) (|coerce| (((|TexFormat|) |#1|) "\\spad{coerce(s)} provides a direct coercion from a domain \\spad{S} to TeX format. This allows the user to skip the step of first manually coercing the object to standard output format before it is coerced to TeX format."))) 
 NIL 
 NIL 
-(-1185) 
+(-1206) 
 ((|constructor| (NIL "\\spadtype{TexFormat} provides a coercion from \\spadtype{OutputForm} to \\TeX{} format. The particular dialect of \\TeX{} used is \\LaTeX{}. The basic object consists of three parts: a prologue, a tex part and an epilogue. The functions \\spadfun{prologue}, \\spadfun{tex} and \\spadfun{epilogue} extract these parts, respectively. The main guts of the expression go into the tex part. The other parts can be set (\\spadfun{setPrologue!}, \\spadfun{setEpilogue!}) so that contain the appropriate tags for printing. For example, the prologue and epilogue might simply contain ``\\verb+\\[+'' and ``\\verb+\\]+'', respectively, so that the TeX section will be printed in LaTeX display math mode.")) (|setPrologue!| (((|List| (|String|)) $ (|List| (|String|))) "\\spad{setPrologue!(t,strings)} sets the prologue section of a TeX form \\spad{t} to strings.")) (|setTex!| (((|List| (|String|)) $ (|List| (|String|))) "\\spad{setTex!(t,strings)} sets the TeX section of a TeX form \\spad{t} to strings.")) (|setEpilogue!| (((|List| (|String|)) $ (|List| (|String|))) "\\spad{setEpilogue!(t,strings)} sets the epilogue section of a TeX form \\spad{t} to strings.")) (|prologue| (((|List| (|String|)) $) "\\spad{prologue(t)} extracts the prologue section of a TeX form \\spad{t.}")) (|new| (($) "\\spad{new()} create a new, empty object. Use \\spadfun{setPrologue!}, \\spadfun{setTex!} and \\spadfun{setEpilogue!} to set the various components of this object.")) (|tex| (((|List| (|String|)) $) "\\spad{tex(t)} extracts the TeX section of a TeX form \\spad{t.}")) (|epilogue| (((|List| (|String|)) $) "\\spad{epilogue(t)} extracts the epilogue section of a TeX form \\spad{t.}")) (|display| (((|Void|) $) "\\spad{display(t)} outputs the TeX formatted code \\spad{t} so that each line has length less than or equal to the value set by the system command \\spadsyscom{set output length}.") (((|Void|) $ (|Integer|)) "\\spad{display(t,width)} outputs the TeX formatted code \\spad{t} so that each line has length less than or equal to \\spadvar{width}.")) (|convert| (($ (|OutputForm|) (|Integer|) (|OutputForm|)) "\\spad{convert(o,step,type)} changes \\spad{o} in standard output format to TeX format and also adds the given \\spad{step} number and type. This is useful if you want to create equations with given numbers or have the equation numbers correspond to the interpreter \\spad{step} numbers.") (($ (|OutputForm|) (|Integer|)) "\\spad{convert(o,step)} changes \\spad{o} in standard output format to TeX format and also adds the given \\spad{step} number. This is useful if you want to create equations with given numbers or have the equation numbers correspond to the interpreter \\spad{step} numbers.")) (|coerce| (($ (|OutputForm|)) "\\spad{coerce(o)} changes \\spad{o} in the standard output format to TeX format."))) 
 NIL 
 NIL 
-(-1186) 
+(-1207) 
 ((|constructor| (NIL "This domain provides an implementation of text files. Text is stored in these files using the native character set of the computer.")) (|endOfFile?| (((|Boolean|) $) "\\spad{endOfFile?(f)} tests whether the file \\spad{f} is positioned after the end of all text. If the file is open for output, then this test is always true.")) (|readIfCan!| (((|Union| (|String|) "failed") $) "\\spad{readIfCan!(f)} returns a string of the contents of a line from file \\spad{f,} if possible. If \\spad{f} is not readable or if it is positioned at the end of file, then \\spad{\"failed\"} is returned.")) (|readLineIfCan!| (((|Union| (|String|) "failed") $) "\\spad{readLineIfCan!(f)} returns a string of the contents of a line from file \\spad{f,} if possible. If \\spad{f} is not readable or if it is positioned at the end of file, then \\spad{\"failed\"} is returned.")) (|readLine!| (((|String|) $) "\\spad{readLine!(f)} returns a string of the contents of a line from the file \\spad{f.}")) (|writeLine!| (((|String|) $) "\\spad{writeLine!(f)} finishes the current line in the file \\spad{f.} An empty string is returned. The call \\spad{writeLine!(f)} is equivalent to \\spad{writeLine!(f,\"\")}.") (((|String|) $ (|String|)) "\\spad{writeLine!(f,s)} writes the contents of the string \\spad{s} and finishes the current line in the file \\spad{f.} The value of \\spad{s} is returned."))) 
 NIL 
 NIL 
-(-1187 R) 
+(-1208 R) 
 ((|constructor| (NIL "Tools for the sign finding utilities.")) (|direction| (((|Integer|) (|String|)) "\\spad{direction(s)} \\undocumented")) (|nonQsign| (((|Union| (|Integer|) "failed") |#1|) "\\spad{nonQsign(r)} \\undocumented")) (|sign| (((|Union| (|Integer|) "failed") |#1|) "\\spad{sign(r)} \\undocumented"))) 
 NIL 
 NIL 
-(-1188) 
+(-1209) 
 ((|constructor| (NIL "This package exports a function for making a \\spadtype{ThreeSpace}")) (|createThreeSpace| (((|ThreeSpace| (|DoubleFloat|))) "\\spad{createThreeSpace()} creates a \\spadtype{ThreeSpace(DoubleFloat)} object capable of holding point, curve, mesh components and any combination."))) 
 NIL 
 NIL 
-(-1189 S) 
+(-1210 S) 
 ((|constructor| (NIL "Category for the transcendental elementary functions.")) (|pi| (($) "\\spad{pi()} returns the constant pi."))) 
 NIL 
 NIL 
-(-1190) 
+(-1211) 
 ((|constructor| (NIL "Category for the transcendental elementary functions.")) (|pi| (($) "\\spad{pi()} returns the constant pi."))) 
 NIL 
 NIL 
-(-1191 S) 
+(-1212 S) 
 ((|constructor| (NIL "\\spadtype{Tree(S)} is a basic domains of tree structures. Each tree is either empty or else is a node consisting of a value and a list of (sub)trees.")) (|cyclicParents| (((|List| $) $) "\\indented{1}{cyclicParents(t) returns a list of cycles that are parents of \\spad{t.}} \\blankline \\spad{X} t1:=tree [1,2,3,4] \\spad{X} cyclicParents \\spad{t1}")) (|cyclicEqual?| (((|Boolean|) $ $) "\\indented{1}{cyclicEqual?(t1, \\spad{t2)} tests of two cyclic trees have} \\indented{1}{the same structure.} \\blankline \\spad{X} t1:=tree [1,2,3,4] \\spad{X} t2:=tree [1,2,3,4] \\spad{X} cyclicEqual?(t1,t2)")) (|cyclicEntries| (((|List| $) $) "\\indented{1}{cyclicEntries(t) returns a list of top-level cycles in tree \\spad{t.}} \\blankline \\spad{X} t1:=tree [1,2,3,4] \\spad{X} cyclicEntries \\spad{t1}")) (|cyclicCopy| (($ $) "\\indented{1}{cyclicCopy(l) makes a copy of a (possibly) cyclic tree \\spad{l.}} \\blankline \\spad{X} t1:=tree [1,2,3,4] \\spad{X} cyclicCopy \\spad{t1}")) (|cyclic?| (((|Boolean|) $) "\\indented{1}{cyclic?(t) tests if \\spad{t} is a cyclic tree.} \\blankline \\spad{X} t1:=tree [1,2,3,4] \\spad{X} cyclic? \\spad{t1}")) (|tree| (($ |#1|) "\\indented{1}{tree(nd) creates a tree with value \\spad{nd,} and no children} \\blankline \\spad{X} tree 6") (($ (|List| |#1|)) "\\indented{1}{tree(ls) creates a tree from a list of elements of \\spad{s.}} \\blankline \\spad{X} tree [1,2,3,4]") (($ |#1| (|List| $)) "\\indented{1}{tree(nd,ls) creates a tree with value \\spad{nd,} and children ls.} \\blankline \\spad{X} t1:=tree [1,2,3,4] \\spad{X} tree(5,[t1])"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098))))) 
-(-1192 S) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119))))) 
+(-1213 S) 
 ((|constructor| (NIL "Category for the trigonometric functions.")) (|tan| (($ $) "\\spad{tan(x)} returns the tangent of \\spad{x.}")) (|sin| (($ $) "\\spad{sin(x)} returns the sine of \\spad{x.}")) (|sec| (($ $) "\\spad{sec(x)} returns the secant of \\spad{x.}")) (|csc| (($ $) "\\spad{csc(x)} returns the cosecant of \\spad{x.}")) (|cot| (($ $) "\\spad{cot(x)} returns the cotangent of \\spad{x.}")) (|cos| (($ $) "\\spad{cos(x)} returns the cosine of \\spad{x.}"))) 
 NIL 
 NIL 
-(-1193) 
+(-1214) 
 ((|constructor| (NIL "Category for the trigonometric functions.")) (|tan| (($ $) "\\spad{tan(x)} returns the tangent of \\spad{x.}")) (|sin| (($ $) "\\spad{sin(x)} returns the sine of \\spad{x.}")) (|sec| (($ $) "\\spad{sec(x)} returns the secant of \\spad{x.}")) (|csc| (($ $) "\\spad{csc(x)} returns the cosecant of \\spad{x.}")) (|cot| (($ $) "\\spad{cot(x)} returns the cotangent of \\spad{x.}")) (|cos| (($ $) "\\spad{cos(x)} returns the cosine of \\spad{x.}"))) 
 NIL 
 NIL 
-(-1194 R -3313) 
+(-1215 R -3958) 
 ((|constructor| (NIL "\\spadtype{TrigonometricManipulations} provides transformations from trigonometric functions to complex exponentials and logarithms, and back.")) (|complexForm| (((|Complex| |#2|) |#2|) "\\spad{complexForm(f)} returns \\spad{[real \\spad{f,} imag f]}.")) (|real?| (((|Boolean|) |#2|) "\\spad{real?(f)} returns \\spad{true} if \\spad{f = real \\spad{f}.}")) (|imag| ((|#2| |#2|) "\\spad{imag(f)} returns the imaginary part of \\spad{f} where \\spad{f} is a complex function.")) (|real| ((|#2| |#2|) "\\spad{real(f)} returns the real part of \\spad{f} where \\spad{f} is a complex function.")) (|trigs| ((|#2| |#2|) "\\spad{trigs(f)} rewrites all the complex logs and exponentials appearing in \\spad{f} in terms of trigonometric functions.")) (|complexElementary| ((|#2| |#2| (|Symbol|)) "\\spad{complexElementary(f, \\spad{x)}} rewrites the kernels of \\spad{f} involving \\spad{x} in terms of the 2 fundamental complex transcendental elementary functions: \\spad{log, exp}.") ((|#2| |#2|) "\\spad{complexElementary(f)} rewrites \\spad{f} in terms of the 2 fundamental complex transcendental elementary functions: \\spad{log, exp}.")) (|complexNormalize| ((|#2| |#2| (|Symbol|)) "\\spad{complexNormalize(f, \\spad{x)}} rewrites \\spad{f} using the least possible number of complex independent kernels involving \\spad{x}.") ((|#2| |#2|) "\\spad{complexNormalize(f)} rewrites \\spad{f} using the least possible number of complex independent kernels."))) 
 NIL 
 NIL 
-(-1195 R |Row| |Col| M) 
+(-1216 R |Row| |Col| M) 
 ((|constructor| (NIL "This package provides functions that compute \"fraction-free\" inverses of upper and lower triangular matrices over a integral domain. By \"fraction-free inverses\" we mean the following: given a matrix \\spad{B} with entries in \\spad{R} and an element \\spad{d} of \\spad{R} such that \\spad{d} * inv(B) also has entries in \\spad{R,} we return \\spad{d} * inv(B). Thus, it is not necessary to pass to the quotient field in any of our computations.")) (|LowTriBddDenomInv| ((|#4| |#4| |#1|) "\\spad{LowTriBddDenomInv(B,d)} returns \\spad{M,} where \\spad{B} is a non-singular lower triangular matrix and \\spad{d} is an element of \\spad{R} such that \\spad{M = \\spad{d} * inv(B)} has entries in \\spad{R.}")) (|UpTriBddDenomInv| ((|#4| |#4| |#1|) "\\spad{UpTriBddDenomInv(B,d)} returns \\spad{M,} where \\spad{B} is a non-singular upper triangular matrix and \\spad{d} is an element of \\spad{R} such that \\spad{M = \\spad{d} * inv(B)} has entries in \\spad{R.}"))) 
 NIL 
 NIL 
-(-1196 R -3313) 
+(-1217 R -3958) 
 ((|constructor| (NIL "TranscendentalManipulations provides functions to simplify and expand expressions involving transcendental operators.")) (|expandTrigProducts| ((|#2| |#2|) "\\spad{expandTrigProducts(e)} replaces \\axiom{sin(x)*sin(y)} by \\spad{(cos(x-y)-cos(x+y))/2}, \\axiom{cos(x)*cos(y)} by \\spad{(cos(x-y)+cos(x+y))/2}, and \\axiom{sin(x)*cos(y)} by \\spad{(sin(x-y)+sin(x+y))/2}. Note that this operation uses the pattern matcher and so is relatively expensive. To avoid getting into an infinite loop the transformations are applied at most ten times.")) (|removeSinhSq| ((|#2| |#2|) "\\spad{removeSinhSq(f)} converts every \\spad{sinh(u)**2} appearing in \\spad{f} into \\spad{1 - cosh(x)**2}, and also reduces higher powers of \\spad{sinh(u)} with that formula.")) (|removeCoshSq| ((|#2| |#2|) "\\spad{removeCoshSq(f)} converts every \\spad{cosh(u)**2} appearing in \\spad{f} into \\spad{1 - sinh(x)**2}, and also reduces higher powers of \\spad{cosh(u)} with that formula.")) (|removeSinSq| ((|#2| |#2|) "\\spad{removeSinSq(f)} converts every \\spad{sin(u)**2} appearing in \\spad{f} into \\spad{1 - cos(x)**2}, and also reduces higher powers of \\spad{sin(u)} with that formula.")) (|removeCosSq| ((|#2| |#2|) "\\spad{removeCosSq(f)} converts every \\spad{cos(u)**2} appearing in \\spad{f} into \\spad{1 - sin(x)**2}, and also reduces higher powers of \\spad{cos(u)} with that formula.")) (|coth2tanh| ((|#2| |#2|) "\\spad{coth2tanh(f)} converts every \\spad{coth(u)} appearing in \\spad{f} into \\spad{1/tanh(u)}.")) (|cot2tan| ((|#2| |#2|) "\\spad{cot2tan(f)} converts every \\spad{cot(u)} appearing in \\spad{f} into \\spad{1/tan(u)}.")) (|tanh2coth| ((|#2| |#2|) "\\spad{tanh2coth(f)} converts every \\spad{tanh(u)} appearing in \\spad{f} into \\spad{1/coth(u)}.")) (|tan2cot| ((|#2| |#2|) "\\spad{tan2cot(f)} converts every \\spad{tan(u)} appearing in \\spad{f} into \\spad{1/cot(u)}.")) (|tanh2trigh| ((|#2| |#2|) "\\spad{tanh2trigh(f)} converts every \\spad{tanh(u)} appearing in \\spad{f} into \\spad{sinh(u)/cosh(u)}.")) (|tan2trig| ((|#2| |#2|) "\\spad{tan2trig(f)} converts every \\spad{tan(u)} appearing in \\spad{f} into \\spad{sin(u)/cos(u)}.")) (|sinh2csch| ((|#2| |#2|) "\\spad{sinh2csch(f)} converts every \\spad{sinh(u)} appearing in \\spad{f} into \\spad{1/csch(u)}.")) (|sin2csc| ((|#2| |#2|) "\\spad{sin2csc(f)} converts every \\spad{sin(u)} appearing in \\spad{f} into \\spad{1/csc(u)}.")) (|sech2cosh| ((|#2| |#2|) "\\spad{sech2cosh(f)} converts every \\spad{sech(u)} appearing in \\spad{f} into \\spad{1/cosh(u)}.")) (|sec2cos| ((|#2| |#2|) "\\spad{sec2cos(f)} converts every \\spad{sec(u)} appearing in \\spad{f} into \\spad{1/cos(u)}.")) (|csch2sinh| ((|#2| |#2|) "\\spad{csch2sinh(f)} converts every \\spad{csch(u)} appearing in \\spad{f} into \\spad{1/sinh(u)}.")) (|csc2sin| ((|#2| |#2|) "\\spad{csc2sin(f)} converts every \\spad{csc(u)} appearing in \\spad{f} into \\spad{1/sin(u)}.")) (|coth2trigh| ((|#2| |#2|) "\\spad{coth2trigh(f)} converts every \\spad{coth(u)} appearing in \\spad{f} into \\spad{cosh(u)/sinh(u)}.")) (|cot2trig| ((|#2| |#2|) "\\spad{cot2trig(f)} converts every \\spad{cot(u)} appearing in \\spad{f} into \\spad{cos(u)/sin(u)}.")) (|cosh2sech| ((|#2| |#2|) "\\spad{cosh2sech(f)} converts every \\spad{cosh(u)} appearing in \\spad{f} into \\spad{1/sech(u)}.")) (|cos2sec| ((|#2| |#2|) "\\spad{cos2sec(f)} converts every \\spad{cos(u)} appearing in \\spad{f} into \\spad{1/sec(u)}.")) (|expandLog| ((|#2| |#2|) "\\spad{expandLog(f)} converts every \\spad{log(a/b)} appearing in \\spad{f} into \\spad{log(a) - log(b)}, and every \\spad{log(a*b)} into \\spad{log(a) + log(b)}..")) (|expandPower| ((|#2| |#2|) "\\spad{expandPower(f)} converts every power \\spad{(a/b)**c} appearing in \\spad{f} into \\spad{a**c * b**(-c)}.")) (|simplifyLog| ((|#2| |#2|) "\\spad{simplifyLog(f)} converts every \\spad{log(a) - log(b)} appearing in \\spad{f} into \\spad{log(a/b)}, every \\spad{log(a) + log(b)} into \\spad{log(a*b)} and every \\spad{n*log(a)} into \\spad{log(a^n)}.")) (|simplifyExp| ((|#2| |#2|) "\\spad{simplifyExp(f)} converts every product \\spad{exp(a)*exp(b)} appearing in \\spad{f} into \\spad{exp(a+b)}.")) (|htrigs| ((|#2| |#2|) "\\spad{htrigs(f)} converts all the exponentials in \\spad{f} into hyperbolic sines and cosines.")) (|simplify| ((|#2| |#2|) "\\spad{simplify(f)} performs the following simplifications on f:\\begin{items} \\item 1. rewrites trigs and hyperbolic trigs in terms of \\spad{sin} ,\\spad{cos}, \\spad{sinh}, \\spad{cosh}. \\item 2. rewrites \\spad{sin**2} and \\spad{sinh**2} in terms of \\spad{cos} and \\spad{cosh}, \\item 3. rewrites \\spad{exp(a)*exp(b)} as \\spad{exp(a+b)}. \\item 4. rewrites \\spad{(a**(1/n))**m * (a**(1/s))**t} as a single power of a single radical of \\spad{a}. \\end{items}")) (|expand| ((|#2| |#2|) "\\spad{expand(f)} performs the following expansions on f:\\begin{items} \\item 1. logs of products are expanded into sums of logs, \\item 2. trigonometric and hyperbolic trigonometric functions of sums are expanded into sums of products of trigonometric and hyperbolic trigonometric functions. \\item 3. formal powers of the form \\spad{(a/b)**c} are expanded into \\spad{a**c * b**(-c)}. \\end{items}"))) 
 NIL 
-((-12 (|HasCategory| |#1| (LIST (QUOTE -613) (LIST (QUOTE -893) (|devaluate| |#1|)))) (|HasCategory| |#1| (LIST (QUOTE -887) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -887) (|devaluate| |#1|))))) 
-(-1197 S R E V P) 
+((-12 (|HasCategory| |#1| (LIST (QUOTE -633) (LIST (QUOTE -914) (|devaluate| |#1|)))) (|HasCategory| |#1| (LIST (QUOTE -908) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -908) (|devaluate| |#1|))))) 
+(-1218 S R E V P) 
 ((|constructor| (NIL "The category of triangular sets of multivariate polynomials with coefficients in an integral domain. Let \\axiom{R} be an integral domain and \\axiom{V} a finite ordered set of variables, say \\axiom{X1 < \\spad{X2} < \\spad{...} < Xn}. A set \\axiom{S} of polynomials in \\axiom{R[X1,X2,...,Xn]} is triangular if no elements of \\axiom{S} lies in \\axiom{R}, and if two distinct elements of \\axiom{S} have distinct main variables. Note that the empty set is a triangular set. A triangular set is not necessarily a (lexicographical) Groebner basis and the notion of reduction related to triangular sets is based on the recursive view of polynomials. We recall this notion here and refer to \\spad{[1]} for more details. A polynomial \\axiom{P} is reduced w.r.t a non-constant polynomial \\axiom{Q} if the degree of \\axiom{P} in the main variable of \\axiom{Q} is less than the main degree of \\axiom{Q}. A polynomial \\axiom{P} is reduced w.r.t a triangular set \\axiom{T} if it is reduced w.r.t. every polynomial of \\axiom{T}.")) (|coHeight| (((|NonNegativeInteger|) $) "\\axiom{coHeight(ts)} returns \\axiom{size()\\$V} minus \\axiom{\\#ts}.")) (|extend| (($ $ |#5|) "\\axiom{extend(ts,p)} returns a triangular set which encodes the simple extension by \\axiom{p} of the extension of the base field defined by \\axiom{ts}, according to the properties of triangular sets of the current category. If the required properties do not hold an error is returned.")) (|extendIfCan| (((|Union| $ "failed") $ |#5|) "\\axiom{extendIfCan(ts,p)} returns a triangular set which encodes the simple extension by \\axiom{p} of the extension of the base field defined by \\axiom{ts}, according to the properties of triangular sets of the current domain. If the required properties do not hold then \"failed\" is returned. This operation encodes in some sense the properties of the triangular sets of the current category. Is is used to implement the \\axiom{construct} operation to guarantee that every triangular set build from a list of polynomials has the required properties.")) (|select| (((|Union| |#5| "failed") $ |#4|) "\\axiom{select(ts,v)} returns the polynomial of \\axiom{ts} with \\axiom{v} as main variable, if any.")) (|algebraic?| (((|Boolean|) |#4| $) "\\axiom{algebraic?(v,ts)} returns \\spad{true} iff \\axiom{v} is the main variable of some polynomial in \\axiom{ts}.")) (|algebraicVariables| (((|List| |#4|) $) "\\axiom{algebraicVariables(ts)} returns the decreasingly sorted list of the main variables of the polynomials of \\axiom{ts}.")) (|rest| (((|Union| $ "failed") $) "\\axiom{rest(ts)} returns the polynomials of \\axiom{ts} with smaller main variable than \\axiom{mvar(ts)} if \\axiom{ts} is not empty, otherwise returns \"failed\"")) (|last| (((|Union| |#5| "failed") $) "\\axiom{last(ts)} returns the polynomial of \\axiom{ts} with smallest main variable if \\axiom{ts} is not empty, otherwise returns \\axiom{\"failed\"}.")) (|first| (((|Union| |#5| "failed") $) "\\axiom{first(ts)} returns the polynomial of \\axiom{ts} with greatest main variable if \\axiom{ts} is not empty, otherwise returns \\axiom{\"failed\"}.")) (|zeroSetSplitIntoTriangularSystems| (((|List| (|Record| (|:| |close| $) (|:| |open| (|List| |#5|)))) (|List| |#5|)) "\\axiom{zeroSetSplitIntoTriangularSystems(lp)} returns a list of triangular systems \\axiom{[[ts1,qs1],...,[tsn,qsn]]} such that the zero set of \\axiom{lp} is the union of the closures of the \\axiom{W_i} where \\axiom{W_i} consists of the zeros of \\axiom{ts} which do not cancel any polynomial in \\axiom{qsi}.")) (|zeroSetSplit| (((|List| $) (|List| |#5|)) "\\axiom{zeroSetSplit(lp)} returns a list \\axiom{lts} of triangular sets such that the zero set of \\axiom{lp} is the union of the closures of the regular zero sets of the members of \\axiom{lts}.")) (|reduceByQuasiMonic| ((|#5| |#5| $) "\\axiom{reduceByQuasiMonic(p,ts)} returns the same as \\axiom{remainder(p,collectQuasiMonic(ts)).polnum}.")) (|collectQuasiMonic| (($ $) "\\axiom{collectQuasiMonic(ts)} returns the subset of \\axiom{ts} consisting of the polynomials with initial in \\axiom{R}.")) (|removeZero| ((|#5| |#5| $) "\\axiom{removeZero(p,ts)} returns \\axiom{0} if \\axiom{p} reduces to \\axiom{0} by pseudo-division w.r.t \\axiom{ts} otherwise returns a polynomial \\axiom{q} computed from \\axiom{p} by removing any coefficient in \\axiom{p} reducing to \\axiom{0}.")) (|initiallyReduce| ((|#5| |#5| $) "\\axiom{initiallyReduce(p,ts)} returns a polynomial \\axiom{r} such that \\axiom{initiallyReduced?(r,ts)} holds and there exists some product \\axiom{h} of \\axiom{initials(ts)} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}.")) (|headReduce| ((|#5| |#5| $) "\\axiom{headReduce(p,ts)} returns a polynomial \\axiom{r} such that \\axiom{headReduce?(r,ts)} holds and there exists some product \\axiom{h} of \\axiom{initials(ts)} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}.")) (|stronglyReduce| ((|#5| |#5| $) "\\axiom{stronglyReduce(p,ts)} returns a polynomial \\axiom{r} such that \\axiom{stronglyReduced?(r,ts)} holds and there exists some product \\axiom{h} of \\axiom{initials(ts)} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}.")) (|rewriteSetWithReduction| (((|List| |#5|) (|List| |#5|) $ (|Mapping| |#5| |#5| |#5|) (|Mapping| (|Boolean|) |#5| |#5|)) "\\axiom{rewriteSetWithReduction(lp,ts,redOp,redOp?)} returns a list \\axiom{lq} of polynomials such that \\axiom{[reduce(p,ts,redOp,redOp?) for \\spad{p} in lp]} and \\axiom{lp} have the same zeros inside the regular zero set of \\axiom{ts}. Moreover, for every polynomial \\axiom{q} in \\axiom{lq} and every polynomial \\axiom{t} in \\axiom{ts} \\axiom{redOp?(q,t)} holds and there exists a polynomial \\axiom{p} in the ideal generated by \\axiom{lp} and a product \\axiom{h} of \\axiom{initials(ts)} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}. The operation \\axiom{redOp} must satisfy the following conditions. For every \\axiom{p} and \\axiom{q} we have \\axiom{redOp?(redOp(p,q),q)} and there exists an integer \\axiom{e} and a polynomial \\axiom{f} such that \\axiom{init(q)^e*p = \\spad{f*q} + redOp(p,q)}.")) (|reduce| ((|#5| |#5| $ (|Mapping| |#5| |#5| |#5|) (|Mapping| (|Boolean|) |#5| |#5|)) "\\axiom{reduce(p,ts,redOp,redOp?)} returns a polynomial \\axiom{r} such that \\axiom{redOp?(r,p)} holds for every \\axiom{p} of \\axiom{ts} and there exists some product \\axiom{h} of the initials of the members of \\axiom{ts} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}. The operation \\axiom{redOp} must satisfy the following conditions. For every \\axiom{p} and \\axiom{q} we have \\axiom{redOp?(redOp(p,q),q)} and there exists an integer \\axiom{e} and a polynomial \\axiom{f} such that \\axiom{init(q)^e*p = \\spad{f*q} + redOp(p,q)}.")) (|autoReduced?| (((|Boolean|) $ (|Mapping| (|Boolean|) |#5| (|List| |#5|))) "\\axiom{autoReduced?(ts,redOp?)} returns \\spad{true} iff every element of \\axiom{ts} is reduced w.r.t to every other in the sense of \\axiom{redOp?}")) (|initiallyReduced?| (((|Boolean|) $) "\\spad{initiallyReduced?(ts)} returns \\spad{true} iff for every element \\axiom{p} of \\axiom{ts}. \\axiom{p} and all its iterated initials are reduced w.r.t. to the other elements of \\axiom{ts} with the same main variable.") (((|Boolean|) |#5| $) "\\axiom{initiallyReduced?(p,ts)} returns \\spad{true} iff \\axiom{p} and all its iterated initials are reduced w.r.t. to the elements of \\axiom{ts} with the same main variable.")) (|headReduced?| (((|Boolean|) $) "\\spad{headReduced?(ts)} returns \\spad{true} iff the head of every element of \\axiom{ts} is reduced w.r.t to any other element of \\axiom{ts}.") (((|Boolean|) |#5| $) "\\axiom{headReduced?(p,ts)} returns \\spad{true} iff the head of \\axiom{p} is reduced w.r.t. \\axiom{ts}.")) (|stronglyReduced?| (((|Boolean|) $) "\\axiom{stronglyReduced?(ts)} returns \\spad{true} iff every element of \\axiom{ts} is reduced w.r.t to any other element of \\axiom{ts}.") (((|Boolean|) |#5| $) "\\axiom{stronglyReduced?(p,ts)} returns \\spad{true} iff \\axiom{p} is reduced w.r.t. \\axiom{ts}.")) (|reduced?| (((|Boolean|) |#5| $ (|Mapping| (|Boolean|) |#5| |#5|)) "\\axiom{reduced?(p,ts,redOp?)} returns \\spad{true} iff \\axiom{p} is reduced w.r.t.in the sense of the operation \\axiom{redOp?}, that is if for every \\axiom{t} in \\axiom{ts} \\axiom{redOp?(p,t)} holds.")) (|normalized?| (((|Boolean|) $) "\\axiom{normalized?(ts)} returns \\spad{true} iff for every axiom{p} in \\axiom{ts} we have \\axiom{normalized?(p,us)} where \\axiom{us} is \\axiom{collectUnder(ts,mvar(p))}.") (((|Boolean|) |#5| $) "\\axiom{normalized?(p,ts)} returns \\spad{true} iff \\axiom{p} and all its iterated initials have degree zero w.r.t. the main variables of the polynomials of \\axiom{ts}")) (|quasiComponent| (((|Record| (|:| |close| (|List| |#5|)) (|:| |open| (|List| |#5|))) $) "\\axiom{quasiComponent(ts)} returns \\axiom{[lp,lq]} where \\axiom{lp} is the list of the members of \\axiom{ts} and \\axiom{lq}is \\axiom{initials(ts)}.")) (|degree| (((|NonNegativeInteger|) $) "\\axiom{degree(ts)} returns the product of main degrees of the members of \\axiom{ts}.")) (|initials| (((|List| |#5|) $) "\\axiom{initials(ts)} returns the list of the non-constant initials of the members of \\axiom{ts}.")) (|basicSet| (((|Union| (|Record| (|:| |bas| $) (|:| |top| (|List| |#5|))) "failed") (|List| |#5|) (|Mapping| (|Boolean|) |#5|) (|Mapping| (|Boolean|) |#5| |#5|)) "\\axiom{basicSet(ps,pred?,redOp?)} returns the same as \\axiom{basicSet(qs,redOp?)} where \\axiom{qs} consists of the polynomials of \\axiom{ps} satisfying property \\axiom{pred?}.") (((|Union| (|Record| (|:| |bas| $) (|:| |top| (|List| |#5|))) "failed") (|List| |#5|) (|Mapping| (|Boolean|) |#5| |#5|)) "\\axiom{basicSet(ps,redOp?)} returns \\axiom{[bs,ts]} where \\axiom{concat(bs,ts)} is \\axiom{ps} and \\axiom{bs} is a basic set in Wu Wen Tsun sense of \\axiom{ps} w.r.t the reduction-test \\axiom{redOp?}, if no non-zero constant polynomial lie in \\axiom{ps}, otherwise \\axiom{\"failed\"} is returned.")) (|infRittWu?| (((|Boolean|) $ $) "\\axiom{infRittWu?(ts1,ts2)} returns \\spad{true} iff \\axiom{ts2} has higher rank than \\axiom{ts1} in Wu Wen Tsun sense."))) 
 NIL 
-((|HasCategory| |#4| (QUOTE (-374)))) 
-(-1198 R E V P) 
+((|HasCategory| |#4| (QUOTE (-394)))) 
+(-1219 R E V P) 
 ((|constructor| (NIL "The category of triangular sets of multivariate polynomials with coefficients in an integral domain. Let \\axiom{R} be an integral domain and \\axiom{V} a finite ordered set of variables, say \\axiom{X1 < \\spad{X2} < \\spad{...} < Xn}. A set \\axiom{S} of polynomials in \\axiom{R[X1,X2,...,Xn]} is triangular if no elements of \\axiom{S} lies in \\axiom{R}, and if two distinct elements of \\axiom{S} have distinct main variables. Note that the empty set is a triangular set. A triangular set is not necessarily a (lexicographical) Groebner basis and the notion of reduction related to triangular sets is based on the recursive view of polynomials. We recall this notion here and refer to \\spad{[1]} for more details. A polynomial \\axiom{P} is reduced w.r.t a non-constant polynomial \\axiom{Q} if the degree of \\axiom{P} in the main variable of \\axiom{Q} is less than the main degree of \\axiom{Q}. A polynomial \\axiom{P} is reduced w.r.t a triangular set \\axiom{T} if it is reduced w.r.t. every polynomial of \\axiom{T}.")) (|coHeight| (((|NonNegativeInteger|) $) "\\axiom{coHeight(ts)} returns \\axiom{size()\\$V} minus \\axiom{\\#ts}.")) (|extend| (($ $ |#4|) "\\axiom{extend(ts,p)} returns a triangular set which encodes the simple extension by \\axiom{p} of the extension of the base field defined by \\axiom{ts}, according to the properties of triangular sets of the current category. If the required properties do not hold an error is returned.")) (|extendIfCan| (((|Union| $ "failed") $ |#4|) "\\axiom{extendIfCan(ts,p)} returns a triangular set which encodes the simple extension by \\axiom{p} of the extension of the base field defined by \\axiom{ts}, according to the properties of triangular sets of the current domain. If the required properties do not hold then \"failed\" is returned. This operation encodes in some sense the properties of the triangular sets of the current category. Is is used to implement the \\axiom{construct} operation to guarantee that every triangular set build from a list of polynomials has the required properties.")) (|select| (((|Union| |#4| "failed") $ |#3|) "\\axiom{select(ts,v)} returns the polynomial of \\axiom{ts} with \\axiom{v} as main variable, if any.")) (|algebraic?| (((|Boolean|) |#3| $) "\\axiom{algebraic?(v,ts)} returns \\spad{true} iff \\axiom{v} is the main variable of some polynomial in \\axiom{ts}.")) (|algebraicVariables| (((|List| |#3|) $) "\\axiom{algebraicVariables(ts)} returns the decreasingly sorted list of the main variables of the polynomials of \\axiom{ts}.")) (|rest| (((|Union| $ "failed") $) "\\axiom{rest(ts)} returns the polynomials of \\axiom{ts} with smaller main variable than \\axiom{mvar(ts)} if \\axiom{ts} is not empty, otherwise returns \"failed\"")) (|last| (((|Union| |#4| "failed") $) "\\axiom{last(ts)} returns the polynomial of \\axiom{ts} with smallest main variable if \\axiom{ts} is not empty, otherwise returns \\axiom{\"failed\"}.")) (|first| (((|Union| |#4| "failed") $) "\\axiom{first(ts)} returns the polynomial of \\axiom{ts} with greatest main variable if \\axiom{ts} is not empty, otherwise returns \\axiom{\"failed\"}.")) (|zeroSetSplitIntoTriangularSystems| (((|List| (|Record| (|:| |close| $) (|:| |open| (|List| |#4|)))) (|List| |#4|)) "\\axiom{zeroSetSplitIntoTriangularSystems(lp)} returns a list of triangular systems \\axiom{[[ts1,qs1],...,[tsn,qsn]]} such that the zero set of \\axiom{lp} is the union of the closures of the \\axiom{W_i} where \\axiom{W_i} consists of the zeros of \\axiom{ts} which do not cancel any polynomial in \\axiom{qsi}.")) (|zeroSetSplit| (((|List| $) (|List| |#4|)) "\\axiom{zeroSetSplit(lp)} returns a list \\axiom{lts} of triangular sets such that the zero set of \\axiom{lp} is the union of the closures of the regular zero sets of the members of \\axiom{lts}.")) (|reduceByQuasiMonic| ((|#4| |#4| $) "\\axiom{reduceByQuasiMonic(p,ts)} returns the same as \\axiom{remainder(p,collectQuasiMonic(ts)).polnum}.")) (|collectQuasiMonic| (($ $) "\\axiom{collectQuasiMonic(ts)} returns the subset of \\axiom{ts} consisting of the polynomials with initial in \\axiom{R}.")) (|removeZero| ((|#4| |#4| $) "\\axiom{removeZero(p,ts)} returns \\axiom{0} if \\axiom{p} reduces to \\axiom{0} by pseudo-division w.r.t \\axiom{ts} otherwise returns a polynomial \\axiom{q} computed from \\axiom{p} by removing any coefficient in \\axiom{p} reducing to \\axiom{0}.")) (|initiallyReduce| ((|#4| |#4| $) "\\axiom{initiallyReduce(p,ts)} returns a polynomial \\axiom{r} such that \\axiom{initiallyReduced?(r,ts)} holds and there exists some product \\axiom{h} of \\axiom{initials(ts)} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}.")) (|headReduce| ((|#4| |#4| $) "\\axiom{headReduce(p,ts)} returns a polynomial \\axiom{r} such that \\axiom{headReduce?(r,ts)} holds and there exists some product \\axiom{h} of \\axiom{initials(ts)} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}.")) (|stronglyReduce| ((|#4| |#4| $) "\\axiom{stronglyReduce(p,ts)} returns a polynomial \\axiom{r} such that \\axiom{stronglyReduced?(r,ts)} holds and there exists some product \\axiom{h} of \\axiom{initials(ts)} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}.")) (|rewriteSetWithReduction| (((|List| |#4|) (|List| |#4|) $ (|Mapping| |#4| |#4| |#4|) (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{rewriteSetWithReduction(lp,ts,redOp,redOp?)} returns a list \\axiom{lq} of polynomials such that \\axiom{[reduce(p,ts,redOp,redOp?) for \\spad{p} in lp]} and \\axiom{lp} have the same zeros inside the regular zero set of \\axiom{ts}. Moreover, for every polynomial \\axiom{q} in \\axiom{lq} and every polynomial \\axiom{t} in \\axiom{ts} \\axiom{redOp?(q,t)} holds and there exists a polynomial \\axiom{p} in the ideal generated by \\axiom{lp} and a product \\axiom{h} of \\axiom{initials(ts)} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}. The operation \\axiom{redOp} must satisfy the following conditions. For every \\axiom{p} and \\axiom{q} we have \\axiom{redOp?(redOp(p,q),q)} and there exists an integer \\axiom{e} and a polynomial \\axiom{f} such that \\axiom{init(q)^e*p = \\spad{f*q} + redOp(p,q)}.")) (|reduce| ((|#4| |#4| $ (|Mapping| |#4| |#4| |#4|) (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{reduce(p,ts,redOp,redOp?)} returns a polynomial \\axiom{r} such that \\axiom{redOp?(r,p)} holds for every \\axiom{p} of \\axiom{ts} and there exists some product \\axiom{h} of the initials of the members of \\axiom{ts} such that \\axiom{h*p - \\spad{r}} lies in the ideal generated by \\axiom{ts}. The operation \\axiom{redOp} must satisfy the following conditions. For every \\axiom{p} and \\axiom{q} we have \\axiom{redOp?(redOp(p,q),q)} and there exists an integer \\axiom{e} and a polynomial \\axiom{f} such that \\axiom{init(q)^e*p = \\spad{f*q} + redOp(p,q)}.")) (|autoReduced?| (((|Boolean|) $ (|Mapping| (|Boolean|) |#4| (|List| |#4|))) "\\axiom{autoReduced?(ts,redOp?)} returns \\spad{true} iff every element of \\axiom{ts} is reduced w.r.t to every other in the sense of \\axiom{redOp?}")) (|initiallyReduced?| (((|Boolean|) $) "\\spad{initiallyReduced?(ts)} returns \\spad{true} iff for every element \\axiom{p} of \\axiom{ts}. \\axiom{p} and all its iterated initials are reduced w.r.t. to the other elements of \\axiom{ts} with the same main variable.") (((|Boolean|) |#4| $) "\\axiom{initiallyReduced?(p,ts)} returns \\spad{true} iff \\axiom{p} and all its iterated initials are reduced w.r.t. to the elements of \\axiom{ts} with the same main variable.")) (|headReduced?| (((|Boolean|) $) "\\spad{headReduced?(ts)} returns \\spad{true} iff the head of every element of \\axiom{ts} is reduced w.r.t to any other element of \\axiom{ts}.") (((|Boolean|) |#4| $) "\\axiom{headReduced?(p,ts)} returns \\spad{true} iff the head of \\axiom{p} is reduced w.r.t. \\axiom{ts}.")) (|stronglyReduced?| (((|Boolean|) $) "\\axiom{stronglyReduced?(ts)} returns \\spad{true} iff every element of \\axiom{ts} is reduced w.r.t to any other element of \\axiom{ts}.") (((|Boolean|) |#4| $) "\\axiom{stronglyReduced?(p,ts)} returns \\spad{true} iff \\axiom{p} is reduced w.r.t. \\axiom{ts}.")) (|reduced?| (((|Boolean|) |#4| $ (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{reduced?(p,ts,redOp?)} returns \\spad{true} iff \\axiom{p} is reduced w.r.t.in the sense of the operation \\axiom{redOp?}, that is if for every \\axiom{t} in \\axiom{ts} \\axiom{redOp?(p,t)} holds.")) (|normalized?| (((|Boolean|) $) "\\axiom{normalized?(ts)} returns \\spad{true} iff for every axiom{p} in \\axiom{ts} we have \\axiom{normalized?(p,us)} where \\axiom{us} is \\axiom{collectUnder(ts,mvar(p))}.") (((|Boolean|) |#4| $) "\\axiom{normalized?(p,ts)} returns \\spad{true} iff \\axiom{p} and all its iterated initials have degree zero w.r.t. the main variables of the polynomials of \\axiom{ts}")) (|quasiComponent| (((|Record| (|:| |close| (|List| |#4|)) (|:| |open| (|List| |#4|))) $) "\\axiom{quasiComponent(ts)} returns \\axiom{[lp,lq]} where \\axiom{lp} is the list of the members of \\axiom{ts} and \\axiom{lq}is \\axiom{initials(ts)}.")) (|degree| (((|NonNegativeInteger|) $) "\\axiom{degree(ts)} returns the product of main degrees of the members of \\axiom{ts}.")) (|initials| (((|List| |#4|) $) "\\axiom{initials(ts)} returns the list of the non-constant initials of the members of \\axiom{ts}.")) (|basicSet| (((|Union| (|Record| (|:| |bas| $) (|:| |top| (|List| |#4|))) "failed") (|List| |#4|) (|Mapping| (|Boolean|) |#4|) (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{basicSet(ps,pred?,redOp?)} returns the same as \\axiom{basicSet(qs,redOp?)} where \\axiom{qs} consists of the polynomials of \\axiom{ps} satisfying property \\axiom{pred?}.") (((|Union| (|Record| (|:| |bas| $) (|:| |top| (|List| |#4|))) "failed") (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{basicSet(ps,redOp?)} returns \\axiom{[bs,ts]} where \\axiom{concat(bs,ts)} is \\axiom{ps} and \\axiom{bs} is a basic set in Wu Wen Tsun sense of \\axiom{ps} w.r.t the reduction-test \\axiom{redOp?}, if no non-zero constant polynomial lie in \\axiom{ps}, otherwise \\axiom{\"failed\"} is returned.")) (|infRittWu?| (((|Boolean|) $ $) "\\axiom{infRittWu?(ts1,ts2)} returns \\spad{true} iff \\axiom{ts2} has higher rank than \\axiom{ts1} in Wu Wen Tsun sense."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-1199 |Coef|) 
+(-1220 |Coef|) 
 ((|constructor| (NIL "\\spadtype{TaylorSeries} is a general multivariate Taylor series domain over the ring Coef and with variables of type Symbol.")) (|fintegrate| (($ (|Mapping| $) (|Symbol|) |#1|) "\\spad{fintegrate(f,v,c)} is the integral of \\spad{f()} with respect \\indented{1}{to \\spad{v} and having \\spad{c} as the constant of integration.} \\indented{1}{The evaluation of \\spad{f()} is delayed.}")) (|integrate| (($ $ (|Symbol|) |#1|) "\\spad{integrate(s,v,c)} is the integral of \\spad{s} with respect \\indented{1}{to \\spad{v} and having \\spad{c} as the constant of integration.}")) (|coerce| (($ (|Polynomial| |#1|)) "\\spad{coerce(s)} regroups terms of \\spad{s} by total degree \\indented{1}{and forms a series.}") (($ (|Symbol|)) "\\spad{coerce(s)} converts a variable to a Taylor series")) (|coefficient| (((|Polynomial| |#1|) $ (|NonNegativeInteger|)) "\\spad{coefficient(s, \\spad{n)}} gives the terms of total degree \\spad{n.}"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-562))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-1200 |Curve|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-582))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-1221 |Curve|) 
 ((|constructor| (NIL "Package for constructing tubes around 3-dimensional parametric curves. Domain of tubes around 3-dimensional parametric curves.")) (|tube| (($ |#1| (|List| (|List| (|Point| (|DoubleFloat|)))) (|Boolean|)) "\\spad{tube(c,ll,b)} creates a tube of the domain \\spadtype{TubePlot} from a space curve \\spad{c} of the category \\spadtype{PlottableSpaceCurveCategory}, a list of lists of points (loops) \\spad{ll} and a boolean \\spad{b} which if \\spad{true} indicates a closed tube, or if \\spad{false} an open tube.")) (|setClosed| (((|Boolean|) $ (|Boolean|)) "\\spad{setClosed(t,b)} declares the given tube plot \\spad{t} to be closed if \\spad{b} is true, or if \\spad{b} is false, \\spad{t} is set to be open.")) (|open?| (((|Boolean|) $) "\\spad{open?(t)} tests whether the given tube plot \\spad{t} is open.")) (|closed?| (((|Boolean|) $) "\\spad{closed?(t)} tests whether the given tube plot \\spad{t} is closed.")) (|listLoops| (((|List| (|List| (|Point| (|DoubleFloat|)))) $) "\\spad{listLoops(t)} returns the list of lists of points, or the 'loops', of the given tube plot \\spad{t.}")) (|getCurve| ((|#1| $) "\\spad{getCurve(t)} returns the \\spadtype{PlottableSpaceCurveCategory} representing the parametric curve of the given tube plot \\spad{t.}"))) 
 NIL 
 NIL 
-(-1201) 
+(-1222) 
 ((|constructor| (NIL "Tools for constructing tubes around 3-dimensional parametric curves.")) (|loopPoints| (((|List| (|Point| (|DoubleFloat|))) (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|List| (|List| (|DoubleFloat|)))) "\\spad{loopPoints(p,n,b,r,lls)} creates and returns a list of points which form the loop with radius \\spad{r,} around the center point indicated by the point \\spad{p,} with the principal normal vector of the space curve at point \\spad{p} given by the point(vector) \\spad{n,} and the binormal vector given by the point(vector) \\spad{b,} and a list of lists, lls, which is the \\spadfun{cosSinInfo} of the number of points defining the loop.")) (|cosSinInfo| (((|List| (|List| (|DoubleFloat|))) (|Integer|)) "\\spad{cosSinInfo(n)} returns the list of lists of values for \\spad{n,} in the form \\spad{[[cos(n-1) a,sin(n-1) a],...,[cos 2 a,sin 2 a],[cos a,sin a]]} where \\spad{a = 2 pi/n}. Note that \\spad{n} should be greater than 2.")) (|unitVector| (((|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|))) "\\spad{unitVector(p)} creates the unit vector of the point \\spad{p} and returns the result as a point. Note that \\spad{unitVector(p) = p/|p|}.")) (|cross| (((|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|))) "\\spad{cross(p,q)} computes the cross product of the two points \\spad{p} and \\spad{q} using only the first three coordinates, and keeping the color of the first point \\spad{p.} The result is returned as a point.")) (|dot| (((|DoubleFloat|) (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|))) "\\spad{dot(p,q)} computes the dot product of the two points \\spad{p} and \\spad{q} using only the first three coordinates, and returns the resulting \\spadtype{DoubleFloat}.")) (- (((|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|))) "\\spad{p - \\spad{q}} computes and returns a point whose coordinates are the differences of the coordinates of two points \\spad{p} and \\spad{q}, using the color, or fourth coordinate, of the first point \\spad{p} as the color also of the point \\spad{q}.")) (+ (((|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|))) "\\spad{p + \\spad{q}} computes and returns a point whose coordinates are the sums of the coordinates of the two points \\spad{p} and \\spad{q}, using the color, or fourth coordinate, of the first point \\spad{p} as the color also of the point \\spad{q}.")) (* (((|Point| (|DoubleFloat|)) (|DoubleFloat|) (|Point| (|DoubleFloat|))) "\\spad{s * \\spad{p}} returns a point whose coordinates are the scalar multiple of the point \\spad{p} by the scalar \\spad{s,} preserving the color, or fourth coordinate, of \\spad{p.}")) (|point| (((|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{point(x1,x2,x3,c)} creates and returns a point from the three specified coordinates \\spad{x1}, \\spad{x2}, \\spad{x3}, and also a fourth coordinate, \\spad{c,} which is generally used to specify the color of the point."))) 
 NIL 
 NIL 
-(-1202 S) 
+(-1223 S) 
 ((|constructor| (NIL "This domain is used to interface with the interpreter's notion of comma-delimited sequences of values.")) (|length| (((|NonNegativeInteger|) $) "\\indented{1}{length(x) returns the number of elements in tuple \\spad{x}} \\blankline \\spad{X} t1:PrimitiveArray(Integer):= \\spad{[i} for \\spad{i} in 1..10] \\spad{X} t2:=coerce(t1)$Tuple(Integer) \\spad{X} length(t2)")) (|select| ((|#1| $ (|NonNegativeInteger|)) "\\indented{1}{select(x,n) returns the \\spad{n}-th element of tuple \\spad{x.}} \\indented{1}{tuples are 0-based} \\blankline \\spad{X} t1:PrimitiveArray(Integer):= \\spad{[i} for \\spad{i} in 1..10] \\spad{X} t2:=coerce(t1)$Tuple(Integer) \\spad{X} select(t2,3)")) (|coerce| (($ (|PrimitiveArray| |#1|)) "\\indented{1}{coerce(a) makes a tuple from primitive array a} \\blankline \\spad{X} t1:PrimitiveArray(Integer):= \\spad{[i} for \\spad{i} in 1..10] \\spad{X} t2:=coerce(t1)$Tuple(Integer)"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-1098)))) 
-(-1203 -3313) 
+((|HasCategory| |#1| (QUOTE (-1119)))) 
+(-1224 -3958) 
 ((|constructor| (NIL "A basic package for the factorization of bivariate polynomials over a finite field. The functions here represent the base step for the multivariate factorizer.")) (|twoFactor| (((|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#1|))) (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#1|)) (|Integer|)) "\\spad{twoFactor(p,n)} returns the factorisation of polynomial \\spad{p,} a sparse univariate polynomial (sup) over a sup over \\spad{F.} Also, \\spad{p} is assumed primitive and square-free and \\spad{n} is the degree of the inner variable of \\spad{p} (maximum of the degrees of the coefficients of \\spad{p).}")) (|generalSqFr| (((|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#1|))) (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#1|))) "\\spad{generalSqFr(p)} returns the square-free factorisation of polynomial \\spad{p,} a sparse univariate polynomial (sup) over a sup over \\spad{F.}")) (|generalTwoFactor| (((|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#1|))) (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#1|))) "\\spad{generalTwoFactor(p)} returns the factorisation of polynomial \\spad{p,} a sparse univariate polynomial (sup) over a sup over \\spad{F.}"))) 
 NIL 
 NIL 
-(-1204) 
+(-1225) 
 ((|constructor| (NIL "The fundamental Type."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-1205) 
+(-1226) 
 ((|constructor| (NIL "This is a low-level domain which implements matrices (two dimensional arrays) of 16-bit integers. Indexing is 0 based, there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|) (|Integer|)) "\\indented{1}{qnew(n, \\spad{m)} creates a new \\spad{n} by \\spad{m} matrix of zeros.} \\blankline \\spad{X} qnew(3,4)$U16Matrix()"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-572) (QUOTE (-1098))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-303))) (|HasCategory| (-572) (QUOTE (-562))) (|HasAttribute| (-572) (QUOTE (-4604 "*"))) (|HasCategory| (-572) (QUOTE (-174))) (|HasCategory| (-572) (QUOTE (-368)))) 
-(-1206) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-592) (QUOTE (-1119))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-323))) (|HasCategory| (-592) (QUOTE (-582))) (|HasAttribute| (-592) (QUOTE (-4627 "*"))) (|HasCategory| (-592) (QUOTE (-194))) (|HasCategory| (-592) (QUOTE (-388)))) 
+(-1227) 
 ((|constructor| (NIL "\\indented{2}{fill!(x, \\spad{s)} modifies a vector \\spad{x} so every element has value \\spad{s}} \\blankline \\spad{X} t1:=new(10,7)$U16Vector \\spad{X} fill!(t1,9)"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-572) (QUOTE (-1098))) (|HasCategory| (-572) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-572) (QUOTE (-848))) (-1841 (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-572) (QUOTE (-1098)))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-848)))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))))) 
-(-1207) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-592) (QUOTE (-1119))) (|HasCategory| (-592) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-592) (QUOTE (-869))) (-3836 (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-592) (QUOTE (-1119)))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-869)))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))))) 
+(-1228) 
 ((|constructor| (NIL "This is a low-level domain which implements matrices (two dimensional arrays) of 32-bit integers. Indexing is 0 based, there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|) (|Integer|)) "\\indented{1}{qnew(n, \\spad{m)} creates a new \\spad{n} by \\spad{m} matrix of zeros.} \\blankline \\spad{X} qnew(3,4)$U32Matrix()"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-572) (QUOTE (-1098))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-303))) (|HasCategory| (-572) (QUOTE (-562))) (|HasAttribute| (-572) (QUOTE (-4604 "*"))) (|HasCategory| (-572) (QUOTE (-174))) (|HasCategory| (-572) (QUOTE (-368)))) 
-(-1208) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-592) (QUOTE (-1119))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-323))) (|HasCategory| (-592) (QUOTE (-582))) (|HasAttribute| (-592) (QUOTE (-4627 "*"))) (|HasCategory| (-592) (QUOTE (-194))) (|HasCategory| (-592) (QUOTE (-388)))) 
+(-1229) 
 ((|constructor| (NIL "\\indented{2}{fill!(x, \\spad{s)} modifies a vector \\spad{x} so every element has value \\spad{s}} \\blankline \\spad{X} t1:=new(10,7)$U32Vector \\spad{X} fill!(t1,9)"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-572) (QUOTE (-1098))) (|HasCategory| (-572) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-572) (QUOTE (-848))) (-1841 (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-572) (QUOTE (-1098)))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-848)))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))))) 
-(-1209) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-592) (QUOTE (-1119))) (|HasCategory| (-592) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-592) (QUOTE (-869))) (-3836 (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-592) (QUOTE (-1119)))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-869)))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))))) 
+(-1230) 
 ((|constructor| (NIL "This is a low-level domain which implements matrices (two dimensional arrays) of 8-bit integers. Indexing is 0 based, there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|) (|Integer|)) "\\indented{1}{qnew(n, \\spad{m)} creates a new \\spad{n} by \\spad{m} matrix of zeros.} \\blankline \\spad{X} qnew(3,4)$U8Matrix()"))) 
-((-4602 . T) (-4603 . T)) 
-((|HasCategory| (-572) (QUOTE (-1098))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-303))) (|HasCategory| (-572) (QUOTE (-562))) (|HasAttribute| (-572) (QUOTE (-4604 "*"))) (|HasCategory| (-572) (QUOTE (-174))) (|HasCategory| (-572) (QUOTE (-368)))) 
-(-1210) 
+((-4625 . T) (-4626 . T)) 
+((|HasCategory| (-592) (QUOTE (-1119))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-323))) (|HasCategory| (-592) (QUOTE (-582))) (|HasAttribute| (-592) (QUOTE (-4627 "*"))) (|HasCategory| (-592) (QUOTE (-194))) (|HasCategory| (-592) (QUOTE (-388)))) 
+(-1231) 
 ((|constructor| (NIL "\\indented{2}{fill!(x, \\spad{s)} modifies a vector \\spad{x} so every element has value \\spad{s}} \\blankline \\spad{X} t1:=new(10,7)$U8Vector \\spad{X} fill!(t1,9)"))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| (-572) (QUOTE (-1098))) (|HasCategory| (-572) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| (-572) (QUOTE (-848))) (-1841 (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| (-572) (QUOTE (-1098)))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-848)))) (-12 (|HasCategory| (-572) (LIST (QUOTE -305) (QUOTE (-572)))) (|HasCategory| (-572) (QUOTE (-1098)))))) 
-(-1211 S) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| (-592) (QUOTE (-1119))) (|HasCategory| (-592) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| (-592) (QUOTE (-869))) (-3836 (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| (-592) (QUOTE (-1119)))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-869)))) (-12 (|HasCategory| (-592) (LIST (QUOTE -325) (QUOTE (-592)))) (|HasCategory| (-592) (QUOTE (-1119)))))) 
+(-1232 S) 
 ((|constructor| (NIL "Provides functions to force a partial ordering on any set.")) (|more?| (((|Boolean|) |#1| |#1|) "\\spad{more?(a, \\spad{b)}} compares a and \\spad{b} in the partial ordering induced by setOrder, and uses the ordering on \\spad{S} if a and \\spad{b} are not comparable in the partial ordering.")) (|userOrdered?| (((|Boolean|)) "\\spad{userOrdered?()} tests if the partial ordering induced by setOrder is not empty.")) (|largest| ((|#1| (|List| |#1|)) "\\spad{largest \\spad{l}} returns the largest element of \\spad{l} where the partial ordering induced by setOrder is completed into a total one by the ordering on \\spad{S.}") ((|#1| (|List| |#1|) (|Mapping| (|Boolean|) |#1| |#1|)) "\\spad{largest(l, fn)} returns the largest element of \\spad{l} where the partial ordering induced by setOrder is completed into a total one by \\spad{fn.}")) (|less?| (((|Boolean|) |#1| |#1| (|Mapping| (|Boolean|) |#1| |#1|)) "\\spad{less?(a, \\spad{b,} fn)} compares \\spad{a} and \\spad{b} in the partial ordering induced by setOrder, and returns \\spad{fn(a, \\spad{b)}} if \\spad{a} and \\spad{b} are not comparable in that ordering.") (((|Union| (|Boolean|) "failed") |#1| |#1|) "\\spad{less?(a, \\spad{b)}} compares \\spad{a} and \\spad{b} in the partial ordering induced by setOrder.")) (|getOrder| (((|Record| (|:| |low| (|List| |#1|)) (|:| |high| (|List| |#1|)))) "\\spad{getOrder()} returns \\spad{[[b1,...,bm], [a1,...,an]]} such that the partial ordering on \\spad{S} was given by \\spad{setOrder([b1,...,bm],[a1,...,an])}.")) (|setOrder| (((|Void|) (|List| |#1|) (|List| |#1|)) "\\spad{setOrder([b1,...,bm], [a1,...,an])} defines a partial ordering on \\spad{S} given \\spad{by:} \\indented{3}{(1)\\space{2}\\spad{b1 < \\spad{b2} < \\spad{...} < \\spad{bm} < \\spad{a1} < \\spad{a2} < \\spad{...} < an}.} \\indented{3}{(2)\\space{2}\\spad{bj < \\spad{c} < ai}\\space{2}for \\spad{c} not among the ai's and bj's.} \\indented{3}{(3)\\space{2}undefined on \\spad{(c,d)} if neither is among the ai's,bj's.}") (((|Void|) (|List| |#1|)) "\\spad{setOrder([a1,...,an])} defines a partial ordering on \\spad{S} given \\spad{by:} \\indented{3}{(1)\\space{2}\\spad{a1 < \\spad{a2} < \\spad{...} < an}.} \\indented{3}{(2)\\space{2}\\spad{b < ai\\space{3}for \\spad{i} = 1..n} and \\spad{b} not among the ai's.} \\indented{3}{(3)\\space{2}undefined on \\spad{(b, \\spad{c)}} if neither is among the ai's.}"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-848)))) 
-(-1212) 
+((|HasCategory| |#1| (QUOTE (-869)))) 
+(-1233) 
 ((|constructor| (NIL "This packages provides functions to allow the user to select the ordering on the variables and operators for displaying polynomials, fractions and expressions. The ordering affects the display only and not the computations.")) (|resetVariableOrder| (((|Void|)) "\\spad{resetVariableOrder()} cancels any previous use of setVariableOrder and returns to the default system ordering.")) (|getVariableOrder| (((|Record| (|:| |high| (|List| (|Symbol|))) (|:| |low| (|List| (|Symbol|))))) "\\spad{getVariableOrder()} returns \\spad{[[b1,...,bm], [a1,...,an]]} such that the ordering on the variables was given by \\spad{setVariableOrder([b1,...,bm], [a1,...,an])}.")) (|setVariableOrder| (((|Void|) (|List| (|Symbol|)) (|List| (|Symbol|))) "\\spad{setVariableOrder([b1,...,bm], [a1,...,an])} defines an ordering on the variables given by \\spad{b1 > \\spad{b2} > \\spad{...} > \\spad{bm} \\spad{>}} other variables \\spad{> \\spad{a1} > \\spad{a2} > \\spad{...} > an}.") (((|Void|) (|List| (|Symbol|))) "\\spad{setVariableOrder([a1,...,an])} defines an ordering on the variables given by \\spad{a1 > \\spad{a2} > \\spad{...} > an > other variables}."))) 
 NIL 
 NIL 
-(-1213 S) 
+(-1234 S) 
 ((|constructor| (NIL "A constructive unique factorization domain, \\spadignore{i.e.} where we can constructively factor members into a product of a finite number of irreducible elements.")) (|factor| (((|Factored| $) $) "\\spad{factor(x)} returns the factorization of \\spad{x} into irreducibles.")) (|squareFreePart| (($ $) "\\spad{squareFreePart(x)} returns a product of prime factors of \\spad{x} each taken with multiplicity one.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(x)} returns the square-free factorization of \\spad{x} \\spadignore{i.e.} such that the factors are pairwise relatively prime and each has multiple prime factors.")) (|prime?| (((|Boolean|) $) "\\spad{prime?(x)} tests if \\spad{x} can never be written as the product of two non-units of the ring, \\spadignore{i.e.} \\spad{x} is an irreducible element."))) 
 NIL 
 NIL 
-(-1214) 
+(-1235) 
 ((|constructor| (NIL "A constructive unique factorization domain, \\spadignore{i.e.} where we can constructively factor members into a product of a finite number of irreducible elements.")) (|factor| (((|Factored| $) $) "\\spad{factor(x)} returns the factorization of \\spad{x} into irreducibles.")) (|squareFreePart| (($ $) "\\spad{squareFreePart(x)} returns a product of prime factors of \\spad{x} each taken with multiplicity one.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(x)} returns the square-free factorization of \\spad{x} \\spadignore{i.e.} such that the factors are pairwise relatively prime and each has multiple prime factors.")) (|prime?| (((|Boolean|) $) "\\spad{prime?(x)} tests if \\spad{x} can never be written as the product of two non-units of the ring, \\spadignore{i.e.} \\spad{x} is an irreducible element."))) 
-((-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1215 |Coef|) 
+(-1236 |Coef|) 
 ((|constructor| (NIL "This package has no description"))) 
 NIL 
 NIL 
-(-1216 |Coef|) 
+(-1237 |Coef|) 
 ((|constructor| (NIL "This domain has no description"))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-769)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-769)) (|devaluate| |#1|))))) (|HasCategory| (-769) (QUOTE (-1110))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-769))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-769))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-1217 |Coef1| |Coef2| |var1| |var2| |cen1| |cen2|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-790)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-790)) (|devaluate| |#1|))))) (|HasCategory| (-790) (QUOTE (-1131))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-790))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-790))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-1238 |Coef1| |Coef2| |var1| |var2| |cen1| |cen2|) 
 ((|constructor| (NIL "Mapping package for univariate Laurent series This package allows one to apply a function to the coefficients of a univariate Laurent series.")) (|map| (((|UnivariateLaurentSeries| |#2| |#4| |#6|) (|Mapping| |#2| |#1|) (|UnivariateLaurentSeries| |#1| |#3| |#5|)) "\\spad{map(f,g(x))} applies the map \\spad{f} to the coefficients of the Laurent series \\spad{g(x)}."))) 
 NIL 
 NIL 
-(-1218 |Coef|) 
+(-1239 |Coef|) 
 ((|constructor| (NIL "\\spadtype{UnivariateLaurentSeriesCategory} is the category of Laurent series in one variable.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(f(x),y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $ (|Symbol|)) "\\spad{integrate(f(x),y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 1. We may integrate a series when we can divide coefficients by integers.")) (|rationalFunction| (((|Fraction| (|Polynomial| |#1|)) $ (|Integer|) (|Integer|)) "\\spad{rationalFunction(f,k1,k2)} returns a rational function consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 \\spad{<=} \\spad{d} \\spad{<=} k2}.") (((|Fraction| (|Polynomial| |#1|)) $ (|Integer|)) "\\spad{rationalFunction(f,k)} returns a rational function consisting of the sum of all terms of \\spad{f} of degree \\spad{<=} \\spad{k.}")) (|multiplyCoefficients| (($ (|Mapping| |#1| (|Integer|)) $) "\\spad{multiplyCoefficients(f,sum(n = n0..infinity,a[n] * x**n)) = sum(n = 0..infinity,f(n) * a[n] * x**n)}. This function is used when Puiseux series are represented by a Laurent series and an exponent.")) (|series| (($ (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|)))) "\\spad{series(st)} creates a series from a stream of non-zero terms, where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1219 S |Coef| UTS) 
+(-1240 S |Coef| UTS) 
 ((|constructor| (NIL "This is a category of univariate Laurent series constructed from univariate Taylor series. A Laurent series is represented by a pair \\spad{[n,f(x)]}, where \\spad{n} is an arbitrary integer and \\spad{f(x)} is a Taylor series. This pair represents the Laurent series \\spad{x**n * f(x)}.")) (|taylorIfCan| (((|Union| |#3| "failed") $) "\\spad{taylorIfCan(f(x))} converts the Laurent series \\spad{f(x)} to a Taylor series, if possible. If this is not possible, \"failed\" is returned.")) (|taylor| ((|#3| $) "\\spad{taylor(f(x))} converts the Laurent series \\spad{f(x)} to a Taylor series, if possible. Error: if this is not possible.")) (|coerce| (($ |#3|) "\\spad{coerce(f(x))} converts the Taylor series \\spad{f(x)} to a Laurent series.")) (|removeZeroes| (($ (|Integer|) $) "\\spad{removeZeroes(n,f(x))} removes up to \\spad{n} leading zeroes from the Laurent series \\spad{f(x)}. A Laurent series is represented by \\spad{(1)} an exponent and \\spad{(2)} a Taylor series which may have leading zero coefficients. When the Taylor series has a leading zero coefficient, the 'leading zero' is removed from the Laurent series as follows: the series is rewritten by increasing the exponent by 1 and dividing the Taylor series by its variable.") (($ $) "\\spad{removeZeroes(f(x))} removes leading zeroes from the representation of the Laurent series \\spad{f(x)}. A Laurent series is represented by \\spad{(1)} an exponent and \\spad{(2)} a Taylor series which may have leading zero coefficients. When the Taylor series has a leading zero coefficient, the 'leading zero' is removed from the Laurent series as follows: the series is rewritten by increasing the exponent by 1 and dividing the Taylor series by its variable. Note that \\spad{removeZeroes(f)} removes all leading zeroes from \\spad{f}")) (|taylorRep| ((|#3| $) "\\spad{taylorRep(f(x))} returns \\spad{g(x)}, where \\spad{f = x**n * g(x)} is represented by \\spad{[n,g(x)]}.")) (|degree| (((|Integer|) $) "\\spad{degree(f(x))} returns the degree of the lowest order term of \\spad{f(x)}, which may have zero as a coefficient.")) (|laurent| (($ (|Integer|) |#3|) "\\spad{laurent(n,f(x))} returns \\spad{x**n * f(x)}."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-368)))) 
-(-1220 |Coef| UTS) 
+((|HasCategory| |#2| (QUOTE (-388)))) 
+(-1241 |Coef| UTS) 
 ((|constructor| (NIL "This is a category of univariate Laurent series constructed from univariate Taylor series. A Laurent series is represented by a pair \\spad{[n,f(x)]}, where \\spad{n} is an arbitrary integer and \\spad{f(x)} is a Taylor series. This pair represents the Laurent series \\spad{x**n * f(x)}.")) (|taylorIfCan| (((|Union| |#2| "failed") $) "\\spad{taylorIfCan(f(x))} converts the Laurent series \\spad{f(x)} to a Taylor series, if possible. If this is not possible, \"failed\" is returned.")) (|taylor| ((|#2| $) "\\spad{taylor(f(x))} converts the Laurent series \\spad{f(x)} to a Taylor series, if possible. Error: if this is not possible.")) (|coerce| (($ |#2|) "\\spad{coerce(f(x))} converts the Taylor series \\spad{f(x)} to a Laurent series.")) (|removeZeroes| (($ (|Integer|) $) "\\spad{removeZeroes(n,f(x))} removes up to \\spad{n} leading zeroes from the Laurent series \\spad{f(x)}. A Laurent series is represented by \\spad{(1)} an exponent and \\spad{(2)} a Taylor series which may have leading zero coefficients. When the Taylor series has a leading zero coefficient, the 'leading zero' is removed from the Laurent series as follows: the series is rewritten by increasing the exponent by 1 and dividing the Taylor series by its variable.") (($ $) "\\spad{removeZeroes(f(x))} removes leading zeroes from the representation of the Laurent series \\spad{f(x)}. A Laurent series is represented by \\spad{(1)} an exponent and \\spad{(2)} a Taylor series which may have leading zero coefficients. When the Taylor series has a leading zero coefficient, the 'leading zero' is removed from the Laurent series as follows: the series is rewritten by increasing the exponent by 1 and dividing the Taylor series by its variable. Note that \\spad{removeZeroes(f)} removes all leading zeroes from \\spad{f}")) (|taylorRep| ((|#2| $) "\\spad{taylorRep(f(x))} returns \\spad{g(x)}, where \\spad{f = x**n * g(x)} is represented by \\spad{[n,g(x)]}.")) (|degree| (((|Integer|) $) "\\spad{degree(f(x))} returns the degree of the lowest order term of \\spad{f(x)}, which may have zero as a coefficient.")) (|laurent| (($ (|Integer|) |#2|) "\\spad{laurent(n,f(x))} returns \\spad{x**n * f(x)}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-3389 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-2623 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1221 |Coef| UTS) 
+(-1242 |Coef| UTS) 
 ((|constructor| (NIL "This package enables one to construct a univariate Laurent series domain from a univariate Taylor series domain. Univariate Laurent series are represented by a pair \\spad{[n,f(x)]}, where \\spad{n} is an arbitrary integer and \\spad{f(x)} is a Taylor series. This pair represents the Laurent series \\spad{x**n * f(x)}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| (-572) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (QUOTE (-151))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-151))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-227)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|))))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1028)))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-821)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1144)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -283) (|devaluate| |#2|) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-848)))) (-1841 (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-821)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-848))))) (|HasCategory| |#2| (QUOTE (-910))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-910)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-554)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-303)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-149))) (-1841 (|HasCategory| |#1| (QUOTE (-149))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-149))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (-1841 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -283) (|devaluate| |#2|) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -305) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -527) (QUOTE (-1170)) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-1170))))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-821)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-910)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1028)))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1144))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|)))))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-910)))) (|HasCategory| |#1| (QUOTE (-149))) (-12 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-149)))))) 
-(-1222 |Coef| |var| |cen|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| (-592) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (QUOTE (-171))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-171))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-247)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|))))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1049)))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1165)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-869)))) (-3836 (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-869))))) (|HasCategory| |#2| (QUOTE (-931))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-931)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-574)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-323)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-169))) (-3836 (|HasCategory| |#1| (QUOTE (-169))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-169))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (-3836 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -325) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -547) (QUOTE (-1191)) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-1191))))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-931)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1049)))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1165))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|)))))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-931)))) (|HasCategory| |#1| (QUOTE (-169))) (-12 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-169)))))) 
+(-1243 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Dense Laurent series in one variable \\spadtype{UnivariateLaurentSeries} is a domain representing Laurent series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring, the power series variable, and the center of the power series expansion. For example, \\spad{UnivariateLaurentSeries(Integer,x,3)} represents Laurent series in \\spad{(x - 3)} with integer coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Laurent series."))) 
-(((-4604 "*") -1841 (-4028 (|has| |#1| (-368)) (|has| (-1250 |#1| |#2| |#3|) (-821))) (|has| |#1| (-174)) (-4028 (|has| |#1| (-368)) (|has| (-1250 |#1| |#2| |#3|) (-910)))) (-4595 -1841 (-4028 (|has| |#1| (-368)) (|has| (-1250 |#1| |#2| |#3|) (-821))) (|has| |#1| (-562)) (-4028 (|has| |#1| (-368)) (|has| (-1250 |#1| |#2| |#3|) (-910)))) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| (-572) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-151))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-151)))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|)))))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-227))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-572)) (|devaluate| |#1|))))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-1028))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-1144))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -283) (LIST (QUOTE -1250) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1250) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -305) (LIST (QUOTE -1250) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -527) (QUOTE (-1170)) (LIST (QUOTE -1250) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-554))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-303))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-910))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-149))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-149)))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-174)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-368))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -283) (LIST (QUOTE -1250) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1250) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -305) (LIST (QUOTE -1250) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -527) (QUOTE (-1170)) (LIST (QUOTE -1250) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-1170)))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-821))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-1028))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-1144))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|)))))) (-1841 (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-910))) (|HasCategory| |#1| (QUOTE (-368)))) (-12 (|HasCategory| (-1250 |#1| |#2| |#3|) (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-368)))) (|HasCategory| |#1| (QUOTE (-149))))) 
-(-1223 ZP) 
+(((-4627 "*") -3836 (-1732 (|has| |#1| (-388)) (|has| (-1271 |#1| |#2| |#3|) (-842))) (|has| |#1| (-194)) (-1732 (|has| |#1| (-388)) (|has| (-1271 |#1| |#2| |#3|) (-931)))) (-4618 -3836 (-1732 (|has| |#1| (-388)) (|has| (-1271 |#1| |#2| |#3|) (-842))) (|has| |#1| (-582)) (-1732 (|has| |#1| (-388)) (|has| (-1271 |#1| |#2| |#3|) (-931)))) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| (-592) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-171))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-171)))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|)))))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-247))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-592)) (|devaluate| |#1|))))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-1049))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-1165))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1271) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1271) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -325) (LIST (QUOTE -1271) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -547) (QUOTE (-1191)) (LIST (QUOTE -1271) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-574))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-323))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-931))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-169))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-169)))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-194)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-388))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1271) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1271) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -325) (LIST (QUOTE -1271) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -547) (QUOTE (-1191)) (LIST (QUOTE -1271) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-1191)))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-1049))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-1165))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|)))))) (-3836 (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-931))) (|HasCategory| |#1| (QUOTE (-388)))) (-12 (|HasCategory| (-1271 |#1| |#2| |#3|) (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-388)))) (|HasCategory| |#1| (QUOTE (-169))))) 
+(-1244 ZP) 
 ((|constructor| (NIL "Package for the factorization of univariate polynomials with integer coefficients. The factorization is done by \"lifting\" (HENSEL) the factorization over a finite field.")) (|henselFact| (((|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| |#1|) (|:| |pow| (|Integer|)))))) |#1| (|Boolean|)) "\\spad{henselFact(m,flag)} returns the factorization of \\spad{m,} FinalFact is a Record s.t. FinalFact.contp=content \\spad{m,} FinalFact.factors=List of irreducible factors of \\spad{m} with exponent ,{} if \\spad{flag} =true the polynomial is assumed square free.")) (|factorSquareFree| (((|Factored| |#1|) |#1|) "\\spad{factorSquareFree(m)} returns the factorization of \\spad{m} square free polynomial")) (|factor| (((|Factored| |#1|) |#1|) "\\spad{factor(m)} returns the factorization of \\spad{m}"))) 
 NIL 
 NIL 
-(-1224 R S) 
+(-1245 R S) 
 ((|constructor| (NIL "This package provides operations for mapping functions onto segments.")) (|map| (((|Stream| |#2|) (|Mapping| |#2| |#1|) (|UniversalSegment| |#1|)) "\\spad{map(f,s)} expands the segment \\spad{s,} applying \\spad{f} to each value.") (((|UniversalSegment| |#2|) (|Mapping| |#2| |#1|) (|UniversalSegment| |#1|)) "\\spad{map(f,seg)} returns the new segment obtained by applying \\spad{f} to the endpoints of seg."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-846)))) 
-(-1225 S) 
+((|HasCategory| |#1| (QUOTE (-867)))) 
+(-1246 S) 
 ((|constructor| (NIL "This domain provides segments which may be half open. That is, ranges of the form \\spad{a..} or \\spad{a..b}.")) (|hasHi| (((|Boolean|) $) "\\spad{hasHi(s)} tests whether the segment \\spad{s} has an upper bound.")) (|coerce| (($ (|Segment| |#1|)) "\\spad{coerce(x)} allows \\spadtype{Segment} values to be used as \\spad{%.}")) (|segment| (($ |#1|) "\\spad{segment(l)} is an alternate way to construct the segment \\spad{l..}.")) (SEGMENT (($ |#1|) "\\spad{l..} produces a half open segment, that is, one with no upper bound."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-846))) (|HasCategory| |#1| (QUOTE (-1098)))) 
-(-1226 |x| R |y| S) 
+((|HasCategory| |#1| (QUOTE (-867))) (|HasCategory| |#1| (QUOTE (-1119)))) 
+(-1247 |x| R |y| S) 
 ((|constructor| (NIL "This package lifts a mapping from coefficient rings \\spad{R} to \\spad{S} to a mapping from \\spadtype{UnivariatePolynomial}(x,R) to \\spadtype{UnivariatePolynomial}(y,S). Note that the mapping is assumed to send zero to zero, since it will only be applied to the non-zero coefficients of the polynomial.")) (|map| (((|UnivariatePolynomial| |#3| |#4|) (|Mapping| |#4| |#2|) (|UnivariatePolynomial| |#1| |#2|)) "\\spad{map(func, poly)} creates a new polynomial by applying \\spad{func} to every non-zero coefficient of the polynomial poly."))) 
 NIL 
 NIL 
-(-1227 R Q UP) 
+(-1248 R Q UP) 
 ((|constructor| (NIL "UnivariatePolynomialCommonDenominator provides functions to compute the common denominator of the coefficients of univariate polynomials over the quotient field of a \\spad{gcd} domain.")) (|splitDenominator| (((|Record| (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) "\\spad{splitDenominator(q)} returns \\spad{[p, \\spad{d]}} such that \\spad{q = p/d} and \\spad{d} is a common denominator for the coefficients of \\spad{q.}")) (|clearDenominator| ((|#3| |#3|) "\\spad{clearDenominator(q)} returns \\spad{p} such that \\spad{q = p/d} where \\spad{d} is a common denominator for the coefficients of \\spad{q.}")) (|commonDenominator| ((|#1| |#3|) "\\spad{commonDenominator(q)} returns a common denominator \\spad{d} for the coefficients of \\spad{q.}"))) 
 NIL 
 NIL 
-(-1228 R UP) 
+(-1249 R UP) 
 ((|constructor| (NIL "UnivariatePolynomialDecompositionPackage implements functional decomposition of univariate polynomial with coefficients in an \\spad{IntegralDomain} of \\spad{CharacteristicZero}.")) (|monicCompleteDecompose| (((|List| |#2|) |#2|) "\\spad{monicCompleteDecompose(f)} returns a list of factors of \\spad{f} for the functional decomposition \\spad{([} \\spad{f1,} ..., \\spad{fn} ] means \\spad{f} = \\spad{f1} \\spad{o} \\spad{...} \\spad{o} fn).")) (|monicDecomposeIfCan| (((|Union| (|Record| (|:| |left| |#2|) (|:| |right| |#2|)) "failed") |#2|) "\\spad{monicDecomposeIfCan(f)} returns a functional decomposition of the monic polynomial \\spad{f} of \"failed\" if it has not found any.")) (|leftFactorIfCan| (((|Union| |#2| "failed") |#2| |#2|) "\\spad{leftFactorIfCan(f,h)} returns the left factor \\spad{(g} in \\spad{f} = \\spad{g} \\spad{o} \\spad{h)} of the functional decomposition of the polynomial \\spad{f} with given \\spad{h} or \\spad{\"failed\"} if \\spad{g} does not exist.")) (|rightFactorIfCan| (((|Union| |#2| "failed") |#2| (|NonNegativeInteger|) |#1|) "\\spad{rightFactorIfCan(f,d,c)} returns a candidate to be the right factor \\spad{(h} in \\spad{f} = \\spad{g} \\spad{o} \\spad{h)} of degree \\spad{d} with leading coefficient \\spad{c} of a functional decomposition of the polynomial \\spad{f} or \\spad{\"failed\"} if no such candidate.")) (|monicRightFactorIfCan| (((|Union| |#2| "failed") |#2| (|NonNegativeInteger|)) "\\spad{monicRightFactorIfCan(f,d)} returns a candidate to be the monic right factor \\spad{(h} in \\spad{f} = \\spad{g} \\spad{o} \\spad{h)} of degree \\spad{d} of a functional decomposition of the polynomial \\spad{f} or \\spad{\"failed\"} if no such candidate."))) 
 NIL 
 NIL 
-(-1229 R UP) 
+(-1250 R UP) 
 ((|constructor| (NIL "UnivariatePolynomialDivisionPackage provides a division for non monic univarite polynomials with coefficients in an \\spad{IntegralDomain}.")) (|divideIfCan| (((|Union| (|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) "failed") |#2| |#2|) "\\spad{divideIfCan(f,g)} returns quotient and remainder of the division of \\spad{f} by \\spad{g} or \"failed\" if it has not succeeded."))) 
 NIL 
 NIL 
-(-1230 R U) 
+(-1251 R U) 
 ((|constructor| (NIL "This package implements Karatsuba's trick for multiplying (large) univariate polynomials. It could be improved with a version doing the work on place and also with a special case for squares. We've done this in Basicmath, but we believe that this out of the scope of AXIOM.")) (|karatsuba| ((|#2| |#2| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{karatsuba(a,b,l,k)} returns \\spad{a*b} by applying Karatsuba's trick provided that both \\spad{a} and \\spad{b} have at least \\spad{l} terms and \\spad{k > 0} holds and by calling \\spad{noKaratsuba} otherwise. The other multiplications are performed by recursive calls with the same third argument and \\spad{k-1} as fourth argument.")) (|karatsubaOnce| ((|#2| |#2| |#2|) "\\spad{karatsuba(a,b)} returns \\spad{a*b} by applying Karatsuba's trick once. The other multiplications are performed by calling \\spad{*} from \\spad{U}.")) (|noKaratsuba| ((|#2| |#2| |#2|) "\\spad{noKaratsuba(a,b)} returns \\spad{a*b} without using Karatsuba's trick at all."))) 
 NIL 
 NIL 
-(-1231 |x| R) 
+(-1252 |x| R) 
 ((|constructor| (NIL "This domain represents univariate polynomials in some symbol over arbitrary (not necessarily commutative) coefficient rings. The representation is sparse in the sense that only non-zero terms are represented. Note that if the coefficient ring is a field, then this domain forms a euclidean domain.")) (|fmecg| (($ $ (|NonNegativeInteger|) |#2| $) "\\spad{fmecg(p1,e,r,p2)} finds \\spad{x} : \\spad{p1} - \\spad{r} * x**e * \\spad{p2}")) (|coerce| (($ (|Variable| |#1|)) "\\spad{coerce(x)} converts the variable \\spad{x} to a univariate polynomial."))) 
-(((-4604 "*") |has| |#2| (-174)) (-4595 |has| |#2| (-562)) (-4598 |has| |#2| (-368)) (-4600 |has| |#2| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-910))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-562)))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-385)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-385))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -887) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -887) (QUOTE (-572))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-385)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -613) (LIST (QUOTE -893) (QUOTE (-572)))))) (-12 (|HasCategory| (-1082) (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#2| (LIST (QUOTE -613) (QUOTE (-545))))) (|HasCategory| |#2| (QUOTE (-848))) (|HasCategory| |#2| (LIST (QUOTE -634) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-151))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-1144))) (|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (-1841 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasCategory| |#2| (QUOTE (-227))) (|HasAttribute| |#2| (QUOTE -4600)) (|HasCategory| |#2| (QUOTE (-457))) (-1841 (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-910)))) (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (-1841 (-12 (|HasCategory| $ (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-910)))) (|HasCategory| |#2| (QUOTE (-149))))) 
-(-1232 R PR S PS) 
+(((-4627 "*") |has| |#2| (-194)) (-4618 |has| |#2| (-582)) (-4621 |has| |#2| (-388)) (-4623 |has| |#2| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-931))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-582)))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-405)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-405))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -908) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -908) (QUOTE (-592))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-405)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -633) (LIST (QUOTE -914) (QUOTE (-592)))))) (-12 (|HasCategory| (-1103) (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#2| (LIST (QUOTE -633) (QUOTE (-565))))) (|HasCategory| |#2| (QUOTE (-869))) (|HasCategory| |#2| (LIST (QUOTE -654) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-171))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-1165))) (|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (-3836 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasCategory| |#2| (QUOTE (-247))) (|HasAttribute| |#2| (QUOTE -4623)) (|HasCategory| |#2| (QUOTE (-477))) (-3836 (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-931)))) (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (-3836 (-12 (|HasCategory| $ (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-931)))) (|HasCategory| |#2| (QUOTE (-169))))) 
+(-1253 R PR S PS) 
 ((|constructor| (NIL "Mapping from polynomials over \\spad{R} to polynomials over \\spad{S} given a map from \\spad{R} to \\spad{S} assumed to send zero to zero.")) (|map| ((|#4| (|Mapping| |#3| |#1|) |#2|) "\\spad{map(f, \\spad{p)}} takes a function \\spad{f} from \\spad{R} to \\spad{S,} and applies it to each (non-zero) coefficient of a polynomial \\spad{p} over \\spad{R,} getting a new polynomial over \\spad{S.} Note that since the map is not applied to zero elements, it may map zero to zero."))) 
 NIL 
 NIL 
-(-1233 S R) 
-((|constructor| (NIL "The category of univariate polynomials over a ring \\spad{R.} No particular model is assumed - implementations can be either sparse or dense.")) (|integrate| (($ $) "\\spad{integrate(p)} integrates the univariate polynomial \\spad{p} with respect to its distinguished variable.")) (|additiveValuation| ((|attribute|) "euclideanSize(a*b) = euclideanSize(a) + euclideanSize(b)")) (|separate| (((|Record| (|:| |primePart| $) (|:| |commonPart| $)) $ $) "\\spad{separate(p, \\spad{q)}} returns \\spad{[a, \\spad{b]}} such that polynomial \\spad{p = a \\spad{b}} and \\spad{a} is relatively prime to \\spad{q.}")) (|pseudoDivide| (((|Record| (|:| |coef| |#2|) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{pseudoDivide(p,q)} returns \\spad{[c, \\spad{q,} r]}, when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1) = \\spad{c} * \\spad{p}} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|pseudoQuotient| (($ $ $) "\\spad{pseudoQuotient(p,q)} returns \\spad{r,} the quotient when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1)} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|composite| (((|Union| (|Fraction| $) "failed") (|Fraction| $) $) "\\spad{composite(f, \\spad{q)}} returns \\spad{h} if \\spad{f} = h(q), and \"failed\" is no such \\spad{h} exists.") (((|Union| $ "failed") $ $) "\\spad{composite(p, \\spad{q)}} returns \\spad{h} if \\spad{p = h(q)}, and \"failed\" no such \\spad{h} exists.")) (|subResultantGcd| (($ $ $) "\\spad{subResultantGcd(p,q)} computes the \\spad{gcd} of the polynomials \\spad{p} and \\spad{q} using the SubResultant \\spad{GCD} algorithm.")) (|order| (((|NonNegativeInteger|) $ $) "\\spad{order(p, \\spad{q)}} returns the largest \\spad{n} such that \\spad{q**n} divides polynomial \\spad{p} \\spadignore{i.e.} the order of \\spad{p(x)} at \\spad{q(x)=0}.")) (|elt| ((|#2| (|Fraction| $) |#2|) "\\spad{elt(a,r)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by the constant \\spad{r.}") (((|Fraction| $) (|Fraction| $) (|Fraction| $)) "\\spad{elt(a,b)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by \\spad{b.}")) (|resultant| ((|#2| $ $) "\\spad{resultant(p,q)} returns the resultant of the polynomials \\spad{p} and \\spad{q.}")) (|discriminant| ((|#2| $) "\\spad{discriminant(p)} returns the discriminant of the polynomial \\spad{p.}")) (|differentiate| (($ $ (|Mapping| |#2| |#2|) $) "\\spad{differentiate(p, \\spad{d,} x')} extends the R-derivation \\spad{d} to an extension \\spad{D} in \\spad{R[x]} where \\spad{Dx} is given by \\spad{x',} and returns \\spad{Dp}.")) (|pseudoRemainder| (($ $ $) "\\spad{pseudoRemainder(p,q)} = \\spad{r,} for polynomials \\spad{p} and \\spad{q,} returns the remainder when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1)} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|shiftLeft| (($ $ (|NonNegativeInteger|)) "\\spad{shiftLeft(p,n)} returns \\spad{p * monomial(1,n)}")) (|shiftRight| (($ $ (|NonNegativeInteger|)) "\\spad{shiftRight(p,n)} returns \\spad{monicDivide(p,monomial(1,n)).quotient}")) (|karatsubaDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ (|NonNegativeInteger|)) "\\spad{karatsubaDivide(p,n)} returns the same as \\spad{monicDivide(p,monomial(1,n))}")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicDivide(p,q)} divide the polynomial \\spad{p} by the monic polynomial \\spad{q,} returning the pair \\spad{[quotient, remainder]}. Error: if \\spad{q} isn't monic.")) (|divideExponents| (((|Union| $ "failed") $ (|NonNegativeInteger|)) "\\spad{divideExponents(p,n)} returns a new polynomial resulting from dividing all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n,} or \"failed\" if some exponent is not exactly divisible by \\spad{n.}")) (|multiplyExponents| (($ $ (|NonNegativeInteger|)) "\\spad{multiplyExponents(p,n)} returns a new polynomial resulting from multiplying all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n.}")) (|unmakeSUP| (($ (|SparseUnivariatePolynomial| |#2|)) "\\spad{unmakeSUP(sup)} converts \\spad{sup} of type \\spadtype{SparseUnivariatePolynomial(R)} to be a member of the given type. Note that converse of makeSUP.")) (|makeSUP| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{makeSUP(p)} converts the polynomial \\spad{p} to be of type SparseUnivariatePolynomial over the same coefficients.")) (|vectorise| (((|Vector| |#2|) $ (|NonNegativeInteger|)) "\\spad{vectorise(p, \\spad{n)}} returns \\spad{[a0,...,a(n-1)]} where \\spad{p = \\spad{a0} + a1*x + \\spad{...} + a(n-1)*x**(n-1)} + higher order terms. The degree of polynomial \\spad{p} can be different from \\spad{n-1}."))) 
+(-1254 S R) 
+((|constructor| (NIL "The category of univariate polynomials over a ring \\spad{R.} No particular model is assumed - implementations can be either sparse or dense.")) (|integrate| (($ $) "\\spad{integrate(p)} integrates the univariate polynomial \\spad{p} with respect to its distinguished variable.")) (|additiveValuation| ((|attribute|) "euclideanSize(a*b) = euclideanSize(a) + euclideanSize(b)")) (|separate| (((|Record| (|:| |primePart| $) (|:| |commonPart| $)) $ $) "\\spad{separate(p, \\spad{q)}} returns \\spad{[a, \\spad{b]}} such that polynomial \\spad{p = a \\spad{b}} and \\spad{a} is relatively prime to \\spad{q.}")) (|pseudoDivide| (((|Record| (|:| |coef| |#2|) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{pseudoDivide(p,q)} returns \\spad{[c, \\spad{q,} r]}, when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1) = \\spad{c} * \\spad{p}} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|pseudoQuotient| (($ $ $) "\\spad{pseudoQuotient(p,q)} returns \\spad{r,} the quotient when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1)} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|composite| (((|Union| (|Fraction| $) "failed") (|Fraction| $) $) "\\spad{composite(f, \\spad{q)}} returns \\spad{h} if \\spad{f} = h(q), and \"failed\" is no such \\spad{h} exists.") (((|Union| $ "failed") $ $) "\\spad{composite(p, \\spad{q)}} returns \\spad{h} if \\spad{p = h(q)}, and \"failed\" no such \\spad{h} exists.")) (|subResultantGcd| (($ $ $) "\\spad{subResultantGcd(p,q)} computes the \\spad{gcd} of the polynomials \\spad{p} and \\spad{q} using the SubResultant \\spad{GCD} algorithm.")) (|order| (((|NonNegativeInteger|) $ $) "\\spad{order(p, \\spad{q)}} returns the largest \\spad{n} such that \\spad{q**n} divides polynomial \\spad{p} \\spadignore{i.e.} the order of \\spad{p(x)} at \\spad{q(x)=0}.")) (|elt| ((|#2| (|Fraction| $) |#2|) "\\spad{elt(a,r)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by the constant \\spad{r.}") (((|Fraction| $) (|Fraction| $) (|Fraction| $)) "\\spad{elt(a,b)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by \\spad{b.}")) (|resultant| ((|#2| $ $) "\\spad{resultant(p,q)} returns the resultant of the polynomials \\spad{p} and \\spad{q.}")) (|discriminant| ((|#2| $) "\\spad{discriminant(p)} returns the discriminant of the polynomial \\spad{p.}")) (|differentiate| (($ $ (|Mapping| |#2| |#2|) $) "\\spad{differentiate(p, \\spad{d,} x')} extends the R-derivation \\spad{d} to an extension \\spad{D} in \\spad{R[x]} where \\spad{Dx} is given by \\spad{x',} and returns \\spad{Dp}.")) (|pseudoRemainder| (($ $ $) "\\spad{pseudoRemainder(p,q)} = \\spad{r,} for polynomials \\spad{p} and \\spad{q,} returns the remainder when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1)} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|shiftLeft| (($ $ (|NonNegativeInteger|)) "\\spad{shiftLeft(p,n)} returns \\spad{p * monomial(1,n)}")) (|shiftRight| (($ $ (|NonNegativeInteger|)) "\\spad{shiftRight(p,n)} returns \\spad{monicDivide(p,monomial(1,n)).quotient}")) (|karatsubaDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ (|NonNegativeInteger|)) "\\spad{karatsubaDivide(p,n)} returns the same as \\spad{monicDivide(p,monomial(1,n))}")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicDivide(p,q)} divide the polynomial \\spad{p} by the monic polynomial \\spad{q,} returning the pair \\spad{[quotient, remainder]}. Error: if \\spad{q} isn't monic.")) (|divideExponents| (((|Union| $ "failed") $ (|NonNegativeInteger|)) "\\spad{divideExponents(p,n)} returns a new polynomial resulting from dividing all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n,} or \"failed\" if some exponent is not exactly divisible by \\spad{n.}")) (|multiplyExponents| (($ $ (|NonNegativeInteger|)) "\\spad{multiplyExponents(p,n)} returns a new polynomial resulting from multiplying all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n.}")) (|unmakeSUP| (($ (|SparseUnivariatePolynomial| |#2|)) "\\spad{unmakeSUP(sup)} converts \\spad{sup} of type \\spadtype{SparseUnivariatePolynomial(R)} to be a member of the given type. Note that converse of makeSUP.")) (|makeSUP| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{makeSUP(p)} converts the polynomial \\spad{p} to be of type SparseUnivariatePolynomial over the same coefficients.")) (|unvectorise| (($ (|Vector| |#2|)) "\\indented{1}{unvectorise(v) returns the polynomial which has for coefficients the} \\indented{1}{entries of \\spad{v} in the increasing order.} \\blankline \\spad{X} \\spad{t1:UP(x,FRAC(INT)):=3*x^3+4*x^2+5*x+6} \\spad{X} t2:=vectorise(t1,4) \\spad{X} t3:UP(x,FRAC(INT)):=unvectorise(t2)")) (|vectorise| (((|Vector| |#2|) $ (|NonNegativeInteger|)) "\\indented{1}{vectorise(p, \\spad{n)} returns \\spad{[a0,...,a(n-1)]} where} \\indented{1}{\\spad{p = \\spad{a0} + a1*x + \\spad{...} + a(n-1)*x**(n-1)} + higher order terms.} \\indented{1}{The degree of polynomial \\spad{p} can be different from \\spad{n-1}.} \\blankline \\spad{X} \\spad{t1:UP(x,FRAC(INT)):=3*x^3+4*x^2+5*x+6} \\spad{X} t2:=vectorise(t1,4)"))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368))) (|HasCategory| |#2| (QUOTE (-457))) (|HasCategory| |#2| (QUOTE (-562))) (|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (QUOTE (-1144)))) 
-(-1234 R) 
-((|constructor| (NIL "The category of univariate polynomials over a ring \\spad{R.} No particular model is assumed - implementations can be either sparse or dense.")) (|integrate| (($ $) "\\spad{integrate(p)} integrates the univariate polynomial \\spad{p} with respect to its distinguished variable.")) (|additiveValuation| ((|attribute|) "euclideanSize(a*b) = euclideanSize(a) + euclideanSize(b)")) (|separate| (((|Record| (|:| |primePart| $) (|:| |commonPart| $)) $ $) "\\spad{separate(p, \\spad{q)}} returns \\spad{[a, \\spad{b]}} such that polynomial \\spad{p = a \\spad{b}} and \\spad{a} is relatively prime to \\spad{q.}")) (|pseudoDivide| (((|Record| (|:| |coef| |#1|) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{pseudoDivide(p,q)} returns \\spad{[c, \\spad{q,} r]}, when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1) = \\spad{c} * \\spad{p}} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|pseudoQuotient| (($ $ $) "\\spad{pseudoQuotient(p,q)} returns \\spad{r,} the quotient when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1)} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|composite| (((|Union| (|Fraction| $) "failed") (|Fraction| $) $) "\\spad{composite(f, \\spad{q)}} returns \\spad{h} if \\spad{f} = h(q), and \"failed\" is no such \\spad{h} exists.") (((|Union| $ "failed") $ $) "\\spad{composite(p, \\spad{q)}} returns \\spad{h} if \\spad{p = h(q)}, and \"failed\" no such \\spad{h} exists.")) (|subResultantGcd| (($ $ $) "\\spad{subResultantGcd(p,q)} computes the \\spad{gcd} of the polynomials \\spad{p} and \\spad{q} using the SubResultant \\spad{GCD} algorithm.")) (|order| (((|NonNegativeInteger|) $ $) "\\spad{order(p, \\spad{q)}} returns the largest \\spad{n} such that \\spad{q**n} divides polynomial \\spad{p} \\spadignore{i.e.} the order of \\spad{p(x)} at \\spad{q(x)=0}.")) (|elt| ((|#1| (|Fraction| $) |#1|) "\\spad{elt(a,r)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by the constant \\spad{r.}") (((|Fraction| $) (|Fraction| $) (|Fraction| $)) "\\spad{elt(a,b)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by \\spad{b.}")) (|resultant| ((|#1| $ $) "\\spad{resultant(p,q)} returns the resultant of the polynomials \\spad{p} and \\spad{q.}")) (|discriminant| ((|#1| $) "\\spad{discriminant(p)} returns the discriminant of the polynomial \\spad{p.}")) (|differentiate| (($ $ (|Mapping| |#1| |#1|) $) "\\spad{differentiate(p, \\spad{d,} x')} extends the R-derivation \\spad{d} to an extension \\spad{D} in \\spad{R[x]} where \\spad{Dx} is given by \\spad{x',} and returns \\spad{Dp}.")) (|pseudoRemainder| (($ $ $) "\\spad{pseudoRemainder(p,q)} = \\spad{r,} for polynomials \\spad{p} and \\spad{q,} returns the remainder when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1)} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|shiftLeft| (($ $ (|NonNegativeInteger|)) "\\spad{shiftLeft(p,n)} returns \\spad{p * monomial(1,n)}")) (|shiftRight| (($ $ (|NonNegativeInteger|)) "\\spad{shiftRight(p,n)} returns \\spad{monicDivide(p,monomial(1,n)).quotient}")) (|karatsubaDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ (|NonNegativeInteger|)) "\\spad{karatsubaDivide(p,n)} returns the same as \\spad{monicDivide(p,monomial(1,n))}")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicDivide(p,q)} divide the polynomial \\spad{p} by the monic polynomial \\spad{q,} returning the pair \\spad{[quotient, remainder]}. Error: if \\spad{q} isn't monic.")) (|divideExponents| (((|Union| $ "failed") $ (|NonNegativeInteger|)) "\\spad{divideExponents(p,n)} returns a new polynomial resulting from dividing all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n,} or \"failed\" if some exponent is not exactly divisible by \\spad{n.}")) (|multiplyExponents| (($ $ (|NonNegativeInteger|)) "\\spad{multiplyExponents(p,n)} returns a new polynomial resulting from multiplying all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n.}")) (|unmakeSUP| (($ (|SparseUnivariatePolynomial| |#1|)) "\\spad{unmakeSUP(sup)} converts \\spad{sup} of type \\spadtype{SparseUnivariatePolynomial(R)} to be a member of the given type. Note that converse of makeSUP.")) (|makeSUP| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{makeSUP(p)} converts the polynomial \\spad{p} to be of type SparseUnivariatePolynomial over the same coefficients.")) (|vectorise| (((|Vector| |#1|) $ (|NonNegativeInteger|)) "\\spad{vectorise(p, \\spad{n)}} returns \\spad{[a0,...,a(n-1)]} where \\spad{p = \\spad{a0} + a1*x + \\spad{...} + a(n-1)*x**(n-1)} + higher order terms. The degree of polynomial \\spad{p} can be different from \\spad{n-1}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4598 |has| |#1| (-368)) (-4600 |has| |#1| (-6 -4600)) (-4597 . T) (-4596 . T) (-4599 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388))) (|HasCategory| |#2| (QUOTE (-477))) (|HasCategory| |#2| (QUOTE (-582))) (|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (QUOTE (-1165)))) 
+(-1255 R) 
+((|constructor| (NIL "The category of univariate polynomials over a ring \\spad{R.} No particular model is assumed - implementations can be either sparse or dense.")) (|integrate| (($ $) "\\spad{integrate(p)} integrates the univariate polynomial \\spad{p} with respect to its distinguished variable.")) (|additiveValuation| ((|attribute|) "euclideanSize(a*b) = euclideanSize(a) + euclideanSize(b)")) (|separate| (((|Record| (|:| |primePart| $) (|:| |commonPart| $)) $ $) "\\spad{separate(p, \\spad{q)}} returns \\spad{[a, \\spad{b]}} such that polynomial \\spad{p = a \\spad{b}} and \\spad{a} is relatively prime to \\spad{q.}")) (|pseudoDivide| (((|Record| (|:| |coef| |#1|) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{pseudoDivide(p,q)} returns \\spad{[c, \\spad{q,} r]}, when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1) = \\spad{c} * \\spad{p}} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|pseudoQuotient| (($ $ $) "\\spad{pseudoQuotient(p,q)} returns \\spad{r,} the quotient when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1)} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|composite| (((|Union| (|Fraction| $) "failed") (|Fraction| $) $) "\\spad{composite(f, \\spad{q)}} returns \\spad{h} if \\spad{f} = h(q), and \"failed\" is no such \\spad{h} exists.") (((|Union| $ "failed") $ $) "\\spad{composite(p, \\spad{q)}} returns \\spad{h} if \\spad{p = h(q)}, and \"failed\" no such \\spad{h} exists.")) (|subResultantGcd| (($ $ $) "\\spad{subResultantGcd(p,q)} computes the \\spad{gcd} of the polynomials \\spad{p} and \\spad{q} using the SubResultant \\spad{GCD} algorithm.")) (|order| (((|NonNegativeInteger|) $ $) "\\spad{order(p, \\spad{q)}} returns the largest \\spad{n} such that \\spad{q**n} divides polynomial \\spad{p} \\spadignore{i.e.} the order of \\spad{p(x)} at \\spad{q(x)=0}.")) (|elt| ((|#1| (|Fraction| $) |#1|) "\\spad{elt(a,r)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by the constant \\spad{r.}") (((|Fraction| $) (|Fraction| $) (|Fraction| $)) "\\spad{elt(a,b)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by \\spad{b.}")) (|resultant| ((|#1| $ $) "\\spad{resultant(p,q)} returns the resultant of the polynomials \\spad{p} and \\spad{q.}")) (|discriminant| ((|#1| $) "\\spad{discriminant(p)} returns the discriminant of the polynomial \\spad{p.}")) (|differentiate| (($ $ (|Mapping| |#1| |#1|) $) "\\spad{differentiate(p, \\spad{d,} x')} extends the R-derivation \\spad{d} to an extension \\spad{D} in \\spad{R[x]} where \\spad{Dx} is given by \\spad{x',} and returns \\spad{Dp}.")) (|pseudoRemainder| (($ $ $) "\\spad{pseudoRemainder(p,q)} = \\spad{r,} for polynomials \\spad{p} and \\spad{q,} returns the remainder when \\spad{p' \\spad{:=} p*lc(q)**(deg \\spad{p} - deg \\spad{q} + 1)} is pseudo right-divided by \\spad{q,} \\spadignore{i.e.} \\spad{p' = \\spad{s} \\spad{q} + \\spad{r}.}")) (|shiftLeft| (($ $ (|NonNegativeInteger|)) "\\spad{shiftLeft(p,n)} returns \\spad{p * monomial(1,n)}")) (|shiftRight| (($ $ (|NonNegativeInteger|)) "\\spad{shiftRight(p,n)} returns \\spad{monicDivide(p,monomial(1,n)).quotient}")) (|karatsubaDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ (|NonNegativeInteger|)) "\\spad{karatsubaDivide(p,n)} returns the same as \\spad{monicDivide(p,monomial(1,n))}")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicDivide(p,q)} divide the polynomial \\spad{p} by the monic polynomial \\spad{q,} returning the pair \\spad{[quotient, remainder]}. Error: if \\spad{q} isn't monic.")) (|divideExponents| (((|Union| $ "failed") $ (|NonNegativeInteger|)) "\\spad{divideExponents(p,n)} returns a new polynomial resulting from dividing all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n,} or \"failed\" if some exponent is not exactly divisible by \\spad{n.}")) (|multiplyExponents| (($ $ (|NonNegativeInteger|)) "\\spad{multiplyExponents(p,n)} returns a new polynomial resulting from multiplying all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n.}")) (|unmakeSUP| (($ (|SparseUnivariatePolynomial| |#1|)) "\\spad{unmakeSUP(sup)} converts \\spad{sup} of type \\spadtype{SparseUnivariatePolynomial(R)} to be a member of the given type. Note that converse of makeSUP.")) (|makeSUP| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{makeSUP(p)} converts the polynomial \\spad{p} to be of type SparseUnivariatePolynomial over the same coefficients.")) (|unvectorise| (($ (|Vector| |#1|)) "\\indented{1}{unvectorise(v) returns the polynomial which has for coefficients the} \\indented{1}{entries of \\spad{v} in the increasing order.} \\blankline \\spad{X} \\spad{t1:UP(x,FRAC(INT)):=3*x^3+4*x^2+5*x+6} \\spad{X} t2:=vectorise(t1,4) \\spad{X} t3:UP(x,FRAC(INT)):=unvectorise(t2)")) (|vectorise| (((|Vector| |#1|) $ (|NonNegativeInteger|)) "\\indented{1}{vectorise(p, \\spad{n)} returns \\spad{[a0,...,a(n-1)]} where} \\indented{1}{\\spad{p = \\spad{a0} + a1*x + \\spad{...} + a(n-1)*x**(n-1)} + higher order terms.} \\indented{1}{The degree of polynomial \\spad{p} can be different from \\spad{n-1}.} \\blankline \\spad{X} \\spad{t1:UP(x,FRAC(INT)):=3*x^3+4*x^2+5*x+6} \\spad{X} t2:=vectorise(t1,4)"))) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4621 |has| |#1| (-388)) (-4623 |has| |#1| (-6 -4623)) (-4620 . T) (-4619 . T) (-4622 . T)) 
 NIL 
-(-1235 S |Coef| |Expon|) 
+(-1256 S |Coef| |Expon|) 
 ((|constructor| (NIL "\\spadtype{UnivariatePowerSeriesCategory} is the most general univariate power series category with exponents in an ordered abelian monoid. Note that this category exports a substitution function if it is possible to multiply exponents. Also note that this category exports a derivative operation if it is possible to multiply coefficients by exponents.")) (|eval| (((|Stream| |#2|) $ |#2|) "\\spad{eval(f,a)} evaluates a power series at a value in the ground ring by returning a stream of partial sums.")) (|extend| (($ $ |#3|) "\\spad{extend(f,n)} causes all terms of \\spad{f} of degree \\spad{<=} \\spad{n} to be computed.")) (|approximate| ((|#2| $ |#3|) "\\spad{approximate(f)} returns a truncated power series with the series variable viewed as an element of the coefficient domain.")) (|truncate| (($ $ |#3| |#3|) "\\spad{truncate(f,k1,k2)} returns a (finite) power series consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 \\spad{<=} \\spad{d} \\spad{<=} k2}.") (($ $ |#3|) "\\spad{truncate(f,k)} returns a (finite) power series consisting of the sum of all terms of \\spad{f} of degree \\spad{<= \\spad{k}.}")) (|order| ((|#3| $ |#3|) "\\spad{order(f,n) = min(m,n)}, where \\spad{m} is the degree of the lowest order non-zero term in \\spad{f.}") ((|#3| $) "\\spad{order(f)} is the degree of the lowest order non-zero term in \\spad{f.} This will result in an infinite loop if \\spad{f} has no non-zero terms.")) (|multiplyExponents| (($ $ (|PositiveInteger|)) "\\spad{multiplyExponents(f,n)} multiplies all exponents of the power series \\spad{f} by the positive integer \\spad{n.}")) (|center| ((|#2| $) "\\spad{center(f)} returns the point about which the series \\spad{f} is expanded.")) (|variable| (((|Symbol|) $) "\\spad{variable(f)} returns the (unique) power series variable of the power series \\spad{f.}")) (|elt| ((|#2| $ |#3|) "\\spad{elt(f(x),r)} returns the coefficient of the term of degree \\spad{r} in \\spad{f(x)}. This is the same as the function \\spadfun{coefficient}.")) (|terms| (((|Stream| (|Record| (|:| |k| |#3|) (|:| |c| |#2|))) $) "\\spad{terms(f(x))} returns a stream of non-zero terms, where a a term is an exponent-coefficient pair. The terms in the stream are ordered by increasing order of exponents."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#2| (LIST (QUOTE *) (LIST (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#2|)))) (|HasCategory| |#3| (QUOTE (-1110))) (|HasSignature| |#2| (LIST (QUOTE **) (LIST (|devaluate| |#2|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasSignature| |#2| (LIST (QUOTE -3972) (LIST (|devaluate| |#2|) (QUOTE (-1170)))))) 
-(-1236 |Coef| |Expon|) 
+((|HasCategory| |#2| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#2| (LIST (QUOTE *) (LIST (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#2|)))) (|HasCategory| |#3| (QUOTE (-1131))) (|HasSignature| |#2| (LIST (QUOTE **) (LIST (|devaluate| |#2|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasSignature| |#2| (LIST (QUOTE -1683) (LIST (|devaluate| |#2|) (QUOTE (-1191)))))) 
+(-1257 |Coef| |Expon|) 
 ((|constructor| (NIL "\\spadtype{UnivariatePowerSeriesCategory} is the most general univariate power series category with exponents in an ordered abelian monoid. Note that this category exports a substitution function if it is possible to multiply exponents. Also note that this category exports a derivative operation if it is possible to multiply coefficients by exponents.")) (|eval| (((|Stream| |#1|) $ |#1|) "\\spad{eval(f,a)} evaluates a power series at a value in the ground ring by returning a stream of partial sums.")) (|extend| (($ $ |#2|) "\\spad{extend(f,n)} causes all terms of \\spad{f} of degree \\spad{<=} \\spad{n} to be computed.")) (|approximate| ((|#1| $ |#2|) "\\spad{approximate(f)} returns a truncated power series with the series variable viewed as an element of the coefficient domain.")) (|truncate| (($ $ |#2| |#2|) "\\spad{truncate(f,k1,k2)} returns a (finite) power series consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 \\spad{<=} \\spad{d} \\spad{<=} k2}.") (($ $ |#2|) "\\spad{truncate(f,k)} returns a (finite) power series consisting of the sum of all terms of \\spad{f} of degree \\spad{<= \\spad{k}.}")) (|order| ((|#2| $ |#2|) "\\spad{order(f,n) = min(m,n)}, where \\spad{m} is the degree of the lowest order non-zero term in \\spad{f.}") ((|#2| $) "\\spad{order(f)} is the degree of the lowest order non-zero term in \\spad{f.} This will result in an infinite loop if \\spad{f} has no non-zero terms.")) (|multiplyExponents| (($ $ (|PositiveInteger|)) "\\spad{multiplyExponents(f,n)} multiplies all exponents of the power series \\spad{f} by the positive integer \\spad{n.}")) (|center| ((|#1| $) "\\spad{center(f)} returns the point about which the series \\spad{f} is expanded.")) (|variable| (((|Symbol|) $) "\\spad{variable(f)} returns the (unique) power series variable of the power series \\spad{f.}")) (|elt| ((|#1| $ |#2|) "\\spad{elt(f(x),r)} returns the coefficient of the term of degree \\spad{r} in \\spad{f(x)}. This is the same as the function \\spadfun{coefficient}.")) (|terms| (((|Stream| (|Record| (|:| |k| |#2|) (|:| |c| |#1|))) $) "\\spad{terms(f(x))} returns a stream of non-zero terms, where a a term is an exponent-coefficient pair. The terms in the stream are ordered by increasing order of exponents."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1237 RC P) 
+(-1258 RC P) 
 ((|constructor| (NIL "This package provides for square-free decomposition of univariate polynomials over arbitrary rings, \\spadignore{i.e.} a partial factorization such that each factor is a product of irreducibles with multiplicity one and the factors are pairwise relatively prime. If the ring has characteristic zero, the result is guaranteed to satisfy this condition. If the ring is an infinite ring of finite characteristic, then it may not be possible to decide when polynomials contain factors which are \\spad{p}th powers. In this case, the flag associated with that polynomial is set to \"nil\" (meaning that that polynomials are not guaranteed to be square-free).")) (|BumInSepFFE| (((|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (|Integer|))) (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (|Integer|)))) "\\spad{BumInSepFFE(f)} is a local function, exported only because it has multiple conditional definitions.")) (|squareFreePart| ((|#2| |#2|) "\\spad{squareFreePart(p)} returns a polynomial which has the same irreducible factors as the univariate polynomial \\spad{p,} but each factor has multiplicity one.")) (|squareFree| (((|Factored| |#2|) |#2|) "\\spad{squareFree(p)} computes the square-free factorization of the univariate polynomial \\spad{p.} Each factor has no repeated roots, and the factors are pairwise relatively prime.")) (|gcd| (($ $ $) "\\spad{gcd(p,q)} computes the greatest-common-divisor of \\spad{p} and \\spad{q.}"))) 
 NIL 
 NIL 
-(-1238 |Coef1| |Coef2| |var1| |var2| |cen1| |cen2|) 
+(-1259 |Coef1| |Coef2| |var1| |var2| |cen1| |cen2|) 
 ((|constructor| (NIL "Mapping package for univariate Puiseux series. This package allows one to apply a function to the coefficients of a univariate Puiseux series.")) (|map| (((|UnivariatePuiseuxSeries| |#2| |#4| |#6|) (|Mapping| |#2| |#1|) (|UnivariatePuiseuxSeries| |#1| |#3| |#5|)) "\\spad{map(f,g(x))} applies the map \\spad{f} to the coefficients of the Puiseux series \\spad{g(x)}."))) 
 NIL 
 NIL 
-(-1239 |Coef|) 
+(-1260 |Coef|) 
 ((|constructor| (NIL "\\spadtype{UnivariatePuiseuxSeriesCategory} is the category of Puiseux series in one variable.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(f(x),y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $ (|Symbol|)) "\\spad{integrate(f(x),var)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{var}.") (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 1. We may integrate a series when we can divide coefficients by rational numbers.")) (|multiplyExponents| (($ $ (|Fraction| (|Integer|))) "\\spad{multiplyExponents(f,r)} multiplies all exponents of the power series \\spad{f} by the positive rational number \\spad{r.}")) (|series| (($ (|NonNegativeInteger|) (|Stream| (|Record| (|:| |k| (|Fraction| (|Integer|))) (|:| |c| |#1|)))) "\\spad{series(n,st)} creates a series from a common denomiator and a stream of non-zero terms, where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents and \\spad{n} should be a common denominator for the exponents in the stream of terms."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1240 S |Coef| ULS) 
+(-1261 S |Coef| ULS) 
 ((|constructor| (NIL "This is a category of univariate Puiseux series constructed from univariate Laurent series. A Puiseux series is represented by a pair \\spad{[r,f(x)]}, where \\spad{r} is a positive rational number and \\spad{f(x)} is a Laurent series. This pair represents the Puiseux series \\spad{f(x^r)}.")) (|laurentIfCan| (((|Union| |#3| "failed") $) "\\spad{laurentIfCan(f(x))} converts the Puiseux series \\spad{f(x)} to a Laurent series if possible. If this is not possible, \"failed\" is returned.")) (|laurent| ((|#3| $) "\\spad{laurent(f(x))} converts the Puiseux series \\spad{f(x)} to a Laurent series if possible. Error: if this is not possible.")) (|coerce| (($ |#3|) "\\spad{coerce(f(x))} converts the Laurent series \\spad{f(x)} to a Puiseux series.")) (|degree| (((|Fraction| (|Integer|)) $) "\\spad{degree(f(x))} returns the degree of the leading term of the Puiseux series \\spad{f(x)}, which may have zero as a coefficient.")) (|laurentRep| ((|#3| $) "\\spad{laurentRep(f(x))} returns \\spad{g(x)} where the Puiseux series \\spad{f(x) = g(x^r)} is represented by \\spad{[r,g(x)]}.")) (|rationalPower| (((|Fraction| (|Integer|)) $) "\\spad{rationalPower(f(x))} returns \\spad{r} where the Puiseux series \\spad{f(x) = g(x^r)}.")) (|puiseux| (($ (|Fraction| (|Integer|)) |#3|) "\\spad{puiseux(r,f(x))} returns \\spad{f(x^r)}."))) 
 NIL 
 NIL 
-(-1241 |Coef| ULS) 
+(-1262 |Coef| ULS) 
 ((|constructor| (NIL "This is a category of univariate Puiseux series constructed from univariate Laurent series. A Puiseux series is represented by a pair \\spad{[r,f(x)]}, where \\spad{r} is a positive rational number and \\spad{f(x)} is a Laurent series. This pair represents the Puiseux series \\spad{f(x^r)}.")) (|laurentIfCan| (((|Union| |#2| "failed") $) "\\spad{laurentIfCan(f(x))} converts the Puiseux series \\spad{f(x)} to a Laurent series if possible. If this is not possible, \"failed\" is returned.")) (|laurent| ((|#2| $) "\\spad{laurent(f(x))} converts the Puiseux series \\spad{f(x)} to a Laurent series if possible. Error: if this is not possible.")) (|coerce| (($ |#2|) "\\spad{coerce(f(x))} converts the Laurent series \\spad{f(x)} to a Puiseux series.")) (|degree| (((|Fraction| (|Integer|)) $) "\\spad{degree(f(x))} returns the degree of the leading term of the Puiseux series \\spad{f(x)}, which may have zero as a coefficient.")) (|laurentRep| ((|#2| $) "\\spad{laurentRep(f(x))} returns \\spad{g(x)} where the Puiseux series \\spad{f(x) = g(x^r)} is represented by \\spad{[r,g(x)]}.")) (|rationalPower| (((|Fraction| (|Integer|)) $) "\\spad{rationalPower(f(x))} returns \\spad{r} where the Puiseux series \\spad{f(x) = g(x^r)}.")) (|puiseux| (($ (|Fraction| (|Integer|)) |#2|) "\\spad{puiseux(r,f(x))} returns \\spad{f(x^r)}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1242 |Coef| ULS) 
+(-1263 |Coef| ULS) 
 ((|constructor| (NIL "This package enables one to construct a univariate Puiseux series domain from a univariate Laurent series domain. Univariate Puiseux series are represented by a pair \\spad{[r,f(x)]}, where \\spad{r} is a positive rational number and \\spad{f(x)} is a Laurent series. This pair represents the Puiseux series \\spad{f(x^r)}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|))))) (|HasCategory| (-413 (-572)) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-1243 |Coef| |var| |cen|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|))))) (|HasCategory| (-433 (-592)) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-1264 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Dense Puiseux series in one variable")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Puiseux series."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4600 |has| |#1| (-368)) (-4594 |has| |#1| (-368)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572))) (|devaluate| |#1|))))) (|HasCategory| (-413 (-572)) (QUOTE (-1110))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (-1841 (|HasCategory| |#1| (QUOTE (-368))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-1244 R FE |var| |cen|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4623 |has| |#1| (-388)) (-4617 |has| |#1| (-388)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592))) (|devaluate| |#1|))))) (|HasCategory| (-433 (-592)) (QUOTE (-1131))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (-3836 (|HasCategory| |#1| (QUOTE (-388))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-1265 R FE |var| |cen|) 
 ((|constructor| (NIL "UnivariatePuiseuxSeriesWithExponentialSingularity is a domain used to represent functions with essential singularities. Objects in this domain are sums, where each term in the sum is a univariate Puiseux series times the exponential of a univariate Puiseux series. Thus, the elements of this domain are sums of expressions of the form \\spad{g(x) * exp(f(x))}, where g(x) is a univariate Puiseux series and f(x) is a univariate Puiseux series with no terms of non-negative degree.")) (|dominantTerm| (((|Union| (|Record| (|:| |%term| (|Record| (|:| |%coef| (|UnivariatePuiseuxSeries| |#2| |#3| |#4|)) (|:| |%expon| (|ExponentialOfUnivariatePuiseuxSeries| |#2| |#3| |#4|)) (|:| |%expTerms| (|List| (|Record| (|:| |k| (|Fraction| (|Integer|))) (|:| |c| |#2|)))))) (|:| |%type| (|String|))) "failed") $) "\\spad{dominantTerm(f(var))} returns the term that dominates the limiting behavior of \\spad{f(var)} as \\spad{var \\spad{->} cen+} together with a \\spadtype{String} which briefly describes that behavior. The value of the \\spadtype{String} will be \\spad{\"zero\"} (resp. \\spad{\"infinity\"}) if the term tends to zero (resp. infinity) exponentially and will \\spad{\"series\"} if the term is a Puiseux series.")) (|limitPlus| (((|Union| (|OrderedCompletion| |#2|) "failed") $) "\\spad{limitPlus(f(var))} returns \\spad{limit(var \\spad{->} cen+,f(var))}."))) 
-(((-4604 "*") |has| (-1243 |#2| |#3| |#4|) (-174)) (-4595 |has| (-1243 |#2| |#3| |#4|) (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| (-1243 |#2| |#3| |#4|) (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-1243 |#2| |#3| |#4|) (QUOTE (-149))) (|HasCategory| (-1243 |#2| |#3| |#4|) (QUOTE (-151))) (|HasCategory| (-1243 |#2| |#3| |#4|) (QUOTE (-174))) (|HasCategory| (-1243 |#2| |#3| |#4|) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-1243 |#2| |#3| |#4|) (LIST (QUOTE -1044) (QUOTE (-572)))) (|HasCategory| (-1243 |#2| |#3| |#4|) (QUOTE (-368))) (|HasCategory| (-1243 |#2| |#3| |#4|) (QUOTE (-457))) (-1841 (|HasCategory| (-1243 |#2| |#3| |#4|) (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| (-1243 |#2| |#3| |#4|) (LIST (QUOTE -1044) (LIST (QUOTE -413) (QUOTE (-572)))))) (|HasCategory| (-1243 |#2| |#3| |#4|) (QUOTE (-562)))) 
-(-1245 A S) 
+(((-4627 "*") |has| (-1264 |#2| |#3| |#4|) (-194)) (-4618 |has| (-1264 |#2| |#3| |#4|) (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| (-1264 |#2| |#3| |#4|) (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-1264 |#2| |#3| |#4|) (QUOTE (-169))) (|HasCategory| (-1264 |#2| |#3| |#4|) (QUOTE (-171))) (|HasCategory| (-1264 |#2| |#3| |#4|) (QUOTE (-194))) (|HasCategory| (-1264 |#2| |#3| |#4|) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-1264 |#2| |#3| |#4|) (LIST (QUOTE -1065) (QUOTE (-592)))) (|HasCategory| (-1264 |#2| |#3| |#4|) (QUOTE (-388))) (|HasCategory| (-1264 |#2| |#3| |#4|) (QUOTE (-477))) (-3836 (|HasCategory| (-1264 |#2| |#3| |#4|) (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| (-1264 |#2| |#3| |#4|) (LIST (QUOTE -1065) (LIST (QUOTE -433) (QUOTE (-592)))))) (|HasCategory| (-1264 |#2| |#3| |#4|) (QUOTE (-582)))) 
+(-1266 A S) 
 ((|constructor| (NIL "A unary-recursive aggregate is a one where nodes may have either 0 or 1 children. This aggregate models, though not precisely, a linked list possibly with a single cycle. A node with one children models a non-empty list, with the \\spadfun{value} of the list designating the head, or \\spadfun{first}, of the list, and the child designating the tail, or \\spadfun{rest}, of the list. A node with no child then designates the empty list. Since these aggregates are recursive aggregates, they may be cyclic.")) (|split!| (($ $ (|Integer|)) "\\spad{split!(u,n)} splits \\spad{u} into two aggregates: \\axiom{v = rest(u,n)} and \\axiom{w = first(u,n)}, returning \\axiom{v}. Note that afterwards \\axiom{rest(u,n)} returns \\axiom{empty()}.")) (|setlast!| ((|#2| $ |#2|) "\\spad{setlast!(u,x)} destructively changes the last element of \\spad{u} to \\spad{x.}")) (|setrest!| (($ $ $) "\\spad{setrest!(u,v)} destructively changes the rest of \\spad{u} to \\spad{v.}")) (|setelt| ((|#2| $ "last" |#2|) "\\spad{setelt(u,\"last\",x)} (also written: \\axiom{u.last \\spad{:=} \\spad{b})} is equivalent to \\axiom{setlast!(u,v)}.") (($ $ "rest" $) "\\spad{setelt(u,\"rest\",v)} (also written: \\axiom{u.rest \\spad{:=} \\spad{v})} is equivalent to \\axiom{setrest!(u,v)}.") ((|#2| $ "first" |#2|) "\\spad{setelt(u,\"first\",x)} (also written: \\axiom{u.first \\spad{:=} \\spad{x})} is equivalent to \\axiom{setfirst!(u,x)}.")) (|setfirst!| ((|#2| $ |#2|) "\\spad{setfirst!(u,x)} destructively changes the first element of a to \\spad{x.}")) (|cycleSplit!| (($ $) "\\spad{cycleSplit!(u)} splits the aggregate by dropping off the cycle. The value returned is the cycle entry, or nil if none exists. For example, if \\axiom{w = concat(u,v)} is the cyclic list where \\spad{v} is the head of the cycle, \\axiom{cycleSplit!(w)} will drop \\spad{v} off \\spad{w} thus destructively changing \\spad{w} to u, and returning \\spad{v.}")) (|concat!| (($ $ |#2|) "\\spad{concat!(u,x)} destructively adds element \\spad{x} to the end of u. Note that \\axiom{concat!(a,x) = setlast!(a,[x])}.") (($ $ $) "\\spad{concat!(u,v)} destructively concatenates \\spad{v} to the end of u. Note that \\axiom{concat!(u,v) = setlast_!(u,v)}.")) (|cycleTail| (($ $) "\\spad{cycleTail(u)} returns the last node in the cycle, or empty if none exists.")) (|cycleLength| (((|NonNegativeInteger|) $) "\\spad{cycleLength(u)} returns the length of a top-level cycle contained in aggregate u, or 0 is \\spad{u} has no such cycle.")) (|cycleEntry| (($ $) "\\spad{cycleEntry(u)} returns the head of a top-level cycle contained in aggregate u, or \\axiom{empty()} if none exists.")) (|third| ((|#2| $) "\\spad{third(u)} returns the third element of u. Note that \\axiom{third(u) = first(rest(rest(u)))}.")) (|second| ((|#2| $) "\\spad{second(u)} returns the second element of u. Note that \\axiom{second(u) = first(rest(u))}.")) (|tail| (($ $) "\\spad{tail(u)} returns the last node of u. Note that if \\spad{u} is \\axiom{shallowlyMutable}, \\axiom{setrest(tail(u),v) = concat(u,v)}.")) (|last| (($ $ (|NonNegativeInteger|)) "\\spad{last(u,n)} returns a copy of the last \\spad{n} (\\axiom{n \\spad{>=} 0}) nodes of u. Note that \\axiom{last(u,n)} is a list of \\spad{n} elements.") ((|#2| $) "\\spad{last(u)} resturn the last element of u. Note that for lists, \\axiom{last(u)=u . (maxIndex u)=u . \\spad{(#} \\spad{u} - 1)}.")) (|rest| (($ $ (|NonNegativeInteger|)) "\\spad{rest(u,n)} returns the \\axiom{n}th \\spad{(n} \\spad{>=} 0) node of u. Note that \\axiom{rest(u,0) = u}.") (($ $) "\\spad{rest(u)} returns an aggregate consisting of all but the first element of \\spad{u} (equivalently, the next node of u).")) (|elt| ((|#2| $ "last") "\\spad{elt(u,\"last\")} (also written: \\axiom{u . last}) is equivalent to last u.") (($ $ "rest") "\\spad{elt(\\%,\"rest\")} (also written: \\axiom{u.rest}) is equivalent to \\axiom{rest u}.") ((|#2| $ "first") "\\spad{elt(u,\"first\")} (also written: \\axiom{u . first}) is equivalent to first u.")) (|first| (($ $ (|NonNegativeInteger|)) "\\spad{first(u,n)} returns a copy of the first \\spad{n} (\\axiom{n \\spad{>=} 0}) elements of u.") ((|#2| $) "\\spad{first(u)} returns the first element of \\spad{u} (equivalently, the value at the current node).")) (|concat| (($ |#2| $) "\\spad{concat(x,u)} returns aggregate consisting of \\spad{x} followed by the elements of u. Note that if \\axiom{v = concat(x,u)} then \\axiom{x = first \\spad{v}} and \\axiom{u = rest \\spad{v}.}") (($ $ $) "\\spad{concat(u,v)} returns an aggregate \\spad{w} consisting of the elements of \\spad{u} followed by the elements of \\spad{v.} Note that \\axiom{v = rest(w,\\#a)}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4603))) 
-(-1246 S) 
+((|HasAttribute| |#1| (QUOTE -4626))) 
+(-1267 S) 
 ((|constructor| (NIL "A unary-recursive aggregate is a one where nodes may have either 0 or 1 children. This aggregate models, though not precisely, a linked list possibly with a single cycle. A node with one children models a non-empty list, with the \\spadfun{value} of the list designating the head, or \\spadfun{first}, of the list, and the child designating the tail, or \\spadfun{rest}, of the list. A node with no child then designates the empty list. Since these aggregates are recursive aggregates, they may be cyclic.")) (|split!| (($ $ (|Integer|)) "\\spad{split!(u,n)} splits \\spad{u} into two aggregates: \\axiom{v = rest(u,n)} and \\axiom{w = first(u,n)}, returning \\axiom{v}. Note that afterwards \\axiom{rest(u,n)} returns \\axiom{empty()}.")) (|setlast!| ((|#1| $ |#1|) "\\spad{setlast!(u,x)} destructively changes the last element of \\spad{u} to \\spad{x.}")) (|setrest!| (($ $ $) "\\spad{setrest!(u,v)} destructively changes the rest of \\spad{u} to \\spad{v.}")) (|setelt| ((|#1| $ "last" |#1|) "\\spad{setelt(u,\"last\",x)} (also written: \\axiom{u.last \\spad{:=} \\spad{b})} is equivalent to \\axiom{setlast!(u,v)}.") (($ $ "rest" $) "\\spad{setelt(u,\"rest\",v)} (also written: \\axiom{u.rest \\spad{:=} \\spad{v})} is equivalent to \\axiom{setrest!(u,v)}.") ((|#1| $ "first" |#1|) "\\spad{setelt(u,\"first\",x)} (also written: \\axiom{u.first \\spad{:=} \\spad{x})} is equivalent to \\axiom{setfirst!(u,x)}.")) (|setfirst!| ((|#1| $ |#1|) "\\spad{setfirst!(u,x)} destructively changes the first element of a to \\spad{x.}")) (|cycleSplit!| (($ $) "\\spad{cycleSplit!(u)} splits the aggregate by dropping off the cycle. The value returned is the cycle entry, or nil if none exists. For example, if \\axiom{w = concat(u,v)} is the cyclic list where \\spad{v} is the head of the cycle, \\axiom{cycleSplit!(w)} will drop \\spad{v} off \\spad{w} thus destructively changing \\spad{w} to u, and returning \\spad{v.}")) (|concat!| (($ $ |#1|) "\\spad{concat!(u,x)} destructively adds element \\spad{x} to the end of u. Note that \\axiom{concat!(a,x) = setlast!(a,[x])}.") (($ $ $) "\\spad{concat!(u,v)} destructively concatenates \\spad{v} to the end of u. Note that \\axiom{concat!(u,v) = setlast_!(u,v)}.")) (|cycleTail| (($ $) "\\spad{cycleTail(u)} returns the last node in the cycle, or empty if none exists.")) (|cycleLength| (((|NonNegativeInteger|) $) "\\spad{cycleLength(u)} returns the length of a top-level cycle contained in aggregate u, or 0 is \\spad{u} has no such cycle.")) (|cycleEntry| (($ $) "\\spad{cycleEntry(u)} returns the head of a top-level cycle contained in aggregate u, or \\axiom{empty()} if none exists.")) (|third| ((|#1| $) "\\spad{third(u)} returns the third element of u. Note that \\axiom{third(u) = first(rest(rest(u)))}.")) (|second| ((|#1| $) "\\spad{second(u)} returns the second element of u. Note that \\axiom{second(u) = first(rest(u))}.")) (|tail| (($ $) "\\spad{tail(u)} returns the last node of u. Note that if \\spad{u} is \\axiom{shallowlyMutable}, \\axiom{setrest(tail(u),v) = concat(u,v)}.")) (|last| (($ $ (|NonNegativeInteger|)) "\\spad{last(u,n)} returns a copy of the last \\spad{n} (\\axiom{n \\spad{>=} 0}) nodes of u. Note that \\axiom{last(u,n)} is a list of \\spad{n} elements.") ((|#1| $) "\\spad{last(u)} resturn the last element of u. Note that for lists, \\axiom{last(u)=u . (maxIndex u)=u . \\spad{(#} \\spad{u} - 1)}.")) (|rest| (($ $ (|NonNegativeInteger|)) "\\spad{rest(u,n)} returns the \\axiom{n}th \\spad{(n} \\spad{>=} 0) node of u. Note that \\axiom{rest(u,0) = u}.") (($ $) "\\spad{rest(u)} returns an aggregate consisting of all but the first element of \\spad{u} (equivalently, the next node of u).")) (|elt| ((|#1| $ "last") "\\spad{elt(u,\"last\")} (also written: \\axiom{u . last}) is equivalent to last u.") (($ $ "rest") "\\spad{elt(\\%,\"rest\")} (also written: \\axiom{u.rest}) is equivalent to \\axiom{rest u}.") ((|#1| $ "first") "\\spad{elt(u,\"first\")} (also written: \\axiom{u . first}) is equivalent to first u.")) (|first| (($ $ (|NonNegativeInteger|)) "\\spad{first(u,n)} returns a copy of the first \\spad{n} (\\axiom{n \\spad{>=} 0}) elements of u.") ((|#1| $) "\\spad{first(u)} returns the first element of \\spad{u} (equivalently, the value at the current node).")) (|concat| (($ |#1| $) "\\spad{concat(x,u)} returns aggregate consisting of \\spad{x} followed by the elements of u. Note that if \\axiom{v = concat(x,u)} then \\axiom{x = first \\spad{v}} and \\axiom{u = rest \\spad{v}.}") (($ $ $) "\\spad{concat(u,v)} returns an aggregate \\spad{w} consisting of the elements of \\spad{u} followed by the elements of \\spad{v.} Note that \\axiom{v = rest(w,\\#a)}."))) 
-((-3389 . T)) 
+((-2623 . T)) 
 NIL 
-(-1247 |Coef1| |Coef2| UTS1 UTS2) 
+(-1268 |Coef1| |Coef2| UTS1 UTS2) 
 ((|constructor| (NIL "Mapping package for univariate Taylor series. This package allows one to apply a function to the coefficients of a univariate Taylor series.")) (|map| ((|#4| (|Mapping| |#2| |#1|) |#3|) "\\spad{map(f,g(x))} applies the map \\spad{f} to the coefficients of \\indented{1}{the Taylor series \\spad{g(x)}.}"))) 
 NIL 
 NIL 
-(-1248 S |Coef|) 
+(-1269 S |Coef|) 
 ((|constructor| (NIL "\\spadtype{UnivariateTaylorSeriesCategory} is the category of Taylor series in one variable.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(f(x),y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $ (|Symbol|)) "\\spad{integrate(f(x),y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (** (($ $ |#2|) "\\spad{f(x) \\spad{**} a} computes a power of a power series. When the coefficient ring is a field, we may raise a series to an exponent from the coefficient ring provided that the constant coefficient of the series is 1.")) (|polynomial| (((|Polynomial| |#2|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{polynomial(f,k1,k2)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 \\spad{<=} \\spad{d} \\spad{<=} k2}.") (((|Polynomial| |#2|) $ (|NonNegativeInteger|)) "\\spad{polynomial(f,k)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{<= \\spad{k}.}")) (|multiplyCoefficients| (($ (|Mapping| |#2| (|Integer|)) $) "\\spad{multiplyCoefficients(f,sum(n = 0..infinity,a[n] * x**n))} returns \\spad{sum(n = 0..infinity,f(n) * a[n] * x**n)}. This function is used when Laurent series are represented by a Taylor series and an order.")) (|quoByVar| (($ $) "\\spad{quoByVar(a0 + \\spad{a1} \\spad{x} + \\spad{a2} \\spad{x**2} + ...)} returns \\spad{a1 + \\spad{a2} \\spad{x} + \\spad{a3} \\spad{x**2} + ...} Thus, this function substracts the constant term and divides by the series variable. This function is used when Laurent series are represented by a Taylor series and an order.")) (|coefficients| (((|Stream| |#2|) $) "\\spad{coefficients(a0 + \\spad{a1} \\spad{x} + \\spad{a2} \\spad{x**2} + ...)} returns a stream of coefficients: \\spad{[a0,a1,a2,...]}. The entries of the stream may be zero.")) (|series| (($ (|Stream| |#2|)) "\\spad{series([a0,a1,a2,...])} is the Taylor series \\spad{a0 + \\spad{a1} \\spad{x} + \\spad{a2} \\spad{x**2} + ...}.") (($ (|Stream| (|Record| (|:| |k| (|NonNegativeInteger|)) (|:| |c| |#2|)))) "\\spad{series(st)} creates a series from a stream of non-zero terms, where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#2| (QUOTE (-966))) (|HasCategory| |#2| (QUOTE (-1190))) (|HasSignature| |#2| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#2|)))) (|HasSignature| |#2| (LIST (QUOTE -2774) (LIST (|devaluate| |#2|) (|devaluate| |#2|) (QUOTE (-1170))))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#2| (QUOTE (-368)))) 
-(-1249 |Coef|) 
+((|HasCategory| |#2| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#2| (QUOTE (-987))) (|HasCategory| |#2| (QUOTE (-1211))) (|HasSignature| |#2| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#2|)))) (|HasSignature| |#2| (LIST (QUOTE -3162) (LIST (|devaluate| |#2|) (|devaluate| |#2|) (QUOTE (-1191))))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#2| (QUOTE (-388)))) 
+(-1270 |Coef|) 
 ((|constructor| (NIL "\\spadtype{UnivariateTaylorSeriesCategory} is the category of Taylor series in one variable.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(f(x),y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $ (|Symbol|)) "\\spad{integrate(f(x),y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (** (($ $ |#1|) "\\spad{f(x) \\spad{**} a} computes a power of a power series. When the coefficient ring is a field, we may raise a series to an exponent from the coefficient ring provided that the constant coefficient of the series is 1.")) (|polynomial| (((|Polynomial| |#1|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{polynomial(f,k1,k2)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 \\spad{<=} \\spad{d} \\spad{<=} k2}.") (((|Polynomial| |#1|) $ (|NonNegativeInteger|)) "\\spad{polynomial(f,k)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{<= \\spad{k}.}")) (|multiplyCoefficients| (($ (|Mapping| |#1| (|Integer|)) $) "\\spad{multiplyCoefficients(f,sum(n = 0..infinity,a[n] * x**n))} returns \\spad{sum(n = 0..infinity,f(n) * a[n] * x**n)}. This function is used when Laurent series are represented by a Taylor series and an order.")) (|quoByVar| (($ $) "\\spad{quoByVar(a0 + \\spad{a1} \\spad{x} + \\spad{a2} \\spad{x**2} + ...)} returns \\spad{a1 + \\spad{a2} \\spad{x} + \\spad{a3} \\spad{x**2} + ...} Thus, this function substracts the constant term and divides by the series variable. This function is used when Laurent series are represented by a Taylor series and an order.")) (|coefficients| (((|Stream| |#1|) $) "\\spad{coefficients(a0 + \\spad{a1} \\spad{x} + \\spad{a2} \\spad{x**2} + ...)} returns a stream of coefficients: \\spad{[a0,a1,a2,...]}. The entries of the stream may be zero.")) (|series| (($ (|Stream| |#1|)) "\\spad{series([a0,a1,a2,...])} is the Taylor series \\spad{a0 + \\spad{a1} \\spad{x} + \\spad{a2} \\spad{x**2} + ...}.") (($ (|Stream| (|Record| (|:| |k| (|NonNegativeInteger|)) (|:| |c| |#1|)))) "\\spad{series(st)} creates a series from a stream of non-zero terms, where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1250 |Coef| |var| |cen|) 
+(-1271 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Dense Taylor series in one variable \\spadtype{UnivariateTaylorSeries} is a domain representing Taylor series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring, the power series variable, and the center of the power series expansion. For example, \\spadtype{UnivariateTaylorSeries}(Integer,x,3) represents Taylor series in \\spad{(x - 3)} with \\spadtype{Integer} coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x),x)} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|invmultisect| (($ (|Integer|) (|Integer|) $) "\\spad{invmultisect(a,b,f(x))} substitutes \\spad{x^((a+b)*n)} \\indented{1}{for \\spad{x^n} and multiples by \\spad{x^b}.}")) (|multisect| (($ (|Integer|) (|Integer|) $) "\\spad{multisect(a,b,f(x))} selects the coefficients of \\indented{1}{\\spad{x^((a+b)*n+a)}, and changes this monomial to \\spad{x^n}.}")) (|revert| (($ $) "\\spad{revert(f(x))} returns a Taylor series \\spad{g(x)} such that \\spad{f(g(x)) = g(f(x)) = \\spad{x}.} Series \\spad{f(x)} should have constant coefficient 0 and 1st order coefficient 1.")) (|generalLambert| (($ $ (|Integer|) (|Integer|)) "\\spad{generalLambert(f(x),a,d)} returns \\spad{f(x^a) + f(x^(a + \\spad{d))} + \\indented{1}{f(x^(a + 2 \\spad{d))} + \\spad{...} \\spad{}.} \\spad{f(x)} should have zero constant} \\indented{1}{coefficient and \\spad{a} and \\spad{d} should be positive.}")) (|evenlambert| (($ $) "\\spad{evenlambert(f(x))} returns \\spad{f(x^2) + f(x^4) + f(x^6) + ...}. \\indented{1}{\\spad{f(x)} should have a zero constant coefficient.} \\indented{1}{This function is used for computing infinite products.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1, then} \\indented{1}{\\spad{product(n=1..infinity,f(x^(2*n))) = exp(log(evenlambert(f(x))))}.}")) (|oddlambert| (($ $) "\\spad{oddlambert(f(x))} returns \\spad{f(x) + f(x^3) + f(x^5) + ...}. \\indented{1}{\\spad{f(x)} should have a zero constant coefficient.} \\indented{1}{This function is used for computing infinite products.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1, then} \\indented{1}{\\spad{product(n=1..infinity,f(x^(2*n-1)))=exp(log(oddlambert(f(x))))}.}")) (|lambert| (($ $) "\\spad{lambert(f(x))} returns \\spad{f(x) + f(x^2) + f(x^3) + ...}. \\indented{1}{This function is used for computing infinite products.} \\indented{1}{\\spad{f(x)} should have zero constant coefficient.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1, then} \\indented{1}{\\spad{product(n = 1..infinity,f(x^n)) = exp(log(lambert(f(x))))}.}")) (|lagrange| (($ $) "\\spad{lagrange(g(x))} produces the Taylor series for \\spad{f(x)} \\indented{1}{where \\spad{f(x)} is implicitly defined as \\spad{f(x) = x*g(f(x))}.}")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),x)} computes the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|univariatePolynomial| (((|UnivariatePolynomial| |#2| |#1|) $ (|NonNegativeInteger|)) "\\spad{univariatePolynomial(f,k)} returns a univariate polynomial \\indented{1}{consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.}")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a \\indented{1}{Taylor series.}") (($ (|UnivariatePolynomial| |#2| |#1|)) "\\spad{coerce(p)} converts a univariate polynomial \\spad{p} in the variable \\spad{var} to a univariate Taylor series in \\spad{var}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-769)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-769)) (|devaluate| |#1|))))) (|HasCategory| (-769) (QUOTE (-1110))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-769))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-769))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-1251 |Coef| UTS) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-790)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-790)) (|devaluate| |#1|))))) (|HasCategory| (-790) (QUOTE (-1131))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-790))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-790))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-1272 |Coef| UTS) 
 ((|constructor| (NIL "Taylor series solutions of explicit ODE's. This package provides Taylor series solutions to regular linear or non-linear ordinary differential equations of arbitrary order.")) (|mpsode| (((|List| |#2|) (|List| |#1|) (|List| (|Mapping| |#2| (|List| |#2|)))) "\\spad{mpsode(r,f)} solves the system of differential equations \\spad{dy[i]/dx =f[i] [x,y[1],y[2],...,y[n]]}, \\spad{y[i](a) = r[i]} for \\spad{i} in 1..n.")) (|ode| ((|#2| (|Mapping| |#2| (|List| |#2|)) (|List| |#1|)) "\\spad{ode(f,cl)} is the solution to \\spad{y<n>=f(y,y',..,y<n-1>)} such that \\spad{y<i>(a) = cl.i} for \\spad{i} in 1..n.")) (|ode2| ((|#2| (|Mapping| |#2| |#2| |#2|) |#1| |#1|) "\\spad{ode2(f,c0,c1)} is the solution to \\spad{y'' = f(y,y')} such that \\spad{y(a) = \\spad{c0}} and \\spad{y'(a) = c1}.")) (|ode1| ((|#2| (|Mapping| |#2| |#2|) |#1|) "\\spad{ode1(f,c)} is the solution to \\spad{y' = f(y)} such that \\spad{y(a) = \\spad{c}.}")) (|fixedPointExquo| ((|#2| |#2| |#2|) "\\spad{fixedPointExquo(f,g)} computes the exact quotient of \\spad{f} and \\spad{g} using a fixed point computation.")) (|stFuncN| (((|Mapping| (|Stream| |#1|) (|List| (|Stream| |#1|))) (|Mapping| |#2| (|List| |#2|))) "\\spad{stFuncN(f)} is a local function xported due to compiler problem. This function is of no interest to the top-level user.")) (|stFunc2| (((|Mapping| (|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) (|Mapping| |#2| |#2| |#2|)) "\\spad{stFunc2(f)} is a local function exported due to compiler problem. This function is of no interest to the top-level user.")) (|stFunc1| (((|Mapping| (|Stream| |#1|) (|Stream| |#1|)) (|Mapping| |#2| |#2|)) "\\spad{stFunc1(f)} is a local function exported due to compiler problem. This function is of no interest to the top-level user."))) 
 NIL 
 NIL 
-(-1252 -3313 UP L UTS) 
+(-1273 -3958 UP L UTS) 
 ((|constructor| (NIL "\\spad{RUTSodetools} provides tools to interface with the series ODE solver when presented with linear ODEs.")) (RF2UTS ((|#4| (|Fraction| |#2|)) "\\spad{RF2UTS(f)} converts \\spad{f} to a Taylor series.")) (LODO2FUN (((|Mapping| |#4| (|List| |#4|)) |#3|) "\\spad{LODO2FUN(op)} returns the function to pass to the series ODE solver in order to solve \\spad{op \\spad{y} = 0}.")) (UTS2UP ((|#2| |#4| (|NonNegativeInteger|)) "\\spad{UTS2UP(s, \\spad{n)}} converts the first \\spad{n} terms of \\spad{s} to a univariate polynomial.")) (UP2UTS ((|#4| |#2|) "\\spad{UP2UTS(p)} converts \\spad{p} to a Taylor series."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-562)))) 
-(-1253 -3313 UTSF UTSSUPF) 
+((|HasCategory| |#1| (QUOTE (-582)))) 
+(-1274 -3958 UTSF UTSSUPF) 
 ((|constructor| (NIL "This package has no description"))) 
 NIL 
 NIL 
-(-1254 |Coef| |var|) 
+(-1275 |Coef| |var|) 
 ((|constructor| (NIL "Part of the Package for Algebraic Function Fields in one variable PAFF")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x),x)} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|invmultisect| (($ (|Integer|) (|Integer|) $) "\\spad{invmultisect(a,b,f(x))} substitutes \\spad{x^((a+b)*n)} \\indented{1}{for \\spad{x^n} and multiples by \\spad{x^b}.}")) (|multisect| (($ (|Integer|) (|Integer|) $) "\\spad{multisect(a,b,f(x))} selects the coefficients of \\indented{1}{\\spad{x^((a+b)*n+a)}, and changes this monomial to \\spad{x^n}.}")) (|revert| (($ $) "\\spad{revert(f(x))} returns a Taylor series \\spad{g(x)} such that \\spad{f(g(x)) = g(f(x)) = \\spad{x}.} Series \\spad{f(x)} should have constant coefficient 0 and 1st order coefficient 1.")) (|generalLambert| (($ $ (|Integer|) (|Integer|)) "\\spad{generalLambert(f(x),a,d)} returns \\spad{f(x^a) + f(x^(a + \\spad{d))} + \\indented{1}{f(x^(a + 2 \\spad{d))} + \\spad{...} \\spad{}.} \\spad{f(x)} should have zero constant} \\indented{1}{coefficient and \\spad{a} and \\spad{d} should be positive.}")) (|evenlambert| (($ $) "\\spad{evenlambert(f(x))} returns \\spad{f(x^2) + f(x^4) + f(x^6) + ...}. \\indented{1}{\\spad{f(x)} should have a zero constant coefficient.} \\indented{1}{This function is used for computing infinite products.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1, then} \\indented{1}{\\spad{product(n=1..infinity,f(x^(2*n)))=exp(log(evenlambert(f(x))))}.}")) (|oddlambert| (($ $) "\\spad{oddlambert(f(x))} returns \\spad{f(x) + f(x^3) + f(x^5) + ...}. \\indented{1}{\\spad{f(x)} should have a zero constant coefficient.} \\indented{1}{This function is used for computing infinite products.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1, then} \\indented{1}{\\spad{product(n=1..infinity,f(x^(2*n-1)))=exp(log(oddlambert(f(x))))}.}")) (|lambert| (($ $) "\\spad{lambert(f(x))} returns \\spad{f(x) + f(x^2) + f(x^3) + ...}. \\indented{1}{This function is used for computing infinite products.} \\indented{1}{\\spad{f(x)} should have zero constant coefficient.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1, then} \\indented{1}{\\spad{product(n = 1..infinity,f(x^n)) = exp(log(lambert(f(x))))}.}")) (|lagrange| (($ $) "\\spad{lagrange(g(x))} produces the Taylor series for \\spad{f(x)} \\indented{1}{where \\spad{f(x)} is implicitly defined as \\spad{f(x) = x*g(f(x))}.}")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),x)} computes the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|univariatePolynomial| (((|UnivariatePolynomial| |#2| |#1|) $ (|NonNegativeInteger|)) "\\spad{univariatePolynomial(f,k)} returns a univariate polynomial \\indented{1}{consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.}")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a \\indented{1}{Taylor series.}") (($ (|UnivariatePolynomial| |#2| |#1|)) "\\spad{coerce(p)} converts a univariate polynomial \\spad{p} in the variable \\spad{var} to a univariate Taylor series in \\spad{var}."))) 
-(((-4604 "*") |has| |#1| (-174)) (-4595 |has| |#1| (-562)) (-4596 . T) (-4597 . T) (-4599 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#1| (QUOTE (-174))) (-1841 (|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-562)))) (|HasCategory| |#1| (QUOTE (-149))) (|HasCategory| |#1| (QUOTE (-151))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-769)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -901) (QUOTE (-1170)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-769)) (|devaluate| |#1|))))) (|HasCategory| (-769) (QUOTE (-1110))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-769))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-769))))) (|HasSignature| |#1| (LIST (QUOTE -3972) (LIST (|devaluate| |#1|) (QUOTE (-1170)))))) (|HasCategory| |#1| (QUOTE (-368))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-572)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasCategory| |#1| (QUOTE (-966))) (|HasCategory| |#1| (QUOTE (-1190)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasSignature| |#1| (LIST (QUOTE -2774) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1170))))) (|HasSignature| |#1| (LIST (QUOTE -3456) (LIST (LIST (QUOTE -638) (QUOTE (-1170))) (|devaluate| |#1|))))))) 
-(-1255 |sym|) 
+(((-4627 "*") |has| |#1| (-194)) (-4618 |has| |#1| (-582)) (-4619 . T) (-4620 . T) (-4622 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#1| (QUOTE (-194))) (-3836 (|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-582)))) (|HasCategory| |#1| (QUOTE (-169))) (|HasCategory| |#1| (QUOTE (-171))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-790)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -922) (QUOTE (-1191)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-790)) (|devaluate| |#1|))))) (|HasCategory| (-790) (QUOTE (-1131))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-790))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-790))))) (|HasSignature| |#1| (LIST (QUOTE -1683) (LIST (|devaluate| |#1|) (QUOTE (-1191)))))) (|HasCategory| |#1| (QUOTE (-388))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-592)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasCategory| |#1| (QUOTE (-987))) (|HasCategory| |#1| (QUOTE (-1211)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasSignature| |#1| (LIST (QUOTE -3162) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1191))))) (|HasSignature| |#1| (LIST (QUOTE -4085) (LIST (LIST (QUOTE -658) (QUOTE (-1191))) (|devaluate| |#1|))))))) 
+(-1276 |sym|) 
 ((|constructor| (NIL "This domain implements variables")) (|variable| (((|Symbol|)) "\\spad{variable()} returns the symbol")) (|coerce| (((|Symbol|) $) "\\spad{coerce(x)} returns the symbol"))) 
 NIL 
 NIL 
-(-1256 S R) 
+(-1277 S R) 
 ((|constructor| (NIL "\\spadtype{VectorCategory} represents the type of vector like objects, that is, finite sequences indexed by some finite segment of the integers. The operations available on vectors depend on the structure of the underlying components. Many operations from the component domain are defined for vectors componentwise. It can by assumed that extraction or updating components can be done in constant time.")) (|magnitude| ((|#2| $) "\\spad{magnitude(v)} computes the sqrt(dot(v,v)), that is, the length")) (|length| ((|#2| $) "\\spad{length(v)} computes the sqrt(dot(v,v)), that is, the magnitude")) (|cross| (($ $ $) "\\spad{cross(u,v)} constructs the cross product of \\spad{u} and \\spad{v.} Error: if \\spad{u} and \\spad{v} are not of length 3.")) (|outerProduct| (((|Matrix| |#2|) $ $) "\\spad{outerProduct(u,v)} constructs the matrix whose (i,j)'th element is u(i)*v(j).")) (|dot| ((|#2| $ $) "\\spad{dot(x,y)} computes the inner product of the two vectors \\spad{x} and \\spad{y.} Error: if \\spad{x} and \\spad{y} are not of the same length.")) (* (($ $ |#2|) "\\spad{y * \\spad{r}} multiplies each component of the vector \\spad{y} by the element \\spad{r.}") (($ |#2| $) "\\spad{r * \\spad{y}} multiplies the element \\spad{r} times each component of the vector \\spad{y.}") (($ (|Integer|) $) "\\spad{n * \\spad{y}} multiplies each component of the vector \\spad{y} by the integer \\spad{n.}")) (- (($ $ $) "\\spad{x - \\spad{y}} returns the component-wise difference of the vectors \\spad{x} and \\spad{y.} Error: if \\spad{x} and \\spad{y} are not of the same length.") (($ $) "\\spad{-x} negates all components of the vector \\spad{x.}")) (|zero| (($ (|NonNegativeInteger|)) "\\spad{zero(n)} creates a zero vector of length \\spad{n.}")) (+ (($ $ $) "\\spad{x + \\spad{y}} returns the component-wise sum of the vectors \\spad{x} and \\spad{y.} Error: if \\spad{x} and \\spad{y} are not of the same length."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-1009))) (|HasCategory| |#2| (QUOTE (-1054))) (|HasCategory| |#2| (QUOTE (-722))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-25)))) 
-(-1257 R) 
+((|HasCategory| |#2| (QUOTE (-1030))) (|HasCategory| |#2| (QUOTE (-1075))) (|HasCategory| |#2| (QUOTE (-743))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-25)))) 
+(-1278 R) 
 ((|constructor| (NIL "\\spadtype{VectorCategory} represents the type of vector like objects, that is, finite sequences indexed by some finite segment of the integers. The operations available on vectors depend on the structure of the underlying components. Many operations from the component domain are defined for vectors componentwise. It can by assumed that extraction or updating components can be done in constant time.")) (|magnitude| ((|#1| $) "\\spad{magnitude(v)} computes the sqrt(dot(v,v)), that is, the length")) (|length| ((|#1| $) "\\spad{length(v)} computes the sqrt(dot(v,v)), that is, the magnitude")) (|cross| (($ $ $) "\\spad{cross(u,v)} constructs the cross product of \\spad{u} and \\spad{v.} Error: if \\spad{u} and \\spad{v} are not of length 3.")) (|outerProduct| (((|Matrix| |#1|) $ $) "\\spad{outerProduct(u,v)} constructs the matrix whose (i,j)'th element is u(i)*v(j).")) (|dot| ((|#1| $ $) "\\spad{dot(x,y)} computes the inner product of the two vectors \\spad{x} and \\spad{y.} Error: if \\spad{x} and \\spad{y} are not of the same length.")) (* (($ $ |#1|) "\\spad{y * \\spad{r}} multiplies each component of the vector \\spad{y} by the element \\spad{r.}") (($ |#1| $) "\\spad{r * \\spad{y}} multiplies the element \\spad{r} times each component of the vector \\spad{y.}") (($ (|Integer|) $) "\\spad{n * \\spad{y}} multiplies each component of the vector \\spad{y} by the integer \\spad{n.}")) (- (($ $ $) "\\spad{x - \\spad{y}} returns the component-wise difference of the vectors \\spad{x} and \\spad{y.} Error: if \\spad{x} and \\spad{y} are not of the same length.") (($ $) "\\spad{-x} negates all components of the vector \\spad{x.}")) (|zero| (($ (|NonNegativeInteger|)) "\\spad{zero(n)} creates a zero vector of length \\spad{n.}")) (+ (($ $ $) "\\spad{x + \\spad{y}} returns the component-wise sum of the vectors \\spad{x} and \\spad{y.} Error: if \\spad{x} and \\spad{y} are not of the same length."))) 
-((-4603 . T) (-4602 . T) (-3389 . T)) 
+((-4626 . T) (-4625 . T) (-2623 . T)) 
 NIL 
-(-1258 A B) 
+(-1279 A B) 
 ((|constructor| (NIL "This package provides operations which all take as arguments vectors of elements of some type \\spad{A} and functions from \\spad{A} to another of type \\spad{B.} The operations all iterate over their vector argument and either return a value of type \\spad{B} or a vector over \\spad{B.}")) (|map| (((|Union| (|Vector| |#2|) "failed") (|Mapping| (|Union| |#2| "failed") |#1|) (|Vector| |#1|)) "\\spad{map(f, \\spad{v)}} applies the function \\spad{f} to every element of the vector \\spad{v} producing a new vector containing the values or \\spad{\"failed\"}.") (((|Vector| |#2|) (|Mapping| |#2| |#1|) (|Vector| |#1|)) "\\spad{map(f, \\spad{v)}} applies the function \\spad{f} to every element of the vector \\spad{v} producing a new vector containing the values.")) (|reduce| ((|#2| (|Mapping| |#2| |#1| |#2|) (|Vector| |#1|) |#2|) "\\spad{reduce(func,vec,ident)} combines the elements in \\spad{vec} using the binary function func. Argument \\spad{ident} is returned if \\spad{vec} is empty.")) (|scan| (((|Vector| |#2|) (|Mapping| |#2| |#1| |#2|) (|Vector| |#1|) |#2|) "\\spad{scan(func,vec,ident)} creates a new vector whose elements are the result of applying reduce to the binary function func, increasing initial subsequences of the vector vec, and the element ident."))) 
 NIL 
 NIL 
-(-1259 R) 
+(-1280 R) 
 ((|constructor| (NIL "This type represents vector like objects with varying lengths and indexed by a finite segment of integers starting at 1.")) (|vector| (($ (|List| |#1|)) "\\spad{vector(l)} converts the list \\spad{l} to a vector."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#1| (QUOTE (-1098))) (|HasCategory| |#1| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#1| (QUOTE (-848))) (-1841 (|HasCategory| |#1| (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-1098)))) (|HasCategory| (-572) (QUOTE (-848))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-722))) (|HasCategory| |#1| (QUOTE (-1054))) (-12 (|HasCategory| |#1| (QUOTE (-1009))) (|HasCategory| |#1| (QUOTE (-1054)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))) (-1841 (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-848)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -305) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1098)))))) 
-(-1260) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#1| (QUOTE (-1119))) (|HasCategory| |#1| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#1| (QUOTE (-869))) (-3836 (|HasCategory| |#1| (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-1119)))) (|HasCategory| (-592) (QUOTE (-869))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-743))) (|HasCategory| |#1| (QUOTE (-1075))) (-12 (|HasCategory| |#1| (QUOTE (-1030))) (|HasCategory| |#1| (QUOTE (-1075)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))) (-3836 (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-869)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -325) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1119)))))) 
+(-1281) 
 ((|constructor| (NIL "TwoDimensionalViewport creates viewports to display graphs.")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(v)} returns the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport} as output of the domain \\spadtype{OutputForm}.")) (|key| (((|Integer|) $) "\\spad{key(v)} returns the process ID number of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}.")) (|reset| (((|Void|) $) "\\spad{reset(v)} sets the current state of the graph characteristics of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, back to their initial settings.")) (|write| (((|String|) $ (|String|) (|List| (|String|))) "\\spad{write(v,s,lf)} takes the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, and creates a directory indicated by \\spad{s,} which contains the graph data files for \\spad{v} and the optional file types indicated by the list \\spad{lf.}") (((|String|) $ (|String|) (|String|)) "\\spad{write(v,s,f)} takes the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, and creates a directory indicated by \\spad{s,} which contains the graph data files for \\spad{v} and an optional file type \\spad{f.}") (((|String|) $ (|String|)) "\\spad{write(v,s)} takes the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, and creates a directory indicated by \\spad{s,} which contains the graph data files for \\spad{v.}")) (|resize| (((|Void|) $ (|PositiveInteger|) (|PositiveInteger|)) "\\spad{resize(v,w,h)} displays the two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, with a width of \\spad{w} and a height of \\spad{h,} keeping the upper left-hand corner position unchanged.")) (|update| (((|Void|) $ (|GraphImage|) (|PositiveInteger|)) "\\spad{update(v,gr,n)} drops the graph \\spad{gr} in slot \\spad{n} of viewport \\spad{v}. The graph \\spad{gr} must have been transmitted already and acquired an integer key.")) (|move| (((|Void|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{move(v,x,y)} displays the two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, with the upper left-hand corner of the viewport window at the screen coordinate position \\spad{x,} \\spad{y.}")) (|show| (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{show(v,n,s)} displays the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, if \\spad{s} is \"on\", or does not display the graph if \\spad{s} is \"off\".")) (|translate| (((|Void|) $ (|PositiveInteger|) (|Float|) (|Float|)) "\\spad{translate(v,n,dx,dy)} displays the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, translated by \\spad{dx} in the x-coordinate direction from the center of the viewport, and by \\spad{dy} in the y-coordinate direction from the center. Setting \\spad{dx} and \\spad{dy} to \\spad{0} places the center of the graph at the center of the viewport.")) (|scale| (((|Void|) $ (|PositiveInteger|) (|Float|) (|Float|)) "\\spad{scale(v,n,sx,sy)} displays the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, scaled by the factor \\spad{sx} in the x-coordinate direction and by the factor \\spad{sy} in the y-coordinate direction.")) (|dimensions| (((|Void|) $ (|NonNegativeInteger|) (|NonNegativeInteger|) (|PositiveInteger|) (|PositiveInteger|)) "\\spad{dimensions(v,x,y,width,height)} sets the position of the upper left-hand corner of the two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, to the window coordinate \\spad{x,} \\spad{y,} and sets the dimensions of the window to that of \\spad{width}, \\spad{height}. The new dimensions are not displayed until the function \\spadfun{makeViewport2D} is executed again for \\spad{v.}")) (|close| (((|Void|) $) "\\spad{close(v)} closes the viewport window of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, and terminates the corresponding process ID.")) (|controlPanel| (((|Void|) $ (|String|)) "\\spad{controlPanel(v,s)} displays the control panel of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, if \\spad{s} is \"on\", or hides the control panel if \\spad{s} is \"off\".")) (|connect| (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{connect(v,n,s)} displays the lines connecting the graph points in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, if \\spad{s} is \"on\", or does not display the lines if \\spad{s} is \"off\".")) (|region| (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{region(v,n,s)} displays the bounding box of the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, if \\spad{s} is \"on\", or does not display the bounding box if \\spad{s} is \"off\".")) (|points| (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{points(v,n,s)} displays the points of the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, if \\spad{s} is \"on\", or does not display the points if \\spad{s} is \"off\".")) (|units| (((|Void|) $ (|PositiveInteger|) (|Palette|)) "\\spad{units(v,n,c)} displays the units of the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, with the units color set to the given palette color \\spad{c.}") (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{units(v,n,s)} displays the units of the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, if \\spad{s} is \"on\", or does not display the units if \\spad{s} is \"off\".")) (|axes| (((|Void|) $ (|PositiveInteger|) (|Palette|)) "\\spad{axes(v,n,c)} displays the axes of the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, with the axes color set to the given palette color \\spad{c.}") (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{axes(v,n,s)} displays the axes of the graph in field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, if \\spad{s} is \"on\", or does not display the axes if \\spad{s} is \"off\".")) (|getGraph| (((|GraphImage|) $ (|PositiveInteger|)) "\\spad{getGraph(v,n)} returns the graph which is of the domain \\spadtype{GraphImage} which is located in graph field \\spad{n} of the given two-dimensional viewport, \\spad{v,} which is of the domain \\spadtype{TwoDimensionalViewport}.")) (|putGraph| (((|Void|) $ (|GraphImage|) (|PositiveInteger|)) "\\spad{putGraph(v,gi,n)} sets the graph field indicated by \\spad{n,} of the indicated two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}, to be the graph, \\spad{gi} of domain \\spadtype{GraphImage}. The contents of viewport, \\spad{v,} will contain \\spad{gi} when the function \\spadfun{makeViewport2D} is called to create the an updated viewport \\spad{v.}")) (|title| (((|Void|) $ (|String|)) "\\spad{title(v,s)} changes the title which is shown in the two-dimensional viewport window, \\spad{v} of domain \\spadtype{TwoDimensionalViewport}.")) (|graphs| (((|Vector| (|Union| (|GraphImage|) "undefined")) $) "\\spad{graphs(v)} returns a vector, or list, which is a union of all the graphs, of the domain \\spadtype{GraphImage}, which are allocated for the two-dimensional viewport, \\spad{v,} of domain \\spadtype{TwoDimensionalViewport}. Those graphs which have no data are labeled \"undefined\", otherwise their contents are shown.")) (|graphStates| (((|Vector| (|Record| (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)) (|:| |points| (|Integer|)) (|:| |connect| (|Integer|)) (|:| |spline| (|Integer|)) (|:| |axes| (|Integer|)) (|:| |axesColor| (|Palette|)) (|:| |units| (|Integer|)) (|:| |unitsColor| (|Palette|)) (|:| |showing| (|Integer|)))) $) "\\spad{graphStates(v)} returns and shows a listing of a record containing the current state of the characteristics of each of the ten graph records in the given two-dimensional viewport, \\spad{v,} which is of domain \\spadtype{TwoDimensionalViewport}.")) (|graphState| (((|Void|) $ (|PositiveInteger|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Palette|) (|Integer|) (|Palette|) (|Integer|)) "\\spad{graphState(v,num,sX,sY,dX,dY,pts,lns,box,axes,axesC,un,unC,cP)} sets the state of the characteristics for the graph indicated by \\spad{num} in the given two-dimensional viewport \\spad{v,} of domain \\spadtype{TwoDimensionalViewport}, to the values given as parameters. The scaling of the graph in the \\spad{x} and \\spad{y} component directions is set to be \\spad{sX} and \\spad{sY}; the window translation in the \\spad{x} and \\spad{y} component directions is set to be \\spad{dX} and \\spad{dY}; The graph points, lines, bounding box, axes, or units will be shown in the viewport if their given parameters \\spad{pts}, \\spad{lns}, \\spad{box}, \\spad{axes} or \\spad{un} are set to be \\spad{1}, but will not be shown if they are set to \\spad{0}. The color of the \\spad{axes} and the color of the units are indicated by the palette colors \\spad{axesC} and \\spad{unC} respectively. To display the control panel when the viewport window is displayed, set \\spad{cP} to \\spad{1}, otherwise set it to \\spad{0}.")) (|options| (($ $ (|List| (|DrawOption|))) "\\spad{options(v,lopt)} takes the given two-dimensional viewport, \\spad{v,} of the domain \\spadtype{TwoDimensionalViewport} and returns \\spad{v} with it's draw options modified to be those which are indicated in the given list, \\spad{lopt} of domain \\spadtype{DrawOption}.") (((|List| (|DrawOption|)) $) "\\spad{options(v)} takes the given two-dimensional viewport, \\spad{v,} of the domain \\spadtype{TwoDimensionalViewport} and returns a list containing the draw options from the domain \\spadtype{DrawOption} for \\spad{v.}")) (|makeViewport2D| (($ (|GraphImage|) (|List| (|DrawOption|))) "\\spad{makeViewport2D(gi,lopt)} creates and displays a viewport window of the domain \\spadtype{TwoDimensionalViewport} whose graph field is assigned to be the given graph, \\spad{gi}, of domain \\spadtype{GraphImage}, and whose options field is set to be the list of options, \\spad{lopt} of domain \\spadtype{DrawOption}.") (($ $) "\\spad{makeViewport2D(v)} takes the given two-dimensional viewport, \\spad{v,} of the domain \\spadtype{TwoDimensionalViewport} and displays a viewport window on the screen which contains the contents of \\spad{v.}")) (|viewport2D| (($) "\\spad{viewport2D()} returns an undefined two-dimensional viewport of the domain \\spadtype{TwoDimensionalViewport} whose contents are empty.")) (|getPickedPoints| (((|List| (|Point| (|DoubleFloat|))) $) "\\spad{getPickedPoints(x)} returns a list of small floats for the points the user interactively picked on the viewport for full integration into the system, some design issues need to be addressed: \\spadignore{e.g.} how to go through the GraphImage interface, how to default to graphs, etc."))) 
 NIL 
 NIL 
-(-1261) 
+(-1282) 
 ((|constructor| (NIL "ThreeDimensionalViewport creates viewports to display graphs")) (|key| (((|Integer|) $) "\\spad{key(v)} returns the process ID number of the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}.")) (|close| (((|Void|) $) "\\spad{close(v)} closes the viewport window of the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, and terminates the corresponding process ID.")) (|write| (((|String|) $ (|String|) (|List| (|String|))) "\\spad{write(v,s,lf)} takes the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, and creates a directory indicated by \\spad{s,} which contains the graph data file for \\spad{v} and the optional file types indicated by the list \\spad{lf.}") (((|String|) $ (|String|) (|String|)) "\\spad{write(v,s,f)} takes the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, and creates a directory indicated by \\spad{s,} which contains the graph data file for \\spad{v} and an optional file type \\spad{f.}") (((|String|) $ (|String|)) "\\spad{write(v,s)} takes the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, and creates a directory indicated by \\spad{s,} which contains the graph data file for \\spad{v.}")) (|colorDef| (((|Void|) $ (|Color|) (|Color|)) "\\spad{colorDef(v,c1,c2)} sets the range of colors along the colormap so that the lower end of the colormap is defined by \\spad{c1} and the top end of the colormap is defined by \\spad{c2}, for the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}.")) (|reset| (((|Void|) $) "\\spad{reset(v)} sets the current state of the graph characteristics of the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, back to their initial settings.")) (|intensity| (((|Void|) $ (|Float|)) "\\spad{intensity(v,i)} sets the intensity of the light source to i, for the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}.")) (|lighting| (((|Void|) $ (|Float|) (|Float|) (|Float|)) "\\spad{lighting(v,x,y,z)} sets the position of the light source to the coordinates \\spad{x,} \\spad{y,} and \\spad{z} and displays the graph for the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}.")) (|clipSurface| (((|Void|) $ (|String|)) "\\spad{clipSurface(v,s)} displays the graph with the specified clipping region removed if \\spad{s} is \"on\", or displays the graph without clipping implemented if \\spad{s} is \"off\", for the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}.")) (|showClipRegion| (((|Void|) $ (|String|)) "\\spad{showClipRegion(v,s)} displays the clipping region of the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, if \\spad{s} is \"on\", or does not display the region if \\spad{s} is \"off\".")) (|showRegion| (((|Void|) $ (|String|)) "\\spad{showRegion(v,s)} displays the bounding box of the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, if \\spad{s} is \"on\", or does not display the box if \\spad{s} is \"off\".")) (|hitherPlane| (((|Void|) $ (|Float|)) "\\spad{hitherPlane(v,h)} sets the hither clipping plane of the graph to \\spad{h,} for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}.")) (|eyeDistance| (((|Void|) $ (|Float|)) "\\spad{eyeDistance(v,d)} sets the distance of the observer from the center of the graph to \\spad{d,} for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}.")) (|perspective| (((|Void|) $ (|String|)) "\\spad{perspective(v,s)} displays the graph in perspective if \\spad{s} is \"on\", or does not display perspective if \\spad{s} is \"off\" for the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}.")) (|translate| (((|Void|) $ (|Float|) (|Float|)) "\\spad{translate(v,dx,dy)} sets the horizontal viewport offset to \\spad{dx} and the vertical viewport offset to \\spad{dy}, for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}.")) (|zoom| (((|Void|) $ (|Float|) (|Float|) (|Float|)) "\\spad{zoom(v,sx,sy,sz)} sets the graph scaling factors for the x-coordinate axis to \\spad{sx}, the y-coordinate axis to \\spad{sy} and the z-coordinate axis to \\spad{sz} for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}.") (((|Void|) $ (|Float|)) "\\spad{zoom(v,s)} sets the graph scaling factor to \\spad{s,} for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}.")) (|rotate| (((|Void|) $ (|Integer|) (|Integer|)) "\\spad{rotate(v,th,phi)} rotates the graph to the longitudinal view angle \\spad{th} degrees and the latitudinal view angle \\spad{phi} degrees for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}. The new rotation position is not displayed until the function \\spadfun{makeViewport3D} is executed again for \\spad{v.}") (((|Void|) $ (|Float|) (|Float|)) "\\spad{rotate(v,th,phi)} rotates the graph to the longitudinal view angle \\spad{th} radians and the latitudinal view angle \\spad{phi} radians for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}.")) (|drawStyle| (((|Void|) $ (|String|)) "\\spad{drawStyle(v,s)} displays the surface for the given three-dimensional viewport \\spad{v} which is of domain \\spadtype{ThreeDimensionalViewport} in the style of drawing indicated by \\spad{s.} If \\spad{s} is not a valid drawing style the style is wireframe by default. Possible styles are \\spad{\"shade\"}, \\spad{\"solid\"} or \\spad{\"opaque\"}, \\spad{\"smooth\"}, and \\spad{\"wireMesh\"}.")) (|outlineRender| (((|Void|) $ (|String|)) "\\spad{outlineRender(v,s)} displays the polygon outline showing either triangularized surface or a quadrilateral surface outline depending on the whether the \\spadfun{diagonals} function has been set, for the given three-dimensional viewport \\spad{v} which is of domain \\spadtype{ThreeDimensionalViewport}, if \\spad{s} is \"on\", or does not display the polygon outline if \\spad{s} is \"off\".")) (|diagonals| (((|Void|) $ (|String|)) "\\spad{diagonals(v,s)} displays the diagonals of the polygon outline showing a triangularized surface instead of a quadrilateral surface outline, for the given three-dimensional viewport \\spad{v} which is of domain \\spadtype{ThreeDimensionalViewport}, if \\spad{s} is \"on\", or does not display the diagonals if \\spad{s} is \"off\".")) (|axes| (((|Void|) $ (|String|)) "\\spad{axes(v,s)} displays the axes of the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, if \\spad{s} is \"on\", or does not display the axes if \\spad{s} is \"off\".")) (|controlPanel| (((|Void|) $ (|String|)) "\\spad{controlPanel(v,s)} displays the control panel of the given three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, if \\spad{s} is \"on\", or hides the control panel if \\spad{s} is \"off\".")) (|viewpoint| (((|Void|) $ (|Float|) (|Float|) (|Float|)) "\\spad{viewpoint(v,rotx,roty,rotz)} sets the rotation about the x-axis to be \\spad{rotx} radians, sets the rotation about the y-axis to be \\spad{roty} radians, and sets the rotation about the z-axis to be \\spad{rotz} radians, for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport} and displays \\spad{v} with the new view position.") (((|Void|) $ (|Float|) (|Float|)) "\\spad{viewpoint(v,th,phi)} sets the longitudinal view angle to \\spad{th} radians and the latitudinal view angle to \\spad{phi} radians for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}. The new viewpoint position is not displayed until the function \\spadfun{makeViewport3D} is executed again for \\spad{v.}") (((|Void|) $ (|Integer|) (|Integer|) (|Float|) (|Float|) (|Float|)) "\\spad{viewpoint(v,th,phi,s,dx,dy)} sets the longitudinal view angle to \\spad{th} degrees, the latitudinal view angle to \\spad{phi} degrees, the scale factor to \\spad{s}, the horizontal viewport offset to \\spad{dx}, and the vertical viewport offset to \\spad{dy} for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}. The new viewpoint position is not displayed until the function \\spadfun{makeViewport3D} is executed again for \\spad{v.}") (((|Void|) $ (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) "\\spad{viewpoint(v,viewpt)} sets the viewpoint for the viewport. The viewport record consists of the latitudal and longitudal angles, the zoom factor, the x,y and \\spad{z} scales, and the \\spad{x} and \\spad{y} displacements.") (((|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|))) $) "\\spad{viewpoint(v)} returns the current viewpoint setting of the given viewport, \\spad{v.} This function is useful in the situation where the user has created a viewport, proceeded to interact with it via the control panel and desires to save the values of the viewpoint as the default settings for another viewport to be created using the system.") (((|Void|) $ (|Float|) (|Float|) (|Float|) (|Float|) (|Float|)) "\\spad{viewpoint(v,th,phi,s,dx,dy)} sets the longitudinal view angle to \\spad{th} radians, the latitudinal view angle to \\spad{phi} radians, the scale factor to \\spad{s}, the horizontal viewport offset to \\spad{dx}, and the vertical viewport offset to \\spad{dy} for the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}. The new viewpoint position is not displayed until the function \\spadfun{makeViewport3D} is executed again for \\spad{v.}")) (|dimensions| (((|Void|) $ (|NonNegativeInteger|) (|NonNegativeInteger|) (|PositiveInteger|) (|PositiveInteger|)) "\\spad{dimensions(v,x,y,width,height)} sets the position of the upper left-hand corner of the three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, to the window coordinate \\spad{x,} \\spad{y,} and sets the dimensions of the window to that of \\spad{width}, \\spad{height}. The new dimensions are not displayed until the function \\spadfun{makeViewport3D} is executed again for \\spad{v.}")) (|title| (((|Void|) $ (|String|)) "\\spad{title(v,s)} changes the title which is shown in the three-dimensional viewport window, \\spad{v} of domain \\spadtype{ThreeDimensionalViewport}.")) (|resize| (((|Void|) $ (|PositiveInteger|) (|PositiveInteger|)) "\\spad{resize(v,w,h)} displays the three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, with a width of \\spad{w} and a height of \\spad{h,} keeping the upper left-hand corner position unchanged.")) (|move| (((|Void|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{move(v,x,y)} displays the three-dimensional viewport, \\spad{v,} which is of domain \\spadtype{ThreeDimensionalViewport}, with the upper left-hand corner of the viewport window at the screen coordinate position \\spad{x,} \\spad{y.}")) (|options| (($ $ (|List| (|DrawOption|))) "\\spad{options(v,lopt)} takes the viewport, \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport} and sets the draw options being used by \\spad{v} to those indicated in the list, \\spad{lopt}, which is a list of options from the domain \\spad{DrawOption}.") (((|List| (|DrawOption|)) $) "\\spad{options(v)} takes the viewport, \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport} and returns a list of all the draw options from the domain \\spad{DrawOption} which are being used by \\spad{v.}")) (|modifyPointData| (((|Void|) $ (|NonNegativeInteger|) (|Point| (|DoubleFloat|))) "\\spad{modifyPointData(v,ind,pt)} takes the viewport, \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}, and places the data point, \\spad{pt} into the list of points database of \\spad{v} at the index location given by \\spad{ind}.")) (|subspace| (($ $ (|ThreeSpace| (|DoubleFloat|))) "\\spad{subspace(v,sp)} places the contents of the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}, in the subspace \\spad{sp}, which is of the domain \\spad{ThreeSpace}.") (((|ThreeSpace| (|DoubleFloat|)) $) "\\spad{subspace(v)} returns the contents of the viewport \\spad{v,} which is of the domain \\spadtype{ThreeDimensionalViewport}, as a subspace of the domain \\spad{ThreeSpace}.")) (|makeViewport3D| (($ (|ThreeSpace| (|DoubleFloat|)) (|List| (|DrawOption|))) "\\spad{makeViewport3D(sp,lopt)} takes the given space, \\spad{sp} which is of the domain \\spadtype{ThreeSpace} and displays a viewport window on the screen which contains the contents of \\spad{sp}, and whose draw options are indicated by the list \\spad{lopt}, which is a list of options from the domain \\spad{DrawOption}.") (($ (|ThreeSpace| (|DoubleFloat|)) (|String|)) "\\spad{makeViewport3D(sp,s)} takes the given space, \\spad{sp} which is of the domain \\spadtype{ThreeSpace} and displays a viewport window on the screen which contains the contents of \\spad{sp}, and whose title is given by \\spad{s.}") (($ $) "\\spad{makeViewport3D(v)} takes the given three-dimensional viewport, \\spad{v,} of the domain \\spadtype{ThreeDimensionalViewport} and displays a viewport window on the screen which contains the contents of \\spad{v.}")) (|viewport3D| (($) "\\spad{viewport3D()} returns an undefined three-dimensional viewport of the domain \\spadtype{ThreeDimensionalViewport} whose contents are empty.")) (|viewDeltaYDefault| (((|Float|) (|Float|)) "\\spad{viewDeltaYDefault(dy)} sets the current default vertical offset from the center of the viewport window to be \\spad{dy} and returns \\spad{dy}.") (((|Float|)) "\\spad{viewDeltaYDefault()} returns the current default vertical offset from the center of the viewport window.")) (|viewDeltaXDefault| (((|Float|) (|Float|)) "\\spad{viewDeltaXDefault(dx)} sets the current default horizontal offset from the center of the viewport window to be \\spad{dx} and returns \\spad{dx}.") (((|Float|)) "\\spad{viewDeltaXDefault()} returns the current default horizontal offset from the center of the viewport window.")) (|viewZoomDefault| (((|Float|) (|Float|)) "\\spad{viewZoomDefault(s)} sets the current default graph scaling value to \\spad{s} and returns \\spad{s.}") (((|Float|)) "\\spad{viewZoomDefault()} returns the current default graph scaling value.")) (|viewPhiDefault| (((|Float|) (|Float|)) "\\spad{viewPhiDefault(p)} sets the current default latitudinal view angle in radians to the value \\spad{p} and returns \\spad{p.}") (((|Float|)) "\\spad{viewPhiDefault()} returns the current default latitudinal view angle in radians.")) (|viewThetaDefault| (((|Float|) (|Float|)) "\\spad{viewThetaDefault(t)} sets the current default longitudinal view angle in radians to the value \\spad{t} and returns \\spad{t.}") (((|Float|)) "\\spad{viewThetaDefault()} returns the current default longitudinal view angle in radians."))) 
 NIL 
 NIL 
-(-1262) 
+(-1283) 
 ((|constructor| (NIL "ViewportDefaultsPackage describes default and user definable values for graphics")) (|tubeRadiusDefault| (((|DoubleFloat|)) "\\spad{tubeRadiusDefault()} returns the radius used for a 3D tube plot.") (((|DoubleFloat|) (|Float|)) "\\spad{tubeRadiusDefault(r)} sets the default radius for a 3D tube plot to \\spad{r.}")) (|tubePointsDefault| (((|PositiveInteger|)) "\\spad{tubePointsDefault()} returns the number of points to be used when creating the circle to be used in creating a 3D tube plot.") (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{tubePointsDefault(i)} sets the number of points to use when creating the circle to be used in creating a 3D tube plot to i.")) (|var2StepsDefault| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{var2StepsDefault(i)} sets the number of steps to take when creating a 3D mesh in the direction of the first defined free variable to \\spad{i} (a free variable is considered defined when its range is specified (\\spadignore{e.g.} x=0..10)).") (((|PositiveInteger|)) "\\spad{var2StepsDefault()} is the current setting for the number of steps to take when creating a 3D mesh in the direction of the first defined free variable (a free variable is considered defined when its range is specified (\\spadignore{e.g.} x=0..10)).")) (|var1StepsDefault| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{var1StepsDefault(i)} sets the number of steps to take when creating a 3D mesh in the direction of the first defined free variable to \\spad{i} (a free variable is considered defined when its range is specified (\\spadignore{e.g.} x=0..10)).") (((|PositiveInteger|)) "\\spad{var1StepsDefault()} is the current setting for the number of steps to take when creating a 3D mesh in the direction of the first defined free variable (a free variable is considered defined when its range is specified (\\spadignore{e.g.} x=0..10)).")) (|viewWriteAvailable| (((|List| (|String|))) "\\spad{viewWriteAvailable()} returns a list of available methods for writing, such as BITMAP, POSTSCRIPT, etc.")) (|viewWriteDefault| (((|List| (|String|)) (|List| (|String|))) "\\spad{viewWriteDefault(l)} sets the default list of things to write in a viewport data file to the strings in \\spad{l;} a viewalone file is always genereated.") (((|List| (|String|))) "\\spad{viewWriteDefault()} returns the list of things to write in a viewport data file; a viewalone file is always generated.")) (|viewDefaults| (((|Void|)) "\\spad{viewDefaults()} resets all the default graphics settings.")) (|viewSizeDefault| (((|List| (|PositiveInteger|)) (|List| (|PositiveInteger|))) "\\spad{viewSizeDefault([w,h])} sets the default viewport width to \\spad{w} and height to \\spad{h.}") (((|List| (|PositiveInteger|))) "\\spad{viewSizeDefault()} returns the default viewport width and height.")) (|viewPosDefault| (((|List| (|NonNegativeInteger|)) (|List| (|NonNegativeInteger|))) "\\spad{viewPosDefault([x,y])} sets the default \\spad{x} and \\spad{y} position of a viewport window unless overriden explicityly, newly created viewports will have the \\spad{x} and \\spad{y} coordinates \\spad{x,} \\spad{y.}") (((|List| (|NonNegativeInteger|))) "\\spad{viewPosDefault()} returns the default \\spad{x} and \\spad{y} position of a viewport window unless overriden explicityly, newly created viewports will have this \\spad{x} and \\spad{y} coordinate.")) (|pointSizeDefault| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{pointSizeDefault(i)} sets the default size of the points in a 2D viewport to i.") (((|PositiveInteger|)) "\\spad{pointSizeDefault()} returns the default size of the points in a 2D viewport.")) (|unitsColorDefault| (((|Palette|) (|Palette|)) "\\spad{unitsColorDefault(p)} sets the default color of the unit ticks in a 2D viewport to the palette \\spad{p.}") (((|Palette|)) "\\spad{unitsColorDefault()} returns the default color of the unit ticks in a 2D viewport.")) (|axesColorDefault| (((|Palette|) (|Palette|)) "\\spad{axesColorDefault(p)} sets the default color of the axes in a 2D viewport to the palette \\spad{p.}") (((|Palette|)) "\\spad{axesColorDefault()} returns the default color of the axes in a 2D viewport.")) (|lineColorDefault| (((|Palette|) (|Palette|)) "\\spad{lineColorDefault(p)} sets the default color of lines connecting points in a 2D viewport to the palette \\spad{p.}") (((|Palette|)) "\\spad{lineColorDefault()} returns the default color of lines connecting points in a 2D viewport.")) (|pointColorDefault| (((|Palette|) (|Palette|)) "\\spad{pointColorDefault(p)} sets the default color of points in a 2D viewport to the palette \\spad{p.}") (((|Palette|)) "\\spad{pointColorDefault()} returns the default color of points in a 2D viewport."))) 
 NIL 
 NIL 
-(-1263) 
+(-1284) 
 ((|constructor| (NIL "ViewportPackage provides functions for creating GraphImages and TwoDimensionalViewports from lists of lists of points.")) (|coerce| (((|TwoDimensionalViewport|) (|GraphImage|)) "\\spad{coerce(gi)} converts the indicated \\spadtype{GraphImage}, gi, into the \\spadtype{TwoDimensionalViewport} form.")) (|drawCurves| (((|TwoDimensionalViewport|) (|List| (|List| (|Point| (|DoubleFloat|)))) (|List| (|DrawOption|))) "\\spad{drawCurves([[p0],[p1],...,[pn]],[options])} creates a \\spadtype{TwoDimensionalViewport} from the list of lists of points, \\spad{p0} throught \\spad{pn,} using the options specified in the list \\spad{options}.") (((|TwoDimensionalViewport|) (|List| (|List| (|Point| (|DoubleFloat|)))) (|Palette|) (|Palette|) (|PositiveInteger|) (|List| (|DrawOption|))) "\\spad{drawCurves([[p0],[p1],...,[pn]],ptColor,lineColor,ptSize,[options])} creates a \\spadtype{TwoDimensionalViewport} from the list of lists of points, \\spad{p0} throught \\spad{pn,} using the options specified in the list \\spad{options}. The point color is specified by \\spad{ptColor}, the line color is specified by \\spad{lineColor}, and the point size is specified by \\spad{ptSize}.")) (|graphCurves| (((|GraphImage|) (|List| (|List| (|Point| (|DoubleFloat|)))) (|List| (|DrawOption|))) "\\spad{graphCurves([[p0],[p1],...,[pn]],[options])} creates a \\spadtype{GraphImage} from the list of lists of points, \\spad{p0} throught \\spad{pn,} using the options specified in the list \\spad{options}.") (((|GraphImage|) (|List| (|List| (|Point| (|DoubleFloat|))))) "\\spad{graphCurves([[p0],[p1],...,[pn]])} creates a \\spadtype{GraphImage} from the list of lists of points indicated by \\spad{p0} through \\spad{pn.}") (((|GraphImage|) (|List| (|List| (|Point| (|DoubleFloat|)))) (|Palette|) (|Palette|) (|PositiveInteger|) (|List| (|DrawOption|))) "\\spad{graphCurves([[p0],[p1],...,[pn]],ptColor,lineColor,ptSize,[options])} creates a \\spadtype{GraphImage} from the list of lists of points, \\spad{p0} throught \\spad{pn,} using the options specified in the list \\spad{options}. The graph point color is specified by \\spad{ptColor}, the graph line color is specified by \\spad{lineColor}, and the size of the points is specified by \\spad{ptSize}."))) 
 NIL 
 NIL 
-(-1264) 
+(-1285) 
 ((|constructor| (NIL "This type is used when no value is needed, \\spadignore{e.g.} in the \\spad{then} part of a one armed \\spad{if}. All values can be coerced to type Void. Once a value has been coerced to Void, it cannot be recovered.")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(v)} coerces void object to outputForm.")) (|void| (($) "\\spad{void()} produces a void object."))) 
 NIL 
 NIL 
-(-1265 A S) 
+(-1286 A S) 
 ((|constructor| (NIL "Vector Spaces (not necessarily finite dimensional) over a field.")) (|dimension| (((|CardinalNumber|)) "\\spad{dimension()} returns the dimensionality of the vector space.")) (/ (($ $ |#2|) "\\spad{x/y} divides the vector \\spad{x} by the scalar \\spad{y.}"))) 
 NIL 
 NIL 
-(-1266 S) 
+(-1287 S) 
 ((|constructor| (NIL "Vector Spaces (not necessarily finite dimensional) over a field.")) (|dimension| (((|CardinalNumber|)) "\\spad{dimension()} returns the dimensionality of the vector space.")) (/ (($ $ |#1|) "\\spad{x/y} divides the vector \\spad{x} by the scalar \\spad{y.}"))) 
-((-4597 . T) (-4596 . T)) 
+((-4620 . T) (-4619 . T)) 
 NIL 
-(-1267 R) 
+(-1288 R) 
 ((|constructor| (NIL "This package implements the Weierstrass preparation theorem \\spad{f} or multivariate power series. weierstrass(v,p) where \\spad{v} is a variable, and \\spad{p} is a TaylorSeries(R) in which the terms of lowest degree \\spad{s} must include c*v**s where \\spad{c} is a constant,s>0, is a list of TaylorSeries coefficients A[i] of the equivalent polynomial A = A[0] + A[1]*v + \\spad{A[2]*v**2} + \\spad{...} + A[s-1]*v**(s-1) + v**s such that p=A*B ,{} \\spad{B} being a TaylorSeries of minimum degree 0")) (|qqq| (((|Mapping| (|Stream| (|TaylorSeries| |#1|)) (|Stream| (|TaylorSeries| |#1|))) (|NonNegativeInteger|) (|TaylorSeries| |#1|) (|Stream| (|TaylorSeries| |#1|))) "\\spad{qqq(n,s,st)} is used internally.")) (|weierstrass| (((|List| (|TaylorSeries| |#1|)) (|Symbol|) (|TaylorSeries| |#1|)) "\\spad{weierstrass(v,ts)} where \\spad{v} is a variable and \\spad{ts} is \\indented{1}{a TaylorSeries, impements the Weierstrass Preparation} \\indented{1}{Theorem. The result is a list of TaylorSeries that} \\indented{1}{are the coefficients of the equivalent series.}")) (|clikeUniv| (((|Mapping| (|SparseUnivariatePolynomial| (|Polynomial| |#1|)) (|Polynomial| |#1|)) (|Symbol|)) "\\spad{clikeUniv(v)} is used internally.")) (|sts2stst| (((|Stream| (|Stream| (|Polynomial| |#1|))) (|Symbol|) (|Stream| (|Polynomial| |#1|))) "\\spad{sts2stst(v,s)} is used internally.")) (|cfirst| (((|Mapping| (|Stream| (|Polynomial| |#1|)) (|Stream| (|Polynomial| |#1|))) (|NonNegativeInteger|)) "\\spad{cfirst \\spad{n}} is used internally.")) (|crest| (((|Mapping| (|Stream| (|Polynomial| |#1|)) (|Stream| (|Polynomial| |#1|))) (|NonNegativeInteger|)) "\\spad{crest \\spad{n}} is used internally."))) 
 NIL 
 NIL 
-(-1268 K R UP -3313) 
+(-1289 K R UP -3958) 
 ((|constructor| (NIL "In this package \\spad{K} is a finite field, \\spad{R} is a ring of univariate polynomials over \\spad{K,} and \\spad{F} is a framed algebra over \\spad{R.} The package provides a function to compute the integral closure of \\spad{R} in the quotient field of \\spad{F} as well as a function to compute a \"local integral basis\" at a specific prime.")) (|localIntegralBasis| (((|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|))) |#2|) "\\spad{integralBasis(p)} returns a record \\spad{[basis,basisDen,basisInv]} containing information regarding the local integral closure of \\spad{R} at the prime \\spad{p} in the quotient field of \\spad{F,} where \\spad{F} is a framed algebra with R-module basis \\spad{w1,w2,...,wn}. If \\spad{basis} is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then the \\spad{i}th element of the local integral basis is \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of \\spad{basis} contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if \\spad{basisInv} is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}.")) (|integralBasis| (((|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|)))) "\\spad{integralBasis()} returns a record \\spad{[basis,basisDen,basisInv]} containing information regarding the integral closure of \\spad{R} in the quotient field of \\spad{F,} where \\spad{F} is a framed algebra with R-module basis \\spad{w1,w2,...,wn}. If \\spad{basis} is the matrix \\spad{(aij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then the \\spad{i}th element of the integral basis is \\spad{vi = (1/basisDen) * sum(aij * \\spad{wj,} \\spad{j} = 1..n)}, \\spadignore{i.e.} the \\spad{i}th row of \\spad{basis} contains the coordinates of the \\spad{i}th basis vector. Similarly, the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{wi} with respect to the basis \\spad{v1,...,vn}: if \\spad{basisInv} is the matrix \\spad{(bij, \\spad{i} = 1..n, \\spad{j} = 1..n)}, then \\spad{wi = sum(bij * \\spad{vj,} \\spad{j} = 1..n)}."))) 
 NIL 
 NIL 
-(-1269 R |VarSet| E P |vl| |wl| |wtlevel|) 
+(-1290 R |VarSet| E P |vl| |wl| |wtlevel|) 
 ((|constructor| (NIL "This domain represents truncated weighted polynomials over a general (not necessarily commutative) polynomial type. The variables must be specified, as must the weights. The representation is sparse in the sense that only non-zero terms are represented.")) (|changeWeightLevel| (((|Void|) (|NonNegativeInteger|)) "\\spad{changeWeightLevel(n)} changes the weight level to the new value given: \\spad{NB:} previously calculated terms are not affected")) (/ (((|Union| $ "failed") $ $) "\\spad{x/y} division (only works if minimum weight of divisor is zero, and if \\spad{R} is a Field)")) (|coerce| (($ |#4|) "\\spad{coerce(p)} coerces \\spad{p} into Weighted form, applying weights and ignoring terms") ((|#4| $) "convert back into a \"P\", ignoring weights"))) 
-((-4597 |has| |#1| (-174)) (-4596 |has| |#1| (-174)) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368)))) 
-(-1270 R E V P) 
+((-4620 |has| |#1| (-194)) (-4619 |has| |#1| (-194)) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388)))) 
+(-1291 R E V P) 
 ((|constructor| (NIL "A domain constructor of the category \\axiomType{GeneralTriangularSet}. The only requirement for a list of polynomials to be a member of such a domain is the following: no polynomial is constant and two distinct polynomials have distinct main variables. Such a triangular set may not be auto-reduced or consistent. The construct operation does not check the previous requirement. Triangular sets are stored as sorted lists w.r.t. the main variables of their members. Furthermore, this domain exports operations dealing with the characteristic set method of Wu Wen Tsun and some optimizations mainly proposed by Dong Ming Wang.")) (|characteristicSerie| (((|List| $) (|List| |#4|)) "\\axiom{characteristicSerie(ps)} returns the same as \\axiom{characteristicSerie(ps,initiallyReduced?,initiallyReduce)}.") (((|List| $) (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{characteristicSerie(ps,redOp?,redOp)} returns a list \\axiom{lts} of triangular sets such that the zero set of \\axiom{ps} is the union of the regular zero sets of the members of \\axiom{lts}. This is made by the Ritt and Wu Wen Tsun process applying the operation \\axiom{characteristicSet(ps,redOp?,redOp)} to compute characteristic sets in Wu Wen Tsun sense.")) (|characteristicSet| (((|Union| $ "failed") (|List| |#4|)) "\\axiom{characteristicSet(ps)} returns the same as \\axiom{characteristicSet(ps,initiallyReduced?,initiallyReduce)}.") (((|Union| $ "failed") (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{characteristicSet(ps,redOp?,redOp)} returns a non-contradictory characteristic set of \\axiom{ps} in Wu Wen Tsun sense w.r.t the reduction-test \\axiom{redOp?} (using \\axiom{redOp} to reduce polynomials w.r.t a \\axiom{redOp?} basic set), if no non-zero constant polynomial appear during those reductions, else \\axiom{\"failed\"} is returned. The operations \\axiom{redOp} and \\axiom{redOp?} must satisfy the following conditions: \\axiom{redOp?(redOp(p,q),q)} holds for every polynomials \\axiom{p,q} and there exists an integer \\axiom{e} and a polynomial \\axiom{f} such that we have \\axiom{init(q)^e*p = \\spad{f*q} + redOp(p,q)}.")) (|medialSet| (((|Union| $ "failed") (|List| |#4|)) "\\axiom{medial(ps)} returns the same as \\axiom{medialSet(ps,initiallyReduced?,initiallyReduce)}.") (((|Union| $ "failed") (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{medialSet(ps,redOp?,redOp)} returns \\axiom{bs} a basic set (in Wu Wen Tsun sense w.r.t the reduction-test \\axiom{redOp?}) of some set generating the same ideal as \\axiom{ps} (with rank not higher than any basic set of \\axiom{ps}), if no non-zero constant polynomials appear during the computatioms, else \\axiom{\"failed\"} is returned. In the former case, \\axiom{bs} has to be understood as a candidate for being a characteristic set of \\axiom{ps}. In the original algorithm, \\axiom{bs} is simply a basic set of \\axiom{ps}."))) 
-((-4603 . T) (-4602 . T)) 
-((|HasCategory| |#4| (LIST (QUOTE -613) (QUOTE (-545)))) (|HasCategory| |#4| (QUOTE (-1098))) (-12 (|HasCategory| |#4| (LIST (QUOTE -305) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1098)))) (|HasCategory| |#1| (QUOTE (-562))) (|HasCategory| |#3| (QUOTE (-374)))) 
-(-1271 R) 
+((-4626 . T) (-4625 . T)) 
+((|HasCategory| |#4| (LIST (QUOTE -633) (QUOTE (-565)))) (|HasCategory| |#4| (QUOTE (-1119))) (-12 (|HasCategory| |#4| (LIST (QUOTE -325) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1119)))) (|HasCategory| |#1| (QUOTE (-582))) (|HasCategory| |#3| (QUOTE (-394)))) 
+(-1292 R) 
 ((|constructor| (NIL "This is the category of algebras over non-commutative rings. It is used by constructors of non-commutative algebras such as XPolynomialRing and XFreeAlgebra")) (|coerce| (($ |#1|) "\\spad{coerce(r)} equals \\spad{r*1}."))) 
-((-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1272 |vl| R) 
+(-1293 |vl| R) 
 ((|constructor| (NIL "This type supports distributed multivariate polynomials whose variables do not commute. The coefficient ring may be non-commutative too. However, coefficients and variables commute."))) 
-((-4599 . T) (-4595 |has| |#2| (-6 -4595)) (-4597 . T) (-4596 . T)) 
-((|HasCategory| |#2| (QUOTE (-174))) (|HasAttribute| |#2| (QUOTE -4595))) 
-(-1273 R |VarSet| XPOLY) 
+((-4622 . T) (-4618 |has| |#2| (-6 -4618)) (-4620 . T) (-4619 . T)) 
+((|HasCategory| |#2| (QUOTE (-194))) (|HasAttribute| |#2| (QUOTE -4618))) 
+(-1294 R |VarSet| XPOLY) 
 ((|constructor| (NIL "This package provides computations of logarithms and exponentials for polynomials in non-commutative variables.")) (|Hausdorff| ((|#3| |#3| |#3| (|NonNegativeInteger|)) "\\axiom{Hausdorff(a,b,n)} returns log(exp(a)*exp(b)) truncated at order \\axiom{n}.")) (|log| ((|#3| |#3| (|NonNegativeInteger|)) "\\axiom{log(p, \\spad{n)}} returns the logarithm of \\axiom{p} truncated at order \\axiom{n}.")) (|exp| ((|#3| |#3| (|NonNegativeInteger|)) "\\axiom{exp(p, \\spad{n)}} returns the exponential of \\axiom{p} truncated at order \\axiom{n}."))) 
 NIL 
 NIL 
-(-1274 |vl| R) 
+(-1295 |vl| R) 
 ((|constructor| (NIL "This category specifies opeations for polynomials and formal series with non-commutative variables.")) (|varList| (((|List| |#1|) $) "\\spad{varList(x)} returns the list of variables which appear in \\spad{x}.")) (|map| (($ (|Mapping| |#2| |#2|) $) "\\spad{map(fn,x)} returns \\spad{Sum(fn(r_i) w_i)} if \\spad{x} writes \\spad{Sum(r_i w_i)}.")) (|sh| (($ $ (|NonNegativeInteger|)) "\\spad{sh(x,n)} returns the shuffle power of \\spad{x} to the \\spad{n}.") (($ $ $) "\\spad{sh(x,y)} returns the shuffle-product of \\spad{x} by \\spad{y}. This multiplication is associative and commutative.")) (|quasiRegular| (($ $) "\\spad{quasiRegular(x)} return \\spad{x} minus its constant term.")) (|quasiRegular?| (((|Boolean|) $) "\\spad{quasiRegular?(x)} return \\spad{true} if \\spad{constant(x)} is zero")) (|constant| ((|#2| $) "\\spad{constant(x)} returns the constant term of \\spad{x}.")) (|constant?| (((|Boolean|) $) "\\spad{constant?(x)} returns \\spad{true} if \\spad{x} is constant.")) (|coerce| (($ |#1|) "\\spad{coerce(v)} returns \\spad{v}.")) (|mirror| (($ $) "\\spad{mirror(x)} returns \\spad{Sum(r_i mirror(w_i))} if \\spad{x} writes \\spad{Sum(r_i w_i)}.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(x)} returns \\spad{true} if \\spad{x} is a monomial")) (|monom| (($ (|OrderedFreeMonoid| |#1|) |#2|) "\\spad{monom(w,r)} returns the product of the word \\spad{w} by the coefficient \\spad{r}.")) (|rquo| (($ $ $) "\\spad{rquo(x,y)} returns the right simplification of \\spad{x} by \\spad{y}.") (($ $ (|OrderedFreeMonoid| |#1|)) "\\spad{rquo(x,w)} returns the right simplification of \\spad{x} by \\spad{w}.") (($ $ |#1|) "\\spad{rquo(x,v)} returns the right simplification of \\spad{x} by the variable \\spad{v}.")) (|lquo| (($ $ $) "\\spad{lquo(x,y)} returns the left simplification of \\spad{x} by \\spad{y}.") (($ $ (|OrderedFreeMonoid| |#1|)) "\\spad{lquo(x,w)} returns the left simplification of \\spad{x} by the word \\spad{w}.") (($ $ |#1|) "\\spad{lquo(x,v)} returns the left simplification of \\spad{x} by the variable \\spad{v}.")) (|coef| ((|#2| $ $) "\\spad{coef(x,y)} returns scalar product of \\spad{x} by \\spad{y}, the set of words being regarded as an orthogonal basis.") ((|#2| $ (|OrderedFreeMonoid| |#1|)) "\\spad{coef(x,w)} returns the coefficient of the word \\spad{w} in \\spad{x}.")) (|mindegTerm| (((|Record| (|:| |k| (|OrderedFreeMonoid| |#1|)) (|:| |c| |#2|)) $) "\\spad{mindegTerm(x)} returns the term whose word is \\spad{mindeg(x)}.")) (|mindeg| (((|OrderedFreeMonoid| |#1|) $) "\\spad{mindeg(x)} returns the little word which appears in \\spad{x}. Error if \\spad{x=0}.")) (* (($ $ |#2|) "\\spad{x * \\spad{r}} returns the product of \\spad{x} by \\spad{r}. Usefull if \\spad{R} is a non-commutative Ring.") (($ |#1| $) "\\spad{v * \\spad{x}} returns the product of a variable \\spad{x} by \\spad{x}."))) 
-((-4595 |has| |#2| (-6 -4595)) (-4597 . T) (-4596 . T) (-4599 . T)) 
+((-4618 |has| |#2| (-6 -4618)) (-4620 . T) (-4619 . T) (-4622 . T)) 
 NIL 
-(-1275 S -3313) 
+(-1296 S -3958) 
 ((|constructor| (NIL "ExtensionField \\spad{F} is the category of fields which extend the field \\spad{F}")) (|Frobenius| (($ $ (|NonNegativeInteger|)) "\\spad{Frobenius(a,s)} returns \\spad{a**(q**s)} where \\spad{q} is the size()$F.") (($ $) "\\spad{Frobenius(a)} returns \\spad{a \\spad{**} \\spad{q}} where \\spad{q} is the \\spad{size()$F}.")) (|transcendenceDegree| (((|NonNegativeInteger|)) "\\spad{transcendenceDegree()} returns the transcendence degree of the field extension, 0 if the extension is algebraic.")) (|extensionDegree| (((|OnePointCompletion| (|PositiveInteger|))) "\\spad{extensionDegree()} returns the degree of the field extension if the extension is algebraic, and \\spad{infinity} if it is not.")) (|degree| (((|OnePointCompletion| (|PositiveInteger|)) $) "\\spad{degree(a)} returns the degree of minimal polynomial of an element \\spad{a} if \\spad{a} is algebraic with respect to the ground field \\spad{F,} and \\spad{infinity} otherwise.")) (|inGroundField?| (((|Boolean|) $) "\\spad{inGroundField?(a)} tests whether an element \\spad{a} is already in the ground field \\spad{F.}")) (|transcendent?| (((|Boolean|) $) "\\spad{transcendent?(a)} tests whether an element \\spad{a} is transcendent with respect to the ground field \\spad{F.}")) (|algebraic?| (((|Boolean|) $) "\\spad{algebraic?(a)} tests whether an element \\spad{a} is algebraic with respect to the ground field \\spad{F.}"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-374))) (|HasCategory| |#2| (QUOTE (-149))) (|HasCategory| |#2| (QUOTE (-151)))) 
-(-1276 -3313) 
+((|HasCategory| |#2| (QUOTE (-394))) (|HasCategory| |#2| (QUOTE (-169))) (|HasCategory| |#2| (QUOTE (-171)))) 
+(-1297 -3958) 
 ((|constructor| (NIL "ExtensionField \\spad{F} is the category of fields which extend the field \\spad{F}")) (|Frobenius| (($ $ (|NonNegativeInteger|)) "\\spad{Frobenius(a,s)} returns \\spad{a**(q**s)} where \\spad{q} is the size()$F.") (($ $) "\\spad{Frobenius(a)} returns \\spad{a \\spad{**} \\spad{q}} where \\spad{q} is the \\spad{size()$F}.")) (|transcendenceDegree| (((|NonNegativeInteger|)) "\\spad{transcendenceDegree()} returns the transcendence degree of the field extension, 0 if the extension is algebraic.")) (|extensionDegree| (((|OnePointCompletion| (|PositiveInteger|))) "\\spad{extensionDegree()} returns the degree of the field extension if the extension is algebraic, and \\spad{infinity} if it is not.")) (|degree| (((|OnePointCompletion| (|PositiveInteger|)) $) "\\spad{degree(a)} returns the degree of minimal polynomial of an element \\spad{a} if \\spad{a} is algebraic with respect to the ground field \\spad{F,} and \\spad{infinity} otherwise.")) (|inGroundField?| (((|Boolean|) $) "\\spad{inGroundField?(a)} tests whether an element \\spad{a} is already in the ground field \\spad{F.}")) (|transcendent?| (((|Boolean|) $) "\\spad{transcendent?(a)} tests whether an element \\spad{a} is transcendent with respect to the ground field \\spad{F.}")) (|algebraic?| (((|Boolean|) $) "\\spad{algebraic?(a)} tests whether an element \\spad{a} is algebraic with respect to the ground field \\spad{F.}"))) 
-((-4594 . T) (-4600 . T) (-4595 . T) ((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+((-4617 . T) (-4623 . T) (-4618 . T) ((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
-(-1277 |VarSet| R) 
+(-1298 |VarSet| R) 
 ((|constructor| (NIL "This domain constructor implements polynomials in non-commutative variables written in the Poincare-Birkhoff-Witt basis from the Lyndon basis. These polynomials can be used to compute Baker-Campbell-Hausdorff relations.")) (|log| (($ $ (|NonNegativeInteger|)) "\\axiom{log(p,n)} returns the logarithm of \\axiom{p} (truncated up to order \\axiom{n}).")) (|exp| (($ $ (|NonNegativeInteger|)) "\\axiom{exp(p,n)} returns the exponential of \\axiom{p} (truncated up to order \\axiom{n}).")) (|product| (($ $ $ (|NonNegativeInteger|)) "\\axiom{product(a,b,n)} returns \\axiom{a*b} (truncated up to order \\axiom{n}).")) (|LiePolyIfCan| (((|Union| (|LiePolynomial| |#1| |#2|) "failed") $) "\\axiom{LiePolyIfCan(p)} return \\axiom{p} if \\axiom{p} is a Lie polynomial.")) (|coerce| (((|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{coerce(p)} returns \\axiom{p} as a recursive polynomial.") (((|XDistributedPolynomial| |#1| |#2|) $) "\\axiom{coerce(p)} returns \\axiom{p} as a distributed polynomial.") (($ (|LiePolynomial| |#1| |#2|)) "\\axiom{coerce(p)} returns \\axiom{p}."))) 
-((-4595 |has| |#2| (-6 -4595)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-174))) (|HasCategory| |#2| (LIST (QUOTE -713) (LIST (QUOTE -413) (QUOTE (-572))))) (|HasAttribute| |#2| (QUOTE -4595))) 
-(-1278 |vl| R) 
+((-4618 |has| |#2| (-6 -4618)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-194))) (|HasCategory| |#2| (LIST (QUOTE -734) (LIST (QUOTE -433) (QUOTE (-592))))) (|HasAttribute| |#2| (QUOTE -4618))) 
+(-1299 |vl| R) 
 ((|constructor| (NIL "The Category of polynomial rings with non-commutative variables. The coefficient ring may be non-commutative too. However coefficients commute with variables.")) (|trunc| (($ $ (|NonNegativeInteger|)) "\\spad{trunc(p,n)} returns the polynomial \\spad{p} truncated at order \\spad{n}.")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(p)} returns the degree of \\spad{p}. \\indented{1}{Note that the degree of a word is its length.}")) (|maxdeg| (((|OrderedFreeMonoid| |#1|) $) "\\spad{maxdeg(p)} returns the greatest leading word in the support of \\spad{p}."))) 
-((-4595 |has| |#2| (-6 -4595)) (-4597 . T) (-4596 . T) (-4599 . T)) 
+((-4618 |has| |#2| (-6 -4618)) (-4620 . T) (-4619 . T) (-4622 . T)) 
 NIL 
-(-1279 R) 
+(-1300 R) 
 ((|constructor| (NIL "This type supports multivariate polynomials whose set of variables is \\spadtype{Symbol}. The representation is recursive. The coefficient ring may be non-commutative and the variables do not commute. However, coefficients and variables commute."))) 
-((-4595 |has| |#1| (-6 -4595)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasAttribute| |#1| (QUOTE -4595))) 
-(-1280 R E) 
+((-4618 |has| |#1| (-6 -4618)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasAttribute| |#1| (QUOTE -4618))) 
+(-1301 R E) 
 ((|constructor| (NIL "This domain represents generalized polynomials with coefficients (from a not necessarily commutative ring), and words belonging to an arbitrary \\spadtype{OrderedMonoid}. This type is used, for instance, by the \\spadtype{XDistributedPolynomial} domain constructor where the Monoid is free.")) (|canonicalUnitNormal| ((|attribute|) "canonicalUnitNormal guarantees that the function unitCanonical returns the same representative for all associates of any particular element.")) (/ (($ $ |#1|) "\\spad{p/r} returns \\spad{p*(1/r)}.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(fn,x)} returns \\spad{Sum(fn(r_i) w_i)} if \\spad{x} writes \\spad{Sum(r_i w_i)}.")) (|quasiRegular| (($ $) "\\spad{quasiRegular(x)} return \\spad{x} minus its constant term.")) (|quasiRegular?| (((|Boolean|) $) "\\spad{quasiRegular?(x)} return \\spad{true} if \\spad{constant(p)} is zero.")) (|constant| ((|#1| $) "\\spad{constant(p)} return the constant term of \\spad{p}.")) (|constant?| (((|Boolean|) $) "\\spad{constant?(p)} tests whether the polynomial \\spad{p} belongs to the coefficient ring.")) (|coef| ((|#1| $ |#2|) "\\spad{coef(p,e)} extracts the coefficient of the monomial \\spad{e}. Returns zero if \\spad{e} is not present.")) (|reductum| (($ $) "\\spad{reductum(p)} returns \\spad{p} minus its leading term. An error is produced if \\spad{p} is zero.")) (|mindeg| ((|#2| $) "\\spad{mindeg(p)} returns the smallest word occurring in the polynomial \\spad{p} with a non-zero coefficient. An error is produced if \\spad{p} is zero.")) (|maxdeg| ((|#2| $) "\\spad{maxdeg(p)} returns the greatest word occurring in the polynomial \\spad{p} with a non-zero coefficient. An error is produced if \\spad{p} is zero.")) (|coerce| (($ |#2|) "\\spad{coerce(e)} returns \\spad{1*e}")) (|#| (((|NonNegativeInteger|) $) "\\spad{# \\spad{p}} returns the number of terms in \\spad{p}.")) (* (($ $ |#1|) "\\spad{p*r} returns the product of \\spad{p} by \\spad{r}."))) 
-((-4599 . T) (-4600 |has| |#1| (-6 -4600)) (-4595 |has| |#1| (-6 -4595)) (-4597 . T) (-4596 . T)) 
-((|HasCategory| |#1| (QUOTE (-174))) (|HasCategory| |#1| (QUOTE (-368))) (|HasAttribute| |#1| (QUOTE -4599)) (|HasAttribute| |#1| (QUOTE -4600)) (|HasAttribute| |#1| (QUOTE -4595))) 
-(-1281 |VarSet| R) 
+((-4622 . T) (-4623 |has| |#1| (-6 -4623)) (-4618 |has| |#1| (-6 -4618)) (-4620 . T) (-4619 . T)) 
+((|HasCategory| |#1| (QUOTE (-194))) (|HasCategory| |#1| (QUOTE (-388))) (|HasAttribute| |#1| (QUOTE -4622)) (|HasAttribute| |#1| (QUOTE -4623)) (|HasAttribute| |#1| (QUOTE -4618))) 
+(-1302 |VarSet| R) 
 ((|constructor| (NIL "This type supports multivariate polynomials whose variables do not commute. The representation is recursive. The coefficient ring may be non-commutative. Coefficients and variables commute.")) (|RemainderList| (((|List| (|Record| (|:| |k| |#1|) (|:| |c| $))) $) "\\spad{RemainderList(p)} returns the regular part of \\spad{p} as a list of terms.")) (|unexpand| (($ (|XDistributedPolynomial| |#1| |#2|)) "\\spad{unexpand(p)} returns \\spad{p} in recursive form.")) (|expand| (((|XDistributedPolynomial| |#1| |#2|) $) "\\spad{expand(p)} returns \\spad{p} in distributed form."))) 
-((-4595 |has| |#2| (-6 -4595)) (-4597 . T) (-4596 . T) (-4599 . T)) 
-((|HasCategory| |#2| (QUOTE (-174))) (|HasAttribute| |#2| (QUOTE -4595))) 
-(-1282 A) 
+((-4618 |has| |#2| (-6 -4618)) (-4620 . T) (-4619 . T) (-4622 . T)) 
+((|HasCategory| |#2| (QUOTE (-194))) (|HasAttribute| |#2| (QUOTE -4618))) 
+(-1303 A) 
 ((|constructor| (NIL "This package implements fixed-point computations on streams.")) (Y (((|List| (|Stream| |#1|)) (|Mapping| (|List| (|Stream| |#1|)) (|List| (|Stream| |#1|))) (|Integer|)) "\\spad{Y(g,n)} computes a fixed point of the function \\spad{g,} where \\spad{g} takes a list of \\spad{n} streams and returns a list of \\spad{n} streams.") (((|Stream| |#1|) (|Mapping| (|Stream| |#1|) (|Stream| |#1|))) "\\spad{Y(f)} computes a fixed point of the function \\spad{f.}"))) 
 NIL 
 NIL 
-(-1283 R |ls| |ls2|) 
+(-1304 R |ls| |ls2|) 
 ((|constructor| (NIL "A package for computing symbolically the complex and real roots of zero-dimensional algebraic systems over the integer or rational numbers. Complex roots are given by means of univariate representations of irreducible regular chains. Real roots are given by means of tuples of coordinates lying in the \\spadtype{RealClosure} of the coefficient ring. This constructor takes three arguments. The first one \\spad{R} is the coefficient ring. The second one \\spad{ls} is the list of variables involved in the systems to solve. The third one must be \\spad{concat(ls,s)} where \\spad{s} is an additional symbol used for the univariate representations. WARNING. The third argument is not checked. All operations are based on triangular decompositions. The default is to compute these decompositions directly from the input system by using the \\spadtype{RegularChain} domain constructor. The lexTriangular algorithm can also be used for computing these decompositions (see \\spadtype{LexTriangularPackage} package constructor). For that purpose, the operations univariateSolve, realSolve and positiveSolve admit an optional argument.")) (|convert| (((|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#3|))) (|SquareFreeRegularTriangularSet| |#1| (|IndexedExponents| (|OrderedVariableList| |#3|)) (|OrderedVariableList| |#3|) (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#3|)))) "\\spad{convert(st)} returns the members of \\spad{st}.") (((|SparseUnivariatePolynomial| (|RealClosure| (|Fraction| |#1|))) (|SparseUnivariatePolynomial| |#1|)) "\\spad{convert(u)} converts \\spad{u}.") (((|Polynomial| (|RealClosure| (|Fraction| |#1|))) (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#3|))) "\\spad{convert(q)} converts \\spad{q}.") (((|Polynomial| (|RealClosure| (|Fraction| |#1|))) (|Polynomial| |#1|)) "\\spad{convert(p)} converts \\spad{p}.") (((|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#3|)) (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) "\\spad{convert(q)} converts \\spad{q}.")) (|squareFree| (((|List| (|SquareFreeRegularTriangularSet| |#1| (|IndexedExponents| (|OrderedVariableList| |#3|)) (|OrderedVariableList| |#3|) (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#3|)))) (|RegularChain| |#1| |#2|)) "\\spad{squareFree(ts)} returns the square-free factorization of \\spad{ts}. Moreover, each factor is a Lazard triangular set and the decomposition is a Kalkbrener split of \\spad{ts}, which is enough here for the matter of solving zero-dimensional algebraic systems. WARNING. \\spad{ts} is not checked to be zero-dimensional.")) (|positiveSolve| (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|List| (|Polynomial| |#1|))) "\\spad{positiveSolve(lp)} returns the same as \\spad{positiveSolve(lp,false,false)}.") (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|List| (|Polynomial| |#1|)) (|Boolean|)) "\\spad{positiveSolve(lp)} returns the same as \\spad{positiveSolve(lp,info?,false)}.") (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|List| (|Polynomial| |#1|)) (|Boolean|) (|Boolean|)) "\\spad{positiveSolve(lp,info?,lextri?)} returns the set of the points in the variety associated with \\spad{lp} whose coordinates are (real) strictly positive. Moreover, if \\spad{info?} is \\spad{true} then some information is displayed during decomposition into regular chains. If \\spad{lextri?} is \\spad{true} then the lexTriangular algorithm is called from the \\spadtype{LexTriangularPackage} constructor (see zeroSetSplit from LexTriangularPackage(lp,false)). Otherwise, the triangular decomposition is computed directly from the input system by using the zeroSetSplit from \\spadtype{RegularChain}. WARNING. For each set of coordinates given by \\spad{positiveSolve(lp,info?,lextri?)} the ordering of the indeterminates is reversed w.r.t. \\spad{ls}.") (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|RegularChain| |#1| |#2|)) "\\spad{positiveSolve(ts)} returns the points of the regular set of \\spad{ts} with (real) strictly positive coordinates.")) (|realSolve| (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|List| (|Polynomial| |#1|))) "\\spad{realSolve(lp)} returns the same as \\spad{realSolve(ts,false,false,false)}") (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|List| (|Polynomial| |#1|)) (|Boolean|)) "\\spad{realSolve(ts,info?)} returns the same as \\spad{realSolve(ts,info?,false,false)}.") (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|List| (|Polynomial| |#1|)) (|Boolean|) (|Boolean|)) "\\spad{realSolve(ts,info?,check?)} returns the same as \\spad{realSolve(ts,info?,check?,false)}.") (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|List| (|Polynomial| |#1|)) (|Boolean|) (|Boolean|) (|Boolean|)) "\\spad{realSolve(ts,info?,check?,lextri?)} returns the set of the points in the variety associated with \\spad{lp} whose coordinates are all real. Moreover, if \\spad{info?} is \\spad{true} then some information is displayed during decomposition into regular chains. If \\spad{check?} is \\spad{true} then the result is checked. If \\spad{lextri?} is \\spad{true} then the lexTriangular algorithm is called from the \\spadtype{LexTriangularPackage} constructor (see zeroSetSplit from LexTriangularPackage(lp,false)). Otherwise, the triangular decomposition is computed directly from the input system by using the zeroSetSplit from \\spadtype{RegularChain}. WARNING. For each set of coordinates given by \\spad{realSolve(ts,info?,check?,lextri?)} the ordering of the indeterminates is reversed w.r.t. \\spad{ls}.") (((|List| (|List| (|RealClosure| (|Fraction| |#1|)))) (|RegularChain| |#1| |#2|)) "\\spad{realSolve(ts)} returns the set of the points in the regular zero set of \\spad{ts} whose coordinates are all real. WARNING. For each set of coordinates given by \\spad{realSolve(ts)} the ordering of the indeterminates is reversed w.r.t. \\spad{ls}.")) (|univariateSolve| (((|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| |#1|)) (|:| |coordinates| (|List| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|))) "\\spad{univariateSolve(lp)} returns the same as \\spad{univariateSolve(lp,false,false,false)}.") (((|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| |#1|)) (|:| |coordinates| (|List| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|)) (|Boolean|)) "\\spad{univariateSolve(lp,info?)} returns the same as \\spad{univariateSolve(lp,info?,false,false)}.") (((|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| |#1|)) (|:| |coordinates| (|List| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|)) (|Boolean|) (|Boolean|)) "\\spad{univariateSolve(lp,info?,check?)} returns the same as \\spad{univariateSolve(lp,info?,check?,false)}.") (((|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| |#1|)) (|:| |coordinates| (|List| (|Polynomial| |#1|))))) (|List| (|Polynomial| |#1|)) (|Boolean|) (|Boolean|) (|Boolean|)) "\\spad{univariateSolve(lp,info?,check?,lextri?)} returns a univariate representation of the variety associated with \\spad{lp}. Moreover, if \\spad{info?} is \\spad{true} then some information is displayed during the decomposition into regular chains. If \\spad{check?} is \\spad{true} then the result is checked. See rur from RationalUnivariateRepresentationPackage(lp,true). If \\spad{lextri?} is \\spad{true} then the lexTriangular algorithm is called from the \\spadtype{LexTriangularPackage} constructor (see zeroSetSplit from LexTriangularPackage(lp,false)). Otherwise, the triangular decomposition is computed directly from the input system by using the zeroSetSplit from RegularChain") (((|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| |#1|)) (|:| |coordinates| (|List| (|Polynomial| |#1|))))) (|RegularChain| |#1| |#2|)) "\\spad{univariateSolve(ts)} returns a univariate representation of \\spad{ts}. See rur from RationalUnivariateRepresentationPackage(lp,true).")) (|triangSolve| (((|List| (|RegularChain| |#1| |#2|)) (|List| (|Polynomial| |#1|))) "\\spad{triangSolve(lp)} returns the same as \\spad{triangSolve(lp,false,false)}") (((|List| (|RegularChain| |#1| |#2|)) (|List| (|Polynomial| |#1|)) (|Boolean|)) "\\spad{triangSolve(lp,info?)} returns the same as \\spad{triangSolve(lp,false)}") (((|List| (|RegularChain| |#1| |#2|)) (|List| (|Polynomial| |#1|)) (|Boolean|) (|Boolean|)) "\\spad{triangSolve(lp,info?,lextri?)} decomposes the variety associated with \\axiom{lp} into regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{lp} needs to generate a zero-dimensional ideal. If \\axiom{lp} is not zero-dimensional then the result is only a decomposition of its zero-set in the sense of the closure (w.r.t. Zarisky topology). Moreover, if \\spad{info?} is \\spad{true} then some information is displayed during the computations. See zeroSetSplit from RegularTriangularSetCategory(lp,true,info?). If \\spad{lextri?} is \\spad{true} then the lexTriangular algorithm is called from the \\spadtype{LexTriangularPackage} constructor (see zeroSetSplit from LexTriangularPackage(lp,false)). Otherwise, the triangular decomposition is computed directly from the input system by using the zeroSetSplit from RegularChain"))) 
 NIL 
 NIL 
-(-1284 R) 
+(-1305 R) 
 ((|constructor| (NIL "Test for linear dependence over the integers.")) (|solveLinearlyOverQ| (((|Union| (|Vector| (|Fraction| (|Integer|))) "failed") (|Vector| |#1|) |#1|) "\\spad{solveLinearlyOverQ([v1,...,vn], u)} returns \\spad{[c1,...,cn]} such that \\spad{c1*v1 + \\spad{...} + cn*vn = u}, \"failed\" if no such rational numbers ci's exist.")) (|linearDependenceOverZ| (((|Union| (|Vector| (|Integer|)) "failed") (|Vector| |#1|)) "\\spad{linearlyDependenceOverZ([v1,...,vn])} returns \\spad{[c1,...,cn]} if \\spad{c1*v1 + \\spad{...} + cn*vn = 0} and not all the ci's are 0, \"failed\" if the vi's are linearly independent over the integers.")) (|linearlyDependentOverZ?| (((|Boolean|) (|Vector| |#1|)) "\\spad{linearlyDependentOverZ?([v1,...,vn])} returns \\spad{true} if the vi's are linearly dependent over the integers, \\spad{false} otherwise."))) 
 NIL 
 NIL 
-(-1285 |p|) 
+(-1306 |p|) 
 ((|constructor| (NIL "IntegerMod(n) creates the ring of integers reduced modulo the integer \\spad{n.}"))) 
-(((-4604 "*") . T) (-4596 . T) (-4597 . T) (-4599 . T)) 
+(((-4627 "*") . T) (-4619 . T) (-4620 . T) (-4622 . T)) 
 NIL 
 NIL 
 NIL 
@@ -5092,4 +5176,4 @@ NIL
 NIL 
 NIL 
 NIL 
-((-1290 NIL 2388970 2388975 2388980 2388985) (-3 NIL 2388950 2388955 2388960 2388965) (-2 NIL 2388930 2388935 2388940 2388945) (-1 NIL 2388910 2388915 2388920 2388925) (0 NIL 2388890 2388895 2388900 2388905) (-1285 "bookvol10.3.pamphlet" 2388707 2388720 2388828 2388885) (-1284 "bookvol10.4.pamphlet" 2387827 2387838 2388697 2388702) (-1283 "bookvol10.4.pamphlet" 2378443 2378465 2387817 2387822) (-1282 "bookvol10.4.pamphlet" 2377940 2377951 2378433 2378438) (-1281 "bookvol10.3.pamphlet" 2377175 2377195 2377796 2377865) (-1280 "bookvol10.3.pamphlet" 2374908 2374921 2376893 2376992) (-1279 "bookvol10.3.pamphlet" 2374480 2374491 2374764 2374833) (-1278 "bookvol10.2.pamphlet" 2373798 2373814 2374406 2374475) (-1277 "bookvol10.3.pamphlet" 2372463 2372483 2373578 2373647) (-1276 "bookvol10.2.pamphlet" 2370927 2370942 2372365 2372458) (-1275 NIL 2369371 2369388 2370811 2370816) (-1274 "bookvol10.2.pamphlet" 2366406 2366422 2369297 2369366) (-1273 "bookvol10.4.pamphlet" 2365805 2365831 2366396 2366401) (-1272 "bookvol10.3.pamphlet" 2365436 2365452 2365661 2365730) (-1271 "bookvol10.2.pamphlet" 2365135 2365146 2365392 2365431) (-1270 "bookvol10.3.pamphlet" 2361803 2361820 2364837 2364864) (-1269 "bookvol10.3.pamphlet" 2360833 2360877 2361661 2361728) (-1268 "bookvol10.4.pamphlet" 2358408 2358430 2360823 2360828) (-1267 "bookvol10.4.pamphlet" 2356672 2356683 2358398 2358403) (-1266 "bookvol10.2.pamphlet" 2356345 2356356 2356640 2356667) (-1265 NIL 2356038 2356051 2356335 2356340) (-1264 "bookvol10.3.pamphlet" 2355632 2355641 2356028 2356033) (-1263 "bookvol10.4.pamphlet" 2353348 2353357 2355622 2355627) (-1262 "bookvol10.4.pamphlet" 2348608 2348617 2353338 2353343) (-1261 "bookvol10.3.pamphlet" 2332824 2332833 2348598 2348603) (-1260 "bookvol10.3.pamphlet" 2321015 2321024 2332814 2332819) (-1259 "bookvol10.3.pamphlet" 2319912 2319923 2320163 2320190) (-1258 "bookvol10.4.pamphlet" 2318586 2318599 2319902 2319907) (-1257 "bookvol10.2.pamphlet" 2316586 2316597 2318542 2318581) (-1256 NIL 2314405 2314418 2316363 2316368) (-1255 "bookvol10.3.pamphlet" 2314185 2314200 2314395 2314400) (-1254 "bookvol10.3.pamphlet" 2309361 2309383 2312652 2312749) (-1253 "bookvol10.4.pamphlet" 2309264 2309292 2309351 2309356) (-1252 "bookvol10.4.pamphlet" 2308558 2308582 2309220 2309225) (-1251 "bookvol10.4.pamphlet" 2306748 2306768 2308548 2308553) (-1250 "bookvol10.3.pamphlet" 2301547 2301575 2305215 2305312) (-1249 "bookvol10.2.pamphlet" 2298864 2298880 2301445 2301542) (-1248 NIL 2295825 2295843 2298408 2298413) (-1247 "bookvol10.4.pamphlet" 2295450 2295485 2295815 2295820) (-1246 "bookvol10.2.pamphlet" 2290734 2290745 2295430 2295445) (-1245 NIL 2285992 2286005 2290690 2290695) (-1244 "bookvol10.3.pamphlet" 2283659 2283685 2285073 2285206) (-1243 "bookvol10.3.pamphlet" 2281210 2281238 2281791 2281940) (-1242 "bookvol10.3.pamphlet" 2278971 2278991 2279342 2279491) (-1241 "bookvol10.2.pamphlet" 2277441 2277461 2278817 2278966) (-1240 NIL 2276053 2276075 2277431 2277436) (-1239 "bookvol10.2.pamphlet" 2274644 2274660 2275899 2276048) (-1238 "bookvol10.4.pamphlet" 2274187 2274240 2274634 2274639) (-1237 "bookvol10.4.pamphlet" 2272615 2272629 2274177 2274182) (-1236 "bookvol10.2.pamphlet" 2270185 2270209 2272513 2272610) (-1235 NIL 2267461 2267487 2269791 2269796) (-1234 "bookvol10.2.pamphlet" 2262313 2262324 2267303 2267456) (-1233 NIL 2257057 2257070 2262049 2262054) (-1232 "bookvol10.4.pamphlet" 2256522 2256541 2257047 2257052) (-1231 "bookvol10.3.pamphlet" 2253481 2253496 2254072 2254225) (-1230 "bookvol10.4.pamphlet" 2252415 2252428 2253471 2253476) (-1229 "bookvol10.4.pamphlet" 2251980 2251994 2252405 2252410) (-1228 "bookvol10.4.pamphlet" 2250221 2250235 2251970 2251975) (-1227 "bookvol10.4.pamphlet" 2249422 2249438 2250211 2250216) (-1226 "bookvol10.4.pamphlet" 2248824 2248845 2249412 2249417) (-1225 "bookvol10.3.pamphlet" 2248177 2248188 2248743 2248748) (-1224 "bookvol10.4.pamphlet" 2247684 2247697 2248133 2248138) (-1223 "bookvol10.4.pamphlet" 2246807 2246819 2247674 2247679) (-1222 "bookvol10.3.pamphlet" 2237479 2237507 2238452 2238881) (-1221 "bookvol10.3.pamphlet" 2231520 2231540 2231888 2232037) (-1220 "bookvol10.2.pamphlet" 2229113 2229133 2231340 2231515) (-1219 NIL 2226840 2226862 2229069 2229074) (-1218 "bookvol10.2.pamphlet" 2225050 2225066 2226686 2226835) (-1217 "bookvol10.4.pamphlet" 2224594 2224647 2225040 2225045) (-1216 "bookvol10.3.pamphlet" 2222987 2223003 2223061 2223158) (-1215 "bookvol10.4.pamphlet" 2222902 2222918 2222977 2222982) (-1214 "bookvol10.2.pamphlet" 2221971 2221980 2222828 2222897) (-1213 NIL 2221102 2221113 2221961 2221966) (-1212 "bookvol10.4.pamphlet" 2219913 2219922 2221092 2221097) (-1211 "bookvol10.4.pamphlet" 2217439 2217450 2219869 2219874) (-1210 "bookvol10.3.pamphlet" 2216670 2216679 2216873 2216900) (-1209 "bookvol10.3.pamphlet" 2215915 2215924 2216302 2216329) (-1208 "bookvol10.3.pamphlet" 2215145 2215154 2215349 2215376) (-1207 "bookvol10.3.pamphlet" 2214388 2214397 2214777 2214804) (-1206 "bookvol10.3.pamphlet" 2213618 2213627 2213822 2213849) (-1205 "bookvol10.3.pamphlet" 2212861 2212870 2213250 2213277) (-1204 "bookvol10.2.pamphlet" 2212783 2212792 2212841 2212856) (-1203 "bookvol10.4.pamphlet" 2211443 2211458 2212773 2212778) (-1202 "bookvol10.3.pamphlet" 2210452 2210463 2211398 2211403) (-1201 "bookvol10.4.pamphlet" 2207346 2207355 2210442 2210447) (-1200 "bookvol10.3.pamphlet" 2206036 2206053 2207336 2207341) (-1199 "bookvol10.3.pamphlet" 2204627 2204643 2205601 2205698) (-1198 "bookvol10.2.pamphlet" 2194183 2194200 2204583 2204622) (-1197 NIL 2183737 2183756 2194139 2194144) (-1196 "bookvol10.4.pamphlet" 2178193 2178210 2183443 2183448) (-1195 "bookvol10.4.pamphlet" 2177164 2177189 2178183 2178188) (-1194 "bookvol10.4.pamphlet" 2175661 2175678 2177154 2177159) (-1193 "bookvol10.2.pamphlet" 2175173 2175182 2175651 2175656) (-1192 NIL 2174683 2174694 2175163 2175168) (-1191 "bookvol10.3.pamphlet" 2172896 2172907 2174513 2174540) (-1190 "bookvol10.2.pamphlet" 2172743 2172752 2172886 2172891) (-1189 NIL 2172588 2172599 2172733 2172738) (-1188 "bookvol10.4.pamphlet" 2172266 2172275 2172578 2172583) (-1187 "bookvol10.4.pamphlet" 2171929 2171940 2172256 2172261) (-1186 "bookvol10.3.pamphlet" 2170508 2170517 2171919 2171924) (-1185 "bookvol10.3.pamphlet" 2167645 2167654 2170498 2170503) (-1184 "bookvol10.4.pamphlet" 2167201 2167212 2167635 2167640) (-1183 "bookvol10.4.pamphlet" 2166762 2166771 2167191 2167196) (-1182 "bookvol10.4.pamphlet" 2164953 2164976 2166752 2166757) (-1181 "bookvol10.2.pamphlet" 2163975 2163998 2164921 2164948) (-1180 NIL 2163017 2163042 2163965 2163970) (-1179 "bookvol10.4.pamphlet" 2162393 2162404 2163007 2163012) (-1178 "bookvol10.3.pamphlet" 2161366 2161389 2161636 2161663) (-1177 "bookvol10.3.pamphlet" 2160856 2160867 2161356 2161361) (-1176 "bookvol10.4.pamphlet" 2157774 2157785 2160846 2160851) (-1175 "bookvol10.4.pamphlet" 2154405 2154416 2157764 2157769) (-1174 "bookvol10.3.pamphlet" 2152502 2152511 2154395 2154400) (-1173 "bookvol10.3.pamphlet" 2148567 2148576 2152492 2152497) (-1172 "bookvol10.3.pamphlet" 2147574 2147585 2147656 2147783) (-1171 "bookvol10.4.pamphlet" 2146995 2147006 2147564 2147569) (-1170 "bookvol10.3.pamphlet" 2144457 2144466 2146985 2146990) (-1169 "bookvol10.3.pamphlet" 2141203 2141212 2144447 2144452) (-1168 "bookvol10.3.pamphlet" 2138234 2138262 2139670 2139767) (-1167 "bookvol10.3.pamphlet" 2135368 2135396 2136366 2136515) (-1166 "bookvol10.3.pamphlet" 2132063 2132074 2132918 2133071) (-1165 "bookvol10.4.pamphlet" 2131183 2131201 2132053 2132058) (-1164 "bookvol10.3.pamphlet" 2128627 2128638 2128696 2128849) (-1163 "bookvol10.4.pamphlet" 2128021 2128034 2128617 2128622) (-1162 "bookvol10.4.pamphlet" 2126623 2126634 2128011 2128016) (-1161 "bookvol10.4.pamphlet" 2126301 2126318 2126613 2126618) (-1160 "bookvol10.3.pamphlet" 2116960 2116988 2117946 2118375) (-1159 "bookvol10.3.pamphlet" 2116642 2116657 2116950 2116955) (-1158 "bookvol10.3.pamphlet" 2108997 2109012 2116632 2116637) (-1157 "bookvol10.4.pamphlet" 2108169 2108183 2108953 2108958) (-1156 "bookvol10.4.pamphlet" 2104270 2104286 2108159 2108164) (-1155 "bookvol10.4.pamphlet" 2100740 2100756 2104260 2104265) (-1154 "bookvol10.4.pamphlet" 2093312 2093323 2100621 2100626) (-1153 "bookvol10.3.pamphlet" 2092391 2092408 2092540 2092567) (-1152 "bookvol10.3.pamphlet" 2091774 2091783 2091872 2091899) (-1151 "bookvol10.2.pamphlet" 2091550 2091559 2091730 2091769) (-1150 "bookvol10.3.pamphlet" 2087138 2087149 2091298 2091313) (-1149 "bookvol10.4.pamphlet" 2086479 2086494 2087128 2087133) (-1148 "bookvol10.4.pamphlet" 2085052 2085065 2086469 2086474) (-1147 "bookvol10.4.pamphlet" 2084560 2084571 2085042 2085047) (-1146 "bookvol10.4.pamphlet" 2084245 2084256 2084550 2084555) (-1145 "bookvol10.4.pamphlet" 2083181 2083197 2084235 2084240) (-1144 "bookvol10.2.pamphlet" 2082407 2082416 2083171 2083176) (-1143 "bookvol10.3.pamphlet" 2081497 2081525 2081662 2081677) (-1142 "bookvol10.2.pamphlet" 2080596 2080607 2081477 2081492) (-1141 NIL 2079703 2079716 2080586 2080591) (-1140 "bookvol10.3.pamphlet" 2075740 2075751 2079533 2079560) (-1139 "bookvol10.3.pamphlet" 2073987 2074004 2075442 2075469) (-1138 "bookvol10.4.pamphlet" 2072753 2072773 2073977 2073982) (-1137 "bookvol10.2.pamphlet" 2068090 2068099 2072709 2072748) (-1136 NIL 2063459 2063470 2068080 2068085) (-1135 "bookvol10.3.pamphlet" 2061141 2061159 2062047 2062134) (-1134 "bookvol10.3.pamphlet" 2056648 2056661 2060892 2060919) (-1133 "bookvol10.3.pamphlet" 2053696 2053709 2056638 2056643) (-1132 "bookvol10.2.pamphlet" 2052507 2052516 2053686 2053691) (-1131 "bookvol10.4.pamphlet" 2051076 2051085 2052497 2052502) (-1130 "bookvol10.2.pamphlet" 2035466 2035477 2051066 2051071) (-1129 "bookvol10.3.pamphlet" 2035248 2035259 2035456 2035461) (-1128 "bookvol10.4.pamphlet" 2034797 2034810 2035204 2035209) (-1127 "bookvol10.4.pamphlet" 2032392 2032403 2034787 2034792) (-1126 "bookvol10.4.pamphlet" 2030981 2030992 2032382 2032387) (-1125 "bookvol10.4.pamphlet" 2025469 2025480 2030971 2030976) (-1124 "bookvol10.4.pamphlet" 2023933 2023951 2025459 2025464) (-1123 "bookvol10.2.pamphlet" 2023704 2023721 2023889 2023928) (-1122 "bookvol10.3.pamphlet" 2021858 2021884 2023269 2023366) (-1121 "bookvol10.3.pamphlet" 2019314 2019334 2019687 2019814) (-1120 "bookvol10.4.pamphlet" 2018151 2018176 2019304 2019309) (-1119 "bookvol10.2.pamphlet" 2016259 2016289 2018083 2018146) (-1118 NIL 2014311 2014343 2016137 2016142) (-1117 "bookvol10.2.pamphlet" 2012913 2012924 2014267 2014306) (-1116 "bookvol10.3.pamphlet" 2011276 2011285 2012779 2012908) (-1115 "bookvol10.4.pamphlet" 2011019 2011028 2011266 2011271) (-1114 "bookvol10.4.pamphlet" 2010109 2010120 2011009 2011014) (-1113 "bookvol10.4.pamphlet" 2009368 2009385 2010099 2010104) (-1112 "bookvol10.4.pamphlet" 2007332 2007347 2009324 2009329) (-1111 "bookvol10.3.pamphlet" 1999045 1999072 1999547 1999678) (-1110 "bookvol10.2.pamphlet" 1998357 1998366 1999035 1999040) (-1109 NIL 1997667 1997678 1998347 1998352) (-1108 "bookvol10.4.pamphlet" 1991179 1991188 1997657 1997662) (-1107 "bookvol10.2.pamphlet" 1990742 1990759 1991135 1991174) (-1106 "bookvol10.4.pamphlet" 1990441 1990461 1990732 1990737) (-1105 "bookvol10.4.pamphlet" 1986358 1986378 1990431 1990436) (-1104 "bookvol10.3.pamphlet" 1985819 1985833 1986348 1986353) (-1103 "bookvol10.3.pamphlet" 1985662 1985702 1985809 1985814) (-1102 "bookvol10.3.pamphlet" 1985554 1985563 1985652 1985657) (-1101 "bookvol10.2.pamphlet" 1982805 1982845 1985544 1985549) (-1100 "bookvol10.3.pamphlet" 1981169 1981180 1982282 1982321) (-1099 "bookvol10.3.pamphlet" 1979649 1979666 1981159 1981164) (-1098 "bookvol10.2.pamphlet" 1979139 1979148 1979639 1979644) (-1097 NIL 1978627 1978638 1979129 1979134) (-1096 "bookvol10.2.pamphlet" 1978518 1978527 1978617 1978622) (-1095 "bookvol10.2.pamphlet" 1975408 1975419 1978486 1978513) (-1094 NIL 1972318 1972331 1975398 1975403) (-1093 "bookvol10.2.pamphlet" 1971380 1971393 1972298 1972313) (-1092 "bookvol10.3.pamphlet" 1971193 1971204 1971299 1971304) (-1091 "bookvol10.2.pamphlet" 1969981 1969992 1971173 1971188) (-1090 "bookvol10.3.pamphlet" 1969067 1969078 1969936 1969941) (-1089 "bookvol10.4.pamphlet" 1968773 1968786 1969057 1969062) (-1088 "bookvol10.4.pamphlet" 1968192 1968205 1968729 1968734) (-1087 "bookvol10.3.pamphlet" 1967490 1967501 1968182 1968187) (-1086 "bookvol10.3.pamphlet" 1964894 1964905 1965171 1965298) (-1085 "bookvol10.3.pamphlet" 1961365 1961376 1964862 1964889) (-1084 "bookvol10.4.pamphlet" 1959468 1959479 1961355 1961360) (-1083 "bookvol10.4.pamphlet" 1958317 1958328 1959458 1959463) (-1082 "bookvol10.3.pamphlet" 1958189 1958198 1958307 1958312) (-1081 "bookvol10.4.pamphlet" 1957902 1957922 1958179 1958184) (-1080 "bookvol10.3.pamphlet" 1956031 1956047 1956688 1956823) (-1079 "bookvol10.4.pamphlet" 1955732 1955752 1956021 1956026) (-1078 "bookvol10.4.pamphlet" 1953468 1953484 1955722 1955727) (-1077 "bookvol10.3.pamphlet" 1952900 1952924 1953458 1953463) (-1076 "bookvol10.3.pamphlet" 1951082 1951106 1952890 1952895) (-1075 "bookvol10.3.pamphlet" 1950934 1950947 1951072 1951077) (-1074 "bookvol10.4.pamphlet" 1948304 1948324 1950924 1950929) (-1073 "bookvol10.2.pamphlet" 1939142 1939159 1948260 1948299) (-1072 NIL 1930012 1930031 1939132 1939137) (-1071 "bookvol10.4.pamphlet" 1928765 1928785 1930002 1930007) (-1070 "bookvol10.2.pamphlet" 1927171 1927201 1928755 1928760) (-1069 NIL 1925575 1925607 1927161 1927166) (-1068 "bookvol10.2.pamphlet" 1908817 1908832 1925443 1925570) (-1067 NIL 1891772 1891789 1908400 1908405) (-1066 "bookvol10.3.pamphlet" 1888257 1888266 1891001 1891028) (-1065 "bookvol10.3.pamphlet" 1887504 1887513 1888123 1888252) (-1064 "bookvol10.3.pamphlet" 1886638 1886670 1887494 1887499) (-1063 "bookvol10.2.pamphlet" 1885461 1885470 1886540 1886633) (-1062 NIL 1884370 1884381 1885451 1885456) (-1061 "bookvol10.2.pamphlet" 1883890 1883899 1884360 1884365) (-1060 "bookvol10.2.pamphlet" 1883405 1883416 1883880 1883885) (-1059 "bookvol10.4.pamphlet" 1882833 1882890 1883395 1883400) (-1058 "bookvol10.3.pamphlet" 1881568 1881587 1882056 1882095) (-1057 "bookvol10.2.pamphlet" 1877204 1877235 1881512 1881563) (-1056 NIL 1872742 1872775 1877052 1877057) (-1055 "bookvol10.4.pamphlet" 1872630 1872650 1872732 1872737) (-1054 "bookvol10.2.pamphlet" 1871989 1871998 1872610 1872625) (-1053 NIL 1871356 1871367 1871979 1871984) (-1052 "bookvol10.4.pamphlet" 1870384 1870393 1871346 1871351) (-1051 "bookvol10.3.pamphlet" 1869063 1869079 1869944 1869971) (-1050 "bookvol10.4.pamphlet" 1867113 1867124 1869053 1869058) (-1049 "bookvol10.4.pamphlet" 1864769 1864780 1867103 1867108) (-1048 "bookvol10.4.pamphlet" 1864231 1864242 1864759 1864764) (-1047 "bookvol10.4.pamphlet" 1863966 1863978 1864221 1864226) (-1046 "bookvol10.4.pamphlet" 1862962 1862971 1863956 1863961) (-1045 "bookvol10.4.pamphlet" 1862381 1862394 1862952 1862957) (-1044 "bookvol10.2.pamphlet" 1861723 1861734 1862371 1862376) (-1043 NIL 1861063 1861076 1861713 1861718) (-1042 "bookvol10.3.pamphlet" 1859707 1859716 1860292 1860319) (-1041 "bookvol10.3.pamphlet" 1859054 1859101 1859645 1859702) (-1040 "bookvol10.4.pamphlet" 1858380 1858391 1859044 1859049) (-1039 "bookvol10.4.pamphlet" 1858111 1858122 1858370 1858375) (-1038 "bookvol10.4.pamphlet" 1855667 1855676 1858101 1858106) (-1037 "bookvol10.4.pamphlet" 1855366 1855377 1855657 1855662) (-1036 "bookvol10.4.pamphlet" 1845386 1845397 1855208 1855213) (-1035 "bookvol10.4.pamphlet" 1839774 1839785 1845336 1845341) (-1034 "bookvol10.3.pamphlet" 1838069 1838086 1839476 1839503) (-1033 "bookvol10.3.pamphlet" 1837419 1837430 1838024 1838029) (-1032 "bookvol10.4.pamphlet" 1836549 1836566 1837409 1837414) (-1031 "bookvol10.4.pamphlet" 1834956 1834973 1836504 1836509) (-1030 "bookvol10.3.pamphlet" 1833789 1833809 1834443 1834536) (-1029 "bookvol10.4.pamphlet" 1832362 1832371 1833779 1833784) (-1028 "bookvol10.2.pamphlet" 1832246 1832255 1832352 1832357) (-1027 "bookvol10.4.pamphlet" 1829597 1829612 1832236 1832241) (-1026 "bookvol10.4.pamphlet" 1826506 1826521 1829587 1829592) (-1025 "bookvol10.4.pamphlet" 1826255 1826280 1826496 1826501) (-1024 "bookvol10.4.pamphlet" 1825822 1825833 1826245 1826250) (-1023 "bookvol10.4.pamphlet" 1824676 1824694 1825812 1825817) (-1022 "bookvol10.4.pamphlet" 1822641 1822659 1824666 1824671) (-1021 "bookvol10.4.pamphlet" 1821882 1821899 1822631 1822636) (-1020 "bookvol10.4.pamphlet" 1820938 1820955 1821872 1821877) (-1019 "bookvol10.2.pamphlet" 1818267 1818276 1820840 1820933) (-1018 NIL 1815682 1815693 1818257 1818262) (-1017 "bookvol10.2.pamphlet" 1813655 1813666 1815662 1815677) (-1016 NIL 1811565 1811578 1813574 1813579) (-1015 "bookvol10.4.pamphlet" 1810986 1810997 1811555 1811560) (-1014 "bookvol10.4.pamphlet" 1810170 1810182 1810976 1810981) (-1013 "bookvol10.4.pamphlet" 1809527 1809536 1810160 1810165) (-1012 "bookvol10.4.pamphlet" 1809283 1809292 1809517 1809522) (-1011 "bookvol10.3.pamphlet" 1806098 1806112 1807750 1807843) (-1010 "bookvol10.3.pamphlet" 1804527 1804564 1804630 1804786) (-1009 "bookvol10.2.pamphlet" 1804158 1804167 1804517 1804522) (-1008 NIL 1803787 1803798 1804148 1804153) (-1007 "bookvol10.3.pamphlet" 1799604 1799615 1803617 1803644) (-1006 "bookvol10.3.pamphlet" 1798234 1798245 1798528 1798593) (-1005 "bookvol10.4.pamphlet" 1797638 1797657 1798224 1798229) (-1004 "bookvol10.2.pamphlet" 1795844 1795855 1797568 1797633) (-1003 NIL 1793801 1793814 1795527 1795532) (-1002 "bookvol10.2.pamphlet" 1792614 1792625 1793757 1793796) (-1001 "bookvol10.3.pamphlet" 1792082 1792097 1792604 1792609) (-1000 "bookvol10.2.pamphlet" 1790776 1790787 1791972 1792077) (-999 NIL 1789074 1789086 1790271 1790276) (-998 "bookvol10.4.pamphlet" 1788775 1788791 1789064 1789069) (-997 "bookvol10.3.pamphlet" 1788350 1788358 1788765 1788770) (-996 "bookvol10.4.pamphlet" 1784334 1784353 1788340 1788345) (-995 "bookvol10.3.pamphlet" 1780507 1780539 1784248 1784253) (-994 "bookvol10.4.pamphlet" 1778519 1778537 1780497 1780502) (-993 "bookvol10.4.pamphlet" 1775847 1775868 1778509 1778514) (-992 "bookvol10.4.pamphlet" 1775184 1775203 1775837 1775842) (-991 "bookvol10.2.pamphlet" 1771463 1771473 1775174 1775179) (-990 "bookvol10.4.pamphlet" 1768589 1768599 1771453 1771458) (-989 "bookvol10.4.pamphlet" 1768408 1768422 1768579 1768584) (-988 "bookvol10.2.pamphlet" 1767500 1767510 1768364 1768403) (-987 "bookvol10.4.pamphlet" 1766811 1766835 1767490 1767495) (-986 "bookvol10.4.pamphlet" 1765681 1765691 1766801 1766806) (-985 "bookvol10.4.pamphlet" 1753190 1753206 1765559 1765564) (-984 "bookvol10.2.pamphlet" 1748045 1748068 1753158 1753185) (-983 NIL 1742886 1742911 1748001 1748006) (-982 "bookvol10.2.pamphlet" 1741911 1741919 1742876 1742881) (-981 "bookvol10.2.pamphlet" 1740674 1740703 1741809 1741906) (-980 NIL 1739527 1739558 1740664 1740669) (-979 "bookvol10.3.pamphlet" 1738330 1738338 1739517 1739522) (-978 "bookvol10.2.pamphlet" 1735825 1735835 1738320 1738325) (-977 "bookvol10.4.pamphlet" 1727494 1727511 1735781 1735786) (-976 "bookvol10.2.pamphlet" 1726917 1726927 1727450 1727489) (-975 "bookvol10.3.pamphlet" 1726801 1726817 1726907 1726912) (-974 "bookvol10.3.pamphlet" 1726691 1726701 1726791 1726796) (-973 "bookvol10.3.pamphlet" 1726581 1726591 1726681 1726686) (-972 "bookvol10.3.pamphlet" 1724020 1724032 1724547 1724602) (-971 "bookvol10.3.pamphlet" 1722418 1722430 1723111 1723238) (-970 "bookvol10.4.pamphlet" 1721672 1721711 1722408 1722413) (-969 "bookvol10.4.pamphlet" 1721424 1721432 1721662 1721667) (-968 "bookvol10.4.pamphlet" 1719657 1719667 1721414 1721419) (-967 "bookvol10.4.pamphlet" 1717744 1717758 1719647 1719652) (-966 "bookvol10.2.pamphlet" 1717355 1717363 1717734 1717739) (-965 "bookvol10.3.pamphlet" 1716608 1716618 1716761 1716788) (-964 "bookvol10.4.pamphlet" 1714714 1714726 1716598 1716603) (-963 "bookvol10.4.pamphlet" 1714080 1714092 1714704 1714709) (-962 "bookvol10.2.pamphlet" 1713445 1713453 1714070 1714075) (-961 "bookvol10.4.pamphlet" 1708254 1708262 1713435 1713440) (-960 "bookvol10.4.pamphlet" 1706998 1707020 1708210 1708215) (-959 "bookvol10.3.pamphlet" 1704316 1704326 1704812 1704939) (-958 "bookvol10.4.pamphlet" 1703605 1703628 1704306 1704311) (-957 "bookvol10.4.pamphlet" 1701615 1701637 1703595 1703600) (-956 "bookvol10.2.pamphlet" 1695045 1695066 1701483 1701610) (-955 NIL 1687777 1687800 1694217 1694222) (-954 "bookvol10.4.pamphlet" 1687223 1687237 1687767 1687772) (-953 "bookvol10.4.pamphlet" 1686829 1686841 1687213 1687218) (-952 "bookvol10.4.pamphlet" 1685870 1685899 1686785 1686790) (-951 "bookvol10.4.pamphlet" 1684618 1684633 1685860 1685865) (-950 "bookvol10.3.pamphlet" 1683679 1683689 1683766 1683793) (-949 "bookvol10.4.pamphlet" 1680351 1680359 1683669 1683674) (-948 "bookvol10.4.pamphlet" 1679172 1679186 1680341 1680346) (-947 "bookvol10.4.pamphlet" 1678729 1678739 1679162 1679167) (-946 "bookvol10.4.pamphlet" 1678328 1678342 1678719 1678724) (-945 "bookvol10.4.pamphlet" 1677848 1677862 1678318 1678323) (-944 "bookvol10.4.pamphlet" 1677343 1677365 1677838 1677843) (-943 "bookvol10.4.pamphlet" 1676423 1676441 1677275 1677280) (-942 "bookvol10.4.pamphlet" 1676008 1676022 1676413 1676418) (-941 "bookvol10.4.pamphlet" 1675587 1675599 1675998 1676003) (-940 "bookvol10.4.pamphlet" 1675167 1675177 1675577 1675582) (-939 "bookvol10.4.pamphlet" 1674752 1674770 1675157 1675162) (-938 "bookvol10.4.pamphlet" 1674062 1674076 1674742 1674747) (-937 "bookvol10.4.pamphlet" 1673129 1673137 1674052 1674057) (-936 "bookvol10.4.pamphlet" 1672153 1672169 1673119 1673124) (-935 "bookvol10.4.pamphlet" 1671051 1671089 1672143 1672148) (-934 "bookvol10.4.pamphlet" 1670831 1670839 1671041 1671046) (-933 "bookvol10.3.pamphlet" 1665683 1665691 1670821 1670826) (-932 "bookvol10.3.pamphlet" 1662297 1662305 1665673 1665678) (-931 "bookvol10.4.pamphlet" 1661448 1661458 1662287 1662292) (-930 "bookvol10.4.pamphlet" 1647561 1647588 1661438 1661443) (-929 "bookvol10.3.pamphlet" 1647468 1647482 1647551 1647556) (-928 "bookvol10.3.pamphlet" 1647379 1647389 1647458 1647463) (-927 "bookvol10.3.pamphlet" 1647290 1647300 1647369 1647374) (-926 "bookvol10.2.pamphlet" 1646332 1646346 1647280 1647285) (-925 "bookvol10.4.pamphlet" 1645954 1645973 1646322 1646327) (-924 "bookvol10.4.pamphlet" 1645738 1645754 1645944 1645949) (-923 "bookvol10.3.pamphlet" 1645362 1645370 1645712 1645733) (-922 "bookvol10.2.pamphlet" 1644342 1644350 1645288 1645357) (-921 "bookvol10.4.pamphlet" 1644087 1644097 1644332 1644337) (-920 "bookvol10.4.pamphlet" 1642705 1642719 1644077 1644082) (-919 "bookvol10.4.pamphlet" 1634663 1634671 1642695 1642700) (-918 "bookvol10.4.pamphlet" 1633237 1633254 1634653 1634658) (-917 "bookvol10.4.pamphlet" 1632288 1632298 1633227 1633232) (-916 "bookvol10.3.pamphlet" 1627858 1627868 1632190 1632283) (-915 "bookvol10.4.pamphlet" 1627205 1627221 1627848 1627853) (-914 "bookvol10.4.pamphlet" 1625346 1625375 1627195 1627200) (-913 "bookvol10.4.pamphlet" 1624716 1624734 1625336 1625341) (-912 "bookvol10.4.pamphlet" 1624137 1624164 1624706 1624711) (-911 "bookvol10.3.pamphlet" 1623812 1623824 1623942 1624035) (-910 "bookvol10.2.pamphlet" 1621520 1621528 1623738 1623807) (-909 NIL 1619256 1619266 1621476 1621481) (-908 "bookvol10.4.pamphlet" 1617163 1617175 1619246 1619251) (-907 "bookvol10.4.pamphlet" 1614823 1614846 1617153 1617158) (-906 "bookvol10.3.pamphlet" 1610145 1610155 1614653 1614668) (-905 "bookvol10.3.pamphlet" 1604910 1604920 1610135 1610140) (-904 "bookvol10.2.pamphlet" 1603573 1603583 1604890 1604905) (-903 "bookvol10.4.pamphlet" 1602332 1602346 1603563 1603568) (-902 "bookvol10.3.pamphlet" 1601604 1601614 1602184 1602189) (-901 "bookvol10.2.pamphlet" 1599979 1599989 1601584 1601599) (-900 NIL 1598362 1598374 1599969 1599974) (-899 "bookvol10.3.pamphlet" 1596541 1596549 1598352 1598357) (-898 "bookvol10.4.pamphlet" 1590617 1590625 1596531 1596536) (-897 "bookvol10.4.pamphlet" 1589969 1589986 1590607 1590612) (-896 "bookvol10.2.pamphlet" 1588119 1588127 1589959 1589964) (-895 "bookvol10.4.pamphlet" 1587854 1587867 1588109 1588114) (-894 "bookvol10.3.pamphlet" 1586496 1586513 1587844 1587849) (-893 "bookvol10.3.pamphlet" 1580781 1580791 1586486 1586491) (-892 "bookvol10.4.pamphlet" 1580512 1580524 1580771 1580776) (-891 "bookvol10.4.pamphlet" 1578810 1578826 1580502 1580507) (-890 "bookvol10.3.pamphlet" 1576471 1576483 1578800 1578805) (-889 "bookvol10.4.pamphlet" 1576183 1576197 1576461 1576466) (-888 "bookvol10.4.pamphlet" 1574404 1574435 1575891 1575896) (-887 "bookvol10.2.pamphlet" 1573843 1573853 1574394 1574399) (-886 "bookvol10.3.pamphlet" 1572953 1572967 1573833 1573838) (-885 "bookvol10.2.pamphlet" 1572659 1572669 1572943 1572948) (-884 "bookvol10.4.pamphlet" 1570177 1570185 1572649 1572654) (-883 "bookvol10.3.pamphlet" 1569635 1569663 1570167 1570172) (-882 "bookvol10.4.pamphlet" 1569428 1569444 1569625 1569630) (-881 "bookvol10.3.pamphlet" 1568886 1568914 1569418 1569423) (-880 "bookvol10.4.pamphlet" 1568673 1568689 1568876 1568881) (-879 "bookvol10.3.pamphlet" 1568143 1568171 1568663 1568668) (-878 "bookvol10.4.pamphlet" 1567930 1567946 1568133 1568138) (-877 "bookvol10.4.pamphlet" 1566753 1566802 1567920 1567925) (-876 "bookvol10.4.pamphlet" 1566167 1566175 1566743 1566748) (-875 "bookvol10.3.pamphlet" 1565175 1565183 1566157 1566162) (-874 "bookvol10.4.pamphlet" 1559622 1559645 1565131 1565136) (-873 "bookvol10.4.pamphlet" 1553503 1553526 1559571 1559576) (-872 "bookvol10.3.pamphlet" 1550879 1550897 1552008 1552101) (-871 "bookvol10.3.pamphlet" 1548942 1548954 1549115 1549208) (-870 "bookvol10.3.pamphlet" 1548687 1548699 1548868 1548937) (-869 "bookvol10.2.pamphlet" 1547233 1547245 1548613 1548682) (-868 "bookvol10.4.pamphlet" 1546178 1546197 1547223 1547228) (-867 "bookvol10.4.pamphlet" 1545183 1545199 1546168 1546173) (-866 "bookvol10.3.pamphlet" 1544018 1544026 1544854 1544947) (-865 "bookvol10.2.pamphlet" 1543002 1543010 1543920 1544013) (-864 "bookvol10.2.pamphlet" 1541301 1541309 1542904 1542997) (-863 "bookvol10.3.pamphlet" 1540260 1540270 1541097 1541190) (-862 "bookvol10.2.pamphlet" 1539247 1539255 1540162 1540255) (-861 "bookvol10.3.pamphlet" 1537786 1537806 1538637 1538730) (-860 "bookvol10.2.pamphlet" 1536762 1536770 1537688 1537781) (-859 "bookvol10.3.pamphlet" 1535770 1535800 1536620 1536687) (-858 "bookvol10.3.pamphlet" 1535551 1535574 1535760 1535765) (-857 "bookvol10.4.pamphlet" 1534677 1534685 1535541 1535546) (-856 "bookvol10.3.pamphlet" 1524091 1524099 1534667 1534672) (-855 "bookvol10.3.pamphlet" 1523696 1523704 1524081 1524086) (-854 "bookvol10.4.pamphlet" 1522153 1522163 1523613 1523618) (-853 "bookvol10.3.pamphlet" 1521503 1521531 1521833 1521872) (-852 "bookvol10.3.pamphlet" 1520788 1520812 1521183 1521222) (-851 "bookvol10.4.pamphlet" 1518548 1518560 1520708 1520713) (-850 "bookvol10.2.pamphlet" 1512560 1512570 1518504 1518543) (-849 NIL 1506462 1506474 1512408 1512413) (-848 "bookvol10.2.pamphlet" 1505602 1505610 1506452 1506457) (-847 NIL 1504740 1504750 1505592 1505597) (-846 "bookvol10.2.pamphlet" 1504074 1504082 1504720 1504735) (-845 NIL 1503416 1503426 1504064 1504069) (-844 "bookvol10.2.pamphlet" 1503140 1503148 1503406 1503411) (-843 "bookvol10.4.pamphlet" 1502287 1502303 1503130 1503135) (-842 "bookvol10.2.pamphlet" 1502221 1502229 1502277 1502282) (-841 "bookvol10.3.pamphlet" 1500713 1500723 1501768 1501797) (-840 "bookvol10.4.pamphlet" 1500065 1500077 1500703 1500708) (-839 "bookvol10.3.pamphlet" 1497831 1497839 1500055 1500060) (-838 "bookvol10.4.pamphlet" 1490283 1490291 1497821 1497826) (-837 "bookvol10.2.pamphlet" 1487761 1487769 1490273 1490278) (-836 "bookvol10.4.pamphlet" 1487316 1487324 1487751 1487756) (-835 "bookvol10.3.pamphlet" 1487058 1487068 1487138 1487205) (-834 "bookvol10.3.pamphlet" 1485834 1485844 1486605 1486634) (-833 "bookvol10.4.pamphlet" 1485325 1485337 1485824 1485829) (-832 "bookvol10.4.pamphlet" 1484375 1484383 1485315 1485320) (-831 "bookvol10.2.pamphlet" 1484159 1484169 1484319 1484370) (-830 "bookvol10.4.pamphlet" 1482835 1482843 1484149 1484154) (-829 "bookvol10.2.pamphlet" 1481910 1481918 1482825 1482830) (-828 "bookvol10.3.pamphlet" 1481327 1481339 1481796 1481835) (-827 "bookvol10.4.pamphlet" 1481161 1481171 1481317 1481322) (-826 "bookvol10.3.pamphlet" 1480714 1480722 1481151 1481156) (-825 "bookvol10.3.pamphlet" 1479766 1479774 1480704 1480709) (-824 "bookvol10.3.pamphlet" 1479112 1479120 1479756 1479761) (-823 "bookvol10.3.pamphlet" 1473855 1473863 1479102 1479107) (-822 "bookvol10.3.pamphlet" 1473272 1473280 1473845 1473850) (-821 "bookvol10.2.pamphlet" 1473049 1473057 1473198 1473267) (-820 "bookvol10.3.pamphlet" 1466676 1466686 1473039 1473044) (-819 "bookvol10.3.pamphlet" 1465959 1465969 1466666 1466671) (-818 "bookvol10.3.pamphlet" 1465407 1465433 1465771 1465920) (-817 "bookvol10.3.pamphlet" 1462767 1462777 1463093 1463220) (-816 "bookvol10.3.pamphlet" 1454624 1454644 1454982 1455113) (-815 "bookvol10.4.pamphlet" 1453149 1453168 1454614 1454619) (-814 "bookvol10.4.pamphlet" 1450609 1450626 1453139 1453144) (-813 "bookvol10.4.pamphlet" 1446538 1446555 1450566 1450571) (-812 "bookvol10.4.pamphlet" 1445899 1445923 1446528 1446533) (-811 "bookvol10.4.pamphlet" 1443343 1443360 1445889 1445894) (-810 "bookvol10.4.pamphlet" 1440358 1440380 1443333 1443338) (-809 "bookvol10.3.pamphlet" 1439014 1439022 1440348 1440353) (-808 "bookvol10.4.pamphlet" 1436272 1436294 1439004 1439009) (-807 "bookvol10.4.pamphlet" 1435638 1435662 1436262 1436267) (-806 "bookvol10.4.pamphlet" 1423382 1423390 1435628 1435633) (-805 "bookvol10.4.pamphlet" 1422801 1422817 1423372 1423377) (-804 "bookvol10.3.pamphlet" 1420204 1420212 1422791 1422796) (-803 "bookvol10.4.pamphlet" 1415521 1415537 1420194 1420199) (-802 "bookvol10.4.pamphlet" 1415030 1415048 1415511 1415516) (-801 "bookvol10.2.pamphlet" 1413421 1413429 1415020 1415025) (-800 "bookvol10.3.pamphlet" 1411589 1411599 1412271 1412310) (-799 "bookvol10.4.pamphlet" 1411235 1411256 1411579 1411584) (-798 "bookvol10.2.pamphlet" 1409183 1409193 1411191 1411230) (-797 NIL 1406856 1406868 1408866 1408871) (-796 "bookvol10.2.pamphlet" 1406706 1406714 1406846 1406851) (-795 "bookvol10.2.pamphlet" 1406472 1406480 1406696 1406701) (-794 "bookvol10.2.pamphlet" 1405826 1405834 1406462 1406467) (-793 "bookvol10.2.pamphlet" 1405689 1405697 1405816 1405821) (-792 "bookvol10.2.pamphlet" 1405553 1405561 1405679 1405684) (-791 "bookvol10.4.pamphlet" 1405280 1405296 1405543 1405548) (-790 "bookvol10.4.pamphlet" 1394009 1394017 1405270 1405275) (-789 "bookvol10.4.pamphlet" 1385576 1385584 1393999 1394004) (-788 "bookvol10.2.pamphlet" 1382931 1382939 1385566 1385571) (-787 "bookvol10.4.pamphlet" 1381773 1381781 1382921 1382926) (-786 "bookvol10.4.pamphlet" 1373931 1373941 1381578 1381583) (-785 "bookvol10.2.pamphlet" 1373338 1373354 1373887 1373926) (-784 "bookvol10.4.pamphlet" 1372889 1372899 1373255 1373260) (-783 "bookvol10.3.pamphlet" 1366790 1366800 1370439 1370592) (-782 "bookvol10.4.pamphlet" 1366186 1366198 1366780 1366785) (-781 "bookvol10.3.pamphlet" 1362396 1362415 1362688 1362815) (-780 "bookvol10.3.pamphlet" 1360920 1360930 1360997 1361090) (-779 "bookvol10.4.pamphlet" 1359310 1359324 1360910 1360915) (-778 "bookvol10.4.pamphlet" 1359202 1359231 1359300 1359305) (-777 "bookvol10.4.pamphlet" 1358450 1358470 1359192 1359197) (-776 "bookvol10.3.pamphlet" 1358338 1358352 1358430 1358445) (-775 "bookvol10.4.pamphlet" 1357932 1357971 1358328 1358333) (-774 "bookvol10.4.pamphlet" 1356780 1356799 1357922 1357927) (-773 "bookvol10.4.pamphlet" 1356462 1356488 1356770 1356775) (-772 "bookvol10.3.pamphlet" 1356203 1356211 1356452 1356457) (-771 "bookvol10.4.pamphlet" 1355879 1355889 1356193 1356198) (-770 "bookvol10.4.pamphlet" 1355336 1355352 1355869 1355874) (-769 "bookvol10.3.pamphlet" 1354226 1354234 1355310 1355331) (-768 "bookvol10.4.pamphlet" 1352852 1352862 1354216 1354221) (-767 "bookvol10.3.pamphlet" 1350540 1350548 1352842 1352847) (-766 "bookvol10.4.pamphlet" 1348008 1348025 1350530 1350535) (-765 "bookvol10.4.pamphlet" 1347327 1347341 1347998 1348003) (-764 "bookvol10.4.pamphlet" 1345467 1345483 1347317 1347322) (-763 "bookvol10.4.pamphlet" 1345124 1345138 1345457 1345462) (-762 "bookvol10.4.pamphlet" 1343302 1343316 1345114 1345119) (-761 "bookvol10.2.pamphlet" 1342900 1342908 1343292 1343297) (-760 NIL 1342496 1342506 1342890 1342895) (-759 "bookvol10.2.pamphlet" 1341874 1341882 1342486 1342491) (-758 NIL 1341250 1341260 1341864 1341869) (-757 "bookvol10.4.pamphlet" 1340327 1340335 1341240 1341245) (-756 "bookvol10.4.pamphlet" 1330769 1330777 1340317 1340322) (-755 "bookvol10.4.pamphlet" 1329269 1329277 1330759 1330764) (-754 "bookvol10.4.pamphlet" 1323733 1323741 1329259 1329264) (-753 "bookvol10.4.pamphlet" 1317889 1317897 1323723 1323728) (-752 "bookvol10.4.pamphlet" 1313699 1313707 1317879 1317884) (-751 "bookvol10.4.pamphlet" 1307493 1307501 1313689 1313694) (-750 "bookvol10.4.pamphlet" 1298250 1298258 1307483 1307488) (-749 "bookvol10.4.pamphlet" 1294341 1294349 1298240 1298245) (-748 "bookvol10.4.pamphlet" 1292380 1292388 1294331 1294336) (-747 "bookvol10.4.pamphlet" 1285186 1285194 1292370 1292375) (-746 "bookvol10.4.pamphlet" 1279730 1279738 1285176 1285181) (-745 "bookvol10.4.pamphlet" 1275662 1275670 1279720 1279725) (-744 "bookvol10.4.pamphlet" 1274208 1274216 1275652 1275657) (-743 "bookvol10.4.pamphlet" 1273538 1273546 1274198 1274203) (-742 "bookvol10.2.pamphlet" 1273090 1273100 1273506 1273533) (-741 NIL 1272662 1272674 1273080 1273085) (-740 "bookvol10.3.pamphlet" 1269889 1269903 1270212 1270365) (-739 "bookvol10.3.pamphlet" 1268008 1268022 1268080 1268300) (-738 "bookvol10.4.pamphlet" 1264976 1264993 1267998 1268003) (-737 "bookvol10.4.pamphlet" 1264374 1264391 1264966 1264971) (-736 "bookvol10.2.pamphlet" 1262404 1262425 1264272 1264369) (-735 "bookvol10.4.pamphlet" 1262063 1262073 1262394 1262399) (-734 "bookvol10.4.pamphlet" 1261521 1261529 1262053 1262058) (-733 "bookvol10.3.pamphlet" 1259584 1259594 1261283 1261322) (-732 "bookvol10.2.pamphlet" 1259417 1259427 1259540 1259579) (-731 "bookvol10.3.pamphlet" 1256452 1256464 1259125 1259192) (-730 "bookvol10.4.pamphlet" 1256014 1256028 1256442 1256447) (-729 "bookvol10.4.pamphlet" 1255575 1255592 1256004 1256009) (-728 "bookvol10.4.pamphlet" 1253648 1253667 1255565 1255570) (-727 "bookvol10.3.pamphlet" 1251100 1251115 1251442 1251569) (-726 "bookvol10.4.pamphlet" 1250379 1250398 1251090 1251095) (-725 "bookvol10.4.pamphlet" 1250189 1250232 1250369 1250374) (-724 "bookvol10.4.pamphlet" 1249937 1249973 1250179 1250184) (-723 "bookvol10.4.pamphlet" 1248308 1248325 1249927 1249932) (-722 "bookvol10.2.pamphlet" 1247210 1247218 1248298 1248303) (-721 NIL 1246110 1246120 1247200 1247205) (-720 "bookvol10.2.pamphlet" 1244838 1244851 1245970 1246105) (-719 NIL 1243588 1243603 1244722 1244727) (-718 "bookvol10.2.pamphlet" 1241741 1241749 1243578 1243583) (-717 NIL 1239892 1239902 1241731 1241736) (-716 "bookvol10.2.pamphlet" 1239083 1239091 1239882 1239887) (-715 NIL 1238272 1238282 1239073 1239078) (-714 "bookvol10.3.pamphlet" 1236929 1236943 1238252 1238267) (-713 "bookvol10.2.pamphlet" 1236642 1236652 1236897 1236924) (-712 NIL 1236375 1236387 1236632 1236637) (-711 "bookvol10.3.pamphlet" 1235694 1235733 1236355 1236370) (-710 "bookvol10.3.pamphlet" 1234314 1234326 1235516 1235583) (-709 "bookvol10.3.pamphlet" 1233827 1233845 1234304 1234309) (-708 "bookvol10.3.pamphlet" 1230487 1230503 1231305 1231458) (-707 "bookvol10.3.pamphlet" 1229854 1229893 1230389 1230482) (-706 "bookvol10.3.pamphlet" 1228659 1228667 1229844 1229849) (-705 "bookvol10.4.pamphlet" 1228393 1228427 1228649 1228654) (-704 "bookvol10.2.pamphlet" 1226811 1226821 1228349 1228388) (-703 "bookvol10.4.pamphlet" 1225427 1225444 1226801 1226806) (-702 "bookvol10.4.pamphlet" 1224867 1224885 1225417 1225422) (-701 "bookvol10.4.pamphlet" 1224459 1224472 1224857 1224862) (-700 "bookvol10.4.pamphlet" 1223744 1223754 1224449 1224454) (-699 "bookvol10.4.pamphlet" 1222594 1222604 1223734 1223739) (-698 "bookvol10.3.pamphlet" 1222372 1222382 1222584 1222589) (-697 "bookvol10.4.pamphlet" 1221811 1221829 1222362 1222367) (-696 "bookvol10.3.pamphlet" 1221250 1221258 1221713 1221806) (-695 "bookvol10.4.pamphlet" 1219889 1219899 1221240 1221245) (-694 "bookvol10.3.pamphlet" 1218337 1218345 1219779 1219884) (-693 "bookvol10.4.pamphlet" 1217737 1217759 1218327 1218332) (-692 "bookvol10.4.pamphlet" 1215649 1215657 1217727 1217732) (-691 "bookvol10.4.pamphlet" 1213902 1213912 1215639 1215644) (-690 "bookvol10.2.pamphlet" 1213183 1213193 1213870 1213897) (-689 "bookvol10.3.pamphlet" 1209156 1209164 1209770 1209971) (-688 "bookvol10.4.pamphlet" 1208358 1208370 1209146 1209151) (-687 "bookvol10.4.pamphlet" 1205618 1205644 1208348 1208353) (-686 "bookvol10.4.pamphlet" 1202898 1202908 1205608 1205613) (-685 "bookvol10.3.pamphlet" 1201791 1201801 1202273 1202300) (-684 "bookvol10.4.pamphlet" 1199199 1199223 1201675 1201680) (-683 "bookvol10.2.pamphlet" 1185327 1185349 1199155 1199194) (-682 NIL 1171303 1171327 1185133 1185138) (-681 "bookvol10.4.pamphlet" 1170585 1170633 1171293 1171298) (-680 "bookvol10.4.pamphlet" 1169379 1169391 1170575 1170580) (-679 "bookvol10.4.pamphlet" 1168254 1168268 1169369 1169374) (-678 "bookvol10.4.pamphlet" 1167560 1167572 1168244 1168249) (-677 "bookvol10.4.pamphlet" 1166382 1166392 1167550 1167555) (-676 "bookvol10.4.pamphlet" 1166194 1166208 1166372 1166377) (-675 "bookvol10.4.pamphlet" 1165963 1165975 1166184 1166189) (-674 "bookvol10.4.pamphlet" 1165599 1165609 1165953 1165958) (-673 "bookvol10.4.pamphlet" 1161271 1161295 1165589 1165594) (-672 "bookvol10.3.pamphlet" 1159555 1159572 1161261 1161266) (-671 "bookvol10.2.pamphlet" 1157411 1157426 1159545 1159550) (-670 "bookvol10.3.pamphlet" 1155396 1155406 1157012 1157017) (-669 "bookvol10.2.pamphlet" 1151144 1151154 1155376 1155391) (-668 NIL 1146900 1146912 1151134 1151139) (-667 "bookvol10.3.pamphlet" 1144138 1144155 1146890 1146895) (-666 "bookvol10.3.pamphlet" 1142436 1142450 1142818 1142869) (-665 "bookvol10.4.pamphlet" 1141979 1141996 1142426 1142431) (-664 "bookvol10.4.pamphlet" 1140781 1140809 1141969 1141974) (-663 "bookvol10.4.pamphlet" 1138543 1138557 1140771 1140776) (-662 "bookvol10.2.pamphlet" 1138200 1138210 1138499 1138538) (-661 NIL 1137889 1137901 1138190 1138195) (-660 "bookvol10.3.pamphlet" 1137037 1137056 1137745 1137814) (-659 "bookvol10.4.pamphlet" 1136298 1136308 1137027 1137032) (-658 "bookvol10.4.pamphlet" 1134774 1134823 1136288 1136293) (-657 "bookvol10.4.pamphlet" 1133447 1133457 1134764 1134769) (-656 "bookvol10.3.pamphlet" 1132844 1132858 1133381 1133408) (-655 "bookvol10.2.pamphlet" 1132476 1132484 1132834 1132839) (-654 NIL 1132106 1132116 1132466 1132471) (-653 "bookvol10.4.pamphlet" 1131036 1131048 1132096 1132101) (-652 "bookvol10.3.pamphlet" 1130407 1130423 1130716 1130755) (-651 "bookvol10.4.pamphlet" 1129455 1129472 1130364 1130369) (-650 "bookvol10.2.pamphlet" 1128104 1128114 1129411 1129450) (-649 NIL 1126751 1126763 1128060 1128065) (-648 "bookvol10.3.pamphlet" 1126011 1126023 1126431 1126470) (-647 "bookvol10.3.pamphlet" 1125398 1125408 1125691 1125730) (-646 "bookvol10.4.pamphlet" 1124124 1124142 1125388 1125393) (-645 "bookvol10.2.pamphlet" 1122547 1122557 1124026 1124119) (-644 "bookvol10.2.pamphlet" 1119023 1119033 1122527 1122542) (-643 NIL 1115473 1115485 1118979 1118984) (-642 "bookvol10.3.pamphlet" 1112085 1112102 1115463 1115468) (-641 "bookvol10.2.pamphlet" 1111600 1111610 1112075 1112080) (-640 "bookvol10.3.pamphlet" 1110722 1110732 1111374 1111401) (-639 "bookvol10.4.pamphlet" 1110173 1110187 1110712 1110717) (-638 "bookvol10.3.pamphlet" 1108136 1108146 1109543 1109570) (-637 "bookvol10.4.pamphlet" 1107451 1107465 1108126 1108131) (-636 "bookvol10.4.pamphlet" 1106131 1106143 1107441 1107446) (-635 "bookvol10.4.pamphlet" 1102994 1103006 1106121 1106126) (-634 "bookvol10.2.pamphlet" 1102372 1102382 1102974 1102989) (-633 "bookvol10.4.pamphlet" 1101245 1101257 1102284 1102289) (-632 "bookvol10.4.pamphlet" 1099203 1099213 1101235 1101240) (-631 "bookvol10.4.pamphlet" 1098078 1098091 1099193 1099198) (-630 "bookvol10.3.pamphlet" 1096108 1096120 1097368 1097513) (-629 "bookvol10.2.pamphlet" 1095693 1095703 1096034 1096103) (-628 NIL 1095306 1095318 1095649 1095654) (-627 "bookvol10.3.pamphlet" 1093841 1093849 1094547 1094562) (-626 "bookvol10.4.pamphlet" 1091219 1091238 1093831 1093836) (-625 "bookvol10.4.pamphlet" 1089998 1090014 1091209 1091214) (-624 "bookvol10.2.pamphlet" 1088851 1088859 1089988 1089993) (-623 "bookvol10.4.pamphlet" 1084683 1084698 1088841 1088846) (-622 "bookvol10.3.pamphlet" 1082918 1082945 1084663 1084678) (-621 "bookvol10.4.pamphlet" 1081348 1081365 1082908 1082913) (-620 "bookvol10.4.pamphlet" 1080458 1080480 1081338 1081343) (-619 "bookvol10.3.pamphlet" 1079234 1079247 1080051 1080120) (-618 "bookvol10.4.pamphlet" 1078779 1078795 1079224 1079229) (-617 "bookvol10.3.pamphlet" 1078189 1078203 1078701 1078740) (-616 "bookvol10.2.pamphlet" 1077965 1077975 1078169 1078184) (-615 NIL 1077749 1077761 1077955 1077960) (-614 "bookvol10.4.pamphlet" 1076430 1076447 1077739 1077744) (-613 "bookvol10.2.pamphlet" 1076154 1076164 1076420 1076425) (-612 "bookvol10.2.pamphlet" 1075891 1075901 1076144 1076149) (-611 "bookvol10.3.pamphlet" 1074452 1074462 1075675 1075680) (-610 "bookvol10.4.pamphlet" 1074155 1074167 1074442 1074447) (-609 "bookvol10.2.pamphlet" 1073294 1073316 1074123 1074150) (-608 NIL 1072453 1072477 1073284 1073289) (-607 "bookvol10.3.pamphlet" 1071091 1071107 1071800 1071827) (-606 "bookvol10.3.pamphlet" 1069100 1069112 1070381 1070526) (-605 "bookvol10.2.pamphlet" 1067344 1067368 1069080 1069095) (-604 NIL 1065453 1065479 1067191 1067196) (-603 "bookvol10.3.pamphlet" 1064461 1064476 1064601 1064628) (-602 "bookvol10.3.pamphlet" 1063581 1063591 1064451 1064456) (-601 "bookvol10.4.pamphlet" 1062344 1062363 1063571 1063576) (-600 "bookvol10.4.pamphlet" 1061850 1061864 1062334 1062339) (-599 "bookvol10.4.pamphlet" 1061594 1061606 1061840 1061845) (-598 "bookvol10.3.pamphlet" 1059402 1059417 1061430 1061555) (-597 "bookvol10.3.pamphlet" 1051790 1051805 1058376 1058473) (-596 "bookvol10.4.pamphlet" 1051257 1051273 1051780 1051785) (-595 "bookvol10.3.pamphlet" 1050487 1050500 1050653 1050680) (-594 "bookvol10.4.pamphlet" 1049482 1049501 1050477 1050482) (-593 "bookvol10.4.pamphlet" 1047550 1047558 1049472 1049477) (-592 "bookvol10.4.pamphlet" 1046097 1046107 1047506 1047511) (-591 "bookvol10.4.pamphlet" 1045698 1045709 1046087 1046092) (-590 "bookvol10.4.pamphlet" 1044014 1044024 1045688 1045693) (-589 "bookvol10.3.pamphlet" 1041737 1041751 1043869 1043896) (-588 "bookvol10.4.pamphlet" 1040881 1040897 1041727 1041732) (-587 "bookvol10.4.pamphlet" 1040058 1040074 1040871 1040876) (-586 "bookvol10.4.pamphlet" 1039834 1039842 1040048 1040053) (-585 "bookvol10.3.pamphlet" 1039535 1039547 1039639 1039732) (-584 "bookvol10.3.pamphlet" 1039306 1039332 1039461 1039530) (-583 "bookvol10.4.pamphlet" 1038903 1038919 1039296 1039301) (-582 "bookvol10.4.pamphlet" 1031925 1031942 1038893 1038898) (-581 "bookvol10.4.pamphlet" 1029790 1029806 1031499 1031504) (-580 "bookvol10.4.pamphlet" 1029110 1029118 1029780 1029785) (-579 "bookvol10.3.pamphlet" 1028886 1028896 1029024 1029105) (-578 "bookvol10.4.pamphlet" 1027250 1027264 1028876 1028881) (-577 "bookvol10.4.pamphlet" 1026743 1026753 1027240 1027245) (-576 "bookvol10.4.pamphlet" 1025412 1025429 1026733 1026738) (-575 "bookvol10.4.pamphlet" 1023725 1023741 1025055 1025060) (-574 "bookvol10.4.pamphlet" 1021382 1021400 1023657 1023662) (-573 "bookvol10.4.pamphlet" 1011907 1011915 1021372 1021377) (-572 "bookvol10.3.pamphlet" 1011268 1011276 1011761 1011902) (-571 "bookvol10.4.pamphlet" 1010534 1010551 1011258 1011263) (-570 "bookvol10.4.pamphlet" 1010179 1010203 1010524 1010529) (-569 "bookvol10.4.pamphlet" 1006558 1006566 1010169 1010174) (-568 "bookvol10.4.pamphlet" 999716 999734 1006490 1006495) (-567 "bookvol10.3.pamphlet" 993714 993722 999706 999711) (-566 "bookvol10.4.pamphlet" 992866 992923 993704 993709) (-565 "bookvol10.4.pamphlet" 991952 991962 992856 992861) (-564 "bookvol10.4.pamphlet" 991820 991844 991942 991947) (-563 "bookvol10.4.pamphlet" 990178 990194 991810 991815) (-562 "bookvol10.2.pamphlet" 988830 988838 990104 990173) (-561 NIL 987544 987554 988820 988825) (-560 "bookvol10.4.pamphlet" 986690 986777 987534 987539) (-559 "bookvol10.2.pamphlet" 985311 985321 986604 986685) (-558 "bookvol10.4.pamphlet" 984842 984850 985301 985306) (-557 "bookvol10.4.pamphlet" 984000 984027 984832 984837) (-556 "bookvol10.4.pamphlet" 983476 983492 983990 983995) (-555 "bookvol10.3.pamphlet" 982556 982587 982719 982746) (-554 "bookvol10.2.pamphlet" 979890 979898 982458 982551) (-553 NIL 977310 977320 979880 979885) (-552 "bookvol10.4.pamphlet" 976758 976771 977300 977305) (-551 "bookvol10.4.pamphlet" 975854 975873 976748 976753) (-550 "bookvol10.4.pamphlet" 974942 974966 975844 975849) (-549 "bookvol10.4.pamphlet" 973948 973965 974932 974937) (-548 "bookvol10.4.pamphlet" 973105 973135 973938 973943) (-547 "bookvol10.4.pamphlet" 971450 971472 973095 973100) (-546 "bookvol10.4.pamphlet" 970530 970549 971440 971445) (-545 "bookvol10.3.pamphlet" 967451 967459 970520 970525) (-544 "bookvol10.4.pamphlet" 967096 967106 967441 967446) (-543 "bookvol10.4.pamphlet" 966684 966692 967086 967091) (-542 "bookvol10.3.pamphlet" 966101 966164 966674 966679) (-541 "bookvol10.3.pamphlet" 965543 965566 966091 966096) (-540 "bookvol10.2.pamphlet" 964196 964259 965533 965538) (-539 "bookvol10.4.pamphlet" 962740 962762 964186 964191) (-538 "bookvol10.3.pamphlet" 962646 962663 962730 962735) (-537 "bookvol10.4.pamphlet" 962063 962073 962636 962641) (-536 "bookvol10.4.pamphlet" 957957 957968 962053 962058) (-535 "bookvol10.3.pamphlet" 957089 957115 957601 957628) (-534 "bookvol10.4.pamphlet" 956181 956225 957045 957050) (-533 "bookvol10.4.pamphlet" 954794 954818 956137 956142) (-532 "bookvol10.3.pamphlet" 953681 953696 954200 954227) (-531 "bookvol10.3.pamphlet" 953406 953444 953511 953538) (-530 "bookvol10.3.pamphlet" 952836 952852 953087 953180) (-529 "bookvol10.3.pamphlet" 950069 950084 952242 952269) (-528 "bookvol10.3.pamphlet" 949907 949924 950025 950030) (-527 "bookvol10.2.pamphlet" 949304 949316 949897 949902) (-526 NIL 948699 948713 949294 949299) (-525 "bookvol10.3.pamphlet" 948512 948524 948689 948694) (-524 "bookvol10.3.pamphlet" 948285 948297 948502 948507) (-523 "bookvol10.3.pamphlet" 948020 948032 948275 948280) (-522 "bookvol10.2.pamphlet" 946958 946970 948010 948015) (-521 "bookvol10.3.pamphlet" 946718 946730 946948 946953) (-520 "bookvol10.3.pamphlet" 946480 946492 946708 946713) (-519 "bookvol10.4.pamphlet" 943752 943770 946470 946475) (-518 "bookvol10.3.pamphlet" 938832 938871 943687 943692) (-517 "bookvol10.3.pamphlet" 938289 938312 938822 938827) (-516 "bookvol10.4.pamphlet" 937522 937538 938279 938284) (-515 "bookvol10.3.pamphlet" 936805 936813 937512 937517) (-514 "bookvol10.4.pamphlet" 935448 935465 936795 936800) (-513 "bookvol10.3.pamphlet" 934730 934743 935142 935169) (-512 "bookvol10.4.pamphlet" 931657 931676 934720 934725) (-511 "bookvol10.4.pamphlet" 930567 930582 931647 931652) (-510 "bookvol10.3.pamphlet" 930298 930324 930397 930424) (-509 "bookvol10.3.pamphlet" 929611 929626 929704 929731) (-508 "bookvol10.3.pamphlet" 927834 927842 929427 929520) (-507 "bookvol10.4.pamphlet" 927391 927424 927824 927829) (-506 "bookvol10.2.pamphlet" 926769 926777 927381 927386) (-505 NIL 926145 926155 926759 926764) (-504 "bookvol10.3.pamphlet" 924997 925005 926135 926140) (-503 "bookvol10.2.pamphlet" 922791 922801 924977 924992) (-502 NIL 920426 920438 922614 922619) (-501 "bookvol10.3.pamphlet" 918295 918303 918893 918986) (-500 "bookvol10.4.pamphlet" 917247 917258 918285 918290) (-499 "bookvol10.3.pamphlet" 916879 916903 917237 917242) (-498 "bookvol10.3.pamphlet" 913016 913026 916709 916736) (-497 "bookvol10.3.pamphlet" 904871 904887 905231 905362) (-496 "bookvol10.3.pamphlet" 902066 902081 902665 902792) (-495 "bookvol10.4.pamphlet" 900662 900670 902056 902061) (-494 "bookvol10.3.pamphlet" 899696 899727 899905 899932) (-493 "bookvol10.3.pamphlet" 899307 899315 899598 899691) (-492 "bookvol10.4.pamphlet" 885404 885416 899297 899302) (-491 "bookvol10.4.pamphlet" 885149 885157 885249 885254) (-490 "bookvol10.4.pamphlet" 869446 869482 885019 885024) (-489 "bookvol10.4.pamphlet" 869207 869215 869305 869310) (-488 "bookvol10.4.pamphlet" 869028 869042 869141 869146) (-487 "bookvol10.4.pamphlet" 868905 868919 869018 869023) (-486 "bookvol10.4.pamphlet" 868738 868746 868838 868843) (-485 "bookvol10.3.pamphlet" 867954 867970 868440 868467) (-484 "bookvol10.3.pamphlet" 867037 867072 867209 867224) (-483 "bookvol10.3.pamphlet" 864210 864237 865169 865318) (-482 "bookvol10.2.pamphlet" 863188 863196 864190 864205) (-481 NIL 862174 862184 863178 863183) (-480 "bookvol10.4.pamphlet" 860765 860786 862164 862169) (-479 "bookvol10.2.pamphlet" 859405 859417 860755 860760) (-478 NIL 858043 858057 859395 859400) (-477 "bookvol10.3.pamphlet" 851082 851090 858033 858038) (-476 "bookvol10.4.pamphlet" 849477 849485 851072 851077) (-475 "bookvol10.4.pamphlet" 848018 848026 849467 849472) (-474 "bookvol10.2.pamphlet" 847221 847233 848008 848013) (-473 NIL 846422 846436 847211 847216) (-472 "bookvol10.3.pamphlet" 845948 845971 846160 846187) (-471 "bookvol10.4.pamphlet" 840722 840809 845904 845909) (-470 "bookvol10.4.pamphlet" 839991 840009 840712 840717) (-469 "bookvol10.3.pamphlet" 834284 834292 839981 839986) (-468 "bookvol10.3.pamphlet" 830699 830707 834274 834279) (-467 "bookvol10.3.pamphlet" 829816 829843 830667 830694) (-466 "bookvol10.4.pamphlet" 828988 829002 829806 829811) (-465 "bookvol10.4.pamphlet" 824801 824814 828978 828983) (-464 "bookvol10.4.pamphlet" 824405 824415 824791 824796) (-463 "bookvol10.4.pamphlet" 824055 824072 824395 824400) (-462 "bookvol10.4.pamphlet" 823522 823541 824045 824050) (-461 "bookvol10.4.pamphlet" 822004 822017 823512 823517) (-460 "bookvol10.4.pamphlet" 820469 820477 821994 821999) (-459 "bookvol10.3.pamphlet" 817510 817527 818263 818390) (-458 "bookvol10.3.pamphlet" 811481 811508 817304 817371) (-457 "bookvol10.2.pamphlet" 810435 810443 811407 811476) (-456 NIL 809451 809461 810425 810430) (-455 "bookvol10.4.pamphlet" 804998 805036 809407 809412) (-454 "bookvol10.4.pamphlet" 801096 801134 804988 804993) (-453 "bookvol10.4.pamphlet" 796561 796599 801086 801091) (-452 "bookvol10.4.pamphlet" 793214 793252 796551 796556) (-451 "bookvol10.4.pamphlet" 792537 792545 793204 793209) (-450 "bookvol10.4.pamphlet" 790863 790873 792493 792498) (-449 "bookvol10.4.pamphlet" 789330 789343 790853 790858) (-448 "bookvol10.4.pamphlet" 787535 787554 789320 789325) (-447 "bookvol10.4.pamphlet" 777973 777984 787525 787530) (-446 "bookvol10.2.pamphlet" 774916 774924 777953 777968) (-445 "bookvol10.2.pamphlet" 773960 773968 774896 774911) (-444 "bookvol10.3.pamphlet" 773809 773821 773950 773955) (-443 "bookvol10.3.pamphlet" 772041 772049 773799 773804) (-442 "bookvol10.3.pamphlet" 771212 771220 772031 772036) (-441 "bookvol10.4.pamphlet" 770258 770277 771148 771153) (-440 "bookvol10.3.pamphlet" 768402 768410 770248 770253) (-439 "bookvol10.4.pamphlet" 767826 767842 768392 768397) (-438 "bookvol10.4.pamphlet" 766686 766702 767783 767788) (-437 "bookvol10.4.pamphlet" 763973 763989 766676 766681) (-436 "bookvol10.2.pamphlet" 757883 757893 763736 763968) (-435 NIL 751583 751595 757438 757443) (-434 "bookvol10.4.pamphlet" 751199 751215 751573 751578) (-433 "bookvol10.3.pamphlet" 750527 750539 751019 751118) (-432 "bookvol10.4.pamphlet" 749791 749807 750517 750522) (-431 "bookvol10.2.pamphlet" 748968 748978 749735 749786) (-430 NIL 748119 748131 748888 748893) (-429 "bookvol10.4.pamphlet" 746862 746878 748109 748114) (-428 "bookvol10.4.pamphlet" 741353 741387 746852 746857) (-427 "bookvol10.4.pamphlet" 740965 740981 741343 741348) (-426 "bookvol10.4.pamphlet" 740128 740151 740955 740960) (-425 "bookvol10.4.pamphlet" 739128 739138 740118 740123) (-424 "bookvol10.3.pamphlet" 731104 731114 738152 738221) (-423 "bookvol10.2.pamphlet" 726287 726297 731046 731099) (-422 NIL 721482 721494 726243 726248) (-421 "bookvol10.4.pamphlet" 720930 720948 721472 721477) (-420 "bookvol10.3.pamphlet" 720340 720370 720861 720866) (-419 "bookvol10.3.pamphlet" 719573 719594 720320 720335) (-418 "bookvol10.4.pamphlet" 719311 719343 719563 719568) (-417 "bookvol10.2.pamphlet" 718985 718995 719301 719306) (-416 NIL 718525 718537 718843 718848) (-415 "bookvol10.2.pamphlet" 716931 716944 718481 718520) (-414 NIL 715369 715384 716921 716926) (-413 "bookvol10.3.pamphlet" 712486 712496 712871 713044) (-412 "bookvol10.4.pamphlet" 712099 712111 712476 712481) (-411 "bookvol10.4.pamphlet" 711457 711469 712089 712094) (-410 "bookvol10.2.pamphlet" 708406 708414 711347 711452) (-409 NIL 705383 705393 708326 708331) (-408 "bookvol10.2.pamphlet" 704437 704445 705285 705378) (-407 NIL 703577 703587 704427 704432) (-406 "bookvol10.2.pamphlet" 703329 703339 703557 703572) (-405 "bookvol10.3.pamphlet" 702079 702096 703319 703324) (-404 "bookvol10.3.pamphlet" 700564 700613 702069 702074) (-403 "bookvol10.4.pamphlet" 699513 699521 700554 700559) (-402 "bookvol10.2.pamphlet" 696603 696611 699493 699508) (-401 "bookvol10.2.pamphlet" 696306 696314 696583 696598) (-400 "bookvol10.3.pamphlet" 693700 693708 696296 696301) (-399 "bookvol10.4.pamphlet" 693179 693189 693690 693695) (-398 "bookvol10.4.pamphlet" 692960 692984 693169 693174) (-397 "bookvol10.4.pamphlet" 692161 692169 692950 692955) (-396 "bookvol10.3.pamphlet" 691583 691605 692129 692156) (-395 "bookvol10.2.pamphlet" 689927 689935 691573 691578) (-394 "bookvol10.3.pamphlet" 689819 689827 689917 689922) (-393 "bookvol10.2.pamphlet" 689617 689625 689745 689814) (-392 "bookvol10.3.pamphlet" 686387 686397 689573 689578) (-391 "bookvol10.3.pamphlet" 686090 686102 686321 686348) (-390 "bookvol10.2.pamphlet" 683040 683048 686070 686085) (-389 "bookvol10.2.pamphlet" 682084 682092 683020 683035) (-388 "bookvol10.2.pamphlet" 679778 679796 682052 682079) (-387 "bookvol10.3.pamphlet" 679240 679252 679712 679739) (-386 "bookvol10.4.pamphlet" 677048 677062 679230 679235) (-385 "bookvol10.3.pamphlet" 673953 673961 676914 677043) (-384 "bookvol10.4.pamphlet" 671419 671433 673943 673948) (-383 "bookvol10.2.pamphlet" 671121 671131 671399 671414) (-382 NIL 670777 670789 671057 671062) (-381 "bookvol10.4.pamphlet" 670033 670045 670767 670772) (-380 "bookvol10.2.pamphlet" 668100 668119 669959 670028) (-379 "bookvol10.2.pamphlet" 665306 665316 668068 668095) (-378 NIL 662425 662437 665189 665194) (-377 "bookvol10.4.pamphlet" 661146 661162 662415 662420) (-376 "bookvol10.2.pamphlet" 659267 659280 661102 661141) (-375 NIL 657314 657329 659151 659156) (-374 "bookvol10.2.pamphlet" 656309 656317 657304 657309) (-373 NIL 655302 655312 656299 656304) (-372 "bookvol10.2.pamphlet" 644651 644661 655244 655297) (-371 NIL 634012 634024 644607 644612) (-370 "bookvol10.3.pamphlet" 633599 633609 634002 634007) (-369 "bookvol10.2.pamphlet" 632046 632063 633589 633594) (-368 "bookvol10.2.pamphlet" 631384 631392 631948 632041) (-367 NIL 630808 630818 631374 631379) (-366 "bookvol10.3.pamphlet" 629349 629359 630788 630803) (-365 "bookvol10.4.pamphlet" 628256 628271 629339 629344) (-364 "bookvol10.3.pamphlet" 627685 627700 627972 628065) (-363 "bookvol10.4.pamphlet" 627558 627575 627675 627680) (-362 "bookvol10.4.pamphlet" 627061 627082 627548 627553) (-361 "bookvol10.4.pamphlet" 618460 618471 627051 627056) (-360 "bookvol10.4.pamphlet" 617542 617559 618450 618455) (-359 "bookvol10.3.pamphlet" 617038 617058 617258 617351) (-358 "bookvol10.3.pamphlet" 616506 616522 616719 616812) (-357 "bookvol10.3.pamphlet" 615056 615076 616222 616315) (-356 "bookvol10.3.pamphlet" 613592 613609 614772 614865) (-355 "bookvol10.3.pamphlet" 612133 612154 613273 613366) (-354 "bookvol10.4.pamphlet" 609503 609522 612123 612128) (-353 "bookvol10.2.pamphlet" 607101 607109 609405 609498) (-352 NIL 604785 604795 607091 607096) (-351 "bookvol10.4.pamphlet" 603578 603595 604775 604780) (-350 "bookvol10.4.pamphlet" 601053 601064 603568 603573) (-349 "bookvol10.4.pamphlet" 595175 595191 601043 601048) (-348 "bookvol10.4.pamphlet" 593850 593869 595165 595170) (-347 "bookvol10.4.pamphlet" 593269 593286 593840 593845) (-346 "bookvol10.4.pamphlet" 593190 593207 593259 593264) (-345 "bookvol10.3.pamphlet" 592071 592091 592906 592999) (-344 "bookvol10.3.pamphlet" 590986 591006 591787 591880) (-343 "bookvol10.3.pamphlet" 589813 589834 590667 590760) (-342 "bookvol10.2.pamphlet" 578618 578640 589652 589808) (-341 NIL 567502 567526 578538 578543) (-340 "bookvol10.4.pamphlet" 567241 567281 567492 567497) (-339 "bookvol10.3.pamphlet" 559917 559963 566997 567036) (-338 "bookvol10.2.pamphlet" 559627 559637 559907 559912) (-337 NIL 559122 559134 559404 559409) (-336 "bookvol10.3.pamphlet" 558573 558597 559112 559117) (-335 "bookvol10.2.pamphlet" 556585 556609 558563 558568) (-334 NIL 554595 554621 556575 556580) (-333 "bookvol10.4.pamphlet" 554341 554381 554585 554590) (-332 "bookvol10.4.pamphlet" 552902 552910 554331 554336) (-331 "bookvol10.3.pamphlet" 552433 552443 552892 552897) (-330 "bookvol10.3.pamphlet" 542398 542406 552423 552428) (-329 "bookvol10.2.pamphlet" 535675 535689 542300 542393) (-328 NIL 529004 529020 535631 535636) (-327 "bookvol10.3.pamphlet" 527432 527442 528410 528437) (-326 "bookvol10.2.pamphlet" 525574 525586 527330 527427) (-325 NIL 523700 523714 525458 525463) (-324 "bookvol10.4.pamphlet" 523274 523296 523690 523695) (-323 "bookvol10.3.pamphlet" 522931 522941 523228 523233) (-322 "bookvol10.2.pamphlet" 521114 521126 522921 522926) (-321 "bookvol10.3.pamphlet" 520728 520738 521010 521037) (-320 "bookvol10.4.pamphlet" 518940 518957 520718 520723) (-319 "bookvol10.4.pamphlet" 518822 518832 518930 518935) (-318 "bookvol10.4.pamphlet" 518016 518026 518812 518817) (-317 "bookvol10.4.pamphlet" 517898 517908 518006 518011) (-316 "bookvol10.3.pamphlet" 514735 514758 516030 516179) (-315 "bookvol10.4.pamphlet" 512203 512211 514725 514730) (-314 "bookvol10.4.pamphlet" 512105 512134 512193 512198) (-313 "bookvol10.4.pamphlet" 508849 508865 512095 512100) (-312 "bookvol10.3.pamphlet" 504116 504126 504838 505245) (-311 "bookvol10.4.pamphlet" 500206 500219 504106 504111) (-310 "bookvol10.4.pamphlet" 499976 499988 500196 500201) (-309 "bookvol10.3.pamphlet" 496910 496935 497548 497641) (-308 "bookvol10.4.pamphlet" 496763 496771 496900 496905) (-307 "bookvol10.3.pamphlet" 496434 496442 496753 496758) (-306 "bookvol10.4.pamphlet" 495928 495942 496424 496429) (-305 "bookvol10.2.pamphlet" 495492 495502 495918 495923) (-304 NIL 495054 495066 495482 495487) (-303 "bookvol10.2.pamphlet" 492626 492634 494980 495049) (-302 NIL 490260 490270 492616 492621) (-301 "bookvol10.4.pamphlet" 482118 482126 490250 490255) (-300 "bookvol10.4.pamphlet" 481713 481727 482108 482113) (-299 "bookvol10.4.pamphlet" 481398 481409 481703 481708) (-298 "bookvol10.2.pamphlet" 474345 474353 481388 481393) (-297 NIL 467198 467208 474243 474248) (-296 "bookvol10.4.pamphlet" 464007 464015 467188 467193) (-295 "bookvol10.4.pamphlet" 463748 463760 463997 464002) (-294 "bookvol10.4.pamphlet" 463255 463271 463738 463743) (-293 "bookvol10.4.pamphlet" 462813 462829 463245 463250) (-292 "bookvol10.4.pamphlet" 460289 460297 462803 462808) (-291 "bookvol10.3.pamphlet" 459323 459345 459532 459559) (-290 "bookvol10.3.pamphlet" 454249 454259 456996 457108) (-289 "bookvol10.4.pamphlet" 453967 453979 454239 454244) (-288 "bookvol10.4.pamphlet" 450321 450331 453957 453962) (-287 "bookvol10.2.pamphlet" 449865 449873 450265 450316) (-286 "bookvol10.3.pamphlet" 449061 449102 449791 449860) (-285 "bookvol10.2.pamphlet" 447517 447536 449051 449056) (-284 NIL 445937 445958 447473 447478) (-283 "bookvol10.2.pamphlet" 445469 445487 445927 445932) (-282 "bookvol10.4.pamphlet" 444858 444877 445459 445464) (-281 "bookvol10.2.pamphlet" 444555 444563 444848 444853) (-280 NIL 444250 444260 444545 444550) (-279 "bookvol10.2.pamphlet" 442166 442176 444218 444245) (-278 NIL 440031 440043 442085 442090) (-277 "bookvol10.3.pamphlet" 436806 436836 439987 439992) (-276 "bookvol10.3.pamphlet" 433642 433665 436762 436767) (-275 "bookvol10.4.pamphlet" 431639 431655 433632 433637) (-274 "bookvol10.4.pamphlet" 426415 426431 431629 431634) (-273 "bookvol10.3.pamphlet" 424729 424737 426405 426410) (-272 "bookvol10.3.pamphlet" 424267 424275 424719 424724) (-271 "bookvol10.3.pamphlet" 423846 423854 424257 424262) (-270 "bookvol10.3.pamphlet" 423428 423436 423836 423841) (-269 "bookvol10.3.pamphlet" 422966 422974 423418 423423) (-268 "bookvol10.3.pamphlet" 422504 422512 422956 422961) (-267 "bookvol10.3.pamphlet" 422042 422050 422494 422499) (-266 "bookvol10.3.pamphlet" 421580 421588 422032 422037) (-265 "bookvol10.4.pamphlet" 417322 417330 421570 421575) (-264 "bookvol10.2.pamphlet" 414071 414081 417312 417317) (-263 NIL 410818 410830 414061 414066) (-262 "bookvol10.4.pamphlet" 407903 407990 410808 410813) (-261 "bookvol10.3.pamphlet" 407109 407119 407733 407760) (-260 "bookvol10.2.pamphlet" 406703 406713 407065 407104) (-259 "bookvol10.3.pamphlet" 404146 404160 404439 404566) (-258 "bookvol10.3.pamphlet" 397909 397917 404136 404141) (-257 "bookvol10.4.pamphlet" 397580 397590 397899 397904) (-256 "bookvol10.4.pamphlet" 392539 392547 397570 397575) (-255 "bookvol10.4.pamphlet" 390780 390788 392529 392534) (-254 "bookvol10.4.pamphlet" 383688 383701 390770 390775) (-253 "bookvol10.4.pamphlet" 382951 382961 383678 383683) (-252 "bookvol10.4.pamphlet" 380376 380384 382941 382946) (-251 "bookvol10.4.pamphlet" 379923 379938 380366 380371) (-250 "bookvol10.4.pamphlet" 369363 369371 379913 379918) (-249 "bookvol10.2.pamphlet" 367573 367583 369319 369358) (-248 "bookvol10.2.pamphlet" 362970 362986 367441 367568) (-247 NIL 358453 358471 362926 362931) (-246 "bookvol10.3.pamphlet" 351828 351844 351950 352251) (-245 "bookvol10.3.pamphlet" 345200 345218 345325 345626) (-244 "bookvol10.3.pamphlet" 342441 342456 342994 343121) (-243 "bookvol10.4.pamphlet" 341781 341791 342431 342436) (-242 "bookvol10.3.pamphlet" 340496 340506 341187 341214) (-241 "bookvol10.2.pamphlet" 338943 338953 340476 340491) (-240 "bookvol10.2.pamphlet" 338384 338392 338887 338938) (-239 NIL 337869 337879 338374 338379) (-238 "bookvol10.3.pamphlet" 337722 337732 337801 337828) (-237 "bookvol10.2.pamphlet" 336487 336497 337690 337717) (-236 "bookvol10.4.pamphlet" 334701 334709 336477 336482) (-235 "bookvol10.3.pamphlet" 333981 333996 334537 334662) (-234 "bookvol10.3.pamphlet" 325571 325587 326196 326327) (-233 "bookvol10.4.pamphlet" 324432 324450 325561 325566) (-232 "bookvol10.2.pamphlet" 323363 323379 324284 324427) (-231 NIL 322035 322053 322958 322963) (-230 "bookvol10.4.pamphlet" 320880 320888 322025 322030) (-229 "bookvol10.2.pamphlet" 319960 319970 320848 320875) (-228 NIL 319026 319038 319916 319921) (-227 "bookvol10.2.pamphlet" 318147 318155 319006 319021) (-226 NIL 317276 317286 318137 318142) (-225 "bookvol10.2.pamphlet" 316427 316437 317256 317271) (-224 NIL 315495 315507 316326 316331) (-223 "bookvol10.2.pamphlet" 315115 315125 315463 315490) (-222 NIL 314755 314767 315105 315110) (-221 "bookvol10.3.pamphlet" 313037 313047 314399 314426) (-220 "bookvol10.3.pamphlet" 311775 311783 312161 312188) (-219 "bookvol10.4.pamphlet" 302969 302977 311765 311770) (-218 "bookvol10.3.pamphlet" 302186 302194 302601 302628) (-217 "bookvol10.3.pamphlet" 298571 298579 302076 302181) (-216 "bookvol10.4.pamphlet" 296806 296822 298561 298566) (-215 "bookvol10.3.pamphlet" 294764 294796 296786 296801) (-214 "bookvol10.3.pamphlet" 288954 288964 294594 294621) (-213 "bookvol10.4.pamphlet" 288569 288583 288944 288949) (-212 "bookvol10.4.pamphlet" 286034 286044 288559 288564) (-211 "bookvol10.4.pamphlet" 284514 284530 286024 286029) (-210 "bookvol10.3.pamphlet" 282395 282403 282981 283074) (-209 "bookvol10.4.pamphlet" 280272 280289 282385 282390) (-208 "bookvol10.4.pamphlet" 279880 279904 280262 280267) (-207 "bookvol10.3.pamphlet" 278533 278543 279870 279875) (-206 "bookvol10.3.pamphlet" 278361 278369 278523 278528) (-205 "bookvol10.3.pamphlet" 278181 278189 278351 278356) (-204 "bookvol10.4.pamphlet" 277126 277134 278171 278176) (-203 "bookvol10.3.pamphlet" 276590 276598 277116 277121) (-202 "bookvol10.3.pamphlet" 276070 276078 276580 276585) (-201 "bookvol10.3.pamphlet" 275562 275570 276060 276065) (-200 "bookvol10.3.pamphlet" 275054 275062 275552 275557) (-199 "bookvol10.4.pamphlet" 269999 270007 275044 275049) (-198 "bookvol10.4.pamphlet" 268322 268330 269989 269994) (-197 "bookvol10.3.pamphlet" 268299 268307 268312 268317) (-196 "bookvol10.3.pamphlet" 267823 267831 268289 268294) (-195 "bookvol10.3.pamphlet" 267347 267355 267813 267818) (-194 "bookvol10.3.pamphlet" 266817 266825 267337 267342) (-193 "bookvol10.3.pamphlet" 266312 266320 266807 266812) (-192 "bookvol10.3.pamphlet" 265794 265802 266302 266307) (-191 "bookvol10.3.pamphlet" 265290 265298 265784 265789) (-190 "bookvol10.3.pamphlet" 264802 264810 265280 265285) (-189 "bookvol10.3.pamphlet" 264344 264352 264792 264797) (-188 "bookvol10.3.pamphlet" 263874 263882 264334 264339) (-187 "bookvol10.3.pamphlet" 263399 263407 263864 263869) (-186 "bookvol10.4.pamphlet" 259506 259514 263389 263394) (-185 "bookvol10.4.pamphlet" 259010 259018 259496 259501) (-184 "bookvol10.4.pamphlet" 255821 255829 259000 259005) (-183 "bookvol10.4.pamphlet" 255206 255216 255811 255816) (-182 "bookvol10.4.pamphlet" 253674 253690 255196 255201) (-181 "bookvol10.4.pamphlet" 252463 252476 253664 253669) (-180 "bookvol10.4.pamphlet" 246478 246491 252453 252458) (-179 "bookvol10.4.pamphlet" 245635 245645 246468 246473) (-178 "bookvol10.4.pamphlet" 245147 245162 245560 245565) (-177 "bookvol10.4.pamphlet" 244852 244871 245137 245142) (-176 "bookvol10.4.pamphlet" 239867 239877 244842 244847) (-175 "bookvol10.3.pamphlet" 235868 235878 239769 239862) (-174 "bookvol10.2.pamphlet" 235547 235555 235806 235863) (-173 "bookvol10.3.pamphlet" 235047 235055 235537 235542) (-172 "bookvol10.4.pamphlet" 234814 234829 235037 235042) (-171 "bookvol10.3.pamphlet" 228832 228842 229081 229342) (-170 "bookvol10.4.pamphlet" 228555 228567 228822 228827) (-169 "bookvol10.4.pamphlet" 228351 228365 228545 228550) (-168 "bookvol10.2.pamphlet" 226457 226467 228073 228346) (-167 NIL 224267 224279 225885 225890) (-166 "bookvol10.2.pamphlet" 224006 224014 224257 224262) (-165 "bookvol10.4.pamphlet" 223780 223798 223996 224001) (-164 "bookvol10.4.pamphlet" 223319 223327 223770 223775) (-163 "bookvol10.3.pamphlet" 223128 223136 223309 223314) (-162 "bookvol10.2.pamphlet" 222163 222171 223118 223123) (-161 "bookvol10.4.pamphlet" 220655 220665 222153 222158) (-160 "bookvol10.4.pamphlet" 218105 218121 220645 220650) (-159 "bookvol10.3.pamphlet" 216943 216951 218095 218100) (-158 "bookvol10.4.pamphlet" 216277 216294 216933 216938) (-157 "bookvol10.4.pamphlet" 212397 212405 216267 216272) (-156 "bookvol10.3.pamphlet" 211112 211128 212353 212392) (-155 "bookvol10.2.pamphlet" 208132 208142 211092 211107) (-154 NIL 205033 205045 207995 208000) (-153 "bookvol10.4.pamphlet" 204372 204385 205023 205028) (-152 "bookvol10.4.pamphlet" 202342 202364 204362 204367) (-151 "bookvol10.2.pamphlet" 202257 202265 202322 202337) (-150 "bookvol10.4.pamphlet" 201771 201781 202247 202252) (-149 "bookvol10.2.pamphlet" 201524 201532 201751 201766) (-148 "bookvol10.3.pamphlet" 197885 197893 201514 201519) (-147 "bookvol10.2.pamphlet" 197058 197066 197875 197880) (-146 "bookvol10.3.pamphlet" 195365 195373 195996 196023) (-145 "bookvol10.3.pamphlet" 194497 194505 194921 194948) (-144 "bookvol10.4.pamphlet" 193737 193751 194487 194492) (-143 "bookvol10.3.pamphlet" 192148 192156 193206 193245) (-142 "bookvol10.3.pamphlet" 183327 183351 192138 192143) (-141 "bookvol10.4.pamphlet" 182717 182744 183317 183322) (-140 "bookvol10.3.pamphlet" 179055 179063 182691 182712) (-139 "bookvol10.2.pamphlet" 178671 178679 179045 179050) (-138 "bookvol10.2.pamphlet" 178164 178172 178661 178666) (-137 "bookvol10.3.pamphlet" 177256 177266 177994 178021) (-136 "bookvol10.3.pamphlet" 176498 176508 177086 177113) (-135 "bookvol10.2.pamphlet" 175872 175882 176454 176493) (-134 NIL 175278 175290 175862 175867) (-133 "bookvol10.2.pamphlet" 174381 174389 175234 175273) (-132 NIL 173516 173526 174371 174376) (-131 "bookvol10.3.pamphlet" 172174 172184 173346 173373) (-130 "Makefile.pamphlet" 170064 170072 172164 172169) (-129 "bookvol10.4.pamphlet" 168837 168848 170054 170059) (-128 "bookvol10.2.pamphlet" 167797 167807 168817 168832) (-127 NIL 166731 166743 167753 167758) (-126 "bookvol10.3.pamphlet" 164776 164788 164967 165060) (-125 "bookvol10.3.pamphlet" 164504 164516 164702 164771) (-124 "bookvol10.4.pamphlet" 164162 164179 164494 164499) (-123 "bookvol10.3.pamphlet" 159694 159702 164152 164157) (-122 "bookvol10.4.pamphlet" 157180 157190 159650 159655) (-121 "bookvol10.3.pamphlet" 156050 156058 157170 157175) (-120 "bookvol10.2.pamphlet" 155694 155706 156018 156045) (-119 "bookvol10.4.pamphlet" 153972 154008 155684 155689) (-118 "bookvol10.3.pamphlet" 153862 153870 153937 153967) (-117 "bookvol10.2.pamphlet" 153839 153847 153852 153857) (-116 "bookvol10.3.pamphlet" 153731 153739 153806 153834) (-115 "bookvol10.5.pamphlet" 142003 142011 153721 153726) (-114 "bookvol10.3.pamphlet" 141482 141490 141697 141724) (-113 "bookvol10.3.pamphlet" 140839 140847 141472 141477) (-112 "bookvol10.3.pamphlet" 138687 138695 139306 139399) (-111 "bookvol10.2.pamphlet" 137932 137942 138655 138682) (-110 NIL 137197 137209 137922 137927) (-109 "bookvol10.3.pamphlet" 136618 136626 137177 137192) (-108 "bookvol10.4.pamphlet" 135758 135785 136568 136573) (-107 "bookvol10.4.pamphlet" 133621 133631 135748 135753) (-106 "bookvol10.3.pamphlet" 129253 129263 133451 133478) (-105 "bookvol10.2.pamphlet" 128947 128955 129243 129248) (-104 NIL 128639 128649 128937 128942) (-103 "bookvol10.4.pamphlet" 128058 128071 128629 128634) (-102 "bookvol10.4.pamphlet" 127918 127926 128048 128053) (-101 "bookvol10.3.pamphlet" 127362 127372 127898 127913) (-100 "bookvol10.2.pamphlet" 123917 123925 127102 127357) (-99 "bookvol10.3.pamphlet" 120042 120049 123897 123912) (-98 "bookvol10.2.pamphlet" 119512 119519 120032 120037) (-97 NIL 118980 118989 119502 119507) (-96 "bookvol10.3.pamphlet" 114684 114693 118810 118837) (-95 "bookvol10.4.pamphlet" 113474 113485 114640 114645) (-94 "bookvol10.3.pamphlet" 112631 112644 113464 113469) (-93 "bookvol10.3.pamphlet" 111574 111587 112621 112626) (-92 "bookvol10.3.pamphlet" 110906 110919 111564 111569) (-91 "bookvol10.3.pamphlet" 110104 110117 110896 110901) (-90 "bookvol10.3.pamphlet" 109583 109596 110094 110099) (-89 "bookvol10.3.pamphlet" 108956 108969 109573 109578) (-88 "bookvol10.3.pamphlet" 107983 107996 108946 108951) (-87 "bookvol10.3.pamphlet" 107246 107259 107973 107978) (-86 "bookvol10.3.pamphlet" 105926 105939 107236 107241) (-85 "bookvol10.3.pamphlet" 104363 104376 105916 105921) (-84 "bookvol10.3.pamphlet" 102019 102032 104353 104358) (-83 "bookvol10.3.pamphlet" 101308 101321 102009 102014) (-82 "bookvol10.3.pamphlet" 100297 100310 101298 101303) (-81 "bookvol10.3.pamphlet" 98573 98612 100287 100292) (-80 "bookvol10.3.pamphlet" 97075 97114 98563 98568) (-79 "bookvol10.3.pamphlet" 96060 96073 97065 97070) (-78 "bookvol10.3.pamphlet" 95311 95324 96050 96055) (-77 "bookvol10.3.pamphlet" 94897 94910 95301 95306) (-76 "bookvol10.3.pamphlet" 94011 94024 94887 94892) (-75 "bookvol10.3.pamphlet" 92743 92756 94001 94006) (-74 "bookvol10.3.pamphlet" 92227 92240 92733 92738) (-73 "bookvol10.3.pamphlet" 82658 82671 92217 92222) (-72 "bookvol10.3.pamphlet" 81514 81527 82648 82653) (-71 "bookvol10.3.pamphlet" 80597 80610 81504 81509) (-70 "bookvol10.3.pamphlet" 79770 79783 80587 80592) (-69 "bookvol10.3.pamphlet" 79150 79163 79760 79765) (-68 "bookvol10.3.pamphlet" 73229 73242 79140 79145) (-67 "bookvol10.3.pamphlet" 72647 72660 73219 73224) (-66 "bookvol10.3.pamphlet" 71928 71941 72637 72642) (-65 "bookvol10.3.pamphlet" 71534 71543 71758 71785) (-64 "bookvol10.3.pamphlet" 70450 70459 70940 70967) (-63 "bookvol10.4.pamphlet" 68487 68498 70440 70445) (-62 "bookvol10.2.pamphlet" 61763 61784 68443 68482) (-61 NIL 55071 55094 61753 61758) (-60 "bookvol10.4.pamphlet" 54387 54409 55061 55066) (-59 "bookvol10.4.pamphlet" 53990 54003 54377 54382) (-58 "bookvol10.4.pamphlet" 53144 53151 53980 53985) (-57 "bookvol10.3.pamphlet" 51492 51499 53134 53139) (-56 "bookvol10.4.pamphlet" 50569 50578 51482 51487) (-55 "bookvol10.3.pamphlet" 49026 49042 50549 50564) (-54 "bookvol10.3.pamphlet" 48939 48946 49016 49021) (-53 "bookvol10.3.pamphlet" 47250 47257 48755 48848) (-52 "bookvol10.2.pamphlet" 45461 45472 47148 47245) (-51 NIL 43509 43522 45198 45203) (-50 "bookvol10.3.pamphlet" 41555 41576 41903 41930) (-49 "bookvol10.3.pamphlet" 40662 40688 41427 41480) (-48 "bookvol10.4.pamphlet" 36627 36638 40618 40623) (-47 "bookvol10.4.pamphlet" 35836 35850 36617 36622) (-46 "bookvol10.4.pamphlet" 33310 33325 35633 35638) (-45 "bookvol10.3.pamphlet" 31642 31669 31842 31998) (-44 "bookvol10.4.pamphlet" 30767 30777 31632 31637) (-43 "bookvol10.2.pamphlet" 30267 30276 30723 30762) (-42 NIL 29799 29810 30257 30262) (-41 "bookvol10.2.pamphlet" 29301 29322 29755 29794) (-40 "bookvol10.2.pamphlet" 28682 28689 29291 29296) (-39 "bookvol10.2.pamphlet" 27059 27066 28662 28677) (-38 NIL 25410 25419 27015 27020) (-37 "bookvol10.2.pamphlet" 23298 23307 25400 25405) (-36 "bookvol10.4.pamphlet" 21697 21712 23233 23238) (-35 "bookvol10.3.pamphlet" 21540 21555 21687 21692) (-34 "bookvol10.3.pamphlet" 21389 21398 21530 21535) (-33 "bookvol10.3.pamphlet" 21238 21247 21379 21384) (-32 "bookvol10.4.pamphlet" 21121 21159 21228 21233) (-31 "bookvol10.4.pamphlet" 20704 20742 21111 21116) (-30 "bookvol10.3.pamphlet" 18992 18999 20694 20699) (-29 "bookvol10.2.pamphlet" 16871 16880 18882 18987) (-28 NIL 14848 14859 16861 16866) (-27 "bookvol10.2.pamphlet" 10002 10009 14750 14843) (-26 NIL 5242 5251 9992 9997) (-25 "bookvol10.2.pamphlet" 4600 4607 5232 5237) (-24 NIL 3956 3965 4590 4595) (-23 "bookvol10.2.pamphlet" 3325 3332 3946 3951) (-22 NIL 2692 2701 3315 3320) (-21 "bookvol10.2.pamphlet" 2198 2205 2682 2687) (-20 NIL 1702 1711 2188 2193) (-19 "bookvol10.2.pamphlet" 850 859 1658 1697) (-18 NIL 30 41 840 845)) 
\ No newline at end of file
+((-1311 NIL 2394200 2394205 2394210 2394215) (-3 NIL 2394180 2394185 2394190 2394195) (-2 NIL 2394160 2394165 2394170 2394175) (-1 NIL 2394140 2394145 2394150 2394155) (0 NIL 2394120 2394125 2394130 2394135) (-1306 "bookvol10.3.pamphlet" 2393937 2393950 2394058 2394115) (-1305 "bookvol10.4.pamphlet" 2393057 2393068 2393927 2393932) (-1304 "bookvol10.4.pamphlet" 2383673 2383695 2393047 2393052) (-1303 "bookvol10.4.pamphlet" 2383170 2383181 2383663 2383668) (-1302 "bookvol10.3.pamphlet" 2382405 2382425 2383026 2383095) (-1301 "bookvol10.3.pamphlet" 2380138 2380151 2382123 2382222) (-1300 "bookvol10.3.pamphlet" 2379710 2379721 2379994 2380063) (-1299 "bookvol10.2.pamphlet" 2379028 2379044 2379636 2379705) (-1298 "bookvol10.3.pamphlet" 2377693 2377713 2378808 2378877) (-1297 "bookvol10.2.pamphlet" 2376157 2376172 2377595 2377688) (-1296 NIL 2374601 2374618 2376041 2376046) (-1295 "bookvol10.2.pamphlet" 2371636 2371652 2374527 2374596) (-1294 "bookvol10.4.pamphlet" 2371035 2371061 2371626 2371631) (-1293 "bookvol10.3.pamphlet" 2370666 2370682 2370891 2370960) (-1292 "bookvol10.2.pamphlet" 2370365 2370376 2370622 2370661) (-1291 "bookvol10.3.pamphlet" 2367033 2367050 2370067 2370094) (-1290 "bookvol10.3.pamphlet" 2366063 2366107 2366891 2366958) (-1289 "bookvol10.4.pamphlet" 2363638 2363660 2366053 2366058) (-1288 "bookvol10.4.pamphlet" 2361902 2361913 2363628 2363633) (-1287 "bookvol10.2.pamphlet" 2361575 2361586 2361870 2361897) (-1286 NIL 2361268 2361281 2361565 2361570) (-1285 "bookvol10.3.pamphlet" 2360862 2360871 2361258 2361263) (-1284 "bookvol10.4.pamphlet" 2358578 2358587 2360852 2360857) (-1283 "bookvol10.4.pamphlet" 2353838 2353847 2358568 2358573) (-1282 "bookvol10.3.pamphlet" 2338054 2338063 2353828 2353833) (-1281 "bookvol10.3.pamphlet" 2326245 2326254 2338044 2338049) (-1280 "bookvol10.3.pamphlet" 2325142 2325153 2325393 2325420) (-1279 "bookvol10.4.pamphlet" 2323816 2323829 2325132 2325137) (-1278 "bookvol10.2.pamphlet" 2321816 2321827 2323772 2323811) (-1277 NIL 2319635 2319648 2321593 2321598) (-1276 "bookvol10.3.pamphlet" 2319415 2319430 2319625 2319630) (-1275 "bookvol10.3.pamphlet" 2314591 2314613 2317882 2317979) (-1274 "bookvol10.4.pamphlet" 2314494 2314522 2314581 2314586) (-1273 "bookvol10.4.pamphlet" 2313788 2313812 2314450 2314455) (-1272 "bookvol10.4.pamphlet" 2311978 2311998 2313778 2313783) (-1271 "bookvol10.3.pamphlet" 2306777 2306805 2310445 2310542) (-1270 "bookvol10.2.pamphlet" 2304094 2304110 2306675 2306772) (-1269 NIL 2301055 2301073 2303638 2303643) (-1268 "bookvol10.4.pamphlet" 2300680 2300715 2301045 2301050) (-1267 "bookvol10.2.pamphlet" 2295964 2295975 2300660 2300675) (-1266 NIL 2291222 2291235 2295920 2295925) (-1265 "bookvol10.3.pamphlet" 2288889 2288915 2290303 2290436) (-1264 "bookvol10.3.pamphlet" 2286440 2286468 2287021 2287170) (-1263 "bookvol10.3.pamphlet" 2284201 2284221 2284572 2284721) (-1262 "bookvol10.2.pamphlet" 2282671 2282691 2284047 2284196) (-1261 NIL 2281283 2281305 2282661 2282666) (-1260 "bookvol10.2.pamphlet" 2279874 2279890 2281129 2281278) (-1259 "bookvol10.4.pamphlet" 2279417 2279470 2279864 2279869) (-1258 "bookvol10.4.pamphlet" 2277845 2277859 2279407 2279412) (-1257 "bookvol10.2.pamphlet" 2275415 2275439 2277743 2277840) (-1256 NIL 2272691 2272717 2275021 2275026) (-1255 "bookvol10.2.pamphlet" 2267079 2267090 2272533 2272686) (-1254 NIL 2261359 2261372 2266815 2266820) (-1253 "bookvol10.4.pamphlet" 2260824 2260843 2261349 2261354) (-1252 "bookvol10.3.pamphlet" 2257783 2257798 2258374 2258527) (-1251 "bookvol10.4.pamphlet" 2256717 2256730 2257773 2257778) (-1250 "bookvol10.4.pamphlet" 2256282 2256296 2256707 2256712) (-1249 "bookvol10.4.pamphlet" 2254523 2254537 2256272 2256277) (-1248 "bookvol10.4.pamphlet" 2253724 2253740 2254513 2254518) (-1247 "bookvol10.4.pamphlet" 2253126 2253147 2253714 2253719) (-1246 "bookvol10.3.pamphlet" 2252479 2252490 2253045 2253050) (-1245 "bookvol10.4.pamphlet" 2251986 2251999 2252435 2252440) (-1244 "bookvol10.4.pamphlet" 2251109 2251121 2251976 2251981) (-1243 "bookvol10.3.pamphlet" 2241781 2241809 2242754 2243183) (-1242 "bookvol10.3.pamphlet" 2235822 2235842 2236190 2236339) (-1241 "bookvol10.2.pamphlet" 2233415 2233435 2235642 2235817) (-1240 NIL 2231142 2231164 2233371 2233376) (-1239 "bookvol10.2.pamphlet" 2229352 2229368 2230988 2231137) (-1238 "bookvol10.4.pamphlet" 2228896 2228949 2229342 2229347) (-1237 "bookvol10.3.pamphlet" 2227289 2227305 2227363 2227460) (-1236 "bookvol10.4.pamphlet" 2227204 2227220 2227279 2227284) (-1235 "bookvol10.2.pamphlet" 2226273 2226282 2227130 2227199) (-1234 NIL 2225404 2225415 2226263 2226268) (-1233 "bookvol10.4.pamphlet" 2224215 2224224 2225394 2225399) (-1232 "bookvol10.4.pamphlet" 2221741 2221752 2224171 2224176) (-1231 "bookvol10.3.pamphlet" 2220972 2220981 2221175 2221202) (-1230 "bookvol10.3.pamphlet" 2220217 2220226 2220604 2220631) (-1229 "bookvol10.3.pamphlet" 2219447 2219456 2219651 2219678) (-1228 "bookvol10.3.pamphlet" 2218690 2218699 2219079 2219106) (-1227 "bookvol10.3.pamphlet" 2217920 2217929 2218124 2218151) (-1226 "bookvol10.3.pamphlet" 2217163 2217172 2217552 2217579) (-1225 "bookvol10.2.pamphlet" 2217085 2217094 2217143 2217158) (-1224 "bookvol10.4.pamphlet" 2215745 2215760 2217075 2217080) (-1223 "bookvol10.3.pamphlet" 2214754 2214765 2215700 2215705) (-1222 "bookvol10.4.pamphlet" 2211648 2211657 2214744 2214749) (-1221 "bookvol10.3.pamphlet" 2210338 2210355 2211638 2211643) (-1220 "bookvol10.3.pamphlet" 2208929 2208945 2209903 2210000) (-1219 "bookvol10.2.pamphlet" 2198485 2198502 2208885 2208924) (-1218 NIL 2188039 2188058 2198441 2198446) (-1217 "bookvol10.4.pamphlet" 2182495 2182512 2187745 2187750) (-1216 "bookvol10.4.pamphlet" 2181466 2181491 2182485 2182490) (-1215 "bookvol10.4.pamphlet" 2179963 2179980 2181456 2181461) (-1214 "bookvol10.2.pamphlet" 2179475 2179484 2179953 2179958) (-1213 NIL 2178985 2178996 2179465 2179470) (-1212 "bookvol10.3.pamphlet" 2177198 2177209 2178815 2178842) (-1211 "bookvol10.2.pamphlet" 2177045 2177054 2177188 2177193) (-1210 NIL 2176890 2176901 2177035 2177040) (-1209 "bookvol10.4.pamphlet" 2176568 2176577 2176880 2176885) (-1208 "bookvol10.4.pamphlet" 2176231 2176242 2176558 2176563) (-1207 "bookvol10.3.pamphlet" 2174810 2174819 2176221 2176226) (-1206 "bookvol10.3.pamphlet" 2171947 2171956 2174800 2174805) (-1205 "bookvol10.4.pamphlet" 2171503 2171514 2171937 2171942) (-1204 "bookvol10.4.pamphlet" 2171064 2171073 2171493 2171498) (-1203 "bookvol10.4.pamphlet" 2169255 2169278 2171054 2171059) (-1202 "bookvol10.2.pamphlet" 2168277 2168300 2169223 2169250) (-1201 NIL 2167319 2167344 2168267 2168272) (-1200 "bookvol10.4.pamphlet" 2166695 2166706 2167309 2167314) (-1199 "bookvol10.3.pamphlet" 2165668 2165691 2165938 2165965) (-1198 "bookvol10.3.pamphlet" 2165158 2165169 2165658 2165663) (-1197 "bookvol10.4.pamphlet" 2162076 2162087 2165148 2165153) (-1196 "bookvol10.4.pamphlet" 2158707 2158718 2162066 2162071) (-1195 "bookvol10.3.pamphlet" 2156804 2156813 2158697 2158702) (-1194 "bookvol10.3.pamphlet" 2152869 2152878 2156794 2156799) (-1193 "bookvol10.3.pamphlet" 2151875 2151886 2151957 2152084) (-1192 "bookvol10.4.pamphlet" 2151296 2151307 2151865 2151870) (-1191 "bookvol10.3.pamphlet" 2148758 2148767 2151286 2151291) (-1190 "bookvol10.3.pamphlet" 2145504 2145513 2148748 2148753) (-1189 "bookvol10.3.pamphlet" 2142535 2142563 2143971 2144068) (-1188 "bookvol10.3.pamphlet" 2139669 2139697 2140667 2140816) (-1187 "bookvol10.3.pamphlet" 2136364 2136375 2137219 2137372) (-1186 "bookvol10.4.pamphlet" 2135484 2135502 2136354 2136359) (-1185 "bookvol10.3.pamphlet" 2132928 2132939 2132997 2133150) (-1184 "bookvol10.4.pamphlet" 2132322 2132335 2132918 2132923) (-1183 "bookvol10.4.pamphlet" 2130924 2130935 2132312 2132317) (-1182 "bookvol10.4.pamphlet" 2130602 2130619 2130914 2130919) (-1181 "bookvol10.3.pamphlet" 2121261 2121289 2122247 2122676) (-1180 "bookvol10.3.pamphlet" 2120943 2120958 2121251 2121256) (-1179 "bookvol10.3.pamphlet" 2113298 2113313 2120933 2120938) (-1178 "bookvol10.4.pamphlet" 2112470 2112484 2113254 2113259) (-1177 "bookvol10.4.pamphlet" 2108571 2108587 2112460 2112465) (-1176 "bookvol10.4.pamphlet" 2105041 2105057 2108561 2108566) (-1175 "bookvol10.4.pamphlet" 2097613 2097624 2104922 2104927) (-1174 "bookvol10.3.pamphlet" 2096692 2096709 2096841 2096868) (-1173 "bookvol10.3.pamphlet" 2096075 2096084 2096173 2096200) (-1172 "bookvol10.2.pamphlet" 2095851 2095860 2096031 2096070) (-1171 "bookvol10.3.pamphlet" 2091439 2091450 2095599 2095614) (-1170 "bookvol10.4.pamphlet" 2090780 2090795 2091429 2091434) (-1169 "bookvol10.4.pamphlet" 2089353 2089366 2090770 2090775) (-1168 "bookvol10.4.pamphlet" 2088861 2088872 2089343 2089348) (-1167 "bookvol10.4.pamphlet" 2088546 2088557 2088851 2088856) (-1166 "bookvol10.4.pamphlet" 2087482 2087498 2088536 2088541) (-1165 "bookvol10.2.pamphlet" 2086708 2086717 2087472 2087477) (-1164 "bookvol10.3.pamphlet" 2085798 2085826 2085963 2085978) (-1163 "bookvol10.2.pamphlet" 2084897 2084908 2085778 2085793) (-1162 NIL 2084004 2084017 2084887 2084892) (-1161 "bookvol10.3.pamphlet" 2080041 2080052 2083834 2083861) (-1160 "bookvol10.3.pamphlet" 2078288 2078305 2079743 2079770) (-1159 "bookvol10.4.pamphlet" 2077054 2077074 2078278 2078283) (-1158 "bookvol10.2.pamphlet" 2072391 2072400 2077010 2077049) (-1157 NIL 2067760 2067771 2072381 2072386) (-1156 "bookvol10.3.pamphlet" 2065442 2065460 2066348 2066435) (-1155 "bookvol10.3.pamphlet" 2060949 2060962 2065193 2065220) (-1154 "bookvol10.3.pamphlet" 2057997 2058010 2060939 2060944) (-1153 "bookvol10.2.pamphlet" 2056808 2056817 2057987 2057992) (-1152 "bookvol10.4.pamphlet" 2055377 2055386 2056798 2056803) (-1151 "bookvol10.2.pamphlet" 2039767 2039778 2055367 2055372) (-1150 "bookvol10.3.pamphlet" 2039549 2039560 2039757 2039762) (-1149 "bookvol10.4.pamphlet" 2039098 2039111 2039505 2039510) (-1148 "bookvol10.4.pamphlet" 2036693 2036704 2039088 2039093) (-1147 "bookvol10.4.pamphlet" 2035282 2035293 2036683 2036688) (-1146 "bookvol10.4.pamphlet" 2029770 2029781 2035272 2035277) (-1145 "bookvol10.4.pamphlet" 2028234 2028252 2029760 2029765) (-1144 "bookvol10.2.pamphlet" 2028005 2028022 2028190 2028229) (-1143 "bookvol10.3.pamphlet" 2026159 2026185 2027570 2027667) (-1142 "bookvol10.3.pamphlet" 2023615 2023635 2023988 2024115) (-1141 "bookvol10.4.pamphlet" 2022452 2022477 2023605 2023610) (-1140 "bookvol10.2.pamphlet" 2020560 2020590 2022384 2022447) (-1139 NIL 2018612 2018644 2020438 2020443) (-1138 "bookvol10.2.pamphlet" 2017214 2017225 2018568 2018607) (-1137 "bookvol10.3.pamphlet" 2015577 2015586 2017080 2017209) (-1136 "bookvol10.4.pamphlet" 2015320 2015329 2015567 2015572) (-1135 "bookvol10.4.pamphlet" 2014410 2014421 2015310 2015315) (-1134 "bookvol10.4.pamphlet" 2013669 2013686 2014400 2014405) (-1133 "bookvol10.4.pamphlet" 2011633 2011648 2013625 2013630) (-1132 "bookvol10.3.pamphlet" 2003346 2003373 2003848 2003979) (-1131 "bookvol10.2.pamphlet" 2002658 2002667 2003336 2003341) (-1130 NIL 2001968 2001979 2002648 2002653) (-1129 "bookvol10.4.pamphlet" 1995480 1995489 2001958 2001963) (-1128 "bookvol10.2.pamphlet" 1995043 1995060 1995436 1995475) (-1127 "bookvol10.4.pamphlet" 1994742 1994762 1995033 1995038) (-1126 "bookvol10.4.pamphlet" 1990659 1990679 1994732 1994737) (-1125 "bookvol10.3.pamphlet" 1990120 1990134 1990649 1990654) (-1124 "bookvol10.3.pamphlet" 1989963 1990003 1990110 1990115) (-1123 "bookvol10.3.pamphlet" 1989855 1989864 1989953 1989958) (-1122 "bookvol10.2.pamphlet" 1987106 1987146 1989845 1989850) (-1121 "bookvol10.3.pamphlet" 1985470 1985481 1986583 1986622) (-1120 "bookvol10.3.pamphlet" 1983950 1983967 1985460 1985465) (-1119 "bookvol10.2.pamphlet" 1983440 1983449 1983940 1983945) (-1118 NIL 1982928 1982939 1983430 1983435) (-1117 "bookvol10.2.pamphlet" 1982819 1982828 1982918 1982923) (-1116 "bookvol10.2.pamphlet" 1979709 1979720 1982787 1982814) (-1115 NIL 1976619 1976632 1979699 1979704) (-1114 "bookvol10.2.pamphlet" 1975681 1975694 1976599 1976614) (-1113 "bookvol10.3.pamphlet" 1975494 1975505 1975600 1975605) (-1112 "bookvol10.2.pamphlet" 1974282 1974293 1975474 1975489) (-1111 "bookvol10.3.pamphlet" 1973368 1973379 1974237 1974242) (-1110 "bookvol10.4.pamphlet" 1973074 1973087 1973358 1973363) (-1109 "bookvol10.4.pamphlet" 1972493 1972506 1973030 1973035) (-1108 "bookvol10.3.pamphlet" 1971791 1971802 1972483 1972488) (-1107 "bookvol10.3.pamphlet" 1969195 1969206 1969472 1969599) (-1106 "bookvol10.3.pamphlet" 1965666 1965677 1969163 1969190) (-1105 "bookvol10.4.pamphlet" 1963769 1963780 1965656 1965661) (-1104 "bookvol10.4.pamphlet" 1962618 1962629 1963759 1963764) (-1103 "bookvol10.3.pamphlet" 1962490 1962499 1962608 1962613) (-1102 "bookvol10.4.pamphlet" 1962203 1962223 1962480 1962485) (-1101 "bookvol10.3.pamphlet" 1960332 1960348 1960989 1961124) (-1100 "bookvol10.4.pamphlet" 1960033 1960053 1960322 1960327) (-1099 "bookvol10.4.pamphlet" 1957769 1957785 1960023 1960028) (-1098 "bookvol10.3.pamphlet" 1957201 1957225 1957759 1957764) (-1097 "bookvol10.3.pamphlet" 1955383 1955407 1957191 1957196) (-1096 "bookvol10.3.pamphlet" 1955235 1955248 1955373 1955378) (-1095 "bookvol10.4.pamphlet" 1952605 1952625 1955225 1955230) (-1094 "bookvol10.2.pamphlet" 1943443 1943460 1952561 1952600) (-1093 NIL 1934313 1934332 1943433 1943438) (-1092 "bookvol10.4.pamphlet" 1933066 1933086 1934303 1934308) (-1091 "bookvol10.2.pamphlet" 1931472 1931502 1933056 1933061) (-1090 NIL 1929876 1929908 1931462 1931467) (-1089 "bookvol10.2.pamphlet" 1913118 1913133 1929744 1929871) (-1088 NIL 1896073 1896090 1912701 1912706) (-1087 "bookvol10.3.pamphlet" 1892558 1892567 1895302 1895329) (-1086 "bookvol10.3.pamphlet" 1891805 1891814 1892424 1892553) (-1085 "bookvol10.3.pamphlet" 1890939 1890971 1891795 1891800) (-1084 "bookvol10.2.pamphlet" 1889762 1889771 1890841 1890934) (-1083 NIL 1888671 1888682 1889752 1889757) (-1082 "bookvol10.2.pamphlet" 1888191 1888200 1888661 1888666) (-1081 "bookvol10.2.pamphlet" 1887706 1887717 1888181 1888186) (-1080 "bookvol10.4.pamphlet" 1887134 1887191 1887696 1887701) (-1079 "bookvol10.3.pamphlet" 1885869 1885888 1886357 1886396) (-1078 "bookvol10.2.pamphlet" 1881505 1881536 1885813 1885864) (-1077 NIL 1877043 1877076 1881353 1881358) (-1076 "bookvol10.4.pamphlet" 1876931 1876951 1877033 1877038) (-1075 "bookvol10.2.pamphlet" 1876290 1876299 1876911 1876926) (-1074 NIL 1875657 1875668 1876280 1876285) (-1073 "bookvol10.4.pamphlet" 1874685 1874694 1875647 1875652) (-1072 "bookvol10.3.pamphlet" 1873364 1873380 1874245 1874272) (-1071 "bookvol10.4.pamphlet" 1871414 1871425 1873354 1873359) (-1070 "bookvol10.4.pamphlet" 1869070 1869081 1871404 1871409) (-1069 "bookvol10.4.pamphlet" 1868532 1868543 1869060 1869065) (-1068 "bookvol10.4.pamphlet" 1868267 1868279 1868522 1868527) (-1067 "bookvol10.4.pamphlet" 1867263 1867272 1868257 1868262) (-1066 "bookvol10.4.pamphlet" 1866682 1866695 1867253 1867258) (-1065 "bookvol10.2.pamphlet" 1866024 1866035 1866672 1866677) (-1064 NIL 1865364 1865377 1866014 1866019) (-1063 "bookvol10.3.pamphlet" 1864008 1864017 1864593 1864620) (-1062 "bookvol10.3.pamphlet" 1863355 1863402 1863946 1864003) (-1061 "bookvol10.4.pamphlet" 1862681 1862692 1863345 1863350) (-1060 "bookvol10.4.pamphlet" 1862412 1862423 1862671 1862676) (-1059 "bookvol10.4.pamphlet" 1859968 1859977 1862402 1862407) (-1058 "bookvol10.4.pamphlet" 1859667 1859678 1859958 1859963) (-1057 "bookvol10.4.pamphlet" 1849687 1849698 1859509 1859514) (-1056 "bookvol10.4.pamphlet" 1844075 1844086 1849637 1849642) (-1055 "bookvol10.3.pamphlet" 1842370 1842387 1843777 1843804) (-1054 "bookvol10.3.pamphlet" 1841720 1841731 1842325 1842330) (-1053 "bookvol10.4.pamphlet" 1840850 1840867 1841710 1841715) (-1052 "bookvol10.4.pamphlet" 1839257 1839274 1840805 1840810) (-1051 "bookvol10.3.pamphlet" 1838090 1838110 1838744 1838837) (-1050 "bookvol10.4.pamphlet" 1836663 1836672 1838080 1838085) (-1049 "bookvol10.2.pamphlet" 1836547 1836556 1836653 1836658) (-1048 "bookvol10.4.pamphlet" 1833898 1833913 1836537 1836542) (-1047 "bookvol10.4.pamphlet" 1830807 1830822 1833888 1833893) (-1046 "bookvol10.4.pamphlet" 1830556 1830581 1830797 1830802) (-1045 "bookvol10.4.pamphlet" 1830123 1830134 1830546 1830551) (-1044 "bookvol10.4.pamphlet" 1828977 1828995 1830113 1830118) (-1043 "bookvol10.4.pamphlet" 1826942 1826960 1828967 1828972) (-1042 "bookvol10.4.pamphlet" 1826183 1826200 1826932 1826937) (-1041 "bookvol10.4.pamphlet" 1825239 1825256 1826173 1826178) (-1040 "bookvol10.2.pamphlet" 1822568 1822577 1825141 1825234) (-1039 NIL 1819983 1819994 1822558 1822563) (-1038 "bookvol10.2.pamphlet" 1817956 1817967 1819963 1819978) (-1037 NIL 1815866 1815879 1817875 1817880) (-1036 "bookvol10.4.pamphlet" 1815287 1815298 1815856 1815861) (-1035 "bookvol10.4.pamphlet" 1814471 1814483 1815277 1815282) (-1034 "bookvol10.4.pamphlet" 1813828 1813837 1814461 1814466) (-1033 "bookvol10.4.pamphlet" 1813584 1813593 1813818 1813823) (-1032 "bookvol10.3.pamphlet" 1810399 1810413 1812051 1812144) (-1031 "bookvol10.3.pamphlet" 1808828 1808865 1808931 1809087) (-1030 "bookvol10.2.pamphlet" 1808459 1808468 1808818 1808823) (-1029 NIL 1808088 1808099 1808449 1808454) (-1028 "bookvol10.3.pamphlet" 1803905 1803916 1807918 1807945) (-1027 "bookvol10.3.pamphlet" 1802535 1802546 1802829 1802894) (-1026 "bookvol10.4.pamphlet" 1801939 1801958 1802525 1802530) (-1025 "bookvol10.2.pamphlet" 1800145 1800156 1801869 1801934) (-1024 NIL 1798102 1798115 1799828 1799833) (-1023 "bookvol10.2.pamphlet" 1796915 1796926 1798058 1798097) (-1022 "bookvol10.3.pamphlet" 1796383 1796398 1796905 1796910) (-1021 "bookvol10.2.pamphlet" 1795077 1795088 1796273 1796378) (-1020 NIL 1793374 1793387 1794572 1794577) (-1019 "bookvol10.4.pamphlet" 1793074 1793091 1793364 1793369) (-1018 "bookvol10.3.pamphlet" 1792648 1792657 1793064 1793069) (-1017 "bookvol10.4.pamphlet" 1788631 1788651 1792638 1792643) (-1016 "bookvol10.3.pamphlet" 1784803 1784836 1788545 1788550) (-1015 "bookvol10.4.pamphlet" 1782814 1782833 1784793 1784798) (-1014 "bookvol10.4.pamphlet" 1780141 1780163 1782804 1782809) (-1013 "bookvol10.4.pamphlet" 1779477 1779497 1780131 1780136) (-1012 "bookvol10.2.pamphlet" 1775755 1775766 1779467 1779472) (-1011 "bookvol10.4.pamphlet" 1772880 1772891 1775745 1775750) (-1010 "bookvol10.4.pamphlet" 1772698 1772713 1772870 1772875) (-1009 "bookvol10.2.pamphlet" 1771789 1771800 1772654 1772693) (-1008 "bookvol10.4.pamphlet" 1771099 1771124 1771779 1771784) (-1007 "bookvol10.4.pamphlet" 1769968 1769979 1771089 1771094) (-1006 "bookvol10.4.pamphlet" 1757476 1757493 1769846 1769851) (-1005 "bookvol10.2.pamphlet" 1752330 1752354 1757444 1757471) (-1004 NIL 1747170 1747196 1752286 1752291) (-1003 "bookvol10.2.pamphlet" 1746194 1746203 1747160 1747165) (-1002 "bookvol10.2.pamphlet" 1744956 1744986 1746092 1746189) (-1001 NIL 1743808 1743840 1744946 1744951) (-1000 "bookvol10.3.pamphlet" 1742610 1742619 1743798 1743803) (-999 "bookvol10.2.pamphlet" 1740105 1740115 1742600 1742605) (-998 "bookvol10.4.pamphlet" 1731774 1731791 1740061 1740066) (-997 "bookvol10.2.pamphlet" 1731197 1731207 1731730 1731769) (-996 "bookvol10.3.pamphlet" 1731081 1731097 1731187 1731192) (-995 "bookvol10.3.pamphlet" 1730971 1730981 1731071 1731076) (-994 "bookvol10.3.pamphlet" 1730861 1730871 1730961 1730966) (-993 "bookvol10.3.pamphlet" 1728300 1728312 1728827 1728882) (-992 "bookvol10.3.pamphlet" 1726698 1726710 1727391 1727518) (-991 "bookvol10.4.pamphlet" 1725952 1725991 1726688 1726693) (-990 "bookvol10.4.pamphlet" 1725704 1725712 1725942 1725947) (-989 "bookvol10.4.pamphlet" 1723937 1723947 1725694 1725699) (-988 "bookvol10.4.pamphlet" 1722024 1722038 1723927 1723932) (-987 "bookvol10.2.pamphlet" 1721635 1721643 1722014 1722019) (-986 "bookvol10.3.pamphlet" 1720888 1720898 1721041 1721068) (-985 "bookvol10.4.pamphlet" 1718994 1719006 1720878 1720883) (-984 "bookvol10.4.pamphlet" 1718360 1718372 1718984 1718989) (-983 "bookvol10.2.pamphlet" 1717725 1717733 1718350 1718355) (-982 "bookvol10.4.pamphlet" 1712534 1712542 1717715 1717720) (-981 "bookvol10.4.pamphlet" 1711278 1711300 1712490 1712495) (-980 "bookvol10.3.pamphlet" 1708596 1708606 1709092 1709219) (-979 "bookvol10.4.pamphlet" 1707885 1707908 1708586 1708591) (-978 "bookvol10.4.pamphlet" 1705895 1705917 1707875 1707880) (-977 "bookvol10.2.pamphlet" 1699325 1699346 1705763 1705890) (-976 NIL 1692057 1692080 1698497 1698502) (-975 "bookvol10.4.pamphlet" 1691503 1691517 1692047 1692052) (-974 "bookvol10.4.pamphlet" 1691109 1691121 1691493 1691498) (-973 "bookvol10.4.pamphlet" 1690150 1690179 1691065 1691070) (-972 "bookvol10.4.pamphlet" 1688898 1688913 1690140 1690145) (-971 "bookvol10.3.pamphlet" 1687959 1687969 1688046 1688073) (-970 "bookvol10.4.pamphlet" 1684631 1684639 1687949 1687954) (-969 "bookvol10.4.pamphlet" 1683452 1683466 1684621 1684626) (-968 "bookvol10.4.pamphlet" 1683009 1683019 1683442 1683447) (-967 "bookvol10.4.pamphlet" 1682608 1682622 1682999 1683004) (-966 "bookvol10.4.pamphlet" 1682128 1682142 1682598 1682603) (-965 "bookvol10.4.pamphlet" 1681623 1681645 1682118 1682123) (-964 "bookvol10.4.pamphlet" 1680703 1680721 1681555 1681560) (-963 "bookvol10.4.pamphlet" 1680288 1680302 1680693 1680698) (-962 "bookvol10.4.pamphlet" 1679867 1679879 1680278 1680283) (-961 "bookvol10.4.pamphlet" 1679447 1679457 1679857 1679862) (-960 "bookvol10.4.pamphlet" 1679032 1679050 1679437 1679442) (-959 "bookvol10.4.pamphlet" 1678342 1678356 1679022 1679027) (-958 "bookvol10.4.pamphlet" 1677409 1677417 1678332 1678337) (-957 "bookvol10.4.pamphlet" 1676433 1676449 1677399 1677404) (-956 "bookvol10.4.pamphlet" 1675331 1675369 1676423 1676428) (-955 "bookvol10.4.pamphlet" 1675111 1675119 1675321 1675326) (-954 "bookvol10.3.pamphlet" 1669963 1669971 1675101 1675106) (-953 "bookvol10.3.pamphlet" 1666577 1666585 1669953 1669958) (-952 "bookvol10.4.pamphlet" 1665728 1665738 1666567 1666572) (-951 "bookvol10.4.pamphlet" 1651841 1651868 1665718 1665723) (-950 "bookvol10.3.pamphlet" 1651748 1651762 1651831 1651836) (-949 "bookvol10.3.pamphlet" 1651659 1651669 1651738 1651743) (-948 "bookvol10.3.pamphlet" 1651570 1651580 1651649 1651654) (-947 "bookvol10.2.pamphlet" 1650612 1650626 1651560 1651565) (-946 "bookvol10.4.pamphlet" 1650234 1650253 1650602 1650607) (-945 "bookvol10.4.pamphlet" 1650018 1650034 1650224 1650229) (-944 "bookvol10.3.pamphlet" 1649642 1649650 1649992 1650013) (-943 "bookvol10.2.pamphlet" 1648622 1648630 1649568 1649637) (-942 "bookvol10.4.pamphlet" 1648367 1648377 1648612 1648617) (-941 "bookvol10.4.pamphlet" 1646985 1646999 1648357 1648362) (-940 "bookvol10.4.pamphlet" 1638943 1638951 1646975 1646980) (-939 "bookvol10.4.pamphlet" 1637424 1637441 1638933 1638938) (-938 "bookvol10.4.pamphlet" 1636475 1636485 1637414 1637419) (-937 "bookvol10.3.pamphlet" 1632045 1632055 1636377 1636470) (-936 "bookvol10.4.pamphlet" 1631392 1631408 1632035 1632040) (-935 "bookvol10.4.pamphlet" 1629533 1629562 1631382 1631387) (-934 "bookvol10.4.pamphlet" 1628903 1628921 1629523 1629528) (-933 "bookvol10.4.pamphlet" 1628324 1628351 1628893 1628898) (-932 "bookvol10.3.pamphlet" 1627999 1628011 1628129 1628222) (-931 "bookvol10.2.pamphlet" 1625707 1625715 1627925 1627994) (-930 NIL 1623443 1623453 1625663 1625668) (-929 "bookvol10.4.pamphlet" 1621350 1621362 1623433 1623438) (-928 "bookvol10.4.pamphlet" 1619010 1619033 1621340 1621345) (-927 "bookvol10.3.pamphlet" 1614332 1614342 1618840 1618855) (-926 "bookvol10.3.pamphlet" 1609097 1609107 1614322 1614327) (-925 "bookvol10.2.pamphlet" 1607760 1607770 1609077 1609092) (-924 "bookvol10.4.pamphlet" 1606519 1606533 1607750 1607755) (-923 "bookvol10.3.pamphlet" 1605791 1605801 1606371 1606376) (-922 "bookvol10.2.pamphlet" 1604166 1604176 1605771 1605786) (-921 NIL 1602549 1602561 1604156 1604161) (-920 "bookvol10.3.pamphlet" 1600728 1600736 1602539 1602544) (-919 "bookvol10.4.pamphlet" 1594804 1594812 1600718 1600723) (-918 "bookvol10.4.pamphlet" 1594156 1594173 1594794 1594799) (-917 "bookvol10.2.pamphlet" 1592306 1592314 1594146 1594151) (-916 "bookvol10.4.pamphlet" 1592041 1592054 1592296 1592301) (-915 "bookvol10.3.pamphlet" 1590683 1590700 1592031 1592036) (-914 "bookvol10.3.pamphlet" 1584968 1584978 1590673 1590678) (-913 "bookvol10.4.pamphlet" 1584699 1584711 1584958 1584963) (-912 "bookvol10.4.pamphlet" 1582997 1583013 1584689 1584694) (-911 "bookvol10.3.pamphlet" 1580658 1580670 1582987 1582992) (-910 "bookvol10.4.pamphlet" 1580370 1580384 1580648 1580653) (-909 "bookvol10.4.pamphlet" 1578591 1578622 1580078 1580083) (-908 "bookvol10.2.pamphlet" 1578030 1578040 1578581 1578586) (-907 "bookvol10.3.pamphlet" 1577140 1577154 1578020 1578025) (-906 "bookvol10.2.pamphlet" 1576846 1576856 1577130 1577135) (-905 "bookvol10.4.pamphlet" 1574364 1574372 1576836 1576841) (-904 "bookvol10.3.pamphlet" 1573822 1573850 1574354 1574359) (-903 "bookvol10.4.pamphlet" 1573615 1573631 1573812 1573817) (-902 "bookvol10.3.pamphlet" 1573073 1573101 1573605 1573610) (-901 "bookvol10.4.pamphlet" 1572860 1572876 1573063 1573068) (-900 "bookvol10.3.pamphlet" 1572330 1572358 1572850 1572855) (-899 "bookvol10.4.pamphlet" 1572117 1572133 1572320 1572325) (-898 "bookvol10.4.pamphlet" 1570940 1570989 1572107 1572112) (-897 "bookvol10.4.pamphlet" 1570354 1570362 1570930 1570935) (-896 "bookvol10.3.pamphlet" 1569362 1569370 1570344 1570349) (-895 "bookvol10.4.pamphlet" 1563809 1563832 1569318 1569323) (-894 "bookvol10.4.pamphlet" 1557690 1557713 1563758 1563763) (-893 "bookvol10.3.pamphlet" 1555066 1555084 1556195 1556288) (-892 "bookvol10.3.pamphlet" 1553129 1553141 1553302 1553395) (-891 "bookvol10.3.pamphlet" 1552874 1552886 1553055 1553124) (-890 "bookvol10.2.pamphlet" 1551420 1551432 1552800 1552869) (-889 "bookvol10.4.pamphlet" 1550365 1550384 1551410 1551415) (-888 "bookvol10.4.pamphlet" 1549370 1549386 1550355 1550360) (-887 "bookvol10.3.pamphlet" 1548205 1548213 1549041 1549134) (-886 "bookvol10.2.pamphlet" 1547189 1547197 1548107 1548200) (-885 "bookvol10.2.pamphlet" 1545488 1545496 1547091 1547184) (-884 "bookvol10.3.pamphlet" 1544447 1544457 1545284 1545377) (-883 "bookvol10.2.pamphlet" 1543434 1543442 1544349 1544442) (-882 "bookvol10.3.pamphlet" 1541973 1541993 1542824 1542917) (-881 "bookvol10.2.pamphlet" 1540949 1540957 1541875 1541968) (-880 "bookvol10.3.pamphlet" 1539957 1539987 1540807 1540874) (-879 "bookvol10.3.pamphlet" 1539738 1539761 1539947 1539952) (-878 "bookvol10.4.pamphlet" 1538864 1538872 1539728 1539733) (-877 "bookvol10.3.pamphlet" 1528278 1528286 1538854 1538859) (-876 "bookvol10.3.pamphlet" 1527883 1527891 1528268 1528273) (-875 "bookvol10.4.pamphlet" 1526340 1526350 1527800 1527805) (-874 "bookvol10.3.pamphlet" 1525690 1525718 1526020 1526059) (-873 "bookvol10.3.pamphlet" 1524975 1524999 1525370 1525409) (-872 "bookvol10.4.pamphlet" 1522735 1522747 1524895 1524900) (-871 "bookvol10.2.pamphlet" 1516747 1516757 1522691 1522730) (-870 NIL 1510649 1510661 1516595 1516600) (-869 "bookvol10.2.pamphlet" 1509789 1509797 1510639 1510644) (-868 NIL 1508927 1508937 1509779 1509784) (-867 "bookvol10.2.pamphlet" 1508261 1508269 1508907 1508922) (-866 NIL 1507603 1507613 1508251 1508256) (-865 "bookvol10.2.pamphlet" 1507327 1507335 1507593 1507598) (-864 "bookvol10.4.pamphlet" 1506474 1506490 1507317 1507322) (-863 "bookvol10.2.pamphlet" 1506408 1506416 1506464 1506469) (-862 "bookvol10.3.pamphlet" 1504900 1504910 1505955 1505984) (-861 "bookvol10.4.pamphlet" 1504252 1504264 1504890 1504895) (-860 "bookvol10.3.pamphlet" 1502018 1502026 1504242 1504247) (-859 "bookvol10.4.pamphlet" 1494470 1494478 1502008 1502013) (-858 "bookvol10.2.pamphlet" 1491948 1491956 1494460 1494465) (-857 "bookvol10.4.pamphlet" 1491503 1491511 1491938 1491943) (-856 "bookvol10.3.pamphlet" 1491245 1491255 1491325 1491392) (-855 "bookvol10.3.pamphlet" 1490021 1490031 1490792 1490821) (-854 "bookvol10.4.pamphlet" 1489512 1489524 1490011 1490016) (-853 "bookvol10.4.pamphlet" 1488562 1488570 1489502 1489507) (-852 "bookvol10.2.pamphlet" 1488346 1488356 1488506 1488557) (-851 "bookvol10.4.pamphlet" 1487022 1487030 1488336 1488341) (-850 "bookvol10.2.pamphlet" 1486097 1486105 1487012 1487017) (-849 "bookvol10.3.pamphlet" 1485514 1485526 1485983 1486022) (-848 "bookvol10.4.pamphlet" 1485348 1485358 1485504 1485509) (-847 "bookvol10.3.pamphlet" 1484901 1484909 1485338 1485343) (-846 "bookvol10.3.pamphlet" 1483953 1483961 1484891 1484896) (-845 "bookvol10.3.pamphlet" 1483299 1483307 1483943 1483948) (-844 "bookvol10.3.pamphlet" 1478042 1478050 1483289 1483294) (-843 "bookvol10.3.pamphlet" 1477459 1477467 1478032 1478037) (-842 "bookvol10.2.pamphlet" 1477236 1477244 1477385 1477454) (-841 "bookvol10.3.pamphlet" 1470863 1470873 1477226 1477231) (-840 "bookvol10.3.pamphlet" 1470146 1470156 1470853 1470858) (-839 "bookvol10.3.pamphlet" 1469594 1469620 1469958 1470107) (-838 "bookvol10.3.pamphlet" 1466954 1466964 1467280 1467407) (-837 "bookvol10.3.pamphlet" 1458811 1458831 1459169 1459300) (-836 "bookvol10.4.pamphlet" 1457336 1457355 1458801 1458806) (-835 "bookvol10.4.pamphlet" 1454796 1454813 1457326 1457331) (-834 "bookvol10.4.pamphlet" 1450725 1450742 1454753 1454758) (-833 "bookvol10.4.pamphlet" 1450086 1450110 1450715 1450720) (-832 "bookvol10.4.pamphlet" 1447530 1447547 1450076 1450081) (-831 "bookvol10.4.pamphlet" 1444545 1444567 1447520 1447525) (-830 "bookvol10.3.pamphlet" 1443201 1443209 1444535 1444540) (-829 "bookvol10.4.pamphlet" 1440459 1440481 1443191 1443196) (-828 "bookvol10.4.pamphlet" 1439825 1439849 1440449 1440454) (-827 "bookvol10.4.pamphlet" 1427569 1427577 1439815 1439820) (-826 "bookvol10.4.pamphlet" 1426988 1427004 1427559 1427564) (-825 "bookvol10.3.pamphlet" 1424391 1424399 1426978 1426983) (-824 "bookvol10.4.pamphlet" 1419708 1419724 1424381 1424386) (-823 "bookvol10.4.pamphlet" 1419217 1419235 1419698 1419703) (-822 "bookvol10.2.pamphlet" 1417608 1417616 1419207 1419212) (-821 "bookvol10.3.pamphlet" 1415776 1415786 1416458 1416497) (-820 "bookvol10.4.pamphlet" 1415422 1415443 1415766 1415771) (-819 "bookvol10.2.pamphlet" 1413370 1413380 1415378 1415417) (-818 NIL 1411043 1411055 1413053 1413058) (-817 "bookvol10.2.pamphlet" 1410893 1410901 1411033 1411038) (-816 "bookvol10.2.pamphlet" 1410659 1410667 1410883 1410888) (-815 "bookvol10.2.pamphlet" 1410013 1410021 1410649 1410654) (-814 "bookvol10.2.pamphlet" 1409876 1409884 1410003 1410008) (-813 "bookvol10.2.pamphlet" 1409740 1409748 1409866 1409871) (-812 "bookvol10.4.pamphlet" 1409467 1409483 1409730 1409735) (-811 "bookvol10.4.pamphlet" 1398196 1398204 1409457 1409462) (-810 "bookvol10.4.pamphlet" 1389763 1389771 1398186 1398191) (-809 "bookvol10.2.pamphlet" 1387118 1387126 1389753 1389758) (-808 "bookvol10.4.pamphlet" 1385960 1385968 1387108 1387113) (-807 "bookvol10.4.pamphlet" 1378118 1378128 1385765 1385770) (-806 "bookvol10.2.pamphlet" 1377525 1377541 1378074 1378113) (-805 "bookvol10.4.pamphlet" 1377076 1377086 1377442 1377447) (-804 "bookvol10.3.pamphlet" 1370977 1370987 1374626 1374779) (-803 "bookvol10.4.pamphlet" 1370373 1370385 1370967 1370972) (-802 "bookvol10.3.pamphlet" 1366583 1366602 1366875 1367002) (-801 "bookvol10.3.pamphlet" 1365107 1365117 1365184 1365277) (-800 "bookvol10.4.pamphlet" 1363497 1363511 1365097 1365102) (-799 "bookvol10.4.pamphlet" 1363389 1363418 1363487 1363492) (-798 "bookvol10.4.pamphlet" 1362637 1362657 1363379 1363384) (-797 "bookvol10.3.pamphlet" 1362525 1362539 1362617 1362632) (-796 "bookvol10.4.pamphlet" 1362119 1362158 1362515 1362520) (-795 "bookvol10.4.pamphlet" 1360967 1360986 1362109 1362114) (-794 "bookvol10.4.pamphlet" 1360649 1360675 1360957 1360962) (-793 "bookvol10.3.pamphlet" 1360390 1360398 1360639 1360644) (-792 "bookvol10.4.pamphlet" 1360066 1360076 1360380 1360385) (-791 "bookvol10.4.pamphlet" 1359523 1359539 1360056 1360061) (-790 "bookvol10.3.pamphlet" 1358413 1358421 1359497 1359518) (-789 "bookvol10.4.pamphlet" 1357039 1357049 1358403 1358408) (-788 "bookvol10.3.pamphlet" 1354727 1354735 1357029 1357034) (-787 "bookvol10.4.pamphlet" 1352195 1352212 1354717 1354722) (-786 "bookvol10.4.pamphlet" 1351514 1351528 1352185 1352190) (-785 "bookvol10.4.pamphlet" 1349654 1349670 1351504 1351509) (-784 "bookvol10.4.pamphlet" 1349311 1349325 1349644 1349649) (-783 "bookvol10.4.pamphlet" 1347489 1347503 1349301 1349306) (-782 "bookvol10.2.pamphlet" 1347087 1347095 1347479 1347484) (-781 NIL 1346683 1346693 1347077 1347082) (-780 "bookvol10.2.pamphlet" 1346061 1346069 1346673 1346678) (-779 NIL 1345437 1345447 1346051 1346056) (-778 "bookvol10.4.pamphlet" 1344514 1344522 1345427 1345432) (-777 "bookvol10.4.pamphlet" 1334956 1334964 1344504 1344509) (-776 "bookvol10.4.pamphlet" 1333456 1333464 1334946 1334951) (-775 "bookvol10.4.pamphlet" 1327920 1327928 1333446 1333451) (-774 "bookvol10.4.pamphlet" 1322076 1322084 1327910 1327915) (-773 "bookvol10.4.pamphlet" 1317886 1317894 1322066 1322071) (-772 "bookvol10.4.pamphlet" 1311680 1311688 1317876 1317881) (-771 "bookvol10.4.pamphlet" 1302437 1302445 1311670 1311675) (-770 "bookvol10.4.pamphlet" 1298528 1298536 1302427 1302432) (-769 "bookvol10.4.pamphlet" 1296567 1296575 1298518 1298523) (-768 "bookvol10.4.pamphlet" 1289373 1289381 1296557 1296562) (-767 "bookvol10.4.pamphlet" 1283917 1283925 1289363 1289368) (-766 "bookvol10.4.pamphlet" 1279849 1279857 1283907 1283912) (-765 "bookvol10.4.pamphlet" 1278395 1278403 1279839 1279844) (-764 "bookvol10.4.pamphlet" 1277725 1277733 1278385 1278390) (-763 "bookvol10.2.pamphlet" 1277277 1277287 1277693 1277720) (-762 NIL 1276849 1276861 1277267 1277272) (-761 "bookvol10.3.pamphlet" 1274076 1274090 1274399 1274552) (-760 "bookvol10.3.pamphlet" 1272195 1272209 1272267 1272487) (-759 "bookvol10.4.pamphlet" 1269163 1269180 1272185 1272190) (-758 "bookvol10.4.pamphlet" 1268561 1268578 1269153 1269158) (-757 "bookvol10.2.pamphlet" 1266591 1266612 1268459 1268556) (-756 "bookvol10.4.pamphlet" 1266250 1266260 1266581 1266586) (-755 "bookvol10.4.pamphlet" 1265708 1265716 1266240 1266245) (-754 "bookvol10.3.pamphlet" 1263771 1263781 1265470 1265509) (-753 "bookvol10.2.pamphlet" 1263604 1263614 1263727 1263766) (-752 "bookvol10.3.pamphlet" 1260639 1260651 1263312 1263379) (-751 "bookvol10.4.pamphlet" 1260201 1260215 1260629 1260634) (-750 "bookvol10.4.pamphlet" 1259762 1259779 1260191 1260196) (-749 "bookvol10.4.pamphlet" 1257835 1257854 1259752 1259757) (-748 "bookvol10.3.pamphlet" 1255287 1255302 1255629 1255756) (-747 "bookvol10.4.pamphlet" 1254566 1254585 1255277 1255282) (-746 "bookvol10.4.pamphlet" 1254376 1254419 1254556 1254561) (-745 "bookvol10.4.pamphlet" 1254124 1254160 1254366 1254371) (-744 "bookvol10.4.pamphlet" 1252495 1252512 1254114 1254119) (-743 "bookvol10.2.pamphlet" 1251397 1251405 1252485 1252490) (-742 NIL 1250297 1250307 1251387 1251392) (-741 "bookvol10.2.pamphlet" 1249025 1249038 1250157 1250292) (-740 NIL 1247775 1247790 1248909 1248914) (-739 "bookvol10.2.pamphlet" 1245928 1245936 1247765 1247770) (-738 NIL 1244079 1244089 1245918 1245923) (-737 "bookvol10.2.pamphlet" 1243270 1243278 1244069 1244074) (-736 NIL 1242459 1242469 1243260 1243265) (-735 "bookvol10.3.pamphlet" 1241116 1241130 1242439 1242454) (-734 "bookvol10.2.pamphlet" 1240829 1240839 1241084 1241111) (-733 NIL 1240562 1240574 1240819 1240824) (-732 "bookvol10.3.pamphlet" 1239881 1239920 1240542 1240557) (-731 "bookvol10.3.pamphlet" 1238501 1238513 1239703 1239770) (-730 "bookvol10.3.pamphlet" 1238014 1238032 1238491 1238496) (-729 "bookvol10.3.pamphlet" 1234674 1234690 1235492 1235645) (-728 "bookvol10.3.pamphlet" 1234041 1234080 1234576 1234669) (-727 "bookvol10.3.pamphlet" 1232846 1232854 1234031 1234036) (-726 "bookvol10.4.pamphlet" 1232580 1232614 1232836 1232841) (-725 "bookvol10.2.pamphlet" 1230998 1231008 1232536 1232575) (-724 "bookvol10.4.pamphlet" 1229614 1229631 1230988 1230993) (-723 "bookvol10.4.pamphlet" 1229054 1229072 1229604 1229609) (-722 "bookvol10.4.pamphlet" 1228646 1228659 1229044 1229049) (-721 "bookvol10.4.pamphlet" 1227931 1227941 1228636 1228641) (-720 "bookvol10.4.pamphlet" 1226781 1226791 1227921 1227926) (-719 "bookvol10.3.pamphlet" 1226559 1226569 1226771 1226776) (-718 "bookvol10.4.pamphlet" 1225998 1226016 1226549 1226554) (-717 "bookvol10.3.pamphlet" 1225437 1225445 1225900 1225993) (-716 "bookvol10.4.pamphlet" 1224076 1224086 1225427 1225432) (-715 "bookvol10.3.pamphlet" 1222524 1222532 1223966 1224071) (-714 "bookvol10.4.pamphlet" 1221924 1221946 1222514 1222519) (-713 "bookvol10.4.pamphlet" 1219836 1219844 1221914 1221919) (-712 "bookvol10.4.pamphlet" 1218089 1218099 1219826 1219831) (-711 "bookvol10.2.pamphlet" 1217370 1217380 1218057 1218084) (-710 "bookvol10.3.pamphlet" 1213343 1213351 1213957 1214158) (-709 "bookvol10.4.pamphlet" 1212545 1212557 1213333 1213338) (-708 "bookvol10.4.pamphlet" 1209805 1209831 1212535 1212540) (-707 "bookvol10.4.pamphlet" 1207085 1207095 1209795 1209800) (-706 "bookvol10.3.pamphlet" 1205978 1205988 1206460 1206487) (-705 "bookvol10.4.pamphlet" 1203386 1203410 1205862 1205867) (-704 "bookvol10.2.pamphlet" 1189514 1189536 1203342 1203381) (-703 NIL 1175490 1175514 1189320 1189325) (-702 "bookvol10.4.pamphlet" 1174772 1174820 1175480 1175485) (-701 "bookvol10.4.pamphlet" 1173566 1173578 1174762 1174767) (-700 "bookvol10.4.pamphlet" 1172441 1172455 1173556 1173561) (-699 "bookvol10.4.pamphlet" 1171747 1171759 1172431 1172436) (-698 "bookvol10.4.pamphlet" 1170569 1170579 1171737 1171742) (-697 "bookvol10.4.pamphlet" 1170381 1170395 1170559 1170564) (-696 "bookvol10.4.pamphlet" 1170150 1170162 1170371 1170376) (-695 "bookvol10.4.pamphlet" 1169786 1169796 1170140 1170145) (-694 "bookvol10.4.pamphlet" 1165458 1165482 1169776 1169781) (-693 "bookvol10.3.pamphlet" 1163742 1163759 1165448 1165453) (-692 "bookvol10.2.pamphlet" 1161598 1161613 1163732 1163737) (-691 "bookvol10.3.pamphlet" 1159583 1159593 1161199 1161204) (-690 "bookvol10.2.pamphlet" 1155331 1155341 1159563 1159578) (-689 NIL 1151087 1151099 1155321 1155326) (-688 "bookvol10.3.pamphlet" 1148325 1148342 1151077 1151082) (-687 "bookvol10.3.pamphlet" 1146623 1146637 1147005 1147056) (-686 "bookvol10.4.pamphlet" 1146166 1146183 1146613 1146618) (-685 "bookvol10.4.pamphlet" 1144968 1144996 1146156 1146161) (-684 "bookvol10.4.pamphlet" 1142730 1142744 1144958 1144963) (-683 "bookvol10.2.pamphlet" 1142387 1142397 1142686 1142725) (-682 NIL 1142076 1142088 1142377 1142382) (-681 "bookvol10.3.pamphlet" 1141224 1141243 1141932 1142001) (-680 "bookvol10.4.pamphlet" 1140485 1140495 1141214 1141219) (-679 "bookvol10.4.pamphlet" 1138961 1139010 1140475 1140480) (-678 "bookvol10.2.pamphlet" 1138450 1138458 1138905 1138956) (-677 "bookvol10.4.pamphlet" 1137123 1137133 1138440 1138445) (-676 "bookvol10.3.pamphlet" 1136520 1136534 1137057 1137084) (-675 "bookvol10.2.pamphlet" 1136152 1136160 1136510 1136515) (-674 NIL 1135782 1135792 1136142 1136147) (-673 "bookvol10.4.pamphlet" 1134712 1134724 1135772 1135777) (-672 "bookvol10.3.pamphlet" 1134083 1134099 1134392 1134431) (-671 "bookvol10.4.pamphlet" 1133131 1133148 1134040 1134045) (-670 "bookvol10.2.pamphlet" 1131780 1131790 1133087 1133126) (-669 NIL 1130427 1130439 1131736 1131741) (-668 "bookvol10.3.pamphlet" 1129687 1129699 1130107 1130146) (-667 "bookvol10.3.pamphlet" 1129074 1129084 1129367 1129406) (-666 "bookvol10.4.pamphlet" 1127800 1127818 1129064 1129069) (-665 "bookvol10.2.pamphlet" 1126223 1126233 1127702 1127795) (-664 "bookvol10.2.pamphlet" 1122699 1122709 1126203 1126218) (-663 NIL 1119149 1119161 1122655 1122660) (-662 "bookvol10.3.pamphlet" 1115761 1115778 1119139 1119144) (-661 "bookvol10.2.pamphlet" 1115276 1115286 1115751 1115756) (-660 "bookvol10.3.pamphlet" 1114398 1114408 1115050 1115077) (-659 "bookvol10.4.pamphlet" 1113849 1113863 1114388 1114393) (-658 "bookvol10.3.pamphlet" 1111812 1111822 1113219 1113246) (-657 "bookvol10.4.pamphlet" 1111127 1111141 1111802 1111807) (-656 "bookvol10.4.pamphlet" 1109807 1109819 1111117 1111122) (-655 "bookvol10.4.pamphlet" 1106670 1106682 1109797 1109802) (-654 "bookvol10.2.pamphlet" 1106048 1106058 1106650 1106665) (-653 "bookvol10.4.pamphlet" 1104921 1104933 1105960 1105965) (-652 "bookvol10.4.pamphlet" 1102879 1102889 1104911 1104916) (-651 "bookvol10.4.pamphlet" 1101754 1101767 1102869 1102874) (-650 "bookvol10.3.pamphlet" 1099784 1099796 1101044 1101189) (-649 "bookvol10.2.pamphlet" 1099369 1099379 1099710 1099779) (-648 NIL 1098982 1098994 1099325 1099330) (-647 "bookvol10.3.pamphlet" 1097517 1097525 1098223 1098238) (-646 "bookvol10.4.pamphlet" 1094895 1094914 1097507 1097512) (-645 "bookvol10.4.pamphlet" 1093674 1093690 1094885 1094890) (-644 "bookvol10.2.pamphlet" 1092527 1092535 1093664 1093669) (-643 "bookvol10.4.pamphlet" 1088359 1088374 1092517 1092522) (-642 "bookvol10.3.pamphlet" 1086594 1086621 1088339 1088354) (-641 "bookvol10.4.pamphlet" 1085024 1085041 1086584 1086589) (-640 "bookvol10.4.pamphlet" 1084134 1084156 1085014 1085019) (-639 "bookvol10.3.pamphlet" 1082910 1082923 1083727 1083796) (-638 "bookvol10.4.pamphlet" 1082455 1082471 1082900 1082905) (-637 "bookvol10.3.pamphlet" 1081865 1081879 1082377 1082416) (-636 "bookvol10.2.pamphlet" 1081641 1081651 1081845 1081860) (-635 NIL 1081425 1081437 1081631 1081636) (-634 "bookvol10.4.pamphlet" 1080106 1080123 1081415 1081420) (-633 "bookvol10.2.pamphlet" 1079830 1079840 1080096 1080101) (-632 "bookvol10.2.pamphlet" 1079567 1079577 1079820 1079825) (-631 "bookvol10.3.pamphlet" 1078128 1078138 1079351 1079356) (-630 "bookvol10.4.pamphlet" 1077831 1077843 1078118 1078123) (-629 "bookvol10.2.pamphlet" 1076970 1076992 1077799 1077826) (-628 NIL 1076129 1076153 1076960 1076965) (-627 "bookvol10.3.pamphlet" 1074767 1074783 1075476 1075503) (-626 "bookvol10.3.pamphlet" 1072776 1072788 1074057 1074202) (-625 "bookvol10.2.pamphlet" 1071020 1071044 1072756 1072771) (-624 NIL 1069129 1069155 1070867 1070872) (-623 "bookvol10.3.pamphlet" 1068137 1068152 1068277 1068304) (-622 "bookvol10.3.pamphlet" 1067257 1067267 1068127 1068132) (-621 "bookvol10.4.pamphlet" 1066020 1066039 1067247 1067252) (-620 "bookvol10.4.pamphlet" 1065526 1065540 1066010 1066015) (-619 "bookvol10.4.pamphlet" 1065270 1065282 1065516 1065521) (-618 "bookvol10.3.pamphlet" 1063078 1063093 1065106 1065231) (-617 "bookvol10.3.pamphlet" 1055466 1055481 1062052 1062149) (-616 "bookvol10.4.pamphlet" 1054933 1054949 1055456 1055461) (-615 "bookvol10.3.pamphlet" 1054163 1054176 1054329 1054356) (-614 "bookvol10.4.pamphlet" 1053158 1053177 1054153 1054158) (-613 "bookvol10.4.pamphlet" 1051226 1051234 1053148 1053153) (-612 "bookvol10.4.pamphlet" 1049773 1049783 1051182 1051187) (-611 "bookvol10.4.pamphlet" 1049374 1049385 1049763 1049768) (-610 "bookvol10.4.pamphlet" 1047690 1047700 1049364 1049369) (-609 "bookvol10.3.pamphlet" 1045413 1045427 1047545 1047572) (-608 "bookvol10.4.pamphlet" 1044557 1044573 1045403 1045408) (-607 "bookvol10.4.pamphlet" 1043734 1043750 1044547 1044552) (-606 "bookvol10.4.pamphlet" 1043510 1043518 1043724 1043729) (-605 "bookvol10.3.pamphlet" 1043211 1043223 1043315 1043408) (-604 "bookvol10.3.pamphlet" 1042982 1043008 1043137 1043206) (-603 "bookvol10.4.pamphlet" 1042579 1042595 1042972 1042977) (-602 "bookvol10.4.pamphlet" 1035601 1035618 1042569 1042574) (-601 "bookvol10.4.pamphlet" 1033466 1033482 1035175 1035180) (-600 "bookvol10.4.pamphlet" 1032786 1032794 1033456 1033461) (-599 "bookvol10.3.pamphlet" 1032562 1032572 1032700 1032781) (-598 "bookvol10.4.pamphlet" 1030926 1030940 1032552 1032557) (-597 "bookvol10.4.pamphlet" 1030419 1030429 1030916 1030921) (-596 "bookvol10.4.pamphlet" 1029088 1029105 1030409 1030414) (-595 "bookvol10.4.pamphlet" 1027401 1027417 1028731 1028736) (-594 "bookvol10.4.pamphlet" 1025058 1025076 1027333 1027338) (-593 "bookvol10.4.pamphlet" 1015583 1015591 1025048 1025053) (-592 "bookvol10.3.pamphlet" 1014944 1014952 1015437 1015578) (-591 "bookvol10.4.pamphlet" 1014210 1014227 1014934 1014939) (-590 "bookvol10.4.pamphlet" 1013855 1013879 1014200 1014205) (-589 "bookvol10.4.pamphlet" 1010234 1010242 1013845 1013850) (-588 "bookvol10.4.pamphlet" 1003392 1003410 1010166 1010171) (-587 "bookvol10.3.pamphlet" 997390 997398 1003382 1003387) (-586 "bookvol10.4.pamphlet" 996542 996599 997380 997385) (-585 "bookvol10.4.pamphlet" 995628 995638 996532 996537) (-584 "bookvol10.4.pamphlet" 995496 995520 995618 995623) (-583 "bookvol10.4.pamphlet" 993854 993870 995486 995491) (-582 "bookvol10.2.pamphlet" 992506 992514 993780 993849) (-581 NIL 991220 991230 992496 992501) (-580 "bookvol10.4.pamphlet" 990366 990453 991210 991215) (-579 "bookvol10.2.pamphlet" 988987 988997 990280 990361) (-578 "bookvol10.4.pamphlet" 988518 988526 988977 988982) (-577 "bookvol10.4.pamphlet" 987676 987703 988508 988513) (-576 "bookvol10.4.pamphlet" 987152 987168 987666 987671) (-575 "bookvol10.3.pamphlet" 986232 986263 986395 986422) (-574 "bookvol10.2.pamphlet" 983566 983574 986134 986227) (-573 NIL 980986 980996 983556 983561) (-572 "bookvol10.4.pamphlet" 980434 980447 980976 980981) (-571 "bookvol10.4.pamphlet" 979530 979549 980424 980429) (-570 "bookvol10.4.pamphlet" 978618 978642 979520 979525) (-569 "bookvol10.4.pamphlet" 977624 977641 978608 978613) (-568 "bookvol10.4.pamphlet" 976781 976811 977614 977619) (-567 "bookvol10.4.pamphlet" 975126 975148 976771 976776) (-566 "bookvol10.4.pamphlet" 974206 974225 975116 975121) (-565 "bookvol10.3.pamphlet" 971127 971135 974196 974201) (-564 "bookvol10.4.pamphlet" 970772 970782 971117 971122) (-563 "bookvol10.4.pamphlet" 970360 970368 970762 970767) (-562 "bookvol10.3.pamphlet" 969777 969840 970350 970355) (-561 "bookvol10.3.pamphlet" 969219 969242 969767 969772) (-560 "bookvol10.2.pamphlet" 967872 967935 969209 969214) (-559 "bookvol10.4.pamphlet" 966416 966438 967862 967867) (-558 "bookvol10.3.pamphlet" 966322 966339 966406 966411) (-557 "bookvol10.4.pamphlet" 965739 965749 966312 966317) (-556 "bookvol10.4.pamphlet" 961633 961644 965729 965734) (-555 "bookvol10.3.pamphlet" 960765 960791 961277 961304) (-554 "bookvol10.4.pamphlet" 959857 959901 960721 960726) (-553 "bookvol10.4.pamphlet" 958470 958494 959813 959818) (-552 "bookvol10.3.pamphlet" 957357 957372 957876 957903) (-551 "bookvol10.3.pamphlet" 957082 957120 957187 957214) (-550 "bookvol10.3.pamphlet" 956512 956528 956763 956856) (-549 "bookvol10.3.pamphlet" 953745 953760 955918 955945) (-548 "bookvol10.3.pamphlet" 953583 953600 953701 953706) (-547 "bookvol10.2.pamphlet" 952980 952992 953573 953578) (-546 NIL 952375 952389 952970 952975) (-545 "bookvol10.3.pamphlet" 952188 952200 952365 952370) (-544 "bookvol10.3.pamphlet" 951961 951973 952178 952183) (-543 "bookvol10.3.pamphlet" 951696 951708 951951 951956) (-542 "bookvol10.2.pamphlet" 950634 950646 951686 951691) (-541 "bookvol10.3.pamphlet" 950394 950406 950624 950629) (-540 "bookvol10.3.pamphlet" 950156 950168 950384 950389) (-539 "bookvol10.4.pamphlet" 947428 947446 950146 950151) (-538 "bookvol10.3.pamphlet" 942508 942547 947363 947368) (-537 "bookvol10.3.pamphlet" 941965 941988 942498 942503) (-536 "bookvol10.4.pamphlet" 941198 941214 941955 941960) (-535 "bookvol10.3.pamphlet" 940481 940489 941188 941193) (-534 "bookvol10.4.pamphlet" 939124 939141 940471 940476) (-533 "bookvol10.3.pamphlet" 938406 938419 938818 938845) (-532 "bookvol10.4.pamphlet" 935333 935352 938396 938401) (-531 "bookvol10.4.pamphlet" 934243 934258 935323 935328) (-530 "bookvol10.3.pamphlet" 933974 934000 934073 934100) (-529 "bookvol10.3.pamphlet" 933287 933302 933380 933407) (-528 "bookvol10.3.pamphlet" 931510 931518 933103 933196) (-527 "bookvol10.4.pamphlet" 931067 931100 931500 931505) (-526 "bookvol10.2.pamphlet" 930445 930453 931057 931062) (-525 NIL 929821 929831 930435 930440) (-524 "bookvol10.3.pamphlet" 928673 928681 929811 929816) (-523 "bookvol10.2.pamphlet" 926467 926477 928653 928668) (-522 NIL 924102 924114 926290 926295) (-521 "bookvol10.3.pamphlet" 921971 921979 922569 922662) (-520 "bookvol10.4.pamphlet" 920923 920934 921961 921966) (-519 "bookvol10.3.pamphlet" 920555 920579 920913 920918) (-518 "bookvol10.3.pamphlet" 916692 916702 920385 920412) (-517 "bookvol10.3.pamphlet" 908547 908563 908907 909038) (-516 "bookvol10.3.pamphlet" 905742 905757 906341 906468) (-515 "bookvol10.4.pamphlet" 904338 904346 905732 905737) (-514 "bookvol10.3.pamphlet" 903372 903403 903581 903608) (-513 "bookvol10.3.pamphlet" 902983 902991 903274 903367) (-512 "bookvol10.4.pamphlet" 889080 889092 902973 902978) (-511 "bookvol10.4.pamphlet" 888825 888833 888925 888930) (-510 "bookvol10.4.pamphlet" 873122 873158 888695 888700) (-509 "bookvol10.4.pamphlet" 872883 872891 872981 872986) (-508 "bookvol10.4.pamphlet" 872704 872718 872817 872822) (-507 "bookvol10.4.pamphlet" 872581 872595 872694 872699) (-506 "bookvol10.4.pamphlet" 872414 872422 872514 872519) (-505 "bookvol10.3.pamphlet" 871630 871646 872116 872143) (-504 "bookvol10.3.pamphlet" 870713 870748 870885 870900) (-503 "bookvol10.3.pamphlet" 867886 867913 868845 868994) (-502 "bookvol10.2.pamphlet" 866864 866872 867866 867881) (-501 NIL 865850 865860 866854 866859) (-500 "bookvol10.4.pamphlet" 864441 864462 865840 865845) (-499 "bookvol10.2.pamphlet" 863081 863093 864431 864436) (-498 NIL 861719 861733 863071 863076) (-497 "bookvol10.3.pamphlet" 854758 854766 861709 861714) (-496 "bookvol10.4.pamphlet" 853153 853161 854748 854753) (-495 "bookvol10.4.pamphlet" 851694 851702 853143 853148) (-494 "bookvol10.2.pamphlet" 850897 850909 851684 851689) (-493 NIL 850098 850112 850887 850892) (-492 "bookvol10.3.pamphlet" 849624 849647 849836 849863) (-491 "bookvol10.4.pamphlet" 844398 844485 849580 849585) (-490 "bookvol10.4.pamphlet" 843667 843685 844388 844393) (-489 "bookvol10.3.pamphlet" 837960 837968 843657 843662) (-488 "bookvol10.3.pamphlet" 834375 834383 837950 837955) (-487 "bookvol10.3.pamphlet" 833492 833519 834343 834370) (-486 "bookvol10.4.pamphlet" 832664 832678 833482 833487) (-485 "bookvol10.4.pamphlet" 828477 828490 832654 832659) (-484 "bookvol10.4.pamphlet" 828081 828091 828467 828472) (-483 "bookvol10.4.pamphlet" 827731 827748 828071 828076) (-482 "bookvol10.4.pamphlet" 827198 827217 827721 827726) (-481 "bookvol10.4.pamphlet" 825680 825693 827188 827193) (-480 "bookvol10.4.pamphlet" 824145 824153 825670 825675) (-479 "bookvol10.3.pamphlet" 821186 821203 821939 822066) (-478 "bookvol10.3.pamphlet" 815157 815184 820980 821047) (-477 "bookvol10.2.pamphlet" 814111 814119 815083 815152) (-476 NIL 813127 813137 814101 814106) (-475 "bookvol10.4.pamphlet" 808674 808712 813083 813088) (-474 "bookvol10.4.pamphlet" 804772 804810 808664 808669) (-473 "bookvol10.4.pamphlet" 800237 800275 804762 804767) (-472 "bookvol10.4.pamphlet" 796890 796928 800227 800232) (-471 "bookvol10.4.pamphlet" 796213 796221 796880 796885) (-470 "bookvol10.4.pamphlet" 794539 794549 796169 796174) (-469 "bookvol10.4.pamphlet" 793006 793019 794529 794534) (-468 "bookvol10.4.pamphlet" 791211 791230 792996 793001) (-467 "bookvol10.4.pamphlet" 781649 781660 791201 791206) (-466 "bookvol10.2.pamphlet" 778592 778600 781629 781644) (-465 "bookvol10.2.pamphlet" 777636 777644 778572 778587) (-464 "bookvol10.3.pamphlet" 777485 777497 777626 777631) (-463 "bookvol10.3.pamphlet" 775717 775725 777475 777480) (-462 "bookvol10.3.pamphlet" 774888 774896 775707 775712) (-461 "bookvol10.4.pamphlet" 773934 773953 774824 774829) (-460 "bookvol10.3.pamphlet" 772078 772086 773924 773929) (-459 "bookvol10.4.pamphlet" 771502 771518 772068 772073) (-458 "bookvol10.4.pamphlet" 770362 770378 771459 771464) (-457 "bookvol10.4.pamphlet" 767649 767665 770352 770357) (-456 "bookvol10.2.pamphlet" 761559 761569 767412 767644) (-455 NIL 755259 755271 761114 761119) (-454 "bookvol10.4.pamphlet" 754875 754891 755249 755254) (-453 "bookvol10.3.pamphlet" 754203 754215 754695 754794) (-452 "bookvol10.4.pamphlet" 753467 753483 754193 754198) (-451 "bookvol10.2.pamphlet" 752644 752654 753411 753462) (-450 NIL 751795 751807 752564 752569) (-449 "bookvol10.4.pamphlet" 750538 750554 751785 751790) (-448 "bookvol10.4.pamphlet" 745029 745063 750528 750533) (-447 "bookvol10.4.pamphlet" 744641 744657 745019 745024) (-446 "bookvol10.4.pamphlet" 743804 743827 744631 744636) (-445 "bookvol10.4.pamphlet" 742804 742814 743794 743799) (-444 "bookvol10.3.pamphlet" 734780 734790 741828 741897) (-443 "bookvol10.2.pamphlet" 729963 729973 734722 734775) (-442 NIL 725158 725170 729919 729924) (-441 "bookvol10.4.pamphlet" 724606 724624 725148 725153) (-440 "bookvol10.3.pamphlet" 724016 724046 724537 724542) (-439 "bookvol10.3.pamphlet" 723249 723270 723996 724011) (-438 "bookvol10.4.pamphlet" 722987 723019 723239 723244) (-437 "bookvol10.2.pamphlet" 722661 722671 722977 722982) (-436 NIL 722201 722213 722519 722524) (-435 "bookvol10.2.pamphlet" 720607 720620 722157 722196) (-434 NIL 719045 719060 720597 720602) (-433 "bookvol10.3.pamphlet" 716162 716172 716547 716720) (-432 "bookvol10.4.pamphlet" 715775 715787 716152 716157) (-431 "bookvol10.4.pamphlet" 715133 715145 715765 715770) (-430 "bookvol10.2.pamphlet" 712082 712090 715023 715128) (-429 NIL 709059 709069 712002 712007) (-428 "bookvol10.2.pamphlet" 708113 708121 708961 709054) (-427 NIL 707253 707263 708103 708108) (-426 "bookvol10.2.pamphlet" 707005 707015 707233 707248) (-425 "bookvol10.3.pamphlet" 705755 705772 706995 707000) (-424 "bookvol10.3.pamphlet" 704240 704289 705745 705750) (-423 "bookvol10.4.pamphlet" 703189 703197 704230 704235) (-422 "bookvol10.2.pamphlet" 700279 700287 703169 703184) (-421 "bookvol10.2.pamphlet" 699982 699990 700259 700274) (-420 "bookvol10.3.pamphlet" 697376 697384 699972 699977) (-419 "bookvol10.4.pamphlet" 696855 696865 697366 697371) (-418 "bookvol10.4.pamphlet" 696636 696660 696845 696850) (-417 "bookvol10.4.pamphlet" 695837 695845 696626 696631) (-416 "bookvol10.3.pamphlet" 695259 695281 695805 695832) (-415 "bookvol10.2.pamphlet" 693603 693611 695249 695254) (-414 "bookvol10.3.pamphlet" 693495 693503 693593 693598) (-413 "bookvol10.2.pamphlet" 693293 693301 693421 693490) (-412 "bookvol10.3.pamphlet" 690063 690073 693249 693254) (-411 "bookvol10.3.pamphlet" 689766 689778 689997 690024) (-410 "bookvol10.2.pamphlet" 686716 686724 689746 689761) (-409 "bookvol10.2.pamphlet" 685760 685768 686696 686711) (-408 "bookvol10.2.pamphlet" 683454 683472 685728 685755) (-407 "bookvol10.3.pamphlet" 682916 682928 683388 683415) (-406 "bookvol10.4.pamphlet" 680724 680738 682906 682911) (-405 "bookvol10.3.pamphlet" 677629 677637 680590 680719) (-404 "bookvol10.4.pamphlet" 675095 675109 677619 677624) (-403 "bookvol10.2.pamphlet" 674797 674807 675075 675090) (-402 NIL 674453 674465 674733 674738) (-401 "bookvol10.4.pamphlet" 673709 673721 674443 674448) (-400 "bookvol10.2.pamphlet" 671776 671795 673635 673704) (-399 "bookvol10.2.pamphlet" 668982 668992 671744 671771) (-398 NIL 666101 666113 668865 668870) (-397 "bookvol10.4.pamphlet" 664822 664838 666091 666096) (-396 "bookvol10.2.pamphlet" 662943 662956 664778 664817) (-395 NIL 660990 661005 662827 662832) (-394 "bookvol10.2.pamphlet" 659985 659993 660980 660985) (-393 NIL 658978 658988 659975 659980) (-392 "bookvol10.2.pamphlet" 648327 648337 658920 658973) (-391 NIL 637688 637700 648283 648288) (-390 "bookvol10.3.pamphlet" 637275 637285 637678 637683) (-389 "bookvol10.2.pamphlet" 635722 635739 637265 637270) (-388 "bookvol10.2.pamphlet" 635060 635068 635624 635717) (-387 NIL 634484 634494 635050 635055) (-386 "bookvol10.3.pamphlet" 633025 633035 634464 634479) (-385 "bookvol10.4.pamphlet" 631932 631947 633015 633020) (-384 "bookvol10.3.pamphlet" 631361 631376 631648 631741) (-383 "bookvol10.4.pamphlet" 631234 631251 631351 631356) (-382 "bookvol10.4.pamphlet" 630737 630758 631224 631229) (-381 "bookvol10.4.pamphlet" 622136 622147 630727 630732) (-380 "bookvol10.4.pamphlet" 621218 621235 622126 622131) (-379 "bookvol10.3.pamphlet" 620714 620734 620934 621027) (-378 "bookvol10.3.pamphlet" 620182 620198 620395 620488) (-377 "bookvol10.3.pamphlet" 618732 618752 619898 619991) (-376 "bookvol10.3.pamphlet" 617268 617285 618448 618541) (-375 "bookvol10.3.pamphlet" 615809 615830 616949 617042) (-374 "bookvol10.4.pamphlet" 613179 613198 615799 615804) (-373 "bookvol10.2.pamphlet" 610777 610785 613081 613174) (-372 NIL 608461 608471 610767 610772) (-371 "bookvol10.4.pamphlet" 607254 607271 608451 608456) (-370 "bookvol10.4.pamphlet" 604729 604740 607244 607249) (-369 "bookvol10.4.pamphlet" 598851 598867 604719 604724) (-368 "bookvol10.4.pamphlet" 597526 597545 598841 598846) (-367 "bookvol10.4.pamphlet" 596945 596962 597516 597521) (-366 "bookvol10.4.pamphlet" 596866 596883 596935 596940) (-365 "bookvol10.3.pamphlet" 595747 595767 596582 596675) (-364 "bookvol10.3.pamphlet" 594662 594682 595463 595556) (-363 "bookvol10.3.pamphlet" 593489 593510 594343 594436) (-362 "bookvol10.2.pamphlet" 582294 582316 593328 593484) (-361 NIL 571178 571202 582214 582219) (-360 "bookvol10.4.pamphlet" 570917 570957 571168 571173) (-359 "bookvol10.3.pamphlet" 563593 563639 570673 570712) (-358 "bookvol10.2.pamphlet" 563303 563313 563583 563588) (-357 NIL 562798 562810 563080 563085) (-356 "bookvol10.3.pamphlet" 562249 562273 562788 562793) (-355 "bookvol10.2.pamphlet" 560261 560285 562239 562244) (-354 NIL 558271 558297 560251 560256) (-353 "bookvol10.4.pamphlet" 558017 558057 558261 558266) (-352 "bookvol10.4.pamphlet" 556578 556586 558007 558012) (-351 "bookvol10.3.pamphlet" 556109 556119 556568 556573) (-350 "bookvol10.3.pamphlet" 546074 546082 556099 556104) (-349 "bookvol10.2.pamphlet" 539351 539365 545976 546069) (-348 NIL 532680 532696 539307 539312) (-347 "bookvol10.3.pamphlet" 531108 531118 532086 532113) (-346 "bookvol10.2.pamphlet" 529250 529262 531006 531103) (-345 NIL 527376 527390 529134 529139) (-344 "bookvol10.4.pamphlet" 526950 526972 527366 527371) (-343 "bookvol10.3.pamphlet" 526607 526617 526904 526909) (-342 "bookvol10.2.pamphlet" 524790 524802 526597 526602) (-341 "bookvol10.3.pamphlet" 524404 524414 524686 524713) (-340 "bookvol10.4.pamphlet" 522616 522633 524394 524399) (-339 "bookvol10.4.pamphlet" 522498 522508 522606 522611) (-338 "bookvol10.4.pamphlet" 521692 521702 522488 522493) (-337 "bookvol10.4.pamphlet" 521574 521584 521682 521687) (-336 "bookvol10.3.pamphlet" 518411 518434 519706 519855) (-335 "bookvol10.4.pamphlet" 515879 515887 518401 518406) (-334 "bookvol10.4.pamphlet" 515781 515810 515869 515874) (-333 "bookvol10.4.pamphlet" 512525 512541 515771 515776) (-332 "bookvol10.3.pamphlet" 507792 507802 508514 508921) (-331 "bookvol10.4.pamphlet" 503882 503895 507782 507787) (-330 "bookvol10.4.pamphlet" 503652 503664 503872 503877) (-329 "bookvol10.3.pamphlet" 500586 500611 501224 501317) (-328 "bookvol10.4.pamphlet" 500439 500447 500576 500581) (-327 "bookvol10.3.pamphlet" 500110 500118 500429 500434) (-326 "bookvol10.4.pamphlet" 499604 499618 500100 500105) (-325 "bookvol10.2.pamphlet" 499168 499178 499594 499599) (-324 NIL 498730 498742 499158 499163) (-323 "bookvol10.2.pamphlet" 496302 496310 498656 498725) (-322 NIL 493936 493946 496292 496297) (-321 "bookvol10.4.pamphlet" 485794 485802 493926 493931) (-320 "bookvol10.4.pamphlet" 485389 485403 485784 485789) (-319 "bookvol10.4.pamphlet" 485074 485085 485379 485384) (-318 "bookvol10.2.pamphlet" 478021 478029 485064 485069) (-317 NIL 470874 470884 477919 477924) (-316 "bookvol10.4.pamphlet" 467683 467691 470864 470869) (-315 "bookvol10.4.pamphlet" 467424 467436 467673 467678) (-314 "bookvol10.4.pamphlet" 466931 466947 467414 467419) (-313 "bookvol10.4.pamphlet" 466489 466505 466921 466926) (-312 "bookvol10.4.pamphlet" 463965 463973 466479 466484) (-311 "bookvol10.3.pamphlet" 462999 463021 463208 463235) (-310 "bookvol10.3.pamphlet" 457925 457935 460672 460784) (-309 "bookvol10.4.pamphlet" 457643 457655 457915 457920) (-308 "bookvol10.4.pamphlet" 453997 454007 457633 457638) (-307 "bookvol10.2.pamphlet" 453541 453549 453941 453992) (-306 "bookvol10.3.pamphlet" 452737 452778 453467 453536) (-305 "bookvol10.2.pamphlet" 451193 451212 452727 452732) (-304 NIL 449613 449634 451149 451154) (-303 "bookvol10.2.pamphlet" 449145 449163 449603 449608) (-302 "bookvol10.4.pamphlet" 448534 448553 449135 449140) (-301 "bookvol10.2.pamphlet" 448231 448239 448524 448529) (-300 NIL 447926 447936 448221 448226) (-299 "bookvol10.2.pamphlet" 445842 445852 447894 447921) (-298 NIL 443707 443719 445761 445766) (-297 "bookvol10.3.pamphlet" 440482 440512 443663 443668) (-296 "bookvol10.3.pamphlet" 437318 437341 440438 440443) (-295 "bookvol10.4.pamphlet" 435315 435331 437308 437313) (-294 "bookvol10.4.pamphlet" 430091 430107 435305 435310) (-293 "bookvol10.3.pamphlet" 428405 428413 430081 430086) (-292 "bookvol10.3.pamphlet" 427943 427951 428395 428400) (-291 "bookvol10.3.pamphlet" 427522 427530 427933 427938) (-290 "bookvol10.3.pamphlet" 427104 427112 427512 427517) (-289 "bookvol10.3.pamphlet" 426642 426650 427094 427099) (-288 "bookvol10.3.pamphlet" 426180 426188 426632 426637) (-287 "bookvol10.3.pamphlet" 425718 425726 426170 426175) (-286 "bookvol10.3.pamphlet" 425256 425264 425708 425713) (-285 "bookvol10.4.pamphlet" 420998 421006 425246 425251) (-284 "bookvol10.2.pamphlet" 417747 417757 420988 420993) (-283 NIL 414494 414506 417737 417742) (-282 "bookvol10.4.pamphlet" 411579 411666 414484 414489) (-281 "bookvol10.3.pamphlet" 410785 410795 411409 411436) (-280 "bookvol10.2.pamphlet" 410379 410389 410741 410780) (-279 "bookvol10.3.pamphlet" 407822 407836 408115 408242) (-278 "bookvol10.3.pamphlet" 401585 401593 407812 407817) (-277 "bookvol10.4.pamphlet" 401256 401266 401575 401580) (-276 "bookvol10.4.pamphlet" 396215 396223 401246 401251) (-275 "bookvol10.4.pamphlet" 394456 394464 396205 396210) (-274 "bookvol10.4.pamphlet" 387364 387377 394446 394451) (-273 "bookvol10.4.pamphlet" 386627 386637 387354 387359) (-272 "bookvol10.4.pamphlet" 384052 384060 386617 386622) (-271 "bookvol10.4.pamphlet" 383599 383614 384042 384047) (-270 "bookvol10.4.pamphlet" 373039 373047 383589 383594) (-269 "bookvol10.2.pamphlet" 371249 371259 372995 373034) (-268 "bookvol10.2.pamphlet" 366646 366662 371117 371244) (-267 NIL 362129 362147 366602 366607) (-266 "bookvol10.3.pamphlet" 355504 355520 355626 355927) (-265 "bookvol10.3.pamphlet" 348876 348894 349001 349302) (-264 "bookvol10.3.pamphlet" 346117 346132 346670 346797) (-263 "bookvol10.4.pamphlet" 345457 345467 346107 346112) (-262 "bookvol10.3.pamphlet" 344172 344182 344863 344890) (-261 "bookvol10.2.pamphlet" 342619 342629 344152 344167) (-260 "bookvol10.2.pamphlet" 342060 342068 342563 342614) (-259 NIL 341545 341555 342050 342055) (-258 "bookvol10.3.pamphlet" 341398 341408 341477 341504) (-257 "bookvol10.2.pamphlet" 340163 340173 341366 341393) (-256 "bookvol10.4.pamphlet" 338377 338385 340153 340158) (-255 "bookvol10.3.pamphlet" 337657 337672 338213 338338) (-254 "bookvol10.3.pamphlet" 329247 329263 329872 330003) (-253 "bookvol10.4.pamphlet" 328108 328126 329237 329242) (-252 "bookvol10.2.pamphlet" 327039 327055 327960 328103) (-251 NIL 325711 325729 326634 326639) (-250 "bookvol10.4.pamphlet" 324556 324564 325701 325706) (-249 "bookvol10.2.pamphlet" 323636 323646 324524 324551) (-248 NIL 322702 322714 323592 323597) (-247 "bookvol10.2.pamphlet" 321823 321831 322682 322697) (-246 NIL 320952 320962 321813 321818) (-245 "bookvol10.2.pamphlet" 320103 320113 320932 320947) (-244 NIL 319171 319183 320002 320007) (-243 "bookvol10.2.pamphlet" 318791 318801 319139 319166) (-242 NIL 318431 318443 318781 318786) (-241 "bookvol10.3.pamphlet" 316713 316723 318075 318102) (-240 "bookvol10.3.pamphlet" 315451 315459 315837 315864) (-239 "bookvol10.4.pamphlet" 306645 306653 315441 315446) (-238 "bookvol10.3.pamphlet" 305862 305870 306277 306304) (-237 "bookvol10.3.pamphlet" 302247 302255 305752 305857) (-236 "bookvol10.4.pamphlet" 300482 300498 302237 302242) (-235 "bookvol10.3.pamphlet" 298440 298472 300462 300477) (-234 "bookvol10.3.pamphlet" 292630 292640 298270 298297) (-233 "bookvol10.4.pamphlet" 292245 292259 292620 292625) (-232 "bookvol10.4.pamphlet" 289710 289720 292235 292240) (-231 "bookvol10.4.pamphlet" 288190 288206 289700 289705) (-230 "bookvol10.3.pamphlet" 286071 286079 286657 286750) (-229 "bookvol10.4.pamphlet" 283948 283965 286061 286066) (-228 "bookvol10.4.pamphlet" 283556 283580 283938 283943) (-227 "bookvol10.3.pamphlet" 282209 282219 283546 283551) (-226 "bookvol10.3.pamphlet" 282037 282045 282199 282204) (-225 "bookvol10.3.pamphlet" 281857 281865 282027 282032) (-224 "bookvol10.4.pamphlet" 280802 280810 281847 281852) (-223 "bookvol10.3.pamphlet" 280266 280274 280792 280797) (-222 "bookvol10.3.pamphlet" 279746 279754 280256 280261) (-221 "bookvol10.3.pamphlet" 279238 279246 279736 279741) (-220 "bookvol10.3.pamphlet" 278730 278738 279228 279233) (-219 "bookvol10.4.pamphlet" 273675 273683 278720 278725) (-218 "bookvol10.4.pamphlet" 271998 272006 273665 273670) (-217 "bookvol10.3.pamphlet" 271975 271983 271988 271993) (-216 "bookvol10.3.pamphlet" 271499 271507 271965 271970) (-215 "bookvol10.3.pamphlet" 271023 271031 271489 271494) (-214 "bookvol10.3.pamphlet" 270493 270501 271013 271018) (-213 "bookvol10.3.pamphlet" 269988 269996 270483 270488) (-212 "bookvol10.3.pamphlet" 269470 269478 269978 269983) (-211 "bookvol10.3.pamphlet" 268966 268974 269460 269465) (-210 "bookvol10.3.pamphlet" 268478 268486 268956 268961) (-209 "bookvol10.3.pamphlet" 268020 268028 268468 268473) (-208 "bookvol10.3.pamphlet" 267550 267558 268010 268015) (-207 "bookvol10.3.pamphlet" 267075 267083 267540 267545) (-206 "bookvol10.4.pamphlet" 263182 263190 267065 267070) (-205 "bookvol10.4.pamphlet" 262686 262694 263172 263177) (-204 "bookvol10.4.pamphlet" 259497 259505 262676 262681) (-203 "bookvol10.4.pamphlet" 258882 258892 259487 259492) (-202 "bookvol10.4.pamphlet" 257350 257366 258872 258877) (-201 "bookvol10.4.pamphlet" 256139 256152 257340 257345) (-200 "bookvol10.4.pamphlet" 250154 250167 256129 256134) (-199 "bookvol10.4.pamphlet" 249311 249321 250144 250149) (-198 "bookvol10.4.pamphlet" 248823 248838 249236 249241) (-197 "bookvol10.4.pamphlet" 248528 248547 248813 248818) (-196 "bookvol10.4.pamphlet" 243543 243553 248518 248523) (-195 "bookvol10.3.pamphlet" 239544 239554 243445 243538) (-194 "bookvol10.2.pamphlet" 239223 239231 239482 239539) (-193 "bookvol10.3.pamphlet" 238723 238731 239213 239218) (-192 "bookvol10.4.pamphlet" 238490 238505 238713 238718) (-191 "bookvol10.3.pamphlet" 232508 232518 232757 233018) (-190 "bookvol10.4.pamphlet" 232231 232243 232498 232503) (-189 "bookvol10.4.pamphlet" 232027 232041 232221 232226) (-188 "bookvol10.2.pamphlet" 230133 230143 231749 232022) (-187 NIL 227943 227955 229561 229566) (-186 "bookvol10.2.pamphlet" 227682 227690 227933 227938) (-185 "bookvol10.4.pamphlet" 227456 227474 227672 227677) (-184 "bookvol10.4.pamphlet" 226995 227003 227446 227451) (-183 "bookvol10.3.pamphlet" 226804 226812 226985 226990) (-182 "bookvol10.2.pamphlet" 225839 225847 226794 226799) (-181 "bookvol10.4.pamphlet" 224331 224341 225829 225834) (-180 "bookvol10.4.pamphlet" 221781 221797 224321 224326) (-179 "bookvol10.3.pamphlet" 220619 220627 221771 221776) (-178 "bookvol10.4.pamphlet" 219953 219970 220609 220614) (-177 "bookvol10.4.pamphlet" 216073 216081 219943 219948) (-176 "bookvol10.3.pamphlet" 214788 214804 216029 216068) (-175 "bookvol10.2.pamphlet" 211808 211818 214768 214783) (-174 NIL 208709 208721 211671 211676) (-173 "bookvol10.4.pamphlet" 208048 208061 208699 208704) (-172 "bookvol10.4.pamphlet" 206018 206040 208038 208043) (-171 "bookvol10.2.pamphlet" 205933 205941 205998 206013) (-170 "bookvol10.4.pamphlet" 205447 205457 205923 205928) (-169 "bookvol10.2.pamphlet" 205200 205208 205427 205442) (-168 "bookvol10.3.pamphlet" 201561 201569 205190 205195) (-167 "bookvol10.2.pamphlet" 200734 200742 201551 201556) (-166 "bookvol10.3.pamphlet" 199041 199049 199672 199699) (-165 "bookvol10.3.pamphlet" 198173 198181 198597 198624) (-164 "bookvol10.4.pamphlet" 197413 197427 198163 198168) (-163 "bookvol10.3.pamphlet" 195824 195832 196882 196921) (-162 "bookvol10.3.pamphlet" 187003 187027 195814 195819) (-161 "bookvol10.4.pamphlet" 186393 186420 186993 186998) (-160 "bookvol10.3.pamphlet" 182731 182739 186367 186388) (-159 "bookvol10.2.pamphlet" 182347 182355 182721 182726) (-158 "bookvol10.2.pamphlet" 181840 181848 182337 182342) (-157 "bookvol10.3.pamphlet" 180932 180942 181670 181697) (-156 "bookvol10.3.pamphlet" 180174 180184 180762 180789) (-155 "bookvol10.2.pamphlet" 179548 179558 180130 180169) (-154 NIL 178954 178966 179538 179543) (-153 "bookvol10.2.pamphlet" 178057 178065 178910 178949) (-152 NIL 177192 177202 178047 178052) (-151 "bookvol10.3.pamphlet" 175850 175860 177022 177049) (-150 "Makefile.pamphlet" 173740 173748 175840 175845) (-149 "bookvol10.4.pamphlet" 172513 172524 173730 173735) (-148 "bookvol10.2.pamphlet" 171473 171483 172493 172508) (-147 NIL 170407 170419 171429 171434) (-146 "bookvol10.3.pamphlet" 168452 168464 168643 168736) (-145 "bookvol10.3.pamphlet" 168180 168192 168378 168447) (-144 "bookvol10.4.pamphlet" 167838 167855 168170 168175) (-143 "bookvol10.3.pamphlet" 163370 163378 167828 167833) (-142 "bookvol10.4.pamphlet" 160856 160866 163326 163331) (-141 "bookvol10.3.pamphlet" 159726 159734 160846 160851) (-140 "bookvol10.2.pamphlet" 159370 159382 159694 159721) (-139 "bookvol10.4.pamphlet" 157648 157684 159360 159365) (-138 "bookvol10.3.pamphlet" 157538 157546 157613 157643) (-137 "bookvol10.2.pamphlet" 157515 157523 157528 157533) (-136 "bookvol10.3.pamphlet" 157407 157415 157482 157510) (-135 "bookvol10.5.pamphlet" 145679 145687 157397 157402) (-134 "bookvol10.3.pamphlet" 145158 145166 145373 145400) (-133 "bookvol10.3.pamphlet" 144515 144523 145148 145153) (-132 "bookvol10.3.pamphlet" 142363 142371 142982 143075) (-131 "bookvol10.2.pamphlet" 141608 141618 142331 142358) (-130 NIL 140873 140885 141598 141603) (-129 "bookvol10.3.pamphlet" 140294 140302 140853 140868) (-128 "bookvol10.4.pamphlet" 139434 139461 140244 140249) (-127 "bookvol10.4.pamphlet" 137297 137307 139424 139429) (-126 "bookvol10.3.pamphlet" 132929 132939 137127 137154) (-125 "bookvol10.2.pamphlet" 132623 132631 132919 132924) (-124 NIL 132315 132325 132613 132618) (-123 "bookvol10.4.pamphlet" 131734 131747 132305 132310) (-122 "bookvol10.4.pamphlet" 131594 131602 131724 131729) (-121 "bookvol10.3.pamphlet" 131038 131048 131574 131589) (-120 "bookvol10.2.pamphlet" 130833 130841 131018 131033) (-119 "bookvol10.2.pamphlet" 127388 127396 130573 130828) (-118 "bookvol10.3.pamphlet" 123512 123520 127368 127383) (-117 "bookvol10.2.pamphlet" 123272 123280 123492 123507) (-116 "bookvol10.2.pamphlet" 122741 122749 123262 123267) (-115 NIL 122208 122218 122731 122736) (-114 "bookvol10.2.pamphlet" 122006 122014 122188 122203) (-113 "bookvol10.2.pamphlet" 121828 121836 121986 122001) (-112 "bookvol10.2.pamphlet" 121710 121718 121808 121823) (-111 "bookvol10.2.pamphlet" 121584 121592 121690 121705) (-110 "bookvol10.2.pamphlet" 121423 121431 121564 121579) (-109 "bookvol10.2.pamphlet" 121284 121292 121403 121418) (-108 "bookvol10.2.pamphlet" 121171 121179 121264 121279) (-107 "bookvol10.2.pamphlet" 121025 121033 121151 121166) (-106 "bookvol10.2.pamphlet" 120908 120916 121005 121020) (-105 "bookvol10.2.pamphlet" 120608 120616 120888 120903) (-104 "bookvol10.2.pamphlet" 120357 120365 120588 120603) (-103 "bookvol10.2.pamphlet" 120052 120060 120337 120352) (-102 "bookvol10.2.pamphlet" 119865 119873 120032 120047) (-101 "bookvol10.2.pamphlet" 119703 119711 119845 119860) (-100 "bookvol10.2.pamphlet" 119558 119566 119683 119698) (-99 "bookvol10.2.pamphlet" 119451 119458 119538 119553) (-98 "bookvol10.2.pamphlet" 119359 119366 119431 119446) (-97 "bookvol10.2.pamphlet" 119197 119204 119339 119354) (-96 "bookvol10.3.pamphlet" 114901 114910 119027 119054) (-95 "bookvol10.4.pamphlet" 113691 113702 114857 114862) (-94 "bookvol10.3.pamphlet" 112848 112861 113681 113686) (-93 "bookvol10.3.pamphlet" 111791 111804 112838 112843) (-92 "bookvol10.3.pamphlet" 111123 111136 111781 111786) (-91 "bookvol10.3.pamphlet" 110321 110334 111113 111118) (-90 "bookvol10.3.pamphlet" 109800 109813 110311 110316) (-89 "bookvol10.3.pamphlet" 109173 109186 109790 109795) (-88 "bookvol10.3.pamphlet" 108200 108213 109163 109168) (-87 "bookvol10.3.pamphlet" 107463 107476 108190 108195) (-86 "bookvol10.3.pamphlet" 106143 106156 107453 107458) (-85 "bookvol10.3.pamphlet" 104580 104593 106133 106138) (-84 "bookvol10.3.pamphlet" 102236 102249 104570 104575) (-83 "bookvol10.3.pamphlet" 101525 101538 102226 102231) (-82 "bookvol10.3.pamphlet" 100514 100527 101515 101520) (-81 "bookvol10.3.pamphlet" 98790 98829 100504 100509) (-80 "bookvol10.3.pamphlet" 97292 97331 98780 98785) (-79 "bookvol10.3.pamphlet" 96277 96290 97282 97287) (-78 "bookvol10.3.pamphlet" 95528 95541 96267 96272) (-77 "bookvol10.3.pamphlet" 95114 95127 95518 95523) (-76 "bookvol10.3.pamphlet" 94228 94241 95104 95109) (-75 "bookvol10.3.pamphlet" 92960 92973 94218 94223) (-74 "bookvol10.3.pamphlet" 92444 92457 92950 92955) (-73 "bookvol10.3.pamphlet" 82875 82888 92434 92439) (-72 "bookvol10.3.pamphlet" 81731 81744 82865 82870) (-71 "bookvol10.3.pamphlet" 80814 80827 81721 81726) (-70 "bookvol10.3.pamphlet" 79987 80000 80804 80809) (-69 "bookvol10.3.pamphlet" 79367 79380 79977 79982) (-68 "bookvol10.3.pamphlet" 73446 73459 79357 79362) (-67 "bookvol10.3.pamphlet" 72864 72877 73436 73441) (-66 "bookvol10.3.pamphlet" 72145 72158 72854 72859) (-65 "bookvol10.3.pamphlet" 71751 71760 71975 72002) (-64 "bookvol10.3.pamphlet" 70667 70676 71157 71184) (-63 "bookvol10.4.pamphlet" 68704 68715 70657 70662) (-62 "bookvol10.2.pamphlet" 61980 62001 68660 68699) (-61 NIL 55288 55311 61970 61975) (-60 "bookvol10.4.pamphlet" 54604 54626 55278 55283) (-59 "bookvol10.4.pamphlet" 54207 54220 54594 54599) (-58 "bookvol10.4.pamphlet" 53144 53151 54197 54202) (-57 "bookvol10.3.pamphlet" 51492 51499 53134 53139) (-56 "bookvol10.4.pamphlet" 50569 50578 51482 51487) (-55 "bookvol10.3.pamphlet" 49026 49042 50549 50564) (-54 "bookvol10.3.pamphlet" 48939 48946 49016 49021) (-53 "bookvol10.3.pamphlet" 47250 47257 48755 48848) (-52 "bookvol10.2.pamphlet" 45461 45472 47148 47245) (-51 NIL 43509 43522 45198 45203) (-50 "bookvol10.3.pamphlet" 41555 41576 41903 41930) (-49 "bookvol10.3.pamphlet" 40662 40688 41427 41480) (-48 "bookvol10.4.pamphlet" 36627 36638 40618 40623) (-47 "bookvol10.4.pamphlet" 35836 35850 36617 36622) (-46 "bookvol10.4.pamphlet" 33310 33325 35633 35638) (-45 "bookvol10.3.pamphlet" 31642 31669 31842 31998) (-44 "bookvol10.4.pamphlet" 30767 30777 31632 31637) (-43 "bookvol10.2.pamphlet" 30267 30276 30723 30762) (-42 NIL 29799 29810 30257 30262) (-41 "bookvol10.2.pamphlet" 29301 29322 29755 29794) (-40 "bookvol10.2.pamphlet" 28682 28689 29291 29296) (-39 "bookvol10.2.pamphlet" 27059 27066 28662 28677) (-38 NIL 25410 25419 27015 27020) (-37 "bookvol10.2.pamphlet" 23298 23307 25400 25405) (-36 "bookvol10.4.pamphlet" 21697 21712 23233 23238) (-35 "bookvol10.3.pamphlet" 21540 21555 21687 21692) (-34 "bookvol10.3.pamphlet" 21389 21398 21530 21535) (-33 "bookvol10.3.pamphlet" 21238 21247 21379 21384) (-32 "bookvol10.4.pamphlet" 21121 21159 21228 21233) (-31 "bookvol10.4.pamphlet" 20704 20742 21111 21116) (-30 "bookvol10.3.pamphlet" 18992 18999 20694 20699) (-29 "bookvol10.2.pamphlet" 16871 16880 18882 18987) (-28 NIL 14848 14859 16861 16866) (-27 "bookvol10.2.pamphlet" 10002 10009 14750 14843) (-26 NIL 5242 5251 9992 9997) (-25 "bookvol10.2.pamphlet" 4600 4607 5232 5237) (-24 NIL 3956 3965 4590 4595) (-23 "bookvol10.2.pamphlet" 3325 3332 3946 3951) (-22 NIL 2692 2701 3315 3320) (-21 "bookvol10.2.pamphlet" 2198 2205 2682 2687) (-20 NIL 1702 1711 2188 2193) (-19 "bookvol10.2.pamphlet" 850 859 1658 1697) (-18 NIL 30 41 840 845)) 
\ No newline at end of file
diff --git a/src/share/algebra/category.daase b/src/share/algebra/category.daase
index 3635c0a..b29c2df 100644
--- a/src/share/algebra/category.daase
+++ b/src/share/algebra/category.daase
@@ -1,3535 +1,3566 @@
 
-(156960 . 3575754979)        
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
+(158286 . 3613822961)        
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
 (((|#2| |#2|) . T)) 
-((((-572)) . T)) 
-((($ $) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) ((|#2| |#2|) . T) (((-413 (-572)) (-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
+((((-592)) . T)) 
+((($ $) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) ((|#2| |#2|) . T) (((-433 (-592)) (-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
 ((($) . T)) 
 (((|#1|) . T)) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
 (((|#2|) . T)) 
-((($) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) ((|#2|) . T) (((-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
-(|has| |#1| (-910)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-572) (-171 (-217))) . T)) 
-((((-572) (-217)) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
+((($) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) ((|#2|) . T) (((-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
+(|has| |#1| (-931)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-592) (-191 (-237))) . T)) 
+((((-592) (-237)) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
 ((($) . T)) 
 ((($) . T)) 
 ((($) . T)) 
 (((|#2| |#2|) . T)) 
-((((-148)) . T)) 
-((((-545)) . T) (((-1152)) . T) (((-217)) . T) (((-385)) . T) (((-893 (-385))) . T)) 
-(((|#1|) . T)) 
-((((-217)) . T) (((-856)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-846))) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1| |#1|) . T)) 
-(-1841 (|has| |#1| (-821)) (|has| |#1| (-848))) 
-((((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(|has| |#1| (-846)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+((((-168)) . T)) 
+((((-565)) . T) (((-1173)) . T) (((-237)) . T) (((-405)) . T) (((-914 (-405))) . T)) 
+(((|#1|) . T)) 
+((((-237)) . T) (((-877)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-867))) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1| |#1|) . T)) 
+(-3836 (|has| |#1| (-842)) (|has| |#1| (-869))) 
+((((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(|has| |#1| (-867)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 (((|#1| |#2| |#3|) . T)) 
 (((|#4|) . T)) 
-((($) . T) (((-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1|) . T)) 
-(((|#1| (-769) (-1082)) . T)) 
-((((-856)) . T)) 
-((((-856)) |has| |#1| (-1098))) 
+((($) . T) (((-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1|) . T)) 
+(((|#1| (-790) (-1103)) . T)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+((((-877)) . T)) 
+((((-877)) |has| |#1| (-1119))) 
 (((|#1|) . T) ((|#2|) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(((|#2| (-497 (-4032 |#1|) (-769))) . T)) 
-(((|#1| (-538 (-1170))) . T)) 
-((((-870 |#1|) (-870 |#1|)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(|has| |#1| (-1190)) 
-(|has| |#4| (-374)) 
-(|has| |#3| (-374)) 
-(((|#1|) . T)) 
-((((-870 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(((|#2| (-517 (-1699 |#1|) (-790))) . T)) 
+(((|#1| (-558 (-1191))) . T)) 
+((((-891 |#1|) (-891 |#1|)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(|has| |#1| (-1211)) 
+(|has| |#4| (-394)) 
+(|has| |#3| (-394)) 
+(((|#1|) . T)) 
+((((-891 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
 (((|#1| |#2|) . T)) 
 ((($) . T)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-562)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-((($) . T)) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((($) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T)) 
-((((-171 (-217)) (-146) (-146)) . T)) 
-((((-217) (-220) (-220)) . T)) 
-((($) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-171 (-217))) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-217)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) |has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-305 (-2 (|:| |k| (-572)) (|:| |c| |#1|))))) 
-(((|#1|) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-582)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+((($) . T)) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((($) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T)) 
+((((-191 (-237)) (-166) (-166)) . T)) 
+((((-237) (-240) (-240)) . T)) 
+((($) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-191 (-237))) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-237)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) |has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-325 (-2 (|:| |k| (-592)) (|:| |c| |#1|))))) 
+(((|#1|) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) (($) . T)) 
-(((|#1|) . T)) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (((-1250 |#1| |#2| |#3|)) |has| |#1| (-368)) (($) . T) ((|#1|) . T)) 
-(((|#1|) . T) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) . T)) 
-((((-413 (-572)) (-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2| |#2|) . T) (($ $) -1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) (($) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) |has| |#2| (-174)) (($) -1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910)))) 
+((((-877)) . T)) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) (($) . T)) 
+(((|#1|) . T)) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (((-1271 |#1| |#2| |#3|)) |has| |#1| (-388)) (($) . T) ((|#1|) . T)) 
+(((|#1|) . T) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) . T)) 
+((((-433 (-592)) (-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2| |#2|) . T) (($ $) -3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) (($) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) |has| |#2| (-194)) (($) -3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931)))) 
 ((($ $) . T)) 
 (((|#2|) . T)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) . T) (($) -1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910)))) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) . T) (($) -3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931)))) 
 ((($) . T)) 
-(|has| |#1| (-374)) 
+(|has| |#1| (-394)) 
 (((|#1|) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054))) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054))) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075))) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075))) 
 (((|#1| |#1|) . T)) 
-(|has| |#1| (-562)) 
-(((|#2| |#2|) -12 (|has| |#1| (-368)) (|has| |#2| (-305 |#2|))) (((-1170) |#2|) -12 (|has| |#1| (-368)) (|has| |#2| (-527 (-1170) |#2|)))) 
-((((-413 |#2|)) . T) (((-413 (-572))) . T) (($) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-846))) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(|has| |#1| (-1098)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(|has| |#1| (-1098)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(|has| |#1| (-846)) 
-((($) . T) (((-413 (-572))) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(-1841 (|has| |#4| (-794)) (|has| |#4| (-846))) 
-(-1841 (|has| |#4| (-794)) (|has| |#4| (-846))) 
-(-1841 (|has| |#3| (-794)) (|has| |#3| (-846))) 
-(-1841 (|has| |#3| (-794)) (|has| |#3| (-846))) 
+(|has| |#1| (-582)) 
+(((|#2| |#2|) -12 (|has| |#1| (-388)) (|has| |#2| (-325 |#2|))) (((-1191) |#2|) -12 (|has| |#1| (-388)) (|has| |#2| (-547 (-1191) |#2|)))) 
+((((-433 |#2|)) . T) (((-433 (-592))) . T) (($) . T)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-867))) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(|has| |#1| (-1119)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(|has| |#1| (-1119)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(|has| |#1| (-867)) 
+((($) . T) (((-433 (-592))) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#4| (-815)) (|has| |#4| (-867))) 
+(-3836 (|has| |#4| (-815)) (|has| |#4| (-867))) 
+(-3836 (|has| |#3| (-815)) (|has| |#3| (-867))) 
+(-3836 (|has| |#3| (-815)) (|has| |#3| (-867))) 
 (((|#1| |#2|) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
 (((|#1| |#2|) . T)) 
-(|has| |#2| (-368)) 
-(|has| |#1| (-1098)) 
-(|has| |#1| (-1098)) 
-(((|#1| (-1170) (-1087 (-1170)) (-538 (-1087 (-1170)))) . T)) 
-((((-572) |#1|) . T)) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-((((-911 |#1|)) . T)) 
-(((|#1| (-538 |#2|)) . T)) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-722)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(((|#1| (-769)) . T)) 
-(|has| |#2| (-794)) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-(|has| |#2| (-846)) 
+(|has| |#2| (-388)) 
+(|has| |#1| (-1119)) 
+(|has| |#1| (-1119)) 
+(((|#1| (-1191) (-1108 (-1191)) (-558 (-1108 (-1191)))) . T)) 
+((((-592) |#1|) . T)) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+((((-932 |#1|)) . T)) 
+(((|#1| (-558 |#2|)) . T)) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-743)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(((|#1| (-790)) . T)) 
+(|has| |#2| (-815)) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+(|has| |#2| (-867)) 
 (((|#1|) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#1| |#2|) . T)) 
-((((-1152) |#1|) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-(((|#1|) . T)) 
-(((|#3| (-769)) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(|has| |#1| (-1098)) 
-((((-413 (-572))) . T) (((-572)) . T)) 
-((((-1170) |#2|) |has| |#2| (-527 (-1170) |#2|)) ((|#2| |#2|) |has| |#2| (-305 |#2|))) 
-((((-413 (-572))) . T) (((-572)) . T)) 
+((((-1173) |#1|) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+(((|#1|) . T)) 
+(((|#3| (-790)) . T)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(|has| |#1| (-1119)) 
+((((-433 (-592))) . T) (((-592)) . T)) 
+((((-1191) |#2|) |has| |#2| (-547 (-1191) |#2|)) ((|#2| |#2|) |has| |#2| (-325 |#2|))) 
+((((-433 (-592))) . T) (((-592)) . T)) 
 (((|#1|) . T) (($) . T)) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#1|) |has| |#1| (-174))) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-((((-694) (-1166 (-694))) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((($) . T) (((-413 (-572))) . T) ((|#1|) |has| |#1| (-174))) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#1|) . T)) 
-(|has| |#2| (-368)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-572) |#1|) . T)) 
-((($) . T) (((-572)) . T) (((-413 (-572))) . T)) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#1|) |has| |#1| (-194))) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+((((-715) (-1187 (-715))) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((($) . T) (((-433 (-592))) . T) ((|#1|) |has| |#1| (-194))) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#1|) . T)) 
+(|has| |#2| (-388)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-592) |#1|) . T)) 
+((($) . T) (((-592)) . T) (((-433 (-592))) . T)) 
 (((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
-((((-856)) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-1152) |#1|) . T)) 
+((((-877)) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-1173) |#1|) . T)) 
 (((|#3| |#3|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#1|) . T)) 
-((((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910)))) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-312 |#1|)) . T)) 
-(((|#1|) . T)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910)))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) -1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) ((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054)))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-572) |#1|) . T)) 
-((((-171 (-217))) |has| |#1| (-1028)) (((-171 (-385))) |has| |#1| (-1028)) (((-545)) |has| |#1| (-613 (-545))) (((-1166 |#1|)) . T) (((-893 (-572))) |has| |#1| (-613 (-893 (-572)))) (((-893 (-385))) |has| |#1| (-613 (-893 (-385))))) 
-((((-856)) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-846))) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-846))) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) ((|#2|) |has| |#1| (-368)) ((|#1|) |has| |#1| (-174))) 
-(|has| |#2| (-562)) 
-(|has| |#1| (-368)) 
-(((|#1|) |has| |#1| (-174)) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562)))) 
-((((-863 |#1|) (-780 (-863 |#1|))) . T)) 
-(((|#1| |#1|) |has| |#1| (-174)) (($ $) |has| |#1| (-174))) 
-(-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) 
-(-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) 
-(((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-174))) 
-(-1841 (|has| |#4| (-174)) (|has| |#4| (-846)) (|has| |#4| (-1054))) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((((-1170)) |has| |#2| (-901 (-1170))) (((-1082)) . T)) 
-((((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-634 (-572)))) 
-(((|#2|) . T) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(((|#1|) . T) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-562)) 
-(((|#1|) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#1|) . T)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-562)) 
-((((-694)) . T)) 
-(((|#1|) . T)) 
-(((|#2|) . T)) 
-(-12 (|has| |#1| (-1009)) (|has| |#1| (-1190))) 
-(((|#2|) . T) (($) . T) (((-413 (-572))) . T)) 
-((($) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T)) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (((-1168 |#1| |#2| |#3|)) |has| |#1| (-368)) (($) . T) ((|#1|) . T)) 
-(((|#1|) . T) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) (($) . T)) 
-(((|#4| |#4|) -1841 (|has| |#4| (-174)) (|has| |#4| (-368)) (|has| |#4| (-1054))) (($ $) |has| |#4| (-174))) 
-(((|#3| |#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-1054))) (($ $) |has| |#3| (-174))) 
-(((|#2|) . T)) 
-(((|#1|) . T)) 
-((((-545)) |has| |#2| (-613 (-545))) (((-893 (-385))) |has| |#2| (-613 (-893 (-385)))) (((-893 (-572))) |has| |#2| (-613 (-893 (-572))))) 
-((((-856)) . T)) 
+((((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931)))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-332 |#1|)) . T)) 
+(((|#1|) . T)) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931)))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) -3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) ((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075)))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-592) |#1|) . T)) 
+((((-877)) . T)) 
+((((-191 (-237))) |has| |#1| (-1049)) (((-191 (-405))) |has| |#1| (-1049)) (((-565)) |has| |#1| (-633 (-565))) (((-1187 |#1|)) . T) (((-914 (-592))) |has| |#1| (-633 (-914 (-592)))) (((-914 (-405))) |has| |#1| (-633 (-914 (-405))))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-867))) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-867))) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) ((|#2|) |has| |#1| (-388)) ((|#1|) |has| |#1| (-194))) 
+(|has| |#2| (-582)) 
+(|has| |#1| (-388)) 
+(((|#1|) |has| |#1| (-194)) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582)))) 
+((((-884 |#1|) (-801 (-884 |#1|))) . T)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(((|#1| |#1|) |has| |#1| (-194)) (($ $) |has| |#1| (-194))) 
+(-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) 
+(-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) 
+(((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-194))) 
+(-3836 (|has| |#4| (-194)) (|has| |#4| (-867)) (|has| |#4| (-1075))) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+((((-877)) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(((|#1|) . T)) 
+((((-1191)) |has| |#2| (-922 (-1191))) (((-1103)) . T)) 
+((((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-654 (-592)))) 
+(((|#2|) . T) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(((|#1|) . T) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-582)) 
+(((|#1|) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#1|) . T)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-582)) 
+((((-715)) . T)) 
+(((|#1|) . T)) 
+(((|#2|) . T)) 
+(-12 (|has| |#1| (-1030)) (|has| |#1| (-1211))) 
+(((|#2|) . T) (($) . T) (((-433 (-592))) . T)) 
+((($) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T)) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (((-1189 |#1| |#2| |#3|)) |has| |#1| (-388)) (($) . T) ((|#1|) . T)) 
+(((|#1|) . T) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) (($) . T)) 
+(((|#4| |#4|) -3836 (|has| |#4| (-194)) (|has| |#4| (-388)) (|has| |#4| (-1075))) (($ $) |has| |#4| (-194))) 
+(((|#3| |#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-1075))) (($ $) |has| |#3| (-194))) 
+(((|#2|) . T)) 
+(((|#1|) . T)) 
+((((-565)) |has| |#2| (-633 (-565))) (((-914 (-405))) |has| |#2| (-633 (-914 (-405)))) (((-914 (-592))) |has| |#2| (-633 (-914 (-592))))) 
+((((-877)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-((((-856)) . T)) 
-((((-545)) |has| |#1| (-613 (-545))) (((-893 (-385))) |has| |#1| (-613 (-893 (-385)))) (((-893 (-572))) |has| |#1| (-613 (-893 (-572))))) 
-((((-856)) . T)) 
-(((|#4|) -1841 (|has| |#4| (-174)) (|has| |#4| (-368)) (|has| |#4| (-1054))) (($) |has| |#4| (-174))) 
-(((|#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-1054))) (($) |has| |#3| (-174))) 
-((((-856)) . T)) 
-((((-545)) . T) (((-572)) . T) (((-893 (-572))) . T) (((-385)) . T) (((-217)) . T)) 
-((((-1082)) . T) ((|#2|) . T) (((-572)) |has| |#2| (-1044 (-572))) (((-413 (-572))) |has| |#2| (-1044 (-413 (-572))))) 
-(((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-((($) . T) (((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) . T)) 
-((((-413 $) (-413 $)) |has| |#2| (-562)) (($ $) . T) ((|#2| |#2|) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) . T)) 
-(((|#1|) . T)) 
-(|has| |#2| (-910)) 
-((((-1152) (-57)) . T)) 
-((((-572)) |has| (-413 |#2|) (-634 (-572))) (((-413 |#2|)) . T)) 
-((((-545)) . T) (((-217)) . T) (((-385)) . T) (((-893 (-385))) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054))) 
-(((|#1|) |has| |#1| (-174))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(((|#1| $) |has| |#1| (-283 |#1| |#1|))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-848)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-1098)) 
-(((|#1|) . T)) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) |has| |#2| (-174)) (($) -1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-(((|#2| (-769)) . T)) 
-((($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(|has| |#1| (-227)) 
-((($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1| (-538 (-819 (-1170)))) . T)) 
-(((|#1| (-979)) . T)) 
-((((-870 |#1|) $) |has| (-870 |#1|) (-283 (-870 |#1|) (-870 |#1|)))) 
-((((-572) |#4|) . T)) 
-((((-572) |#3|) . T)) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565))) (((-914 (-405))) |has| |#1| (-633 (-914 (-405)))) (((-914 (-592))) |has| |#1| (-633 (-914 (-592))))) 
+((((-877)) . T)) 
+(((|#4|) -3836 (|has| |#4| (-194)) (|has| |#4| (-388)) (|has| |#4| (-1075))) (($) |has| |#4| (-194))) 
+(((|#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-1075))) (($) |has| |#3| (-194))) 
+((((-877)) . T)) 
+((((-565)) . T) (((-592)) . T) (((-914 (-592))) . T) (((-405)) . T) (((-237)) . T)) 
+((((-1103)) . T) ((|#2|) . T) (((-592)) |has| |#2| (-1065 (-592))) (((-433 (-592))) |has| |#2| (-1065 (-433 (-592))))) 
+(((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+((($) . T) (((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) . T)) 
+((((-433 $) (-433 $)) |has| |#2| (-582)) (($ $) . T) ((|#2| |#2|) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) . T)) 
+(((|#1|) . T)) 
+(|has| |#2| (-931)) 
+((((-1173) (-57)) . T)) 
+((((-592)) |has| (-433 |#2|) (-654 (-592))) (((-433 |#2|)) . T)) 
+((((-565)) . T) (((-237)) . T) (((-405)) . T) (((-914 (-405))) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075))) 
+(((|#1|) |has| |#1| (-194))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(((|#1| $) |has| |#1| (-303 |#1| |#1|))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-869)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-1119)) 
+(((|#1|) . T)) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) |has| |#2| (-194)) (($) -3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+(((|#2| (-790)) . T)) 
+((($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(|has| |#1| (-247)) 
+((($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1| (-558 (-840 (-1191)))) . T)) 
+(((|#1| (-1000)) . T)) 
+((((-891 |#1|) $) |has| (-891 |#1|) (-303 (-891 |#1|) (-891 |#1|)))) 
+((((-592) |#4|) . T)) 
+((((-592) |#3|) . T)) 
 (((|#1|) . T)) 
 (((|#2| |#2|) . T)) 
-(|has| |#1| (-1144)) 
-(((|#1| (-769) (-1082)) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-(|has| (-1244 |#1| |#2| |#3| |#4|) (-149)) 
-(|has| (-1244 |#1| |#2| |#3| |#4|) (-151)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(((|#1|) |has| |#1| (-174))) 
-((((-171 (-217))) . T)) 
-((((-217)) . T)) 
-((((-1170)) -12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) 
-(|has| |#1| (-1098)) 
-((((-1152) |#1|) . T)) 
-(((|#1|) . T)) 
-(((|#2|) . T)) 
-(((|#2|) . T) (((-572)) |has| |#2| (-634 (-572)))) 
-(|has| |#2| (-374)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+(|has| |#1| (-1165)) 
+(((|#1| (-790) (-1103)) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+(|has| (-1265 |#1| |#2| |#3| |#4|) (-169)) 
+(|has| (-1265 |#1| |#2| |#3| |#4|) (-171)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(((|#1|) |has| |#1| (-194))) 
+((((-191 (-237))) . T)) 
+((((-237)) . T)) 
+((((-1191)) -12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) 
+(|has| |#1| (-1119)) 
+((((-1173) |#1|) . T)) 
+(((|#1|) . T)) 
+(((|#2|) . T)) 
+(((|#2|) . T) (((-592)) |has| |#2| (-654 (-592)))) 
+(|has| |#2| (-394)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-1235))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 ((($) . T) ((|#1|) . T)) 
-(((|#2|) |has| |#2| (-1054))) 
-((((-856)) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
+(((|#2|) |has| |#2| (-1075))) 
+((((-877)) . T)) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
 (((|#1|) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) |has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))))) 
-((((-572) |#1|) . T)) 
-((((-856)) . T)) 
-((((-545)) -12 (|has| |#1| (-613 (-545))) (|has| |#2| (-613 (-545)))) (((-893 (-385))) -12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385))))) (((-893 (-572))) -12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) |has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))))) 
+((((-592) |#1|) . T)) 
+((((-877)) . T)) 
+((((-565)) -12 (|has| |#1| (-633 (-565))) (|has| |#2| (-633 (-565)))) (((-914 (-405))) -12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405))))) (((-914 (-592))) -12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 ((($) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
 ((($) . T)) 
 ((($) . T)) 
 ((($) . T)) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(|has| (-1243 |#2| |#3| |#4|) (-151)) 
-(|has| (-1243 |#2| |#3| |#4|) (-149)) 
-(((|#2|) |has| |#2| (-1098)) (((-572)) -12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098))) (((-413 (-572))) -12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(|has| (-1264 |#2| |#3| |#4|) (-171)) 
+(|has| (-1264 |#2| |#3| |#4|) (-169)) 
+(((|#2|) |has| |#2| (-1119)) (((-592)) -12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119))) (((-433 (-592))) -12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) 
 (((|#1|) . T)) 
-(|has| |#1| (-1098)) 
-((((-856)) . T)) 
+(|has| |#1| (-1119)) 
+((((-877)) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054))) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075))) 
 (((|#1|) . T)) 
-((((-572) |#1|) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-(((|#1|) |has| |#1| (-174))) 
+((((-592) |#1|) . T)) 
+(((|#2|) |has| |#2| (-194))) 
+(((|#1|) |has| |#1| (-194))) 
 (((|#1|) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-846))) 
-((((-856)) |has| |#1| (-1098))) 
-(-1841 (|has| |#1| (-482)) (|has| |#1| (-722)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054)) (|has| |#1| (-1110))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-((((-911 |#1|)) . T)) 
-((((-413 |#2|) |#3|) . T)) 
-(|has| |#1| (-15 * (|#1| (-572) |#1|))) 
-((((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-848)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-867))) 
+((((-877)) |has| |#1| (-1119))) 
+(-3836 (|has| |#1| (-502)) (|has| |#1| (-743)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075)) (|has| |#1| (-1131))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+((((-932 |#1|)) . T)) 
+((((-433 |#2|) |#3|) . T)) 
+(|has| |#1| (-15 * (|#1| (-592) |#1|))) 
+((((-433 (-592))) . T) (($) . T)) 
+(|has| |#1| (-869)) 
 (((|#1|) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-562))) 
-(|has| |#1| (-15 * (|#1| (-769) |#1|))) 
-(|has| |#1| (-368)) 
-(-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))) 
-(|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) 
-((((-572)) . T)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-15 * (|#1| (-769) |#1|))) 
-((((-1135 |#2| (-413 (-959 |#1|)))) . T) (((-413 (-959 |#1|))) . T)) 
-((($) . T)) 
-(((|#1|) |has| |#1| (-174)) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) (($) . T)) 
-(((|#1|) . T)) 
-((((-572) |#1|) . T)) 
-(((|#2|) . T)) 
-(-1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-((((-572)) . T)) 
-(((|#1|) . T)) 
-(|has| |#2| (-149)) 
-(|has| |#2| (-151)) 
-((((-1170)) -12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-856)) . T)) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-821))) 
-(-1841 (|has| |#1| (-303)) (|has| |#1| (-368)) (|has| |#1| (-353)) (|has| |#1| (-562))) 
-((((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562)))) 
-((($ $) |has| |#1| (-562))) 
-((((-694) (-1166 (-694))) . T)) 
-((((-856)) . T)) 
-((((-856)) . T) (((-1259 |#4|)) . T)) 
-((((-856)) . T) (((-1259 |#3|)) . T)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562)))) 
-((($) |has| |#1| (-562))) 
-((((-856)) . T)) 
-((($) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (((-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|)) |has| |#1| (-368)) ((|#1| |#1|) . T)) 
-(((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368)))) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (((-1250 |#1| |#2| |#3|)) |has| |#1| (-368)) ((|#1|) . T)) 
-(((|#3|) |has| |#3| (-1054))) 
-(((|#1|) . T) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368)))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(|has| |#1| (-1098)) 
-(((|#2| (-820 |#1|)) . T)) 
-(((|#1|) . T)) 
-(|has| |#1| (-368)) 
-((((-413 $) (-413 $)) |has| |#1| (-562)) (($ $) . T) ((|#1| |#1|) . T)) 
-((((-1082) |#2|) . T) (((-1082) $) . T) (($ $) . T)) 
-((((-911 |#1|)) . T)) 
-((((-148)) . T)) 
-((((-148)) . T)) 
-(((|#3|) |has| |#3| (-1098)) (((-572)) -12 (|has| |#3| (-1044 (-572))) (|has| |#3| (-1098))) (((-413 (-572))) -12 (|has| |#3| (-1044 (-413 (-572)))) (|has| |#3| (-1098)))) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-910))) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(((|#1|) . T)) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-(|has| |#1| (-368)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-846))) 
-((((-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((|#1| |#1|) |has| |#1| (-305 |#1|))) 
-(|has| |#2| (-821)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-846)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-545)) |has| |#1| (-613 (-545)))) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-582))) 
+(|has| |#1| (-15 * (|#1| (-790) |#1|))) 
+(|has| |#1| (-388)) 
+(-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))) 
+(|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) 
+((((-592)) . T)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-15 * (|#1| (-790) |#1|))) 
+((((-1156 |#2| (-433 (-980 |#1|)))) . T) (((-433 (-980 |#1|))) . T)) 
+((($) . T)) 
+(((|#1|) |has| |#1| (-194)) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) (($) . T)) 
+(((|#1|) . T)) 
+((((-592) |#1|) . T)) 
+(((|#2|) . T)) 
+(-3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+((((-592)) . T)) 
+(((|#1|) . T)) 
+(|has| |#2| (-169)) 
+(|has| |#2| (-171)) 
+((((-1191)) -12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-877)) . T)) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-842))) 
+(-3836 (|has| |#1| (-323)) (|has| |#1| (-388)) (|has| |#1| (-373)) (|has| |#1| (-582))) 
+((((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582)))) 
+((($ $) |has| |#1| (-582))) 
+((((-715) (-1187 (-715))) . T)) 
+((((-877)) . T)) 
+((((-877)) . T) (((-1280 |#4|)) . T)) 
+((((-877)) . T) (((-1280 |#3|)) . T)) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582)))) 
+((($) |has| |#1| (-582))) 
+((((-877)) . T)) 
+((($) . T)) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (((-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|)) |has| |#1| (-388)) ((|#1| |#1|) . T)) 
+(((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388)))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (((-1271 |#1| |#2| |#3|)) |has| |#1| (-388)) ((|#1|) . T)) 
+(((|#3|) |has| |#3| (-1075))) 
+(((|#1|) . T) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388)))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(|has| |#1| (-1119)) 
+(((|#2| (-841 |#1|)) . T)) 
+(((|#1|) . T)) 
+(|has| |#1| (-388)) 
+((((-433 $) (-433 $)) |has| |#1| (-582)) (($ $) . T) ((|#1| |#1|) . T)) 
+((((-1103) |#2|) . T) (((-1103) $) . T) (($ $) . T)) 
+((((-932 |#1|)) . T)) 
+((((-168)) . T)) 
+((((-168)) . T)) 
+(((|#3|) |has| |#3| (-1119)) (((-592)) -12 (|has| |#3| (-1065 (-592))) (|has| |#3| (-1119))) (((-433 (-592))) -12 (|has| |#3| (-1065 (-433 (-592)))) (|has| |#3| (-1119)))) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-931))) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(((|#1|) . T)) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+(|has| |#1| (-388)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-867))) 
+((((-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((|#1| |#1|) |has| |#1| (-325 |#1|))) 
+(|has| |#2| (-842)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-867)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565)))) 
 (((|#1| |#2|) . T)) 
-((((-1170)) -12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) 
-((((-1152) |#1|) . T)) 
-(((|#1| |#2| |#3| (-538 |#3|)) . T)) 
-((((-923) |#1|) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
+((((-1191)) -12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) 
+((((-1173) |#1|) . T)) 
+(((|#1| |#2| |#3| (-558 |#3|)) . T)) 
+((((-944) |#1|) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
 (((|#1| |#2|) . T)) 
-(|has| |#1| (-374)) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-((((-856)) . T)) 
-(((|#2|) . T)) 
-((((-856)) . T)) 
-(-12 (|has| |#2| (-227)) (|has| |#2| (-1054))) 
-((((-1170) (-870 |#1|)) |has| (-870 |#1|) (-527 (-1170) (-870 |#1|))) (((-870 |#1|) (-870 |#1|)) |has| (-870 |#1|) (-305 (-870 |#1|)))) 
-(((|#1|) . T)) 
-((((-572) |#4|) . T)) 
-((((-572) |#3|) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-634 (-572)))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T)) 
-((((-413 (-572))) . T) (((-572)) . T)) 
-((((-856)) |has| |#1| (-1098))) 
+(|has| |#1| (-394)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+((((-877)) . T)) 
+(((|#2|) . T)) 
+((((-877)) . T)) 
+(-12 (|has| |#2| (-247)) (|has| |#2| (-1075))) 
+((((-1191) (-891 |#1|)) |has| (-891 |#1|) (-547 (-1191) (-891 |#1|))) (((-891 |#1|) (-891 |#1|)) |has| (-891 |#1|) (-325 (-891 |#1|)))) 
+(((|#1|) . T)) 
+((((-592) |#4|) . T)) 
+((((-592) |#3|) . T)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-654 (-592)))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T)) 
+((((-433 (-592))) . T) (((-592)) . T)) 
+((((-877)) |has| |#1| (-1119))) 
 (((|#1| |#1|) . T)) 
 (((|#1|) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((($) . T) (((-572)) . T) (((-413 (-572))) . T)) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-((($) . T) (((-572)) . T) (((-413 (-572))) . T)) 
-(((|#1| |#1|) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-572) (-572)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#1|) |has| |#1| (-562))) 
-((((-572) |#4|) . T)) 
-((((-572) |#3|) . T)) 
-((((-856)) . T)) 
-((((-572)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-856)) . T)) 
-((((-572) |#1|) . T)) 
-(((|#1|) . T)) 
-((($ $) . T) (((-858 |#1|) $) . T) (((-858 |#1|) |#2|) . T)) 
-((((-312 |#1|) (-312 |#1|)) . T)) 
-((($) . T)) 
-((($ $) . T) (((-1170) $) . T) (((-1170) |#1|) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-((((-312 |#1|)) . T)) 
-(((|#2| |#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054))) (($ $) |has| |#2| (-174))) 
-((((-148)) . T)) 
-((($) -1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) ((|#2|) |has| |#2| (-174)) (((-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
-(((|#1|) . T)) 
-(-12 (|has| |#1| (-374)) (|has| |#2| (-374))) 
-((((-856)) . T)) 
-(((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054))) (($) |has| |#2| (-174))) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-1098)) 
-(|has| $ (-151)) 
-((((-863 |#1|) |#2| (-244 |#2| (-863 |#1|)) (-234 (-4032 |#2|) (-769)) (-974 |#1|) (-780 (-863 |#1|)) (-928 |#1|) (-238 (-928 |#1|)) |#3|) . T)) 
-((((-572) |#1|) . T)) 
-((($) -1841 (|has| |#1| (-303)) (|has| |#1| (-368)) (|has| |#1| (-353)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1|) . T)) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) 
-(|has| |#1| (-368)) 
-(-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))) 
-(|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-15 * (|#1| (-769) |#1|))) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-((((-856)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(((|#2| (-538 (-858 |#1|))) . T)) 
-((((-856)) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-585 |#1|)) . T)) 
-((($) . T)) 
-(|has| |#1| (-1190)) 
-(|has| |#1| (-1190)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((($) . T) (((-592)) . T) (((-433 (-592))) . T)) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+((($) . T) (((-592)) . T) (((-433 (-592))) . T)) 
+(((|#1| |#1|) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-592) (-592)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#1|) |has| |#1| (-582))) 
+((((-592) |#4|) . T)) 
+((((-592) |#3|) . T)) 
+((((-877)) . T)) 
+((((-592)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-877)) . T)) 
+((((-592) |#1|) . T)) 
+(((|#1|) . T)) 
+((($ $) . T) (((-879 |#1|) $) . T) (((-879 |#1|) |#2|) . T)) 
+((((-332 |#1|) (-332 |#1|)) . T)) 
+((($) . T)) 
+((($ $) . T) (((-1191) $) . T) (((-1191) |#1|) . T)) 
+(((|#2|) |has| |#2| (-194))) 
+((((-332 |#1|)) . T)) 
+(((|#2| |#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075))) (($ $) |has| |#2| (-194))) 
+((((-168)) . T)) 
+((($) -3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) ((|#2|) |has| |#2| (-194)) (((-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
+(((|#1|) . T)) 
+(-12 (|has| |#1| (-394)) (|has| |#2| (-394))) 
+((((-877)) . T)) 
+(((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075))) (($) |has| |#2| (-194))) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-1119)) 
+(|has| $ (-171)) 
+((((-884 |#1|) |#2| (-264 |#2| (-884 |#1|)) (-254 (-1699 |#2|) (-790)) (-995 |#1|) (-801 (-884 |#1|)) (-949 |#1|) (-258 (-949 |#1|)) |#3|) . T)) 
+((((-592) |#1|) . T)) 
+((($) -3836 (|has| |#1| (-323)) (|has| |#1| (-388)) (|has| |#1| (-373)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1|) . T)) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) 
+(|has| |#1| (-388)) 
+(-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))) 
+(|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-15 * (|#1| (-790) |#1|))) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+((((-877)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(((|#2| (-558 (-879 |#1|))) . T)) 
+((((-877)) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(-3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-605 |#1|)) . T)) 
+((($) . T)) 
+(|has| |#1| (-1211)) 
+(|has| |#1| (-1211)) 
 (((|#1|) . T) (($) . T)) 
-((((-572)) |has| |#1| (-634 (-572))) ((|#1|) . T)) 
+((((-592)) |has| |#1| (-654 (-592))) ((|#1|) . T)) 
 (((|#4|) . T)) 
 (((|#3|) . T)) 
-((((-870 |#1|)) . T) (($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-1190)) 
-(|has| |#1| (-1190)) 
-((((-1170)) -12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-572) |#2|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+((((-891 |#1|)) . T) (($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-1211)) 
+(|has| |#1| (-1211)) 
+((((-1191)) -12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-592) |#2|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#2| |#3| |#4| |#5|) . T)) 
-((((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562)))) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (((-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|)) |has| |#1| (-368)) ((|#1| |#1|) . T)) 
-(((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368)))) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#2|) |has| |#2| (-1054))) 
-(|has| |#1| (-1098)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562)))) 
-(|has| |#1| (-174)) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (((-1168 |#1| |#2| |#3|)) |has| |#1| (-368)) ((|#1|) . T)) 
-(((|#1|) . T) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368)))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1|) |has| |#1| (-174)) (($) . T)) 
-(((|#1|) . T)) 
-((((-413 (-572)) (-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2| |#2|) . T) (($ $) -1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((((-856)) . T)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) |has| |#2| (-174)) (($) -1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((($) . T) ((|#2|) . T) (((-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
+((((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582)))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (((-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|)) |has| |#1| (-388)) ((|#1| |#1|) . T)) 
+(((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388)))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#2|) |has| |#2| (-1075))) 
+(|has| |#1| (-1119)) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582)))) 
+(|has| |#1| (-194)) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (((-1189 |#1| |#2| |#3|)) |has| |#1| (-388)) ((|#1|) . T)) 
+(((|#1|) . T) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388)))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1|) |has| |#1| (-194)) (($) . T)) 
+(((|#1|) . T)) 
+(|has| |#2| (-388)) 
+((((-433 (-592)) (-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2| |#2|) . T) (($ $) -3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((((-877)) . T)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) |has| |#2| (-194)) (($) -3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((($) . T) ((|#2|) . T) (((-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
 ((($ $) . T) ((|#2| $) . T) ((|#2| |#1|) . T)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910)))) 
-((((-1082) |#1|) . T) (((-1082) $) . T) (($ $) . T)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) . T) (($) -1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((($) . T)) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) (($) . T)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#2|) |has| |#1| (-368))) 
-(((|#1|) . T)) 
-(|has| |#2| (-910)) 
-(((|#2|) |has| |#2| (-1098)) (((-572)) -12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098))) (((-413 (-572))) -12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) 
-((((-572) |#1|) . T)) 
-(((|#1| (-413 (-572))) . T)) 
-((((-413 |#2|) |#3|) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) |has| |#2| (-174)) (($) -1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#2| |#3| (-858 |#1|)) . T)) 
-((((-1170)) |has| |#2| (-901 (-1170)))) 
-(((|#1|) . T)) 
-(((|#1| (-538 |#2|) |#2|) . T)) 
-(((|#1| (-769) (-1082)) . T)) 
-((((-413 (-572))) |has| |#2| (-368)) (($) . T)) 
-(((|#1| (-538 (-1087 (-1170))) (-1087 (-1170))) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-722)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(|has| |#2| (-794)) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#2| (-846)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-((((-894 |#1|)) . T) (((-820 |#1|)) . T)) 
-((((-820 (-1170))) . T)) 
-(((|#1|) . T)) 
-(((|#2|) . T)) 
-(((|#2|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-638 (-572))) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-545)) . T) (((-893 (-572))) . T) (((-385)) . T) (((-217)) . T)) 
-(|has| |#1| (-227)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931)))) 
+((((-1103) |#1|) . T) (((-1103) $) . T) (($ $) . T)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) . T) (($) -3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((($) . T)) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) (($) . T)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#2|) |has| |#1| (-388))) 
+(((|#1|) . T)) 
+(|has| |#2| (-931)) 
+(((|#2|) |has| |#2| (-1119)) (((-592)) -12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119))) (((-433 (-592))) -12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) 
+((((-592) |#1|) . T)) 
+(((|#1| (-433 (-592))) . T)) 
+((((-433 |#2|) |#3|) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) |has| |#2| (-194)) (($) -3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#2| |#3| (-879 |#1|)) . T)) 
+((((-1191)) |has| |#2| (-922 (-1191)))) 
+(((|#1|) . T)) 
+(((|#1| (-558 |#2|) |#2|) . T)) 
+(((|#1| (-790) (-1103)) . T)) 
+((((-433 (-592))) |has| |#2| (-388)) (($) . T)) 
+(((|#1| (-558 (-1108 (-1191))) (-1108 (-1191))) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-743)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(|has| |#2| (-815)) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#2| (-867)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+((((-915 |#1|)) . T) (((-841 |#1|)) . T)) 
+((((-841 (-1191))) . T)) 
+(((|#1|) . T)) 
+(((|#2|) . T)) 
+(((|#2|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-658 (-592))) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-565)) . T) (((-914 (-592))) . T) (((-405)) . T) (((-237)) . T)) 
+(|has| |#1| (-247)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 ((($ $) . T)) 
 (((|#1| |#1|) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 ((($ $) . T)) 
-((((-1250 |#1| |#2| |#3|) $) -12 (|has| (-1250 |#1| |#2| |#3|) (-283 (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368))) (($ $) . T)) 
+((((-1271 |#1| |#2| |#3|) $) -12 (|has| (-1271 |#1| |#2| |#3|) (-303 (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388))) (($ $) . T)) 
 ((($ $) . T)) 
 ((($ $) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-174)) 
-((((-1133 |#1| |#2|)) |has| (-1133 |#1| |#2|) (-305 (-1133 |#1| |#2|)))) 
-(((|#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(((|#2|) . T) (((-572)) |has| |#2| (-1044 (-572))) (((-413 (-572))) |has| |#2| (-1044 (-413 (-572))))) 
-(((|#3| |#3|) -12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
+(|has| |#1| (-194)) 
+((((-1154 |#1| |#2|)) |has| (-1154 |#1| |#2|) (-325 (-1154 |#1| |#2|)))) 
+(((|#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(((|#2|) . T) (((-592)) |has| |#2| (-1065 (-592))) (((-433 (-592))) |has| |#2| (-1065 (-433 (-592))))) 
+(((|#3| |#3|) -12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
 (((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
-((((-856)) . T)) 
+((((-877)) . T)) 
 ((($) . T)) 
 ((($) . T)) 
 (((|#2|) . T)) 
 (((|#3|) . T)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-((((-572) (-1206) (-1206)) . T)) 
-(((|#2|) . T)) 
-((((-856)) -1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) (((-1259 |#2|)) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-((((-572)) . T)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910)))) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-572) (-148)) . T)) 
-((($) -1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) ((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054)))) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-562)) (|has| |#1| (-1054))) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-562)) (|has| |#1| (-1054))) 
-(((|#2|) |has| |#1| (-368))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+((((-592) (-1227) (-1227)) . T)) 
+(((|#2|) . T)) 
+((((-877)) -3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) (((-1280 |#2|)) . T)) 
+(((|#1|) |has| |#1| (-194))) 
+((((-592)) . T)) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931)))) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-592) (-168)) . T)) 
+((($) -3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) ((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075)))) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-582)) (|has| |#1| (-1075))) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-582)) (|has| |#1| (-1075))) 
+(((|#2|) |has| |#1| (-388))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 (((|#1| |#1|) . T) (($ $) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#1|) |has| |#1| (-174))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((($) . T) (((-413 (-572))) . T) ((|#1|) |has| |#1| (-174))) 
-((($) . T) (((-413 (-572))) . T)) 
-(((|#1| (-538 (-1170)) (-1170)) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#1|) |has| |#1| (-194))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((($) . T) (((-433 (-592))) . T) ((|#1|) |has| |#1| (-194))) 
+((($) . T) (((-433 (-592))) . T)) 
+(((|#1| (-558 (-1191)) (-1191)) . T)) 
 (((|#1|) . T) (($) . T)) 
-(|has| |#4| (-174)) 
-(|has| |#3| (-174)) 
-((((-413 (-959 |#1|)) (-413 (-959 |#1|))) . T)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(|has| |#1| (-1098)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(|has| |#1| (-1098)) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-174))) 
-(((|#1| |#1|) |has| |#1| (-174))) 
-((((-866)) . T) (((-413 (-572))) . T)) 
-((((-413 (-572))) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-413 (-959 |#1|))) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-856)) . T)) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T)) 
-(((|#1|) |has| |#1| (-1054)) (((-572)) -12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))) 
+(|has| |#4| (-194)) 
+(|has| |#3| (-194)) 
+((((-433 (-980 |#1|)) (-433 (-980 |#1|))) . T)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(|has| |#1| (-1119)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(|has| |#1| (-1119)) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-194))) 
+(((|#1| |#1|) |has| |#1| (-194))) 
+((((-887)) . T) (((-433 (-592))) . T)) 
+((((-433 (-592))) . T)) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-433 (-980 |#1|))) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) . T)) 
+(((|#1|) |has| |#1| (-194))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-877)) . T)) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T)) 
+(((|#1|) |has| |#1| (-1075)) (((-592)) -12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))) 
 (((|#1| |#2|) . T)) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-722)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-(|has| |#3| (-794)) 
-(-1841 (|has| |#3| (-794)) (|has| |#3| (-846))) 
-(|has| |#3| (-846)) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) ((|#2|) |has| |#1| (-368)) ((|#1|) |has| |#1| (-174))) 
-(((|#1|) |has| |#1| (-174)) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562)))) 
-(((|#2|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1| (-1150 |#1|)) |has| |#1| (-846))) 
-((((-572) |#2|) . T)) 
-(|has| |#1| (-1098)) 
-(((|#1|) . T)) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|))) |has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-305 (-2 (|:| |k| (-572)) (|:| |c| |#1|))))) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-1144))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(|has| |#1| (-1098)) 
-(((|#2|) . T)) 
-((((-545)) |has| |#2| (-613 (-545))) (((-893 (-385))) |has| |#2| (-613 (-893 (-385)))) (((-893 (-572))) |has| |#2| (-613 (-893 (-572))))) 
-(((|#4|) -1841 (|has| |#4| (-174)) (|has| |#4| (-368)))) 
-(((|#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)))) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-910))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-910))) 
-((($ $) . T) (((-1170) $) |has| |#1| (-227)) (((-1170) |#1|) |has| |#1| (-227)) (((-819 (-1170)) |#1|) . T) (((-819 (-1170)) $) . T)) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-910))) 
-((((-572) |#2|) . T)) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((($) -1841 (|has| |#3| (-174)) (|has| |#3| (-846)) (|has| |#3| (-1054))) ((|#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-1054)))) 
-((((-572) |#1|) . T)) 
-(|has| (-413 |#2|) (-151)) 
-(|has| (-413 |#2|) (-149)) 
-(((|#2|) -12 (|has| |#1| (-368)) (|has| |#2| (-305 |#2|)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-572)) . T)) 
-(((|#1|) . T)) 
-(((|#2|) . T) (($) . T) (((-413 (-572))) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-394) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#2| (-1144)) 
-(|has| |#1| (-562)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(((|#1|) . T)) 
-((((-394) (-1152)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(|has| |#1| (-562)) 
-((((-125 |#1|)) . T)) 
-((((-856)) . T)) 
-((((-572) |#1|) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(((|#2|) . T)) 
-((((-856)) . T)) 
-(((|#2|) |has| |#2| (-1054)) (((-572)) -12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) 
-((((-820 |#1|)) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-((((-1170) (-57)) . T)) 
-(((|#1|) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-562)) 
-(((|#1|) |has| |#1| (-174))) 
-((((-856)) . T)) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#2|) |has| |#2| (-305 |#2|))) 
-((((-572) (-572)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-(((|#1|) . T)) 
-(((|#1| (-1166 |#1|)) . T)) 
-(|has| $ (-151)) 
-(((|#2|) . T)) 
-((((-572) (-572)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((($) . T) (((-572)) . T) (((-413 (-572))) . T)) 
-(|has| |#2| (-374)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-572)) . T) (((-413 (-572))) . T) (($) . T)) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-743)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+(|has| |#3| (-815)) 
+(-3836 (|has| |#3| (-815)) (|has| |#3| (-867))) 
+(|has| |#3| (-867)) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) ((|#2|) |has| |#1| (-388)) ((|#1|) |has| |#1| (-194))) 
+(((|#1|) |has| |#1| (-194)) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582)))) 
+(((|#2|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1| (-1171 |#1|)) |has| |#1| (-867))) 
+((((-592) |#2|) . T)) 
+(|has| |#1| (-1119)) 
+(((|#1|) . T)) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|))) |has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-325 (-2 (|:| |k| (-592)) (|:| |c| |#1|))))) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-1165))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#1| (-1119)) 
+(((|#2|) . T)) 
+((((-565)) |has| |#2| (-633 (-565))) (((-914 (-405))) |has| |#2| (-633 (-914 (-405)))) (((-914 (-592))) |has| |#2| (-633 (-914 (-592))))) 
+(((|#4|) -3836 (|has| |#4| (-194)) (|has| |#4| (-388)))) 
+(((|#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)))) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-931))) 
+((($ $) . T) (((-1191) $) |has| |#1| (-247)) (((-1191) |#1|) |has| |#1| (-247)) (((-840 (-1191)) |#1|) . T) (((-840 (-1191)) $) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+((((-592) |#2|) . T)) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((($) -3836 (|has| |#3| (-194)) (|has| |#3| (-867)) (|has| |#3| (-1075))) ((|#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-1075)))) 
+((((-592) |#1|) . T)) 
+(|has| (-433 |#2|) (-171)) 
+(|has| (-433 |#2|) (-169)) 
+(((|#2|) -12 (|has| |#1| (-388)) (|has| |#2| (-325 |#2|)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-592)) . T)) 
+(((|#1|) . T)) 
+(((|#2|) . T) (($) . T) (((-433 (-592))) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-582)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+((((-414) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(|has| |#2| (-1165)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(((|#1|) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-414) (-1173)) . T)) 
+(|has| |#1| (-582)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+((((-145 |#1|)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(|has| |#1| (-582)) 
+((((-877)) . T)) 
+((((-592) |#1|) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(((|#2|) . T)) 
+((((-877)) . T)) 
+(((|#2|) |has| |#2| (-1075)) (((-592)) -12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) 
+((((-841 |#1|)) . T)) 
+(((|#2|) |has| |#2| (-194))) 
+((((-1191) (-57)) . T)) 
+(((|#1|) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-582)) 
+(((|#1|) |has| |#1| (-194))) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#2|) |has| |#2| (-325 |#2|))) 
+((((-592) (-592)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+(((|#1|) . T)) 
+(((|#1| (-1187 |#1|)) . T)) 
+(|has| $ (-171)) 
+(((|#2|) . T)) 
+((((-592) (-592)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+((($) . T) (((-592)) . T) (((-433 (-592))) . T)) 
+(|has| |#2| (-394)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-592)) . T) (((-433 (-592))) . T) (($) . T)) 
 (((|#1| |#2|) . T)) 
 (((|#1| |#2|) . T)) 
-((((-572)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-1168 |#1| |#2| |#3|) $) -12 (|has| (-1168 |#1| |#2| |#3|) (-283 (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368))) (($ $) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((($) . T) (((-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1|) . T)) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) |has| |#1| (-1098))) 
+((((-592)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-1189 |#1| |#2| |#3|) $) -12 (|has| (-1189 |#1| |#2| |#3|) (-303 (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388))) (($ $) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((($) . T) (((-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1|) . T)) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) |has| |#1| (-1119))) 
 ((($ $) . T)) 
 ((($ $) . T)) 
-((((-856)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|)) -12 (|has| (-1250 |#1| |#2| |#3|) (-305 (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368))) (((-1170) (-1250 |#1| |#2| |#3|)) -12 (|has| (-1250 |#1| |#2| |#3|) (-527 (-1170) (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368)))) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-572) (-1208) (-1208)) . T)) 
-((($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-413 (-572))) . T) (((-572)) . T)) 
-((((-572) (-148)) . T)) 
-((((-148)) . T)) 
-(((|#1|) . T)) 
-(|has| |#1| (-848)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-562)) (|has| |#1| (-1054))) 
-((((-121)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-121)) . T)) 
-(((|#1|) . T)) 
-((((-545)) |has| |#1| (-613 (-545))) (((-217)) |has| |#1| (-1028)) (((-385)) |has| |#1| (-1028))) 
-((((-856)) . T)) 
-(|has| |#1| (-821)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(|has| |#1| (-848)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-910)) 
-(((|#1|) . T)) 
-(|has| |#1| (-1098)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-(((|#1| (-1259 |#1|) (-1259 |#1|)) . T)) 
-((((-572) (-148)) . T)) 
-((($) . T)) 
-(-1841 (|has| |#4| (-174)) (|has| |#4| (-846)) (|has| |#4| (-1054))) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-(((|#2| (-769)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-1098)) 
-(((|#1| (-979)) . T)) 
+((((-877)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|)) -12 (|has| (-1271 |#1| |#2| |#3|) (-325 (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388))) (((-1191) (-1271 |#1| |#2| |#3|)) -12 (|has| (-1271 |#1| |#2| |#3|) (-547 (-1191) (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388)))) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-592) (-1229) (-1229)) . T)) 
+((($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-433 (-592))) . T) (((-592)) . T)) 
+((((-592) (-168)) . T)) 
+((((-168)) . T)) 
+(((|#1|) . T)) 
+(|has| |#1| (-869)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-582)) (|has| |#1| (-1075))) 
+((((-141)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-141)) . T)) 
+(((|#1|) . T)) 
+((((-565)) |has| |#1| (-633 (-565))) (((-237)) |has| |#1| (-1049)) (((-405)) |has| |#1| (-1049))) 
+((((-877)) . T)) 
+(|has| |#1| (-842)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(|has| |#1| (-869)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-931)) 
+(((|#1|) . T)) 
+(|has| |#1| (-1119)) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+(((|#1| (-1280 |#1|) (-1280 |#1|)) . T)) 
+((((-592) (-168)) . T)) 
+((($) . T)) 
+(-3836 (|has| |#4| (-194)) (|has| |#4| (-867)) (|has| |#4| (-1075))) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+(((|#2| (-790)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-1119)) 
+(((|#1| (-1000)) . T)) 
 (((|#1| |#1|) . T)) 
-(|has| (-413 (-572)) (-149)) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-(|has| (-413 (-572)) (-149)) 
-(((|#1| (-572)) . T)) 
+(|has| (-433 (-592)) (-169)) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+(|has| (-433 (-592)) (-169)) 
+(((|#1| (-592)) . T)) 
 ((($) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-722)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(-12 (|has| |#1| (-482)) (|has| |#2| (-482))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-743)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(-12 (|has| |#1| (-502)) (|has| |#2| (-502))) 
 (((|#1|) . T)) 
-(|has| |#2| (-794)) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
+(|has| |#2| (-815)) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
 (((|#1| |#2|) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(|has| |#2| (-846)) 
-(-12 (|has| |#1| (-794)) (|has| |#2| (-794))) 
-(-12 (|has| |#1| (-794)) (|has| |#2| (-794))) 
-(-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722)))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#2| (-867)) 
+(-12 (|has| |#1| (-815)) (|has| |#2| (-815))) 
+(-12 (|has| |#1| (-815)) (|has| |#2| (-815))) 
+(-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743)))) 
 (((|#1| |#2|) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-(((|#1|) |has| |#1| (-174))) 
-((((-856)) . T)) 
-(|has| |#1| (-353)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((($) . T) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#1|) . T)) 
-(|has| |#1| (-829)) 
-((((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T)) 
-(|has| |#1| (-1098)) 
-(((|#1| $) |has| |#1| (-283 |#1| |#1|))) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-562))) 
-((($) |has| |#1| (-562))) 
-(((|#4|) |has| |#4| (-1098))) 
-(((|#3|) |has| |#3| (-1098))) 
-(|has| |#3| (-374)) 
-(((|#1|) . T) (((-856)) . T)) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) (((-1250 |#1| |#2| |#3|)) |has| |#1| (-368)) ((|#1|) |has| |#1| (-174))) 
-((((-856)) . T)) 
-(((|#1|) |has| |#1| (-174)) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562)))) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#2|) . T)) 
-(((|#1| |#1|) |has| |#1| (-174))) 
+(((|#2|) |has| |#2| (-194))) 
+(((|#1|) |has| |#1| (-194))) 
+((((-877)) . T)) 
+(|has| |#1| (-373)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((($) . T) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#1|) . T)) 
+(|has| |#1| (-850)) 
+((((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T)) 
+(|has| |#1| (-1119)) 
+(((|#1| $) |has| |#1| (-303 |#1| |#1|))) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-582))) 
+((($) |has| |#1| (-582))) 
+(((|#4|) |has| |#4| (-1119))) 
+(((|#3|) |has| |#3| (-1119))) 
+(|has| |#3| (-394)) 
+(((|#1|) . T) (((-877)) . T)) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) (((-1271 |#1| |#2| |#3|)) |has| |#1| (-388)) ((|#1|) |has| |#1| (-194))) 
+((((-877)) . T)) 
+(((|#1|) |has| |#1| (-194)) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582)))) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#2|) . T)) 
+(((|#1| |#1|) |has| |#1| (-194))) 
 (((|#1| |#2|) . T)) 
-(|has| |#2| (-368)) 
-(((|#1|) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-((((-413 (-572))) . T) (((-572)) . T)) 
-((($ $) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) ((|#2| |#2|) . T) (((-413 (-572)) (-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) ((|#2|) . T) (((-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-((((-148)) . T)) 
-(((|#1|) . T)) 
-((((-148)) . T)) 
-((($) -1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) ((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054)))) 
-((((-148)) . T)) 
+(|has| |#2| (-388)) 
+(((|#1|) . T)) 
+(((|#1|) |has| |#1| (-194))) 
+((((-433 (-592))) . T) (((-592)) . T)) 
+((($ $) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) ((|#2| |#2|) . T) (((-433 (-592)) (-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) ((|#2|) . T) (((-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+((((-168)) . T)) 
+(((|#1|) . T)) 
+((((-168)) . T)) 
+((($) -3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) ((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075)))) 
+((((-168)) . T)) 
 (((|#1| |#2| |#3|) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-562)) (|has| |#1| (-1054))) 
-(|has| $ (-151)) 
-(|has| $ (-151)) 
-((((-572)) . T)) 
-(|has| |#1| (-1098)) 
-((((-856)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-482)) (|has| |#1| (-562)) (|has| |#1| (-1054)) (|has| |#1| (-1110))) 
-((($ $) |has| |#1| (-283 $ $)) ((|#1| $) |has| |#1| (-283 |#1| |#1|))) 
-(((|#1| (-413 (-572))) . T)) 
-(((|#1|) . T)) 
-(((|#1| (-572)) . T)) 
-((((-1170)) . T)) 
-(|has| |#1| (-562)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-856)) . T)) 
-(|has| |#2| (-149)) 
-(|has| |#2| (-151)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-582)) (|has| |#1| (-1075))) 
+(|has| $ (-171)) 
+(|has| $ (-171)) 
+((((-592)) . T)) 
+(|has| |#1| (-1119)) 
+((((-877)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-502)) (|has| |#1| (-582)) (|has| |#1| (-1075)) (|has| |#1| (-1131))) 
+((($ $) |has| |#1| (-303 $ $)) ((|#1| $) |has| |#1| (-303 |#1| |#1|))) 
+(((|#1| (-433 (-592))) . T)) 
+(((|#1|) . T)) 
+(((|#1| (-592)) . T)) 
+((((-1191)) . T)) 
+(|has| |#1| (-582)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-877)) . T)) 
+(|has| |#2| (-169)) 
+(|has| |#2| (-171)) 
 (((|#2|) . T) (($) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-(|has| |#4| (-846)) 
-(((|#2| (-234 (-4032 |#1|) (-769)) (-858 |#1|)) . T)) 
-(|has| |#3| (-846)) 
-(((|#1| (-538 |#3|) |#3|) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-((((-413 (-572)) (-413 (-572))) |has| |#2| (-368)) (($ $) . T)) 
-((((-870 |#1|)) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-149)) 
-((((-413 (-572))) |has| |#2| (-368)) (($) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(-1841 (|has| |#1| (-353)) (|has| |#1| (-374))) 
-((((-1135 |#2| |#1|)) . T) ((|#1|) . T)) 
-(((|#1|) . T)) 
-(|has| |#2| (-174)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+(|has| |#4| (-867)) 
+(((|#2| (-254 (-1699 |#1|) (-790)) (-879 |#1|)) . T)) 
+(|has| |#3| (-867)) 
+(((|#1| (-558 |#3|) |#3|) . T)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+((((-433 (-592)) (-433 (-592))) |has| |#2| (-388)) (($ $) . T)) 
+((((-891 |#1|)) . T)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-169)) 
+((((-433 (-592))) |has| |#2| (-388)) (($) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-373)) (|has| |#1| (-394))) 
+((((-1156 |#2| |#1|)) . T) ((|#1|) . T)) 
+(((|#1|) . T)) 
+(|has| |#2| (-194)) 
 (((|#1| |#2|) . T)) 
-(-12 (|has| |#2| (-227)) (|has| |#2| (-1054))) 
-(((|#2|) . T) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(-1841 (|has| |#3| (-794)) (|has| |#3| (-846))) 
-(-1841 (|has| |#3| (-794)) (|has| |#3| (-846))) 
-((((-856)) . T)) 
+(-12 (|has| |#2| (-247)) (|has| |#2| (-1075))) 
+(((|#2|) . T) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(-3836 (|has| |#3| (-815)) (|has| |#3| (-867))) 
+(-3836 (|has| |#3| (-815)) (|has| |#3| (-867))) 
+((((-877)) . T)) 
 (((|#1|) . T)) 
 (((|#2|) . T) (($) . T)) 
 (((|#1|) . T) (($) . T)) 
-((((-694)) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(|has| |#1| (-562)) 
+((((-715)) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(|has| |#1| (-582)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-1170) (-57)) . T)) 
-((((-856)) . T)) 
-((((-545)) . T) (((-893 (-572))) . T) (((-385)) . T) (((-217)) . T)) 
+((((-1191) (-57)) . T)) 
+((((-877)) . T)) 
+((((-565)) . T) (((-914 (-592))) . T) (((-405)) . T) (((-237)) . T)) 
 (((|#1|) . T)) 
-((((-856)) . T)) 
-((((-545)) . T) (((-893 (-572))) . T) (((-385)) . T) (((-217)) . T)) 
-(((|#1| (-572)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+((((-877)) . T)) 
+((((-565)) . T) (((-914 (-592))) . T) (((-405)) . T) (((-237)) . T)) 
+(((|#1| (-592)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
-(((|#1| (-413 (-572))) . T)) 
-(((|#3|) . T) (((-611 $)) . T)) 
+(((|#1| (-433 (-592))) . T)) 
+(((|#3|) . T) (((-631 $)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
 (((|#1|) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
 ((($ $) . T) ((|#2| $) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|)) -12 (|has| (-1168 |#1| |#2| |#3|) (-305 (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368))) (((-1170) (-1168 |#1| |#2| |#3|)) -12 (|has| (-1168 |#1| |#2| |#3|) (-527 (-1170) (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368)))) 
-((((-572)) . T) (($) . T) (((-413 (-572))) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|)) -12 (|has| (-1189 |#1| |#2| |#3|) (-325 (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388))) (((-1191) (-1189 |#1| |#2| |#3|)) -12 (|has| (-1189 |#1| |#2| |#3|) (-547 (-1191) (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388)))) 
+((((-592)) . T) (($) . T) (((-433 (-592))) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#1|) . T)) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) |has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))))) 
-((((-856)) . T)) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) |has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))))) 
+((((-877)) . T)) 
 (((|#1|) . T)) 
 (((|#3| |#3|) . T)) 
 (((|#1|) . T)) 
 ((($) . T) ((|#2|) . T)) 
-((((-1170) (-57)) . T)) 
+((((-1191) (-57)) . T)) 
 (((|#3|) . T)) 
-((($ $) . T) (((-858 |#1|) $) . T) (((-858 |#1|) |#2|) . T)) 
-(|has| |#1| (-829)) 
-((((-312 |#1|)) . T)) 
-(|has| |#1| (-1098)) 
-(((|#2| |#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054))) (($ $) |has| |#2| (-174))) 
-(((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)))) 
-((((-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((|#1| |#2|) . T)) 
-(((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054))) (($) |has| |#2| (-174))) 
-((((-769)) . T)) 
-((((-572)) . T)) 
-(|has| |#1| (-562)) 
-((((-856)) . T)) 
-(((|#1| (-413 (-572)) (-1082)) . T)) 
-(|has| |#1| (-149)) 
-(((|#1|) . T)) 
-(|has| |#1| (-562)) 
-((((-572)) . T)) 
-((((-125 |#1|)) . T)) 
-(((|#1| (-572) (-1082)) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-(|has| |#1| (-151)) 
-((((-893 (-572))) . T) (((-893 (-385))) . T) (((-545)) . T) (((-1170)) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-((($) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-((((-572)) |has| |#1| (-634 (-572))) ((|#1|) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-((($) -1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) ((|#2|) |has| |#2| (-174)) (((-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
-((((-870 |#1|)) . T)) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) 
-((((-856)) . T)) 
-(-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) 
-(|has| |#2| (-1144)) 
-((((-57)) . T) (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-(|has| |#2| (-562)) 
+((($ $) . T) (((-879 |#1|) $) . T) (((-879 |#1|) |#2|) . T)) 
+(|has| |#1| (-850)) 
+((((-332 |#1|)) . T)) 
+(|has| |#1| (-1119)) 
+(((|#2| |#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075))) (($ $) |has| |#2| (-194))) 
+(((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)))) 
+((((-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((|#1| |#2|) . T)) 
+(((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075))) (($) |has| |#2| (-194))) 
+((((-790)) . T)) 
+((((-592)) . T)) 
+(|has| |#1| (-582)) 
+((((-877)) . T)) 
+(((|#1| (-433 (-592)) (-1103)) . T)) 
+(|has| |#1| (-169)) 
+(((|#1|) . T)) 
+(|has| |#1| (-582)) 
+((((-592)) . T)) 
+((((-145 |#1|)) . T)) 
+(((|#1| (-592) (-1103)) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+(|has| |#1| (-171)) 
+((((-914 (-592))) . T) (((-914 (-405))) . T) (((-565)) . T) (((-1191)) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+((($) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+((((-592)) |has| |#1| (-654 (-592))) ((|#1|) . T)) 
+(((|#2|) |has| |#2| (-194))) 
+((($) -3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) ((|#2|) |has| |#2| (-194)) (((-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
+((((-891 |#1|)) . T)) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) 
+((((-877)) . T)) 
+(-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) 
+(|has| |#2| (-1165)) 
+((((-57)) . T) (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+(|has| |#2| (-582)) 
 (((|#1| |#2|) . T)) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-(((|#1| (-572) (-1082)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| (-413 (-572)) (-1082)) . T)) 
-((($) -1841 (|has| |#1| (-303)) (|has| |#1| (-368)) (|has| |#1| (-353)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1|) . T)) 
-((((-572) |#2|) . T)) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+(((|#1| (-592) (-1103)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| (-433 (-592)) (-1103)) . T)) 
+((($) -3836 (|has| |#1| (-323)) (|has| |#1| (-388)) (|has| |#1| (-373)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1|) . T)) 
+((((-592) |#2|) . T)) 
 (((|#1| |#2|) . T)) 
 (((|#1| |#2|) . T)) 
-(|has| |#2| (-374)) 
-(-12 (|has| |#1| (-374)) (|has| |#2| (-374))) 
-((((-856)) . T)) 
-((((-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((|#1| |#1|) |has| |#1| (-305 |#1|))) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(((|#1|) . T)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-562))) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) (((-1168 |#1| |#2| |#3|)) |has| |#1| (-368)) ((|#1|) |has| |#1| (-174))) 
-(((|#1|) |has| |#1| (-174)) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562)))) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-353)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-(|has| |#1| (-562)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-856)) . T)) 
+(|has| |#2| (-394)) 
+(-12 (|has| |#1| (-394)) (|has| |#2| (-394))) 
+((((-877)) . T)) 
+((((-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((|#1| |#1|) |has| |#1| (-325 |#1|))) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(((|#1|) . T)) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-582))) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) (((-1189 |#1| |#2| |#3|)) |has| |#1| (-388)) ((|#1|) |has| |#1| (-194))) 
+(((|#1|) |has| |#1| (-194)) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582)))) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-373)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+(|has| |#1| (-582)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-910))) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-910))) 
-((((-413 (-572))) . T) (((-572)) . T)) 
-((((-572)) . T)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) |has| |#2| (-174)) (($) -1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((($) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((((-870 |#1|)) . T) (($) . T) (((-413 (-572))) . T)) 
-((((-856)) . T)) 
-(|has| (-413 (-572)) (-149)) 
-(|has| (-413 (-572)) (-149)) 
-(((|#3| |#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-1054))) (($ $) |has| |#3| (-174))) 
-(|has| |#1| (-1028)) 
-((((-856)) . T)) 
-(((|#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-1054))) (($) |has| |#3| (-174))) 
-((((-572) (-121)) . T)) 
-(((|#1|) |has| |#1| (-305 |#1|))) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-((((-1170) $) |has| |#1| (-527 (-1170) $)) (($ $) |has| |#1| (-305 $)) ((|#1| |#1|) |has| |#1| (-305 |#1|)) (((-1170) |#1|) |has| |#1| (-527 (-1170) |#1|))) 
-(|has| |#2| (-562)) 
-((((-1170)) |has| |#1| (-901 (-1170)))) 
-(-1841 (-12 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353))) 
-((((-394) (-1116)) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+((((-433 (-592))) . T) (((-592)) . T)) 
+((((-592)) . T)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) |has| |#2| (-194)) (($) -3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((($) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+((((-891 |#1|)) . T) (($) . T) (((-433 (-592))) . T)) 
+((((-877)) . T)) 
+(|has| (-433 (-592)) (-169)) 
+(|has| (-433 (-592)) (-169)) 
+(((|#3| |#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-1075))) (($ $) |has| |#3| (-194))) 
+(|has| |#1| (-1049)) 
+((((-877)) . T)) 
+(((|#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-1075))) (($) |has| |#3| (-194))) 
+((((-592) (-141)) . T)) 
+(((|#1|) |has| |#1| (-325 |#1|))) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+((((-1191) $) |has| |#1| (-547 (-1191) $)) (($ $) |has| |#1| (-325 $)) ((|#1| |#1|) |has| |#1| (-325 |#1|)) (((-1191) |#1|) |has| |#1| (-547 (-1191) |#1|))) 
+(|has| |#2| (-582)) 
+((((-1191)) |has| |#1| (-922 (-1191)))) 
+(-3836 (-12 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373))) 
+((((-414) (-1137)) . T)) 
 (((|#1| |#4|) . T)) 
 (((|#1| |#3|) . T)) 
-((((-394) |#1|) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(|has| |#1| (-1098)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-911 |#1|)) . T)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) |has| |#2| (-174)) (($) -1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910)))) 
+((((-414) |#1|) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(|has| |#1| (-1119)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-932 |#1|)) . T)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) |has| |#2| (-194)) (($) -3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931)))) 
 (((|#1| |#2|) . T)) 
 ((($) . T)) 
 (((|#1| |#1|) . T)) 
-((((-870 |#1|)) |has| (-870 |#1|) (-305 (-870 |#1|)))) 
-(|has| |#1| (-1190)) 
+((((-891 |#1|)) |has| (-891 |#1|) (-325 (-891 |#1|)))) 
+(|has| |#1| (-1211)) 
 (((|#1| |#2|) . T)) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-(-12 (|has| |#1| (-794)) (|has| |#2| (-794))) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+(-12 (|has| |#1| (-815)) (|has| |#2| (-815))) 
 (((|#1|) . T)) 
-(-12 (|has| |#1| (-794)) (|has| |#2| (-794))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
+(-12 (|has| |#1| (-815)) (|has| |#2| (-815))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
 (((|#2|) . T) (($) . T)) 
-(((|#2|) . T) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(|has| |#1| (-1190)) 
-((((-572) (-572)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#4|) |has| |#4| (-1054))) 
-(((|#3|) |has| |#3| (-1054))) 
-(((|#1| |#1|) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(((|#1| |#1|) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(((|#1| |#1|) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(|has| |#1| (-368)) 
-((((-572)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#1|) . T)) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1| |#1|) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((((-545)) |has| |#3| (-613 (-545)))) 
-((((-685 |#3|)) . T) (((-856)) . T)) 
+(((|#2|) . T) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(|has| |#1| (-1211)) 
+((((-592) (-592)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#4|) |has| |#4| (-1075))) 
+(((|#3|) |has| |#3| (-1075))) 
+(((|#1| |#1|) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(((|#1| |#1|) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(((|#1| |#1|) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(|has| |#1| (-388)) 
+((((-592)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#1|) . T)) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1| |#1|) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+((((-565)) |has| |#3| (-633 (-565)))) 
+((((-706 |#3|)) . T) (((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-(|has| |#1| (-846)) 
-(|has| |#1| (-846)) 
-((($) . T) (((-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1|) . T)) 
-((((-572) |#3|) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) |has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))))) 
-((($) . T)) 
-((((-413 $) (-413 $)) |has| |#2| (-562)) (($ $) . T) ((|#2| |#2|) . T)) 
-((((-171 (-217))) . T)) 
-((((-217)) . T)) 
-(((|#2|) |has| |#2| (-1098))) 
-((((-856)) -1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) (((-1259 |#2|)) . T)) 
-(|has| |#2| (-848)) 
-(|has| |#1| (-848)) 
-(|has| |#1| (-848)) 
-((($) . T)) 
-((((-1152) (-57)) . T)) 
-(|has| |#1| (-848)) 
-((((-856)) . T)) 
-((((-572)) |has| (-413 |#2|) (-634 (-572))) (((-413 |#2|)) . T)) 
-((((-572) (-148)) . T)) 
-((((-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((|#1| |#2|) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-856)) . T)) 
-((((-911 |#1|)) . T)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) 
-(|has| |#1| (-846)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-846)) 
+(|has| |#1| (-867)) 
+(|has| |#1| (-867)) 
+((($) . T) (((-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1|) . T)) 
+((((-592) |#3|) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) |has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))))) 
+((($) . T)) 
+((((-433 $) (-433 $)) |has| |#2| (-582)) (($ $) . T) ((|#2| |#2|) . T)) 
+((((-191 (-237))) . T)) 
+((((-237)) . T)) 
+(((|#2|) |has| |#2| (-1119))) 
+((((-877)) -3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) (((-1280 |#2|)) . T)) 
+(|has| |#2| (-869)) 
+(|has| |#1| (-869)) 
+(|has| |#1| (-869)) 
+((($) . T)) 
+((((-1173) (-57)) . T)) 
+(|has| |#1| (-869)) 
+((((-877)) . T)) 
+((((-592)) |has| (-433 |#2|) (-654 (-592))) (((-433 |#2|)) . T)) 
+((((-592) (-168)) . T)) 
+((((-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((|#1| |#2|) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-877)) . T)) 
+((((-932 |#1|)) . T)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) 
+(|has| |#1| (-867)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-867)) 
 (((|#1|) . T) (($) . T)) 
-(|has| |#1| (-846)) 
-((((-1170)) |has| |#1| (-901 (-1170)))) 
-((((-863 |#1|)) . T)) 
-(((|#1| (-1170)) . T)) 
-(((|#1| (-1259 |#1|) (-1259 |#1|)) . T)) 
+(|has| |#1| (-867)) 
+((((-1191)) |has| |#1| (-922 (-1191)))) 
+((((-884 |#1|)) . T)) 
+(((|#1| (-1191)) . T)) 
+(((|#1| (-1280 |#1|) (-1280 |#1|)) . T)) 
 (((|#1| |#2|) . T)) 
 ((($ $) . T)) 
-(|has| |#1| (-1098)) 
-(((|#1| (-1170) (-819 (-1170)) (-538 (-819 (-1170)))) . T)) 
-((((-413 (-959 |#1|))) . T)) 
-((((-545)) . T)) 
-((((-856)) . T)) 
+(|has| |#1| (-1119)) 
+(((|#1| (-1191) (-840 (-1191)) (-558 (-840 (-1191)))) . T)) 
+((((-433 (-980 |#1|))) . T)) 
+((((-565)) . T)) 
+((((-877)) . T)) 
 ((($) . T)) 
 (((|#2|) . T) (($) . T)) 
-((((-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((|#1| |#2|) . T)) 
+((((-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-856)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+(((|#1|) |has| |#1| (-194))) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-877)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 (((|#3|) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910)))) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-545)) |has| |#1| (-613 (-545))) (((-893 (-385))) |has| |#1| (-613 (-893 (-385)))) (((-893 (-572))) |has| |#1| (-613 (-893 (-572))))) 
-((((-856)) . T)) 
-(((|#2|) . T) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(|has| |#2| (-846)) 
-(-12 (|has| |#2| (-227)) (|has| |#2| (-1054))) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-1144)) 
-((((-1152) |#1|) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-((((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) ((|#1| |#1|) . T)) 
-((((-413 (-572))) |has| |#1| (-1044 (-572))) (((-572)) |has| |#1| (-1044 (-572))) (((-1170)) |has| |#1| (-1044 (-1170))) ((|#1|) . T)) 
-((((-572) |#2|) . T)) 
-((((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T)) 
-((((-572)) |has| |#1| (-887 (-572))) (((-385)) |has| |#1| (-887 (-385)))) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) ((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-638 |#4|)) . T) (((-856)) . T)) 
-((((-545)) |has| |#4| (-613 (-545)))) 
-((((-545)) |has| |#4| (-613 (-545)))) 
-((((-856)) . T) (((-638 |#4|)) . T)) 
-((($) |has| |#1| (-846))) 
-(((|#1|) . T)) 
-(((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-174))) 
-((((-638 |#4|)) . T) (((-856)) . T)) 
-((((-545)) |has| |#4| (-613 (-545)))) 
-(((|#1|) . T)) 
-(((|#2|) . T)) 
-((((-1170)) |has| (-413 |#2|) (-901 (-1170)))) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-((((-572) (-1210) (-1210)) . T)) 
-((($) . T)) 
-((($) . T)) 
-(((|#2|) . T)) 
-((((-856)) -1841 (|has| |#3| (-25)) (|has| |#3| (-138)) (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-374)) (|has| |#3| (-722)) (|has| |#3| (-794)) (|has| |#3| (-846)) (|has| |#3| (-1054)) (|has| |#3| (-1098))) (((-1259 |#3|)) . T)) 
-((((-572) |#2|) . T)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#2| |#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054))) (($ $) |has| |#2| (-174))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((|#2|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-1152) (-1170) (-572) (-217) (-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-856)) . T)) 
-((((-572) (-121)) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-121)) . T)) 
-((((-121)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-121)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-856)) . T)) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) |has| |#1| (-1098))) 
-(((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-1054))) (($) |has| |#2| (-174))) 
-(|has| $ (-151)) 
-((((-413 |#2|)) . T)) 
-((((-413 (-572))) |has| (-413 |#2|) (-1044 (-413 (-572)))) (((-572)) |has| (-413 |#2|) (-1044 (-572))) (((-413 |#2|)) . T)) 
+(((|#1|) |has| |#1| (-194))) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931)))) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-565)) |has| |#1| (-633 (-565))) (((-914 (-405))) |has| |#1| (-633 (-914 (-405)))) (((-914 (-592))) |has| |#1| (-633 (-914 (-592))))) 
+((((-877)) . T)) 
+(((|#2|) . T) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(|has| |#2| (-867)) 
+(-12 (|has| |#2| (-247)) (|has| |#2| (-1075))) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-1165)) 
+((((-1173) |#1|) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+((((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) ((|#1| |#1|) . T)) 
+((((-433 (-592))) |has| |#1| (-1065 (-592))) (((-592)) |has| |#1| (-1065 (-592))) (((-1191)) |has| |#1| (-1065 (-1191))) ((|#1|) . T)) 
+((((-592) |#2|) . T)) 
+((((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T)) 
+((((-592)) |has| |#1| (-908 (-592))) (((-405)) |has| |#1| (-908 (-405)))) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) ((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-658 |#4|)) . T) (((-877)) . T)) 
+((((-565)) |has| |#4| (-633 (-565)))) 
+((((-565)) |has| |#4| (-633 (-565)))) 
+((((-877)) . T) (((-658 |#4|)) . T)) 
+((($) |has| |#1| (-867))) 
+(((|#1|) . T)) 
+(((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-194))) 
+((((-658 |#4|)) . T) (((-877)) . T)) 
+((((-565)) |has| |#4| (-633 (-565)))) 
+(((|#1|) . T)) 
+(((|#2|) . T)) 
+((((-1191)) |has| (-433 |#2|) (-922 (-1191)))) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+((((-592) (-1231) (-1231)) . T)) 
+((($) . T)) 
+((($) . T)) 
+(((|#2|) . T)) 
+((((-877)) -3836 (|has| |#3| (-25)) (|has| |#3| (-158)) (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-394)) (|has| |#3| (-743)) (|has| |#3| (-815)) (|has| |#3| (-867)) (|has| |#3| (-1075)) (|has| |#3| (-1119))) (((-1280 |#3|)) . T)) 
+((((-592) |#2|) . T)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#2| |#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075))) (($ $) |has| |#2| (-194))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((|#2|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-1173) (-1191) (-592) (-237) (-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-877)) . T)) 
+((((-592) (-141)) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-141)) . T)) 
+((((-141)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-141)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) |has| |#1| (-1119))) 
+(((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-1075))) (($) |has| |#2| (-194))) 
+(|has| $ (-171)) 
+((((-433 |#2|)) . T)) 
+((((-433 (-592))) |has| (-433 |#2|) (-1065 (-433 (-592)))) (((-592)) |has| (-433 |#2|) (-1065 (-592))) (((-433 |#2|)) . T)) 
 (((|#2| |#2|) . T)) 
-(((|#4|) |has| |#4| (-174))) 
-(|has| |#2| (-149)) 
-(|has| |#2| (-151)) 
-(((|#3|) |has| |#3| (-174))) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(|has| |#1| (-151)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(|has| |#1| (-151)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(|has| |#1| (-151)) 
-(((|#1|) . T)) 
-(((|#2|) . T)) 
-(|has| |#2| (-227)) 
-((((-1170) (-57)) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
+(((|#4|) |has| |#4| (-194))) 
+(|has| |#2| (-169)) 
+(|has| |#2| (-171)) 
+(((|#3|) |has| |#3| (-194))) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(|has| |#1| (-171)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(|has| |#1| (-171)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(|has| |#1| (-171)) 
+(((|#1|) . T)) 
+(((|#2|) . T)) 
+(|has| |#2| (-247)) 
+((((-1191) (-57)) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
 (((|#1| |#1|) . T)) 
-((((-1170)) |has| |#2| (-901 (-1170)))) 
-((((-572) (-121)) . T)) 
-(|has| |#1| (-562)) 
+((((-1191)) |has| |#2| (-922 (-1191)))) 
+((((-592) (-141)) . T)) 
+(|has| |#1| (-582)) 
 (((|#2|) . T)) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
 (((|#2| |#2|) . T)) 
 (((|#1| |#1|) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
 (((|#3|) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-545)) . T) (((-893 (-572))) . T) (((-385)) . T) (((-217)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-1006 |#1|)) . T) ((|#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-413 (-572))) . T) (((-413 |#1|)) . T) ((|#1|) . T) (($) . T)) 
-(((|#1| (-1166 |#1|)) . T)) 
-((((-572)) . T) (($) . T) (((-413 (-572))) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-565)) . T) (((-914 (-592))) . T) (((-405)) . T) (((-237)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-1027 |#1|)) . T) ((|#1|) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-433 (-592))) . T) (((-433 |#1|)) . T) ((|#1|) . T) (($) . T)) 
+(((|#1| (-1187 |#1|)) . T)) 
+((((-592)) . T) (($) . T) (((-433 (-592))) . T)) 
 (((|#3|) . T) (($) . T)) 
-(|has| |#1| (-848)) 
-(((|#2|) . T)) 
-((((-572)) . T) (($) . T) (((-413 (-572))) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-((((-572) |#2|) . T)) 
-((((-856)) |has| |#1| (-1098))) 
+(|has| |#1| (-869)) 
+(((|#2|) . T)) 
+((((-592)) . T) (($) . T) (((-433 (-592))) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+((((-592) |#2|) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#2|) . T)) 
+((((-592) |#3|) . T)) 
+(((|#2|) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-877)) . T)) 
+((((-1271 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+(((|#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(((|#3|) -12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) 
+(|has| |#1| (-1119)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+(((|#2| |#2|) . T)) 
 (((|#2|) . T)) 
-((((-572) |#3|) . T)) 
+(((|#1|) . T)) 
 (((|#2|) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-1250 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-856)) . T)) 
-(|has| |#1| (-1098)) 
-(((|#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(((|#3|) -12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
+(|has| |#2| (-388)) 
+(((|#2|) . T) (((-592)) |has| |#2| (-1065 (-592))) (((-433 (-592))) |has| |#2| (-1065 (-433 (-592))))) 
 (((|#2|) . T)) 
+((((-1103) |#2|) . T) (((-1103) $) . T) (($ $) . T)) 
+((((-1173) (-57)) . T)) 
+(((|#2|) |has| |#2| (-194))) 
+((((-592) |#3|) . T)) 
+((((-592) (-168)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-168)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-931)) 
+((((-141)) . T)) 
+(|has| |#1| (-171)) 
 (((|#1|) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-(((|#2| |#2|) . T)) 
-(((|#2|) . T)) 
-(|has| |#2| (-368)) 
-(((|#2|) . T) (((-572)) |has| |#2| (-1044 (-572))) (((-413 (-572))) |has| |#2| (-1044 (-413 (-572))))) 
-(((|#2|) . T)) 
-((((-1082) |#2|) . T) (((-1082) $) . T) (($ $) . T)) 
-((((-1152) (-57)) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-((((-572) |#3|) . T)) 
-((((-572) (-148)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-148)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-910)) 
-((((-121)) . T)) 
-(|has| |#1| (-151)) 
-(((|#1|) . T)) 
-(|has| |#1| (-149)) 
-((($) . T)) 
-((((-572)) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-151)) 
-((($) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) . T)) 
-(((|#2|) . T) (((-572)) |has| |#2| (-634 (-572)))) 
-(((|#1| (-780 |#1|)) . T)) 
-((((-856)) . T)) 
-((((-572)) |has| |#1| (-634 (-572))) ((|#1|) . T)) 
-((((-572)) |has| |#1| (-634 (-572))) ((|#1|) . T)) 
-((((-572)) |has| |#1| (-634 (-572))) ((|#1|) . T)) 
-((((-1152) (-57)) . T)) 
-(((|#1|) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+(|has| |#1| (-169)) 
+((($) . T)) 
+((((-592)) . T)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-171)) 
+((($) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) . T)) 
+(((|#2|) . T) (((-592)) |has| |#2| (-654 (-592)))) 
+(((|#1| (-801 |#1|)) . T)) 
+((((-877)) . T)) 
+((((-592)) |has| |#1| (-654 (-592))) ((|#1|) . T)) 
+((((-592)) |has| |#1| (-654 (-592))) ((|#1|) . T)) 
+((((-592)) |has| |#1| (-654 (-592))) ((|#1|) . T)) 
+((((-1173) (-57)) . T)) 
+(((|#1|) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 (((|#1| |#2|) . T)) 
-((((-572) (-148)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) ((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-((($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(|has| |#1| (-848)) 
-(((|#2| (-769) (-1082)) . T)) 
+((((-592) (-168)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) ((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+((($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(|has| |#1| (-869)) 
+(((|#2| (-790) (-1103)) . T)) 
 (((|#1| |#2|) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-(|has| |#1| (-792)) 
-(((|#1|) |has| |#1| (-174))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+(|has| |#1| (-813)) 
+(((|#1|) |has| |#1| (-194))) 
 (((|#4|) . T)) 
 (((|#4|) . T)) 
 (((|#1| |#2|) . T)) 
-(-1841 (|has| |#1| (-151)) (-12 (|has| |#1| (-368)) (|has| |#2| (-151)))) 
-(-1841 (|has| |#1| (-149)) (-12 (|has| |#1| (-368)) (|has| |#2| (-149)))) 
+(-3836 (|has| |#1| (-171)) (-12 (|has| |#1| (-388)) (|has| |#2| (-171)))) 
+(-3836 (|has| |#1| (-169)) (-12 (|has| |#1| (-388)) (|has| |#2| (-169)))) 
 (((|#4|) . T)) 
-(|has| |#1| (-149)) 
-((((-1152) |#1|) . T)) 
-(|has| |#1| (-151)) 
+(|has| |#1| (-169)) 
+((((-1173) |#1|) . T)) 
+(|has| |#1| (-171)) 
 (((|#1|) . T)) 
-((((-572)) . T)) 
-((((-856)) . T)) 
+((((-592)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-856)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+((((-877)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 (((|#3|) . T)) 
-((((-1250 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#1|) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-((((-856)) |has| |#1| (-1098)) (((-965 |#1|)) . T)) 
-(|has| |#1| (-846)) 
-(|has| |#1| (-846)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(|has| |#2| (-368)) 
-(((|#1|) |has| |#1| (-174))) 
-(((|#2|) |has| |#2| (-1054))) 
-((((-1152) |#1|) . T)) 
-(((|#3| |#3|) -12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) 
-(((|#2| (-894 |#1|)) . T)) 
-((($) . T)) 
-((($) -1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) ((|#2|) |has| |#2| (-174)) (((-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
-((((-394) (-1152)) . T)) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-856)) -1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) (((-1259 |#2|)) . T)) 
-((((-57)) . T) (((-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-((((-148)) . T)) 
-(|has| |#2| (-149)) 
-(|has| |#2| (-151)) 
-(|has| |#1| (-482)) 
-(-1841 (|has| |#1| (-482)) (|has| |#1| (-722)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054))) 
-(|has| |#1| (-368)) 
-((((-856)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-562))) 
-((($) |has| |#1| (-562))) 
-(|has| |#2| (-562)) 
-(|has| |#1| (-846)) 
-(|has| |#1| (-846)) 
-((((-856)) . T)) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) (((-1250 |#1| |#2| |#3|)) |has| |#1| (-368)) ((|#1|) |has| |#1| (-174))) 
-(((|#1|) |has| |#1| (-174)) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562)))) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
+((((-1271 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#1|) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-877)) |has| |#1| (-1119)) (((-986 |#1|)) . T)) 
+(|has| |#1| (-867)) 
+(|has| |#1| (-867)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#2| (-388)) 
+(((|#1|) |has| |#1| (-194))) 
+(((|#2|) |has| |#2| (-1075))) 
+((((-1173) |#1|) . T)) 
+(((|#3| |#3|) -12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) 
+(((|#2| (-915 |#1|)) . T)) 
+((($) . T)) 
+((($) -3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) ((|#2|) |has| |#2| (-194)) (((-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
+((((-414) (-1173)) . T)) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-877)) -3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) (((-1280 |#2|)) . T)) 
+((((-57)) . T) (((-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+((((-168)) . T)) 
+(|has| |#2| (-169)) 
+(|has| |#2| (-171)) 
+(|has| |#1| (-502)) 
+(-3836 (|has| |#1| (-502)) (|has| |#1| (-743)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075))) 
+(|has| |#1| (-388)) 
+((((-877)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-582))) 
+((($) |has| |#1| (-582))) 
+(|has| |#2| (-582)) 
+(|has| |#1| (-867)) 
+(|has| |#1| (-867)) 
+((((-877)) . T)) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) (((-1271 |#1| |#2| |#3|)) |has| |#1| (-388)) ((|#1|) |has| |#1| (-194))) 
+(((|#1|) |has| |#1| (-194)) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582)))) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
 (((|#1| |#2|) . T)) 
-((((-1170)) |has| |#1| (-901 (-1170)))) 
-((((-911 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-1098)) 
-(((|#2| (-497 (-4032 |#1|) (-769)) (-858 |#1|)) . T)) 
-((((-413 (-572))) |has| |#2| (-368)) (($) |has| |#2| (-368))) 
-(((|#1| (-538 (-1170)) (-1170)) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+((((-1191)) |has| |#1| (-922 (-1191)))) 
+((((-932 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-1119)) 
+(((|#2| (-517 (-1699 |#1|) (-790)) (-879 |#1|)) . T)) 
+((((-433 (-592))) |has| |#2| (-388)) (($) |has| |#2| (-388))) 
+(((|#1| (-558 (-1191)) (-1191)) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#3|) . T)) 
 (((|#3|) . T)) 
 (((|#1| |#1|) . T)) 
 (((|#1|) . T)) 
-(|has| |#2| (-174)) 
+(|has| |#2| (-194)) 
 (((|#1|) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#2| |#2|) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
 (((|#1|) . T)) 
 (((|#2|) . T)) 
-(((|#1|) . T) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
+(((|#1|) . T) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
 (((|#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) . T)) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-((((-1168 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-1170) (-57)) . T)) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+((((-1189 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-1191) (-57)) . T)) 
 ((($ $) . T)) 
-(((|#1| (-572)) . T)) 
-((((-911 |#1|)) . T)) 
-(((|#1|) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-1054))) (($) -1841 (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054)))) 
-(((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-(|has| |#1| (-848)) 
-(|has| |#1| (-848)) 
-((((-572) |#2|) . T)) 
-((((-572)) . T)) 
-((((-1250 |#1| |#2| |#3|)) -12 (|has| (-1250 |#1| |#2| |#3|) (-305 (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368)))) 
-(|has| |#1| (-848)) 
-((((-685 |#2|)) . T) (((-856)) . T)) 
+(((|#1| (-592)) . T)) 
+((((-932 |#1|)) . T)) 
+(((|#1|) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-1075))) (($) -3836 (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075)))) 
+(((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+(|has| |#1| (-869)) 
+(|has| |#1| (-869)) 
+((((-592) |#2|) . T)) 
+((((-592)) . T)) 
+((((-1271 |#1| |#2| |#3|)) -12 (|has| (-1271 |#1| |#2| |#3|) (-325 (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388)))) 
+(|has| |#1| (-869)) 
+((((-706 |#2|)) . T) (((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-413 (-959 |#1|))) . T)) 
-(((|#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(((|#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(((|#1|) |has| |#1| (-174))) 
-(((|#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(((|#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)))) 
-(|has| |#2| (-848)) 
-(|has| |#1| (-848)) 
-(-1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-910))) 
-(((|#1|) . T)) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-((((-572) |#2|) . T)) 
-(((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)))) 
-(|has| |#1| (-353)) 
-(((|#3| |#3|) -12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) 
-((($) . T) (((-413 (-572))) . T)) 
-((((-572) (-121)) . T)) 
-(|has| |#1| (-821)) 
-(|has| |#1| (-821)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-303)) (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(|has| |#1| (-846)) 
-(|has| |#1| (-846)) 
-(|has| |#1| (-846)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-572)) . T) (($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-1170)) |has| |#1| (-901 (-1170))) (((-1082)) . T)) 
-(((|#1|) . T)) 
-(|has| |#1| (-846)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) |has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(|has| |#1| (-1098)) 
+((((-433 (-980 |#1|))) . T)) 
+(((|#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(((|#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(((|#1|) |has| |#1| (-194))) 
+(((|#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(((|#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)))) 
+(|has| |#2| (-869)) 
+(|has| |#1| (-869)) 
+(-3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(((|#1|) . T)) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+((((-592) |#2|) . T)) 
+(((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)))) 
+(|has| |#1| (-373)) 
+(((|#3| |#3|) -12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) 
+((($) . T) (((-433 (-592))) . T)) 
+((((-592) (-141)) . T)) 
+(|has| |#1| (-842)) 
+(|has| |#1| (-842)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-323)) (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(|has| |#1| (-867)) 
+(|has| |#1| (-867)) 
+(|has| |#1| (-867)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-592)) . T) (($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-1191)) |has| |#1| (-922 (-1191))) (((-1103)) . T)) 
+(((|#1|) . T)) 
+(|has| |#1| (-867)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) |has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#1| (-1119)) 
 (((|#1|) . T)) 
 (((|#2| |#2|) . T)) 
 (((|#1|) . T)) 
-(((|#1| |#2| |#3| (-234 |#2| |#3|) (-234 |#1| |#3|)) . T)) 
+(((|#1| |#2| |#3| (-254 |#2| |#3|) (-254 |#1| |#3|)) . T)) 
 (((|#1|) . T)) 
 (((|#3| |#3|) . T)) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
-(((|#1| (-538 |#2|) |#2|) . T)) 
-((((-856)) . T)) 
-(((|#1| (-769) (-1082)) . T)) 
+(((|#1| (-558 |#2|) |#2|) . T)) 
+((((-877)) . T)) 
+(((|#1| (-790) (-1103)) . T)) 
 (((|#3|) . T)) 
 (((|#1|) . T)) 
-((((-148)) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) 
+((((-168)) . T)) 
+(((|#2|) |has| |#2| (-194))) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) 
 (((|#1|) . T)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(|has| |#3| (-174)) 
-(((|#4|) |has| |#4| (-368))) 
-(((|#3|) |has| |#3| (-368))) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(|has| |#3| (-194)) 
+(((|#4|) |has| |#4| (-388))) 
+(((|#3|) |has| |#3| (-388))) 
 (((|#1|) . T)) 
-(((|#2|) |has| |#1| (-368))) 
+(((|#2|) |has| |#1| (-388))) 
 (((|#2|) . T)) 
-(((|#1| (-1166 |#1|)) . T)) 
-((((-1082)) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) . T)) 
+(((|#1| (-1187 |#1|)) . T)) 
+((((-1103)) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) . T)) 
 (((|#2|) . T)) 
-((((-1168 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-((($) |has| |#1| (-846))) 
-(|has| |#1| (-910)) 
-((((-856)) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+((((-1189 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+((($) |has| |#1| (-867))) 
+(|has| |#1| (-931)) 
+((((-877)) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) |has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))))) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-910))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-910))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) |has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))))) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
 (((|#1|) . T) (($) . T)) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
 (((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(((|#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)))) 
-(|has| |#1| (-848)) 
-(|has| |#1| (-562)) 
-((((-585 |#1|)) . T)) 
+(((|#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)))) 
+(|has| |#1| (-869)) 
+(|has| |#1| (-582)) 
+((((-605 |#1|)) . T)) 
 ((($) . T)) 
 (((|#2|) . T)) 
-(-1841 (-12 (|has| |#1| (-368)) (|has| |#2| (-821))) (-12 (|has| |#1| (-368)) (|has| |#2| (-848)))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-((((-911 |#1|)) . T)) 
-(((|#1| (-509 |#1| |#3|) (-509 |#1| |#2|)) . T)) 
+(-3836 (-12 (|has| |#1| (-388)) (|has| |#2| (-842))) (-12 (|has| |#1| (-388)) (|has| |#2| (-869)))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+((((-932 |#1|)) . T)) 
+(((|#1| (-529 |#1| |#3|) (-529 |#1| |#2|)) . T)) 
 (((|#1| |#4| |#5|) . T)) 
-(((|#1| (-769)) . T)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-562))) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) (((-1168 |#1| |#2| |#3|)) |has| |#1| (-368)) ((|#1|) |has| |#1| (-174))) 
-(((|#1|) |has| |#1| (-174)) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562)))) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-((((-413 |#2|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-667 |#1|)) . T)) 
+(((|#1| (-790)) . T)) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-582))) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) (((-1189 |#1| |#2| |#3|)) |has| |#1| (-388)) ((|#1|) |has| |#1| (-194))) 
+(((|#1|) |has| |#1| (-194)) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582)))) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+((((-433 |#2|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-688 |#1|)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-((((-545)) . T)) 
-((((-856)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-856)) . T)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) |has| |#2| (-174)) (($) -1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#2|) . T)) 
-(-1841 (|has| |#3| (-25)) (|has| |#3| (-138)) (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-374)) (|has| |#3| (-722)) (|has| |#3| (-794)) (|has| |#3| (-846)) (|has| |#3| (-1054)) (|has| |#3| (-1098))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-((((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T)) 
-(|has| |#1| (-1190)) 
-(|has| |#1| (-1190)) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) 
-(|has| |#1| (-1190)) 
-(|has| |#1| (-1190)) 
+((((-565)) . T)) 
+((((-877)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-877)) . T)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) |has| |#2| (-194)) (($) -3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#2|) . T)) 
+(-3836 (|has| |#3| (-25)) (|has| |#3| (-158)) (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-394)) (|has| |#3| (-743)) (|has| |#3| (-815)) (|has| |#3| (-867)) (|has| |#3| (-1075)) (|has| |#3| (-1119))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+((((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T)) 
+(|has| |#1| (-1211)) 
+(|has| |#1| (-1211)) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) 
+(|has| |#1| (-1211)) 
+(|has| |#1| (-1211)) 
 (((|#3| |#3|) . T)) 
-((((-572)) . T) (($) . T) (((-413 (-572))) . T)) 
-((($) . T) (((-413 (-572))) . T) (((-413 |#1|)) . T) ((|#1|) . T)) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T) (((-413 |#1|) (-413 |#1|)) . T) ((|#1| |#1|) . T)) 
+((((-592)) . T) (($) . T) (((-433 (-592))) . T)) 
+((($) . T) (((-433 (-592))) . T) (((-433 |#1|)) . T) ((|#1|) . T)) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T) (((-433 |#1|) (-433 |#1|)) . T) ((|#1| |#1|) . T)) 
 (((|#3|) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-1152) (-57)) . T)) 
-(|has| |#1| (-1098)) 
-(-1841 (|has| |#2| (-821)) (|has| |#2| (-848))) 
-(((|#1|) . T)) 
-(((|#1|) |has| |#1| (-174)) (($) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) (((-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1|) . T)) 
-((($) . T)) 
-((((-1168 |#1| |#2| |#3|)) -12 (|has| (-1168 |#1| |#2| |#3|) (-305 (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368)))) 
-((((-856)) . T)) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-((($) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-910))) 
-(|has| |#2| (-910)) 
-(|has| |#1| (-368)) 
-(((|#2|) |has| |#2| (-1098))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-1173) (-57)) . T)) 
+(|has| |#1| (-1119)) 
+(-3836 (|has| |#2| (-842)) (|has| |#2| (-869))) 
+(((|#1|) . T)) 
+(((|#1|) |has| |#1| (-194)) (($) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) (((-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1|) . T)) 
+((($) . T)) 
+((((-1189 |#1| |#2| |#3|)) -12 (|has| (-1189 |#1| |#2| |#3|) (-325 (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388)))) 
+((((-877)) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((($) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(|has| |#2| (-931)) 
+(|has| |#1| (-388)) 
+(((|#2|) |has| |#2| (-1119))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
 ((($) . T) ((|#2|) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-910))) 
-((((-545)) . T) (((-413 (-1166 (-572)))) . T) (((-217)) . T) (((-385)) . T)) 
-((((-385)) . T) (((-217)) . T) (((-856)) . T)) 
-(|has| |#1| (-910)) 
-(|has| |#1| (-910)) 
-(|has| |#1| (-910)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-(((|#1|) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-(|has| (-171 (-217)) (-848)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-931))) 
+((((-565)) . T) (((-433 (-1187 (-592)))) . T) (((-237)) . T) (((-405)) . T)) 
+((((-405)) . T) (((-237)) . T) (((-877)) . T)) 
+(|has| |#1| (-931)) 
+(|has| |#1| (-931)) 
+(|has| |#1| (-931)) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+(((|#1|) . T)) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+(|has| (-191 (-237)) (-869)) 
 ((($ $) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(|has| |#1| (-368)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(|has| |#1| (-388)) 
 ((($ $) . T)) 
-((((-572) (-121)) . T)) 
+((((-592) (-141)) . T)) 
 ((($) . T)) 
-(|has| |#2| (-562)) 
+(|has| |#2| (-582)) 
 (((|#1|) . T)) 
-((((-121)) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) 
-((((-572)) . T)) 
-(((|#1| (-572)) . T)) 
+((((-141)) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) 
+((((-592)) . T)) 
+(((|#1| (-592)) . T)) 
 ((($) . T)) 
-(((|#2|) . T) (((-572)) |has| |#2| (-634 (-572)))) 
-((((-572)) |has| |#1| (-634 (-572))) ((|#1|) . T)) 
+(((|#2|) . T) (((-592)) |has| |#2| (-654 (-592)))) 
+((((-592)) |has| |#1| (-654 (-592))) ((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-572)) . T)) 
+((((-592)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-1170)) |has| |#1| (-1054))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-856)) . T)) 
-(((|#1| (-769)) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1| (-572)) . T)) 
-(((|#1| (-1250 |#1| |#2| |#3|)) . T)) 
-(((|#1|) . T)) 
-(((|#1| (-413 (-572))) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-856)) . T)) 
-(((|#1| (-1222 |#1| |#2| |#3|)) . T)) 
-(|has| |#1| (-1098)) 
-(((|#1| (-769)) . T)) 
-(((|#1|) . T)) 
-((((-1152) |#1|) . T)) 
-((($) . T)) 
-(|has| |#2| (-151)) 
-(|has| |#2| (-149)) 
-(((|#1| (-538 (-819 (-1170))) (-819 (-1170))) . T)) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T)) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T)) 
-(((|#1|) |has| |#1| (-1054))) 
-((((-572) (-121)) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-(|has| |#2| (-174)) 
-((((-572)) . T)) 
-(|has| |#2| (-846)) 
-(((|#1|) . T)) 
-((((-572)) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-353))) 
-(|has| |#1| (-151)) 
-((((-856)) . T)) 
+((((-1191)) |has| |#1| (-1075))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-877)) . T)) 
+(((|#1| (-790)) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1| (-592)) . T)) 
+(((|#1| (-1271 |#1| |#2| |#3|)) . T)) 
+(((|#1|) . T)) 
+(((|#1| (-433 (-592))) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-877)) . T)) 
+(((|#1| (-1243 |#1| |#2| |#3|)) . T)) 
+(|has| |#1| (-1119)) 
+(((|#1| (-790)) . T)) 
+(((|#1|) . T)) 
+((((-1173) |#1|) . T)) 
+((($) . T)) 
+(|has| |#2| (-171)) 
+(|has| |#2| (-169)) 
+(((|#1| (-558 (-840 (-1191))) (-840 (-1191))) . T)) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T)) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T)) 
+(((|#1|) |has| |#1| (-1075))) 
+((((-592) (-141)) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+(|has| |#2| (-194)) 
+((((-592)) . T)) 
+(|has| |#2| (-867)) 
+(((|#1|) . T)) 
+((((-592)) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-373))) 
+(|has| |#1| (-171)) 
+((((-877)) . T)) 
 (((|#3|) . T)) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-((((-856)) . T)) 
-((((-1243 |#2| |#3| |#4|)) . T) (((-1244 |#1| |#2| |#3| |#4|)) . T)) 
-((((-856)) . T)) 
-((((-53)) -12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572)))) (((-611 $)) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) -1841 (-12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572)))) (|has| |#1| (-1044 (-413 (-572))))) (((-413 (-959 |#1|))) |has| |#1| (-562)) (((-959 |#1|)) |has| |#1| (-1054)) (((-1170)) . T)) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+((((-877)) . T)) 
+((((-1264 |#2| |#3| |#4|)) . T) (((-1265 |#1| |#2| |#3| |#4|)) . T)) 
+((((-877)) . T)) 
+((((-53)) -12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592)))) (((-631 $)) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) -3836 (-12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592)))) (|has| |#1| (-1065 (-433 (-592))))) (((-433 (-980 |#1|))) |has| |#1| (-582)) (((-980 |#1|)) |has| |#1| (-1075)) (((-1191)) . T)) 
 (((|#1|) . T) (($) . T)) 
-(((|#1| (-769)) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#1|) |has| |#1| (-174))) 
-(((|#1|) |has| |#1| (-305 |#1|))) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T)) 
-((((-572)) |has| |#1| (-887 (-572))) (((-385)) |has| |#1| (-887 (-385)))) 
-(((|#1|) . T)) 
-(|has| |#1| (-562)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-(((|#1|) |has| |#1| (-174))) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) 
-(((|#1|) . T)) 
-(((|#3|) |has| |#3| (-1098))) 
-(((|#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-368)))) 
-((((-1243 |#2| |#3| |#4|)) . T)) 
-((((-121)) . T)) 
-(|has| |#1| (-821)) 
-(|has| |#1| (-821)) 
-(((|#1| (-572) (-1082)) . T)) 
-((($) |has| |#1| (-305 $)) ((|#1|) |has| |#1| (-305 |#1|))) 
-(|has| |#1| (-846)) 
-(|has| |#1| (-846)) 
-(((|#1| (-769) (-1082)) . T)) 
-(-1841 (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-1170)) . T)) 
-(((|#1| (-572) (-1082)) . T)) 
-(((|#1| (-413 (-572)) (-1082)) . T)) 
-(((|#1| (-769) (-1082)) . T)) 
-(|has| |#1| (-848)) 
-((((-911 |#1|) (-911 |#1|)) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(|has| |#2| (-149)) 
-(|has| |#2| (-151)) 
-(((|#2|) . T)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-1098)) 
-((((-911 |#1|)) . T) (($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-1098)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-(|has| |#1| (-1098)) 
-((((-572)) -12 (|has| |#1| (-368)) (|has| |#2| (-634 (-572)))) ((|#2|) |has| |#1| (-368))) 
-(((|#2|) |has| |#2| (-1054))) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) 
-(((|#2|) |has| |#2| (-174))) 
-(((|#1|) |has| |#1| (-174))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-((((-856)) . T)) 
-(|has| |#3| (-846)) 
-((((-856)) . T)) 
-((((-1243 |#2| |#3| |#4|) (-316 |#2| |#3| |#4|)) . T)) 
-((((-856)) . T)) 
-(((|#1| |#1|) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-1054)))) 
-(((|#1|) . T)) 
-((((-572)) . T)) 
-((((-856)) . T)) 
-((((-572)) . T)) 
-((((-740 |#1| |#2|)) . T) (((-611 $)) . T) ((|#2|) . T) (((-572)) . T) (((-413 (-572))) -1841 (-12 (|has| |#2| (-562)) (|has| |#2| (-1044 (-572)))) (|has| |#2| (-1044 (-413 (-572))))) (((-413 (-959 |#2|))) |has| |#2| (-562)) (((-959 |#2|)) |has| |#2| (-1054)) (((-1170)) . T)) 
-(((|#1|) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-1054)))) 
-(((|#2|) |has| |#2| (-368))) 
-((((-572)) |has| |#2| (-887 (-572))) (((-385)) |has| |#2| (-887 (-385)))) 
-(((|#2|) . T)) 
-(|has| |#1| (-848)) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-368))) 
-(((|#2|) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(((|#1| (-769)) . T)) 
-(((|#2|) . T)) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) |has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-910))) 
-(((|#2|) . T) (((-572)) |has| |#2| (-634 (-572)))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-545)) . T) (((-572)) . T) (((-893 (-572))) . T) (((-385)) . T) (((-217)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-572)) . T) (($) . T) (((-413 (-572))) . T)) 
-((((-572)) . T) (($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-227)) 
-(((|#1|) . T)) 
-(((|#1| (-572)) . T)) 
-(|has| |#1| (-846)) 
-(((|#1| (-1168 |#1| |#2| |#3|)) . T)) 
+(((|#1| (-790)) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#1|) |has| |#1| (-194))) 
+(((|#1|) |has| |#1| (-325 |#1|))) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T)) 
+((((-592)) |has| |#1| (-908 (-592))) (((-405)) |has| |#1| (-908 (-405)))) 
+(((|#1|) . T)) 
+(|has| |#1| (-582)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+(((|#1|) |has| |#1| (-194))) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) 
+(((|#1|) . T)) 
+(((|#3|) |has| |#3| (-1119))) 
+(((|#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-388)))) 
+((((-1264 |#2| |#3| |#4|)) . T)) 
+((((-141)) . T)) 
+(|has| |#1| (-842)) 
+(|has| |#1| (-842)) 
+(((|#1| (-592) (-1103)) . T)) 
+((($) |has| |#1| (-325 $)) ((|#1|) |has| |#1| (-325 |#1|))) 
+(|has| |#1| (-867)) 
+(|has| |#1| (-867)) 
+(((|#1| (-790) (-1103)) . T)) 
+(-3836 (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-1191)) . T)) 
+(((|#1| (-592) (-1103)) . T)) 
+(((|#1| (-433 (-592)) (-1103)) . T)) 
+(((|#1| (-790) (-1103)) . T)) 
+(|has| |#1| (-869)) 
+((((-932 |#1|) (-932 |#1|)) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(|has| |#2| (-169)) 
+(|has| |#2| (-171)) 
+(((|#2|) . T)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-1119)) 
+((((-932 |#1|)) . T) (($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-1119)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+(|has| |#1| (-1119)) 
+((((-592)) -12 (|has| |#1| (-388)) (|has| |#2| (-654 (-592)))) ((|#2|) |has| |#1| (-388))) 
+(((|#2|) |has| |#2| (-1075))) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) 
+(((|#2|) |has| |#2| (-194))) 
+(((|#1|) |has| |#1| (-194))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+((((-877)) . T)) 
+(|has| |#3| (-867)) 
+((((-877)) . T)) 
+((((-1264 |#2| |#3| |#4|) (-336 |#2| |#3| |#4|)) . T)) 
+((((-877)) . T)) 
+(((|#1| |#1|) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-1075)))) 
+(((|#1|) . T)) 
+((((-592)) . T)) 
+((((-877)) . T)) 
+((((-592)) . T)) 
+((((-761 |#1| |#2|)) . T) (((-631 $)) . T) ((|#2|) . T) (((-592)) . T) (((-433 (-592))) -3836 (-12 (|has| |#2| (-582)) (|has| |#2| (-1065 (-592)))) (|has| |#2| (-1065 (-433 (-592))))) (((-433 (-980 |#2|))) |has| |#2| (-582)) (((-980 |#2|)) |has| |#2| (-1075)) (((-1191)) . T)) 
+(((|#1|) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-1075)))) 
+(((|#2|) |has| |#2| (-388))) 
+((((-592)) |has| |#2| (-908 (-592))) (((-405)) |has| |#2| (-908 (-405)))) 
+(((|#2|) . T)) 
+(|has| |#1| (-869)) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-388))) 
+(((|#2|) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(((|#1| (-790)) . T)) 
+(((|#2|) . T)) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) |has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(((|#2|) . T) (((-592)) |has| |#2| (-654 (-592)))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-565)) . T) (((-592)) . T) (((-914 (-592))) . T) (((-405)) . T) (((-237)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-592)) . T) (($) . T) (((-433 (-592))) . T)) 
+((((-592)) . T) (($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-247)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(((|#1|) . T)) 
+(|has| |#1| (-867)) 
+(((|#1| (-592)) . T)) 
 (((|#1| |#1|) . T)) 
 (((|#1| |#1|) . T)) 
 (((|#1|) . T)) 
+(((|#1| (-1189 |#1| |#2| |#3|)) . T)) 
 (((|#1|) . T)) 
-(((|#1| (-413 (-572))) . T)) 
-(((|#1| (-1160 |#1| |#2| |#3|)) . T)) 
-(((|#1| (-769)) . T)) 
+(((|#1| (-433 (-592))) . T)) 
+(((|#1| (-1181 |#1| |#2| |#3|)) . T)) 
+(((|#1| (-790)) . T)) 
+(((|#1| |#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) . T)) 
 (((|#1|) . T)) 
-(((|#1| |#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
 (((|#1| |#2|) . T)) 
-((((-148)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-856)) |has| |#1| (-1098))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-(|has| (-413 |#2|) (-227)) 
-(|has| |#1| (-910)) 
-(((|#2|) |has| |#2| (-1054))) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-(|has| |#1| (-368)) 
-(((|#1|) |has| |#1| (-174))) 
+((((-168)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-877)) |has| |#1| (-1119))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(|has| (-433 |#2|) (-247)) 
+(|has| |#1| (-931)) 
+(((|#2|) |has| |#2| (-1075))) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+(|has| |#1| (-388)) 
+(((|#1|) |has| |#1| (-194))) 
 (((|#1| |#1|) . T)) 
-((((-870 |#1|)) . T)) 
-((((-856)) . T)) 
+((((-891 |#1|)) . T)) 
+((((-877)) . T)) 
 (((|#1|) . T)) 
-(((|#2|) |has| |#2| (-1098))) 
-(|has| |#2| (-848)) 
+(((|#2|) |has| |#2| (-1119))) 
+(|has| |#2| (-869)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-368)) 
-((((-413 (-572))) . T) (((-572)) . T) (((-611 $)) . T)) 
+(|has| |#1| (-388)) 
+((((-433 (-592))) . T) (((-592)) . T) (((-631 $)) . T)) 
 (((|#1|) . T)) 
-((((-856)) . T)) 
+((((-877)) . T)) 
 ((($) . T)) 
-(|has| |#1| (-848)) 
-((((-856)) . T)) 
-(((|#1| (-538 |#2|) |#2|) . T)) 
-(((|#1| (-572) (-1082)) . T)) 
-((((-911 |#1|)) . T)) 
-((((-856)) . T)) 
+(|has| |#1| (-869)) 
+((((-877)) . T)) 
+(((|#1| (-558 |#2|) |#2|) . T)) 
+(((|#1| (-592) (-1103)) . T)) 
+((((-932 |#1|)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
-(((|#1| (-413 (-572)) (-1082)) . T)) 
-(((|#1| (-769) (-1082)) . T)) 
-((((-413 |#2|) (-413 |#2|)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-(((|#1|) . T) (((-572)) -1841 (|has| (-413 (-572)) (-1044 (-572))) (|has| |#1| (-1044 (-572)))) (((-413 (-572))) . T)) 
-(((|#1| (-603 |#1| |#3|) (-603 |#1| |#2|)) . T)) 
-(((|#1|) |has| |#1| (-174))) 
+(((|#1| (-433 (-592)) (-1103)) . T)) 
+(((|#1| (-790) (-1103)) . T)) 
+((((-433 |#2|) (-433 |#2|)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+(((|#1|) . T) (((-592)) -3836 (|has| (-433 (-592)) (-1065 (-592))) (|has| |#1| (-1065 (-592)))) (((-433 (-592))) . T)) 
+(((|#1| (-623 |#1| |#3|) (-623 |#1| |#2|)) . T)) 
+(((|#1|) |has| |#1| (-194))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-413 |#2|)) . T) (((-413 (-572))) . T) (($) . T)) 
-(|has| |#2| (-227)) 
-(((|#2| (-538 (-858 |#1|)) (-858 |#1|)) . T)) 
-((($) -1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) ((|#2|) |has| |#2| (-174)) (((-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
-((((-856)) . T)) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-856)) . T)) 
+((((-433 |#2|)) . T) (((-433 (-592))) . T) (($) . T)) 
+(|has| |#2| (-247)) 
+(((|#2| (-558 (-879 |#1|)) (-879 |#1|)) . T)) 
+((($) -3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) ((|#2|) |has| |#2| (-194)) (((-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
+((((-877)) . T)) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-877)) . T)) 
 (((|#1| |#3|) . T)) 
-((((-856)) . T)) 
-(|has| |#2| (-1144)) 
-(((|#1|) |has| |#1| (-174))) 
-((((-694)) . T)) 
-((((-694)) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-(|has| |#2| (-846)) 
-((((-121)) |has| |#1| (-1098)) (((-856)) -1841 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-482)) (|has| |#1| (-722)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054)) (|has| |#1| (-1110)) (|has| |#1| (-1098)))) 
+((((-877)) . T)) 
+(|has| |#2| (-1165)) 
+(((|#1|) |has| |#1| (-194))) 
+((((-715)) . T)) 
+((((-715)) . T)) 
+(((|#2|) |has| |#2| (-194))) 
+(|has| |#2| (-867)) 
+((((-141)) |has| |#1| (-1119)) (((-877)) -3836 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-502)) (|has| |#1| (-743)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075)) (|has| |#1| (-1131)) (|has| |#1| (-1119)))) 
 (((|#1|) . T) (($) . T)) 
 (((|#1| |#2|) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-572) |#1|) . T)) 
-((((-694)) . T) (((-413 (-572))) . T) (((-572)) . T)) 
-(((|#2|) . T)) 
-(((|#1| |#1|) |has| |#1| (-174))) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-((((-385)) . T)) 
-((((-694)) . T)) 
-((((-413 (-572))) |has| |#2| (-368)) (($) |has| |#2| (-368))) 
-(((|#1|) |has| |#1| (-174))) 
-((((-413 (-959 |#1|))) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-592) |#1|) . T)) 
+((((-715)) . T) (((-433 (-592))) . T) (((-592)) . T)) 
+(((|#2|) . T)) 
+(((|#1| |#1|) |has| |#1| (-194))) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+((((-405)) . T)) 
+((((-715)) . T)) 
+((((-433 (-592))) |has| |#2| (-388)) (($) |has| |#2| (-388))) 
+(((|#1|) |has| |#1| (-194))) 
+((((-433 (-980 |#1|))) . T)) 
 (((|#2| |#2|) . T)) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((($) . T)) 
-(((|#2|) . T)) 
-(|has| |#2| (-848)) 
-(((|#3|) |has| |#3| (-1054))) 
-(|has| |#2| (-910)) 
-(|has| |#1| (-910)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-848)) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-((((-1170)) |has| |#2| (-901 (-1170)))) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-482)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-368)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-482)) (|has| |#1| (-562)) (|has| |#1| (-1054)) (|has| |#1| (-1110))) 
-((((-125 |#1|)) . T)) 
-((((-125 |#1|)) . T)) 
-((((-148)) . T)) 
-(|has| |#1| (-353)) 
-((((-1170)) |has| |#1| (-901 (-1170))) (((-1082)) . T)) 
-((($) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(((|#2|) . T) (((-856)) . T)) 
-(((|#2|) . T) (((-856)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-171 (-217)) (-146) (-146)) . T)) 
-((((-217) (-220) (-220)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-848)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((($) . T)) 
+(((|#2|) . T)) 
+(|has| |#2| (-869)) 
+(((|#3|) |has| |#3| (-1075))) 
+(|has| |#2| (-931)) 
+(|has| |#1| (-931)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-869)) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+((((-1191)) |has| |#2| (-922 (-1191)))) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(|has| |#1| (-502)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-388)) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-502)) (|has| |#1| (-582)) (|has| |#1| (-1075)) (|has| |#1| (-1131))) 
+((((-145 |#1|)) . T)) 
+((((-145 |#1|)) . T)) 
+((((-168)) . T)) 
+(|has| |#1| (-373)) 
+((((-1191)) |has| |#1| (-922 (-1191))) (((-1103)) . T)) 
+((($) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-582)) 
+(((|#2|) . T) (((-877)) . T)) 
+(((|#2|) . T) (((-877)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-191 (-237)) (-166) (-166)) . T)) 
+((((-237) (-240) (-240)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-869)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
 (((|#1| |#2|) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) ((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) ((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
 (((|#3|) . T)) 
-((((-125 |#1|)) . T)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-848)) 
-(((|#2|) . T) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T)) 
-((((-125 |#1|)) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-(((|#1|) . T)) 
-((((-572)) . T)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-((((-856)) . T)) 
-((((-1082)) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-545)) |has| |#1| (-613 (-545))) (((-893 (-572))) |has| |#1| (-613 (-893 (-572)))) (((-893 (-385))) |has| |#1| (-613 (-893 (-385)))) (((-385)) |has| |#1| (-1028)) (((-217)) |has| |#1| (-1028))) 
-(((|#1|) |has| |#1| (-368))) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((($ $) . T) (((-611 $) $) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-((($) . T) (((-1244 |#1| |#2| |#3| |#4|)) . T) (((-413 (-572))) . T)) 
-((($) -1841 (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-562)) (|has| |#1| (-1054))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-562))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-((((-385)) . T) (((-572)) . T) (((-413 (-572))) . T)) 
-((((-638 (-781 |#1| (-858 |#2|)))) . T) (((-856)) . T)) 
-((((-545)) |has| (-781 |#1| (-858 |#2|)) (-613 (-545)))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-385)) . T)) 
-(((|#3|) -12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) 
-((((-856)) . T)) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-910))) 
-(((|#1|) . T)) 
-(|has| |#1| (-848)) 
-(|has| |#1| (-848)) 
-((((-856)) |has| |#1| (-1098))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-(|has| |#1| (-1098)) 
-((((-856)) . T)) 
-(((|#1| (-769)) . T)) 
-((((-413 (-572))) . T) (((-572)) . T) (((-611 $)) . T)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-((((-572)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-((((-1243 |#2| |#3| |#4|)) . T) (((-413 (-572))) |has| (-1243 |#2| |#3| |#4|) (-43 (-413 (-572)))) (($) . T)) 
-((((-572)) . T)) 
-(|has| |#2| (-482)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-368)) 
-(-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-151)) (|has| |#1| (-368))) (|has| |#1| (-151))) 
-(-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-149)) (|has| |#1| (-368))) (|has| |#1| (-149))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-227)) 
-(|has| |#1| (-368)) 
+((((-145 |#1|)) . T)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-869)) 
+(((|#2|) . T) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T)) 
+((((-145 |#1|)) . T)) 
+(((|#2|) |has| |#2| (-194))) 
+(((|#1|) . T)) 
+((((-592)) . T)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+((((-877)) . T)) 
+((((-1103)) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565))) (((-914 (-592))) |has| |#1| (-633 (-914 (-592)))) (((-914 (-405))) |has| |#1| (-633 (-914 (-405)))) (((-405)) |has| |#1| (-1049)) (((-237)) |has| |#1| (-1049))) 
+(((|#1|) |has| |#1| (-388))) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((($ $) . T) (((-631 $) $) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+((($) . T) (((-1265 |#1| |#2| |#3| |#4|)) . T) (((-433 (-592))) . T)) 
+((($) -3836 (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-582)) (|has| |#1| (-1075))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-582))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+((((-405)) . T) (((-592)) . T) (((-433 (-592))) . T)) 
+((((-658 (-802 |#1| (-879 |#2|)))) . T) (((-877)) . T)) 
+((((-565)) |has| (-802 |#1| (-879 |#2|)) (-633 (-565)))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-405)) . T)) 
+(((|#3|) -12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) 
+((((-877)) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(((|#1|) . T)) 
+(|has| |#1| (-869)) 
+(|has| |#1| (-869)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+(|has| |#1| (-1119)) 
+((((-877)) . T)) 
+(((|#1| (-790)) . T)) 
+((((-433 (-592))) . T) (((-592)) . T) (((-631 $)) . T)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+((((-592)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+((((-1264 |#2| |#3| |#4|)) . T) (((-433 (-592))) |has| (-1264 |#2| |#3| |#4|) (-43 (-433 (-592)))) (($) . T)) 
+((((-592)) . T)) 
+(|has| |#2| (-502)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-388)) 
+(-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-171)) (|has| |#1| (-388))) (|has| |#1| (-171))) 
+(-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-169)) (|has| |#1| (-388))) (|has| |#1| (-169))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-247)) 
+(|has| |#1| (-388)) 
 (((|#3|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-151)) 
-((((-572)) |has| |#2| (-634 (-572))) ((|#2|) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) (($) . T)) 
-(((|#2|) . T)) 
-(|has| |#1| (-1098)) 
+(|has| |#2| (-582)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-592)) |has| |#2| (-654 (-592))) ((|#2|) . T)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) (($) . T)) 
+(((|#2|) . T)) 
+(|has| |#1| (-1119)) 
 (((|#1| |#2|) . T)) 
-((((-171 (-217))) . T)) 
-((((-217)) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-634 (-572)))) 
-(((|#3|) |has| |#3| (-174))) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) 
-((((-572)) . T)) 
-(((|#1| $) |has| |#1| (-283 |#1| |#1|))) 
-((((-413 (-572))) . T) (($) . T) (((-413 |#1|)) . T) ((|#1|) . T)) 
-((((-856)) . T)) 
+((((-191 (-237))) . T)) 
+((((-237)) . T)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-654 (-592)))) 
+(((|#3|) |has| |#3| (-194))) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) 
+((((-592)) . T)) 
+(((|#1| $) |has| |#1| (-303 |#1| |#1|))) 
+((((-433 (-592))) . T) (($) . T) (((-433 |#1|)) . T) ((|#1|) . T)) 
+((((-877)) . T)) 
 (((|#3|) . T)) 
-(((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-287)) (|has| |#1| (-368))) (((-413 (-572)) (-413 (-572))) |has| |#1| (-368))) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-((($) . T)) 
-((($) . T) ((|#2|) |has| |#2| (-174)) (((-413 (-572))) |has| |#2| (-562))) 
-((((-572) |#1|) . T)) 
-((((-1170)) |has| (-413 |#2|) (-901 (-1170)))) 
-(((|#1|) . T) (($) -1841 (|has| |#1| (-287)) (|has| |#1| (-368))) (((-413 (-572))) |has| |#1| (-368))) 
-((((-545)) |has| |#2| (-613 (-545)))) 
-((((-685 |#2|)) . T) (((-856)) . T)) 
-(((|#1|) . T)) 
-(((|#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(((|#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-((((-870 |#1|)) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(-1841 (|has| |#4| (-794)) (|has| |#4| (-846))) 
-(-1841 (|has| |#3| (-794)) (|has| |#3| (-846))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(((|#2|) |has| |#2| (-1054))) 
-((((-572)) . T)) 
-(((|#1|) . T)) 
-((((-572)) . T)) 
-((((-413 |#2|)) . T)) 
-(((|#1|) . T)) 
-(((|#3|) -12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) 
-((((-572) |#1|) . T)) 
-(((|#1|) . T)) 
-((($) . T)) 
-((((-572)) . T) (($) . T) (((-413 (-572))) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-1214))) 
-((($) . T)) 
-((((-413 (-572))) |has| (-413 |#2|) (-1044 (-413 (-572)))) (((-572)) |has| (-413 |#2|) (-1044 (-572))) (((-413 |#2|)) . T)) 
-(((|#2|) . T) (((-572)) |has| |#2| (-634 (-572)))) 
-(((|#1| (-769)) . T)) 
-(|has| |#1| (-848)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-634 (-572)))) 
-((((-572)) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) (((-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1|) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) |has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(|has| |#1| (-846)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-353)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
+(((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-307)) (|has| |#1| (-388))) (((-433 (-592)) (-433 (-592))) |has| |#1| (-388))) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+((($) . T)) 
+((($) . T) ((|#2|) |has| |#2| (-194)) (((-433 (-592))) |has| |#2| (-582))) 
+((((-592) |#1|) . T)) 
+((((-1191)) |has| (-433 |#2|) (-922 (-1191)))) 
+(((|#1|) . T) (($) -3836 (|has| |#1| (-307)) (|has| |#1| (-388))) (((-433 (-592))) |has| |#1| (-388))) 
+((((-565)) |has| |#2| (-633 (-565)))) 
+((((-706 |#2|)) . T) (((-877)) . T)) 
+(((|#1|) . T)) 
+(((|#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(((|#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+((((-891 |#1|)) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(-3836 (|has| |#4| (-815)) (|has| |#4| (-867))) 
+(-3836 (|has| |#3| (-815)) (|has| |#3| (-867))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(((|#2|) |has| |#2| (-1075))) 
+((((-592)) . T)) 
+(((|#1|) . T)) 
+((((-592)) . T)) 
+((((-433 |#2|)) . T)) 
+(((|#1|) . T)) 
+(((|#3|) -12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) 
+((((-592) |#1|) . T)) 
+(((|#1|) . T)) 
+((($) . T)) 
+((((-592)) . T) (($) . T) (((-433 (-592))) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-1235))) 
+((($) . T)) 
+((((-433 (-592))) |has| (-433 |#2|) (-1065 (-433 (-592)))) (((-592)) |has| (-433 |#2|) (-1065 (-592))) (((-433 |#2|)) . T)) 
+(((|#2|) . T) (((-592)) |has| |#2| (-654 (-592)))) 
+(((|#1| (-790)) . T)) 
+(|has| |#1| (-869)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-654 (-592)))) 
+((((-592)) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) (((-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1|) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) |has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#1| (-867)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-373)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
 (((|#2|) . T)) 
 (((|#1| |#2|) . T)) 
-((((-148)) . T)) 
-((((-781 |#1| (-858 |#2|))) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-(|has| |#1| (-1190)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#3| (-25)) (|has| |#3| (-138)) (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-374)) (|has| |#3| (-722)) (|has| |#3| (-794)) (|has| |#3| (-846)) (|has| |#3| (-1054)) (|has| |#3| (-1098))) 
-((((-1170) |#1|) |has| |#1| (-527 (-1170) |#1|))) 
-(((|#2|) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-911 |#1|)) . T)) 
-((($) . T)) 
-((((-413 (-959 |#1|))) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#4| (-613 (-545)))) 
-((((-856)) . T) (((-638 |#4|)) . T)) 
-(|has| |#1| (-846)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(|has| |#1| (-1098)) 
-(((|#1|) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) |has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))))) 
-(((|#2|) . T)) 
-(|has| |#1| (-368)) 
-((((-572) (-572)) . T)) 
-(|has| |#1| (-848)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#1|) |has| |#1| (-174))) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-151)) (|has| |#1| (-368))) (|has| |#1| (-151))) 
-(-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-149)) (|has| |#1| (-368))) (|has| |#1| (-149))) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-((((-856)) |has| |#1| (-1098))) 
-((((-1250 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-(|has| |#1| (-846)) 
+((((-168)) . T)) 
+((((-802 |#1| (-879 |#2|))) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+(|has| |#1| (-1211)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#3| (-25)) (|has| |#3| (-158)) (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-394)) (|has| |#3| (-743)) (|has| |#3| (-815)) (|has| |#3| (-867)) (|has| |#3| (-1075)) (|has| |#3| (-1119))) 
+((((-1191) |#1|) |has| |#1| (-547 (-1191) |#1|))) 
+(((|#2|) . T)) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-932 |#1|)) . T)) 
+((($) . T)) 
+((((-433 (-980 |#1|))) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#1| (-867)) 
+((((-565)) |has| |#4| (-633 (-565)))) 
+(|has| |#1| (-1119)) 
+((((-877)) . T) (((-658 |#4|)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(((|#2|) . T)) 
+(|has| |#1| (-388)) 
+(((|#1|) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) |has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))))) 
+((((-592) (-592)) . T)) 
+(|has| |#1| (-869)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#1|) |has| |#1| (-194))) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-171)) (|has| |#1| (-388))) (|has| |#1| (-171))) 
+(-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-169)) (|has| |#1| (-388))) (|has| |#1| (-169))) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-1271 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+(|has| |#1| (-867)) 
 (((|#1| |#2|) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-634 (-572)))) 
-((((-572)) |has| |#1| (-634 (-572))) ((|#1|) . T)) 
-((((-911 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-1098)) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T) (((-572)) . T)) 
-(|has| |#2| (-149)) 
-(|has| |#2| (-151)) 
-((((-911 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#2| (-769) (-1082)) . T)) 
-(|has| |#1| (-1098)) 
-(((|#2|) |has| |#2| (-174))) 
+(((|#1|) . T) (((-592)) |has| |#1| (-654 (-592)))) 
+((((-592)) |has| |#1| (-654 (-592))) ((|#1|) . T)) 
+((((-932 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+(|has| |#1| (-1119)) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T) (((-592)) . T)) 
+(|has| |#2| (-169)) 
+(|has| |#2| (-171)) 
+((((-932 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#2| (-790) (-1103)) . T)) 
+(|has| |#1| (-1119)) 
+(((|#2|) |has| |#2| (-194))) 
 (((|#2|) . T)) 
 (((|#1| |#1|) . T)) 
-(((|#3|) |has| |#3| (-368))) 
-((((-413 |#2|)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((|#1| |#1|) |has| |#1| (-305 |#1|))) 
-(((|#1|) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)))) 
-((((-312 |#1|)) . T)) 
-(((|#2|) |has| |#2| (-368))) 
-(((|#2|) . T)) 
-((((-413 (-572))) . T) (((-694)) . T) (($) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) |has| (-781 |#1| (-858 |#2|)) (-305 (-781 |#1| (-858 |#2|))))) 
-((((-858 |#1|)) . T)) 
-(((|#2|) |has| |#2| (-174))) 
-(((|#1|) |has| |#1| (-174))) 
-(((|#2|) . T)) 
-((((-1170)) |has| |#1| (-901 (-1170))) (((-1082)) . T)) 
-((((-1170)) |has| |#1| (-901 (-1170))) (((-1087 (-1170))) . T)) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(((|#4|) |has| |#4| (-1054)) (((-572)) -12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054)))) 
-(((|#3|) |has| |#3| (-1054)) (((-572)) -12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054)))) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
+(((|#3|) |has| |#3| (-388))) 
+((((-433 |#2|)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((|#1| |#1|) |has| |#1| (-325 |#1|))) 
+(((|#1|) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)))) 
+((((-332 |#1|)) . T)) 
+(((|#2|) |has| |#2| (-388))) 
+(((|#2|) . T)) 
+((((-433 (-592))) . T) (((-715)) . T) (($) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) |has| (-802 |#1| (-879 |#2|)) (-325 (-802 |#1| (-879 |#2|))))) 
+((((-879 |#1|)) . T)) 
+(|has| |#1| (-388)) 
+(((|#2|) |has| |#2| (-194))) 
+(((|#1|) |has| |#1| (-194))) 
+(((|#2|) . T)) 
+((((-1191)) |has| |#1| (-922 (-1191))) (((-1103)) . T)) 
+((((-1191)) |has| |#1| (-922 (-1191))) (((-1108 (-1191))) . T)) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(((|#4|) |has| |#4| (-1075)) (((-592)) -12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075)))) 
+(((|#3|) |has| |#3| (-1075)) (((-592)) -12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075)))) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
 ((($ $) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-482)) (|has| |#1| (-722)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054)) (|has| |#1| (-1110)) (|has| |#1| (-1098))) 
-(|has| |#1| (-562)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-502)) (|has| |#1| (-743)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075)) (|has| |#1| (-1131)) (|has| |#1| (-1119))) 
+(|has| |#1| (-582)) 
 (((|#2|) . T)) 
-((((-856)) . T)) 
-((((-545)) . T)) 
-((((-572)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
+((((-877)) . T)) 
+((((-565)) . T)) 
+((((-592)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
 (((|#1|) . T)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-562)) (|has| |#1| (-1054))) 
-((((-585 |#1|)) . T)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-582)) (|has| |#1| (-1075))) 
+((((-605 |#1|)) . T)) 
 ((($) . T)) 
 (((|#1| (-64 |#1|) (-64 |#1|)) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 ((($) . T)) 
 (((|#1|) . T)) 
-((((-856)) . T)) 
-(((|#2|) |has| |#2| (-6 (-4604 "*")))) 
+((((-877)) . T)) 
+(((|#2|) |has| |#2| (-6 (-4627 "*")))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-413 (-572))) |has| |#2| (-1044 (-413 (-572)))) (((-572)) |has| |#2| (-1044 (-572))) ((|#2|) . T) (((-858 |#1|)) . T)) 
-((($) . T) (((-125 |#1|)) . T) (((-413 (-572))) . T)) 
-((((-1121 |#1| |#2|)) . T) ((|#2|) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-((((-1166 |#1|)) . T) (((-1082)) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-((((-1121 |#1| (-1170))) . T) (((-1087 (-1170))) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-1170)) . T)) 
-(|has| |#1| (-1098)) 
+((((-433 (-592))) |has| |#2| (-1065 (-433 (-592)))) (((-592)) |has| |#2| (-1065 (-592))) ((|#2|) . T) (((-879 |#1|)) . T)) 
+((($) . T) (((-145 |#1|)) . T) (((-433 (-592))) . T)) 
+((((-1142 |#1| |#2|)) . T) ((|#2|) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+((((-1187 |#1|)) . T) (((-1103)) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+((((-1142 |#1| (-1191))) . T) (((-1108 (-1191))) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-1191)) . T)) 
+(|has| |#1| (-1119)) 
 ((($) . T)) 
-(|has| |#1| (-1098)) 
-((((-572)) -12 (|has| |#1| (-887 (-572))) (|has| |#2| (-887 (-572)))) (((-385)) -12 (|has| |#1| (-887 (-385))) (|has| |#2| (-887 (-385))))) 
+(|has| |#1| (-1119)) 
+((((-592)) -12 (|has| |#1| (-908 (-592))) (|has| |#2| (-908 (-592)))) (((-405)) -12 (|has| |#1| (-908 (-405))) (|has| |#2| (-908 (-405))))) 
 (((|#1| |#2|) . T)) 
-((((-1170) |#1|) . T)) 
+((((-1191) |#1|) . T)) 
 (((|#4|) . T)) 
 (((|#1|) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-((((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T)) 
-((((-1170) (-57)) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-374)) (|has| |#2| (-722)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054)) (|has| |#2| (-1098))) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-1243 |#2| |#3| |#4|) (-316 |#2| |#3| |#4|)) . T)) 
-((((-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-(((|#1| |#1|) |has| |#1| (-174)) (((-413 (-572)) (-413 (-572))) |has| |#1| (-562)) (($ $) |has| |#1| (-562))) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-910)) 
-(((|#1| $) |has| |#1| (-283 |#1| |#1|))) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-562)) (($) |has| |#1| (-562))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#3|) |has| |#3| (-368))) 
-(|has| |#1| (-15 * (|#1| (-769) |#1|))) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-((((-1170)) . T)) 
-(((|#1|) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-(-1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-910))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+((((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T)) 
+((((-1191) (-57)) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-394)) (|has| |#2| (-743)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075)) (|has| |#2| (-1119))) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+(((|#1| |#1|) |has| |#1| (-194)) (((-433 (-592)) (-433 (-592))) |has| |#1| (-582)) (($ $) |has| |#1| (-582))) 
+((((-1264 |#2| |#3| |#4|) (-336 |#2| |#3| |#4|)) . T)) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-931)) 
+(((|#1| $) |has| |#1| (-303 |#1| |#1|))) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-582)) (($) |has| |#1| (-582))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#3|) |has| |#3| (-388))) 
+(|has| |#1| (-15 * (|#1| (-790) |#1|))) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+((((-1191)) . T)) 
+(((|#1|) . T)) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+(-3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-931))) 
 (((|#2| |#3|) . T)) 
-((((-572) (-572)) . T)) 
-(((|#1| (-538 |#2|)) . T)) 
-(((|#1| (-769)) . T)) 
-((((-572) (-572)) . T)) 
-(((|#1| (-538 (-1087 (-1170)))) . T)) 
-((((-572)) . T)) 
-(-1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(((|#1|) . T)) 
-(|has| |#2| (-910)) 
-(((|#1|) |has| |#1| (-174))) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-((((-856)) . T)) 
-((($ $) . T) (((-1243 |#2| |#3| |#4|) (-1243 |#2| |#3| |#4|)) . T) (((-413 (-572)) (-413 (-572))) |has| (-1243 |#2| |#3| |#4|) (-43 (-413 (-572))))) 
-((((-911 |#1|)) . T)) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-821))) 
-((($) . T) (((-413 (-572))) . T)) 
-((($) . T)) 
-((($) . T)) 
-(|has| |#1| (-368)) 
-(-1841 (|has| |#1| (-303)) (|has| |#1| (-368)) (|has| |#1| (-353)) (|has| |#1| (-562))) 
-(|has| |#1| (-368)) 
-((($) . T) (((-1243 |#2| |#3| |#4|)) . T) (((-413 (-572))) |has| (-1243 |#2| |#3| |#4|) (-43 (-413 (-572))))) 
+((((-592) (-592)) . T)) 
+(((|#1| (-558 |#2|)) . T)) 
+(((|#1| (-790)) . T)) 
+((((-592) (-592)) . T)) 
+(((|#1| (-558 (-1108 (-1191)))) . T)) 
+((((-592)) . T)) 
+(-3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(((|#1|) . T)) 
+(|has| |#2| (-931)) 
+(((|#1|) |has| |#1| (-194))) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+((((-877)) . T)) 
+((($ $) . T) (((-1264 |#2| |#3| |#4|) (-1264 |#2| |#3| |#4|)) . T) (((-433 (-592)) (-433 (-592))) |has| (-1264 |#2| |#3| |#4|) (-43 (-433 (-592))))) 
+((((-932 |#1|)) . T)) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-842))) 
+((($) . T) (((-433 (-592))) . T)) 
+((($) . T)) 
+((($) . T)) 
+(|has| |#1| (-388)) 
+(-3836 (|has| |#1| (-323)) (|has| |#1| (-388)) (|has| |#1| (-373)) (|has| |#1| (-582))) 
+(|has| |#1| (-388)) 
+((($) . T) (((-1264 |#2| |#3| |#4|)) . T) (((-433 (-592))) |has| (-1264 |#2| |#3| |#4|) (-43 (-433 (-592))))) 
 (((|#1| |#2|) . T)) 
-(|has| |#2| (-562)) 
-((((-1168 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-(-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(-1841 (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054))) 
-((((-572)) |has| |#1| (-634 (-572))) ((|#1|) . T)) 
-((((-572) (-572)) . T)) 
+(|has| |#2| (-582)) 
+((((-1189 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+(-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(-3836 (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075))) 
+((((-592)) |has| |#1| (-654 (-592))) ((|#1|) . T)) 
+((((-592) (-592)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-121)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-141)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-413 |#2|)) . T) (((-413 (-572))) . T) (($) . T)) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-433 |#2|)) . T) (((-433 (-592))) . T) (($) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-(((|#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|))) . T)) 
-(|has| |#2| (-368)) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(|has| |#1| (-848)) 
+(((|#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|))) . T)) 
+(|has| |#2| (-388)) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(|has| |#1| (-869)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-1098)) 
+((((-877)) . T)) 
+(|has| |#1| (-1119)) 
 (((|#4|) . T)) 
 (((|#4|) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-413 $) (-413 $)) |has| |#1| (-562)) (($ $) . T) ((|#1| |#1|) . T)) 
-(((|#2| |#2|) |has| |#2| (-174)) (((-413 (-572)) (-413 (-572))) |has| |#2| (-562)) (($ $) . T)) 
-(|has| |#2| (-821)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-433 $) (-433 $)) |has| |#1| (-582)) (($ $) . T) ((|#1| |#1|) . T)) 
+(((|#2| |#2|) |has| |#2| (-194)) (((-433 (-592)) (-433 (-592))) |has| |#2| (-582)) (($ $) . T)) 
+(|has| |#2| (-842)) 
 (((|#4|) . T)) 
 ((($) . T)) 
-(((|#2|) |has| |#2| (-174)) (((-413 (-572))) |has| |#2| (-562)) (($) . T)) 
-((((-856)) . T)) 
-(((|#1| (-538 (-1170))) . T)) 
+(((|#2|) |has| |#2| (-194)) (((-433 (-592))) |has| |#2| (-582)) (($) . T)) 
+((((-877)) . T)) 
+(((|#1| (-558 (-1191))) . T)) 
 ((($ $) . T)) 
-((($) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-((((-856)) . T)) 
-(((|#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(((|#2|) -1841 (|has| |#2| (-6 (-4604 "*"))) (|has| |#2| (-174)))) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-572) (-1206) (-1206)) . T)) 
-(|has| |#2| (-848)) 
-(|has| |#2| (-910)) 
-((((-572)) . T)) 
-(|has| |#1| (-910)) 
-(((|#2|) |has| |#2| (-174))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-1250 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-545)) . T) (((-572)) . T) (((-893 (-572))) . T) (((-385)) . T) (((-217)) . T)) 
+(((|#1|) |has| |#1| (-194))) 
+((($) . T)) 
+((((-877)) . T)) 
+(((|#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(((|#2|) -3836 (|has| |#2| (-6 (-4627 "*"))) (|has| |#2| (-194)))) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-592) (-1227) (-1227)) . T)) 
+(|has| |#2| (-869)) 
+(|has| |#2| (-931)) 
+((((-592)) . T)) 
+(|has| |#1| (-931)) 
+(((|#2|) |has| |#2| (-194))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-1271 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-565)) . T) (((-592)) . T) (((-914 (-592))) . T) (((-405)) . T) (((-237)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) . T)) 
 (((|#1|) . T)) 
-((((-866)) . T) (((-572)) . T) (((-413 (-572))) . T)) 
-((((-413 (-572))) . T) (((-572)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+((((-887)) . T) (((-592)) . T) (((-433 (-592))) . T)) 
+((((-433 (-592))) . T) (((-592)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-856)) . T)) 
-(((|#1| (-413 (-572))) . T)) 
+((((-877)) . T)) 
+(((|#1| (-433 (-592))) . T)) 
 (((|#1|) . T)) 
-((((-545)) . T)) 
-(-1841 (|has| |#1| (-287)) (|has| |#1| (-368))) 
-((((-148)) . T)) 
-((((-413 |#2|)) . T) (((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-846)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| |#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) . T)) 
+((((-565)) . T)) 
+(-3836 (|has| |#1| (-307)) (|has| |#1| (-388))) 
+((((-168)) . T)) 
+((((-433 |#2|)) . T) (((-433 (-592))) . T) (($) . T)) 
+(|has| |#1| (-867)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| |#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-856)) . T)) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
 (((|#2| |#2|) . T) ((|#1| |#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-545)) |has| |#1| (-613 (-545))) (((-893 (-572))) |has| |#1| (-613 (-893 (-572)))) (((-893 (-385))) |has| |#1| (-613 (-893 (-385))))) 
-((((-1170) (-57)) . T)) 
-(((|#2|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-638 (-148))) . T) (((-1152)) . T)) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-((((-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((|#1| |#1|) |has| |#1| (-305 |#1|))) 
-(|has| |#1| (-848)) 
-((((-856)) . T)) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) . T)) 
-(((|#2|) |has| |#2| (-368))) 
-((((-856)) . T)) 
-((((-545)) |has| |#4| (-613 (-545)))) 
-((((-856)) . T) (((-638 |#4|)) . T)) 
-(((|#2|) . T)) 
-((((-911 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-(-1841 (|has| |#4| (-174)) (|has| |#4| (-722)) (|has| |#4| (-846)) (|has| |#4| (-1054))) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-722)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-((((-1170) (-57)) . T)) 
-((((-572)) . T)) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-572) (-572)) . T)) 
-(((|#1|) . T)) 
-((((-572)) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(|has| |#1| (-910)) 
-(|has| |#1| (-910)) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-((((-572)) . T)) 
-(((|#2|) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-572)) . T)) 
-((((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#1| (-413 (-572)) (-1082)) . T)) 
-(|has| |#1| (-1098)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(|has| |#1| (-821)) 
-((((-856)) |has| |#1| (-1098))) 
-((((-911 |#1|) (-911 |#1|)) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-((((-413 |#2|)) . T)) 
-((((-572) (-572)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-846)) 
-((((-856)) |has| |#1| (-1098))) 
-(((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) . T) (((-572) (-572)) . T) (($ $) . T)) 
-((((-911 |#1|)) . T) (($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-174)) 
-(((|#2|) |has| |#2| (-1054)) (((-572)) -12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) 
-(|has| |#2| (-151)) 
-(|has| |#2| (-149)) 
-(((|#1|) . T) (((-413 (-572))) . T) (((-572)) . T) (($) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565))) (((-914 (-592))) |has| |#1| (-633 (-914 (-592)))) (((-914 (-405))) |has| |#1| (-633 (-914 (-405))))) 
+((((-1191) (-57)) . T)) 
+(((|#2|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-658 (-168))) . T) (((-1173)) . T)) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+((((-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((|#1| |#1|) |has| |#1| (-325 |#1|))) 
+(|has| |#1| (-869)) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) . T)) 
+(((|#2|) |has| |#2| (-388))) 
+((((-877)) . T)) 
+((((-565)) |has| |#4| (-633 (-565)))) 
+((((-877)) . T) (((-658 |#4|)) . T)) 
+(((|#2|) . T)) 
+((((-932 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+(-3836 (|has| |#4| (-194)) (|has| |#4| (-743)) (|has| |#4| (-867)) (|has| |#4| (-1075))) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-743)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+((((-1191) (-57)) . T)) 
+((((-592)) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-592) (-592)) . T)) 
+(((|#1|) . T)) 
+((((-592)) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(|has| |#1| (-931)) 
+(|has| |#1| (-931)) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+((((-592)) . T)) 
+(((|#2|) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-592)) . T)) 
+((((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#1| (-433 (-592)) (-1103)) . T)) 
+(|has| |#1| (-1119)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(|has| |#1| (-842)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-932 |#1|) (-932 |#1|)) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+((((-433 |#2|)) . T)) 
+((((-592) (-592)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-867)) 
+((((-877)) |has| |#1| (-1119))) 
+(((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) . T) (((-592) (-592)) . T) (($ $) . T)) 
+((((-932 |#1|)) . T) (($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-194)) 
+(((|#2|) |has| |#2| (-1075)) (((-592)) -12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) 
+(|has| |#2| (-171)) 
+(|has| |#2| (-169)) 
+(((|#1|) . T) (((-433 (-592))) . T) (((-592)) . T) (($) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-(((|#2|) . T)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-((((-57)) . T) (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-(|has| |#1| (-353)) 
-((((-572)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-545)) |has| |#2| (-613 (-545))) (((-893 (-572))) |has| |#2| (-613 (-893 (-572)))) (((-893 (-385))) |has| |#2| (-613 (-893 (-385))))) 
-((((-1244 |#1| |#2| |#3| |#4|) $) |has| (-1244 |#1| |#2| |#3| |#4|) (-283 (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|)))) 
-(|has| |#1| (-368)) 
-((((-1082) |#1|) . T) (((-1082) $) . T) (($ $) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-((((-413 (-572)) (-413 (-572))) . T) (((-694) (-694)) . T) (($ $) . T)) 
-((((-312 |#1|)) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-368))) 
-(|has| |#1| (-1098)) 
-(((|#1|) . T)) 
-(((|#1|) -1841 (|has| |#2| (-372 |#1|)) (|has| |#2| (-423 |#1|)))) 
-(((|#1|) -1841 (|has| |#2| (-372 |#1|)) (|has| |#2| (-423 |#1|)))) 
-(((|#2|) . T)) 
-((((-413 (-572))) . T) (((-694)) . T) (($) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+(((|#2|) . T)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+((((-57)) . T) (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+(|has| |#1| (-373)) 
+((((-592)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-565)) |has| |#2| (-633 (-565))) (((-914 (-592))) |has| |#2| (-633 (-914 (-592)))) (((-914 (-405))) |has| |#2| (-633 (-914 (-405))))) 
+((((-1265 |#1| |#2| |#3| |#4|) $) |has| (-1265 |#1| |#2| |#3| |#4|) (-303 (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|)))) 
+(|has| |#1| (-388)) 
+((((-1103) |#1|) . T) (((-1103) $) . T) (($ $) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+((((-433 (-592)) (-433 (-592))) . T) (((-715) (-715)) . T) (($ $) . T)) 
+((((-332 |#1|)) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-388))) 
+(|has| |#1| (-1119)) 
+(((|#1|) -3836 (|has| |#2| (-392 |#1|)) (|has| |#2| (-443 |#1|)))) 
+(((|#1|) -3836 (|has| |#2| (-392 |#1|)) (|has| |#2| (-443 |#1|)))) 
+(((|#2|) . T)) 
+(((|#1|) . T)) 
+((((-433 (-592))) . T) (((-715)) . T) (($) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
 (((|#3| |#3|) . T)) 
-((((-572) (-1208) (-1208)) . T)) 
-((((-572)) . T)) 
-(|has| |#2| (-227)) 
-((((-858 |#1|)) . T)) 
-((((-1170)) |has| |#1| (-901 (-1170))) ((|#3|) . T)) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-1028))) 
-((((-1168 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-((((-856)) . T)) 
-(((|#1| (-769)) . T)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-((((-413 (-572))) . T) (($) . T) (((-413 |#1|)) . T) ((|#1|) . T)) 
-((((-572)) . T)) 
-(|has| |#1| (-1098)) 
+((((-592) (-1229) (-1229)) . T)) 
+((((-592)) . T)) 
+(|has| |#2| (-247)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-931))) 
+((((-879 |#1|)) . T)) 
+((((-1191)) |has| |#1| (-922 (-1191))) ((|#3|) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-1049))) 
+((((-1189 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+((((-877)) . T)) 
+(((|#1| (-790)) . T)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+((((-433 (-592))) . T) (($) . T) (((-433 |#1|)) . T) ((|#1|) . T)) 
+((((-592)) . T)) 
+(|has| |#1| (-1119)) 
 (((|#3|) . T)) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
-((((-572)) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(((|#2|) . T) (((-572)) |has| |#2| (-634 (-572)))) 
+((((-592)) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(((|#2|) . T) (((-592)) |has| |#2| (-654 (-592)))) 
 (((|#1| |#2|) . T)) 
 ((($) . T)) 
-((((-585 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
+((((-605 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
 ((($ $) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#1|) . T) (($) . T)) 
-(((|#1| (-1259 |#1|) (-1259 |#1|)) . T)) 
+(((|#1| (-1280 |#1|) (-1280 |#1|)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-125 |#1|) (-125 |#1|)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((((-413 (-572))) |has| |#2| (-1044 (-413 (-572)))) (((-572)) |has| |#2| (-1044 (-572))) ((|#2|) . T) (((-858 |#1|)) . T)) 
-((((-1121 |#1| |#2|)) . T) ((|#3|) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((|#2|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-145 |#1|) (-145 |#1|)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+((((-433 (-592))) |has| |#2| (-1065 (-433 (-592)))) (((-592)) |has| |#2| (-1065 (-592))) ((|#2|) . T) (((-879 |#1|)) . T)) 
+((((-1142 |#1| |#2|)) . T) ((|#3|) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((|#2|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 ((($ $) . T)) 
-((((-667 |#1|)) . T)) 
-((($) . T) (((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) . T)) 
-((((-125 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-572)) -12 (|has| |#1| (-887 (-572))) (|has| |#3| (-887 (-572)))) (((-385)) -12 (|has| |#1| (-887 (-385))) (|has| |#3| (-887 (-385))))) 
+((((-688 |#1|)) . T)) 
+((($) . T) (((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) . T)) 
+((((-145 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-592)) -12 (|has| |#1| (-908 (-592))) (|has| |#3| (-908 (-592)))) (((-405)) -12 (|has| |#1| (-908 (-405))) (|has| |#3| (-908 (-405))))) 
 (((|#2|) . T) ((|#6|) . T)) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) (($) . T)) 
-((((-148)) . T)) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) (($) . T)) 
+((((-168)) . T)) 
 ((($) . T)) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
 (((|#1|) . T)) 
-(|has| |#2| (-910)) 
-(|has| |#1| (-910)) 
-(|has| |#1| (-910)) 
+(|has| |#2| (-931)) 
+(|has| |#1| (-931)) 
+(|has| |#1| (-931)) 
 (((|#4|) . T)) 
-(|has| |#2| (-1028)) 
+(|has| |#2| (-1049)) 
 ((($) . T)) 
-(|has| |#1| (-910)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-572)) . T)) 
+(|has| |#1| (-931)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-592)) . T)) 
 ((($) . T)) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
 (((|#1|) . T) (($) . T)) 
 ((($) . T)) 
-(|has| |#1| (-368)) 
-((((-911 |#1|)) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(-1841 (|has| |#1| (-374)) (|has| |#1| (-848))) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) 
-((((-413 |#2|) |#3|) . T)) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) 
-((($) . T) (((-413 (-572))) . T)) 
-((((-769) |#1|) . T)) 
-(((|#2| (-234 (-4032 |#1|) (-769))) . T)) 
-(((|#1| (-538 |#3|)) . T)) 
-((((-413 (-572))) . T)) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) |has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))))) 
-(|has| |#1| (-910)) 
-(|has| |#2| (-368)) 
-(-1841 (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(((|#1|) . T)) 
-((((-171 (-385))) . T) (((-217)) . T) (((-385)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((((-385)) . T) (((-572)) . T)) 
-((((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
+(|has| |#1| (-388)) 
+((((-932 |#1|)) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(-3836 (|has| |#1| (-394)) (|has| |#1| (-869))) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) 
+((((-433 |#2|) |#3|) . T)) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) 
+((($) . T) (((-433 (-592))) . T)) 
+((((-790) |#1|) . T)) 
+(((|#2| (-254 (-1699 |#1|) (-790))) . T)) 
+(((|#1| (-558 |#3|)) . T)) 
+((((-433 (-592))) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) |has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))))) 
+(|has| |#1| (-931)) 
+(|has| |#2| (-388)) 
+(-3836 (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(((|#1|) . T)) 
+((((-191 (-405))) . T) (((-237)) . T) (((-405)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+((((-405)) . T) (((-592)) . T)) 
+((((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
 ((($ $) . T)) 
 ((($ $) . T)) 
 (((|#1| |#1|) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-562)) 
-((((-413 (-572))) . T) (($) . T)) 
-((($) . T)) 
-((($) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(-1841 (|has| |#1| (-303)) (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(-12 (|has| |#1| (-554)) (|has| |#1| (-829))) 
-((((-856)) . T)) 
-((((-1170)) -1841 (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))) (-12 (|has| |#1| (-368)) (|has| |#2| (-901 (-1170)))))) 
-(|has| |#1| (-368)) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) 
-(|has| |#1| (-368)) 
-(((|#1|) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((($) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T)) 
-((((-572) |#1|) . T)) 
-(((|#1|) . T)) 
-(((|#2|) |has| |#1| (-368))) 
-(((|#2|) |has| |#1| (-368))) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(((|#1|) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-(((|#1|) . T)) 
-(((|#2|) . T) (((-1170)) -12 (|has| |#1| (-368)) (|has| |#2| (-1044 (-1170)))) (((-572)) -12 (|has| |#1| (-368)) (|has| |#2| (-1044 (-572)))) (((-413 (-572))) -12 (|has| |#1| (-368)) (|has| |#2| (-1044 (-572))))) 
-(((|#2|) . T)) 
-((((-1170) (-1244 |#1| |#2| |#3| |#4|)) |has| (-1244 |#1| |#2| |#3| |#4|) (-527 (-1170) (-1244 |#1| |#2| |#3| |#4|))) (((-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|)) |has| (-1244 |#1| |#2| |#3| |#4|) (-305 (-1244 |#1| |#2| |#3| |#4|)))) 
-((((-611 $) $) . T) (($ $) . T)) 
-((((-171 (-217))) . T) (((-171 (-385))) . T) (((-1166 (-694))) . T) (((-893 (-385))) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-562)) 
-(|has| (-413 |#2|) (-227)) 
-(((|#1| (-413 (-572))) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-582)) 
+((((-433 (-592))) . T) (($) . T)) 
+((($) . T)) 
+((($) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(-3836 (|has| |#1| (-323)) (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(-12 (|has| |#1| (-574)) (|has| |#1| (-850))) 
+((((-877)) . T)) 
+((((-1191)) -3836 (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))) (-12 (|has| |#1| (-388)) (|has| |#2| (-922 (-1191)))))) 
+(|has| |#1| (-388)) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) 
+(|has| |#1| (-388)) 
+(((|#1|) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((($) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T)) 
+((((-592) |#1|) . T)) 
+(((|#1|) . T)) 
+(((|#2|) |has| |#1| (-388))) 
+(((|#2|) |has| |#1| (-388))) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(((|#1|) . T)) 
+(((|#1|) |has| |#1| (-194))) 
+(((|#1|) . T)) 
+(((|#2|) . T) (((-1191)) -12 (|has| |#1| (-388)) (|has| |#2| (-1065 (-1191)))) (((-592)) -12 (|has| |#1| (-388)) (|has| |#2| (-1065 (-592)))) (((-433 (-592))) -12 (|has| |#1| (-388)) (|has| |#2| (-1065 (-592))))) 
+(((|#2|) . T)) 
+((((-1191) (-1265 |#1| |#2| |#3| |#4|)) |has| (-1265 |#1| |#2| |#3| |#4|) (-547 (-1191) (-1265 |#1| |#2| |#3| |#4|))) (((-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|)) |has| (-1265 |#1| |#2| |#3| |#4|) (-325 (-1265 |#1| |#2| |#3| |#4|)))) 
+((((-631 $) $) . T) (($ $) . T)) 
+((((-191 (-237))) . T) (((-191 (-405))) . T) (((-1187 (-715))) . T) (((-914 (-405))) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-582)) 
+(|has| (-433 |#2|) (-247)) 
+(((|#1| (-433 (-592))) . T)) 
 ((($ $) . T)) 
-(((|#1| (-572)) . T)) 
-((((-1170)) |has| |#2| (-901 (-1170)))) 
-((($) . T)) 
-((((-856)) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(|has| |#1| (-562)) 
-(((|#2|) |has| |#1| (-368))) 
-((((-385)) -12 (|has| |#1| (-368)) (|has| |#2| (-887 (-385)))) (((-572)) -12 (|has| |#1| (-368)) (|has| |#2| (-887 (-572))))) 
-(|has| |#1| (-368)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(|has| |#1| (-368)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-562)) 
-(((|#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
+(((|#1| (-592)) . T)) 
+((((-1191)) |has| |#2| (-922 (-1191)))) 
+((($) . T)) 
+((((-877)) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#1| (-582)) 
+(((|#2|) |has| |#1| (-388))) 
+((((-405)) -12 (|has| |#1| (-388)) (|has| |#2| (-908 (-405)))) (((-592)) -12 (|has| |#1| (-388)) (|has| |#2| (-908 (-592))))) 
+(|has| |#1| (-388)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(|has| |#1| (-388)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-582)) 
+(((|#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
 (((|#3|) . T)) 
 (((|#1|) . T)) 
-((((-572) (-572)) . T)) 
-(|has| |#2| (-848)) 
-(-1841 (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
+((((-592) (-592)) . T)) 
+(|has| |#2| (-869)) 
+(-3836 (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
 (((|#2|) . T)) 
 (((|#2|) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-722)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-743)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
 (((|#1| |#2|) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(|has| |#1| (-151)) 
-((((-1152) |#1|) . T)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(|has| |#1| (-151)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-374))) 
-(|has| |#1| (-151)) 
-((((-585 |#1|)) . T)) 
-((($) . T)) 
-((((-413 |#2|)) . T)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-866)) . T) (((-413 (-572))) . T) (($) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-353))) 
-(|has| |#1| (-151)) 
-((((-413 |#2|) (-413 |#2|)) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((((-413 (-572))) |has| |#2| (-1044 (-572))) (((-572)) |has| |#2| (-1044 (-572))) (((-1170)) |has| |#2| (-1044 (-1170))) ((|#2|) . T)) 
-((((-856)) . T)) 
-((($) . T)) 
-((((-1133 |#1| |#2|)) . T)) 
-(((|#1| (-572)) . T)) 
-(((|#1| (-413 (-572))) . T)) 
-((((-572)) |has| |#2| (-887 (-572))) (((-385)) |has| |#2| (-887 (-385)))) 
-(((|#2|) . T)) 
-((((-413 |#2|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-121)) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) . T)) 
-(((|#2|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-1170) (-57)) . T)) 
-((((-413 |#2|)) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-(|has| |#1| (-1098)) 
-(|has| |#1| (-792)) 
-(|has| |#1| (-792)) 
-((((-856)) . T)) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-123)) . T) ((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-217)) . T) (((-385)) . T) (((-893 (-385))) . T)) 
-((((-856)) . T)) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-562)) (((-413 (-572))) |has| |#1| (-562))) 
-((((-856)) . T)) 
-((((-611 $) $) . T) (($ $) . T)) 
-(((|#2|) . T)) 
-((((-856)) . T)) 
-((((-911 |#1|) (-911 |#1|)) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-(((|#1|) . T)) 
-((((-911 |#1|)) . T) (($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-368)) 
-(((|#2|) . T)) 
-((((-572)) . T)) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-((((-572)) . T)) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-((((-171 (-385))) . T) (((-217)) . T) (((-385)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-1152)) . T) (((-545)) . T) (((-572)) . T) (((-893 (-572))) . T) (((-385)) . T) (((-217)) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-149)) 
-((($) . T) (((-1243 |#2| |#3| |#4|)) |has| (-1243 |#2| |#3| |#4|) (-174)) (((-413 (-572))) |has| (-1243 |#2| |#3| |#4|) (-43 (-413 (-572))))) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-((((-856)) . T)) 
-((((-545)) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-((((-856)) |has| |#1| (-1098))) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-482)) (|has| |#1| (-722)) (|has| |#1| (-901 (-1170))) (|has| |#1| (-1054)) (|has| |#1| (-1110)) (|has| |#1| (-1098))) 
-(|has| |#1| (-1144)) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-572) |#1|) . T)) 
-((((-125 |#1|) $) |has| (-125 |#1|) (-283 (-125 |#1|) (-125 |#1|)))) 
-(((|#1|) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((((-863 |#1|)) . T)) 
-((((-123)) . T) ((|#1|) . T)) 
-((((-856)) . T)) 
-((((-413 $) (-413 $)) |has| |#1| (-562)) (($ $) . T) ((|#1| |#1|) . T)) 
-(((|#1|) |has| |#1| (-305 |#1|))) 
-((((-572) |#1|) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(|has| |#1| (-171)) 
+((((-1173) |#1|) . T)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(|has| |#1| (-171)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-394))) 
+(|has| |#1| (-171)) 
+((((-605 |#1|)) . T)) 
+((($) . T)) 
+((((-433 |#2|)) . T)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-887)) . T) (((-433 (-592))) . T) (($) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-373))) 
+(|has| |#1| (-171)) 
+((((-433 |#2|) (-433 |#2|)) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+((((-433 (-592))) |has| |#2| (-1065 (-592))) (((-592)) |has| |#2| (-1065 (-592))) (((-1191)) |has| |#2| (-1065 (-1191))) ((|#2|) . T)) 
+((((-877)) . T)) 
+((($) . T)) 
+((((-1154 |#1| |#2|)) . T)) 
+(((|#1| (-592)) . T)) 
+(((|#1| (-433 (-592))) . T)) 
+((((-592)) |has| |#2| (-908 (-592))) (((-405)) |has| |#2| (-908 (-405)))) 
+(((|#2|) . T)) 
+((((-433 |#2|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-141)) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) . T)) 
+(((|#2|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-1191) (-57)) . T)) 
+((((-433 |#2|)) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+(|has| |#1| (-1119)) 
+(|has| |#1| (-813)) 
+(|has| |#1| (-813)) 
+((((-877)) . T)) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-143)) . T) ((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-237)) . T) (((-405)) . T) (((-914 (-405))) . T)) 
+((((-877)) . T)) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-582)) (((-433 (-592))) |has| |#1| (-582))) 
+((((-877)) . T)) 
+((((-631 $) $) . T) (($ $) . T)) 
+(((|#2|) . T)) 
+((((-877)) . T)) 
+((((-932 |#1|) (-932 |#1|)) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+(((|#1|) . T)) 
+((((-932 |#1|)) . T) (($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-388)) 
+(((|#2|) . T)) 
+((((-592)) . T)) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+((((-592)) . T)) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+((((-191 (-405))) . T) (((-237)) . T) (((-405)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-1173)) . T) (((-565)) . T) (((-592)) . T) (((-914 (-592))) . T) (((-405)) . T) (((-237)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-169)) 
+((($) . T) (((-1264 |#2| |#3| |#4|)) |has| (-1264 |#2| |#3| |#4|) (-194)) (((-433 (-592))) |has| (-1264 |#2| |#3| |#4|) (-43 (-433 (-592))))) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+((((-877)) . T)) 
+((((-565)) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-877)) |has| |#1| (-1119))) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-502)) (|has| |#1| (-743)) (|has| |#1| (-922 (-1191))) (|has| |#1| (-1075)) (|has| |#1| (-1131)) (|has| |#1| (-1119))) 
+(|has| |#1| (-1165)) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-592) |#1|) . T)) 
+((((-145 |#1|) $) |has| (-145 |#1|) (-303 (-145 |#1|) (-145 |#1|)))) 
+(((|#1|) . T)) 
+(((|#1|) |has| |#1| (-194))) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+((((-884 |#1|)) . T)) 
+((((-143)) . T) ((|#1|) . T)) 
+((((-877)) . T)) 
+((((-433 $) (-433 $)) |has| |#1| (-582)) (($ $) . T) ((|#1| |#1|) . T)) 
+(((|#1|) |has| |#1| (-325 |#1|))) 
+((((-592) |#1|) . T)) 
 (((|#1| |#2|) . T)) 
-((((-1170) |#1|) . T)) 
+((((-1191) |#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-572)) . T) (((-413 (-572))) . T)) 
+((((-592)) . T) (((-433 (-592))) . T)) 
 (((|#1|) . T)) 
-(((|#2|) |has| |#2| (-174)) (($) . T) (((-413 (-572))) |has| |#2| (-562))) 
-((((-413 |#2|)) . T) (((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-562)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-((((-385)) . T)) 
-(|has| |#1| (-1098)) 
+(((|#2|) |has| |#2| (-194)) (($) . T) (((-433 (-592))) |has| |#2| (-582))) 
+((((-433 |#2|)) . T) (((-433 (-592))) . T) (($) . T)) 
+(|has| |#1| (-582)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+((((-405)) . T)) 
+(|has| |#1| (-1119)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-368)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-1098)) 
-((((-781 |#1| (-858 |#2|))) |has| (-781 |#1| (-858 |#2|)) (-305 (-781 |#1| (-858 |#2|))))) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
+(|has| |#1| (-388)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-1119)) 
+((((-802 |#1| (-879 |#2|))) |has| (-802 |#1| (-879 |#2|)) (-325 (-802 |#1| (-879 |#2|))))) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
 (((|#1|) . T)) 
 (((|#2| |#3|) . T)) 
-(|has| |#2| (-910)) 
-(((|#1|) . T)) 
-(((|#1| (-538 |#2|)) . T)) 
-(((|#1| (-769)) . T)) 
-(|has| |#1| (-227)) 
-(((|#1| (-538 (-1087 (-1170)))) . T)) 
-((((-572) (-572)) . T)) 
-((((-572)) . T)) 
-(|has| |#2| (-368)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) . T)) 
-(((|#1|) . T)) 
-((((-866)) . T) (((-413 (-572))) . T)) 
-((((-413 (-572))) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#3| (-794)) (|has| |#3| (-846))) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((($ $) . T) (((-611 $) $) . T)) 
-(((|#1|) . T)) 
-((((-572)) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(((|#1|) . T)) 
+(|has| |#2| (-931)) 
+(((|#1| (-558 |#2|)) . T)) 
+(((|#1| (-790)) . T)) 
+(|has| |#1| (-247)) 
+(((|#1| (-558 (-1108 (-1191)))) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) . T)) 
+(((|#1|) . T)) 
+((((-887)) . T) (((-433 (-592))) . T)) 
+((((-433 (-592))) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-592) (-592)) . T)) 
+((((-592)) . T)) 
+(|has| |#2| (-388)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#3| (-815)) (|has| |#3| (-867))) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+((($ $) . T) (((-631 $) $) . T)) 
+(((|#1|) . T)) 
+((((-592)) . T)) 
 (((|#3|) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-303)) (|has| |#1| (-368)) (|has| |#1| (-353))) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-149)) (|has| |#1| (-151)) (|has| |#1| (-174)) (|has| |#1| (-562)) (|has| |#1| (-1054))) 
-((((-572)) |has| |#2| (-634 (-572))) ((|#2|) . T)) 
-((((-585 |#1|) (-585 |#1|)) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-((((-572) (-572)) . T)) 
-(((|#1|) |has| |#1| (-174))) 
-(((|#1| (-1259 |#1|) (-1259 |#1|)) . T)) 
-((((-585 |#1|)) . T) (($) . T) (((-413 (-572))) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
-(((|#2|) |has| |#2| (-6 (-4604 "*")))) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-290 |#3|)) . T)) 
-(((|#1|) . T)) 
-((((-413 (-572)) (-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2| |#2|) . T) (($ $) -1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-323)) (|has| |#1| (-388)) (|has| |#1| (-373))) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-169)) (|has| |#1| (-171)) (|has| |#1| (-194)) (|has| |#1| (-582)) (|has| |#1| (-1075))) 
+((((-592)) |has| |#2| (-654 (-592))) ((|#2|) . T)) 
+((((-605 |#1|) (-605 |#1|)) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+((((-592) (-592)) . T)) 
+(((|#1|) |has| |#1| (-194))) 
+(((|#1| (-1280 |#1|) (-1280 |#1|)) . T)) 
+((((-605 |#1|)) . T) (($) . T) (((-433 (-592))) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
+(((|#2|) |has| |#2| (-6 (-4627 "*")))) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-310 |#3|)) . T)) 
+(((|#1|) . T)) 
+((((-433 (-592)) (-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2| |#2|) . T) (($ $) -3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
 (((|#2| |#2|) . T) ((|#6| |#6|) . T)) 
-((($) . T) (((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) . T)) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#2|) . T)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) . T) (($) -1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
+((($) . T) (((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) . T)) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#2|) . T)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) . T) (($) -3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
 (((|#2|) . T) ((|#6|) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-856)) . T)) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(|has| |#2| (-910)) 
-(|has| |#1| (-910)) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-572) (-572)) . T)) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-877)) . T)) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(|has| |#2| (-931)) 
+(|has| |#1| (-931)) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-592) (-592)) . T)) 
 (((|#1|) . T)) 
-((((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) . T)) 
+((((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1| |#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-1098)) 
-((((-572)) . T)) 
-(((|#1|) . T)) 
-((((-1170)) . T) ((|#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) 
-((((-413 (-572)) (-413 (-572))) . T)) 
-((((-572) (-1210) (-1210)) . T)) 
-((((-413 (-572))) . T)) 
-((((-572)) . T)) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-((((-545)) . T)) 
-((((-856)) . T)) 
-((((-1170)) |has| |#2| (-901 (-1170))) (((-1082)) . T)) 
-((((-1243 |#2| |#3| |#4|)) . T)) 
-((((-911 |#1|)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((($) . T) (((-413 (-572))) . T)) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-821))) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-821))) 
-(|has| |#1| (-1214)) 
-(((|#2|) . T)) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-((((-1170)) |has| |#1| (-901 (-1170)))) 
-((((-911 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((($) . T) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#1|) . T)) 
-((((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-562)))) 
-((($) . T) (((-413 (-572))) . T) ((|#1|) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (((-572)) . T) (($) . T)) 
-(((|#2|) |has| |#2| (-1054)) (((-572)) -12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-562)))) 
-(|has| |#1| (-562)) 
-(((|#1|) |has| |#1| (-368))) 
-((((-572)) . T)) 
-(|has| |#1| (-792)) 
-(|has| |#1| (-792)) 
-((((-1170) (-125 |#1|)) |has| (-125 |#1|) (-527 (-1170) (-125 |#1|))) (((-125 |#1|) (-125 |#1|)) |has| (-125 |#1|) (-305 (-125 |#1|)))) 
-(((|#2|) . T) (((-572)) |has| |#2| (-1044 (-572))) (((-413 (-572))) |has| |#2| (-1044 (-413 (-572))))) 
-((((-1082)) . T) ((|#2|) . T) (((-572)) |has| |#2| (-1044 (-572))) (((-413 (-572))) |has| |#2| (-1044 (-413 (-572))))) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-572) (-769)) . T) ((|#3| (-769)) . T)) 
-((((-1082) |#1|) . T) (((-1082) $) . T) (($ $) . T)) 
-(((|#1|) . T)) 
-(((|#1| |#2| (-244 |#2| |#1|) (-234 (-4032 |#2|) (-769)) (-973 |#1|) (-780 |#1|) (-927 |#1|) (-238 (-927 |#1|)) |#3|) . T)) 
-(((|#2|) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-856)) . T)) 
+(|has| |#1| (-1119)) 
+((((-592)) . T)) 
+(((|#1|) . T)) 
+((((-1191)) . T) ((|#1|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-388)) 
+(((|#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) 
+((((-433 (-592)) (-433 (-592))) . T)) 
+((((-592) (-1231) (-1231)) . T)) 
+((((-433 (-592))) . T)) 
+((((-592)) . T)) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+((((-565)) . T)) 
+((((-877)) . T)) 
+((((-1191)) |has| |#2| (-922 (-1191))) (((-1103)) . T)) 
+((((-1264 |#2| |#3| |#4|)) . T)) 
+((((-932 |#1|)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((($) . T) (((-433 (-592))) . T)) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-842))) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-842))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-1235)) 
+(((|#2|) . T)) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+((((-1191)) |has| |#1| (-922 (-1191)))) 
+((((-932 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((($) . T) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#1|) . T)) 
+((((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-582)))) 
+((($) . T) (((-433 (-592))) . T) ((|#1|) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (((-592)) . T) (($) . T)) 
+(((|#2|) |has| |#2| (-1075)) (((-592)) -12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-582)))) 
+(|has| |#1| (-582)) 
+(((|#1|) |has| |#1| (-388))) 
+((((-592)) . T)) 
+(|has| |#1| (-813)) 
+(|has| |#1| (-813)) 
+((((-1191) (-145 |#1|)) |has| (-145 |#1|) (-547 (-1191) (-145 |#1|))) (((-145 |#1|) (-145 |#1|)) |has| (-145 |#1|) (-325 (-145 |#1|)))) 
+(((|#2|) . T) (((-592)) |has| |#2| (-1065 (-592))) (((-433 (-592))) |has| |#2| (-1065 (-433 (-592))))) 
+((((-1103)) . T) ((|#2|) . T) (((-592)) |has| |#2| (-1065 (-592))) (((-433 (-592))) |has| |#2| (-1065 (-433 (-592))))) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-592) (-790)) . T) ((|#3| (-790)) . T)) 
+((((-1103) |#1|) . T) (((-1103) $) . T) (($ $) . T)) 
+(((|#1|) . T)) 
+(((|#1| |#2| (-264 |#2| |#1|) (-254 (-1699 |#2|) (-790)) (-994 |#1|) (-801 |#1|) (-948 |#1|) (-258 (-948 |#1|)) |#3|) . T)) 
+(((|#2|) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-877)) . T)) 
 (((|#1| |#2|) . T)) 
-(|has| |#2| (-821)) 
-(|has| |#2| (-821)) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#2|) |has| |#1| (-368)) (($) . T) ((|#1|) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-(((|#1|) . T) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-572)) |has| |#1| (-887 (-572))) (((-385)) |has| |#1| (-887 (-385)))) 
-(((|#1|) . T)) 
-((((-870 |#1|)) . T)) 
-((((-870 |#1|)) . T)) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-910))) 
-((((-413 (-572))) . T) (((-694)) . T) (($) . T)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-(|has| |#1| (-368)) 
-(((|#2|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-858 |#1|)) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#2| (-769)) . T)) 
-((((-1170)) . T)) 
-((((-870 |#1|)) . T)) 
-(-1841 (|has| |#3| (-25)) (|has| |#3| (-138)) (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-794)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-794)) (|has| |#2| (-846))) 
-(-1841 (-12 (|has| |#1| (-794)) (|has| |#2| (-794))) (-12 (|has| |#1| (-848)) (|has| |#2| (-848)))) 
-((((-870 |#1|)) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-((($ $) . T) (((-611 $) $) . T)) 
-((((-866) (-866)) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-((($) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#2|) . T)) 
-((((-572)) . T)) 
-((((-856)) . T)) 
-((((-866)) . T) (($) . T) (((-413 (-572))) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T) (((-413 (-572))) |has| |#1| (-368))) 
-((($) . T) ((|#2|) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-1098)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-(|has| |#2| (-910)) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-((((-545)) |has| |#2| (-613 (-545))) (((-893 (-385))) |has| |#2| (-613 (-893 (-385)))) (((-893 (-572))) |has| |#2| (-613 (-893 (-572))))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#3|) |has| |#3| (-1054)) (((-572)) -12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054)))) 
-((((-1121 |#1| |#2|)) . T) (((-959 |#1|)) |has| |#2| (-613 (-1170))) (((-856)) . T)) 
-((((-959 |#1|)) |has| |#2| (-613 (-1170))) (((-1152)) -12 (|has| |#1| (-1044 (-572))) (|has| |#2| (-613 (-1170)))) (((-893 (-572))) -12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572))))) (((-893 (-385))) -12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385))))) (((-545)) -12 (|has| |#1| (-613 (-545))) (|has| |#2| (-613 (-545))))) 
-((((-1166 |#1|)) . T) (((-856)) . T)) 
-((((-856)) . T)) 
-((((-413 (-572))) |has| |#2| (-1044 (-413 (-572)))) (((-572)) |has| |#2| (-1044 (-572))) ((|#2|) . T) (((-858 |#1|)) . T)) 
-((((-125 |#1|)) . T) (($) . T) (((-413 (-572))) . T)) 
-((((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T) (((-1170)) . T)) 
-((((-856)) . T)) 
-((((-572)) . T)) 
-((($) . T)) 
-((((-385)) |has| |#1| (-887 (-385))) (((-572)) |has| |#1| (-887 (-572)))) 
-((((-572)) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1|) |has| |#1| (-174)) (($) . T)) 
-((((-572)) . T) (((-413 (-572))) . T)) 
-(((|#1|) |has| |#1| (-305 |#1|))) 
-((((-856)) . T)) 
-((((-385)) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-413 |#2|) |#3|) . T)) 
-(((|#1|) . T)) 
-(|has| |#1| (-1098)) 
-(((|#2| (-497 (-4032 |#1|) (-769))) . T)) 
-((((-572) |#1|) . T)) 
+(|has| |#2| (-842)) 
+(|has| |#2| (-842)) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#2|) |has| |#1| (-388)) (($) . T) ((|#1|) . T)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+(((|#1|) . T) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-592)) |has| |#1| (-908 (-592))) (((-405)) |has| |#1| (-908 (-405)))) 
+(((|#1|) . T)) 
+((((-891 |#1|)) . T)) 
+((((-891 |#1|)) . T)) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-931))) 
+((((-433 (-592))) . T) (((-715)) . T) (($) . T)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+(|has| |#1| (-388)) 
+(((|#2|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-879 |#1|)) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#2| (-790)) . T)) 
+((((-1191)) . T)) 
+((((-891 |#1|)) . T)) 
+(-3836 (|has| |#3| (-25)) (|has| |#3| (-158)) (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-815)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-815)) (|has| |#2| (-867))) 
+(-3836 (-12 (|has| |#1| (-815)) (|has| |#2| (-815))) (-12 (|has| |#1| (-869)) (|has| |#2| (-869)))) 
+((((-891 |#1|)) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+((($ $) . T) (((-631 $) $) . T)) 
+((((-887) (-887)) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+((($) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#2|) . T)) 
+((((-592)) . T)) 
+((((-877)) . T)) 
+((((-887)) . T) (($) . T) (((-433 (-592))) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T) (((-433 (-592))) |has| |#1| (-388))) 
+((($) . T) ((|#2|) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-1119)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+(|has| |#2| (-931)) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+((((-565)) |has| |#2| (-633 (-565))) (((-914 (-405))) |has| |#2| (-633 (-914 (-405)))) (((-914 (-592))) |has| |#2| (-633 (-914 (-592))))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#3|) |has| |#3| (-1075)) (((-592)) -12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075)))) 
+((((-1142 |#1| |#2|)) . T) (((-980 |#1|)) |has| |#2| (-633 (-1191))) (((-877)) . T)) 
+((((-980 |#1|)) |has| |#2| (-633 (-1191))) (((-1173)) -12 (|has| |#1| (-1065 (-592))) (|has| |#2| (-633 (-1191)))) (((-914 (-592))) -12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592))))) (((-914 (-405))) -12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405))))) (((-565)) -12 (|has| |#1| (-633 (-565))) (|has| |#2| (-633 (-565))))) 
+((((-1187 |#1|)) . T) (((-877)) . T)) 
+((((-877)) . T)) 
+((((-433 (-592))) |has| |#2| (-1065 (-433 (-592)))) (((-592)) |has| |#2| (-1065 (-592))) ((|#2|) . T) (((-879 |#1|)) . T)) 
+((((-145 |#1|)) . T) (($) . T) (((-433 (-592))) . T)) 
+((((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T) (((-1191)) . T)) 
+((((-877)) . T)) 
+((((-592)) . T)) 
+((($) . T)) 
+((((-405)) |has| |#1| (-908 (-405))) (((-592)) |has| |#1| (-908 (-592)))) 
+((((-592)) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1|) |has| |#1| (-194)) (($) . T)) 
+((((-592)) . T) (((-433 (-592))) . T)) 
+(((|#1|) |has| |#1| (-325 |#1|))) 
+((((-877)) . T)) 
+((((-405)) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-433 |#2|) |#3|) . T)) 
+(((|#1|) . T)) 
+(|has| |#1| (-1119)) 
+(((|#2| (-517 (-1699 |#1|) (-790))) . T)) 
+((((-592) |#1|) . T)) 
 (((|#2| |#2|) . T)) 
-(((|#1| (-538 (-1170))) . T)) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-(-1841 (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-((((-572)) . T)) 
+(((|#1| (-558 (-1191))) . T)) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+(-3836 (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+((((-592)) . T)) 
 (((|#2|) . T)) 
 (((|#2|) . T)) 
-((((-1170)) |has| |#1| (-901 (-1170))) (((-1082)) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-634 (-572)))) 
-(|has| |#1| (-562)) 
+((((-1191)) |has| |#1| (-922 (-1191))) (((-1103)) . T)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-654 (-592)))) 
+(|has| |#1| (-582)) 
 (((|#1|) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
 ((($) . T)) 
 ((($) . T)) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
 (((|#1|) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-856)) . T)) 
-((((-148)) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-877)) . T)) 
+((((-168)) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-856)) . T)) 
+((((-877)) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-1144)) 
-(((|#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|))) . T)) 
+(|has| |#1| (-1165)) 
+(((|#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|))) . T)) 
 (((|#1|) . T)) 
-((((-856)) . T)) 
-((((-413 $) (-413 $)) |has| |#1| (-562)) (($ $) . T) ((|#1| |#1|) . T)) 
-(((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-((((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-572)) |has| |#1| (-1044 (-572))) ((|#1|) . T) ((|#2|) . T)) 
-((((-1082)) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572))))) 
-((((-385)) -12 (|has| |#1| (-887 (-385))) (|has| |#2| (-887 (-385)))) (((-572)) -12 (|has| |#1| (-887 (-572))) (|has| |#2| (-887 (-572))))) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T)) 
-((((-572) |#1|) . T)) 
+((((-877)) . T)) 
+((((-433 $) (-433 $)) |has| |#1| (-582)) (($ $) . T) ((|#1| |#1|) . T)) 
+(((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+((((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-592)) |has| |#1| (-1065 (-592))) ((|#1|) . T) ((|#2|) . T)) 
+((((-1103)) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592))))) 
+((((-405)) -12 (|has| |#1| (-908 (-405))) (|has| |#2| (-908 (-405)))) (((-592)) -12 (|has| |#1| (-908 (-592))) (|has| |#2| (-908 (-592))))) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T)) 
+((((-592) |#1|) . T)) 
 (((|#1| |#1|) . T)) 
 ((($) . T) ((|#2|) . T)) 
-(((|#1|) |has| |#1| (-174)) (($) . T)) 
-((($) . T)) 
-((((-694)) . T)) 
-((((-781 |#1| (-858 |#2|))) . T)) 
-((($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-1098)) 
-(|has| |#1| (-1098)) 
-(|has| |#2| (-368)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-572)) . T)) 
-((((-1170)) -12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) 
-((((-1170)) -12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) 
-(-1841 (|has| |#2| (-368)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(((|#1|) . T)) 
-(|has| |#1| (-227)) 
-(((|#1| (-538 |#3|)) . T)) 
-(((|#2| (-234 (-4032 |#1|) (-769))) . T)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#1| (-374)) 
-(|has| |#2| (-910)) 
+(((|#1|) |has| |#1| (-194)) (($) . T)) 
+((($) . T)) 
+((((-715)) . T)) 
+((((-802 |#1| (-879 |#2|))) . T)) 
+((($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(|has| |#1| (-1119)) 
+(|has| |#1| (-1119)) 
+(|has| |#2| (-388)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-592)) . T)) 
+((((-1191)) -12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) 
+((((-1191)) -12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) 
+(-3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(((|#1|) . T)) 
+(|has| |#1| (-247)) 
+(((|#2| (-254 (-1699 |#1|) (-790))) . T)) 
+(((|#1| (-558 |#3|)) . T)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#1| (-394)) 
+(|has| |#2| (-931)) 
 (((|#1|) . T) (($) . T)) 
-(-1841 (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(((|#1| (-538 |#2|)) . T)) 
-(((|#1| (-769)) . T)) 
-(-1841 (|has| |#2| (-25)) (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
+(-3836 (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(((|#1| (-558 |#2|)) . T)) 
+(((|#1| (-790)) . T)) 
+(-3836 (|has| |#2| (-25)) (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) 
-((((-856)) . T)) 
-(-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794)))) 
-(|has| |#1| (-562)) 
-(-1841 (|has| |#3| (-138)) (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-794)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-722)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(((|#1|) |has| |#1| (-174))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#4|) |has| |#4| (-1054))) 
-(((|#3|) |has| |#3| (-1054))) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-821))) 
-(-12 (|has| |#1| (-368)) (|has| |#2| (-821))) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-413 |#2|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-((((-856)) . T)) 
-((((-171 (-217))) . T)) 
-((((-217)) . T)) 
-((((-171 (-217))) . T)) 
-((((-217)) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
-(((|#1|) . T)) 
-(((|#4|) |has| |#4| (-1098)) (((-572)) -12 (|has| |#4| (-1044 (-572))) (|has| |#4| (-1098))) (((-413 (-572))) -12 (|has| |#4| (-1044 (-413 (-572)))) (|has| |#4| (-1098)))) 
-(((|#3|) |has| |#3| (-1098)) (((-572)) -12 (|has| |#3| (-1044 (-572))) (|has| |#3| (-1098))) (((-413 (-572))) -12 (|has| |#3| (-1044 (-413 (-572)))) (|has| |#3| (-1098)))) 
-(|has| |#2| (-368)) 
-(((|#2|) |has| |#2| (-1054)) (((-572)) -12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) 
-(((|#1|) . T)) 
-(|has| |#2| (-368)) 
-((((-413 (-572)) (-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2| |#2|) . T) (($ $) -1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1| |#1|) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(((|#1| |#1|) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(((|#1| |#1|) . T) (($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
+((((-877)) . T)) 
+(-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815)))) 
+(|has| |#1| (-582)) 
+(-3836 (|has| |#3| (-158)) (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-815)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-743)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(((|#1|) |has| |#1| (-194))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#4|) |has| |#4| (-1075))) 
+(((|#3|) |has| |#3| (-1075))) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-842))) 
+(-12 (|has| |#1| (-388)) (|has| |#2| (-842))) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-433 |#2|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+((((-877)) . T)) 
+((((-191 (-237))) . T)) 
+((((-237)) . T)) 
+((((-191 (-237))) . T)) 
+((((-237)) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
+(((|#1|) . T)) 
+(((|#4|) |has| |#4| (-1119)) (((-592)) -12 (|has| |#4| (-1065 (-592))) (|has| |#4| (-1119))) (((-433 (-592))) -12 (|has| |#4| (-1065 (-433 (-592)))) (|has| |#4| (-1119)))) 
+(((|#3|) |has| |#3| (-1119)) (((-592)) -12 (|has| |#3| (-1065 (-592))) (|has| |#3| (-1119))) (((-433 (-592))) -12 (|has| |#3| (-1065 (-433 (-592)))) (|has| |#3| (-1119)))) 
+(|has| |#2| (-388)) 
+(((|#2|) |has| |#2| (-1075)) (((-592)) -12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) 
+(((|#1|) . T)) 
+(|has| |#2| (-388)) 
+((((-433 (-592)) (-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2| |#2|) . T) (($ $) -3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1| |#1|) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(((|#1| |#1|) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(((|#1| |#1|) . T) (($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
 (((|#2| |#2|) . T)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) . T) (($) -1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#1|) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#2|) . T)) 
-(((|#1|) . T)) 
-((($) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(|has| |#2| (-821)) 
-(|has| |#2| (-821)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-15 * (|#1| (-572) |#1|))) 
-(((|#1|) |has| |#2| (-423 |#1|))) 
-(((|#1|) |has| |#2| (-423 |#1|))) 
-((((-911 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) . T)) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) |has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))))) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-((((-572) |#1|) . T)) 
-((((-572) |#1|) . T)) 
-((((-572) |#1|) . T)) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-572) |#1|) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-1170)) |has| |#1| (-901 (-1170))) (((-819 (-1170))) . T)) 
-(-1841 (|has| |#3| (-138)) (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-794)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-((((-820 |#1|)) . T)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) . T) (($) -3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#1|) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#2|) . T)) 
+(((|#1|) . T)) 
+((($) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(|has| |#2| (-842)) 
+(|has| |#2| (-842)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-15 * (|#1| (-592) |#1|))) 
+(((|#1|) |has| |#2| (-443 |#1|))) 
+(((|#1|) |has| |#2| (-443 |#1|))) 
+((((-932 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) . T)) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) |has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))))) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+((((-592) |#1|) . T)) 
+((((-592) |#1|) . T)) 
+((((-592) |#1|) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-592) |#1|) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-1191)) |has| |#1| (-922 (-1191))) (((-840 (-1191))) . T)) 
+(-3836 (|has| |#2| (-388)) (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(-3836 (|has| |#3| (-158)) (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-815)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+((((-841 |#1|)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-722)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
+((((-877)) . T)) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-743)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
 (((|#1| |#2|) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-856)) . T)) 
-((((-1244 |#1| |#2| |#3| |#4|)) . T) (($) . T) (((-413 (-572))) . T)) 
-(((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-562)) (((-413 (-572))) |has| |#1| (-562))) 
-(((|#2|) . T) (((-572)) |has| |#2| (-634 (-572)))) 
-(|has| |#1| (-368)) 
-(-1841 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (-12 (|has| |#1| (-368)) (|has| |#2| (-227)))) 
-(|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) 
-(|has| |#1| (-368)) 
-(((|#1|) . T)) 
-((((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) ((|#1| |#1|) . T)) 
-((((-572) |#1|) . T)) 
-((((-312 |#1|)) . T)) 
-((((-413 (-572)) (-413 (-572))) . T) (($ $) . T) ((|#1| |#1|) . T)) 
-(((|#1| |#1|) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((((-694) (-1166 (-694))) . T)) 
-((((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) ((|#1|) . T)) 
-((((-413 (-572))) . T) (($) . T) ((|#1|) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (($) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-877)) . T)) 
+((((-1265 |#1| |#2| |#3| |#4|)) . T) (($) . T) (((-433 (-592))) . T)) 
+(((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-582)) (((-433 (-592))) |has| |#1| (-582))) 
+(((|#2|) . T) (((-592)) |has| |#2| (-654 (-592)))) 
+(|has| |#1| (-388)) 
+(-3836 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (-12 (|has| |#1| (-388)) (|has| |#2| (-247)))) 
+(|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) 
+(|has| |#1| (-388)) 
+(((|#1|) . T)) 
+((((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) ((|#1| |#1|) . T)) 
+((((-592) |#1|) . T)) 
+(-3836 (|has| |#1| (-323)) (|has| |#1| (-388)) (|has| |#1| (-373))) 
+((((-332 |#1|)) . T)) 
+((((-433 (-592)) (-433 (-592))) . T) (($ $) . T) ((|#1| |#1|) . T)) 
+(((|#1| |#1|) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+((((-715) (-1187 (-715))) . T)) 
+((((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) ((|#1|) . T)) 
+((((-433 (-592))) . T) (($) . T) ((|#1|) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (($) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-(|has| |#1| (-846)) 
-((($ $) . T) (((-858 |#1|) $) . T) (((-858 |#1|) |#2|) . T)) 
-((((-1121 |#1| (-1170))) . T) (((-819 (-1170))) . T) ((|#1|) . T) (((-572)) |has| |#1| (-1044 (-572))) (((-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) (((-1170)) . T)) 
+(|has| |#1| (-867)) 
+((($ $) . T) (((-879 |#1|) $) . T) (((-879 |#1|) |#2|) . T)) 
+((((-1142 |#1| (-1191))) . T) (((-840 (-1191))) . T) ((|#1|) . T) (((-592)) |has| |#1| (-1065 (-592))) (((-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) (((-1191)) . T)) 
 ((($) . T)) 
 (((|#2| |#1|) . T) ((|#2| $) . T) (($ $) . T)) 
-((((-1082) |#1|) . T) (((-1082) $) . T) (($ $) . T)) 
-((($ $) . T) (((-1170) $) |has| |#1| (-227)) (((-1170) |#1|) |has| |#1| (-227)) (((-1087 (-1170)) |#1|) . T) (((-1087 (-1170)) $) . T)) 
+((((-1103) |#1|) . T) (((-1103) $) . T) (($ $) . T)) 
+((($ $) . T) (((-1191) $) |has| |#1| (-247)) (((-1191) |#1|) |has| |#1| (-247)) (((-1108 (-1191)) |#1|) . T) (((-1108 (-1191)) $) . T)) 
 ((($) . T) ((|#2|) . T)) 
-((($) . T) ((|#2|) . T) (((-413 (-572))) |has| |#2| (-43 (-413 (-572))))) 
-(|has| |#2| (-910)) 
-((($) . T) (((-1243 |#2| |#3| |#4|)) |has| (-1243 |#2| |#3| |#4|) (-174)) (((-413 (-572))) |has| (-1243 |#2| |#3| |#4|) (-43 (-413 (-572))))) 
-((((-572) |#1|) . T)) 
-((((-1244 |#1| |#2| |#3| |#4|)) |has| (-1244 |#1| |#2| |#3| |#4|) (-305 (-1244 |#1| |#2| |#3| |#4|)))) 
-((($) . T)) 
-(((|#1|) . T)) 
-((($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#2| |#2|) |has| |#1| (-368)) ((|#1| |#1|) . T)) 
-(((|#1| |#1|) . T) (($ $) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368)))) 
-(((|#2|) . T)) 
-(|has| |#2| (-227)) 
-(|has| $ (-151)) 
-((((-856)) . T)) 
-((($) . T) (((-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-353))) ((|#1|) . T)) 
-((((-856)) . T)) 
-(|has| |#1| (-846)) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) 
-((((-413 |#2|) |#3|) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-(((|#2| (-667 |#1|)) . T)) 
-(-12 (|has| |#1| (-303)) (|has| |#1| (-910))) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
+((($) . T) ((|#2|) . T) (((-433 (-592))) |has| |#2| (-43 (-433 (-592))))) 
+(|has| |#2| (-931)) 
+((($) . T) (((-1264 |#2| |#3| |#4|)) |has| (-1264 |#2| |#3| |#4|) (-194)) (((-433 (-592))) |has| (-1264 |#2| |#3| |#4|) (-43 (-433 (-592))))) 
+((((-592) |#1|) . T)) 
+((((-1265 |#1| |#2| |#3| |#4|)) |has| (-1265 |#1| |#2| |#3| |#4|) (-325 (-1265 |#1| |#2| |#3| |#4|)))) 
+((($) . T)) 
+(((|#1|) . T)) 
+((($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#2| |#2|) |has| |#1| (-388)) ((|#1| |#1|) . T)) 
+(((|#1| |#1|) . T) (($ $) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388)))) 
+(((|#2|) . T)) 
+(|has| |#2| (-247)) 
+(|has| $ (-171)) 
+((((-877)) . T)) 
+((($) . T) (((-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-373))) ((|#1|) . T)) 
+((((-877)) . T)) 
+(|has| |#1| (-867)) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) 
+((((-433 |#2|) |#3|) . T)) 
+(((|#1|) . T)) 
+((((-877)) . T)) 
+(((|#2| (-688 |#1|)) . T)) 
+(-12 (|has| |#1| (-323)) (|has| |#1| (-931))) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
 (((|#4|) . T)) 
-(|has| |#1| (-562)) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) 
-((($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368))) ((|#2|) |has| |#1| (-368)) ((|#1|) . T)) 
-((((-1170)) -1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) 
-(((|#1|) . T) (($) -1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-562))) (((-413 (-572))) -1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-368)))) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) 
-((($) |has| |#1| (-562)) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) 
-((((-572) |#1|) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(((|#1|) . T)) 
-(((|#1| (-538 (-819 (-1170)))) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((((-572) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-(((|#1|) . T)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-(((|#1|) . T)) 
-(-1841 (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794)))) 
-((((-1250 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-((($) . T) (((-870 |#1|)) . T) (((-413 (-572))) . T)) 
-((((-1250 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-(|has| |#1| (-562)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-413 |#2|)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) |has| |#1| (-1098))) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) |has| |#1| (-1098))) 
-(((|#1|) . T)) 
-(((|#2|) |has| |#2| (-174)) (($) . T) (((-413 (-572))) |has| |#2| (-562))) 
-(((|#2| |#2|) . T) (((-413 (-572)) (-413 (-572))) . T) (($ $) . T)) 
-((((-572)) . T)) 
-(((|#2|) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-856)) . T)) 
-((((-585 |#1|)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-572) |#1|) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-856)) . T)) 
-((($ $) . T) (((-1170) $) . T)) 
-((((-1250 |#1| |#2| |#3|)) . T)) 
-((((-1250 |#1| |#2| |#3|)) . T) (((-1222 |#1| |#2| |#3|)) . T)) 
-(((|#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|))) . T)) 
-((((-545)) |has| |#2| (-613 (-545))) (((-893 (-385))) |has| |#2| (-613 (-893 (-385)))) (((-893 (-572))) |has| |#2| (-613 (-893 (-572))))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-893 (-572))) -12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#3| (-613 (-893 (-572))))) (((-893 (-385))) -12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#3| (-613 (-893 (-385))))) (((-545)) -12 (|has| |#1| (-613 (-545))) (|has| |#3| (-613 (-545))))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) . T)) 
-((((-856)) . T)) 
-((((-1250 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-((((-1170)) . T) (((-856)) . T)) 
-(|has| |#1| (-368)) 
-((((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) |has| |#2| (-174)) (($) -1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910)))) 
+(|has| |#1| (-582)) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) 
+((($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388))) ((|#2|) |has| |#1| (-388)) ((|#1|) . T)) 
+((((-1191)) -3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) 
+(((|#1|) . T) (($) -3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-582))) (((-433 (-592))) -3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-388)))) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) 
+((($) |has| |#1| (-582)) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) 
+((((-592) |#1|) . T)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(((|#1|) . T)) 
+(((|#1| (-558 (-840 (-1191)))) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((((-592) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-931))) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(((|#1|) . T)) 
+(-3836 (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815)))) 
+((((-1271 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+((($) . T) (((-891 |#1|)) . T) (((-433 (-592))) . T)) 
+((((-1271 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+(|has| |#1| (-582)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-433 |#2|)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) |has| |#1| (-1119))) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) |has| |#1| (-1119))) 
+(((|#1|) . T)) 
+(((|#2|) |has| |#2| (-194)) (($) . T) (((-433 (-592))) |has| |#2| (-582))) 
+(((|#2| |#2|) . T) (((-433 (-592)) (-433 (-592))) . T) (($ $) . T)) 
+(((|#2|) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-592)) . T)) 
+((((-877)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-877)) . T)) 
+((((-605 |#1|)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-592) |#1|) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((($ $) . T) (((-1191) $) . T)) 
+((((-1271 |#1| |#2| |#3|)) . T)) 
+(((|#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|))) . T)) 
+((((-565)) |has| |#2| (-633 (-565))) (((-914 (-405))) |has| |#2| (-633 (-914 (-405)))) (((-914 (-592))) |has| |#2| (-633 (-914 (-592))))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-914 (-592))) -12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#3| (-633 (-914 (-592))))) (((-914 (-405))) -12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#3| (-633 (-914 (-405))))) (((-565)) -12 (|has| |#1| (-633 (-565))) (|has| |#3| (-633 (-565))))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) . T)) 
+((((-877)) . T)) 
+((((-1271 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+((((-1271 |#1| |#2| |#3|)) . T) (((-1243 |#1| |#2| |#3|)) . T)) 
+(|has| |#1| (-388)) 
+((((-1191)) . T) (((-877)) . T)) 
+((((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) |has| |#2| (-194)) (($) -3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931)))) 
 (((|#2|) . T) ((|#6|) . T)) 
-((($) . T) (((-413 (-572))) |has| |#2| (-43 (-413 (-572)))) ((|#2|) . T)) 
-((($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-1102)) . T)) 
-((((-856)) . T)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((($) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T)) 
-((($) . T)) 
-((($) -1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(|has| |#2| (-910)) 
-(|has| |#1| (-910)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1| |#1|) |has| |#1| (-174))) 
-((((-572)) . T)) 
-((((-694)) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-(((|#1|) |has| |#1| (-174))) 
-(((|#1|) |has| |#1| (-174))) 
-((($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#1| (-572)) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(|has| |#1| (-368)) 
-(|has| |#1| (-368)) 
-(-1841 (|has| |#1| (-174)) (|has| |#1| (-562))) 
-(((|#1| (-769)) . T)) 
-(((|#1| (-572)) . T)) 
-(((|#1| (-413 (-572))) . T)) 
-(((|#1| (-769)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-1098)) 
-((((-413 (-572))) . T)) 
-(((|#1| (-538 |#2|) |#2|) . T)) 
-((((-572) |#1|) . T)) 
-((((-572) |#1|) . T)) 
-(|has| |#1| (-1098)) 
-((((-572) |#1|) . T)) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-((((-893 (-385))) . T) (((-893 (-572))) . T) (((-1170)) . T) (((-545)) . T)) 
-(((|#1|) . T)) 
-((((-856)) . T)) 
-(-1841 (|has| |#2| (-138)) (|has| |#2| (-174)) (|has| |#2| (-368)) (|has| |#2| (-794)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-(-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794)))) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
+((($) . T) (((-433 (-592))) |has| |#2| (-43 (-433 (-592)))) ((|#2|) . T)) 
+((($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-1123)) . T)) 
+((((-877)) . T)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((($) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T)) 
+((($) . T)) 
+((($) -3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(|has| |#2| (-931)) 
+(|has| |#1| (-931)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1| |#1|) |has| |#1| (-194))) 
+((((-592)) . T)) 
+((((-715)) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+(((|#1|) |has| |#1| (-194))) 
+(((|#1|) |has| |#1| (-194))) 
+((($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#1| (-592)) . T)) 
+((((-877)) . T)) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(|has| |#1| (-388)) 
+(|has| |#1| (-388)) 
+(-3836 (|has| |#1| (-194)) (|has| |#1| (-582))) 
+(((|#1| (-790)) . T)) 
+(((|#1| (-592)) . T)) 
+(((|#1| (-433 (-592))) . T)) 
+(((|#1| (-790)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-1119)) 
+((((-433 (-592))) . T)) 
+(((|#1| (-558 |#2|) |#2|) . T)) 
+((((-592) |#1|) . T)) 
+((((-592) |#1|) . T)) 
+(|has| |#1| (-1119)) 
+((((-592) |#1|) . T)) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+((((-914 (-405))) . T) (((-914 (-592))) . T) (((-1191)) . T) (((-565)) . T)) 
+(((|#1|) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(-3836 (|has| |#2| (-158)) (|has| |#2| (-194)) (|has| |#2| (-388)) (|has| |#2| (-815)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+(-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815)))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-931))) 
+((((-877)) . T)) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
 (((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
-(-1841 (|has| |#2| (-174)) (|has| |#2| (-722)) (|has| |#2| (-846)) (|has| |#2| (-1054))) 
-((((-1170)) -12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) 
-(-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722)))) 
-((((-572)) . T)) 
-(|has| |#1| (-149)) 
-(|has| |#1| (-151)) 
-(|has| |#1| (-368)) 
+(-3836 (|has| |#2| (-194)) (|has| |#2| (-743)) (|has| |#2| (-867)) (|has| |#2| (-1075))) 
+((((-1191)) -12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) 
+(-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743)))) 
+((((-592)) . T)) 
+(|has| |#1| (-169)) 
+(|has| |#1| (-171)) 
+(|has| |#1| (-388)) 
 (((|#1| |#2|) . T)) 
 (((|#1| |#2|) . T)) 
-(|has| |#1| (-227)) 
-((((-856)) . T)) 
-(((|#1| (-769) (-1082)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-572) |#1|) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-572) |#1|) . T)) 
-((((-572) |#1|) . T)) 
-((((-125 |#1|)) . T)) 
-((((-572) (-171 (-217))) . T)) 
-((((-572) (-217)) . T)) 
-(((|#2|) |has| |#2| (-1054))) 
-((((-413 (-572))) . T) (($) . T)) 
-(((|#2|) . T)) 
-((((-572)) . T)) 
-((((-572)) . T)) 
-((((-413 (-572))) . T) (((-572)) . T)) 
-((((-1152) (-1170) (-572) (-217) (-856)) . T)) 
+(|has| |#1| (-247)) 
+((((-877)) . T)) 
+(((|#1| (-790) (-1103)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-592) |#1|) . T)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-592) |#1|) . T)) 
+((((-592) |#1|) . T)) 
+((((-145 |#1|)) . T)) 
+((((-592) (-191 (-237))) . T)) 
+((((-592) (-237)) . T)) 
+(((|#2|) |has| |#2| (-1075))) 
+((((-433 (-592))) . T) (($) . T)) 
+(((|#2|) . T)) 
+((((-592)) . T)) 
+((((-592)) . T)) 
+((((-433 (-592))) . T) (((-592)) . T)) 
+((((-1173) (-1191) (-592) (-237) (-877)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#1| |#2|) . T)) 
-((((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) |has| |#1| (-174)) (($) |has| |#1| (-562))) 
-(-1841 (|has| |#1| (-353)) (|has| |#1| (-374))) 
+((((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) |has| |#1| (-194)) (($) |has| |#1| (-582))) 
+(-3836 (|has| |#1| (-373)) (|has| |#1| (-394))) 
 (((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
 ((($) . T) ((|#1|) . T)) 
-((((-856)) . T)) 
-((($) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((|#1|) . T)) 
-((($) . T) ((|#1|) . T) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-(((|#2|) |has| |#2| (-1098)) (((-572)) -12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098))) (((-413 (-572))) -12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) 
-((((-545)) |has| |#1| (-613 (-545)))) 
-((((-856)) -1841 (|has| |#1| (-848)) (|has| |#1| (-1098)))) 
-((($) . T) (((-413 (-572))) . T)) 
-(|has| |#1| (-910)) 
-(|has| |#1| (-910)) 
-((((-217)) -12 (|has| |#1| (-368)) (|has| |#2| (-1028))) (((-385)) -12 (|has| |#1| (-368)) (|has| |#2| (-1028))) (((-893 (-385))) -12 (|has| |#1| (-368)) (|has| |#2| (-613 (-893 (-385))))) (((-893 (-572))) -12 (|has| |#1| (-368)) (|has| |#2| (-613 (-893 (-572))))) (((-545)) -12 (|has| |#1| (-368)) (|has| |#2| (-613 (-545))))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+((((-877)) . T)) 
+((($) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((|#1|) . T)) 
+((($) . T) ((|#1|) . T) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+(((|#2|) |has| |#2| (-1119)) (((-592)) -12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119))) (((-433 (-592))) -12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) 
+((((-565)) |has| |#1| (-633 (-565)))) 
+((((-877)) -3836 (|has| |#1| (-869)) (|has| |#1| (-1119)))) 
+((($) . T) (((-433 (-592))) . T)) 
+(|has| |#1| (-931)) 
+(|has| |#1| (-931)) 
+((((-237)) -12 (|has| |#1| (-388)) (|has| |#2| (-1049))) (((-405)) -12 (|has| |#1| (-388)) (|has| |#2| (-1049))) (((-914 (-405))) -12 (|has| |#1| (-388)) (|has| |#2| (-633 (-914 (-405))))) (((-914 (-592))) -12 (|has| |#1| (-388)) (|has| |#2| (-633 (-914 (-592))))) (((-565)) -12 (|has| |#1| (-388)) (|has| |#2| (-633 (-565))))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#2| |#2|) . T)) 
-(((|#1| |#1|) |has| |#1| (-174))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-562))) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-846))) 
-(((|#2|) . T)) 
-(-1841 (|has| |#1| (-21)) (|has| |#1| (-846))) 
-(((|#1|) |has| |#1| (-174))) 
-(((|#1|) . T)) 
-(((|#1|) . T)) 
-(|has| (-413 |#2|) (-151)) 
-((((-413 |#2|) |#3|) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-368)) 
-((($ $) . T) (((-413 (-572)) (-413 (-572))) . T)) 
-(|has| (-413 |#2|) (-149)) 
-((((-694)) . T)) 
-(((|#1|) . T) (((-413 (-572))) . T) (((-572)) . T) (($) . T)) 
-((((-572) (-572)) . T)) 
-((($) . T) (((-413 (-572))) . T)) 
-(-1841 (|has| |#4| (-174)) (|has| |#4| (-722)) (|has| |#4| (-846)) (|has| |#4| (-1054))) 
-(-1841 (|has| |#3| (-174)) (|has| |#3| (-722)) (|has| |#3| (-846)) (|has| |#3| (-1054))) 
-(|has| |#4| (-794)) 
-(-1841 (|has| |#4| (-794)) (|has| |#4| (-846))) 
-(|has| |#4| (-846)) 
-(|has| |#3| (-794)) 
-(-1841 (|has| |#3| (-794)) (|has| |#3| (-846))) 
-(|has| |#3| (-846)) 
-((((-572)) . T)) 
-(((|#2|) . T)) 
-((((-1170)) -1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) 
-(((|#1|) |has| |#1| (-174)) (($) . T)) 
-((((-1170)) -12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) 
+(((|#1| |#1|) |has| |#1| (-194))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-582))) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-867))) 
+(((|#2|) . T)) 
+(-3836 (|has| |#1| (-21)) (|has| |#1| (-867))) 
+(((|#1|) |has| |#1| (-194))) 
+(((|#1|) . T)) 
+(((|#1|) . T)) 
+(|has| (-433 |#2|) (-171)) 
+((((-433 |#2|) |#3|) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-388)) 
+((($ $) . T) (((-433 (-592)) (-433 (-592))) . T)) 
+(|has| (-433 |#2|) (-169)) 
+((((-715)) . T)) 
+(((|#1|) . T) (((-433 (-592))) . T) (((-592)) . T) (($) . T)) 
+((((-592) (-592)) . T)) 
+((($) . T) (((-433 (-592))) . T)) 
+(-3836 (|has| |#4| (-194)) (|has| |#4| (-743)) (|has| |#4| (-867)) (|has| |#4| (-1075))) 
+(-3836 (|has| |#3| (-194)) (|has| |#3| (-743)) (|has| |#3| (-867)) (|has| |#3| (-1075))) 
+(|has| |#4| (-815)) 
+(-3836 (|has| |#4| (-815)) (|has| |#4| (-867))) 
+(|has| |#4| (-867)) 
+(|has| |#3| (-815)) 
+(-3836 (|has| |#3| (-815)) (|has| |#3| (-867))) 
+(|has| |#3| (-867)) 
+((((-592)) . T)) 
+(((|#2|) . T)) 
+((((-1191)) -3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) 
+(((|#1|) |has| |#1| (-194)) (($) . T)) 
+((((-1191)) -12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) 
 (((|#1| |#1|) . T) (($ $) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(|has| |#2| (-368)) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(|has| |#2| (-388)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T) (($) . T)) 
 (((|#1|) . T)) 
-((((-572) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-((((-858 |#1|)) . T)) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-((((-1168 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-((((-1168 |#1| |#2| |#3|)) |has| |#1| (-368))) 
-((((-1133 |#1| |#2|)) . T)) 
-(((|#2|) . T) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-((($) . T)) 
-(|has| |#1| (-1028)) 
-(((|#2|) . T) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((((-856)) . T)) 
-((((-545)) |has| |#2| (-613 (-545))) (((-893 (-572))) |has| |#2| (-613 (-893 (-572)))) (((-893 (-385))) |has| |#2| (-613 (-893 (-385)))) (((-385)) |has| |#2| (-1028)) (((-217)) |has| |#2| (-1028))) 
-((((-1170) (-57)) . T)) 
-(|has| |#1| (-43 (-413 (-572)))) 
-(|has| |#1| (-43 (-413 (-572)))) 
-((((-866)) . T) (((-413 (-572))) . T) (($) . T)) 
-((((-413 (-572))) . T) (($) . T)) 
+((((-592) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+((((-879 |#1|)) . T)) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+((((-1189 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+((((-1189 |#1| |#2| |#3|)) |has| |#1| (-388))) 
+((((-1154 |#1| |#2|)) . T)) 
+(((|#2|) . T) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+((($) . T)) 
+(|has| |#1| (-1049)) 
+(((|#2|) . T) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((((-877)) . T)) 
+((((-565)) |has| |#2| (-633 (-565))) (((-914 (-592))) |has| |#2| (-633 (-914 (-592)))) (((-914 (-405))) |has| |#2| (-633 (-914 (-405)))) (((-405)) |has| |#2| (-1049)) (((-237)) |has| |#2| (-1049))) 
+((((-1191) (-57)) . T)) 
+(|has| |#1| (-43 (-433 (-592)))) 
+(|has| |#1| (-43 (-433 (-592)))) 
+((((-887)) . T) (((-433 (-592))) . T) (($) . T)) 
+((((-433 (-592))) . T) (($) . T)) 
 (((|#2|) . T)) 
 ((($ $) . T)) 
-((((-413 (-572))) . T) (((-694)) . T) (($) . T)) 
-((((-572) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T) (($ $) . T)) 
-((((-1168 |#1| |#2| |#3|)) . T)) 
-((((-1168 |#1| |#2| |#3|)) . T) (((-1160 |#1| |#2| |#3|)) . T)) 
-((((-856)) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-((((-572) |#1|) . T)) 
-((((-1168 |#1| |#2| |#3|)) |has| |#1| (-368))) 
+((((-433 (-592))) . T) (((-715)) . T) (($) . T)) 
+((((-592) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T) (($ $) . T)) 
+((((-1189 |#1| |#2| |#3|)) . T)) 
+((((-1189 |#1| |#2| |#3|)) . T) (((-1181 |#1| |#2| |#3|)) . T)) 
+((((-877)) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-592) |#1|) . T)) 
+((((-1189 |#1| |#2| |#3|)) |has| |#1| (-388))) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#1|) . T)) 
 (((|#2|) . T)) 
-(|has| |#2| (-368)) 
-(((|#3|) . T) ((|#2|) . T) (($) -1841 (|has| |#4| (-174)) (|has| |#4| (-846)) (|has| |#4| (-1054))) ((|#4|) -1841 (|has| |#4| (-174)) (|has| |#4| (-368)) (|has| |#4| (-1054)))) 
-(((|#2|) . T) (($) -1841 (|has| |#3| (-174)) (|has| |#3| (-846)) (|has| |#3| (-1054))) ((|#3|) -1841 (|has| |#3| (-174)) (|has| |#3| (-368)) (|has| |#3| (-1054)))) 
+(|has| |#2| (-388)) 
+(((|#3|) . T) ((|#2|) . T) (($) -3836 (|has| |#4| (-194)) (|has| |#4| (-867)) (|has| |#4| (-1075))) ((|#4|) -3836 (|has| |#4| (-194)) (|has| |#4| (-388)) (|has| |#4| (-1075)))) 
+(((|#2|) . T) (($) -3836 (|has| |#3| (-194)) (|has| |#3| (-867)) (|has| |#3| (-1075))) ((|#3|) -3836 (|has| |#3| (-194)) (|has| |#3| (-388)) (|has| |#3| (-1075)))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(|has| |#1| (-368)) 
-((((-125 |#1|)) . T)) 
+(|has| |#1| (-388)) 
+((((-145 |#1|)) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((((-413 (-572))) |has| |#2| (-1044 (-413 (-572)))) (((-572)) |has| |#2| (-1044 (-572))) ((|#2|) . T) (((-858 |#1|)) . T)) 
-((((-545)) |has| (-171 (-217)) (-613 (-545)))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-545)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
+((((-433 (-592))) |has| |#2| (-1065 (-433 (-592)))) (((-592)) |has| |#2| (-1065 (-592))) ((|#2|) . T) (((-879 |#1|)) . T)) 
+((((-877)) . T)) 
+((((-565)) |has| (-191 (-237)) (-633 (-565)))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-565)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
 (((|#1|) . T)) 
-((((-856)) |has| |#1| (-1098))) 
-((((-572) |#1|) . T)) 
+((((-877)) |has| |#1| (-1119))) 
+((((-592) |#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(((|#2| $) -12 (|has| |#1| (-368)) (|has| |#2| (-283 |#2| |#2|))) (($ $) . T)) 
+(((|#2| $) -12 (|has| |#1| (-388)) (|has| |#2| (-303 |#2| |#2|))) (($ $) . T)) 
 ((($ $) . T)) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-910))) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-((((-856)) . T)) 
-(((|#1| (-538 |#2|)) . T)) 
-((((-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) . T)) 
-(((|#1| (-572)) . T)) 
-(((|#1| (-413 (-572))) . T)) 
-(((|#1| (-769)) . T)) 
-(((|#1| (-769)) . T)) 
-(((|#1|) . T)) 
-((((-125 |#1|)) . T) (($) . T) (((-413 (-572))) . T)) 
-(-1841 (|has| |#2| (-457)) (|has| |#2| (-562)) (|has| |#2| (-910))) 
-(-1841 (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) 
-((($) . T)) 
-(((|#2| (-538 (-858 |#1|))) . T)) 
-((((-2 (|:| |k| (-572)) (|:| |c| |#1|))) . T)) 
-((((-572) |#1|) . T)) 
-(((|#2|) . T)) 
-(((|#2| (-769)) . T)) 
-((((-856)) |has| |#1| (-1098))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+((((-877)) . T)) 
+(((|#1| (-558 |#2|)) . T)) 
+((((-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) . T)) 
+(((|#1| (-592)) . T)) 
+(((|#1| (-433 (-592))) . T)) 
+(((|#1| (-790)) . T)) 
+(((|#1| (-790)) . T)) 
+(((|#1|) . T)) 
+((((-145 |#1|)) . T) (($) . T) (((-433 (-592))) . T)) 
+(-3836 (|has| |#2| (-477)) (|has| |#2| (-582)) (|has| |#2| (-931))) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) 
+((($) . T)) 
+(((|#2| (-558 (-879 |#1|))) . T)) 
+((((-2 (|:| |k| (-592)) (|:| |c| |#1|))) . T)) 
+((((-592) |#1|) . T)) 
+(((|#2|) . T)) 
+(-3836 (|has| |#1| (-477)) (|has| |#1| (-931))) 
+(((|#2| (-790)) . T)) 
+((((-877)) |has| |#1| (-1119))) 
 (((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
-((((-1152) |#1|) . T)) 
-((((-413 |#2|)) . T)) 
-((((-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-(|has| |#1| (-562)) 
-(|has| |#1| (-562)) 
-((($) -1841 (|has| |#1| (-368)) (|has| |#1| (-457)) (|has| |#1| (-562)) (|has| |#1| (-910))) ((|#1|) |has| |#1| (-174)) (((-413 (-572))) |has| |#1| (-43 (-413 (-572))))) 
-((((-572)) . T)) 
+((((-1173) |#1|) . T)) 
+((((-433 |#2|)) . T)) 
+((((-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+(|has| |#1| (-582)) 
+(|has| |#1| (-582)) 
+((($) -3836 (|has| |#1| (-388)) (|has| |#1| (-477)) (|has| |#1| (-582)) (|has| |#1| (-931))) ((|#1|) |has| |#1| (-194)) (((-433 (-592))) |has| |#1| (-43 (-433 (-592))))) 
+((((-592)) . T)) 
 ((($) . T) ((|#2|) . T)) 
 (((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
-(((|#2| $) |has| |#2| (-283 |#2| |#2|))) 
-(((|#1| (-638 |#1|)) |has| |#1| (-846))) 
-(-1841 (|has| |#1| (-227)) (|has| |#1| (-353))) 
-(-1841 (|has| |#1| (-368)) (|has| |#1| (-353))) 
-(|has| |#1| (-1098)) 
-(((|#1|) . T)) 
-(|has| |#1| (-1144)) 
-((((-413 (-572))) . T) (($) . T)) 
-((((-1006 |#1|)) . T) ((|#1|) . T) (((-572)) -1841 (|has| (-1006 |#1|) (-1044 (-572))) (|has| |#1| (-1044 (-572)))) (((-413 (-572))) -1841 (|has| (-1006 |#1|) (-1044 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-1170)) |has| |#1| (-901 (-1170)))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-(((|#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) 
-((((-572) (-171 (-217))) . T)) 
-((((-572) (-217)) . T)) 
-(((|#1| (-603 |#1| |#3|) (-603 |#1| |#2|)) . T)) 
-(((|#1|) . T)) 
-((((-171 (-217))) . T)) 
-((((-217)) . T)) 
+(((|#2| $) |has| |#2| (-303 |#2| |#2|))) 
+(((|#1| (-658 |#1|)) |has| |#1| (-867))) 
+(-3836 (|has| |#1| (-247)) (|has| |#1| (-373))) 
+(-3836 (|has| |#1| (-388)) (|has| |#1| (-373))) 
+(|has| |#1| (-1119)) 
+(((|#1|) . T)) 
+(|has| |#1| (-1165)) 
+((((-433 (-592))) . T) (($) . T)) 
+((((-1027 |#1|)) . T) ((|#1|) . T) (((-592)) -3836 (|has| (-1027 |#1|) (-1065 (-592))) (|has| |#1| (-1065 (-592)))) (((-433 (-592))) -3836 (|has| (-1027 |#1|) (-1065 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-1191)) |has| |#1| (-922 (-1191)))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+(((|#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) 
+((((-592) (-191 (-237))) . T)) 
+((((-592) (-237)) . T)) 
+(((|#1| (-623 |#1| |#3|) (-623 |#1| |#2|)) . T)) 
+(((|#1|) . T)) 
+((((-191 (-237))) . T)) 
+((((-237)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-((((-1133 |#1| |#2|) (-1133 |#1| |#2|)) |has| (-1133 |#1| |#2|) (-305 (-1133 |#1| |#2|)))) 
-(((|#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 
-((((-125 |#1|)) |has| (-125 |#1|) (-305 (-125 |#1|)))) 
-(-1841 (|has| |#1| (-848)) (|has| |#1| (-1098))) 
+((((-1154 |#1| |#2|) (-1154 |#1| |#2|)) |has| (-1154 |#1| |#2|) (-325 (-1154 |#1| |#2|)))) 
+(((|#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 
+((((-145 |#1|)) |has| (-145 |#1|) (-325 (-145 |#1|)))) 
+(-3836 (|has| |#1| (-869)) (|has| |#1| (-1119))) 
 ((($ $) . T)) 
-((($ $) . T) (((-858 |#1|) $) . T) (((-858 |#1|) |#2|) . T)) 
-((($ $) . T) ((|#2| $) |has| |#1| (-227)) ((|#2| |#1|) |has| |#1| (-227)) ((|#3| |#1|) . T) ((|#3| $) . T)) 
-(((-656 . -1098) T) ((-259 . -527) 156851) ((-244 . -527) 156789) ((-579 . -120) 156774) ((-538 . -23) T) ((-242 . -1098) 156724) ((-126 . -305) 156668) ((-494 . -527) 156428) ((-689 . -105) T) ((-1134 . -527) 156336) ((-396 . -138) T) ((-1270 . -984) 156305) ((-220 . -19) 156287) ((-146 . -19) 156262) ((-603 . -503) 156246) ((-820 . -844) T) ((-617 . -138) T) ((-535 . -62) 156196) ((-220 . -605) 156171) ((-146 . -605) 156139) ((-64 . -527) 156072) ((-531 . -527) 156005) ((-424 . -901) 155964) ((-171 . -1054) T) ((-529 . -527) 155897) ((-510 . -527) 155830) ((-509 . -527) 155763) ((-800 . -1044) 155543) ((-694 . -43) 155508) ((-343 . -353) T) ((-1164 . -1144) 155486) ((-1092 . -1091) 155470) ((-1092 . -1098) 155448) ((-171 . -240) 155399) ((-171 . -227) 155350) ((-1092 . -1093) 155308) ((-872 . -283) 155266) ((-217 . -796) T) ((-217 . -793) T) ((-689 . -281) NIL) ((-1143 . -1181) 155245) ((-413 . -1000) 155229) ((-975 . -105) T) ((-696 . -21) T) ((-696 . -25) T) ((-1272 . -641) 155203) ((-1208 . -155) 155185) ((-1207 . -1204) T) ((-1164 . -43) 155014) ((-312 . -162) 154993) ((-312 . -147) 154972) ((-1143 . -111) 154922) ((-140 . -25) T) ((-45 . -225) 154899) ((-125 . -21) T) ((-125 . -25) T) ((-607 . -285) 154875) ((-484 . -285) 154854) ((-1231 . -1054) T) ((-853 . -1054) T) ((-800 . -338) 154838) ((-126 . -1144) NIL) ((-96 . -612) 154805) ((-493 . -138) T) ((-595 . -1204) T) ((-1231 . -326) 154782) ((-579 . -1054) T) ((-1231 . -227) T) ((-656 . -713) 154766) ((-965 . -285) 154743) ((-780 . -503) 154695) ((-65 . -39) T) ((-1065 . -796) T) ((-1065 . -793) T) ((-817 . -722) T) ((-727 . -52) 154660) ((-619 . -43) 154647) ((-359 . -287) T) ((-356 . -287) T) ((-344 . -287) T) ((-259 . -287) 154578) ((-244 . -287) 154509) ((-1030 . -105) T) ((-419 . -722) T) ((-126 . -43) 154454) ((-419 . -482) T) ((-358 . -105) T) ((-1199 . -1061) T) ((-707 . -1061) T) ((-1254 . -1249) 154438) ((-1254 . -1236) 154415) ((-1168 . -52) 154392) ((-1167 . -52) 154362) ((-1160 . -52) 154339) ((-1042 . -155) 154285) ((-911 . -287) T) ((-1122 . -52) 154257) ((-689 . -305) NIL) ((-528 . -612) 154239) ((-523 . -612) 154221) ((-521 . -612) 154203) ((-327 . -1098) 154153) ((-116 . -105) T) ((-708 . -457) 154084) ((-53 . -105) T) ((-1242 . -283) 154069) ((-1221 . -283) 153989) ((-638 . -662) 153973) ((-638 . -644) 153957) ((-339 . -21) T) ((-339 . -25) T) ((-45 . -353) NIL) ((-866 . -1098) T) ((-175 . -21) T) ((-175 . -25) T) ((-861 . -1098) T) ((-638 . -379) 153941) ((-603 . -283) 153918) ((-394 . -105) T) ((-1116 . -147) T) ((-136 . -612) 153885) ((-875 . -1098) T) ((-652 . -417) 153869) ((-710 . -612) 153851) ((-1272 . -722) T) ((-220 . -612) 153833) ((-220 . -613) 153815) ((-163 . -612) 153797) ((-159 . -612) 153779) ((-146 . -612) 153761) ((-146 . -613) 153713) ((-1100 . -39) T) ((-116 . -117) T) ((-871 . -796) NIL) ((-871 . -793) NIL) ((-855 . -848) T) ((-727 . -887) NIL) ((-1281 . -138) T) ((-387 . -138) T) ((-905 . -105) T) ((-727 . -1044) 153589) ((-538 . -138) T) ((-1086 . -417) 153573) ((-1007 . -503) 153557) ((-126 . -406) 153534) ((-1160 . -1204) 153513) ((-783 . -417) 153497) ((-781 . -417) 153481) ((-950 . -39) T) ((-689 . -1144) NIL) ((-246 . -641) 153316) ((-245 . -641) 153138) ((-818 . -922) 153117) ((-459 . -417) 153101) ((-603 . -19) 153085) ((-1139 . -1198) 153054) ((-1160 . -887) NIL) ((-1160 . -885) 153006) ((-603 . -605) 152983) ((-1191 . -612) 152950) ((-1169 . -612) 152932) ((-67 . -401) T) ((-1167 . -1044) 152867) ((-1160 . -1044) 152833) ((-780 . -283) 152766) ((-689 . -43) 152716) ((-483 . -283) 152701) ((-727 . -383) 152685) ((-866 . -713) 152650) ((-652 . -1061) T) ((-861 . -713) 152600) ((-1242 . -1009) 152566) ((-1221 . -1009) 152532) ((-1066 . -1181) 152507) ((-872 . -613) 152308) ((-872 . -612) 152290) ((-1178 . -503) 152227) ((-424 . -1028) 152205) ((-53 . -305) 152192) ((-1066 . -111) 152138) ((-494 . -503) 152075) ((-532 . -1204) T) ((-1134 . -503) 152046) ((-1160 . -338) 151998) ((-1160 . -383) 151950) ((-443 . -105) T) ((-1086 . -1061) T) ((-246 . -39) T) ((-245 . -39) T) ((-780 . -1246) 151902) ((-783 . -1061) T) ((-781 . -1061) T) ((-727 . -901) 151879) ((-459 . -1061) T) ((-780 . -605) 151824) ((-64 . -503) 151808) ((-1041 . -1060) 151782) ((-929 . -1098) T) ((-531 . -503) 151766) ((-529 . -503) 151750) ((-510 . -503) 151734) ((-509 . -503) 151718) ((-740 . -922) 151697) ((-242 . -527) 151630) ((-1041 . -120) 151597) ((-1168 . -901) 151510) ((-235 . -641) 151470) ((-666 . -1110) T) ((-1167 . -901) 151376) ((-1160 . -901) 151209) ((-1122 . -901) 151193) ((-358 . -1144) T) ((-321 . -1060) 151175) ((-246 . -792) 151154) ((-246 . -795) 151105) ((-246 . -794) 151084) ((-245 . -792) 151063) ((-245 . -795) 151014) ((-245 . -794) 150993) ((-55 . -1061) T) ((-246 . -722) 150903) ((-245 . -722) 150813) ((-1199 . -1098) T) ((-666 . -23) T) ((-585 . -1061) T) ((-530 . -1061) T) ((-385 . -1060) 150778) ((-321 . -120) 150753) ((-78 . -389) T) ((-78 . -401) T) ((-1030 . -43) 150690) ((-689 . -406) 150672) ((-101 . -105) T) ((-707 . -1098) T) ((-1010 . -149) 150644) ((-385 . -120) 150593) ((-316 . -1214) 150572) ((-483 . -1009) 150538) ((-358 . -43) 150503) ((-45 . -376) 150475) ((-1010 . -151) 150447) ((-137 . -135) 150431) ((-131 . -135) 150415) ((-835 . -1060) 150385) ((-834 . -21) 150337) ((-828 . -1060) 150321) ((-834 . -25) 150273) ((-316 . -562) 150224) ((-572 . -829) T) ((-234 . -1204) T) ((-866 . -174) T) ((-861 . -174) T) ((-835 . -120) 150189) ((-828 . -120) 150168) ((-1242 . -612) 150150) ((-1221 . -612) 150132) ((-1221 . -613) 149803) ((-1166 . -910) 149782) ((-1121 . -910) 149761) ((-53 . -43) 149726) ((-1279 . -1110) T) ((-603 . -612) 149665) ((-603 . -613) 149626) ((-1277 . -1110) T) ((-234 . -1044) 149453) ((-1166 . -641) 149378) ((-1121 . -641) 149303) ((-714 . -612) 149285) ((-852 . -641) 149259) ((-1279 . -23) T) ((-1277 . -23) T) ((-1164 . -225) 149243) ((-1041 . -1054) T) ((-1178 . -283) 149222) ((-171 . -374) 149173) ((-1011 . -1204) T) ((-49 . -23) T) ((-1285 . -105) T) ((-1199 . -713) 149070) ((-494 . -283) 149049) ((-589 . -1098) T) ((-1185 . -1098) T) ((-1139 . -1107) 149018) ((-1102 . -1101) 148970) ((-396 . -21) T) ((-396 . -25) T) ((-156 . -1110) T) ((-1011 . -1044) 148930) ((-1011 . -885) 148912) ((-1011 . -887) 148894) ((-739 . -105) T) ((-235 . -722) T) ((-619 . -225) 148878) ((-617 . -21) T) ((-286 . -562) T) ((-617 . -25) T) ((-707 . -713) 148843) ((-385 . -1054) T) ((-234 . -383) 148812) ((-220 . -285) 148787) ((-146 . -285) 148755) ((-215 . -1061) T) ((-126 . -225) 148732) ((-64 . -283) 148709) ((-156 . -23) T) ((-529 . -283) 148686) ((-327 . -527) 148619) ((-509 . -283) 148596) ((-385 . -240) T) ((-385 . -227) T) ((-863 . -612) 148578) ((-835 . -1054) T) ((-828 . -1054) T) ((-780 . -612) 148560) ((-780 . -613) NIL) ((-708 . -956) 148529) ((-696 . -848) T) ((-483 . -612) 148511) ((-828 . -227) 148490) ((-140 . -848) T) ((-1205 . -1204) T) ((-652 . -1098) T) ((-1178 . -605) 148469) ((-555 . -1181) 148448) ((-336 . -1098) T) ((-316 . -368) 148427) ((-413 . -151) 148406) ((-413 . -149) 148385) ((-1206 . -155) 148367) ((-238 . -1098) T) ((-972 . -1110) 148266) ((-234 . -901) 148198) ((-816 . -1110) 148108) ((-648 . -850) 148092) ((-494 . -605) 148071) ((-555 . -111) 148021) ((-1011 . -383) 148003) ((-1011 . -338) 147985) ((-99 . -1098) T) ((-972 . -23) 147796) ((-493 . -21) T) ((-493 . -25) T) ((-816 . -23) 147666) ((-1170 . -612) 147648) ((-64 . -19) 147632) ((-1170 . -613) 147554) ((-1166 . -722) T) ((-1121 . -722) T) ((-529 . -19) 147538) ((-509 . -19) 147522) ((-64 . -605) 147499) ((-1086 . -1098) T) ((-902 . -105) 147477) ((-852 . -722) T) ((-783 . -1098) T) ((-529 . -605) 147454) ((-509 . -605) 147431) ((-781 . -1098) T) ((-781 . -1068) 147398) ((-467 . -1098) T) ((-459 . -1098) T) ((-1254 . -105) T) ((-589 . -713) 147373) ((-261 . -105) 147351) ((-642 . -1098) T) ((-1254 . -281) 147317) ((-1250 . -52) 147294) ((-1244 . -105) T) ((-1243 . -52) 147264) ((-1011 . -901) NIL) ((-1222 . -52) 147241) ((-622 . -1110) T) ((-666 . -138) T) ((-1216 . -52) 147218) ((-1199 . -174) 147169) ((-1167 . -303) 147148) ((-1160 . -303) 147127) ((-1080 . -1214) 147078) ((-273 . -1098) T) ((-90 . -446) T) ((-90 . -401) T) ((-1080 . -562) 147029) ((-776 . -612) 147011) ((-55 . -1098) T) ((-707 . -174) T) ((-597 . -52) 146988) ((-217 . -641) 146953) ((-585 . -1098) T) ((-541 . -1098) T) ((-530 . -1098) T) ((-364 . -1214) T) ((-357 . -1214) T) ((-345 . -1214) T) ((-501 . -821) T) ((-501 . -922) T) ((-316 . -1110) T) ((-112 . -1214) T) ((-739 . -305) 146940) ((-339 . -848) T) ((-210 . -922) T) ((-210 . -821) T) ((-710 . -1060) 146910) ((-364 . -562) T) ((-357 . -562) T) ((-345 . -562) T) ((-112 . -562) T) ((-1160 . -1028) NIL) ((-652 . -713) 146880) ((-866 . -287) T) ((-861 . -287) T) ((-316 . -23) T) ((-72 . -1204) T) ((-1007 . -612) 146847) ((-689 . -225) 146829) ((-238 . -713) 146811) ((-710 . -120) 146776) ((-638 . -39) T) ((-242 . -503) 146760) ((-1100 . -1095) 146744) ((-173 . -1098) T) ((-959 . -910) 146723) ((-496 . -910) 146702) ((-1281 . -21) T) ((-1281 . -25) T) ((-1279 . -138) T) ((-1277 . -138) T) ((-1086 . -713) 146551) ((-1065 . -641) 146538) ((-959 . -641) 146463) ((-783 . -713) 146292) ((-545 . -612) 146274) ((-545 . -613) 146255) ((-781 . -713) 146104) ((-1270 . -105) T) ((-1077 . -105) T) ((-387 . -25) T) ((-387 . -21) T) ((-496 . -641) 146029) ((-467 . -713) 146000) ((-459 . -713) 145849) ((-995 . -105) T) ((-733 . -105) T) ((-1285 . -1144) T) ((-538 . -25) T) ((-1222 . -1204) 145828) ((-1255 . -612) 145794) ((-1222 . -887) NIL) ((-1222 . -885) 145746) ((-143 . -105) T) ((-49 . -138) T) ((-1178 . -613) NIL) ((-1178 . -612) 145728) ((-1135 . -1119) 145673) ((-343 . -1061) T) ((-660 . -612) 145655) ((-286 . -1110) T) ((-359 . -612) 145637) ((-356 . -612) 145619) ((-344 . -612) 145601) ((-259 . -613) 145349) ((-259 . -612) 145331) ((-244 . -612) 145313) ((-244 . -613) 145174) ((-1051 . -1198) 145103) ((-902 . -305) 145041) ((-1243 . -1044) 144976) ((-1222 . -1044) 144942) ((-1199 . -527) 144909) ((-1134 . -612) 144891) ((-820 . -722) T) ((-585 . -713) 144856) ((-603 . -285) 144833) ((-530 . -713) 144778) ((-494 . -613) NIL) ((-494 . -612) 144760) ((-312 . -105) T) ((-261 . -305) 144698) ((-309 . -105) T) ((-286 . -23) T) ((-156 . -138) T) ((-974 . -612) 144680) ((-911 . -612) 144662) ((-392 . -722) T) ((-872 . -1060) 144614) ((-911 . -613) 144596) ((-872 . -120) 144527) ((-739 . -43) 144451) ((-142 . -105) T) ((-123 . -105) T) ((-708 . -1234) 144435) ((-710 . -1054) T) ((-689 . -353) NIL) ((-531 . -612) 144402) ((-385 . -796) T) ((-215 . -1098) T) ((-385 . -793) T) ((-217 . -795) T) ((-217 . -792) T) ((-64 . -613) 144363) ((-64 . -612) 144302) ((-217 . -722) T) ((-529 . -613) 144263) ((-529 . -612) 144202) ((-510 . -612) 144169) ((-509 . -613) 144130) ((-509 . -612) 144069) ((-1080 . -368) 144020) ((-45 . -417) 143997) ((-82 . -1204) T) ((-118 . -105) T) ((-973 . -978) 143981) ((-871 . -910) NIL) ((-364 . -329) 143965) ((-364 . -368) T) ((-357 . -329) 143949) ((-357 . -368) T) ((-345 . -329) 143933) ((-345 . -368) T) ((-312 . -281) 143912) ((-112 . -368) T) ((-75 . -1204) T) ((-1222 . -338) 143864) ((-871 . -641) 143809) ((-1222 . -383) 143761) ((-972 . -138) 143616) ((-816 . -138) 143486) ((-965 . -644) 143470) ((-1086 . -174) 143381) ((-1065 . -795) T) ((-965 . -379) 143365) ((-1065 . -792) T) ((-118 . -117) T) ((-780 . -285) 143310) ((-783 . -174) 143201) ((-781 . -174) 143112) ((-817 . -52) 143074) ((-1065 . -722) T) ((-327 . -503) 143058) ((-959 . -722) T) ((-459 . -174) 142969) ((-242 . -283) 142946) ((-496 . -722) T) ((-1270 . -305) 142884) ((-1254 . -43) 142781) ((-1250 . -901) 142694) ((-1243 . -901) 142600) ((-1242 . -1060) 142435) ((-1222 . -901) 142268) ((-1221 . -1060) 142076) ((-1216 . -901) 141989) ((-1208 . -105) T) ((-1199 . -287) 141968) ((-1139 . -155) 141952) ((-1075 . -105) T) ((-933 . -962) T) ((-733 . -305) 141890) ((-80 . -1204) T) ((-171 . -910) 141843) ((-34 . -105) T) ((-660 . -388) 141815) ((-30 . -962) T) ((-1 . -612) 141797) ((-1116 . -105) T) ((-1080 . -23) T) ((-55 . -616) 141781) ((-1080 . -1110) T) ((-1010 . -415) 141753) ((-597 . -901) 141666) ((-444 . -105) T) ((-143 . -305) NIL) ((-872 . -1054) T) ((-834 . -848) 141645) ((-86 . -1204) T) ((-707 . -287) T) ((-45 . -1061) T) ((-585 . -174) T) ((-530 . -174) T) ((-524 . -612) 141627) ((-171 . -641) 141537) ((-520 . -612) 141519) ((-355 . -151) 141501) ((-355 . -149) T) ((-364 . -1110) T) ((-357 . -1110) T) ((-345 . -1110) T) ((-1011 . -303) T) ((-916 . -303) T) ((-872 . -240) T) ((-112 . -1110) T) ((-872 . -227) 141480) ((-739 . -406) 141464) ((-1242 . -120) 141278) ((-1221 . -120) 141060) ((-242 . -1246) 141044) ((-572 . -846) T) ((-364 . -23) T) ((-358 . -353) T) ((-312 . -305) 141031) ((-309 . -305) 140927) ((-357 . -23) T) ((-316 . -138) T) ((-345 . -23) T) ((-1011 . -1028) T) ((-112 . -23) T) ((-242 . -605) 140904) ((-1244 . -43) 140761) ((-1231 . -910) 140740) ((-121 . -1098) T) ((-1042 . -105) T) ((-1231 . -641) 140665) ((-871 . -795) NIL) ((-853 . -641) 140639) ((-871 . -792) NIL) ((-817 . -887) NIL) ((-871 . -722) T) ((-1086 . -527) 140502) ((-783 . -527) 140448) ((-781 . -527) 140400) ((-579 . -641) 140387) ((-817 . -1044) 140215) ((-459 . -527) 140153) ((-394 . -395) T) ((-65 . -1204) T) ((-617 . -848) 140132) ((-513 . -655) T) ((-1139 . -984) 140101) ((-863 . -1060) 140053) ((-780 . -1060) 140005) ((-1010 . -457) T) ((-694 . -846) T) ((-523 . -793) T) ((-483 . -1060) 139840) ((-343 . -1098) T) ((-309 . -1144) NIL) ((-286 . -138) T) ((-400 . -1098) T) ((-870 . -1061) T) ((-689 . -376) 139807) ((-863 . -120) 139738) ((-780 . -120) 139669) ((-215 . -616) 139646) ((-327 . -283) 139623) ((-1208 . -305) NIL) ((-483 . -120) 139437) ((-1242 . -1054) T) ((-1221 . -1054) T) ((-817 . -383) 139421) ((-171 . -722) T) ((-648 . -105) T) ((-1242 . -240) 139400) ((-1242 . -227) 139352) ((-1221 . -227) 139257) ((-1221 . -240) 139236) ((-1010 . -408) NIL) ((-666 . -634) 139184) ((-312 . -43) 139094) ((-309 . -43) 139023) ((-74 . -612) 139005) ((-316 . -506) 138971) ((-1178 . -285) 138950) ((-1111 . -1110) 138860) ((-88 . -1204) T) ((-66 . -612) 138842) ((-494 . -285) 138821) ((-1272 . -1044) 138798) ((-1158 . -1098) T) ((-1111 . -23) 138668) ((-817 . -901) 138604) ((-1231 . -722) T) ((-1100 . -1204) T) ((-1086 . -287) 138535) ((-894 . -105) T) ((-783 . -287) 138446) ((-327 . -19) 138430) ((-64 . -285) 138407) ((-781 . -287) 138338) ((-853 . -722) T) ((-126 . -846) NIL) ((-529 . -285) 138315) ((-327 . -605) 138292) ((-509 . -285) 138269) ((-459 . -287) 138200) ((-1042 . -305) 138051) ((-579 . -722) T) ((-656 . -612) 138033) ((-242 . -613) 137994) ((-242 . -612) 137933) ((-1140 . -39) T) ((-950 . -1204) T) ((-343 . -713) 137878) ((-863 . -1054) T) ((-780 . -1054) T) ((-666 . -25) T) ((-666 . -21) T) ((-1116 . -1144) T) ((-483 . -1054) T) ((-630 . -423) 137843) ((-606 . -423) 137808) ((-928 . -1098) T) ((-863 . -227) T) ((-863 . -240) T) ((-780 . -227) 137767) ((-780 . -240) T) ((-585 . -287) T) ((-530 . -287) T) ((-1243 . -303) 137746) ((-483 . -227) 137698) ((-483 . -240) 137677) ((-1222 . -303) 137656) ((-1080 . -138) T) ((-872 . -796) 137635) ((-148 . -105) T) ((-45 . -1098) T) ((-872 . -793) 137614) ((-638 . -1017) 137598) ((-584 . -1061) T) ((-572 . -1061) T) ((-508 . -1061) T) ((-413 . -457) T) ((-364 . -138) T) ((-312 . -406) 137582) ((-309 . -406) 137543) ((-357 . -138) T) ((-345 . -138) T) ((-1222 . -1028) NIL) ((-1092 . -612) 137510) ((-112 . -138) T) ((-1116 . -43) 137497) ((-923 . -1098) T) ((-769 . -1098) T) ((-667 . -1098) T) ((-696 . -151) T) ((-1164 . -417) 137481) ((-125 . -151) T) ((-1279 . -21) T) ((-1279 . -25) T) ((-1277 . -21) T) ((-1277 . -25) T) ((-660 . -1060) 137465) ((-538 . -848) T) ((-513 . -848) T) ((-359 . -1060) 137417) ((-356 . -1060) 137369) ((-344 . -1060) 137321) ((-246 . -1204) T) ((-245 . -1204) T) ((-259 . -1060) 137164) ((-244 . -1060) 137007) ((-660 . -120) 136986) ((-359 . -120) 136917) ((-356 . -120) 136848) ((-344 . -120) 136779) ((-259 . -120) 136601) ((-244 . -120) 136423) ((-818 . -1214) 136402) ((-619 . -417) 136386) ((-49 . -21) T) ((-49 . -25) T) ((-816 . -634) 136292) ((-818 . -562) 136271) ((-246 . -1044) 136098) ((-245 . -1044) 135925) ((-136 . -128) 135909) ((-911 . -1060) 135874) ((-694 . -1061) T) ((-708 . -105) T) ((-220 . -644) 135856) ((-146 . -644) 135831) ((-343 . -174) T) ((-220 . -379) 135813) ((-146 . -379) 135788) ((-156 . -21) T) ((-156 . -25) T) ((-93 . -612) 135770) ((-911 . -120) 135719) ((-45 . -713) 135664) ((-870 . -1098) T) ((-327 . -613) 135625) ((-327 . -612) 135564) ((-1221 . -793) 135517) ((-1164 . -1061) T) ((-1221 . -796) 135470) ((-246 . -383) 135439) ((-245 . -383) 135408) ((-866 . -612) 135390) ((-861 . -612) 135372) ((-648 . -43) 135342) ((-607 . -39) T) ((-497 . -1110) 135252) ((-484 . -39) T) ((-1111 . -138) 135122) ((-1172 . -562) 135101) ((-972 . -25) 134912) ((-875 . -612) 134894) ((-972 . -21) 134849) ((-816 . -21) 134759) ((-816 . -25) 134610) ((-1166 . -52) 134587) ((-619 . -1061) T) ((-1121 . -52) 134559) ((-468 . -1098) T) ((-359 . -1054) T) ((-356 . -1054) T) ((-497 . -23) 134429) ((-344 . -1054) T) ((-259 . -1054) T) ((-244 . -1054) T) ((-1041 . -641) 134403) ((-126 . -1061) T) ((-965 . -39) T) ((-740 . -1214) 134382) ((-359 . -227) 134361) ((-359 . -240) T) ((-356 . -227) 134340) ((-356 . -240) T) ((-344 . -227) 134319) ((-244 . -326) 134276) ((-344 . -240) T) ((-259 . -326) 134248) ((-259 . -227) 134227) ((-1150 . -155) 134211) ((-740 . -562) 134122) ((-246 . -901) 134054) ((-245 . -901) 133986) ((-1082 . -848) T) ((-1225 . -1204) T) ((-420 . -1110) T) ((-1206 . -105) T) ((-1058 . -23) T) ((-911 . -1054) T) ((-321 . -641) 133968) ((-1030 . -846) T) ((-1199 . -1009) 133934) ((-1167 . -922) 133913) ((-1160 . -922) 133892) ((-911 . -240) T) ((-818 . -368) 133871) ((-391 . -23) T) ((-137 . -1098) 133849) ((-131 . -1098) 133827) ((-911 . -227) T) ((-1160 . -821) NIL) ((-385 . -641) 133792) ((-870 . -713) 133779) ((-1210 . -1098) T) ((-1051 . -155) 133744) ((-45 . -174) T) ((-689 . -417) 133726) ((-708 . -305) 133713) ((-835 . -641) 133673) ((-828 . -641) 133647) ((-316 . -25) T) ((-316 . -21) T) ((-652 . -283) 133626) ((-584 . -1098) T) ((-572 . -1098) T) ((-508 . -1098) T) ((-242 . -285) 133603) ((-309 . -225) 133564) ((-1166 . -887) NIL) ((-1121 . -887) 133423) ((-1166 . -1044) 133303) ((-1121 . -1044) 133186) ((-852 . -1044) 133082) ((-783 . -283) 133009) ((-929 . -612) 132991) ((-818 . -1110) T) ((-1041 . -722) T) ((-603 . -644) 132975) ((-1051 . -984) 132904) ((-1006 . -105) T) ((-818 . -23) T) ((-708 . -1144) 132882) ((-689 . -1061) T) ((-603 . -379) 132866) ((-355 . -457) T) ((-343 . -287) T) ((-1260 . -1098) T) ((-469 . -105) T) ((-405 . -105) T) ((-286 . -21) T) ((-286 . -25) T) ((-366 . -722) T) ((-706 . -1098) T) ((-694 . -1098) T) ((-366 . -482) T) ((-1206 . -305) NIL) ((-1199 . -612) 132848) ((-1166 . -383) 132832) ((-1121 . -383) 132816) ((-1030 . -417) 132778) ((-143 . -223) 132760) ((-385 . -795) T) ((-385 . -792) T) ((-870 . -174) T) ((-385 . -722) T) ((-707 . -612) 132742) ((-708 . -43) 132571) ((-1259 . -1257) 132555) ((-355 . -408) T) ((-1259 . -1098) 132505) ((-584 . -713) 132492) ((-572 . -713) 132479) ((-508 . -713) 132444) ((-863 . -1276) 132428) ((-312 . -624) 132407) ((-835 . -722) T) ((-828 . -722) T) ((-1164 . -1098) T) ((-638 . -1204) T) ((-1080 . -634) 132355) ((-1166 . -901) 132298) ((-1121 . -901) 132282) ((-656 . -1060) 132266) ((-112 . -634) 132248) ((-497 . -138) 132118) ((-780 . -644) 132070) ((-1172 . -1110) T) ((-863 . -374) T) ((-959 . -52) 132039) ((-740 . -1110) T) ((-619 . -1098) T) ((-656 . -120) 132018) ((-327 . -285) 131995) ((-496 . -52) 131952) ((-1172 . -23) T) ((-130 . -1098) T) ((-126 . -1098) T) ((-106 . -105) 131930) ((-740 . -23) T) ((-1269 . -1110) T) ((-1058 . -138) T) ((-1030 . -1061) T) ((-820 . -1044) 131914) ((-1010 . -720) 131886) ((-1269 . -23) T) ((-694 . -713) 131851) ((-589 . -612) 131833) ((-392 . -1044) 131817) ((-358 . -1061) T) ((-391 . -138) T) ((-323 . -1044) 131801) ((-217 . -887) 131783) ((-1011 . -922) T) ((-96 . -39) T) ((-1011 . -821) T) ((-916 . -922) T) ((-501 . -1214) T) ((-1185 . -612) 131765) ((-1103 . -1098) T) ((-210 . -1214) T) ((-1006 . -305) 131730) ((-217 . -1044) 131690) ((-45 . -287) T) ((-1080 . -21) T) ((-1080 . -25) T) ((-1116 . -829) T) ((-501 . -562) T) ((-364 . -25) T) ((-210 . -562) T) ((-364 . -21) T) ((-357 . -25) T) ((-357 . -21) T) ((-710 . -641) 131650) ((-345 . -25) T) ((-345 . -21) T) ((-112 . -25) T) ((-112 . -21) T) ((-53 . -1061) T) ((-1164 . -713) 131479) ((-584 . -174) T) ((-572 . -174) T) ((-508 . -174) T) ((-652 . -612) 131461) ((-733 . -732) 131445) ((-336 . -612) 131427) ((-238 . -612) 131409) ((-73 . -389) T) ((-73 . -401) T) ((-1100 . -111) 131393) ((-1065 . -887) 131375) ((-959 . -887) 131300) ((-647 . -1110) T) ((-619 . -713) 131287) ((-496 . -887) NIL) ((-1139 . -105) T) ((-1065 . -1044) 131269) ((-99 . -612) 131251) ((-493 . -151) T) ((-959 . -1044) 131131) ((-126 . -713) 131076) ((-647 . -23) T) ((-496 . -1044) 130952) ((-1086 . -613) NIL) ((-1086 . -612) 130934) ((-783 . -613) NIL) ((-783 . -612) 130895) ((-781 . -613) 130529) ((-781 . -612) 130443) ((-1111 . -634) 130349) ((-467 . -612) 130331) ((-459 . -612) 130313) ((-459 . -613) 130174) ((-1042 . -223) 130120) ((-136 . -39) T) ((-818 . -138) T) ((-872 . -910) 130099) ((-642 . -612) 130081) ((-359 . -1276) 130065) ((-356 . -1276) 130049) ((-344 . -1276) 130033) ((-137 . -527) 129966) ((-131 . -527) 129899) ((-524 . -793) T) ((-524 . -796) T) ((-523 . -795) T) ((-106 . -305) 129837) ((-214 . -105) 129815) ((-220 . -39) T) ((-146 . -39) T) ((-689 . -1098) T) ((-694 . -174) T) ((-1210 . -527) NIL) ((-872 . -641) 129767) ((-1006 . -43) 129715) ((-70 . -390) T) ((-273 . -612) 129697) ((-70 . -401) T) ((-959 . -383) 129681) ((-870 . -287) T) ((-55 . -612) 129663) ((-866 . -1060) 129628) ((-861 . -1060) 129578) ((-585 . -612) 129560) ((-585 . -613) 129542) ((-496 . -383) 129526) ((-541 . -612) 129508) ((-530 . -612) 129490) ((-911 . -1276) 129477) ((-871 . -1204) T) ((-866 . -120) 129426) ((-696 . -457) T) ((-861 . -120) 129353) ((-508 . -527) 129319) ((-501 . -368) T) ((-359 . -374) 129298) ((-356 . -374) 129277) ((-344 . -374) 129256) ((-210 . -368) T) ((-710 . -722) T) ((-125 . -457) T) ((-1164 . -174) 129147) ((-1280 . -1271) 129131) ((-871 . -885) 129108) ((-871 . -887) NIL) ((-972 . -848) 129007) ((-816 . -848) 128958) ((-648 . -650) 128942) ((-1191 . -39) T) ((-173 . -612) 128924) ((-1111 . -21) 128834) ((-1111 . -25) 128685) ((-975 . -1098) T) ((-871 . -1044) 128662) ((-959 . -901) 128643) ((-1231 . -52) 128620) ((-911 . -374) T) ((-64 . -644) 128604) ((-529 . -644) 128588) ((-496 . -901) 128565) ((-76 . -446) T) ((-76 . -401) T) ((-509 . -644) 128549) ((-64 . -379) 128533) ((-619 . -174) T) ((-529 . -379) 128517) ((-509 . -379) 128501) ((-828 . -704) 128485) ((-1166 . -303) 128464) ((-1172 . -138) T) ((-126 . -174) T) ((-740 . -138) T) ((-1139 . -305) 128402) ((-171 . -1204) T) ((-630 . -742) 128386) ((-606 . -742) 128370) ((-1269 . -138) T) ((-1243 . -922) 128349) ((-1222 . -922) 128328) ((-1222 . -821) NIL) ((-689 . -713) 128278) ((-1221 . -910) 128231) ((-1030 . -1098) T) ((-871 . -383) 128208) ((-871 . -338) 128185) ((-906 . -1110) T) ((-171 . -885) 128169) ((-171 . -887) 128094) ((-1259 . -527) 128027) ((-501 . -1110) T) ((-358 . -1098) T) ((-210 . -1110) T) ((-81 . -446) T) ((-81 . -401) T) ((-1242 . -641) 127924) ((-171 . -1044) 127820) ((-316 . -848) T) ((-866 . -1054) T) ((-861 . -1054) T) ((-1221 . -641) 127690) ((-872 . -795) 127669) ((-872 . -792) 127648) ((-1281 . -1274) 127627) ((-872 . -722) T) ((-501 . -23) T) ((-215 . -612) 127609) ((-175 . -457) T) ((-214 . -305) 127547) ((-91 . -446) T) ((-91 . -401) T) ((-866 . -240) T) ((-210 . -23) T) ((-861 . -240) T) ((-739 . -417) 127531) ((-517 . -540) 127406) ((-584 . -287) T) ((-572 . -287) T) ((-672 . -1044) 127390) ((-508 . -287) T) ((-1164 . -527) 127336) ((-142 . -479) 127291) ((-116 . -1098) T) ((-53 . -1098) T) ((-708 . -225) 127275) ((-871 . -901) NIL) ((-1231 . -887) NIL) ((-890 . -105) T) ((-886 . -105) T) ((-394 . -1098) T) ((-171 . -383) 127259) ((-171 . -338) 127243) ((-1231 . -1044) 127123) ((-853 . -1044) 127019) ((-1135 . -105) T) ((-647 . -138) T) ((-126 . -527) 126882) ((-656 . -793) 126861) ((-656 . -796) 126840) ((-579 . -1044) 126822) ((-290 . -1266) 126792) ((-859 . -105) T) ((-971 . -562) 126771) ((-1199 . -1060) 126654) ((-497 . -634) 126560) ((-905 . -1098) T) ((-1030 . -713) 126497) ((-707 . -1060) 126462) ((-863 . -641) 126414) ((-780 . -641) 126366) ((-603 . -39) T) ((-1140 . -1204) T) ((-1199 . -120) 126228) ((-483 . -641) 126125) ((-358 . -713) 126070) ((-171 . -901) 126029) ((-694 . -287) T) ((-739 . -1061) T) ((-689 . -174) T) ((-707 . -120) 125978) ((-1285 . -1061) T) ((-1231 . -383) 125962) ((-424 . -1214) 125940) ((-309 . -846) NIL) ((-424 . -562) T) ((-217 . -303) T) ((-1221 . -792) 125893) ((-1221 . -795) 125846) ((-33 . -1096) T) ((-1242 . -722) T) ((-1221 . -722) T) ((-53 . -713) 125811) ((-1164 . -287) 125722) ((-217 . -1028) T) ((-355 . -1266) 125699) ((-1244 . -417) 125665) ((-714 . -722) T) ((-1231 . -901) 125608) ((-121 . -612) 125590) ((-121 . -613) 125572) ((-714 . -482) T) ((-497 . -21) 125482) ((-137 . -503) 125466) ((-131 . -503) 125450) ((-497 . -25) 125301) ((-619 . -287) T) ((-780 . -39) T) ((-1210 . -503) 125283) ((-589 . -1060) 125258) ((-1209 . -62) 125224) ((-443 . -1098) T) ((-1065 . -303) T) ((-126 . -287) T) ((-1102 . -105) T) ((-1010 . -105) T) ((-589 . -120) 125185) ((-1254 . -1061) T) ((-1135 . -305) 125123) ((-1199 . -1054) T) ((-1065 . -1028) T) ((-71 . -1204) T) ((-1058 . -25) T) ((-1058 . -21) T) ((-707 . -1054) T) ((-391 . -21) T) ((-391 . -25) T) ((-689 . -527) NIL) ((-1030 . -174) T) ((-707 . -240) T) ((-1065 . -554) T) ((-863 . -722) T) ((-780 . -722) T) ((-515 . -105) T) ((-358 . -174) T) ((-343 . -612) 125105) ((-400 . -612) 125087) ((-483 . -722) T) ((-1116 . -846) T) ((-893 . -1044) 125055) ((-112 . -848) T) ((-652 . -1060) 125039) ((-501 . -138) T) ((-1244 . -1061) T) ((-210 . -138) T) ((-238 . -1060) 125021) ((-1150 . -105) 124999) ((-101 . -1098) T) ((-242 . -662) 124983) ((-242 . -644) 124967) ((-652 . -120) 124946) ((-312 . -417) 124930) ((-242 . -379) 124914) ((-1153 . -229) 124861) ((-1006 . -225) 124845) ((-238 . -120) 124820) ((-79 . -1204) T) ((-53 . -174) T) ((-696 . -393) T) ((-696 . -147) T) ((-1280 . -105) T) ((-1086 . -1060) 124663) ((-259 . -910) 124642) ((-244 . -910) 124621) ((-783 . -1060) 124444) ((-781 . -1060) 124287) ((-607 . -1204) T) ((-1158 . -612) 124269) ((-1086 . -120) 124091) ((-1051 . -105) T) ((-484 . -1204) T) ((-467 . -1060) 124062) ((-459 . -1060) 123905) ((-660 . -641) 123889) ((-871 . -303) T) ((-783 . -120) 123691) ((-781 . -120) 123513) ((-359 . -641) 123465) ((-356 . -641) 123417) ((-344 . -641) 123369) ((-259 . -641) 123294) ((-244 . -641) 123219) ((-1152 . -848) T) ((-467 . -120) 123180) ((-459 . -120) 123002) ((-1087 . -1044) 122986) ((-1076 . -1044) 122963) ((-1007 . -39) T) ((-965 . -1204) T) ((-136 . -1017) 122947) ((-971 . -1110) T) ((-871 . -1028) NIL) ((-731 . -1110) T) ((-711 . -1110) T) ((-1259 . -503) 122931) ((-1135 . -43) 122891) ((-971 . -23) T) ((-911 . -641) 122856) ((-841 . -105) T) ((-818 . -21) T) ((-818 . -25) T) ((-731 . -23) T) ((-711 . -23) T) ((-114 . -655) T) ((-776 . -722) T) ((-585 . -1060) 122821) ((-530 . -1060) 122766) ((-221 . -62) 122724) ((-458 . -23) T) ((-413 . -105) T) ((-258 . -105) T) ((-776 . -482) T) ((-973 . -105) T) ((-689 . -287) T) ((-859 . -43) 122694) ((-1210 . -283) 122669) ((-585 . -120) 122618) ((-530 . -120) 122535) ((-740 . -634) 122483) ((-424 . -1110) T) ((-312 . -1061) 122373) ((-309 . -1061) T) ((-928 . -612) 122355) ((-739 . -1098) T) ((-652 . -1054) T) ((-1285 . -1098) T) ((-171 . -303) 122286) ((-424 . -23) T) ((-45 . -612) 122268) ((-45 . -613) 122252) ((-112 . -1000) 122234) ((-125 . -869) 122218) ((-53 . -527) 122184) ((-1191 . -1017) 122168) ((-1178 . -39) T) ((-923 . -612) 122150) ((-1111 . -848) 122101) ((-769 . -612) 122083) ((-667 . -612) 122065) ((-1150 . -305) 122003) ((-1090 . -1204) T) ((-494 . -39) T) ((-1086 . -1054) T) ((-493 . -457) T) ((-866 . -1276) 121978) ((-861 . -1276) 121938) ((-1134 . -39) T) ((-783 . -1054) T) ((-781 . -1054) T) ((-640 . -229) 121922) ((-627 . -229) 121868) ((-1231 . -303) 121847) ((-1210 . -19) 121829) ((-1210 . -605) 121804) ((-1086 . -326) 121765) ((-459 . -1054) T) ((-1172 . -21) T) ((-1086 . -227) 121744) ((-783 . -326) 121721) ((-783 . -227) T) ((-781 . -326) 121693) ((-327 . -644) 121677) ((-727 . -1214) 121656) ((-1172 . -25) T) ((-64 . -39) T) ((-531 . -39) T) ((-529 . -39) T) ((-459 . -326) 121635) ((-327 . -379) 121619) ((-510 . -39) T) ((-509 . -39) T) ((-1010 . -1144) NIL) ((-630 . -105) T) ((-606 . -105) T) ((-727 . -562) 121550) ((-359 . -722) T) ((-356 . -722) T) ((-344 . -722) T) ((-259 . -722) T) ((-244 . -722) T) ((-740 . -25) T) ((-740 . -21) T) ((-1051 . -305) 121458) ((-1269 . -21) T) ((-1269 . -25) T) ((-902 . -1098) 121436) ((-55 . -1054) T) ((-1254 . -1098) T) ((-1168 . -562) 121415) ((-1167 . -1214) 121394) ((-1167 . -562) 121345) ((-1160 . -1214) 121324) ((-585 . -1054) T) ((-530 . -1054) T) ((-517 . -105) T) ((-1030 . -287) T) ((-366 . -1044) 121308) ((-321 . -1044) 121292) ((-261 . -1098) 121270) ((-385 . -887) 121252) ((-1160 . -562) 121203) ((-1122 . -562) 121182) ((-1010 . -43) 121127) ((-800 . -1110) T) ((-911 . -722) T) ((-585 . -240) T) ((-585 . -227) T) ((-530 . -227) T) ((-530 . -240) T) ((-739 . -713) 121051) ((-358 . -287) T) ((-640 . -690) 121035) ((-385 . -1044) 120995) ((-261 . -260) 120979) ((-1116 . -1061) T) ((-106 . -135) 120963) ((-800 . -23) T) ((-1279 . -1274) 120939) ((-1277 . -1274) 120918) ((-1259 . -283) 120895) ((-413 . -305) 120860) ((-1244 . -1098) T) ((-1164 . -283) 120787) ((-870 . -612) 120769) ((-835 . -1044) 120738) ((-197 . -788) T) ((-196 . -788) T) ((-34 . -37) 120715) ((-195 . -788) T) ((-194 . -788) T) ((-193 . -788) T) ((-192 . -788) T) ((-191 . -788) T) ((-190 . -788) T) ((-189 . -788) T) ((-188 . -788) T) ((-508 . -1009) T) ((-272 . -837) T) ((-271 . -837) T) ((-270 . -837) T) ((-269 . -837) T) ((-53 . -287) T) ((-268 . -837) T) ((-267 . -837) T) ((-266 . -837) T) ((-187 . -788) T) ((-611 . -848) T) ((-648 . -417) 120699) ((-114 . -848) T) ((-647 . -21) T) ((-647 . -25) T) ((-468 . -612) 120681) ((-1280 . -43) 120651) ((-1259 . -19) 120635) ((-126 . -283) 120565) ((-218 . -105) T) ((-145 . -105) T) ((-1259 . -605) 120542) ((-1270 . -1098) T) ((-1254 . -713) 120439) ((-1077 . -1098) T) ((-995 . -1098) T) ((-971 . -138) T) ((-733 . -1098) T) ((-731 . -138) T) ((-711 . -138) T) ((-524 . -794) T) ((-413 . -1144) 120417) ((-458 . -138) T) ((-524 . -795) T) ((-215 . -1054) T) ((-290 . -105) 120199) ((-143 . -1098) T) ((-694 . -1009) T) ((-96 . -1204) T) ((-137 . -612) 120166) ((-131 . -612) 120133) ((-739 . -174) T) ((-1285 . -174) T) ((-1210 . -613) 120115) ((-1210 . -612) 120097) ((-1167 . -368) 120076) ((-1160 . -368) 120055) ((-312 . -1098) T) ((-424 . -138) T) ((-309 . -1098) T) ((-413 . -43) 120007) ((-1129 . -105) T) ((-1244 . -713) 119864) ((-648 . -1061) T) ((-316 . -149) 119843) ((-316 . -151) 119822) ((-142 . -1098) T) ((-123 . -1098) T) ((-855 . -105) T) ((-584 . -612) 119804) ((-572 . -613) 119703) ((-572 . -612) 119685) ((-508 . -612) 119667) ((-508 . -613) 119612) ((-499 . -23) T) ((-497 . -848) 119563) ((-118 . -1098) T) ((-501 . -634) 119545) ((-780 . -1017) 119497) ((-210 . -634) 119479) ((-217 . -410) T) ((-656 . -641) 119463) ((-1166 . -922) 119442) ((-727 . -1110) T) ((-355 . -105) T) ((-819 . -848) T) ((-727 . -23) T) ((-343 . -1060) 119387) ((-1152 . -1151) T) ((-1140 . -111) 119371) ((-1254 . -174) 119322) ((-1168 . -1110) T) ((-1167 . -1110) T) ((-1160 . -1110) T) ((-1122 . -1110) T) ((-528 . -1044) 119306) ((-343 . -120) 119223) ((-218 . -305) NIL) ((-145 . -305) NIL) ((-1011 . -1214) T) ((-136 . -1204) T) ((-916 . -1214) T) ((-1260 . -612) 119205) ((-1208 . -1098) T) ((-689 . -283) NIL) ((-1168 . -23) T) ((-1167 . -23) T) ((-1160 . -23) T) ((-1135 . -225) 119189) ((-1122 . -23) T) ((-1075 . -1098) T) ((-1011 . -562) T) ((-916 . -562) T) ((-800 . -138) T) ((-220 . -1204) T) ((-146 . -1204) T) ((-739 . -527) 119155) ((-706 . -612) 119137) ((-34 . -1098) T) ((-312 . -713) 119047) ((-309 . -713) 118976) ((-694 . -612) 118958) ((-694 . -613) 118903) ((-413 . -406) 118887) ((-444 . -1098) T) ((-501 . -25) T) ((-501 . -21) T) ((-1116 . -1098) T) ((-210 . -25) T) ((-210 . -21) T) ((-708 . -417) 118871) ((-710 . -1044) 118840) ((-1259 . -612) 118779) ((-1259 . -613) 118740) ((-1244 . -174) T) ((-242 . -39) T) ((-1164 . -613) NIL) ((-1164 . -612) 118722) ((-932 . -982) T) ((-1191 . -1204) T) ((-656 . -792) 118701) ((-656 . -795) 118680) ((-404 . -401) T) ((-535 . -105) 118658) ((-1042 . -1098) T) ((-214 . -1002) 118642) ((-518 . -105) T) ((-619 . -612) 118624) ((-50 . -848) NIL) ((-619 . -613) 118601) ((-1042 . -609) 118576) ((-902 . -527) 118509) ((-343 . -1054) T) ((-130 . -612) 118491) ((-126 . -613) NIL) ((-126 . -612) 118473) ((-872 . -1204) T) ((-666 . -423) 118457) ((-666 . -1119) 118402) ((-261 . -527) 118335) ((-513 . -155) 118317) ((-343 . -227) T) ((-343 . -240) T) ((-45 . -1060) 118262) ((-872 . -885) 118246) ((-872 . -887) 118171) ((-708 . -1061) T) ((-689 . -1009) NIL) ((-1242 . -52) 118141) ((-1221 . -52) 118118) ((-1134 . -1017) 118089) ((-1116 . -713) 118076) ((-1103 . -612) 118058) ((-872 . -1044) 117922) ((-217 . -922) T) ((-45 . -120) 117839) ((-739 . -287) T) ((-1080 . -151) 117818) ((-1080 . -149) 117769) ((-1011 . -368) T) ((-866 . -641) 117734) ((-861 . -641) 117684) ((-316 . -1193) 117650) ((-385 . -303) T) ((-316 . -1190) 117616) ((-312 . -174) 117595) ((-309 . -174) T) ((-1010 . -225) 117572) ((-916 . -368) T) ((-585 . -1276) 117559) ((-530 . -1276) 117536) ((-364 . -151) 117515) ((-364 . -149) 117466) ((-357 . -151) 117445) ((-357 . -149) 117396) ((-607 . -1181) 117372) ((-345 . -151) 117351) ((-345 . -149) 117302) ((-316 . -40) 117268) ((-484 . -1181) 117247) ((0 . |EnumerationCategory|) T) ((-316 . -98) 117213) ((-385 . -1028) T) ((-112 . -151) T) ((-112 . -149) NIL) ((-50 . -229) 117163) ((-648 . -1098) T) ((-607 . -111) 117110) ((-499 . -138) T) ((-484 . -111) 117060) ((-234 . -1110) 116970) ((-1085 . -1110) T) ((-872 . -383) 116954) ((-872 . -338) 116938) ((-234 . -23) 116808) ((-1065 . -922) T) ((-1065 . -821) T) ((-585 . -374) T) ((-530 . -374) T) ((-740 . -848) 116787) ((-1210 . -285) 116762) ((-355 . -1144) T) ((-327 . -39) T) ((-49 . -423) 116746) ((-1085 . -23) T) ((-396 . -742) 116730) ((-1270 . -527) 116663) ((-727 . -138) T) ((-1254 . -287) 116642) ((-1250 . -562) 116621) ((-1243 . -1214) 116600) ((-1243 . -562) 116551) ((-1222 . -1214) 116530) ((-1222 . -562) 116481) ((-733 . -527) 116414) ((-1221 . -1204) 116393) ((-1221 . -887) 116266) ((-894 . -1098) T) ((-148 . -842) T) ((-1221 . -885) 116236) ((-1216 . -562) 116215) ((-1168 . -138) T) ((-535 . -305) 116153) ((-1167 . -138) T) ((-143 . -527) NIL) ((-1160 . -138) T) ((-1122 . -138) T) ((-1030 . -1009) T) ((-1011 . -23) T) ((-355 . -43) 116118) ((-1011 . -1110) T) ((-916 . -1110) T) ((-87 . -612) 116100) ((-45 . -1054) T) ((-870 . -1060) 116087) ((-872 . -901) 116046) ((-780 . -52) 116023) ((-696 . -105) T) ((-1010 . -353) NIL) ((-603 . -1204) T) ((-979 . -23) T) ((-916 . -23) T) ((-870 . -120) 116008) ((-433 . -1110) T) ((-483 . -52) 115978) ((-140 . -105) T) ((-45 . -227) 115950) ((-45 . -240) T) ((-125 . -105) T) ((-598 . -562) 115929) ((-597 . -562) 115908) ((-689 . -612) 115890) ((-689 . -613) 115798) ((-312 . -527) 115764) ((-309 . -527) 115515) ((-1242 . -1044) 115499) ((-1221 . -1044) 115285) ((-1006 . -417) 115269) ((-433 . -23) T) ((-1116 . -174) T) ((-866 . -722) T) ((-861 . -722) T) ((-1244 . -287) T) ((-648 . -713) 115239) ((-148 . -1098) T) ((-53 . -1009) T) ((-413 . -225) 115223) ((-291 . -229) 115173) ((-871 . -922) T) ((-871 . -821) NIL) ((-975 . -612) 115155) ((-858 . -848) T) ((-1221 . -338) 115125) ((-1221 . -383) 115095) ((-214 . -1117) 115079) ((-780 . -1204) T) ((-1259 . -285) 115056) ((-504 . -105) T) ((-1199 . -641) 114981) ((-971 . -21) T) ((-971 . -25) T) ((-731 . -21) T) ((-731 . -25) T) ((-711 . -21) T) ((-711 . -25) T) ((-707 . -641) 114946) ((-458 . -21) T) ((-458 . -25) T) ((-339 . -105) T) ((-175 . -105) T) ((-1006 . -1061) T) ((-870 . -1054) T) ((-863 . -1044) 114930) ((-772 . -105) T) ((-1208 . -527) NIL) ((-1243 . -368) 114909) ((-1242 . -901) 114815) ((-1222 . -368) 114794) ((-1221 . -901) 114645) ((-1030 . -612) 114627) ((-413 . -829) 114580) ((-1168 . -506) 114546) ((-171 . -922) 114477) ((-1167 . -506) 114443) ((-1160 . -506) 114409) ((-708 . -1098) T) ((-1122 . -506) 114375) ((-584 . -1060) 114362) ((-572 . -1060) 114349) ((-508 . -1060) 114314) ((-312 . -287) 114293) ((-309 . -287) T) ((-358 . -612) 114275) ((-424 . -25) T) ((-424 . -21) T) ((-101 . -283) 114254) ((-584 . -120) 114239) ((-572 . -120) 114224) ((-508 . -120) 114173) ((-1170 . -887) 114140) ((-35 . -105) T) ((-902 . -503) 114124) ((-116 . -612) 114106) ((-53 . -612) 114088) ((-53 . -613) 114033) ((-261 . -503) 114017) ((-234 . -138) 113887) ((-1231 . -922) 113866) ((-817 . -1214) 113845) ((-1042 . -527) 113653) ((-1085 . -138) T) ((-394 . -612) 113635) ((-817 . -562) 113566) ((-589 . -641) 113541) ((-259 . -52) 113513) ((-244 . -52) 113470) ((-538 . -522) 113447) ((-1007 . -1204) T) ((-1250 . -23) T) ((-1250 . -1110) T) ((-694 . -1060) 113412) ((-780 . -901) 113325) ((-1243 . -1110) T) ((-1243 . -23) T) ((-1222 . -1110) T) ((-1216 . -1110) T) ((-1010 . -376) 113297) ((-121 . -374) T) ((-483 . -901) 113203) ((-1222 . -23) T) ((-1216 . -23) T) ((-905 . -612) 113185) ((-96 . -111) 113169) ((-1199 . -722) T) ((-906 . -848) 113120) ((-696 . -1144) T) ((-694 . -120) 113069) ((-1206 . -1098) T) ((-598 . -1110) T) ((-597 . -1110) T) ((-708 . -713) 112898) ((-707 . -722) T) ((-1116 . -287) T) ((-1011 . -138) T) ((-501 . -848) T) ((-979 . -138) T) ((-916 . -138) T) ((-800 . -25) T) ((-210 . -848) T) ((-800 . -21) T) ((-584 . -1054) T) ((-572 . -1054) T) ((-508 . -1054) T) ((-598 . -23) T) ((-343 . -1276) 112875) ((-316 . -457) 112854) ((-339 . -305) 112841) ((-597 . -23) T) ((-433 . -138) T) ((-652 . -641) 112815) ((-1164 . -1060) 112638) ((-242 . -1017) 112622) ((-872 . -303) T) ((-1281 . -1271) 112606) ((-769 . -793) T) ((-769 . -796) T) ((-696 . -43) 112593) ((-238 . -641) 112575) ((-572 . -227) T) ((-508 . -240) T) ((-508 . -227) T) ((-1164 . -120) 112377) ((-1143 . -229) 112327) ((-1086 . -910) 112306) ((-125 . -43) 112293) ((-203 . -801) T) ((-202 . -801) T) ((-201 . -801) T) ((-200 . -801) T) ((-872 . -1028) 112271) ((-1270 . -503) 112255) ((-783 . -910) 112234) ((-781 . -910) 112213) ((-1178 . -1204) T) ((-459 . -910) 112192) ((-733 . -503) 112176) ((-1086 . -641) 112101) ((-783 . -641) 112026) ((-619 . -1060) 112013) ((-494 . -1204) T) ((-343 . -374) T) ((-143 . -503) 111995) ((-781 . -641) 111920) ((-1134 . -1204) T) ((-467 . -641) 111891) ((-259 . -887) 111750) ((-244 . -887) NIL) ((-126 . -1060) 111695) ((-459 . -641) 111620) ((-660 . -1044) 111597) ((-619 . -120) 111582) ((-359 . -1044) 111566) ((-356 . -1044) 111550) ((-344 . -1044) 111534) ((-259 . -1044) 111378) ((-244 . -1044) 111254) ((-126 . -120) 111171) ((-64 . -1204) T) ((-531 . -1204) T) ((-529 . -1204) T) ((-510 . -1204) T) ((-509 . -1204) T) ((-443 . -612) 111153) ((-440 . -612) 111135) ((-3 . -105) T) ((-1034 . -1198) 111104) ((-834 . -105) T) ((-685 . -62) 111062) ((-694 . -1054) T) ((-55 . -641) 111036) ((-286 . -457) T) ((-485 . -1198) 111005) ((-1254 . -283) 110990) ((0 . -105) T) ((-585 . -641) 110955) ((-530 . -641) 110900) ((-54 . -105) T) ((-911 . -1044) 110887) ((-694 . -240) T) ((-1080 . -415) 110866) ((-727 . -634) 110814) ((-1006 . -1098) T) ((-708 . -174) 110705) ((-501 . -1000) 110687) ((-469 . -1098) T) ((-259 . -383) 110671) ((-244 . -383) 110655) ((-405 . -1098) T) ((-1164 . -1054) T) ((-339 . -43) 110639) ((-1033 . -105) 110617) ((-210 . -1000) 110599) ((-175 . -43) 110531) ((-1242 . -303) 110510) ((-1221 . -303) 110489) ((-1164 . -326) 110466) ((-652 . -722) T) ((-1164 . -227) T) ((-101 . -612) 110448) ((-1160 . -634) 110400) ((-499 . -25) T) ((-499 . -21) T) ((-1221 . -1028) 110352) ((-619 . -1054) T) ((-385 . -410) T) ((-396 . -105) T) ((-259 . -901) 110298) ((-244 . -901) 110275) ((-126 . -1054) T) ((-817 . -1110) T) ((-1086 . -722) T) ((-619 . -227) 110254) ((-617 . -105) T) ((-1208 . -503) 110236) ((-783 . -722) T) ((-781 . -722) T) ((-1207 . -62) 110202) ((-419 . -1110) T) ((-126 . -240) T) ((-45 . -374) NIL) ((-126 . -227) NIL) ((-459 . -722) T) ((-817 . -23) T) ((-727 . -25) T) ((-727 . -21) T) ((-698 . -848) T) ((-1077 . -283) 110181) ((-83 . -402) T) ((-83 . -401) T) ((-1254 . -1009) 110147) ((-689 . -1060) 110097) ((-1250 . -138) T) ((-1243 . -138) T) ((-1222 . -138) T) ((-1216 . -138) T) ((-1168 . -25) T) ((-1135 . -417) 110081) ((-630 . -372) 110013) ((-606 . -372) 109945) ((-1150 . -1142) 109929) ((-106 . -1098) 109907) ((-1168 . -21) T) ((-1167 . -21) T) ((-1167 . -25) T) ((-1006 . -713) 109855) ((-215 . -641) 109822) ((-689 . -120) 109749) ((-55 . -722) T) ((-1160 . -21) T) ((-355 . -353) T) ((-1160 . -25) T) ((-1080 . -457) 109700) ((-1122 . -21) T) ((-708 . -527) 109646) ((-585 . -722) T) ((-530 . -722) T) ((-863 . -303) T) ((-1122 . -25) T) ((-780 . -303) T) ((-598 . -138) T) ((-597 . -138) T) ((-364 . -457) T) ((-357 . -457) T) ((-345 . -457) T) ((-483 . -303) 109625) ((-309 . -283) 109491) ((-112 . -457) T) ((-84 . -446) T) ((-84 . -401) T) ((-493 . -105) T) ((-739 . -613) 109352) ((-739 . -612) 109334) ((-1285 . -612) 109316) ((-1285 . -613) 109298) ((-1080 . -408) 109277) ((-1042 . -503) 109209) ((-572 . -796) T) ((-572 . -793) T) ((-1066 . -229) 109155) ((-364 . -408) 109106) ((-357 . -408) 109057) ((-345 . -408) 109008) ((-1272 . -1110) T) ((-1272 . -23) T) ((-1261 . -105) T) ((-1135 . -1061) T) ((-666 . -742) 108992) ((-1172 . -149) 108971) ((-1172 . -151) 108950) ((-1139 . -1098) T) ((-1139 . -1073) 108919) ((-74 . -1204) T) ((-1030 . -1060) 108856) ((-859 . -1061) T) ((-740 . -149) 108835) ((-740 . -151) 108814) ((-234 . -634) 108720) ((-689 . -1054) T) ((-235 . -562) 108699) ((-358 . -1060) 108644) ((-66 . -1204) T) ((-1030 . -120) 108553) ((-902 . -612) 108520) ((-689 . -240) T) ((-689 . -227) NIL) ((-1206 . -527) NIL) ((-841 . -846) 108499) ((-694 . -796) T) ((-694 . -793) T) ((-1254 . -612) 108481) ((-1208 . -283) 108456) ((-1010 . -417) 108433) ((-358 . -120) 108350) ((-261 . -612) 108317) ((-385 . -922) T) ((-413 . -846) 108296) ((-708 . -287) 108207) ((-215 . -722) T) ((-1250 . -506) 108173) ((-1243 . -506) 108139) ((-1222 . -506) 108105) ((-1216 . -506) 108071) ((-312 . -1009) 108050) ((-214 . -1098) 108028) ((-316 . -981) 107990) ((-109 . -105) T) ((-53 . -1060) 107955) ((-1281 . -105) T) ((-387 . -105) T) ((-53 . -120) 107904) ((-1011 . -634) 107886) ((-1244 . -612) 107868) ((-538 . -105) T) ((-513 . -105) T) ((-1129 . -1130) 107852) ((-156 . -1266) 107836) ((-242 . -1204) T) ((-1208 . -19) 107818) ((-780 . -669) 107770) ((-1166 . -1214) 107749) ((-1121 . -1214) 107728) ((-234 . -21) 107638) ((-234 . -25) 107489) ((-137 . -128) 107473) ((-131 . -128) 107457) ((-1210 . -644) 107439) ((-49 . -742) 107423) ((-1208 . -605) 107398) ((-1166 . -562) 107309) ((-1121 . -562) 107240) ((-1210 . -379) 107222) ((-1042 . -283) 107197) ((-1085 . -25) T) ((-1085 . -21) T) ((-817 . -138) T) ((-126 . -796) NIL) ((-126 . -793) NIL) ((-359 . -303) T) ((-356 . -303) T) ((-344 . -303) T) ((-1092 . -1204) T) ((-246 . -1110) 107107) ((-245 . -1110) 107017) ((-1030 . -1054) T) ((-1010 . -1061) T) ((-343 . -641) 106962) ((-617 . -43) 106946) ((-1270 . -612) 106908) ((-1270 . -613) 106869) ((-1077 . -612) 106851) ((-1030 . -240) T) ((-358 . -1054) T) ((-816 . -1266) 106821) ((-246 . -23) T) ((-245 . -23) T) ((-995 . -612) 106803) ((-733 . -613) 106764) ((-733 . -612) 106746) ((-800 . -848) 106725) ((-1006 . -527) 106637) ((-358 . -227) T) ((-358 . -240) T) ((-1153 . -155) 106584) ((-1011 . -25) T) ((-143 . -612) 106566) ((-143 . -613) 106525) ((-911 . -303) T) ((-1011 . -21) T) ((-979 . -25) T) ((-916 . -21) T) ((-916 . -25) T) ((-433 . -21) T) ((-433 . -25) T) ((-841 . -417) 106509) ((-53 . -1054) T) ((-1279 . -1271) 106493) ((-1277 . -1271) 106477) ((-1042 . -605) 106452) ((-312 . -613) 106313) ((-312 . -612) 106295) ((-309 . -613) NIL) ((-309 . -612) 106277) ((-53 . -240) T) ((-53 . -227) T) ((-648 . -283) 106238) ((-555 . -229) 106188) ((-142 . -612) 106170) ((-123 . -612) 106152) ((-493 . -43) 106117) ((-1281 . -1278) 106096) ((-1272 . -138) T) ((-1280 . -1061) T) ((-1082 . -105) T) ((-118 . -612) 106078) ((-93 . -1204) T) ((-513 . -305) NIL) ((-1007 . -111) 106062) ((-890 . -1098) T) ((-886 . -1098) T) ((-1259 . -644) 106046) ((-1259 . -379) 106030) ((-327 . -1204) T) ((-595 . -848) T) ((-235 . -1110) T) ((-1135 . -1098) T) ((-1135 . -1057) 105970) ((-106 . -527) 105903) ((-933 . -612) 105885) ((-235 . -23) T) ((-343 . -722) T) ((-30 . -612) 105867) ((-859 . -1098) T) ((-841 . -1061) 105846) ((-45 . -641) 105791) ((-217 . -1214) T) ((-413 . -1061) T) ((-1152 . -155) 105773) ((-1006 . -287) 105724) ((-217 . -562) T) ((-1208 . -613) 105706) ((-316 . -1239) 105690) ((-316 . -1236) 105660) ((-1208 . -612) 105642) ((-1178 . -1181) 105621) ((-1075 . -612) 105603) ((-34 . -612) 105585) ((-866 . -1044) 105545) ((-861 . -1044) 105490) ((-640 . -155) 105474) ((-627 . -155) 105420) ((-1178 . -111) 105370) ((-494 . -1181) 105349) ((-501 . -151) T) ((-501 . -149) NIL) ((-1116 . -613) 105264) ((-444 . -612) 105246) ((-210 . -151) T) ((-210 . -149) NIL) ((-1116 . -612) 105228) ((-57 . -105) T) ((-1222 . -634) 105180) ((-494 . -111) 105130) ((-1001 . -23) T) ((-1281 . -43) 105100) ((-1166 . -1110) T) ((-1121 . -1110) T) ((-1065 . -1214) T) ((-852 . -1110) T) ((-959 . -1214) 105079) ((-1206 . -503) 105061) ((-496 . -1214) 105040) ((-727 . -848) 105019) ((-1065 . -562) T) ((-1205 . -62) 104985) ((-959 . -562) 104916) ((-1166 . -23) T) ((-1121 . -23) T) ((-852 . -23) T) ((-496 . -562) 104847) ((-1135 . -713) 104779) ((-1139 . -527) 104712) ((-1042 . -613) NIL) ((-1042 . -612) 104694) ((-859 . -713) 104664) ((-1285 . -1060) 104651) ((-1285 . -120) 104636) ((-1199 . -52) 104605) ((-246 . -138) T) ((-245 . -138) T) ((-1102 . -1098) T) ((-1010 . -1098) T) ((-67 . -612) 104587) ((-1160 . -848) NIL) ((-1030 . -793) T) ((-1030 . -796) T) ((-1250 . -25) T) ((-739 . -1060) 104511) ((-1250 . -21) T) ((-1243 . -21) T) ((-870 . -641) 104498) ((-1243 . -25) T) ((-1222 . -21) T) ((-1222 . -25) T) ((-1216 . -25) T) ((-1216 . -21) T) ((-1034 . -155) 104482) ((-872 . -821) 104461) ((-872 . -922) T) ((-739 . -120) 104364) ((-708 . -283) 104291) ((-598 . -21) T) ((-598 . -25) T) ((-597 . -21) T) ((-45 . -722) T) ((-214 . -527) 104224) ((-597 . -25) T) ((-485 . -155) 104208) ((-472 . -155) 104192) ((-923 . -722) T) ((-769 . -794) T) ((-769 . -795) T) ((-515 . -1098) T) ((-769 . -722) T) ((-217 . -368) T) ((-1150 . -1098) 104170) ((-871 . -1214) T) ((-648 . -612) 104152) ((-871 . -562) T) ((-689 . -374) NIL) ((-364 . -1266) 104136) ((-666 . -105) T) ((-357 . -1266) 104120) ((-345 . -1266) 104104) ((-1280 . -1098) T) ((-532 . -848) 104083) ((-1254 . -1060) 103966) ((-818 . -457) 103945) ((-1051 . -1098) T) ((-1051 . -1073) 103874) ((-1034 . -984) 103843) ((-820 . -1110) T) ((-1010 . -713) 103788) ((-1254 . -120) 103650) ((-235 . -138) T) ((-392 . -1110) T) ((-485 . -984) 103619) ((-472 . -984) 103588) ((-927 . -1096) T) ((-114 . -155) 103570) ((-78 . -612) 103552) ((-894 . -612) 103534) ((-1080 . -720) 103513) ((-739 . -1054) T) ((-1285 . -1054) T) ((-1206 . -283) 103488) ((-817 . -634) 103436) ((-290 . -1061) 103378) ((-171 . -1214) 103283) ((-217 . -1110) T) ((-323 . -23) T) ((-1160 . -1000) 103235) ((-841 . -1098) T) ((-739 . -240) 103214) ((-1122 . -736) 103193) ((-1244 . -1060) 103082) ((-1242 . -922) 103061) ((-870 . -722) T) ((-171 . -562) 102972) ((-1221 . -922) 102951) ((-584 . -641) 102938) ((-413 . -1098) T) ((-572 . -641) 102925) ((-258 . -1098) T) ((-508 . -641) 102890) ((-217 . -23) T) ((-1221 . -821) 102843) ((-973 . -1098) T) ((-1279 . -105) T) ((-358 . -1276) 102820) ((-1277 . -105) T) ((-1244 . -120) 102670) ((-148 . -612) 102652) ((-1001 . -138) T) ((-49 . -105) T) ((-234 . -848) 102603) ((-1280 . -713) 102573) ((-1231 . -1214) 102552) ((-106 . -503) 102536) ((-1231 . -562) 102447) ((-1206 . -19) 102429) ((-1086 . -52) 102390) ((-1065 . -1110) T) ((-959 . -1110) T) ((-137 . -39) T) ((-131 . -39) T) ((-1210 . -39) T) ((-1208 . -285) 102365) ((-783 . -52) 102342) ((-781 . -52) 102314) ((-1206 . -605) 102289) ((-1166 . -138) T) ((-358 . -374) T) ((-496 . -1110) T) ((-1121 . -138) T) ((-1065 . -23) T) ((-459 . -52) 102268) ((-871 . -368) T) ((-852 . -138) T) ((-156 . -105) T) ((-740 . -457) 102199) ((-959 . -23) T) ((-579 . -562) T) ((-817 . -25) T) ((-817 . -21) T) ((-1135 . -527) 102132) ((-589 . -1044) 102116) ((-496 . -23) T) ((-355 . -1061) T) ((-1254 . -1054) T) ((-1199 . -901) 102097) ((-666 . -305) 102035) ((-1254 . -227) 101994) ((-1111 . -1266) 101964) ((-694 . -641) 101929) ((-1011 . -848) T) ((-1010 . -174) T) ((-971 . -149) 101908) ((-630 . -1098) T) ((-606 . -1098) T) ((-971 . -151) 101887) ((-863 . -922) T) ((-731 . -151) 101866) ((-731 . -149) 101845) ((-979 . -848) T) ((-780 . -922) T) ((-483 . -922) 101824) ((-312 . -1060) 101734) ((-309 . -1060) 101663) ((-1006 . -283) 101621) ((-1164 . -910) 101600) ((-413 . -713) 101552) ((-696 . -846) T) ((-542 . -1096) T) ((-517 . -1098) T) ((-1244 . -1054) T) ((-312 . -120) 101441) ((-309 . -120) 101326) ((-1244 . -326) 101270) ((-1164 . -641) 101195) ((-972 . -105) T) ((-816 . -105) 100985) ((-708 . -613) NIL) ((-708 . -612) 100967) ((-1042 . -285) 100942) ((-652 . -1044) 100838) ((-866 . -303) T) ((-584 . -722) T) ((-572 . -795) T) ((-572 . -792) T) ((-171 . -368) 100789) ((-572 . -722) T) ((-508 . -722) T) ((-238 . -1044) 100773) ((-861 . -303) T) ((-1139 . -503) 100757) ((-1086 . -887) NIL) ((-871 . -1110) T) ((-126 . -910) NIL) ((-1279 . -1278) 100733) ((-1277 . -1278) 100712) ((-783 . -887) NIL) ((-781 . -887) 100571) ((-1272 . -25) T) ((-1272 . -21) T) ((-1202 . -105) 100549) ((-1104 . -401) T) ((-619 . -641) 100536) ((-459 . -887) NIL) ((-670 . -105) 100514) ((-1086 . -1044) 100341) ((-871 . -23) T) ((-783 . -1044) 100200) ((-781 . -1044) 100057) ((-126 . -641) 100002) ((-459 . -1044) 99878) ((-642 . -1044) 99862) ((-622 . -105) T) ((-214 . -503) 99846) ((-1259 . -39) T) ((-630 . -713) 99830) ((-606 . -713) 99814) ((-666 . -43) 99774) ((-316 . -105) T) ((-218 . -1098) T) ((-145 . -1098) T) ((-90 . -612) 99756) ((-55 . -1044) 99740) ((-1116 . -1060) 99727) ((-1086 . -383) 99711) ((-783 . -383) 99695) ((-65 . -62) 99657) ((-694 . -795) T) ((-694 . -792) T) ((-585 . -1044) 99644) ((-530 . -1044) 99621) ((-694 . -722) T) ((-323 . -138) T) ((-312 . -1054) 99511) ((-309 . -1054) T) ((-171 . -1110) T) ((-781 . -383) 99495) ((-50 . -155) 99445) ((-1011 . -1000) 99427) ((-1206 . -613) 99409) ((-1206 . -612) 99391) ((-459 . -383) 99375) ((-413 . -174) T) ((-312 . -240) 99354) ((-309 . -240) T) ((-309 . -227) NIL) ((-290 . -1098) 99136) ((-217 . -138) T) ((-1116 . -120) 99121) ((-171 . -23) T) ((-800 . -151) 99100) ((-800 . -149) 99079) ((-246 . -634) 98985) ((-245 . -634) 98891) ((-316 . -281) 98857) ((-1164 . -722) T) ((-1150 . -527) 98790) ((-1129 . -1098) T) ((-217 . -1063) T) ((-816 . -305) 98728) ((-1086 . -901) 98663) ((-783 . -901) 98606) ((-781 . -901) 98590) ((-1279 . -43) 98560) ((-1277 . -43) 98530) ((-1231 . -1110) T) ((-853 . -1110) T) ((-459 . -901) 98507) ((-855 . -1098) T) ((-1231 . -23) T) ((-579 . -1110) T) ((-853 . -23) T) ((-619 . -722) T) ((-359 . -922) T) ((-356 . -922) T) ((-286 . -105) T) ((-344 . -922) T) ((-1065 . -138) T) ((-959 . -138) T) ((-126 . -795) NIL) ((-126 . -792) NIL) ((-126 . -722) T) ((-689 . -910) NIL) ((-1051 . -527) 98391) ((-496 . -138) T) ((-579 . -23) T) ((-670 . -305) 98329) ((-630 . -759) T) ((-606 . -759) T) ((-1222 . -848) NIL) ((-1010 . -287) T) ((-246 . -21) T) ((-689 . -641) 98279) ((-355 . -1098) T) ((-246 . -25) T) ((-245 . -21) T) ((-245 . -25) T) ((-156 . -43) 98263) ((-2 . -105) T) ((-911 . -922) T) ((-497 . -1266) 98233) ((-215 . -1044) 98210) ((-1116 . -1054) T) ((-707 . -303) T) ((-290 . -713) 98152) ((-696 . -1061) T) ((-501 . -457) T) ((-413 . -527) 98064) ((-210 . -457) T) ((-1116 . -227) T) ((-291 . -155) 98014) ((-1006 . -613) 97975) ((-1006 . -612) 97957) ((-997 . -612) 97939) ((-125 . -1061) T) ((-648 . -1060) 97923) ((-217 . -506) T) ((-469 . -612) 97905) ((-405 . -612) 97887) ((-405 . -613) 97864) ((-1058 . -1266) 97834) ((-648 . -120) 97813) ((-1135 . -503) 97797) ((-816 . -43) 97767) ((-68 . -446) T) ((-68 . -401) T) ((-1153 . -105) T) ((-871 . -138) T) ((-498 . -105) 97745) ((-1285 . -374) T) ((-740 . -956) 97714) ((-1080 . -105) T) ((-1064 . -105) T) ((-355 . -713) 97659) ((-727 . -151) 97638) ((-727 . -149) 97617) ((-1030 . -641) 97554) ((-535 . -1098) 97532) ((-364 . -105) T) ((-357 . -105) T) ((-345 . -105) T) ((-235 . -21) T) ((-235 . -25) T) ((-112 . -105) T) ((-518 . -1098) T) ((-358 . -641) 97477) ((-1166 . -634) 97425) ((-1121 . -634) 97373) ((-391 . -522) 97352) ((-834 . -846) 97331) ((-385 . -1214) T) ((-689 . -722) T) ((-339 . -1061) T) ((-1222 . -1000) 97283) ((-175 . -1061) T) ((-106 . -612) 97250) ((-1168 . -149) 97229) ((-1168 . -151) 97208) ((-385 . -562) T) ((-1167 . -151) 97187) ((-1167 . -149) 97166) ((-1160 . -149) 97073) ((-413 . -287) T) ((-1160 . -151) 96980) ((-1122 . -151) 96959) ((-1122 . -149) 96938) ((-316 . -43) 96779) ((-171 . -138) T) ((-309 . -796) NIL) ((-309 . -793) NIL) ((-648 . -1054) T) ((-53 . -641) 96744) ((-1001 . -21) T) ((-137 . -1017) 96728) ((-131 . -1017) 96712) ((-1001 . -25) T) ((-902 . -128) 96696) ((-1152 . -105) T) ((-817 . -848) 96675) ((-1231 . -138) T) ((-1206 . -285) 96650) ((-1166 . -25) T) ((-1166 . -21) T) ((-853 . -138) T) ((-1121 . -25) T) ((-1121 . -21) T) ((-852 . -25) T) ((-852 . -21) T) ((-783 . -303) 96629) ((-35 . -37) 96613) ((-1153 . -305) 96408) ((-1150 . -503) 96392) ((-640 . -105) 96370) ((-627 . -105) T) ((-1143 . -155) 96320) ((-579 . -138) T) ((-617 . -846) 96299) ((-1139 . -612) 96261) ((-1139 . -613) 96222) ((-1030 . -792) T) ((-1030 . -795) T) ((-1030 . -722) T) ((-498 . -305) 96160) ((-458 . -423) 96130) ((-355 . -174) T) ((-218 . -527) NIL) ((-145 . -527) NIL) ((-286 . -43) 96117) ((-272 . -105) T) ((-271 . -105) T) ((-270 . -105) T) ((-269 . -105) T) ((-268 . -105) T) ((-267 . -105) T) ((-266 . -105) T) ((-343 . -1044) 96094) ((-206 . -105) T) ((-205 . -105) T) ((-203 . -105) T) ((-202 . -105) T) ((-201 . -105) T) ((-200 . -105) T) ((-197 . -105) T) ((-196 . -105) T) ((-708 . -1060) 95917) ((-195 . -105) T) ((-194 . -105) T) ((-193 . -105) T) ((-192 . -105) T) ((-191 . -105) T) ((-190 . -105) T) ((-189 . -105) T) ((-188 . -105) T) ((-187 . -105) T) ((-358 . -722) T) ((-708 . -120) 95719) ((-666 . -225) 95703) ((-585 . -303) T) ((-530 . -303) T) ((-290 . -527) 95652) ((-112 . -305) NIL) ((-77 . -401) T) ((-1111 . -105) 95442) ((-834 . -417) 95426) ((-1116 . -796) T) ((-1116 . -793) T) ((-696 . -1098) T) ((-385 . -368) T) ((-171 . -506) 95404) ((-214 . -612) 95371) ((-140 . -1098) T) ((-125 . -1098) T) ((-53 . -722) T) ((-1051 . -503) 95336) ((-143 . -431) 95318) ((-143 . -374) T) ((-1034 . -105) T) ((-525 . -522) 95297) ((-485 . -105) T) ((-472 . -105) T) ((-1041 . -1110) T) ((-740 . -1234) 95281) ((-1168 . -40) 95247) ((-1168 . -98) 95213) ((-1168 . -1193) 95179) ((-1168 . -1190) 95145) ((-1167 . -1190) 95111) ((-1152 . -305) NIL) ((-94 . -402) T) ((-94 . -401) T) ((-1080 . -1144) 95090) ((-1167 . -1193) 95056) ((-1167 . -98) 95022) ((-1041 . -23) T) ((-1167 . -40) 94988) ((-579 . -506) T) ((-1160 . -1190) 94954) ((-1160 . -1193) 94920) ((-1160 . -98) 94886) ((-1160 . -40) 94852) ((-366 . -1110) T) ((-364 . -1144) 94831) ((-357 . -1144) 94810) ((-345 . -1144) 94789) ((-1122 . -40) 94755) ((-1122 . -98) 94721) ((-1122 . -1193) 94687) ((-112 . -1144) T) ((-1122 . -1190) 94653) ((-834 . -1061) 94632) ((-640 . -305) 94570) ((-627 . -305) 94421) ((-1080 . -43) 94289) ((-708 . -1054) T) ((-1065 . -634) 94271) ((-1011 . -151) T) ((-959 . -634) 94219) ((-504 . -1098) T) ((-1011 . -149) NIL) ((-385 . -1110) T) ((-323 . -25) T) ((-321 . -23) T) ((-950 . -848) 94198) ((-708 . -326) 94175) ((-496 . -634) 94123) ((-45 . -1044) 93998) ((-696 . -713) 93985) ((-708 . -227) T) ((-339 . -1098) T) ((-175 . -1098) T) ((-331 . -848) T) ((-424 . -457) 93935) ((-385 . -23) T) ((-364 . -43) 93900) ((-357 . -43) 93865) ((-345 . -43) 93830) ((-85 . -446) T) ((-85 . -401) T) ((-217 . -25) T) ((-217 . -21) T) ((-835 . -1110) T) ((-112 . -43) 93780) ((-828 . -1110) T) ((-772 . -1098) T) ((-125 . -713) 93767) ((-667 . -1044) 93751) ((-611 . -105) T) ((-835 . -23) T) ((-828 . -23) T) ((-1209 . -105) T) ((-1150 . -283) 93728) ((-1111 . -305) 93666) ((-1100 . -229) 93650) ((-69 . -402) T) ((-69 . -401) T) ((-114 . -105) T) ((-45 . -383) 93627) ((-35 . -1098) T) ((-1208 . -644) 93609) ((-647 . -850) 93593) ((-1208 . -379) 93575) ((-1065 . -21) T) ((-1065 . -25) T) ((-816 . -225) 93544) ((-959 . -25) T) ((-959 . -21) T) ((-617 . -1061) T) ((-496 . -25) T) ((-496 . -21) T) ((-1034 . -305) 93482) ((-890 . -612) 93464) ((-886 . -612) 93446) ((-246 . -848) 93397) ((-245 . -848) 93348) ((-535 . -527) 93281) ((-871 . -634) 93258) ((-485 . -305) 93196) ((-472 . -305) 93134) ((-355 . -287) T) ((-1150 . -1246) 93118) ((-1135 . -612) 93080) ((-1135 . -613) 93041) ((-1133 . -105) T) ((-1006 . -1060) 92937) ((-45 . -901) 92889) ((-1150 . -605) 92866) ((-739 . -641) 92790) ((-1285 . -641) 92777) ((-1066 . -155) 92723) ((-872 . -1214) T) ((-1006 . -120) 92598) ((-339 . -713) 92582) ((-859 . -612) 92564) ((-175 . -713) 92496) ((-413 . -283) 92454) ((-872 . -562) T) ((-112 . -406) 92436) ((-89 . -390) T) ((-89 . -401) T) ((-866 . -922) T) ((-861 . -922) T) ((-696 . -174) T) ((-101 . -722) T) ((-497 . -105) 92226) ((-101 . -482) T) ((-125 . -174) T) ((-1111 . -43) 92196) ((-171 . -634) 92144) ((-218 . -503) 92126) ((-145 . -503) 92101) ((-1058 . -105) T) ((-871 . -25) T) ((-816 . -232) 92080) ((-871 . -21) T) ((-819 . -105) T) ((-1209 . -305) NIL) ((-420 . -105) T) ((-391 . -105) T) ((-114 . -305) NIL) ((-221 . -105) 92058) ((-137 . -1204) T) ((-131 . -1204) T) ((-1210 . -1204) T) ((-1041 . -138) T) ((-666 . -372) 92042) ((-1254 . -641) 91967) ((-1285 . -722) T) ((-1250 . -149) 91946) ((-1006 . -1054) T) ((-1250 . -151) 91925) ((-1231 . -634) 91873) ((-1243 . -151) 91852) ((-1102 . -612) 91834) ((-1010 . -612) 91816) ((-528 . -23) T) ((-523 . -23) T) ((-343 . -303) T) ((-521 . -23) T) ((-321 . -138) T) ((-3 . -1098) T) ((-1010 . -613) 91800) ((-1006 . -240) 91779) ((-1006 . -227) 91758) ((-1243 . -149) 91737) ((-1242 . -1214) 91716) ((-834 . -1098) T) ((-1222 . -149) 91623) ((-1222 . -151) 91530) ((-1221 . -1214) 91509) ((-1216 . -149) 91488) ((-1216 . -151) 91467) ((-739 . -482) 91446) ((-739 . -722) T) ((-385 . -138) T) ((-572 . -887) 91428) ((0 . -1098) T) ((-175 . -174) T) ((-171 . -21) T) ((-171 . -25) T) ((-54 . -1098) T) ((-1244 . -641) 91317) ((-1242 . -562) 91268) ((-710 . -1110) T) ((-1221 . -562) 91219) ((-572 . -1044) 91201) ((-597 . -151) 91180) ((-597 . -149) 91159) ((-508 . -1044) 91102) ((-92 . -390) T) ((-92 . -401) T) ((-872 . -368) T) ((-1164 . -52) 91079) ((-835 . -138) T) ((-828 . -138) T) ((-710 . -23) T) ((-515 . -612) 91061) ((-1281 . -1061) T) ((-385 . -1063) T) ((-1033 . -1098) 91039) ((-902 . -39) T) ((-497 . -305) 90977) ((-1150 . -613) 90938) ((-1150 . -612) 90905) ((-261 . -39) T) ((-1166 . -848) 90884) ((-50 . -105) T) ((-1121 . -848) 90863) ((-818 . -105) T) ((-1231 . -25) T) ((-1231 . -21) T) ((-853 . -25) T) ((-49 . -372) 90847) ((-853 . -21) T) ((-727 . -457) 90798) ((-1280 . -612) 90780) ((-579 . -25) T) ((-579 . -21) T) ((-396 . -1098) T) ((-1058 . -305) 90718) ((-617 . -1098) T) ((-694 . -887) 90700) ((-1259 . -1204) T) ((-221 . -305) 90638) ((-148 . -374) T) ((-1051 . -613) 90580) ((-1051 . -612) 90523) ((-863 . -1214) T) ((-309 . -910) NIL) ((-780 . -1214) T) ((-1254 . -722) T) ((-694 . -1044) 90468) ((-707 . -922) T) ((-483 . -1214) 90447) ((-1167 . -457) 90426) ((-1160 . -457) 90405) ((-863 . -562) T) ((-330 . -105) T) ((-780 . -562) T) ((-872 . -1110) T) ((-312 . -641) 90226) ((-309 . -641) 90155) ((-483 . -562) 90106) ((-339 . -527) 90072) ((-555 . -155) 90022) ((-45 . -303) T) ((-1164 . -887) NIL) ((-841 . -612) 90004) ((-696 . -287) T) ((-872 . -23) T) ((-385 . -506) T) ((-1080 . -225) 89974) ((-525 . -105) T) ((-413 . -613) 89775) ((-413 . -612) 89757) ((-258 . -612) 89739) ((-125 . -287) T) ((-1164 . -1044) 89619) ((-973 . -612) 89601) ((-1244 . -722) T) ((-1242 . -368) 89580) ((-1221 . -368) 89559) ((-1270 . -39) T) ((-126 . -1204) T) ((-112 . -225) 89541) ((-1172 . -105) T) ((-493 . -1098) T) ((-535 . -503) 89525) ((-740 . -105) T) ((-733 . -39) T) ((-497 . -43) 89495) ((-143 . -39) T) ((-126 . -885) 89472) ((-126 . -887) NIL) ((-619 . -1044) 89355) ((-638 . -848) 89334) ((-1269 . -105) T) ((-291 . -105) T) ((-708 . -374) 89313) ((-126 . -1044) 89290) ((-396 . -713) 89274) ((-1164 . -383) 89258) ((-617 . -713) 89242) ((-50 . -305) 89046) ((-817 . -149) 89025) ((-817 . -151) 89004) ((-1280 . -388) 88983) ((-820 . -848) T) ((-1261 . -1098) T) ((-1250 . -40) 88949) ((-1250 . -98) 88915) ((-1250 . -1193) 88881) ((-1153 . -223) 88828) ((-1250 . -1190) 88794) ((-392 . -848) 88773) ((-1243 . -1190) 88739) ((-1243 . -1193) 88705) ((-1243 . -98) 88671) ((-218 . -683) 88639) ((-145 . -683) 88600) ((-1243 . -40) 88566) ((-1242 . -1110) T) ((-1222 . -1190) 88532) ((-528 . -138) T) ((-1222 . -1193) 88498) ((-1216 . -1193) 88464) ((-1216 . -1190) 88430) ((-1222 . -98) 88396) ((-1222 . -40) 88362) ((-630 . -612) 88331) ((-606 . -612) 88300) ((-33 . -105) T) ((-217 . -848) T) ((-1221 . -1110) T) ((-1216 . -40) 88266) ((-1216 . -98) 88232) ((-1116 . -641) 88219) ((-1164 . -901) 88162) ((-1080 . -353) 88141) ((-595 . -155) 88123) ((-870 . -303) T) ((-126 . -383) 88100) ((-126 . -338) 88077) ((-175 . -287) T) ((-863 . -368) T) ((-780 . -368) T) ((-309 . -795) NIL) ((-309 . -792) NIL) ((-312 . -722) 87926) ((-309 . -722) T) ((-517 . -612) 87908) ((-483 . -368) 87887) ((-364 . -353) 87866) ((-357 . -353) 87845) ((-345 . -353) 87824) ((-312 . -482) 87803) ((-1242 . -23) T) ((-1221 . -23) T) ((-714 . -1110) T) ((-710 . -138) T) ((-647 . -105) T) ((-493 . -713) 87768) ((-50 . -279) 87718) ((-109 . -1098) T) ((-73 . -612) 87700) ((-858 . -105) T) ((-619 . -901) 87659) ((-1281 . -1098) T) ((-387 . -1098) T) ((-1208 . -39) T) ((-1206 . -644) 87641) ((-1206 . -379) 87623) ((-87 . -1204) T) ((-1065 . -848) T) ((-959 . -848) 87602) ((-126 . -901) NIL) ((-783 . -922) 87581) ((-709 . -848) T) ((-538 . -1098) T) ((-513 . -1098) T) ((-359 . -1214) T) ((-356 . -1214) T) ((-344 . -1214) T) ((-259 . -1214) 87560) ((-244 . -1214) 87539) ((-1111 . -225) 87508) ((-496 . -848) 87487) ((-1152 . -829) T) ((-1135 . -1060) 87471) ((-396 . -759) T) ((-740 . -305) 87458) ((-689 . -1204) T) ((-359 . -562) T) ((-356 . -562) T) ((-344 . -562) T) ((-259 . -562) 87389) ((-244 . -562) 87320) ((-1135 . -120) 87299) ((-458 . -742) 87269) ((-859 . -1060) 87239) ((-818 . -43) 87176) ((-689 . -885) 87158) ((-689 . -887) 87140) ((-291 . -305) 86944) ((-911 . -1214) T) ((-863 . -1110) T) ((-859 . -120) 86909) ((-666 . -417) 86893) ((-780 . -1110) T) ((-689 . -1044) 86838) ((-1150 . -285) 86815) ((-1011 . -457) T) ((-911 . -562) T) ((-585 . -922) T) ((-483 . -1110) T) ((-530 . -922) T) ((-916 . -457) T) ((-218 . -612) 86797) ((-145 . -612) 86779) ((-70 . -612) 86761) ((-863 . -23) T) ((-627 . -223) 86707) ((-780 . -23) T) ((-483 . -23) T) ((-1116 . -795) T) ((-872 . -138) T) ((-1116 . -792) T) ((-1272 . -1274) 86686) ((-1116 . -722) T) ((-648 . -641) 86660) ((-290 . -612) 86401) ((-1042 . -39) T) ((-816 . -846) 86380) ((-584 . -303) T) ((-572 . -303) T) ((-508 . -303) T) ((-1281 . -713) 86350) ((-689 . -383) 86332) ((-689 . -338) 86314) ((-493 . -174) T) ((-387 . -713) 86284) ((-740 . -1144) 86262) ((-871 . -848) NIL) ((-572 . -1028) T) ((-508 . -1028) T) ((-1129 . -612) 86244) ((-1111 . -232) 86223) ((-207 . -105) T) ((-1143 . -105) T) ((-76 . -612) 86205) ((-1135 . -1054) T) ((-1172 . -43) 86102) ((-855 . -612) 86084) ((-572 . -554) T) ((-740 . -43) 85913) ((-666 . -1061) T) ((-727 . -956) 85866) ((-1135 . -227) 85845) ((-1082 . -1098) T) ((-1041 . -25) T) ((-1041 . -21) T) ((-1010 . -1060) 85790) ((-906 . -105) T) ((-859 . -1054) T) ((-776 . -1110) T) ((-689 . -901) NIL) ((-359 . -329) 85774) ((-359 . -368) T) ((-356 . -329) 85758) ((-356 . -368) T) ((-344 . -329) 85742) ((-344 . -368) T) ((-501 . -105) T) ((-1269 . -43) 85712) ((-535 . -683) 85662) ((-210 . -105) T) ((-1030 . -1044) 85542) ((-1010 . -120) 85459) ((-1168 . -981) 85428) ((-1167 . -981) 85390) ((-532 . -155) 85374) ((-1080 . -376) 85353) ((-355 . -612) 85335) ((-321 . -21) T) ((-358 . -1044) 85312) ((-321 . -25) T) ((-1160 . -981) 85281) ((-1122 . -981) 85248) ((-81 . -612) 85230) ((-694 . -303) T) ((-171 . -848) 85209) ((-911 . -368) T) ((-385 . -25) T) ((-385 . -21) T) ((-911 . -329) 85196) ((-91 . -612) 85178) ((-694 . -1028) T) ((-672 . -848) T) ((-1242 . -138) T) ((-1221 . -138) T) ((-902 . -1017) 85162) ((-835 . -21) T) ((-53 . -1044) 85105) ((-835 . -25) T) ((-828 . -25) T) ((-828 . -21) T) ((-1279 . -1061) T) ((-1277 . -1061) T) ((-648 . -722) T) ((-1164 . -303) 85084) ((-261 . -1017) 85068) ((-1280 . -1060) 85052) ((-1231 . -848) 85031) ((-816 . -417) 85000) ((-106 . -128) 84984) ((-57 . -1098) T) ((-932 . -612) 84966) ((-871 . -1000) 84943) ((-824 . -105) T) ((-1280 . -120) 84922) ((-647 . -43) 84892) ((-579 . -848) T) ((-359 . -1110) T) ((-356 . -1110) T) ((-344 . -1110) T) ((-259 . -1110) T) ((-244 . -1110) T) ((-619 . -303) 84871) ((-1143 . -305) 84675) ((-660 . -23) T) ((-497 . -225) 84644) ((-156 . -1061) T) ((-359 . -23) T) ((-356 . -23) T) ((-344 . -23) T) ((-126 . -303) T) ((-259 . -23) T) ((-244 . -23) T) ((-1010 . -1054) T) ((-708 . -910) 84623) ((-1010 . -227) 84595) ((-1010 . -240) T) ((-126 . -1028) NIL) ((-911 . -1110) T) ((-1243 . -457) 84574) ((-1222 . -457) 84553) ((-535 . -612) 84520) ((-708 . -641) 84445) ((-413 . -1060) 84397) ((-863 . -138) T) ((-518 . -612) 84379) ((-911 . -23) T) ((-780 . -138) T) ((-501 . -305) NIL) ((-483 . -138) T) ((-210 . -305) NIL) ((-413 . -120) 84310) ((-816 . -1061) 84240) ((-733 . -1095) 84224) ((-1242 . -506) 84190) ((-1221 . -506) 84156) ((-143 . -1095) 84138) ((-493 . -287) T) ((-1280 . -1054) T) ((-1066 . -105) T) ((-513 . -527) NIL) ((-698 . -105) T) ((-497 . -232) 84117) ((-1166 . -149) 84096) ((-1166 . -151) 84075) ((-1121 . -151) 84054) ((-1121 . -149) 84033) ((-630 . -1060) 84017) ((-606 . -1060) 84001) ((-666 . -1098) T) ((-666 . -1057) 83941) ((-1168 . -1249) 83925) ((-1168 . -1236) 83902) ((-501 . -1144) T) ((-1167 . -1241) 83863) ((-1167 . -1236) 83833) ((-1167 . -1239) 83817) ((-210 . -1144) T) ((-343 . -922) T) ((-819 . -264) 83801) ((-630 . -120) 83780) ((-606 . -120) 83759) ((-1160 . -1220) 83720) ((-841 . -1054) 83699) ((-1160 . -1236) 83676) ((-528 . -25) T) ((-508 . -298) T) ((-524 . -23) T) ((-523 . -25) T) ((-521 . -25) T) ((-520 . -23) T) ((-1160 . -1218) 83660) ((-413 . -1054) T) ((-316 . -1061) T) ((-689 . -303) T) ((-112 . -846) T) ((-413 . -240) T) ((-413 . -227) 83639) ((-708 . -722) T) ((-501 . -43) 83589) ((-210 . -43) 83539) ((-483 . -506) 83505) ((-1152 . -1137) T) ((-1099 . -105) T) ((-696 . -612) 83487) ((-696 . -613) 83402) ((-710 . -21) T) ((-710 . -25) T) ((-140 . -612) 83384) ((-125 . -612) 83366) ((-159 . -25) T) ((-1279 . -1098) T) ((-872 . -634) 83314) ((-1277 . -1098) T) ((-971 . -105) T) ((-731 . -105) T) ((-711 . -105) T) ((-458 . -105) T) ((-1206 . -39) T) ((-817 . -457) 83265) ((-49 . -1098) T) ((-1087 . -848) T) ((-660 . -138) T) ((-1066 . -305) 83116) ((-666 . -713) 83100) ((-286 . -1061) T) ((-359 . -138) T) ((-356 . -138) T) ((-344 . -138) T) ((-259 . -138) T) ((-244 . -138) T) ((-739 . -1204) T) ((-424 . -105) T) ((-1254 . -52) 83077) ((-156 . -1098) T) ((-50 . -223) 83027) ((-740 . -225) 83011) ((-1006 . -641) 82949) ((-965 . -848) 82928) ((-739 . -885) 82912) ((-739 . -887) 82837) ((-234 . -1266) 82807) ((-1030 . -303) T) ((-290 . -1060) 82728) ((-911 . -138) T) ((-45 . -922) T) ((-739 . -1044) 82450) ((-501 . -406) 82432) ((-504 . -612) 82414) ((-358 . -303) T) ((-210 . -406) 82396) ((-1080 . -417) 82380) ((-290 . -120) 82296) ((-866 . -1214) T) ((-861 . -1214) T) ((-872 . -25) T) ((-872 . -21) T) ((-866 . -562) T) ((-861 . -562) T) ((-339 . -612) 82278) ((-1244 . -52) 82222) ((-217 . -151) T) ((-175 . -612) 82204) ((-1111 . -846) 82183) ((-772 . -612) 82165) ((-607 . -229) 82112) ((-484 . -229) 82062) ((-1279 . -713) 82032) ((-53 . -303) T) ((-1277 . -713) 82002) ((-972 . -1098) T) ((-816 . -1098) 81792) ((-307 . -105) T) ((-902 . -1204) T) ((-739 . -383) 81761) ((-53 . -1028) T) ((-1221 . -634) 81669) ((-685 . -105) 81647) ((-49 . -713) 81631) ((-555 . -105) T) ((-72 . -389) T) ((-261 . -1204) T) ((-72 . -401) T) ((-35 . -612) 81613) ((-656 . -23) T) ((-666 . -759) T) ((-1202 . -1098) 81591) ((-355 . -1060) 81536) ((-670 . -1098) 81514) ((-1065 . -151) T) ((-959 . -151) 81493) ((-959 . -149) 81472) ((-800 . -105) T) ((-156 . -713) 81456) ((-496 . -151) 81435) ((-496 . -149) 81414) ((-355 . -120) 81331) ((-1080 . -1061) T) ((-321 . -848) 81310) ((-974 . -1096) T) ((-1250 . -981) 81279) ((-1243 . -981) 81241) ((-1222 . -981) 81210) ((-622 . -1098) T) ((-739 . -901) 81191) ((-524 . -138) T) ((-520 . -138) T) ((-291 . -223) 81141) ((-364 . -1061) T) ((-357 . -1061) T) ((-345 . -1061) T) ((-290 . -1054) 81083) ((-1216 . -981) 81052) ((-385 . -848) T) ((-112 . -1061) T) ((-1006 . -722) T) ((-870 . -922) T) ((-841 . -796) 81031) ((-841 . -793) 81010) ((-424 . -305) 80949) ((-477 . -105) T) ((-597 . -981) 80918) ((-316 . -1098) T) ((-413 . -796) 80897) ((-413 . -793) 80876) ((-513 . -503) 80858) ((-1244 . -1044) 80824) ((-1242 . -21) T) ((-1242 . -25) T) ((-1221 . -21) T) ((-1221 . -25) T) ((-816 . -713) 80766) ((-1207 . -105) T) ((-866 . -368) T) ((-861 . -368) T) ((-694 . -410) T) ((-1270 . -1204) T) ((-1111 . -417) 80735) ((-1010 . -374) NIL) ((-106 . -39) T) ((-733 . -1204) T) ((-49 . -759) T) ((-595 . -105) T) ((-82 . -402) T) ((-82 . -401) T) ((-647 . -650) 80719) ((-143 . -1204) T) ((-871 . -151) T) ((-871 . -149) NIL) ((-1254 . -901) 80632) ((-355 . -1054) T) ((-75 . -389) T) ((-75 . -401) T) ((-1159 . -105) T) ((-666 . -527) 80565) ((-685 . -305) 80503) ((-971 . -43) 80400) ((-731 . -43) 80370) ((-555 . -305) 80174) ((-312 . -1204) T) ((-355 . -227) T) ((-355 . -240) T) ((-309 . -1204) T) ((-286 . -1098) T) ((-1174 . -612) 80156) ((-707 . -1214) T) ((-1150 . -644) 80140) ((-1199 . -562) 80119) ((-863 . -25) T) ((-863 . -21) T) ((-707 . -562) T) ((-312 . -885) 80103) ((-312 . -887) 80028) ((-309 . -885) 79989) ((-309 . -887) NIL) ((-800 . -305) 79954) ((-780 . -25) T) ((-316 . -713) 79795) ((-780 . -21) T) ((-323 . -322) 79772) ((-499 . -105) T) ((-483 . -25) T) ((-483 . -21) T) ((-424 . -43) 79746) ((-312 . -1044) 79409) ((-217 . -1190) T) ((-217 . -1193) T) ((-3 . -612) 79391) ((-309 . -1044) 79321) ((-866 . -1110) T) ((-2 . -1098) T) ((-2 . |RecordCategory|) T) ((-861 . -1110) T) ((-834 . -612) 79303) ((-1111 . -1061) 79233) ((-584 . -922) T) ((-572 . -821) T) ((-572 . -922) T) ((-508 . -922) T) ((-142 . -1044) 79217) ((-217 . -98) T) ((-80 . -446) T) ((-80 . -401) T) ((0 . -612) 79199) ((-171 . -151) 79178) ((-171 . -149) 79129) ((-217 . -40) T) ((-54 . -612) 79111) ((-866 . -23) T) ((-493 . -1061) T) ((-861 . -23) T) ((-501 . -225) 79093) ((-498 . -976) 79077) ((-497 . -846) 79056) ((-210 . -225) 79038) ((-86 . -446) T) ((-86 . -401) T) ((-1139 . -39) T) ((-816 . -174) 79017) ((-727 . -105) T) ((-1033 . -612) 78984) ((-513 . -283) 78959) ((-312 . -383) 78928) ((-309 . -383) 78889) ((-309 . -338) 78850) ((-1207 . -305) NIL) ((-817 . -956) 78797) ((-656 . -138) T) ((-1231 . -149) 78776) ((-1231 . -151) 78755) ((-1208 . -1204) T) ((-1168 . -105) T) ((-1167 . -105) T) ((-1160 . -105) T) ((-1153 . -1098) T) ((-1122 . -105) T) ((-214 . -39) T) ((-286 . -713) 78742) ((-1153 . -609) 78718) ((-595 . -305) NIL) ((-1250 . -1249) 78702) ((-1250 . -1236) 78679) ((-498 . -1098) 78657) ((-1243 . -1241) 78618) ((-396 . -612) 78600) ((-523 . -848) T) ((-1143 . -223) 78550) ((-1243 . -1236) 78520) ((-1243 . -1239) 78504) ((-1222 . -1220) 78465) ((-1222 . -1236) 78442) ((-1222 . -1218) 78426) ((-1216 . -1249) 78410) ((-1216 . -1236) 78387) ((-617 . -612) 78369) ((-1168 . -281) 78335) ((-694 . -922) T) ((-1167 . -281) 78301) ((-1160 . -281) 78267) ((-1122 . -281) 78233) ((-1080 . -1098) T) ((-1064 . -1098) T) ((-53 . -298) T) ((-312 . -901) 78199) ((-309 . -901) NIL) ((-1064 . -1070) 78178) ((-1116 . -887) 78160) ((-800 . -43) 78144) ((-259 . -634) 78092) ((-244 . -634) 78040) ((-696 . -1060) 78027) ((-597 . -1236) 78004) ((-1116 . -1044) 77986) ((-316 . -174) 77917) ((-364 . -1098) T) ((-357 . -1098) T) ((-345 . -1098) T) ((-513 . -19) 77899) ((-1100 . -155) 77883) ((-739 . -303) 77862) ((-112 . -1098) T) ((-125 . -1060) 77849) ((-707 . -368) T) ((-513 . -605) 77824) ((-696 . -120) 77809) ((-442 . -105) T) ((-1164 . -922) 77788) ((-50 . -1142) 77738) ((-125 . -120) 77723) ((-220 . -848) T) ((-146 . -848) 77693) ((-630 . -716) T) ((-606 . -716) T) ((-816 . -527) 77626) ((-1042 . -1204) T) ((-950 . -155) 77610) ((-532 . -105) 77560) ((-1086 . -1214) 77539) ((-783 . -1214) 77518) ((-781 . -1214) 77497) ((-67 . -1204) T) ((-493 . -612) 77449) ((-493 . -613) 77371) ((-1166 . -457) 77302) ((-1152 . -1098) T) ((-1135 . -641) 77276) ((-1086 . -562) 77207) ((-497 . -417) 77176) ((-619 . -922) 77155) ((-459 . -1214) 77134) ((-1121 . -457) 77085) ((-783 . -562) 76996) ((-404 . -612) 76978) ((-781 . -562) 76909) ((-670 . -527) 76842) ((-727 . -305) 76829) ((-660 . -25) T) ((-660 . -21) T) ((-459 . -562) 76760) ((-126 . -922) T) ((-126 . -821) NIL) ((-359 . -25) T) ((-359 . -21) T) ((-356 . -25) T) ((-356 . -21) T) ((-344 . -25) T) ((-344 . -21) T) ((-259 . -25) T) ((-259 . -21) T) ((-88 . -390) T) ((-88 . -401) T) ((-244 . -25) T) ((-244 . -21) T) ((-1261 . -612) 76742) ((-1199 . -1110) T) ((-1199 . -23) T) ((-1160 . -305) 76627) ((-1122 . -305) 76614) ((-1080 . -713) 76482) ((-859 . -641) 76442) ((-950 . -988) 76426) ((-911 . -21) T) ((-286 . -174) T) ((-911 . -25) T) ((-872 . -848) 76377) ((-866 . -138) T) ((-707 . -1110) T) ((-707 . -23) T) ((-640 . -1098) 76355) ((-627 . -609) 76330) ((-627 . -1098) T) ((-585 . -1214) T) ((-530 . -1214) T) ((-585 . -562) T) ((-530 . -562) T) ((-364 . -713) 76282) ((-357 . -713) 76234) ((-345 . -713) 76186) ((-339 . -1060) 76170) ((-175 . -120) 76069) ((-175 . -1060) 76001) ((-112 . -713) 75951) ((-339 . -120) 75930) ((-272 . -1098) T) ((-271 . -1098) T) ((-270 . -1098) T) ((-269 . -1098) T) ((-696 . -1054) T) ((-268 . -1098) T) ((-267 . -1098) T) ((-266 . -1098) T) ((-206 . -1098) T) ((-205 . -1098) T) ((-203 . -1098) T) ((-171 . -1193) 75908) ((-171 . -1190) 75886) ((-202 . -1098) T) ((-201 . -1098) T) ((-125 . -1054) T) ((-200 . -1098) T) ((-197 . -1098) T) ((-696 . -227) T) ((-196 . -1098) T) ((-195 . -1098) T) ((-194 . -1098) T) ((-193 . -1098) T) ((-192 . -1098) T) ((-191 . -1098) T) ((-190 . -1098) T) ((-189 . -1098) T) ((-188 . -1098) T) ((-187 . -1098) T) ((-234 . -105) 75676) ((-171 . -40) 75654) ((-171 . -98) 75632) ((-861 . -138) T) ((-648 . -1044) 75528) ((-497 . -1061) 75458) ((-1135 . -39) T) ((-1111 . -1098) 75248) ((-1085 . -105) T) ((-666 . -503) 75232) ((-78 . -1204) T) ((-109 . -612) 75214) ((-1281 . -612) 75196) ((-387 . -612) 75178) ((-579 . -1193) T) ((-579 . -1190) T) ((-727 . -43) 75027) ((-538 . -612) 75009) ((-532 . -305) 74947) ((-513 . -612) 74929) ((-513 . -613) 74911) ((-1160 . -1144) NIL) ((-1034 . -1073) 74880) ((-1034 . -1098) T) ((-1011 . -105) T) ((-979 . -105) T) ((-916 . -105) T) ((-894 . -1044) 74857) ((-1135 . -722) T) ((-1010 . -641) 74802) ((-485 . -1098) T) ((-472 . -1098) T) ((-589 . -23) T) ((-579 . -40) T) ((-579 . -98) T) ((-433 . -105) T) ((-1066 . -223) 74748) ((-1168 . -43) 74645) ((-859 . -722) T) ((-689 . -922) T) ((-524 . -25) T) ((-520 . -21) T) ((-520 . -25) T) ((-1167 . -43) 74486) ((-339 . -1054) T) ((-1160 . -43) 74282) ((-1080 . -174) T) ((-175 . -1054) T) ((-1122 . -43) 74179) ((-708 . -52) 74156) ((-364 . -174) T) ((-357 . -174) T) ((-531 . -62) 74130) ((-510 . -62) 74080) ((-355 . -1276) 74057) ((-217 . -457) T) ((-316 . -287) 74008) ((-345 . -174) T) ((-175 . -240) T) ((-1221 . -848) 73907) ((-112 . -174) T) ((-872 . -1000) 73891) ((-652 . -1110) T) ((-585 . -368) T) ((-585 . -329) 73878) ((-530 . -329) 73855) ((-530 . -368) T) ((-312 . -303) 73834) ((-309 . -303) T) ((-603 . -848) 73813) ((-1111 . -713) 73755) ((-532 . -279) 73739) ((-652 . -23) T) ((-424 . -225) 73723) ((-1205 . -105) T) ((-309 . -1028) NIL) ((-336 . -23) T) ((-238 . -23) T) ((-106 . -1017) 73707) ((-50 . -41) 73686) ((-611 . -1098) T) ((-355 . -374) T) ((-508 . -27) T) ((-234 . -305) 73624) ((-1086 . -1110) T) ((-1280 . -641) 73598) ((-783 . -1110) T) ((-781 . -1110) T) ((-459 . -1110) T) ((-1065 . -457) T) ((-1209 . -1098) T) ((-959 . -457) 73549) ((-114 . -1098) T) ((-1086 . -23) T) ((-818 . -1061) T) ((-783 . -23) T) ((-781 . -23) T) ((-496 . -457) 73500) ((-1153 . -527) 73248) ((-387 . -388) 73227) ((-1172 . -417) 73211) ((-467 . -23) T) ((-459 . -23) T) ((-740 . -417) 73195) ((-739 . -298) T) ((-498 . -527) 73128) ((-286 . -287) T) ((-1082 . -612) 73110) ((-413 . -910) 73089) ((-55 . -1110) T) ((-1030 . -922) T) ((-1010 . -722) T) ((-708 . -887) NIL) ((-585 . -1110) T) ((-530 . -1110) T) ((-841 . -641) 73062) ((-1199 . -138) T) ((-1160 . -406) 73014) ((-1011 . -305) NIL) ((-816 . -503) 72998) ((-358 . -922) T) ((-1150 . -39) T) ((-413 . -641) 72950) ((-55 . -23) T) ((-707 . -138) T) ((-708 . -1044) 72830) ((-585 . -23) T) ((-112 . -527) NIL) ((-530 . -23) T) ((-171 . -415) 72801) ((-217 . -1132) T) ((-1133 . -1098) T) ((-1272 . -1271) 72785) ((-696 . -796) T) ((-696 . -793) T) ((-385 . -151) T) ((-1116 . -303) T) ((-1221 . -1000) 72755) ((-53 . -922) T) ((-670 . -503) 72739) ((-246 . -1266) 72709) ((-245 . -1266) 72679) ((-1170 . -848) T) ((-1111 . -174) 72658) ((-1116 . -1028) T) ((-1051 . -39) T) ((-835 . -151) 72637) ((-835 . -149) 72616) ((-733 . -111) 72600) ((-611 . -139) T) ((-497 . -1098) 72390) ((-1172 . -1061) T) ((-871 . -457) T) ((-90 . -1204) T) ((-234 . -43) 72360) ((-143 . -111) 72342) ((-929 . -1096) T) ((-708 . -383) 72326) ((-740 . -1061) T) ((-1116 . -554) T) ((-1205 . -305) NIL) ((-396 . -1060) 72310) ((-1280 . -722) T) ((-1269 . -1061) T) ((-1166 . -956) 72279) ((-57 . -612) 72261) ((-1121 . -956) 72228) ((-647 . -417) 72212) ((-1250 . -105) T) ((-1243 . -105) T) ((-617 . -1060) 72196) ((-656 . -25) T) ((-656 . -21) T) ((-1152 . -527) NIL) ((-1222 . -105) T) ((-1206 . -1204) T) ((-396 . -120) 72175) ((-214 . -249) 72159) ((-1216 . -105) T) ((-1058 . -1098) T) ((-1011 . -1144) T) ((-1058 . -1057) 72099) ((-819 . -1098) T) ((-343 . -1214) T) ((-630 . -641) 72083) ((-617 . -120) 72062) ((-606 . -641) 72046) ((-598 . -105) T) ((-589 . -138) T) ((-597 . -105) T) ((-420 . -1098) T) ((-391 . -1098) T) ((-221 . -1098) 72024) ((-640 . -527) 71957) ((-627 . -527) 71765) ((-834 . -1054) 71744) ((-638 . -155) 71728) ((-343 . -562) T) ((-708 . -901) 71671) ((-555 . -223) 71621) ((-1250 . -281) 71587) ((-1243 . -281) 71553) ((-1080 . -287) 71504) ((-501 . -846) T) ((-215 . -1110) T) ((-1222 . -281) 71470) ((-1216 . -281) 71436) ((-1011 . -43) 71386) ((-210 . -846) T) ((-1199 . -506) 71352) ((-916 . -43) 71304) ((-841 . -795) 71283) ((-841 . -792) 71262) ((-841 . -722) 71241) ((-364 . -287) T) ((-357 . -287) T) ((-345 . -287) T) ((-171 . -457) 71172) ((-433 . -43) 71156) ((-112 . -287) T) ((-215 . -23) T) ((-413 . -795) 71135) ((-413 . -792) 71114) ((-413 . -722) T) ((-513 . -285) 71089) ((-493 . -1060) 71054) ((-652 . -138) T) ((-1111 . -527) 70987) ((-336 . -138) T) ((-171 . -408) 70966) ((-238 . -138) T) ((-497 . -713) 70908) ((-816 . -283) 70885) ((-493 . -120) 70834) ((-33 . -37) 70818) ((-647 . -1061) T) ((-1231 . -457) 70749) ((-1086 . -138) T) ((-259 . -848) 70728) ((-244 . -848) 70707) ((-783 . -138) T) ((-781 . -138) T) ((-579 . -457) T) ((-1058 . -713) 70649) ((-617 . -1054) T) ((-1034 . -527) 70582) ((-467 . -138) T) ((-459 . -138) T) ((-50 . -1098) T) ((-391 . -713) 70552) ((-818 . -1098) T) ((-485 . -527) 70485) ((-472 . -527) 70418) ((-458 . -372) 70388) ((-50 . -609) 70367) ((-312 . -298) T) ((-666 . -612) 70329) ((-64 . -848) 70308) ((-1222 . -305) 70193) ((-1011 . -406) 70175) ((-816 . -605) 70152) ((-529 . -848) 70131) ((-509 . -848) 70110) ((-45 . -1214) T) ((-1006 . -1044) 70006) ((-55 . -138) T) ((-585 . -138) T) ((-530 . -138) T) ((-290 . -641) 69866) ((-343 . -329) 69843) ((-343 . -368) T) ((-321 . -322) 69820) ((-316 . -283) 69805) ((-45 . -562) T) ((-385 . -1190) T) ((-385 . -1193) T) ((-1042 . -1181) 69780) ((-1178 . -229) 69730) ((-1160 . -225) 69682) ((-1042 . -111) 69628) ((-330 . -1098) T) ((-385 . -98) T) ((-385 . -40) T) ((-866 . -21) T) ((-866 . -25) T) ((-861 . -25) T) ((-493 . -1054) T) ((-542 . -540) 69572) ((-861 . -21) T) ((-494 . -229) 69522) ((-1153 . -503) 69456) ((-1281 . -1060) 69440) ((-387 . -1060) 69424) ((-493 . -240) T) ((-817 . -105) T) ((-710 . -151) 69403) ((-710 . -149) 69382) ((-498 . -503) 69366) ((-1281 . -120) 69345) ((-499 . -335) 69314) ((-1006 . -383) 69298) ((-525 . -1098) T) ((-497 . -174) 69277) ((-1006 . -338) 69261) ((-419 . -105) T) ((-387 . -120) 69240) ((-277 . -991) 69224) ((-276 . -991) 69208) ((-218 . -39) T) ((-145 . -39) T) ((-1209 . -527) NIL) ((-1279 . -612) 69190) ((-1277 . -612) 69172) ((-114 . -527) NIL) ((-1166 . -1234) 69156) ((-852 . -850) 69140) ((-1172 . -1098) T) ((-106 . -1204) T) ((-959 . -956) 69101) ((-740 . -1098) T) ((-818 . -713) 69038) ((-1222 . -1144) NIL) ((-496 . -956) 68983) ((-1065 . -147) T) ((-65 . -105) 68961) ((-49 . -612) 68943) ((-83 . -612) 68925) ((-355 . -641) 68870) ((-1269 . -1098) T) ((-524 . -848) T) ((-343 . -1110) T) ((-291 . -1098) T) ((-1006 . -901) 68829) ((-291 . -609) 68808) ((-1250 . -43) 68705) ((-1243 . -43) 68546) ((-541 . -1096) T) ((-1222 . -43) 68342) ((-501 . -1061) T) ((-1216 . -43) 68239) ((-210 . -1061) T) ((-343 . -23) T) ((-156 . -612) 68221) ((-834 . -796) 68200) ((-834 . -793) 68179) ((-739 . -922) 68158) ((-598 . -43) 68131) ((-597 . -43) 68028) ((-870 . -562) T) ((-215 . -138) T) ((-316 . -1009) 67994) ((-84 . -612) 67976) ((-708 . -303) 67955) ((-290 . -722) 67857) ((-825 . -105) T) ((-858 . -842) T) ((-290 . -482) 67836) ((-1272 . -105) T) ((-45 . -368) T) ((-872 . -151) 67815) ((-33 . -1098) T) ((-872 . -149) 67794) ((-1152 . -503) 67776) ((-1281 . -1054) T) ((-497 . -527) 67709) ((-1139 . -1204) T) ((-972 . -612) 67691) ((-640 . -503) 67675) ((-627 . -503) 67607) ((-816 . -612) 67365) ((-53 . -27) T) ((-1172 . -713) 67262) ((-647 . -1098) T) ((-442 . -369) 67236) ((-740 . -713) 67065) ((-1100 . -105) T) ((-817 . -305) 67052) ((-858 . -1098) T) ((-1277 . -388) 67024) ((-1058 . -527) 66957) ((-1153 . -283) 66933) ((-234 . -225) 66902) ((-1269 . -713) 66872) ((-818 . -174) 66851) ((-221 . -527) 66784) ((-617 . -796) 66763) ((-617 . -793) 66742) ((-1202 . -612) 66689) ((-214 . -1204) T) ((-670 . -612) 66656) ((-1150 . -1017) 66640) ((-355 . -722) T) ((-950 . -105) 66590) ((-1222 . -406) 66542) ((-1111 . -503) 66526) ((-65 . -305) 66464) ((-331 . -105) T) ((-1199 . -21) T) ((-1199 . -25) T) ((-45 . -1110) T) ((-707 . -21) T) ((-622 . -612) 66446) ((-528 . -322) 66425) ((-707 . -25) T) ((-112 . -283) NIL) ((-923 . -1110) T) ((-45 . -23) T) ((-769 . -1110) T) ((-572 . -1214) T) ((-508 . -1214) T) ((-316 . -612) 66407) ((-1011 . -225) 66389) ((-171 . -168) 66373) ((-584 . -562) T) ((-572 . -562) T) ((-508 . -562) T) ((-769 . -23) T) ((-1242 . -151) 66352) ((-1153 . -605) 66328) ((-1242 . -149) 66307) ((-1034 . -503) 66291) ((-1221 . -149) 66216) ((-1221 . -151) 66141) ((-1272 . -1278) 66120) ((-485 . -503) 66104) ((-472 . -503) 66088) ((-535 . -39) T) ((-647 . -713) 66058) ((-656 . -848) 66037) ((-1172 . -174) 65988) ((-370 . -105) T) ((-234 . -232) 65967) ((-246 . -105) T) ((-245 . -105) T) ((-1231 . -956) 65936) ((-113 . -105) T) ((-242 . -848) 65915) ((-817 . -43) 65764) ((-740 . -174) 65655) ((-50 . -527) 65415) ((-1152 . -283) 65390) ((-207 . -1098) T) ((-1143 . -1098) T) ((-927 . -105) T) ((-1143 . -609) 65369) ((-589 . -25) T) ((-589 . -21) T) ((-1100 . -305) 65307) ((-971 . -417) 65291) ((-694 . -1214) T) ((-627 . -283) 65266) ((-1086 . -634) 65214) ((-783 . -634) 65162) ((-781 . -634) 65110) ((-343 . -138) T) ((-286 . -612) 65092) ((-927 . -926) 65064) ((-694 . -562) T) ((-906 . -1098) T) ((-870 . -1110) T) ((-459 . -634) 65012) ((-906 . -904) 64996) ((-863 . -862) T) ((-863 . -864) T) ((-950 . -305) 64934) ((-385 . -457) T) ((-870 . -23) T) ((-501 . -1098) T) ((-863 . -149) T) ((-696 . -641) 64921) ((-863 . -151) 64900) ((-210 . -1098) T) ((-312 . -922) 64879) ((-309 . -922) T) ((-309 . -821) NIL) ((-396 . -716) T) ((-780 . -149) 64858) ((-780 . -151) 64837) ((-1209 . -503) 64819) ((-125 . -641) 64806) ((-483 . -149) 64785) ((-424 . -417) 64769) ((-483 . -151) 64748) ((-114 . -503) 64730) ((-1164 . -1214) 64709) ((-2 . -612) 64691) ((-1152 . -19) 64673) ((-1164 . -562) 64584) ((-1152 . -605) 64559) ((-652 . -21) T) ((-652 . -25) T) ((-595 . -1137) T) ((-1111 . -283) 64536) ((-336 . -25) T) ((-336 . -21) T) ((-238 . -25) T) ((-238 . -21) T) ((-508 . -368) T) ((-1272 . -43) 64506) ((-1135 . -1204) T) ((-627 . -605) 64481) ((-1086 . -25) T) ((-1086 . -21) T) ((-971 . -1061) T) ((-740 . -527) 64427) ((-538 . -793) T) ((-538 . -796) T) ((-126 . -1214) T) ((-235 . -105) T) ((-619 . -562) T) ((-783 . -25) T) ((-783 . -21) T) ((-781 . -21) T) ((-781 . -25) T) ((-731 . -1061) T) ((-711 . -1061) T) ((-666 . -1060) 64411) ((-467 . -25) T) ((-126 . -562) T) ((-467 . -21) T) ((-459 . -25) T) ((-459 . -21) T) ((-1135 . -1044) 64307) ((-818 . -287) 64286) ((-739 . -436) 64270) ((-824 . -1098) T) ((-666 . -120) 64249) ((-291 . -527) 64009) ((-1279 . -1060) 63993) ((-1277 . -1060) 63977) ((-1242 . -1190) 63943) ((-246 . -305) 63881) ((-245 . -305) 63819) ((-1225 . -105) 63797) ((-1153 . -613) NIL) ((-1153 . -612) 63779) ((-1242 . -1193) 63745) ((-1222 . -225) 63697) ((-1221 . -1190) 63663) ((-1221 . -1193) 63629) ((-1135 . -383) 63613) ((-1116 . -821) T) ((-1116 . -922) T) ((-1111 . -605) 63590) ((-1080 . -613) 63574) ((-542 . -105) T) ((-498 . -612) 63541) ((-816 . -285) 63518) ((-607 . -155) 63465) ((-424 . -1061) T) ((-501 . -713) 63415) ((-497 . -503) 63399) ((-327 . -848) 63378) ((-339 . -641) 63352) ((-55 . -21) T) ((-55 . -25) T) ((-210 . -713) 63302) ((-171 . -720) 63273) ((-175 . -641) 63205) ((-585 . -21) T) ((-585 . -25) T) ((-530 . -25) T) ((-530 . -21) T) ((-484 . -155) 63155) ((-1080 . -612) 63137) ((-1064 . -612) 63119) ((-1001 . -105) T) ((-856 . -105) T) ((-800 . -417) 63082) ((-45 . -138) T) ((-694 . -368) T) ((-206 . -896) T) ((-696 . -795) T) ((-696 . -792) T) ((-584 . -1110) T) ((-572 . -1110) T) ((-508 . -1110) T) ((-696 . -722) T) ((-364 . -612) 63064) ((-357 . -612) 63046) ((-345 . -612) 63028) ((-71 . -402) T) ((-71 . -401) T) ((-112 . -613) 62958) ((-112 . -612) 62940) ((-205 . -896) T) ((-965 . -155) 62924) ((-1242 . -98) 62890) ((-769 . -138) T) ((-140 . -722) T) ((-125 . -722) T) ((-1242 . -40) 62856) ((-1058 . -503) 62840) ((-584 . -23) T) ((-572 . -23) T) ((-508 . -23) T) ((-1221 . -98) 62806) ((-1221 . -40) 62772) ((-1166 . -105) T) ((-1121 . -105) T) ((-852 . -105) T) ((-221 . -503) 62756) ((-1279 . -120) 62735) ((-1277 . -120) 62714) ((-49 . -1060) 62698) ((-1231 . -1234) 62682) ((-853 . -850) 62666) ((-1172 . -287) 62645) ((-114 . -283) 62620) ((-1135 . -901) 62579) ((-49 . -120) 62558) ((-740 . -287) 62469) ((-666 . -1054) T) ((-1160 . -846) NIL) ((-1152 . -613) NIL) ((-1152 . -612) 62451) ((-1066 . -609) 62426) ((-1066 . -1098) T) ((-79 . -446) T) ((-79 . -401) T) ((-666 . -227) 62405) ((-156 . -1060) 62389) ((-579 . -559) 62373) ((-359 . -151) 62352) ((-359 . -149) 62303) ((-356 . -151) 62282) ((-698 . -1098) T) ((-356 . -149) 62233) ((-344 . -151) 62212) ((-344 . -149) 62163) ((-259 . -149) 62142) ((-259 . -151) 62121) ((-246 . -43) 62091) ((-244 . -151) 62070) ((-126 . -368) T) ((-244 . -149) 62049) ((-245 . -43) 62019) ((-156 . -120) 61998) ((-1010 . -1044) 61873) ((-928 . -1096) T) ((-689 . -1214) T) ((-800 . -1061) T) ((-694 . -1110) T) ((-1279 . -1054) T) ((-1277 . -1054) T) ((-1164 . -1110) T) ((-1150 . -1204) T) ((-1010 . -383) 61850) ((-911 . -149) T) ((-911 . -151) 61832) ((-870 . -138) T) ((-816 . -1060) 61729) ((-689 . -562) T) ((-694 . -23) T) ((-640 . -612) 61696) ((-640 . -613) 61657) ((-627 . -613) NIL) ((-627 . -612) 61639) ((-501 . -174) T) ((-215 . -21) T) ((-215 . -25) T) ((-210 . -174) T) ((-483 . -1193) 61605) ((-483 . -1190) 61571) ((-272 . -612) 61553) ((-271 . -612) 61535) ((-270 . -612) 61517) ((-269 . -612) 61499) ((-268 . -612) 61481) ((-513 . -644) 61463) ((-267 . -612) 61445) ((-339 . -722) T) ((-266 . -612) 61427) ((-114 . -19) 61409) ((-175 . -722) T) ((-513 . -379) 61391) ((-206 . -612) 61373) ((-532 . -1142) 61357) ((-513 . -133) T) ((-114 . -605) 61332) ((-205 . -612) 61314) ((-483 . -40) 61280) ((-483 . -98) 61246) ((-203 . -612) 61228) ((-202 . -612) 61210) ((-201 . -612) 61192) ((-200 . -612) 61174) ((-197 . -612) 61156) ((-196 . -612) 61138) ((-195 . -612) 61120) ((-194 . -612) 61102) ((-193 . -612) 61084) ((-192 . -612) 61066) ((-191 . -612) 61048) ((-545 . -1101) 61000) ((-190 . -612) 60982) ((-189 . -612) 60964) ((-50 . -503) 60901) ((-188 . -612) 60883) ((-187 . -612) 60865) ((-1164 . -23) T) ((-816 . -120) 60755) ((-638 . -105) 60705) ((-497 . -283) 60682) ((-1111 . -612) 60440) ((-1099 . -1098) T) ((-1051 . -1204) T) ((-619 . -1110) T) ((-1280 . -1044) 60424) ((-1166 . -305) 60411) ((-1121 . -305) 60398) ((-126 . -1110) T) ((-1209 . -683) 60364) ((-820 . -105) T) ((-619 . -23) T) ((-1143 . -527) 60124) ((-392 . -105) T) ((-323 . -105) T) ((-1010 . -901) 60076) ((-971 . -1098) T) ((-156 . -1054) T) ((-126 . -23) T) ((-727 . -417) 60060) ((-731 . -1098) T) ((-711 . -1098) T) ((-698 . -139) T) ((-458 . -1098) T) ((-312 . -436) 60044) ((-413 . -1204) T) ((-1034 . -613) 60005) ((-1034 . -612) 59967) ((-1030 . -1214) T) ((-217 . -105) T) ((-235 . -43) 59913) ((-817 . -225) 59897) ((-1030 . -562) T) ((-834 . -641) 59870) ((-358 . -1214) T) ((-485 . -612) 59832) ((-485 . -613) 59793) ((-472 . -613) 59754) ((-472 . -612) 59716) ((-413 . -885) 59700) ((-316 . -1060) 59535) ((-413 . -887) 59460) ((-841 . -1044) 59356) ((-501 . -527) NIL) ((-497 . -605) 59333) ((-358 . -562) T) ((-210 . -527) NIL) ((-872 . -457) T) ((-424 . -1098) T) ((-413 . -1044) 59197) ((-316 . -120) 59011) ((-689 . -368) T) ((-217 . -281) T) ((-53 . -1214) T) ((-816 . -1054) 58941) ((-584 . -138) T) ((-572 . -138) T) ((-508 . -138) T) ((-53 . -562) T) ((-1153 . -285) 58917) ((-1166 . -1144) 58895) ((-312 . -27) 58874) ((-1065 . -105) T) ((-816 . -227) 58826) ((-234 . -846) 58805) ((-959 . -105) T) ((-709 . -105) T) ((-291 . -503) 58742) ((-496 . -105) T) ((-727 . -1061) T) ((-611 . -612) 58724) ((-611 . -613) 58585) ((-413 . -383) 58569) ((-413 . -338) 58553) ((-1166 . -43) 58382) ((-1121 . -43) 58231) ((-852 . -43) 58201) ((-396 . -641) 58185) ((-638 . -305) 58123) ((-1209 . -612) 58105) ((-971 . -713) 58002) ((-731 . -713) 57972) ((-214 . -111) 57956) ((-50 . -283) 57881) ((-617 . -641) 57855) ((-307 . -1098) T) ((-286 . -1060) 57842) ((-114 . -612) 57824) ((-114 . -613) 57806) ((-458 . -713) 57776) ((-817 . -248) 57715) ((-685 . -1098) 57693) ((-555 . -1098) T) ((-1168 . -1061) T) ((-1167 . -1061) T) ((-286 . -120) 57678) ((-1160 . -1061) T) ((-1122 . -1061) T) ((-555 . -609) 57657) ((-1011 . -846) T) ((-221 . -683) 57615) ((-689 . -1110) T) ((-1199 . -736) 57591) ((-974 . -978) 57568) ((-316 . -1054) T) ((-343 . -25) T) ((-343 . -21) T) ((-413 . -901) 57527) ((-73 . -1204) T) ((-834 . -795) 57506) ((-424 . -713) 57480) ((-800 . -1098) T) ((-834 . -792) 57459) ((-694 . -138) T) ((-708 . -922) 57438) ((-689 . -23) T) ((-501 . -287) T) ((-834 . -722) 57417) ((-316 . -227) 57369) ((-316 . -240) 57348) ((-210 . -287) T) ((-1030 . -368) T) ((-1242 . -457) 57327) ((-1221 . -457) 57306) ((-358 . -329) 57283) ((-358 . -368) T) ((-1133 . -612) 57265) ((-50 . -1246) 57215) ((-871 . -105) T) ((-638 . -279) 57199) ((-694 . -1063) T) ((-493 . -641) 57164) ((-477 . -1098) T) ((-50 . -605) 57089) ((-1152 . -285) 57064) ((-1164 . -138) T) ((-45 . -634) 56998) ((-53 . -368) T) ((-1104 . -612) 56980) ((-1086 . -848) 56959) ((-627 . -285) 56934) ((-1207 . -1098) T) ((-959 . -305) 56921) ((-783 . -848) 56900) ((-781 . -848) 56879) ((-459 . -848) 56858) ((-497 . -612) 56616) ((-234 . -417) 56585) ((-218 . -1204) T) ((-145 . -1204) T) ((-220 . -155) 56567) ((-146 . -155) 56542) ((-70 . -1204) T) ((-740 . -283) 56469) ((-619 . -138) T) ((-496 . -305) 56456) ((-1066 . -527) 56264) ((-286 . -1054) T) ((-126 . -138) T) ((-458 . -759) T) ((-971 . -174) 56215) ((-1159 . -1098) T) ((-1111 . -285) 56192) ((-1080 . -1060) 56102) ((-617 . -795) 56081) ((-595 . -1098) T) ((-617 . -792) 56060) ((-617 . -722) T) ((-291 . -283) 56039) ((-290 . -1204) T) ((-1058 . -612) 56001) ((-1058 . -613) 55962) ((-1030 . -1110) T) ((-171 . -105) T) ((-273 . -848) T) ((-1100 . -223) 55946) ((-819 . -612) 55928) ((-1080 . -120) 55817) ((-1010 . -303) T) ((-863 . -457) T) ((-800 . -713) 55801) ((-364 . -1060) 55753) ((-358 . -1110) T) ((-357 . -1060) 55705) ((-420 . -612) 55687) ((-391 . -612) 55669) ((-345 . -1060) 55621) ((-221 . -612) 55588) ((-1030 . -23) T) ((-780 . -457) T) ((-112 . -1060) 55538) ((-899 . -105) T) ((-839 . -105) T) ((-809 . -105) T) ((-767 . -105) T) ((-672 . -105) T) ((-483 . -457) 55517) ((-424 . -174) T) ((-364 . -120) 55448) ((-357 . -120) 55379) ((-345 . -120) 55310) ((-246 . -225) 55279) ((-245 . -225) 55248) ((-358 . -23) T) ((-76 . -1204) T) ((-217 . -43) 55213) ((-112 . -120) 55140) ((-45 . -25) T) ((-45 . -21) T) ((-666 . -716) T) ((-171 . -281) 55118) ((-863 . -408) T) ((-53 . -1110) T) ((-923 . -25) T) ((-769 . -25) T) ((-1143 . -503) 55055) ((-499 . -1098) T) ((-1281 . -641) 55029) ((-1231 . -105) T) ((-853 . -105) T) ((-234 . -1061) 54959) ((-1065 . -1144) T) ((-972 . -793) 54912) ((-387 . -641) 54896) ((-53 . -23) T) ((-972 . -796) 54849) ((-816 . -796) 54800) ((-816 . -793) 54751) ((-291 . -605) 54730) ((-493 . -722) T) ((-1164 . -506) 54708) ((-579 . -105) T) ((-1085 . -1061) T) ((-871 . -305) 54652) ((-647 . -283) 54631) ((-121 . -655) T) ((-81 . -1204) T) ((-1065 . -43) 54618) ((-660 . -380) 54597) ((-959 . -43) 54446) ((-727 . -1098) T) ((-496 . -43) 54295) ((-91 . -1204) T) ((-579 . -281) T) ((-1222 . -846) NIL) ((-1168 . -1098) T) ((-1167 . -1098) T) ((-1160 . -1098) T) ((-355 . -1044) 54272) ((-1080 . -1054) T) ((-1011 . -1061) T) ((-50 . -612) 54254) ((-50 . -613) NIL) ((-916 . -1061) T) ((-818 . -612) 54236) ((-1140 . -105) 54214) ((-1080 . -240) 54165) ((-433 . -1061) T) ((-364 . -1054) T) ((-357 . -1054) T) ((-370 . -369) 54142) ((-345 . -1054) T) ((-246 . -232) 54121) ((-245 . -232) 54100) ((-113 . -369) 54074) ((-1080 . -227) 53999) ((-1122 . -1098) T) ((-290 . -901) 53958) ((-112 . -1054) T) ((-739 . -1214) 53937) ((-689 . -138) T) ((-424 . -527) 53779) ((-364 . -227) 53758) ((-364 . -240) T) ((-49 . -716) T) ((-357 . -227) 53737) ((-357 . -240) T) ((-345 . -227) 53716) ((-345 . -240) T) ((-739 . -562) T) ((-171 . -305) 53681) ((-112 . -240) T) ((-112 . -227) T) ((-316 . -793) T) ((-870 . -21) T) ((-870 . -25) T) ((-413 . -303) T) ((-513 . -39) T) ((-114 . -285) 53656) ((-1111 . -1060) 53553) ((-871 . -1144) NIL) ((-866 . -865) T) ((-866 . -864) T) ((-861 . -860) T) ((-861 . -864) T) ((-861 . -865) T) ((-330 . -612) 53535) ((-413 . -1028) 53513) ((-1111 . -120) 53403) ((-866 . -149) 53373) ((-866 . -151) T) ((-861 . -151) T) ((-861 . -149) 53343) ((-442 . -1098) T) ((-1281 . -722) T) ((-68 . -612) 53325) ((-871 . -43) 53270) ((-535 . -1204) T) ((-603 . -155) 53254) ((-525 . -612) 53236) ((-1231 . -305) 53223) ((-727 . -713) 53072) ((-538 . -794) T) ((-538 . -795) T) ((-572 . -634) 53054) ((-508 . -634) 53014) ((-359 . -457) T) ((-356 . -457) T) ((-344 . -457) T) ((-259 . -457) 52965) ((-532 . -1098) 52915) ((-244 . -457) 52866) ((-1143 . -283) 52845) ((-1172 . -612) 52827) ((-685 . -527) 52760) ((-971 . -287) 52739) ((-555 . -527) 52499) ((-740 . -613) NIL) ((-740 . -612) 52481) ((-1269 . -612) 52463) ((-1166 . -225) 52447) ((-171 . -1144) 52426) ((-1254 . -562) 52405) ((-1168 . -713) 52302) ((-1167 . -713) 52143) ((-893 . -105) T) ((-1160 . -713) 51939) ((-1122 . -713) 51836) ((-1150 . -669) 51820) ((-359 . -408) 51771) ((-356 . -408) 51722) ((-344 . -408) 51673) ((-1030 . -138) T) ((-800 . -527) 51585) ((-291 . -613) NIL) ((-291 . -612) 51567) ((-911 . -457) T) ((-972 . -374) 51520) ((-816 . -374) 51499) ((-523 . -522) 51478) ((-521 . -522) 51457) ((-501 . -283) NIL) ((-497 . -285) 51434) ((-424 . -287) T) ((-358 . -138) T) ((-210 . -283) NIL) ((-689 . -506) NIL) ((-101 . -1110) T) ((-171 . -43) 51262) ((-1244 . -562) T) ((-1242 . -981) 51224) ((-1140 . -305) 51162) ((-1221 . -981) 51131) ((-911 . -408) T) ((-1111 . -1054) 51061) ((-1143 . -605) 51040) ((-739 . -368) 51019) ((-780 . -155) 50971) ((-121 . -848) T) ((-1066 . -503) 50903) ((-584 . -21) T) ((-584 . -25) T) ((-572 . -21) T) ((-572 . -25) T) ((-508 . -25) T) ((-508 . -21) T) ((-1231 . -1144) 50881) ((-1111 . -227) 50833) ((-53 . -138) T) ((-33 . -612) 50815) ((-975 . -1096) T) ((-1186 . -105) T) ((-234 . -1098) 50605) ((-871 . -406) 50582) ((-1087 . -105) T) ((-1076 . -105) T) ((-1207 . -527) NIL) ((-607 . -105) T) ((-484 . -105) T) ((-1231 . -43) 50411) ((-1085 . -1098) T) ((-853 . -43) 50381) ((-1164 . -634) 50329) ((-727 . -174) 50240) ((-647 . -612) 50222) ((-579 . -43) 50209) ((-965 . -105) 50159) ((-858 . -612) 50141) ((-858 . -613) 50063) ((-595 . -527) NIL) ((-1250 . -1061) T) ((-1243 . -1061) T) ((-1222 . -1061) T) ((-1216 . -1061) T) ((-1285 . -1110) T) ((-1199 . -151) 50042) ((-1168 . -174) 49993) ((-598 . -1061) T) ((-597 . -1061) T) ((-1167 . -174) 49924) ((-1160 . -174) 49855) ((-1122 . -174) 49806) ((-1011 . -1098) T) ((-979 . -1098) T) ((-916 . -1098) T) ((-800 . -798) 49790) ((-780 . -645) 49774) ((-780 . -981) 49743) ((-739 . -1110) T) ((-694 . -25) T) ((-694 . -21) T) ((-126 . -634) 49720) ((-696 . -887) 49702) ((-433 . -1098) T) ((-312 . -1214) 49681) ((-309 . -1214) T) ((-171 . -406) 49665) ((-1199 . -149) 49644) ((-483 . -981) 49606) ((-77 . -612) 49588) ((-739 . -23) T) ((-112 . -796) T) ((-112 . -793) T) ((-312 . -562) 49567) ((-696 . -1044) 49549) ((-309 . -562) T) ((-1285 . -23) T) ((-140 . -1044) 49531) ((-497 . -1060) 49428) ((-50 . -285) 49353) ((-1164 . -25) T) ((-1164 . -21) T) ((-234 . -713) 49295) ((-497 . -120) 49185) ((-1090 . -105) 49163) ((-1041 . -105) T) ((-1085 . -713) 49140) ((-638 . -829) 49119) ((-1205 . -1098) T) ((-727 . -527) 49057) ((-1058 . -1060) 49041) ((-619 . -21) T) ((-619 . -25) T) ((-1066 . -283) 49016) ((-366 . -105) T) ((-321 . -105) T) ((-666 . -641) 48990) ((-391 . -1060) 48974) ((-1058 . -120) 48953) ((-817 . -417) 48937) ((-126 . -25) T) ((-94 . -612) 48919) ((-126 . -21) T) ((-607 . -305) 48714) ((-484 . -305) 48518) ((-1254 . -1110) T) ((-1143 . -613) NIL) ((-391 . -120) 48497) ((-385 . -105) T) ((-207 . -612) 48479) ((-1143 . -612) 48461) ((-1011 . -713) 48411) ((-1160 . -527) 48145) ((-916 . -713) 48097) ((-1122 . -527) 48067) ((-355 . -303) T) ((-1254 . -23) T) ((-1178 . -155) 48017) ((-965 . -305) 47955) ((-835 . -105) T) ((-433 . -713) 47939) ((-217 . -829) T) ((-828 . -105) T) ((-826 . -105) T) ((-494 . -155) 47889) ((-1242 . -1241) 47868) ((-1116 . -1214) T) ((-339 . -1044) 47835) ((-1242 . -1236) 47805) ((-1242 . -1239) 47789) ((-1221 . -1220) 47768) ((-85 . -612) 47750) ((-906 . -612) 47732) ((-1221 . -1236) 47709) ((-1116 . -562) T) ((-923 . -848) T) ((-769 . -848) T) ((-501 . -613) 47639) ((-501 . -612) 47621) ((-385 . -281) T) ((-667 . -848) T) ((-1221 . -1218) 47605) ((-1244 . -1110) T) ((-210 . -613) 47535) ((-210 . -612) 47517) ((-1066 . -605) 47492) ((-64 . -155) 47476) ((-529 . -155) 47460) ((-509 . -155) 47444) ((-364 . -1276) 47428) ((-357 . -1276) 47412) ((-345 . -1276) 47396) ((-312 . -368) 47375) ((-309 . -368) T) ((-497 . -1054) 47305) ((-689 . -634) 47287) ((-1279 . -641) 47261) ((-1277 . -641) 47235) ((-1244 . -23) T) ((-685 . -503) 47219) ((-69 . -612) 47201) ((-1111 . -796) 47152) ((-1111 . -793) 47103) ((-555 . -503) 47040) ((-666 . -39) T) ((-497 . -227) 46992) ((-291 . -285) 46971) ((-234 . -174) 46950) ((-863 . -1266) 46934) ((-817 . -1061) T) ((-49 . -641) 46892) ((-1080 . -374) 46843) ((-727 . -287) 46774) ((-532 . -527) 46707) ((-818 . -1060) 46658) ((-1086 . -149) 46637) ((-364 . -374) 46616) ((-357 . -374) 46595) ((-345 . -374) 46574) ((-1086 . -151) 46553) ((-871 . -225) 46530) ((-818 . -120) 46465) ((-783 . -149) 46444) ((-783 . -151) 46423) ((-259 . -956) 46390) ((-246 . -846) 46369) ((-244 . -956) 46314) ((-245 . -846) 46293) ((-781 . -149) 46272) ((-781 . -151) 46251) ((-156 . -641) 46225) ((-459 . -151) 46204) ((-459 . -149) 46183) ((-666 . -722) T) ((-824 . -612) 46165) ((-1250 . -1098) T) ((-1243 . -1098) T) ((-1222 . -1098) T) ((-1216 . -1098) T) ((-1199 . -1193) 46131) ((-1199 . -1190) 46097) ((-1168 . -287) 46076) ((-1167 . -287) 46027) ((-1160 . -287) 45978) ((-1122 . -287) 45957) ((-339 . -901) 45938) ((-1011 . -174) T) ((-916 . -174) T) ((-780 . -1236) 45915) ((-598 . -1098) T) ((-597 . -1098) T) ((-689 . -21) T) ((-689 . -25) T) ((-483 . -1239) 45899) ((-483 . -1236) 45869) ((-424 . -283) 45797) ((-312 . -1110) 45646) ((-309 . -1110) T) ((-1199 . -40) 45612) ((-1199 . -98) 45578) ((-89 . -612) 45560) ((-96 . -105) 45538) ((-1285 . -138) T) ((-1207 . -503) 45520) ((-739 . -138) T) ((-585 . -149) T) ((-585 . -151) 45502) ((-530 . -151) 45484) ((-530 . -149) T) ((-312 . -23) 45336) ((-45 . -342) 45310) ((-309 . -23) T) ((-1152 . -644) 45292) ((-816 . -641) 45140) ((-1272 . -1061) T) ((-1152 . -379) 45122) ((-171 . -225) 45106) ((-595 . -503) 45088) ((-234 . -527) 45021) ((-1279 . -722) T) ((-1277 . -722) T) ((-1172 . -1060) 44904) ((-740 . -1060) 44727) ((-1172 . -120) 44589) ((-818 . -1054) T) ((-740 . -120) 44391) ((-528 . -105) T) ((-53 . -634) 44351) ((-523 . -105) T) ((-521 . -105) T) ((-1269 . -1060) 44321) ((-1041 . -43) 44305) ((-818 . -227) T) ((-818 . -240) 44284) ((-555 . -283) 44263) ((-1269 . -120) 44228) ((-1231 . -225) 44212) ((-1250 . -713) 44109) ((-1243 . -713) 43950) ((-1066 . -613) NIL) ((-1066 . -612) 43932) ((-1222 . -713) 43728) ((-1216 . -713) 43625) ((-1010 . -922) T) ((-698 . -612) 43594) ((-156 . -722) T) ((-1254 . -138) T) ((-1210 . -848) T) ((-1111 . -374) 43573) ((-1011 . -527) NIL) ((-246 . -417) 43542) ((-245 . -417) 43511) ((-1030 . -25) T) ((-1030 . -21) T) ((-598 . -713) 43484) ((-597 . -713) 43381) ((-800 . -283) 43339) ((-136 . -105) 43317) ((-834 . -1044) 43213) ((-171 . -829) 43192) ((-316 . -641) 43089) ((-816 . -39) T) ((-710 . -105) T) ((-1116 . -1110) T) ((-1033 . -1204) T) ((-385 . -43) 43054) ((-358 . -25) T) ((-358 . -21) T) ((-220 . -105) T) ((-163 . -105) T) ((-159 . -105) T) ((-146 . -105) T) ((-359 . -1266) 43038) ((-356 . -1266) 43022) ((-344 . -1266) 43006) ((-866 . -457) T) ((-171 . -353) 42985) ((-572 . -848) T) ((-508 . -848) T) ((-861 . -457) T) ((-1116 . -23) T) ((-92 . -612) 42967) ((-696 . -303) T) ((-835 . -43) 42937) ((-828 . -43) 42907) ((-1244 . -138) T) ((-1143 . -285) 42886) ((-972 . -722) 42785) ((-972 . -794) 42738) ((-972 . -795) 42691) ((-816 . -792) 42670) ((-125 . -303) T) ((-96 . -305) 42608) ((-670 . -39) T) ((-555 . -605) 42587) ((-53 . -25) T) ((-53 . -21) T) ((-816 . -795) 42538) ((-816 . -794) 42517) ((-696 . -1028) T) ((-647 . -1060) 42501) ((-972 . -482) 42454) ((-816 . -722) 42364) ((-911 . -1266) 42351) ((-238 . -322) 42328) ((-866 . -408) 42298) ((-497 . -796) 42249) ((-497 . -793) 42200) ((-861 . -408) 42170) ((-1172 . -1054) T) ((-1205 . -527) NIL) ((-740 . -1054) T) ((-647 . -120) 42149) ((-1172 . -326) 42126) ((-1191 . -105) 42104) ((-1099 . -612) 42086) ((-696 . -554) T) ((-740 . -326) 42063) ((-817 . -1098) T) ((-740 . -227) T) ((-1269 . -1054) T) ((-419 . -1098) T) ((-246 . -1061) 41993) ((-245 . -1061) 41923) ((-286 . -641) 41910) ((-595 . -283) 41885) ((-685 . -683) 41843) ((-1250 . -174) 41794) ((-971 . -612) 41776) ((-872 . -105) T) ((-731 . -612) 41758) ((-711 . -612) 41740) ((-1243 . -174) 41671) ((-1222 . -174) 41602) ((-1216 . -174) 41553) ((-694 . -848) T) ((-1011 . -287) T) ((-458 . -612) 41535) ((-622 . -722) T) ((-65 . -1098) 41513) ((-242 . -155) 41497) ((-916 . -287) T) ((-1030 . -1019) T) ((-622 . -482) T) ((-708 . -1214) 41476) ((-1254 . -506) 41442) ((-598 . -174) 41421) ((-597 . -174) 41372) ((-1259 . -848) 41351) ((-708 . -562) 41262) ((-413 . -922) T) ((-413 . -821) 41241) ((-316 . -795) T) ((-316 . -722) T) ((-424 . -612) 41223) ((-424 . -613) 41124) ((-638 . -1142) 41108) ((-114 . -644) 41090) ((-136 . -305) 41028) ((-114 . -379) 41010) ((-175 . -303) T) ((-404 . -1204) T) ((-312 . -138) 40881) ((-309 . -138) T) ((-74 . -401) T) ((-114 . -133) T) ((-1164 . -848) 40860) ((-532 . -503) 40844) ((-648 . -1110) T) ((-595 . -19) 40826) ((-220 . -305) NIL) ((-66 . -446) T) ((-146 . -305) NIL) ((-66 . -401) T) ((-825 . -1098) T) ((-595 . -605) 40801) ((-493 . -1044) 40761) ((-647 . -1054) T) ((-648 . -23) T) ((-1272 . -1098) T) ((-817 . -713) 40610) ((-1207 . -683) 40576) ((-130 . -848) T) ((-126 . -848) NIL) ((-1166 . -417) 40560) ((-1121 . -417) 40544) ((-852 . -417) 40528) ((-235 . -1061) T) ((-1242 . -105) T) ((-1222 . -527) 40262) ((-1191 . -305) 40200) ((-307 . -612) 40182) ((-1221 . -105) T) ((-1100 . -1098) T) ((-1168 . -283) 40167) ((-1167 . -283) 40152) ((-286 . -722) T) ((-112 . -910) NIL) ((-685 . -612) 40119) ((-685 . -613) 40080) ((-1080 . -641) 39990) ((-602 . -612) 39972) ((-555 . -613) NIL) ((-555 . -612) 39954) ((-1160 . -283) 39802) ((-501 . -1060) 39752) ((-707 . -457) T) ((-524 . -522) 39731) ((-520 . -522) 39710) ((-210 . -1060) 39660) ((-364 . -641) 39612) ((-357 . -641) 39564) ((-217 . -846) T) ((-345 . -641) 39516) ((-603 . -105) 39466) ((-497 . -374) 39445) ((-112 . -641) 39395) ((-501 . -120) 39322) ((-234 . -503) 39306) ((-343 . -151) 39288) ((-343 . -149) T) ((-171 . -376) 39259) ((-950 . -1257) 39243) ((-210 . -120) 39170) ((-872 . -305) 39135) ((-950 . -1098) 39085) ((-800 . -613) 39046) ((-800 . -612) 39028) ((-714 . -105) T) ((-331 . -1098) T) ((-1116 . -138) T) ((-710 . -43) 38998) ((-312 . -506) 38977) ((-513 . -1204) T) ((-1242 . -281) 38943) ((-1221 . -281) 38909) ((-327 . -155) 38893) ((-1066 . -285) 38868) ((-1272 . -713) 38838) ((-1153 . -39) T) ((-1281 . -1044) 38815) ((-739 . -634) 38721) ((-477 . -612) 38703) ((-498 . -39) T) ((-387 . -1044) 38687) ((-1166 . -1061) T) ((-1121 . -1061) T) ((-852 . -1061) T) ((-1065 . -846) T) ((-817 . -174) 38598) ((-532 . -283) 38575) ((-1207 . -612) 38557) ((-126 . -1000) 38534) ((-863 . -105) T) ((-780 . -105) T) ((-1250 . -287) 38513) ((-1243 . -287) 38464) ((-1186 . -369) 38438) ((-1087 . -264) 38422) ((-483 . -105) T) ((-370 . -1098) T) ((-246 . -1098) T) ((-245 . -1098) T) ((-1222 . -287) 38373) ((-113 . -1098) T) ((-1216 . -287) 38352) ((-872 . -1144) 38330) ((-1168 . -1009) 38296) ((-607 . -369) 38236) ((-1167 . -1009) 38202) ((-607 . -223) 38149) ((-595 . -612) 38131) ((-595 . -613) NIL) ((-689 . -848) T) ((-484 . -223) 38081) ((-501 . -1054) T) ((-1160 . -1009) 38047) ((-93 . -445) T) ((-93 . -401) T) ((-210 . -1054) T) ((-1122 . -1009) 38013) ((-34 . -1096) T) ((-927 . -1098) T) ((-1285 . -25) T) ((-1080 . -722) T) ((-708 . -1110) T) ((-598 . -287) 37992) ((-597 . -287) 37971) ((-501 . -240) T) ((-501 . -227) T) ((-1159 . -612) 37953) ((-872 . -43) 37905) ((-210 . -240) T) ((-210 . -227) T) ((-739 . -25) T) ((-739 . -21) T) ((-364 . -722) T) ((-357 . -722) T) ((-345 . -722) T) ((-112 . -795) T) ((-112 . -792) T) ((-532 . -1246) 37889) ((-112 . -722) T) ((-708 . -23) T) ((-1205 . -503) 37871) ((-483 . -281) 37837) ((-1285 . -21) T) ((-1221 . -305) 37776) ((-1170 . -105) T) ((-45 . -149) 37748) ((-45 . -151) 37720) ((-532 . -605) 37697) ((-1111 . -641) 37545) ((-603 . -305) 37483) ((-50 . -644) 37433) ((-50 . -662) 37383) ((-50 . -379) 37333) ((-1152 . -39) T) ((-871 . -846) NIL) ((-648 . -138) T) ((-499 . -612) 37315) ((-234 . -283) 37292) ((-640 . -39) T) ((-627 . -39) T) ((-1086 . -457) 37243) ((-817 . -527) 37108) ((-783 . -457) 37039) ((-781 . -457) 36990) ((-776 . -105) T) ((-459 . -457) 36941) ((-959 . -417) 36925) ((-727 . -612) 36907) ((-246 . -713) 36849) ((-245 . -713) 36791) ((-727 . -613) 36652) ((-496 . -417) 36636) ((-339 . -298) T) ((-235 . -1098) T) ((-355 . -922) T) ((-1007 . -105) 36614) ((-1030 . -848) T) ((-65 . -527) 36547) ((-1254 . -25) T) ((-1254 . -21) T) ((-1221 . -1144) 36499) ((-1011 . -283) NIL) ((-217 . -1061) T) ((-385 . -829) T) ((-1111 . -39) T) ((-780 . -305) 36368) ((-585 . -457) T) ((-530 . -457) T) ((-1225 . -1091) 36352) ((-1225 . -1098) 36330) ((-234 . -605) 36307) ((-1225 . -1093) 36264) ((-1168 . -612) 36246) ((-1167 . -612) 36228) ((-1160 . -612) 36210) ((-1160 . -613) NIL) ((-1122 . -612) 36192) ((-872 . -406) 36176) ((-542 . -1098) T) ((-545 . -105) T) ((-1242 . -43) 36017) ((-1221 . -43) 35831) ((-870 . -151) T) ((-585 . -408) T) ((-53 . -848) T) ((-530 . -408) T) ((-1244 . -21) T) ((-1244 . -25) T) ((-1111 . -792) 35810) ((-1111 . -795) 35761) ((-1111 . -794) 35740) ((-1001 . -1098) T) ((-1034 . -39) T) ((-856 . -1098) T) ((-1255 . -105) T) ((-1111 . -722) 35650) ((-660 . -105) T) ((-555 . -285) 35629) ((-1178 . -105) T) ((-485 . -39) T) ((-472 . -39) T) ((-359 . -105) T) ((-356 . -105) T) ((-344 . -105) T) ((-259 . -105) T) ((-244 . -105) T) ((-493 . -303) T) ((-1065 . -1061) T) ((-959 . -1061) T) ((-312 . -634) 35535) ((-309 . -634) 35496) ((-496 . -1061) T) ((-494 . -105) T) ((-442 . -612) 35478) ((-1166 . -1098) T) ((-1121 . -1098) T) ((-852 . -1098) T) ((-1134 . -105) T) ((-817 . -287) 35409) ((-971 . -1060) 35292) ((-493 . -1028) T) ((-731 . -1060) 35262) ((-1140 . -1117) 35246) ((-1100 . -527) 35179) ((-974 . -105) T) ((-458 . -1060) 35149) ((-971 . -120) 35011) ((-866 . -1266) 34986) ((-861 . -1266) 34946) ((-911 . -105) T) ((-863 . -1144) T) ((-731 . -120) 34911) ((-235 . -713) 34857) ((-64 . -105) 34807) ((-532 . -613) 34768) ((-532 . -612) 34707) ((-531 . -105) 34685) ((-529 . -105) 34635) ((-510 . -105) 34613) ((-509 . -105) 34563) ((-458 . -120) 34514) ((-246 . -174) 34493) ((-245 . -174) 34472) ((-424 . -1060) 34446) ((-1199 . -981) 34407) ((-1006 . -1110) T) ((-863 . -43) 34372) ((-780 . -43) 34310) ((-950 . -527) 34243) ((-501 . -796) T) ((-483 . -43) 34084) ((-424 . -120) 34051) ((-501 . -793) T) ((-1007 . -305) 33989) ((-210 . -796) T) ((-210 . -793) T) ((-1006 . -23) T) ((-708 . -138) T) ((-1221 . -406) 33959) ((-1209 . -39) T) ((-312 . -25) 33811) ((-171 . -417) 33795) ((-312 . -21) 33666) ((-309 . -25) T) ((-309 . -21) T) ((-858 . -374) T) ((-114 . -39) T) ((-497 . -641) 33514) ((-871 . -1061) T) ((-595 . -285) 33489) ((-584 . -151) T) ((-572 . -151) T) ((-508 . -151) T) ((-1166 . -713) 33318) ((-1121 . -713) 33167) ((-1116 . -634) 33149) ((-852 . -713) 33119) ((-666 . -1204) T) ((-1 . -105) T) ((-234 . -612) 32877) ((-1231 . -417) 32861) ((-1205 . -683) 32827) ((-1178 . -305) 32631) ((-971 . -1054) T) ((-731 . -1054) T) ((-711 . -1054) T) ((-638 . -1098) 32581) ((-1058 . -641) 32565) ((-853 . -417) 32549) ((-524 . -105) T) ((-520 . -105) T) ((-244 . -305) 32536) ((-259 . -305) 32523) ((-1085 . -612) 32505) ((-971 . -326) 32484) ((-391 . -641) 32468) ((-494 . -305) 32272) ((-246 . -527) 32205) ((-666 . -1044) 32101) ((-245 . -527) 32034) ((-1134 . -305) 31960) ((-235 . -174) 31939) ((-820 . -1098) T) ((-800 . -1060) 31923) ((-1250 . -283) 31908) ((-1243 . -283) 31893) ((-1222 . -283) 31741) ((-1216 . -283) 31726) ((-392 . -1098) T) ((-323 . -1098) T) ((-424 . -1054) T) ((-171 . -1061) T) ((-64 . -305) 31664) ((-800 . -120) 31643) ((-597 . -283) 31628) ((-531 . -305) 31566) ((-529 . -305) 31504) ((-510 . -305) 31442) ((-509 . -305) 31380) ((-424 . -227) 31359) ((-497 . -39) T) ((-1011 . -613) 31289) ((-217 . -1098) T) ((-1011 . -612) 31271) ((-979 . -612) 31253) ((-979 . -613) 31228) ((-916 . -612) 31210) ((-694 . -151) T) ((-696 . -922) T) ((-696 . -821) T) ((-433 . -612) 31192) ((-1116 . -21) T) ((-1116 . -25) T) ((-666 . -383) 31176) ((-125 . -922) T) ((-872 . -225) 31160) ((-83 . -1204) T) ((-136 . -135) 31144) ((-1058 . -39) T) ((-1279 . -1044) 31118) ((-1277 . -1044) 31075) ((-1231 . -1061) T) ((-1164 . -149) 31054) ((-1164 . -151) 31033) ((-853 . -1061) T) ((-497 . -792) 31012) ((-359 . -1144) 30991) ((-356 . -1144) 30970) ((-344 . -1144) 30949) ((-497 . -795) 30900) ((-497 . -794) 30879) ((-221 . -39) T) ((-497 . -722) 30789) ((-65 . -503) 30773) ((-579 . -1061) T) ((-1205 . -612) 30755) ((-1166 . -174) 30646) ((-1121 . -174) 30557) ((-1065 . -1098) T) ((-1086 . -956) 30502) ((-959 . -1098) T) ((-818 . -641) 30453) ((-783 . -956) 30422) ((-709 . -1098) T) ((-781 . -956) 30389) ((-529 . -279) 30373) ((-666 . -901) 30332) ((-496 . -1098) T) ((-459 . -956) 30299) ((-84 . -1204) T) ((-359 . -43) 30264) ((-356 . -43) 30229) ((-344 . -43) 30194) ((-259 . -43) 30043) ((-244 . -43) 29892) ((-911 . -1144) T) ((-619 . -151) 29871) ((-619 . -149) 29850) ((-126 . -151) T) ((-126 . -149) NIL) ((-420 . -722) T) ((-800 . -1054) T) ((-343 . -457) T) ((-1250 . -1009) 29816) ((-1243 . -1009) 29782) ((-1222 . -1009) 29748) ((-1216 . -1009) 29714) ((-911 . -43) 29679) ((-217 . -713) 29644) ((-739 . -848) T) ((-45 . -415) 29616) ((-316 . -52) 29586) ((-1006 . -138) T) ((-816 . -1204) T) ((-175 . -922) T) ((-343 . -408) T) ((-532 . -285) 29563) ((-50 . -39) T) ((-816 . -1044) 29390) ((-740 . -910) 29369) ((-656 . -105) T) ((-648 . -21) T) ((-648 . -25) T) ((-1100 . -503) 29353) ((-1221 . -225) 29323) ((-670 . -1204) T) ((-242 . -105) 29273) ((-871 . -1098) T) ((-1172 . -641) 29198) ((-1065 . -713) 29185) ((-727 . -1060) 29028) ((-1166 . -527) 28974) ((-959 . -713) 28823) ((-1121 . -527) 28775) ((-740 . -641) 28700) ((-496 . -713) 28549) ((-72 . -612) 28531) ((-727 . -120) 28353) ((-950 . -503) 28337) ((-1269 . -641) 28297) ((-1168 . -1060) 28180) ((-818 . -722) T) ((-1167 . -1060) 28015) ((-1160 . -1060) 27805) ((-235 . -287) 27784) ((-1122 . -1060) 27667) ((-1010 . -1214) T) ((-1092 . -105) 27645) ((-816 . -383) 27614) ((-1010 . -562) T) ((-1168 . -120) 27476) ((-1167 . -120) 27290) ((-1160 . -120) 27036) ((-1122 . -120) 26898) ((-1103 . -1101) 26862) ((-385 . -846) T) ((-1250 . -612) 26844) ((-1243 . -612) 26826) ((-1222 . -612) 26808) ((-1222 . -613) NIL) ((-1216 . -612) 26790) ((-234 . -285) 26767) ((-45 . -457) T) ((-217 . -174) T) ((-171 . -1098) T) ((-689 . -151) T) ((-689 . -149) NIL) ((-598 . -612) 26749) ((-597 . -612) 26731) ((-899 . -1098) T) ((-839 . -1098) T) ((-809 . -1098) T) ((-767 . -1098) T) ((-652 . -850) 26715) ((-672 . -1098) T) ((-816 . -901) 26647) ((-1164 . -1190) 26625) ((-1164 . -1193) 26603) ((-45 . -408) NIL) ((-1116 . -655) T) ((-871 . -713) 26548) ((-246 . -503) 26532) ((-245 . -503) 26516) ((-708 . -634) 26464) ((-647 . -641) 26438) ((-291 . -39) T) ((-1164 . -98) 26416) ((-1164 . -40) 26394) ((-727 . -1054) T) ((-585 . -1266) 26381) ((-530 . -1266) 26358) ((-1231 . -1098) T) ((-1166 . -287) 26269) ((-1121 . -287) 26200) ((-1065 . -174) T) ((-853 . -1098) T) ((-959 . -174) 26111) ((-783 . -1234) 26095) ((-638 . -527) 26028) ((-82 . -612) 26010) ((-727 . -326) 25975) ((-1172 . -722) T) ((-579 . -1098) T) ((-496 . -174) 25886) ((-740 . -722) T) ((-242 . -305) 25824) ((-1135 . -1110) T) ((-75 . -612) 25806) ((-1269 . -722) T) ((-1168 . -1054) T) ((-1167 . -1054) T) ((-327 . -105) 25756) ((-1160 . -1054) T) ((-1135 . -23) T) ((-1122 . -1054) T) ((-96 . -1117) 25740) ((-859 . -1110) T) ((-1168 . -227) 25699) ((-1167 . -240) 25678) ((-1167 . -227) 25630) ((-1160 . -227) 25517) ((-1160 . -240) 25496) ((-316 . -901) 25402) ((-866 . -105) T) ((-861 . -105) T) ((-859 . -23) T) ((-171 . -713) 25230) ((-1099 . -374) T) ((-413 . -1214) T) ((-1030 . -151) T) ((-1010 . -368) T) ((-950 . -283) 25207) ((-870 . -457) T) ((-863 . -353) T) ((-312 . -848) T) ((-309 . -848) NIL) ((-875 . -105) T) ((-541 . -540) 25061) ((-708 . -25) T) ((-413 . -562) T) ((-708 . -21) T) ((-358 . -151) 25043) ((-358 . -149) T) ((-1140 . -1098) 25021) ((-458 . -716) T) ((-80 . -612) 25003) ((-123 . -848) T) ((-242 . -279) 24987) ((-234 . -1060) 24884) ((-86 . -612) 24866) ((-731 . -374) 24819) ((-1170 . -829) T) ((-733 . -229) 24803) ((-1231 . -713) 24632) ((-1153 . -1204) T) ((-143 . -229) 24614) ((-234 . -120) 24504) ((-1085 . -1060) 24481) ((-53 . -151) T) ((-871 . -174) T) ((-853 . -713) 24451) ((-498 . -1204) T) ((-959 . -527) 24397) ((-647 . -722) T) ((-579 . -713) 24384) ((-1085 . -120) 24349) ((-1041 . -1061) T) ((-496 . -527) 24287) ((-950 . -19) 24271) ((-950 . -605) 24248) ((-817 . -613) NIL) ((-817 . -612) 24230) ((-1011 . -1060) 24180) ((-419 . -612) 24162) ((-246 . -283) 24139) ((-245 . -283) 24116) ((-501 . -910) NIL) ((-312 . -29) 24086) ((-112 . -1204) T) ((-1010 . -1110) T) ((-210 . -910) NIL) ((-916 . -1060) 24038) ((-1208 . -848) T) ((-1080 . -1044) 23934) ((-1011 . -120) 23861) ((-733 . -690) 23845) ((-259 . -225) 23829) ((-433 . -1060) 23813) ((-385 . -1061) T) ((-1010 . -23) T) ((-916 . -120) 23744) ((-689 . -1193) NIL) ((-501 . -641) 23694) ((-112 . -885) 23676) ((-112 . -887) 23658) ((-689 . -1190) NIL) ((-210 . -641) 23608) ((-364 . -1044) 23592) ((-357 . -1044) 23576) ((-327 . -305) 23514) ((-345 . -1044) 23498) ((-217 . -287) T) ((-433 . -120) 23477) ((-65 . -612) 23444) ((-171 . -174) T) ((-1116 . -848) T) ((-112 . -1044) 23404) ((-893 . -1098) T) ((-835 . -1061) T) ((-828 . -1061) T) ((-689 . -40) NIL) ((-689 . -98) NIL) ((-309 . -1000) 23365) ((-584 . -457) T) ((-572 . -457) T) ((-508 . -457) T) ((-413 . -368) T) ((-234 . -1054) 23295) ((-1143 . -39) T) ((-929 . -105) T) ((-493 . -922) T) ((-1006 . -634) 23243) ((-246 . -605) 23220) ((-245 . -605) 23197) ((-1080 . -383) 23181) ((-871 . -527) 23044) ((-234 . -227) 22996) ((-1152 . -1204) T) ((-825 . -612) 22978) ((-975 . -978) 22962) ((-1280 . -1110) T) ((-1272 . -612) 22944) ((-1231 . -174) 22835) ((-112 . -383) 22817) ((-112 . -338) 22799) ((-1065 . -287) T) ((-959 . -287) 22730) ((-800 . -374) 22709) ((-929 . -926) 22688) ((-640 . -1204) T) ((-627 . -1204) T) ((-496 . -287) 22619) ((-579 . -174) T) ((-327 . -279) 22603) ((-1280 . -23) T) ((-1199 . -105) T) ((-1186 . -1098) T) ((-1087 . -1098) T) ((-1076 . -1098) T) ((-88 . -612) 22585) ((-707 . -105) T) ((-359 . -353) 22564) ((-607 . -1098) T) ((-356 . -353) 22543) ((-344 . -353) 22522) ((-1178 . -223) 22472) ((-484 . -1098) T) ((-235 . -283) 22449) ((-259 . -248) 22411) ((-1135 . -138) T) ((-607 . -609) 22387) ((-1080 . -901) 22320) ((-1011 . -1054) T) ((-916 . -1054) T) ((-484 . -609) 22299) ((-1160 . -793) NIL) ((-1160 . -796) NIL) ((-1100 . -613) 22260) ((-494 . -223) 22210) ((-1100 . -612) 22192) ((-1011 . -240) T) ((-1011 . -227) T) ((-433 . -1054) T) ((-965 . -1098) 22142) ((-916 . -240) T) ((-859 . -138) T) ((-694 . -457) T) ((-841 . -1110) 22121) ((-112 . -901) NIL) ((-1199 . -281) 22087) ((-872 . -846) 22066) ((-1111 . -1204) T) ((-906 . -722) T) ((-171 . -527) 21978) ((-1006 . -25) T) ((-906 . -482) T) ((-413 . -1110) T) ((-501 . -795) T) ((-501 . -792) T) ((-911 . -353) T) ((-501 . -722) T) ((-210 . -795) T) ((-210 . -792) T) ((-1006 . -21) T) ((-210 . -722) T) ((-841 . -23) 21930) ((-316 . -303) 21909) ((-1042 . -229) 21855) ((-413 . -23) T) ((-950 . -613) 21816) ((-950 . -612) 21755) ((-638 . -503) 21739) ((-50 . -1017) 21689) ((-866 . -43) 21654) ((-861 . -43) 21619) ((-1164 . -457) 21550) ((-331 . -612) 21532) ((-1111 . -1044) 21359) ((-595 . -644) 21341) ((-595 . -379) 21323) ((-343 . -1266) 21300) ((-1034 . -1204) T) ((-871 . -287) T) ((-1231 . -527) 21246) ((-485 . -1204) T) ((-472 . -1204) T) ((-589 . -105) T) ((-1166 . -283) 21173) ((-619 . -457) 21152) ((-1007 . -1002) 21136) ((-1272 . -388) 21108) ((-126 . -457) T) ((-1185 . -105) T) ((-1090 . -1098) 21086) ((-1041 . -1098) T) ((-894 . -848) T) ((-1250 . -1060) 20969) ((-355 . -1214) T) ((-1243 . -1060) 20804) ((-1111 . -383) 20773) ((-1222 . -1060) 20563) ((-1216 . -1060) 20446) ((-1250 . -120) 20308) ((-1243 . -120) 20122) ((-1222 . -120) 19868) ((-1216 . -120) 19730) ((-1199 . -305) 19717) ((-355 . -562) T) ((-370 . -612) 19699) ((-286 . -303) T) ((-598 . -1060) 19672) ((-597 . -1060) 19555) ((-366 . -1098) T) ((-321 . -1098) T) ((-246 . -612) 19516) ((-245 . -612) 19477) ((-1010 . -138) T) ((-113 . -612) 19459) ((-630 . -23) T) ((-689 . -415) 19426) ((-606 . -23) T) ((-652 . -105) T) ((-598 . -120) 19397) ((-597 . -120) 19259) ((-385 . -1098) T) ((-336 . -105) T) ((-171 . -287) 19170) ((-238 . -105) T) ((-1221 . -846) 19123) ((-927 . -612) 19105) ((-710 . -1061) T) ((-1140 . -527) 19038) ((-1111 . -901) 18970) ((-835 . -1098) T) ((-828 . -1098) T) ((-826 . -1098) T) ((-99 . -105) T) ((-148 . -848) T) ((-739 . -151) 18949) ((-739 . -149) 18928) ((-611 . -885) 18912) ((-1209 . -1204) T) ((-1210 . -155) 18894) ((-114 . -1204) T) ((-1086 . -105) T) ((-1066 . -39) T) ((-783 . -105) T) ((-781 . -105) T) ((-467 . -105) T) ((-459 . -105) T) ((-234 . -796) 18845) ((-234 . -793) 18796) ((-780 . -1142) 18748) ((-642 . -105) T) ((-1231 . -287) 18659) ((-660 . -629) 18643) ((-638 . -283) 18620) ((-1041 . -713) 18604) ((-579 . -287) T) ((-971 . -641) 18529) ((-1280 . -138) T) ((-731 . -641) 18489) ((-711 . -641) 18476) ((-273 . -105) T) ((-458 . -641) 18406) ((-55 . -105) T) ((-585 . -105) T) ((-541 . -105) T) ((-530 . -105) T) ((-1250 . -1054) T) ((-1243 . -1054) T) ((-1222 . -1054) T) ((-1216 . -1054) T) ((-1250 . -227) 18365) ((-1243 . -240) 18344) ((-321 . -713) 18326) ((-1243 . -227) 18278) ((-1222 . -227) 18165) ((-1222 . -240) 18144) ((-1216 . -227) 18103) ((-1199 . -43) 18000) ((-1011 . -796) T) ((-598 . -1054) T) ((-597 . -1054) T) ((-1011 . -793) T) ((-979 . -796) T) ((-979 . -793) T) ((-235 . -612) 17982) ((-872 . -1061) T) ((-870 . -869) 17966) ((-689 . -457) T) ((-385 . -713) 17931) ((-424 . -641) 17905) ((-708 . -848) 17884) ((-707 . -43) 17849) ((-597 . -227) 17808) ((-45 . -720) 17780) ((-355 . -329) 17757) ((-355 . -368) T) ((-1254 . -149) 17736) ((-1254 . -151) 17715) ((-1080 . -303) 17666) ((-290 . -1110) 17547) ((-1104 . -1204) T) ((-173 . -105) T) ((-1225 . -612) 17514) ((-841 . -138) 17466) ((-638 . -1246) 17450) ((-835 . -713) 17420) ((-828 . -713) 17390) ((-497 . -1204) T) ((-364 . -303) T) ((-357 . -303) T) ((-345 . -303) T) ((-638 . -605) 17367) ((-413 . -138) T) ((-532 . -662) 17351) ((-112 . -303) T) ((-290 . -23) 17234) ((-532 . -644) 17218) ((-689 . -408) NIL) ((-532 . -379) 17202) ((-542 . -612) 17184) ((-96 . -1098) 17162) ((-112 . -1028) T) ((-572 . -147) T) ((-1259 . -155) 17146) ((-497 . -1044) 16973) ((-1244 . -149) 16934) ((-1244 . -151) 16895) ((-1058 . -1204) T) ((-1001 . -612) 16877) ((-856 . -612) 16859) ((-817 . -1060) 16702) ((-1086 . -305) 16689) ((-221 . -1204) T) ((-783 . -305) 16676) ((-781 . -305) 16663) ((-817 . -120) 16485) ((-459 . -305) 16472) ((-1166 . -613) NIL) ((-1166 . -612) 16454) ((-1121 . -612) 16436) ((-1121 . -613) 16184) ((-1041 . -174) T) ((-852 . -612) 16166) ((-950 . -285) 16143) ((-607 . -527) 15891) ((-819 . -1044) 15875) ((-484 . -527) 15635) ((-971 . -722) T) ((-731 . -722) T) ((-711 . -722) T) ((-355 . -1110) T) ((-1173 . -612) 15617) ((-215 . -105) T) ((-497 . -383) 15586) ((-528 . -1098) T) ((-523 . -1098) T) ((-521 . -1098) T) ((-800 . -641) 15560) ((-1030 . -457) T) ((-965 . -527) 15493) ((-355 . -23) T) ((-1206 . -848) T) ((-630 . -138) T) ((-606 . -138) T) ((-358 . -457) T) ((-234 . -374) 15472) ((-385 . -174) T) ((-1242 . -1061) T) ((-1221 . -1061) T) ((-217 . -1009) T) ((-973 . -1096) T) ((-694 . -393) T) ((-424 . -722) T) ((-696 . -1214) T) ((-1135 . -634) 15420) ((-1272 . -1060) 15404) ((-584 . -869) 15388) ((-1153 . -1181) 15364) ((-710 . -1098) T) ((-696 . -562) T) ((-136 . -1098) 15342) ((-497 . -901) 15274) ((-220 . -1257) 15256) ((-220 . -1098) T) ((-146 . -1257) 15231) ((-163 . -1098) T) ((-652 . -43) 15201) ((-358 . -408) T) ((-312 . -151) 15180) ((-312 . -149) 15159) ((-125 . -562) T) ((-309 . -151) 15115) ((-309 . -149) 15071) ((-53 . -457) T) ((-159 . -1098) T) ((-146 . -1098) T) ((-1153 . -111) 15018) ((-1164 . -956) 14987) ((-783 . -1144) 14965) ((-685 . -39) T) ((-1272 . -120) 14944) ((-555 . -39) T) ((-498 . -111) 14928) ((-246 . -285) 14905) ((-245 . -285) 14882) ((-871 . -283) 14812) ((-50 . -1204) T) ((-817 . -1054) T) ((-1172 . -52) 14789) ((-817 . -326) 14751) ((-1086 . -43) 14600) ((-817 . -227) 14579) ((-783 . -43) 14408) ((-781 . -43) 14257) ((-740 . -52) 14234) ((-459 . -43) 14083) ((-638 . -613) 14044) ((-638 . -612) 13983) ((-585 . -1144) T) ((-530 . -1144) T) ((-1140 . -503) 13967) ((-1191 . -1098) 13945) ((-1135 . -25) T) ((-1135 . -21) T) ((-863 . -1061) T) ((-780 . -1061) T) ((-1254 . -1193) 13911) ((-1254 . -1190) 13877) ((-483 . -1061) T) ((-1222 . -793) NIL) ((-1222 . -796) NIL) ((-1006 . -848) 13856) ((-820 . -612) 13838) ((-859 . -21) T) ((-859 . -25) T) ((-800 . -722) T) ((-517 . -1096) T) ((-175 . -1214) T) ((-585 . -43) 13803) ((-530 . -43) 13768) ((-392 . -612) 13750) ((-323 . -612) 13732) ((-171 . -283) 13690) ((-1254 . -40) 13656) ((-1254 . -98) 13622) ((-68 . -1204) T) ((-121 . -105) T) ((-872 . -1098) T) ((-175 . -562) T) ((-710 . -713) 13592) ((-290 . -138) 13475) ((-217 . -612) 13457) ((-217 . -613) 13387) ((-1207 . -39) T) ((-1010 . -634) 13321) ((-1272 . -1054) T) ((-1116 . -151) T) ((-627 . -1181) 13296) ((-727 . -910) 13275) ((-595 . -39) T) ((-640 . -111) 13259) ((-627 . -111) 13205) ((-740 . -887) NIL) ((-1231 . -283) 13132) ((-727 . -641) 13057) ((-291 . -1204) T) ((-1172 . -1044) 12953) ((-740 . -1044) 12833) ((-1160 . -910) NIL) ((-1065 . -613) 12748) ((-1065 . -612) 12730) ((-343 . -105) T) ((-246 . -1060) 12627) ((-245 . -1060) 12524) ((-400 . -105) T) ((-959 . -612) 12506) ((-959 . -613) 12367) ((-709 . -612) 12349) ((-1270 . -1198) 12318) ((-496 . -612) 12300) ((-496 . -613) 12161) ((-259 . -417) 12145) ((-244 . -417) 12129) ((-246 . -120) 12019) ((-245 . -120) 11909) ((-1168 . -641) 11834) ((-1167 . -641) 11731) ((-1160 . -641) 11583) ((-1122 . -641) 11508) ((-355 . -138) T) ((-87 . -446) T) ((-87 . -401) T) ((-1010 . -25) T) ((-1010 . -21) T) ((-872 . -713) 11460) ((-385 . -287) T) ((-171 . -1009) 11411) ((-740 . -383) 11395) ((-689 . -393) T) ((-1006 . -1004) 11379) ((-696 . -1110) T) ((-689 . -168) 11361) ((-1242 . -1098) T) ((-1221 . -1098) T) ((-312 . -1190) 11340) ((-312 . -1193) 11319) ((-1158 . -105) T) ((-312 . -966) 11298) ((-140 . -1110) T) ((-125 . -1110) T) ((-603 . -1257) 11282) ((-696 . -23) T) ((-603 . -1098) 11232) ((-96 . -527) 11165) ((-175 . -368) T) ((-1164 . -1234) 11149) ((-312 . -98) 11128) ((-312 . -40) 11107) ((-607 . -503) 11041) ((-140 . -23) T) ((-125 . -23) T) ((-714 . -1098) T) ((-484 . -503) 10978) ((-413 . -634) 10926) ((-647 . -1044) 10822) ((-740 . -901) 10765) ((-965 . -503) 10749) ((-359 . -1061) T) ((-356 . -1061) T) ((-344 . -1061) T) ((-259 . -1061) T) ((-244 . -1061) T) ((-871 . -613) NIL) ((-871 . -612) 10731) ((-1280 . -21) T) ((-579 . -1009) T) ((-727 . -722) T) ((-1280 . -25) T) ((-246 . -1054) 10661) ((-245 . -1054) 10591) ((-235 . -1060) 10537) ((-77 . -1204) T) ((-928 . -105) T) ((-246 . -227) 10489) ((-245 . -227) 10441) ((-235 . -120) 10380) ((-45 . -105) T) ((-911 . -1061) T) ((-1168 . -722) T) ((-1167 . -722) T) ((-1160 . -722) T) ((-1160 . -792) NIL) ((-1160 . -795) NIL) ((-1122 . -722) T) ((-928 . -926) 10338) ((-863 . -1098) T) ((-923 . -105) T) ((-780 . -1098) T) ((-769 . -105) T) ((-667 . -105) T) ((-483 . -1098) T) ((-339 . -1110) T) ((-1242 . -713) 10179) ((-175 . -1110) T) ((-316 . -922) 10158) ((-739 . -457) 10137) ((-872 . -174) T) ((-1221 . -713) 9951) ((-841 . -21) 9903) ((-841 . -25) 9855) ((-242 . -1142) 9839) ((-136 . -527) 9772) ((-413 . -25) T) ((-413 . -21) T) ((-339 . -23) T) ((-171 . -612) 9754) ((-171 . -613) 9520) ((-175 . -23) T) ((-638 . -285) 9497) ((-220 . -527) NIL) ((-146 . -527) NIL) ((-532 . -39) T) ((-899 . -612) 9479) ((-94 . -1204) T) ((-839 . -612) 9461) ((-809 . -612) 9443) ((-767 . -612) 9425) ((-672 . -612) 9407) ((-234 . -641) 9255) ((-1170 . -1098) T) ((-1166 . -1060) 9078) ((-1143 . -1204) T) ((-1121 . -1060) 8921) ((-852 . -1060) 8905) ((-1085 . -641) 8882) ((-1166 . -120) 8684) ((-1121 . -120) 8506) ((-852 . -120) 8485) ((-1231 . -613) NIL) ((-1231 . -612) 8467) ((-343 . -1144) T) ((-853 . -612) 8449) ((-1076 . -283) 8428) ((-235 . -1054) T) ((-85 . -1204) T) ((-1011 . -910) NIL) ((-607 . -283) 8404) ((-1191 . -527) 8337) ((-501 . -1204) T) ((-579 . -612) 8319) ((-484 . -283) 8298) ((-1086 . -225) 8282) ((-1011 . -641) 8232) ((-210 . -1204) T) ((-965 . -283) 8209) ((-916 . -641) 8161) ((-286 . -922) T) ((-818 . -303) 8140) ((-870 . -105) T) ((-783 . -225) 8124) ((-776 . -1098) T) ((-863 . -713) 8076) ((-780 . -713) 8014) ((-630 . -21) T) ((-630 . -25) T) ((-606 . -21) T) ((-343 . -43) 7979) ((-689 . -720) 7946) ((-501 . -885) 7928) ((-501 . -887) 7910) ((-483 . -713) 7751) ((-210 . -885) 7733) ((-69 . -1204) T) ((-210 . -887) 7715) ((-606 . -25) T) ((-433 . -641) 7689) ((-501 . -1044) 7649) ((-872 . -527) 7561) ((-210 . -1044) 7521) ((-234 . -39) T) ((-1007 . -1098) 7499) ((-1242 . -174) 7430) ((-1221 . -174) 7361) ((-708 . -149) 7340) ((-708 . -151) 7319) ((-696 . -138) T) ((-142 . -474) 7296) ((-468 . -105) T) ((-652 . -650) 7280) ((-1140 . -612) 7247) ((-125 . -138) T) ((-493 . -1214) T) ((-607 . -605) 7223) ((-484 . -605) 7202) ((-336 . -335) 7171) ((-545 . -1098) T) ((-1166 . -1054) T) ((-493 . -562) T) ((-238 . -237) 7155) ((-1121 . -1054) T) ((-852 . -1054) T) ((-234 . -792) 7134) ((-234 . -795) 7085) ((-234 . -794) 7064) ((-1166 . -326) 7041) ((-234 . -722) 6951) ((-965 . -19) 6935) ((-501 . -383) 6917) ((-501 . -338) 6899) ((-1121 . -326) 6871) ((-358 . -1266) 6848) ((-210 . -383) 6830) ((-210 . -338) 6812) ((-965 . -605) 6789) ((-1166 . -227) T) ((-660 . -1098) T) ((-1255 . -1098) T) ((-1178 . -1098) T) ((-1086 . -248) 6726) ((-359 . -1098) T) ((-356 . -1098) T) ((-344 . -1098) T) ((-259 . -1098) T) ((-244 . -1098) T) ((-89 . -1204) T) ((-137 . -105) 6704) ((-131 . -105) 6682) ((-740 . -303) 6661) ((-1178 . -609) 6640) ((-494 . -1098) T) ((-1210 . -105) T) ((-1134 . -1098) T) ((-494 . -609) 6619) ((-246 . -796) 6570) ((-246 . -793) 6521) ((-245 . -796) 6472) ((-45 . -1144) NIL) ((-245 . -793) 6423) ((-1080 . -922) 6374) ((-1011 . -795) T) ((-1011 . -792) T) ((-1011 . -722) T) ((-979 . -795) T) ((-974 . -1098) T) ((-916 . -722) T) ((-911 . -1098) T) ((-872 . -287) T) ((-96 . -503) 6358) ((-501 . -901) NIL) ((-863 . -174) T) ((-217 . -1060) 6323) ((-834 . -1110) 6302) ((-210 . -901) NIL) ((-780 . -174) T) ((-64 . -1098) 6252) ((-531 . -1098) 6230) ((-529 . -1098) 6180) ((-510 . -1098) 6158) ((-509 . -1098) 6108) ((-584 . -105) T) ((-572 . -105) T) ((-508 . -105) T) ((-483 . -174) 6039) ((-364 . -922) T) ((-357 . -922) T) ((-345 . -922) T) ((-217 . -120) 5988) ((-834 . -23) 5940) ((-433 . -722) T) ((-112 . -922) T) ((-45 . -43) 5885) ((-112 . -821) T) ((-585 . -353) T) ((-530 . -353) T) ((-1221 . -527) 5745) ((-312 . -457) 5724) ((-309 . -457) T) ((-1205 . -39) T) ((-835 . -283) 5703) ((-339 . -138) T) ((-175 . -138) T) ((-290 . -25) 5567) ((-290 . -21) 5450) ((-50 . -1181) 5429) ((-71 . -612) 5411) ((-893 . -612) 5393) ((-603 . -527) 5326) ((-50 . -111) 5276) ((-1100 . -431) 5260) ((-1100 . -374) 5239) ((-1066 . -1204) T) ((-1065 . -1060) 5226) ((-959 . -1060) 5069) ((-496 . -1060) 4912) ((-660 . -713) 4896) ((-1065 . -120) 4881) ((-959 . -120) 4703) ((-493 . -368) T) ((-359 . -713) 4655) ((-356 . -713) 4607) ((-344 . -713) 4559) ((-259 . -713) 4408) ((-244 . -713) 4257) ((-1260 . -105) T) ((-1259 . -105) 4207) ((-950 . -644) 4191) ((-1250 . -641) 4116) ((-496 . -120) 3938) ((-1243 . -641) 3835) ((-1222 . -641) 3687) ((-1222 . -910) NIL) ((-950 . -379) 3671) ((-1216 . -641) 3596) ((-79 . -612) 3578) ((-971 . -52) 3557) ((-617 . -1110) T) ((-1 . -1098) T) ((-706 . -105) T) ((-694 . -105) T) ((-1186 . -612) 3539) ((-1087 . -612) 3521) ((-1076 . -612) 3503) ((-911 . -713) 3468) ((-136 . -503) 3452) ((-780 . -527) 3284) ((-617 . -23) T) ((-396 . -23) T) ((-607 . -612) 3266) ((-92 . -1204) T) ((-607 . -613) NIL) ((-484 . -613) NIL) ((-484 . -612) 3248) ((-355 . -25) T) ((-355 . -21) T) ((-220 . -503) 3230) ((-137 . -305) 3168) ((-524 . -1098) T) ((-520 . -1098) T) ((-146 . -503) 3143) ((-131 . -305) 3081) ((-598 . -641) 3068) ((-218 . -62) 3036) ((-145 . -62) 2997) ((-217 . -1054) T) ((-597 . -641) 2922) ((-1210 . -305) NIL) ((-385 . -1009) T) ((-217 . -240) T) ((-217 . -227) T) ((-1164 . -105) T) ((-965 . -613) 2883) ((-965 . -612) 2822) ((-870 . -43) 2809) ((-1242 . -287) 2760) ((-1221 . -287) 2711) ((-1116 . -457) T) ((-515 . -848) T) ((-312 . -1132) 2690) ((-1006 . -151) 2669) ((-1006 . -149) 2648) ((-739 . -162) T) ((-739 . -147) T) ((-508 . -305) 2635) ((-291 . -1181) 2614) ((-493 . -1110) T) ((-871 . -1060) 2559) ((-619 . -105) T) ((-1191 . -503) 2543) ((-246 . -374) 2522) ((-245 . -374) 2501) ((-1164 . -281) 2479) ((-1065 . -1054) T) ((-291 . -111) 2429) ((-130 . -105) T) ((-126 . -105) T) ((-35 . -1096) T) ((-959 . -1054) T) ((-871 . -120) 2346) ((-493 . -23) T) ((-496 . -1054) T) ((-1065 . -227) T) ((-959 . -326) 2315) ((-496 . -326) 2272) ((-359 . -174) T) ((-356 . -174) T) ((-344 . -174) T) ((-259 . -174) 2183) ((-244 . -174) 2094) ((-971 . -1044) 1990) ((-731 . -1044) 1961) ((-1103 . -105) T) ((-1090 . -612) 1928) ((-1041 . -612) 1910) ((-1254 . -981) 1879) ((-1250 . -722) T) ((-1243 . -722) T) ((-1222 . -722) T) ((-1222 . -792) NIL) ((-1222 . -795) NIL) ((-863 . -287) T) ((-171 . -1060) 1789) ((-911 . -174) T) ((-780 . -287) T) ((-1216 . -722) T) ((-1270 . -155) 1773) ((-1010 . -342) 1747) ((-1007 . -527) 1680) ((-841 . -848) 1659) ((-572 . -1144) T) ((-483 . -287) 1610) ((-598 . -722) T) ((-366 . -612) 1592) ((-321 . -612) 1574) ((-424 . -1044) 1470) ((-597 . -722) T) ((-413 . -848) 1421) ((-171 . -120) 1310) ((-866 . -1061) T) ((-861 . -1061) T) ((-834 . -138) 1262) ((-733 . -155) 1246) ((-1259 . -305) 1184) ((-501 . -303) T) ((-385 . -612) 1151) ((-532 . -1017) 1135) ((-385 . -613) 1049) ((-210 . -303) T) ((-143 . -155) 1031) ((-710 . -283) 1010) ((-1164 . -305) 997) ((-501 . -1028) T) ((-584 . -43) 984) ((-572 . -43) 971) ((-508 . -43) 936) ((-220 . -283) 911) ((-146 . -283) 879) ((-210 . -1028) T) ((-871 . -1054) T) ((-835 . -612) 861) ((-828 . -612) 843) ((-826 . -612) 825) ((-817 . -910) 804) ((-1281 . -1110) T) ((-1231 . -1060) 627) ((-853 . -1060) 611) ((-871 . -240) T) ((-871 . -227) NIL) ((-685 . -1204) T) ((-1281 . -23) T) ((-817 . -641) 536) ((-555 . -1204) T) ((-424 . -338) 520) ((-579 . -1060) 507) ((-1231 . -120) 309) ((-696 . -634) 291) ((-853 . -120) 270) ((-387 . -23) T) ((-1178 . -527) 30)) 
\ No newline at end of file
+((($ $) . T) (((-879 |#1|) $) . T) (((-879 |#1|) |#2|) . T)) 
+((($ $) . T) ((|#2| $) |has| |#1| (-247)) ((|#2| |#1|) |has| |#1| (-247)) ((|#3| |#1|) . T) ((|#3| $) . T)) 
+(((-676 . -1119) T) ((-279 . -547) 158177) ((-264 . -547) 158115) ((-599 . -140) 158100) ((-558 . -23) T) ((-262 . -1119) 158050) ((-146 . -325) 157994) ((-514 . -547) 157754) ((-710 . -125) T) ((-1155 . -547) 157662) ((-416 . -158) T) ((-1291 . -1005) 157631) ((-240 . -19) 157613) ((-166 . -19) 157588) ((-623 . -523) 157572) ((-841 . -865) T) ((-637 . -158) T) ((-555 . -62) 157522) ((-240 . -625) 157497) ((-166 . -625) 157465) ((-64 . -547) 157398) ((-551 . -547) 157331) ((-444 . -922) 157290) ((-191 . -1075) T) ((-549 . -547) 157223) ((-530 . -547) 157156) ((-529 . -547) 157089) ((-821 . -1065) 156869) ((-715 . -43) 156834) ((-363 . -373) T) ((-1185 . -1165) 156812) ((-1113 . -1112) 156796) ((-1113 . -1119) 156774) ((-191 . -260) 156725) ((-191 . -247) 156676) ((-1113 . -1114) 156634) ((-893 . -303) 156592) ((-237 . -817) T) ((-237 . -814) T) ((-710 . -301) NIL) ((-1164 . -1202) 156571) ((-433 . -1021) 156555) ((-996 . -125) T) ((-717 . -21) T) ((-717 . -25) T) ((-1293 . -661) 156529) ((-1229 . -175) 156511) ((-1228 . -1225) T) ((-1185 . -43) 156340) ((-332 . -182) 156319) ((-332 . -167) 156298) ((-1164 . -131) 156248) ((-160 . -25) T) ((-45 . -245) 156225) ((-145 . -21) T) ((-145 . -25) T) ((-627 . -305) 156201) ((-504 . -305) 156180) ((-1252 . -1075) T) ((-874 . -1075) T) ((-821 . -358) 156164) ((-146 . -1165) NIL) ((-96 . -632) 156131) ((-513 . -158) T) ((-1252 . -346) 156108) ((-615 . -1225) T) ((-838 . -678) 156059) ((-599 . -1075) T) ((-1252 . -247) T) ((-676 . -734) 156043) ((-986 . -305) 156020) ((-801 . -523) 155972) ((-65 . -39) T) ((-1086 . -817) T) ((-1086 . -814) T) ((-838 . -743) T) ((-748 . -52) 155937) ((-639 . -43) 155924) ((-379 . -307) T) ((-376 . -307) T) ((-364 . -307) T) ((-279 . -307) 155855) ((-264 . -307) 155786) ((-1051 . -125) T) ((-439 . -743) T) ((-146 . -43) 155731) ((-439 . -502) T) ((-378 . -125) T) ((-1220 . -1082) T) ((-728 . -1082) T) ((-1275 . -1270) 155715) ((-1275 . -1257) 155692) ((-1189 . -52) 155669) ((-1188 . -52) 155639) ((-1181 . -52) 155616) ((-1063 . -175) 155562) ((-932 . -307) T) ((-1143 . -52) 155534) ((-710 . -325) NIL) ((-548 . -632) 155516) ((-543 . -632) 155498) ((-541 . -632) 155480) ((-347 . -1119) 155430) ((-136 . -125) T) ((-729 . -477) 155361) ((-53 . -125) T) ((-1263 . -303) 155346) ((-1242 . -303) 155266) ((-658 . -683) 155250) ((-658 . -664) 155234) ((-359 . -21) T) ((-359 . -25) T) ((-45 . -373) NIL) ((-887 . -1119) T) ((-195 . -21) T) ((-195 . -25) T) ((-882 . -1119) T) ((-658 . -399) 155218) ((-623 . -303) 155195) ((-414 . -125) T) ((-1137 . -167) T) ((-156 . -632) 155162) ((-896 . -1119) T) ((-672 . -437) 155146) ((-731 . -632) 155128) ((-1293 . -743) T) ((-240 . -632) 155110) ((-240 . -633) 155092) ((-179 . -632) 155074) ((-166 . -632) 155056) ((-166 . -633) 155008) ((-183 . -632) 154990) ((-1121 . -39) T) ((-136 . -137) T) ((-892 . -817) NIL) ((-892 . -814) NIL) ((-876 . -869) T) ((-748 . -908) NIL) ((-1302 . -158) T) ((-407 . -158) T) ((-926 . -125) T) ((-748 . -1065) 154866) ((-558 . -158) T) ((-1107 . -437) 154850) ((-1028 . -523) 154834) ((-146 . -426) 154811) ((-1181 . -1225) 154790) ((-804 . -437) 154774) ((-802 . -437) 154758) ((-971 . -39) T) ((-710 . -1165) NIL) ((-266 . -661) 154593) ((-265 . -661) 154415) ((-839 . -943) 154394) ((-479 . -437) 154378) ((-623 . -19) 154362) ((-1160 . -1219) 154331) ((-1181 . -908) NIL) ((-1181 . -906) 154283) ((-623 . -625) 154260) ((-1212 . -632) 154227) ((-1190 . -632) 154209) ((-67 . -421) T) ((-1188 . -1065) 154144) ((-1181 . -1065) 154110) ((-801 . -303) 154043) ((-710 . -43) 153993) ((-503 . -303) 153978) ((-748 . -403) 153962) ((-887 . -734) 153927) ((-672 . -1082) T) ((-882 . -734) 153877) ((-1263 . -1030) 153843) ((-1242 . -1030) 153809) ((-1087 . -1202) 153784) ((-893 . -633) 153585) ((-893 . -632) 153567) ((-1199 . -523) 153504) ((-444 . -1049) 153482) ((-53 . -325) 153469) ((-1087 . -131) 153415) ((-514 . -523) 153352) ((-552 . -1225) T) ((-1155 . -523) 153323) ((-1181 . -358) 153275) ((-1181 . -403) 153227) ((-463 . -125) T) ((-1107 . -1082) T) ((-266 . -39) T) ((-265 . -39) T) ((-801 . -1267) 153179) ((-804 . -1082) T) ((-802 . -1082) T) ((-748 . -922) 153156) ((-479 . -1082) T) ((-801 . -625) 153101) ((-64 . -523) 153085) ((-1062 . -1081) 153059) ((-950 . -1119) T) ((-551 . -523) 153043) ((-549 . -523) 153027) ((-530 . -523) 153011) ((-529 . -523) 152995) ((-761 . -943) 152974) ((-262 . -547) 152907) ((-1062 . -140) 152874) ((-1189 . -922) 152787) ((-255 . -661) 152747) ((-687 . -1131) T) ((-1188 . -922) 152653) ((-1181 . -922) 152486) ((-1143 . -922) 152470) ((-378 . -1165) T) ((-341 . -1081) 152452) ((-266 . -813) 152431) ((-266 . -816) 152382) ((-266 . -815) 152361) ((-265 . -813) 152340) ((-265 . -816) 152291) ((-265 . -815) 152270) ((-55 . -1082) T) ((-266 . -743) 152180) ((-265 . -743) 152090) ((-1220 . -1119) T) ((-687 . -23) T) ((-605 . -1082) T) ((-550 . -1082) T) ((-405 . -1081) 152055) ((-341 . -140) 152030) ((-78 . -409) T) ((-78 . -421) T) ((-1051 . -43) 151967) ((-710 . -426) 151949) ((-121 . -125) T) ((-728 . -1119) T) ((-1031 . -169) 151921) ((-405 . -140) 151870) ((-336 . -1235) 151849) ((-503 . -1030) 151815) ((-378 . -43) 151780) ((-45 . -396) 151752) ((-1031 . -171) 151724) ((-157 . -155) 151708) ((-151 . -155) 151692) ((-856 . -1081) 151662) ((-855 . -21) 151614) ((-849 . -1081) 151598) ((-855 . -25) 151550) ((-336 . -582) 151501) ((-592 . -850) T) ((-254 . -1225) T) ((-887 . -194) T) ((-882 . -194) T) ((-856 . -140) 151466) ((-849 . -140) 151445) ((-1263 . -632) 151427) ((-1242 . -632) 151409) ((-1242 . -633) 151080) ((-1187 . -931) 151059) ((-1142 . -931) 151038) ((-53 . -43) 151003) ((-1300 . -1131) T) ((-623 . -632) 150942) ((-623 . -633) 150903) ((-1298 . -1131) T) ((-254 . -1065) 150730) ((-1187 . -661) 150655) ((-1142 . -661) 150580) ((-735 . -632) 150562) ((-873 . -661) 150536) ((-1300 . -23) T) ((-1298 . -23) T) ((-1185 . -245) 150520) ((-1062 . -1075) T) ((-1199 . -303) 150499) ((-191 . -394) 150450) ((-1032 . -1225) T) ((-49 . -23) T) ((-1306 . -125) T) ((-1220 . -734) 150347) ((-514 . -303) 150326) ((-609 . -1119) T) ((-1206 . -1119) T) ((-1160 . -1128) 150295) ((-1123 . -1122) 150247) ((-416 . -21) T) ((-416 . -25) T) ((-176 . -1131) T) ((-1032 . -1065) 150207) ((-1032 . -906) 150189) ((-1032 . -908) 150171) ((-760 . -125) T) ((-255 . -743) T) ((-639 . -245) 150155) ((-637 . -21) T) ((-306 . -582) T) ((-637 . -25) T) ((-728 . -734) 150120) ((-405 . -1075) T) ((-254 . -403) 150089) ((-240 . -305) 150064) ((-166 . -305) 150032) ((-235 . -1082) T) ((-146 . -245) 150009) ((-64 . -303) 149986) ((-176 . -23) T) ((-549 . -303) 149963) ((-347 . -547) 149896) ((-529 . -303) 149873) ((-405 . -260) T) ((-405 . -247) T) ((-884 . -632) 149855) ((-856 . -1075) T) ((-849 . -1075) T) ((-801 . -632) 149837) ((-801 . -633) NIL) ((-729 . -977) 149806) ((-717 . -869) T) ((-503 . -632) 149788) ((-849 . -247) 149767) ((-160 . -869) T) ((-1226 . -1225) T) ((-672 . -1119) T) ((-1199 . -625) 149746) ((-575 . -1202) 149725) ((-356 . -1119) T) ((-336 . -388) 149704) ((-433 . -171) 149683) ((-433 . -169) 149662) ((-1227 . -175) 149644) ((-258 . -1119) T) ((-993 . -1131) 149543) ((-254 . -922) 149475) ((-837 . -1131) 149385) ((-668 . -871) 149369) ((-514 . -625) 149348) ((-575 . -131) 149298) ((-1032 . -403) 149280) ((-1032 . -358) 149262) ((-1191 . -632) 149244) ((-1187 . -678) 149175) ((-118 . -1119) T) ((-993 . -23) 148986) ((-513 . -21) T) ((-513 . -25) T) ((-837 . -23) 148856) ((-1142 . -678) 148807) ((-64 . -19) 148791) ((-1191 . -633) 148713) ((-1187 . -743) T) ((-1142 . -743) T) ((-549 . -19) 148697) ((-529 . -19) 148681) ((-64 . -625) 148658) ((-1107 . -1119) T) ((-923 . -125) 148636) ((-873 . -743) T) ((-804 . -1119) T) ((-549 . -625) 148613) ((-529 . -625) 148590) ((-802 . -1119) T) ((-802 . -1089) 148557) ((-487 . -1119) T) ((-479 . -1119) T) ((-1275 . -125) T) ((-609 . -734) 148532) ((-281 . -125) 148510) ((-662 . -1119) T) ((-1275 . -301) 148476) ((-1271 . -52) 148453) ((-1265 . -125) T) ((-1264 . -52) 148423) ((-1032 . -922) NIL) ((-1243 . -52) 148400) ((-642 . -1131) T) ((-687 . -158) T) ((-1237 . -52) 148377) ((-1220 . -194) 148328) ((-1188 . -323) 148307) ((-1181 . -323) 148286) ((-1101 . -1235) 148237) ((-293 . -1119) T) ((-90 . -466) T) ((-90 . -421) T) ((-1101 . -582) 148188) ((-797 . -632) 148170) ((-55 . -1119) T) ((-728 . -194) T) ((-617 . -52) 148147) ((-237 . -661) 148112) ((-605 . -1119) T) ((-561 . -1119) T) ((-550 . -1119) T) ((-384 . -1235) T) ((-377 . -1235) T) ((-365 . -1235) T) ((-521 . -842) T) ((-521 . -943) T) ((-336 . -1131) T) ((-132 . -1235) T) ((-760 . -325) 148099) ((-359 . -869) T) ((-230 . -943) T) ((-230 . -842) T) ((-731 . -1081) 148069) ((-384 . -582) T) ((-377 . -582) T) ((-365 . -582) T) ((-132 . -582) T) ((-1181 . -1049) NIL) ((-672 . -734) 148039) ((-887 . -307) T) ((-882 . -307) T) ((-336 . -23) T) ((-72 . -1225) T) ((-1028 . -632) 148006) ((-710 . -245) 147988) ((-258 . -734) 147970) ((-731 . -140) 147935) ((-658 . -39) T) ((-262 . -523) 147919) ((-1121 . -1116) 147903) ((-193 . -1119) T) ((-980 . -931) 147882) ((-516 . -931) 147861) ((-1302 . -21) T) ((-1302 . -25) T) ((-1300 . -158) T) ((-1298 . -158) T) ((-1107 . -734) 147710) ((-1086 . -661) 147697) ((-980 . -661) 147622) ((-804 . -734) 147451) ((-565 . -632) 147433) ((-565 . -633) 147414) ((-802 . -734) 147263) ((-1291 . -125) T) ((-1098 . -125) T) ((-407 . -25) T) ((-407 . -21) T) ((-516 . -661) 147188) ((-487 . -734) 147159) ((-479 . -734) 147008) ((-1016 . -125) T) ((-754 . -125) T) ((-1306 . -1165) T) ((-1276 . -632) 146974) ((-558 . -25) T) ((-1243 . -1225) 146953) ((-1264 . -1065) 146888) ((-1243 . -908) NIL) ((-1243 . -906) 146840) ((-163 . -125) T) ((-49 . -158) T) ((-1199 . -633) NIL) ((-1199 . -632) 146822) ((-1156 . -1140) 146767) ((-363 . -1082) T) ((-681 . -632) 146749) ((-306 . -1131) T) ((-379 . -632) 146731) ((-376 . -632) 146713) ((-364 . -632) 146695) ((-279 . -633) 146443) ((-279 . -632) 146425) ((-264 . -632) 146407) ((-264 . -633) 146268) ((-1072 . -1219) 146197) ((-923 . -325) 146135) ((-1243 . -1065) 146101) ((-1220 . -547) 146068) ((-1155 . -632) 146050) ((-995 . -632) 146032) ((-841 . -743) T) ((-605 . -734) 145997) ((-623 . -305) 145974) ((-550 . -734) 145919) ((-514 . -633) NIL) ((-514 . -632) 145901) ((-332 . -125) T) ((-281 . -325) 145839) ((-329 . -125) T) ((-306 . -23) T) ((-176 . -158) T) ((-932 . -632) 145821) ((-932 . -633) 145803) ((-412 . -743) T) ((-893 . -1081) 145755) ((-893 . -140) 145686) ((-237 . -678) T) ((-760 . -43) 145610) ((-162 . -125) T) ((-143 . -125) T) ((-729 . -1255) 145594) ((-731 . -1075) T) ((-710 . -373) NIL) ((-551 . -632) 145561) ((-405 . -817) T) ((-235 . -1119) T) ((-405 . -814) T) ((-237 . -816) T) ((-237 . -813) T) ((-64 . -633) 145522) ((-64 . -632) 145461) ((-237 . -743) T) ((-549 . -633) 145422) ((-549 . -632) 145361) ((-530 . -632) 145328) ((-529 . -633) 145289) ((-529 . -632) 145228) ((-1101 . -388) 145179) ((-45 . -437) 145156) ((-82 . -1225) T) ((-138 . -125) T) ((-994 . -999) 145140) ((-892 . -931) NIL) ((-384 . -349) 145124) ((-384 . -388) T) ((-377 . -349) 145108) ((-377 . -388) T) ((-365 . -349) 145092) ((-365 . -388) T) ((-332 . -301) 145071) ((-132 . -388) T) ((-75 . -1225) T) ((-1243 . -358) 145023) ((-892 . -661) 144968) ((-1243 . -403) 144920) ((-993 . -158) 144775) ((-837 . -158) 144645) ((-1086 . -678) T) ((-986 . -664) 144629) ((-980 . -678) 144580) ((-1107 . -194) 144491) ((-1086 . -816) T) ((-1086 . -813) T) ((-986 . -399) 144475) ((-138 . -137) T) ((-516 . -678) 144426) ((-801 . -305) 144371) ((-804 . -194) 144262) ((-802 . -194) 144173) ((-838 . -52) 144135) ((-1086 . -743) T) ((-347 . -523) 144119) ((-980 . -743) T) ((-479 . -194) 144030) ((-262 . -303) 144007) ((-516 . -743) T) ((-1291 . -325) 143945) ((-1275 . -43) 143842) ((-1271 . -922) 143755) ((-1264 . -922) 143661) ((-1263 . -1081) 143496) ((-1243 . -922) 143329) ((-1242 . -1081) 143137) ((-1237 . -922) 143050) ((-1229 . -125) T) ((-1220 . -307) 143029) ((-1160 . -175) 143013) ((-1096 . -125) T) ((-954 . -983) T) ((-754 . -325) 142951) ((-80 . -1225) T) ((-191 . -931) 142904) ((-34 . -125) T) ((-681 . -408) 142876) ((-30 . -983) T) ((-1 . -632) 142858) ((-1137 . -125) T) ((-1101 . -23) T) ((-55 . -636) 142842) ((-1101 . -1131) T) ((-1031 . -435) 142814) ((-617 . -922) 142727) ((-464 . -125) T) ((-163 . -325) NIL) ((-893 . -1075) T) ((-855 . -869) 142706) ((-86 . -1225) T) ((-728 . -307) T) ((-45 . -1082) T) ((-605 . -194) T) ((-550 . -194) T) ((-544 . -632) 142688) ((-191 . -661) 142598) ((-540 . -632) 142580) ((-375 . -171) 142562) ((-375 . -169) T) ((-384 . -1131) T) ((-377 . -1131) T) ((-365 . -1131) T) ((-1032 . -323) T) ((-937 . -323) T) ((-893 . -260) T) ((-132 . -1131) T) ((-893 . -247) 142541) ((-760 . -426) 142525) ((-1263 . -140) 142339) ((-1242 . -140) 142121) ((-262 . -1267) 142105) ((-592 . -867) T) ((-384 . -23) T) ((-378 . -373) T) ((-332 . -325) 142092) ((-329 . -325) 141988) ((-377 . -23) T) ((-336 . -158) T) ((-365 . -23) T) ((-1032 . -1049) T) ((-132 . -23) T) ((-262 . -625) 141965) ((-1265 . -43) 141822) ((-1252 . -931) 141801) ((-141 . -1119) T) ((-892 . -678) T) ((-1063 . -125) T) ((-1252 . -661) 141726) ((-892 . -816) NIL) ((-874 . -661) 141700) ((-892 . -813) NIL) ((-838 . -908) NIL) ((-892 . -743) T) ((-1107 . -547) 141563) ((-804 . -547) 141509) ((-802 . -547) 141461) ((-599 . -661) 141448) ((-838 . -1065) 141276) ((-479 . -547) 141214) ((-414 . -415) T) ((-65 . -1225) T) ((-637 . -869) 141193) ((-533 . -675) T) ((-1160 . -1005) 141162) ((-884 . -1081) 141114) ((-801 . -1081) 141066) ((-1031 . -477) T) ((-715 . -867) T) ((-543 . -814) T) ((-503 . -1081) 140901) ((-363 . -1119) T) ((-329 . -1165) NIL) ((-306 . -158) T) ((-420 . -1119) T) ((-891 . -1082) T) ((-710 . -396) 140868) ((-884 . -140) 140799) ((-801 . -140) 140730) ((-235 . -636) 140707) ((-191 . -678) 140638) ((-347 . -303) 140615) ((-1229 . -325) NIL) ((-503 . -140) 140429) ((-1263 . -1075) T) ((-1242 . -1075) T) ((-838 . -403) 140413) ((-191 . -743) T) ((-668 . -125) T) ((-1263 . -260) 140392) ((-1263 . -247) 140344) ((-1242 . -247) 140249) ((-1242 . -260) 140228) ((-1031 . -428) NIL) ((-687 . -654) 140176) ((-332 . -43) 140086) ((-329 . -43) 140015) ((-74 . -632) 139997) ((-336 . -526) 139963) ((-1199 . -305) 139942) ((-1132 . -1131) 139852) ((-88 . -1225) T) ((-66 . -632) 139834) ((-514 . -305) 139813) ((-1293 . -1065) 139790) ((-1179 . -1119) T) ((-1132 . -23) 139660) ((-1252 . -678) 139591) ((-838 . -922) 139527) ((-1252 . -743) T) ((-1121 . -1225) T) ((-1107 . -307) 139458) ((-915 . -125) T) ((-804 . -307) 139369) ((-599 . -678) T) ((-347 . -19) 139353) ((-64 . -305) 139330) ((-802 . -307) 139261) ((-874 . -743) T) ((-146 . -867) NIL) ((-549 . -305) 139238) ((-347 . -625) 139215) ((-529 . -305) 139192) ((-479 . -307) 139123) ((-1063 . -325) 138974) ((-599 . -743) T) ((-676 . -632) 138956) ((-262 . -633) 138917) ((-262 . -632) 138856) ((-1161 . -39) T) ((-971 . -1225) T) ((-363 . -734) 138801) ((-884 . -1075) T) ((-801 . -1075) T) ((-687 . -25) T) ((-687 . -21) T) ((-1137 . -1165) T) ((-503 . -1075) T) ((-650 . -443) 138766) ((-626 . -443) 138731) ((-949 . -1119) T) ((-884 . -247) T) ((-884 . -260) T) ((-801 . -247) 138690) ((-801 . -260) T) ((-605 . -307) T) ((-550 . -307) T) ((-1264 . -323) 138669) ((-503 . -247) 138621) ((-503 . -260) 138600) ((-1243 . -323) 138579) ((-1101 . -158) T) ((-893 . -817) 138558) ((-168 . -125) T) ((-45 . -1119) T) ((-893 . -814) 138537) ((-658 . -1038) 138521) ((-604 . -1082) T) ((-592 . -1082) T) ((-528 . -1082) T) ((-433 . -477) T) ((-384 . -158) T) ((-332 . -426) 138505) ((-329 . -426) 138466) ((-377 . -158) T) ((-365 . -158) T) ((-1243 . -1049) NIL) ((-1113 . -632) 138433) ((-132 . -158) T) ((-1137 . -43) 138420) ((-944 . -1119) T) ((-790 . -1119) T) ((-688 . -1119) T) ((-717 . -171) T) ((-1185 . -437) 138404) ((-145 . -171) T) ((-1300 . -21) T) ((-1300 . -25) T) ((-1298 . -21) T) ((-1298 . -25) T) ((-681 . -1081) 138388) ((-558 . -869) T) ((-533 . -869) T) ((-379 . -1081) 138340) ((-376 . -1081) 138292) ((-364 . -1081) 138244) ((-266 . -1225) T) ((-265 . -1225) T) ((-279 . -1081) 138087) ((-264 . -1081) 137930) ((-681 . -140) 137909) ((-379 . -140) 137840) ((-376 . -140) 137771) ((-364 . -140) 137702) ((-279 . -140) 137524) ((-264 . -140) 137346) ((-839 . -1235) 137325) ((-639 . -437) 137309) ((-49 . -21) T) ((-49 . -25) T) ((-837 . -654) 137215) ((-839 . -582) 137194) ((-266 . -1065) 137021) ((-265 . -1065) 136848) ((-156 . -148) 136832) ((-932 . -1081) 136797) ((-715 . -1082) T) ((-729 . -125) T) ((-240 . -664) 136779) ((-166 . -664) 136754) ((-363 . -194) T) ((-240 . -399) 136736) ((-166 . -399) 136711) ((-176 . -21) T) ((-176 . -25) T) ((-93 . -632) 136693) ((-932 . -140) 136642) ((-45 . -734) 136587) ((-891 . -1119) T) ((-347 . -633) 136548) ((-347 . -632) 136487) ((-1242 . -814) 136440) ((-1185 . -1082) T) ((-1242 . -817) 136393) ((-266 . -403) 136362) ((-265 . -403) 136331) ((-887 . -632) 136313) ((-882 . -632) 136295) ((-668 . -43) 136265) ((-627 . -39) T) ((-517 . -1131) 136175) ((-504 . -39) T) ((-1132 . -158) 136045) ((-1193 . -582) 136024) ((-993 . -25) 135835) ((-896 . -632) 135817) ((-993 . -21) 135772) ((-837 . -21) 135682) ((-837 . -25) 135533) ((-1187 . -52) 135510) ((-639 . -1082) T) ((-1142 . -52) 135482) ((-488 . -1119) T) ((-379 . -1075) T) ((-376 . -1075) T) ((-517 . -23) 135352) ((-364 . -1075) T) ((-279 . -1075) T) ((-264 . -1075) T) ((-1062 . -661) 135326) ((-146 . -1082) T) ((-986 . -39) T) ((-761 . -1235) 135305) ((-379 . -247) 135284) ((-379 . -260) T) ((-376 . -247) 135263) ((-376 . -260) T) ((-364 . -247) 135242) ((-364 . -260) T) ((-279 . -346) 135214) ((-264 . -346) 135171) ((-279 . -247) 135150) ((-1171 . -175) 135134) ((-761 . -582) 135045) ((-266 . -922) 134977) ((-265 . -922) 134909) ((-1103 . -869) T) ((-1246 . -1225) T) ((-440 . -1131) T) ((-1227 . -125) T) ((-1079 . -23) T) ((-932 . -1075) T) ((-341 . -661) 134891) ((-1051 . -867) T) ((-1220 . -1030) 134857) ((-1188 . -943) 134836) ((-1181 . -943) 134815) ((-932 . -260) T) ((-839 . -388) 134794) ((-411 . -23) T) ((-157 . -1119) 134772) ((-151 . -1119) 134750) ((-932 . -247) T) ((-1181 . -842) NIL) ((-405 . -661) 134715) ((-891 . -734) 134702) ((-1231 . -1119) T) ((-1072 . -175) 134667) ((-45 . -194) T) ((-710 . -437) 134649) ((-729 . -325) 134636) ((-856 . -661) 134596) ((-849 . -661) 134570) ((-336 . -25) T) ((-336 . -21) T) ((-672 . -303) 134549) ((-604 . -1119) T) ((-592 . -1119) T) ((-528 . -1119) T) ((-262 . -305) 134526) ((-329 . -245) 134487) ((-1187 . -908) NIL) ((-1142 . -908) 134346) ((-1187 . -1065) 134226) ((-1142 . -1065) 134109) ((-873 . -1065) 134005) ((-804 . -303) 133932) ((-950 . -632) 133914) ((-839 . -1131) T) ((-1062 . -743) T) ((-623 . -664) 133898) ((-1072 . -1005) 133827) ((-1027 . -125) T) ((-839 . -23) T) ((-729 . -1165) 133805) ((-710 . -1082) T) ((-623 . -399) 133789) ((-375 . -477) T) ((-363 . -307) T) ((-1281 . -1119) T) ((-489 . -125) T) ((-425 . -125) T) ((-306 . -21) T) ((-306 . -25) T) ((-386 . -743) T) ((-405 . -678) T) ((-727 . -1119) T) ((-715 . -1119) T) ((-386 . -502) T) ((-1227 . -325) NIL) ((-1220 . -632) 133771) ((-1187 . -403) 133755) ((-1142 . -403) 133739) ((-1051 . -437) 133701) ((-163 . -243) 133683) ((-405 . -816) T) ((-405 . -813) T) ((-891 . -194) T) ((-405 . -743) T) ((-728 . -632) 133665) ((-729 . -43) 133494) ((-1280 . -1278) 133478) ((-375 . -428) T) ((-1280 . -1119) 133428) ((-604 . -734) 133415) ((-592 . -734) 133402) ((-528 . -734) 133367) ((-884 . -1297) 133351) ((-332 . -644) 133330) ((-856 . -743) T) ((-849 . -743) T) ((-1185 . -1119) T) ((-658 . -1225) T) ((-1101 . -654) 133278) ((-1187 . -922) 133221) ((-1142 . -922) 133205) ((-676 . -1081) 133189) ((-132 . -654) 133171) ((-517 . -158) 133041) ((-801 . -664) 132993) ((-1193 . -1131) T) ((-884 . -394) T) ((-980 . -52) 132962) ((-761 . -1131) T) ((-639 . -1119) T) ((-676 . -140) 132941) ((-347 . -305) 132918) ((-516 . -52) 132875) ((-1193 . -23) T) ((-150 . -1119) T) ((-146 . -1119) T) ((-126 . -125) 132853) ((-761 . -23) T) ((-1290 . -1131) T) ((-1079 . -158) T) ((-1051 . -1082) T) ((-841 . -1065) 132837) ((-1031 . -741) 132809) ((-1290 . -23) T) ((-715 . -734) 132774) ((-609 . -632) 132756) ((-412 . -1065) 132740) ((-378 . -1082) T) ((-411 . -158) T) ((-343 . -1065) 132724) ((-237 . -908) 132706) ((-1032 . -943) T) ((-96 . -39) T) ((-1032 . -842) T) ((-937 . -943) T) ((-521 . -1235) T) ((-1206 . -632) 132688) ((-1124 . -1119) T) ((-230 . -1235) T) ((-1027 . -325) 132653) ((-237 . -1065) 132613) ((-45 . -307) T) ((-1101 . -21) T) ((-1101 . -25) T) ((-1137 . -850) T) ((-521 . -582) T) ((-384 . -25) T) ((-230 . -582) T) ((-384 . -21) T) ((-377 . -25) T) ((-377 . -21) T) ((-731 . -661) 132573) ((-365 . -25) T) ((-365 . -21) T) ((-132 . -25) T) ((-132 . -21) T) ((-53 . -1082) T) ((-1185 . -734) 132402) ((-604 . -194) T) ((-592 . -194) T) ((-528 . -194) T) ((-672 . -632) 132384) ((-754 . -753) 132368) ((-356 . -632) 132350) ((-258 . -632) 132332) ((-73 . -409) T) ((-73 . -421) T) ((-1121 . -131) 132316) ((-1086 . -908) 132298) ((-980 . -908) 132223) ((-667 . -1131) T) ((-639 . -734) 132210) ((-516 . -908) NIL) ((-1160 . -125) T) ((-1086 . -1065) 132192) ((-118 . -632) 132174) ((-513 . -171) T) ((-980 . -1065) 132054) ((-146 . -734) 131999) ((-667 . -23) T) ((-516 . -1065) 131875) ((-1107 . -633) NIL) ((-1107 . -632) 131857) ((-804 . -633) NIL) ((-804 . -632) 131818) ((-802 . -633) 131452) ((-802 . -632) 131366) ((-1132 . -654) 131272) ((-487 . -632) 131254) ((-479 . -632) 131236) ((-479 . -633) 131097) ((-1063 . -243) 131043) ((-156 . -39) T) ((-839 . -158) T) ((-893 . -931) 131022) ((-662 . -632) 131004) ((-379 . -1297) 130988) ((-376 . -1297) 130972) ((-364 . -1297) 130956) ((-157 . -547) 130889) ((-151 . -547) 130822) ((-544 . -814) T) ((-544 . -817) T) ((-543 . -816) T) ((-126 . -325) 130760) ((-234 . -125) 130738) ((-240 . -39) T) ((-166 . -39) T) ((-710 . -1119) T) ((-715 . -194) T) ((-1231 . -547) NIL) ((-893 . -661) 130690) ((-1027 . -43) 130638) ((-70 . -410) T) ((-293 . -632) 130620) ((-70 . -421) T) ((-980 . -403) 130604) ((-891 . -307) T) ((-55 . -632) 130586) ((-887 . -1081) 130551) ((-882 . -1081) 130501) ((-605 . -632) 130483) ((-605 . -633) 130465) ((-516 . -403) 130449) ((-561 . -632) 130431) ((-550 . -632) 130413) ((-932 . -1297) 130400) ((-892 . -1225) T) ((-887 . -140) 130349) ((-717 . -477) T) ((-882 . -140) 130276) ((-528 . -547) 130242) ((-521 . -388) T) ((-379 . -394) 130221) ((-376 . -394) 130200) ((-364 . -394) 130179) ((-230 . -388) T) ((-731 . -743) T) ((-145 . -477) T) ((-1185 . -194) 130070) ((-1301 . -1292) 130054) ((-892 . -906) 130031) ((-892 . -908) NIL) ((-993 . -869) 129930) ((-837 . -869) 129881) ((-668 . -670) 129865) ((-1212 . -39) T) ((-193 . -632) 129847) ((-1132 . -21) 129757) ((-1132 . -25) 129608) ((-996 . -1119) T) ((-892 . -1065) 129585) ((-980 . -922) 129566) ((-1252 . -52) 129543) ((-932 . -394) T) ((-64 . -664) 129527) ((-549 . -664) 129511) ((-516 . -922) 129488) ((-76 . -466) T) ((-76 . -421) T) ((-529 . -664) 129472) ((-64 . -399) 129456) ((-639 . -194) T) ((-549 . -399) 129440) ((-529 . -399) 129424) ((-849 . -725) 129408) ((-1187 . -323) 129387) ((-1193 . -158) T) ((-146 . -194) T) ((-761 . -158) T) ((-1160 . -325) 129325) ((-191 . -1225) T) ((-650 . -763) 129309) ((-626 . -763) 129293) ((-1290 . -158) T) ((-1264 . -943) 129272) ((-1243 . -943) 129251) ((-1243 . -842) NIL) ((-710 . -734) 129201) ((-1242 . -931) 129154) ((-1051 . -1119) T) ((-892 . -403) 129131) ((-892 . -358) 129108) ((-927 . -1131) T) ((-191 . -906) 129092) ((-191 . -908) 129017) ((-1280 . -547) 128950) ((-893 . -678) T) ((-521 . -1131) T) ((-378 . -1119) T) ((-230 . -1131) T) ((-81 . -466) T) ((-81 . -421) T) ((-1263 . -661) 128847) ((-191 . -1065) 128743) ((-336 . -869) T) ((-887 . -1075) T) ((-882 . -1075) T) ((-1242 . -661) 128613) ((-893 . -816) 128592) ((-893 . -813) 128571) ((-1302 . -1295) 128550) ((-893 . -743) T) ((-521 . -23) T) ((-235 . -632) 128532) ((-195 . -477) T) ((-234 . -325) 128470) ((-91 . -466) T) ((-91 . -421) T) ((-887 . -260) T) ((-230 . -23) T) ((-882 . -260) T) ((-760 . -437) 128454) ((-537 . -560) 128329) ((-604 . -307) T) ((-592 . -307) T) ((-693 . -1065) 128313) ((-528 . -307) T) ((-1185 . -547) 128259) ((-162 . -499) 128214) ((-136 . -1119) T) ((-53 . -1119) T) ((-729 . -245) 128198) ((-892 . -922) NIL) ((-1252 . -908) NIL) ((-911 . -125) T) ((-907 . -125) T) ((-414 . -1119) T) ((-191 . -403) 128182) ((-191 . -358) 128166) ((-1252 . -1065) 128046) ((-874 . -1065) 127942) ((-1156 . -125) T) ((-667 . -158) T) ((-146 . -547) 127805) ((-676 . -814) 127784) ((-676 . -817) 127763) ((-599 . -1065) 127745) ((-310 . -1287) 127715) ((-880 . -125) T) ((-992 . -582) 127694) ((-1220 . -1081) 127577) ((-517 . -654) 127483) ((-926 . -1119) T) ((-1051 . -734) 127420) ((-728 . -1081) 127385) ((-884 . -661) 127337) ((-801 . -661) 127289) ((-623 . -39) T) ((-1161 . -1225) T) ((-1220 . -140) 127151) ((-503 . -661) 127048) ((-378 . -734) 126993) ((-191 . -922) 126952) ((-715 . -307) T) ((-760 . -1082) T) ((-710 . -194) T) ((-728 . -140) 126901) ((-1306 . -1082) T) ((-1252 . -403) 126885) ((-444 . -1235) 126863) ((-329 . -867) NIL) ((-1263 . -678) 126842) ((-1242 . -678) 126821) ((-444 . -582) T) ((-237 . -323) T) ((-1242 . -813) 126774) ((-1242 . -816) 126727) ((-33 . -1117) T) ((-1263 . -743) T) ((-1242 . -743) T) ((-53 . -734) 126692) ((-1185 . -307) 126603) ((-237 . -1049) T) ((-375 . -1287) 126580) ((-1265 . -437) 126546) ((-735 . -743) T) ((-1252 . -922) 126489) ((-141 . -632) 126471) ((-141 . -633) 126453) ((-735 . -502) T) ((-517 . -21) 126363) ((-157 . -523) 126347) ((-151 . -523) 126331) ((-517 . -25) 126182) ((-639 . -307) T) ((-801 . -39) T) ((-1231 . -523) 126164) ((-609 . -1081) 126139) ((-1230 . -62) 126105) ((-463 . -1119) T) ((-1086 . -323) T) ((-146 . -307) T) ((-1123 . -125) T) ((-1031 . -125) T) ((-609 . -140) 126066) ((-1275 . -1082) T) ((-1156 . -325) 126004) ((-1220 . -1075) T) ((-1086 . -1049) T) ((-71 . -1225) T) ((-1079 . -25) T) ((-1079 . -21) T) ((-728 . -1075) T) ((-884 . -678) T) ((-801 . -678) T) ((-411 . -21) T) ((-411 . -25) T) ((-710 . -547) NIL) ((-1051 . -194) T) ((-503 . -678) 125983) ((-728 . -260) T) ((-1086 . -574) T) ((-884 . -743) T) ((-801 . -743) T) ((-535 . -125) T) ((-378 . -194) T) ((-363 . -632) 125965) ((-420 . -632) 125947) ((-503 . -743) T) ((-1137 . -867) T) ((-914 . -1065) 125915) ((-132 . -869) T) ((-672 . -1081) 125899) ((-521 . -158) T) ((-1265 . -1082) T) ((-230 . -158) T) ((-258 . -1081) 125881) ((-1171 . -125) 125859) ((-121 . -1119) T) ((-262 . -683) 125843) ((-262 . -664) 125827) ((-672 . -140) 125806) ((-332 . -437) 125790) ((-262 . -399) 125774) ((-1174 . -249) 125721) ((-1027 . -245) 125705) ((-258 . -140) 125680) ((-79 . -1225) T) ((-53 . -194) T) ((-717 . -413) T) ((-717 . -167) T) ((-1301 . -125) T) ((-1107 . -1081) 125523) ((-279 . -931) 125502) ((-264 . -931) 125481) ((-804 . -1081) 125304) ((-802 . -1081) 125147) ((-627 . -1225) T) ((-1179 . -632) 125129) ((-1107 . -140) 124951) ((-1072 . -125) T) ((-504 . -1225) T) ((-487 . -1081) 124922) ((-479 . -1081) 124765) ((-681 . -661) 124749) ((-892 . -323) T) ((-804 . -140) 124551) ((-802 . -140) 124373) ((-379 . -661) 124325) ((-376 . -661) 124277) ((-364 . -661) 124229) ((-279 . -661) 124154) ((-264 . -661) 124079) ((-1173 . -869) T) ((-487 . -140) 124040) ((-479 . -140) 123862) ((-1108 . -1065) 123846) ((-1097 . -1065) 123823) ((-1028 . -39) T) ((-986 . -1225) T) ((-156 . -1038) 123807) ((-992 . -1131) T) ((-892 . -1049) NIL) ((-752 . -1131) T) ((-732 . -1131) T) ((-1280 . -523) 123791) ((-1156 . -43) 123751) ((-992 . -23) T) ((-932 . -661) 123716) ((-862 . -125) T) ((-839 . -21) T) ((-839 . -25) T) ((-752 . -23) T) ((-732 . -23) T) ((-134 . -675) T) ((-797 . -743) T) ((-605 . -1081) 123681) ((-550 . -1081) 123626) ((-241 . -62) 123584) ((-478 . -23) T) ((-433 . -125) T) ((-278 . -125) T) ((-797 . -502) T) ((-994 . -125) T) ((-710 . -307) T) ((-880 . -43) 123554) ((-1231 . -303) 123529) ((-605 . -140) 123478) ((-550 . -140) 123395) ((-761 . -654) 123343) ((-444 . -1131) T) ((-332 . -1082) 123233) ((-329 . -1082) T) ((-949 . -632) 123215) ((-760 . -1119) T) ((-672 . -1075) T) ((-1306 . -1119) T) ((-191 . -323) 123146) ((-444 . -23) T) ((-45 . -632) 123128) ((-45 . -633) 123112) ((-132 . -1021) 123094) ((-145 . -890) 123078) ((-53 . -547) 123044) ((-1212 . -1038) 123028) ((-1199 . -39) T) ((-944 . -632) 123010) ((-1132 . -869) 122961) ((-790 . -632) 122943) ((-688 . -632) 122925) ((-1252 . -323) 122904) ((-1231 . -19) 122886) ((-1231 . -625) 122861) ((-1171 . -325) 122799) ((-1111 . -1225) T) ((-514 . -39) T) ((-1107 . -1075) T) ((-513 . -477) T) ((-887 . -1297) 122774) ((-882 . -1297) 122734) ((-1155 . -39) T) ((-804 . -1075) T) ((-802 . -1075) T) ((-660 . -249) 122718) ((-647 . -249) 122664) ((-1193 . -21) T) ((-1193 . -25) T) ((-1107 . -346) 122625) ((-1107 . -247) 122604) ((-804 . -346) 122581) ((-804 . -247) T) ((-479 . -1075) T) ((-802 . -346) 122553) ((-748 . -1235) 122532) ((-379 . -678) T) ((-376 . -678) T) ((-364 . -678) T) ((-347 . -664) 122516) ((-279 . -678) 122467) ((-264 . -678) 122418) ((-64 . -39) T) ((-551 . -39) T) ((-549 . -39) T) ((-479 . -346) 122397) ((-347 . -399) 122381) ((-530 . -39) T) ((-529 . -39) T) ((-1031 . -1165) NIL) ((-748 . -582) 122312) ((-650 . -125) T) ((-626 . -125) T) ((-379 . -743) T) ((-376 . -743) T) ((-364 . -743) T) ((-279 . -743) T) ((-264 . -743) T) ((-761 . -25) T) ((-761 . -21) T) ((-1290 . -21) T) ((-1072 . -325) 122220) ((-1290 . -25) T) ((-1275 . -1119) T) ((-923 . -1119) 122198) ((-55 . -1075) T) ((-1189 . -582) 122177) ((-1188 . -1235) 122156) ((-1188 . -582) 122107) ((-1181 . -1235) 122086) ((-932 . -678) T) ((-605 . -1075) T) ((-550 . -1075) T) ((-537 . -125) T) ((-1051 . -307) T) ((-386 . -1065) 122070) ((-341 . -1065) 122054) ((-281 . -1119) 122032) ((-405 . -908) 122014) ((-1181 . -582) 121965) ((-1143 . -582) 121944) ((-1031 . -43) 121889) ((-821 . -1131) T) ((-932 . -743) T) ((-605 . -260) T) ((-605 . -247) T) ((-550 . -247) T) ((-550 . -260) T) ((-760 . -734) 121813) ((-378 . -307) T) ((-660 . -711) 121797) ((-405 . -1065) 121757) ((-281 . -280) 121741) ((-1137 . -1082) T) ((-126 . -155) 121725) ((-821 . -23) T) ((-1300 . -1295) 121701) ((-1298 . -1295) 121680) ((-1280 . -303) 121657) ((-433 . -325) 121622) ((-1265 . -1119) T) ((-1185 . -303) 121549) ((-891 . -632) 121531) ((-856 . -1065) 121500) ((-217 . -809) T) ((-216 . -809) T) ((-34 . -37) 121477) ((-215 . -809) T) ((-214 . -809) T) ((-213 . -809) T) ((-212 . -809) T) ((-211 . -809) T) ((-210 . -809) T) ((-209 . -809) T) ((-208 . -809) T) ((-528 . -1030) T) ((-292 . -858) T) ((-291 . -858) T) ((-290 . -858) T) ((-289 . -858) T) ((-53 . -307) T) ((-288 . -858) T) ((-287 . -858) T) ((-286 . -858) T) ((-207 . -809) T) ((-631 . -869) T) ((-668 . -437) 121461) ((-134 . -869) T) ((-667 . -21) T) ((-667 . -25) T) ((-488 . -632) 121443) ((-1301 . -43) 121413) ((-1280 . -19) 121397) ((-146 . -303) 121327) ((-238 . -125) T) ((-165 . -125) T) ((-1280 . -625) 121304) ((-1291 . -1119) T) ((-1275 . -734) 121201) ((-1098 . -1119) T) ((-1016 . -1119) T) ((-992 . -158) T) ((-754 . -1119) T) ((-752 . -158) T) ((-732 . -158) T) ((-544 . -815) T) ((-433 . -1165) 121179) ((-478 . -158) T) ((-544 . -816) T) ((-235 . -1075) T) ((-310 . -125) 120961) ((-163 . -1119) T) ((-715 . -1030) T) ((-96 . -1225) T) ((-157 . -632) 120928) ((-151 . -632) 120895) ((-760 . -194) T) ((-1306 . -194) T) ((-1231 . -633) 120877) ((-1231 . -632) 120859) ((-1188 . -388) 120838) ((-1181 . -388) 120817) ((-332 . -1119) T) ((-444 . -158) T) ((-329 . -1119) T) ((-433 . -43) 120769) ((-1150 . -125) T) ((-1265 . -734) 120626) ((-668 . -1082) T) ((-336 . -169) 120605) ((-336 . -171) 120584) ((-162 . -1119) T) ((-143 . -1119) T) ((-876 . -125) T) ((-604 . -632) 120566) ((-592 . -633) 120465) ((-592 . -632) 120447) ((-528 . -632) 120429) ((-528 . -633) 120374) ((-519 . -23) T) ((-517 . -869) 120325) ((-138 . -1119) T) ((-521 . -654) 120307) ((-801 . -1038) 120259) ((-230 . -654) 120241) ((-237 . -430) T) ((-676 . -661) 120225) ((-1187 . -943) 120204) ((-748 . -1131) T) ((-375 . -125) T) ((-840 . -869) T) ((-748 . -23) T) ((-363 . -1081) 120149) ((-1173 . -1172) T) ((-1161 . -131) 120133) ((-1275 . -194) 120084) ((-1189 . -1131) T) ((-1188 . -1131) T) ((-1181 . -1131) T) ((-1143 . -1131) T) ((-548 . -1065) 120068) ((-363 . -140) 119985) ((-238 . -325) NIL) ((-165 . -325) NIL) ((-1032 . -1235) T) ((-156 . -1225) T) ((-937 . -1235) T) ((-1281 . -632) 119967) ((-1229 . -1119) T) ((-710 . -303) NIL) ((-1189 . -23) T) ((-1188 . -23) T) ((-1181 . -23) T) ((-1156 . -245) 119951) ((-1143 . -23) T) ((-1096 . -1119) T) ((-1032 . -582) T) ((-937 . -582) T) ((-821 . -158) T) ((-240 . -1225) T) ((-166 . -1225) T) ((-760 . -547) 119917) ((-727 . -632) 119899) ((-34 . -1119) T) ((-332 . -734) 119809) ((-329 . -734) 119738) ((-715 . -632) 119720) ((-715 . -633) 119665) ((-433 . -426) 119649) ((-464 . -1119) T) ((-521 . -25) T) ((-521 . -21) T) ((-1137 . -1119) T) ((-230 . -25) T) ((-230 . -21) T) ((-729 . -437) 119633) ((-731 . -1065) 119602) ((-1280 . -632) 119541) ((-1280 . -633) 119502) ((-1265 . -194) T) ((-262 . -39) T) ((-1185 . -633) NIL) ((-1185 . -632) 119484) ((-953 . -1003) T) ((-1212 . -1225) T) ((-676 . -813) 119463) ((-676 . -816) 119442) ((-424 . -421) T) ((-555 . -125) 119420) ((-1063 . -1119) T) ((-234 . -1023) 119404) ((-538 . -125) T) ((-639 . -632) 119386) ((-50 . -869) NIL) ((-639 . -633) 119363) ((-1063 . -629) 119338) ((-923 . -547) 119271) ((-363 . -1075) T) ((-150 . -632) 119253) ((-146 . -633) NIL) ((-146 . -632) 119235) ((-893 . -1225) T) ((-687 . -443) 119219) ((-687 . -1140) 119164) ((-281 . -547) 119097) ((-533 . -175) 119079) ((-363 . -247) T) ((-363 . -260) T) ((-45 . -1081) 119024) ((-893 . -906) 119008) ((-893 . -908) 118933) ((-729 . -1082) T) ((-710 . -1030) NIL) ((-1263 . -52) 118903) ((-1242 . -52) 118880) ((-1155 . -1038) 118851) ((-1137 . -734) 118838) ((-1124 . -632) 118820) ((-893 . -1065) 118684) ((-237 . -943) T) ((-45 . -140) 118601) ((-760 . -307) T) ((-1101 . -171) 118580) ((-1101 . -169) 118531) ((-1032 . -388) T) ((-887 . -661) 118496) ((-882 . -661) 118446) ((-336 . -1214) 118412) ((-405 . -323) T) ((-336 . -1211) 118378) ((-332 . -194) 118357) ((-329 . -194) T) ((-1031 . -245) 118334) ((-937 . -388) T) ((-605 . -1297) 118321) ((-550 . -1297) 118298) ((-384 . -171) 118277) ((-384 . -169) 118228) ((-377 . -171) 118207) ((-377 . -169) 118158) ((-627 . -1202) 118134) ((-365 . -171) 118113) ((-365 . -169) 118064) ((-336 . -40) 118030) ((-504 . -1202) 118009) ((0 . |EnumerationCategory|) T) ((-336 . -116) 117975) ((-405 . -1049) T) ((-132 . -171) T) ((-132 . -169) NIL) ((-50 . -249) 117925) ((-668 . -1119) T) ((-627 . -131) 117872) ((-519 . -158) T) ((-504 . -131) 117822) ((-254 . -1131) 117732) ((-1106 . -1131) T) ((-893 . -403) 117716) ((-893 . -358) 117700) ((-254 . -23) 117570) ((-1086 . -943) T) ((-1086 . -842) T) ((-605 . -394) T) ((-550 . -394) T) ((-761 . -869) 117549) ((-1231 . -305) 117524) ((-375 . -1165) T) ((-347 . -39) T) ((-49 . -443) 117508) ((-1106 . -23) T) ((-416 . -763) 117492) ((-1291 . -547) 117425) ((-748 . -158) T) ((-1275 . -307) 117404) ((-1271 . -582) 117383) ((-1264 . -1235) 117362) ((-1264 . -582) 117313) ((-1243 . -1235) 117292) ((-1243 . -582) 117243) ((-754 . -547) 117176) ((-1242 . -1225) 117155) ((-1242 . -908) 117028) ((-915 . -1119) T) ((-168 . -863) T) ((-1242 . -906) 116998) ((-1237 . -582) 116977) ((-1189 . -158) T) ((-555 . -325) 116915) ((-1188 . -158) T) ((-163 . -547) NIL) ((-1181 . -158) T) ((-1143 . -158) T) ((-1051 . -1030) T) ((-1032 . -23) T) ((-375 . -43) 116880) ((-1032 . -1131) T) ((-937 . -1131) T) ((-87 . -632) 116862) ((-45 . -1075) T) ((-891 . -1081) 116849) ((-893 . -922) 116808) ((-801 . -52) 116785) ((-717 . -125) T) ((-1031 . -373) NIL) ((-623 . -1225) T) ((-1000 . -23) T) ((-937 . -23) T) ((-891 . -140) 116770) ((-453 . -1131) T) ((-503 . -52) 116740) ((-160 . -125) T) ((-45 . -247) 116712) ((-45 . -260) T) ((-145 . -125) T) ((-618 . -582) 116691) ((-617 . -582) 116670) ((-710 . -632) 116652) ((-710 . -633) 116560) ((-332 . -547) 116526) ((-329 . -547) 116277) ((-887 . -678) T) ((-882 . -678) T) ((-1263 . -1065) 116261) ((-1242 . -1065) 116047) ((-1027 . -437) 116031) ((-453 . -23) T) ((-1137 . -194) T) ((-887 . -743) T) ((-882 . -743) T) ((-1265 . -307) T) ((-668 . -734) 116001) ((-168 . -1119) T) ((-53 . -1030) T) ((-433 . -245) 115985) ((-311 . -249) 115935) ((-892 . -943) T) ((-892 . -842) NIL) ((-996 . -632) 115917) ((-879 . -869) T) ((-1242 . -358) 115887) ((-1242 . -403) 115857) ((-234 . -1138) 115841) ((-801 . -1225) T) ((-1280 . -305) 115818) ((-524 . -125) T) ((-1220 . -661) 115743) ((-992 . -21) T) ((-992 . -25) T) ((-752 . -21) T) ((-752 . -25) T) ((-732 . -21) T) ((-732 . -25) T) ((-728 . -661) 115708) ((-478 . -21) T) ((-478 . -25) T) ((-359 . -125) T) ((-195 . -125) T) ((-1027 . -1082) T) ((-891 . -1075) T) ((-884 . -1065) 115692) ((-793 . -125) T) ((-1229 . -547) NIL) ((-1264 . -388) 115671) ((-1263 . -922) 115577) ((-1243 . -388) 115556) ((-1242 . -922) 115407) ((-1051 . -632) 115389) ((-433 . -850) 115342) ((-1189 . -526) 115308) ((-191 . -943) 115239) ((-1188 . -526) 115205) ((-1181 . -526) 115171) ((-729 . -1119) T) ((-1143 . -526) 115137) ((-604 . -1081) 115124) ((-592 . -1081) 115111) ((-528 . -1081) 115076) ((-332 . -307) 115055) ((-329 . -307) T) ((-378 . -632) 115037) ((-444 . -25) T) ((-444 . -21) T) ((-121 . -303) 115016) ((-604 . -140) 115001) ((-592 . -140) 114986) ((-528 . -140) 114935) ((-1191 . -908) 114902) ((-35 . -125) T) ((-923 . -523) 114886) ((-136 . -632) 114868) ((-53 . -632) 114850) ((-53 . -633) 114795) ((-281 . -523) 114779) ((-254 . -158) 114649) ((-1252 . -943) 114628) ((-838 . -1235) 114607) ((-1063 . -547) 114415) ((-1106 . -158) T) ((-414 . -632) 114397) ((-838 . -582) 114328) ((-609 . -661) 114303) ((-279 . -52) 114275) ((-264 . -52) 114232) ((-558 . -542) 114209) ((-1028 . -1225) T) ((-1271 . -23) T) ((-1271 . -1131) T) ((-1264 . -1131) T) ((-715 . -1081) 114174) ((-801 . -922) 114087) ((-1264 . -23) T) ((-1243 . -1131) T) ((-1237 . -1131) T) ((-1031 . -396) 114059) ((-728 . -678) T) ((-141 . -394) T) ((-503 . -922) 113965) ((-1243 . -23) T) ((-1237 . -23) T) ((-926 . -632) 113947) ((-96 . -131) 113931) ((-1220 . -743) T) ((-927 . -869) 113882) ((-717 . -1165) T) ((-715 . -140) 113831) ((-1227 . -1119) T) ((-618 . -1131) T) ((-617 . -1131) T) ((-729 . -734) 113660) ((-728 . -743) T) ((-1137 . -307) T) ((-1032 . -158) T) ((-521 . -869) T) ((-1000 . -158) T) ((-937 . -158) T) ((-821 . -25) T) ((-230 . -869) T) ((-821 . -21) T) ((-604 . -1075) T) ((-592 . -1075) T) ((-528 . -1075) T) ((-618 . -23) T) ((-363 . -1297) 113637) ((-336 . -477) 113616) ((-359 . -325) 113603) ((-617 . -23) T) ((-453 . -158) T) ((-672 . -661) 113577) ((-1185 . -1081) 113400) ((-262 . -1038) 113384) ((-893 . -323) T) ((-1302 . -1292) 113368) ((-790 . -814) T) ((-790 . -817) T) ((-717 . -43) 113355) ((-258 . -661) 113337) ((-592 . -247) T) ((-528 . -260) T) ((-528 . -247) T) ((-1185 . -140) 113139) ((-1164 . -249) 113089) ((-1107 . -931) 113068) ((-145 . -43) 113055) ((-223 . -822) T) ((-222 . -822) T) ((-221 . -822) T) ((-220 . -822) T) ((-893 . -1049) 113033) ((-1291 . -523) 113017) ((-804 . -931) 112996) ((-802 . -931) 112975) ((-1199 . -1225) T) ((-479 . -931) 112954) ((-754 . -523) 112938) ((-1107 . -661) 112863) ((-804 . -661) 112788) ((-639 . -1081) 112775) ((-514 . -1225) T) ((-363 . -394) T) ((-163 . -523) 112757) ((-802 . -661) 112682) ((-1155 . -1225) T) ((-487 . -661) 112653) ((-279 . -908) 112512) ((-264 . -908) NIL) ((-146 . -1081) 112457) ((-479 . -661) 112382) ((-681 . -1065) 112359) ((-639 . -140) 112344) ((-379 . -1065) 112328) ((-376 . -1065) 112312) ((-364 . -1065) 112296) ((-279 . -1065) 112140) ((-264 . -1065) 112016) ((-146 . -140) 111933) ((-64 . -1225) T) ((-551 . -1225) T) ((-549 . -1225) T) ((-530 . -1225) T) ((-529 . -1225) T) ((-463 . -632) 111915) ((-460 . -632) 111897) ((-3 . -125) T) ((-1055 . -1219) 111866) ((-855 . -125) T) ((-706 . -62) 111824) ((-715 . -1075) T) ((-55 . -661) 111798) ((-306 . -477) T) ((-505 . -1219) 111767) ((-1275 . -303) 111752) ((0 . -125) T) ((-605 . -661) 111717) ((-550 . -661) 111662) ((-54 . -125) T) ((-932 . -1065) 111649) ((-715 . -260) T) ((-1101 . -435) 111628) ((-748 . -654) 111576) ((-1027 . -1119) T) ((-729 . -194) 111467) ((-521 . -1021) 111449) ((-489 . -1119) T) ((-279 . -403) 111433) ((-264 . -403) 111417) ((-425 . -1119) T) ((-1185 . -1075) T) ((-359 . -43) 111401) ((-1054 . -125) 111379) ((-230 . -1021) 111361) ((-195 . -43) 111293) ((-1263 . -323) 111272) ((-1242 . -323) 111251) ((-1185 . -346) 111228) ((-672 . -743) T) ((-1185 . -247) T) ((-121 . -632) 111210) ((-1181 . -654) 111162) ((-519 . -25) T) ((-519 . -21) T) ((-1242 . -1049) 111114) ((-1107 . -678) 111065) ((-639 . -1075) T) ((-405 . -430) T) ((-804 . -678) 110996) ((-802 . -678) 110947) ((-416 . -125) T) ((-279 . -922) 110893) ((-264 . -922) 110870) ((-146 . -1075) T) ((-479 . -678) 110821) ((-838 . -1131) T) ((-1107 . -743) T) ((-639 . -247) 110800) ((-637 . -125) T) ((-1229 . -523) 110782) ((-804 . -743) T) ((-802 . -743) T) ((-1228 . -62) 110748) ((-439 . -1131) T) ((-146 . -260) T) ((-45 . -394) NIL) ((-146 . -247) NIL) ((-479 . -743) T) ((-838 . -23) T) ((-748 . -25) T) ((-748 . -21) T) ((-719 . -869) T) ((-1098 . -303) 110727) ((-83 . -422) T) ((-83 . -421) T) ((-1275 . -1030) 110693) ((-1271 . -158) T) ((-1264 . -158) T) ((-710 . -1081) 110643) ((-1243 . -158) T) ((-1237 . -158) T) ((-1189 . -25) T) ((-1171 . -1163) 110627) ((-1156 . -437) 110611) ((-605 . -678) T) ((-650 . -392) 110543) ((-626 . -392) 110475) ((-550 . -678) T) ((-126 . -1119) 110453) ((-1189 . -21) T) ((-1188 . -21) T) ((-1188 . -25) T) ((-1027 . -734) 110401) ((-235 . -661) 110368) ((-710 . -140) 110295) ((-55 . -743) T) ((-1181 . -21) T) ((-375 . -373) T) ((-1181 . -25) T) ((-1101 . -477) 110246) ((-1143 . -21) T) ((-729 . -547) 110192) ((-605 . -743) T) ((-550 . -743) T) ((-884 . -323) T) ((-1143 . -25) T) ((-801 . -323) T) ((-618 . -158) T) ((-617 . -158) T) ((-384 . -477) T) ((-377 . -477) T) ((-365 . -477) T) ((-503 . -323) 110171) ((-329 . -303) 110037) ((-132 . -477) T) ((-84 . -466) T) ((-84 . -421) T) ((-513 . -125) T) ((-760 . -633) 109898) ((-760 . -632) 109880) ((-1306 . -632) 109862) ((-1306 . -633) 109844) ((-1101 . -428) 109823) ((-1063 . -523) 109755) ((-592 . -817) T) ((-592 . -814) T) ((-1087 . -249) 109701) ((-384 . -428) 109652) ((-377 . -428) 109603) ((-365 . -428) 109554) ((-1293 . -1131) T) ((-1293 . -23) T) ((-1282 . -125) T) ((-1156 . -1082) T) ((-687 . -763) 109538) ((-1193 . -169) 109517) ((-1193 . -171) 109496) ((-1160 . -1119) T) ((-1160 . -1094) 109465) ((-74 . -1225) T) ((-1051 . -1081) 109402) ((-880 . -1082) T) ((-761 . -169) 109381) ((-761 . -171) 109360) ((-254 . -654) 109266) ((-710 . -1075) T) ((-255 . -582) 109245) ((-378 . -1081) 109190) ((-66 . -1225) T) ((-1051 . -140) 109099) ((-923 . -632) 109066) ((-710 . -260) T) ((-710 . -247) NIL) ((-1227 . -547) NIL) ((-862 . -867) 109045) ((-715 . -817) T) ((-715 . -814) T) ((-1275 . -632) 109027) ((-1229 . -303) 109002) ((-1031 . -437) 108979) ((-378 . -140) 108896) ((-281 . -632) 108863) ((-405 . -943) T) ((-433 . -867) 108842) ((-729 . -307) 108753) ((-235 . -743) T) ((-1271 . -526) 108719) ((-1264 . -526) 108685) ((-1243 . -526) 108651) ((-1237 . -526) 108617) ((-332 . -1030) 108596) ((-234 . -1119) 108574) ((-336 . -1002) 108536) ((-129 . -125) T) ((-53 . -1081) 108501) ((-1302 . -125) T) ((-407 . -125) T) ((-53 . -140) 108450) ((-1032 . -654) 108432) ((-1265 . -632) 108414) ((-558 . -125) T) ((-533 . -125) T) ((-1150 . -1151) 108398) ((-176 . -1287) 108382) ((-262 . -1225) T) ((-1229 . -19) 108364) ((-801 . -690) 108316) ((-1187 . -1235) 108295) ((-1142 . -1235) 108274) ((-254 . -21) 108184) ((-254 . -25) 108035) ((-157 . -148) 108019) ((-151 . -148) 108003) ((-1231 . -664) 107985) ((-49 . -763) 107969) ((-1229 . -625) 107944) ((-1187 . -582) 107855) ((-1142 . -582) 107786) ((-1231 . -399) 107768) ((-1063 . -303) 107743) ((-1106 . -25) T) ((-1106 . -21) T) ((-838 . -158) T) ((-146 . -817) NIL) ((-146 . -814) NIL) ((-379 . -323) T) ((-376 . -323) T) ((-364 . -323) T) ((-1113 . -1225) T) ((-266 . -1131) 107653) ((-265 . -1131) 107563) ((-1051 . -1075) T) ((-1031 . -1082) T) ((-363 . -661) 107508) ((-637 . -43) 107492) ((-1291 . -632) 107454) ((-1291 . -633) 107415) ((-1098 . -632) 107397) ((-1051 . -260) T) ((-378 . -1075) T) ((-837 . -1287) 107367) ((-266 . -23) T) ((-265 . -23) T) ((-1016 . -632) 107349) ((-754 . -633) 107310) ((-754 . -632) 107292) ((-821 . -869) 107271) ((-1027 . -547) 107183) ((-378 . -247) T) ((-378 . -260) T) ((-1174 . -175) 107130) ((-1032 . -25) T) ((-163 . -632) 107112) ((-163 . -633) 107071) ((-932 . -323) T) ((-1032 . -21) T) ((-1000 . -25) T) ((-937 . -21) T) ((-937 . -25) T) ((-453 . -21) T) ((-453 . -25) T) ((-862 . -437) 107055) ((-53 . -1075) T) ((-1300 . -1292) 107039) ((-1298 . -1292) 107023) ((-1063 . -625) 106998) ((-332 . -633) 106859) ((-332 . -632) 106841) ((-329 . -633) NIL) ((-329 . -632) 106823) ((-53 . -260) T) ((-53 . -247) T) ((-668 . -303) 106784) ((-575 . -249) 106734) ((-162 . -632) 106716) ((-143 . -632) 106698) ((-513 . -43) 106663) ((-1302 . -1299) 106642) ((-1293 . -158) T) ((-1301 . -1082) T) ((-1103 . -125) T) ((-138 . -632) 106624) ((-93 . -1225) T) ((-533 . -325) NIL) ((-1028 . -131) 106608) ((-911 . -1119) T) ((-907 . -1119) T) ((-1280 . -664) 106592) ((-1280 . -399) 106576) ((-347 . -1225) T) ((-615 . -869) T) ((-255 . -1131) T) ((-1156 . -1119) T) ((-1156 . -1078) 106516) ((-363 . -678) T) ((-126 . -547) 106449) ((-954 . -632) 106431) ((-255 . -23) T) ((-363 . -743) T) ((-30 . -632) 106413) ((-880 . -1119) T) ((-862 . -1082) 106392) ((-45 . -661) 106337) ((-237 . -1235) T) ((-433 . -1082) T) ((-1173 . -175) 106319) ((-1027 . -307) 106270) ((-237 . -582) T) ((-1229 . -633) 106252) ((-336 . -1260) 106236) ((-336 . -1257) 106206) ((-1229 . -632) 106188) ((-1199 . -1202) 106167) ((-1096 . -632) 106149) ((-34 . -632) 106131) ((-887 . -1065) 106091) ((-882 . -1065) 106036) ((-660 . -175) 106020) ((-647 . -175) 105966) ((-1199 . -131) 105916) ((-514 . -1202) 105895) ((-521 . -171) T) ((-521 . -169) NIL) ((-1137 . -633) 105810) ((-464 . -632) 105792) ((-230 . -171) T) ((-230 . -169) NIL) ((-1137 . -632) 105774) ((-57 . -125) T) ((-1243 . -654) 105726) ((-514 . -131) 105676) ((-1022 . -23) T) ((-1302 . -43) 105646) ((-1187 . -1131) T) ((-1142 . -1131) T) ((-1086 . -1235) T) ((-873 . -1131) T) ((-980 . -1235) 105625) ((-1227 . -523) 105607) ((-516 . -1235) 105586) ((-748 . -869) 105565) ((-1086 . -582) T) ((-1226 . -62) 105531) ((-980 . -582) 105462) ((-1187 . -23) T) ((-1142 . -23) T) ((-873 . -23) T) ((-516 . -582) 105393) ((-1156 . -734) 105325) ((-1160 . -547) 105258) ((-1063 . -633) NIL) ((-1063 . -632) 105240) ((-1306 . -1081) 105227) ((-880 . -734) 105197) ((-1306 . -140) 105182) ((-1271 . -25) T) ((-1220 . -52) 105151) ((-266 . -158) T) ((-265 . -158) T) ((-1123 . -1119) T) ((-1031 . -1119) T) ((-67 . -632) 105133) ((-1181 . -869) NIL) ((-1051 . -814) T) ((-1051 . -817) T) ((-1271 . -21) T) ((-760 . -1081) 105057) ((-1264 . -21) T) ((-45 . -678) T) ((-891 . -661) 105044) ((-1264 . -25) T) ((-1243 . -21) T) ((-1243 . -25) T) ((-1237 . -25) T) ((-1237 . -21) T) ((-1055 . -175) 105028) ((-893 . -842) 105007) ((-893 . -943) T) ((-760 . -140) 104910) ((-729 . -303) 104837) ((-618 . -21) T) ((-618 . -25) T) ((-617 . -21) T) ((-45 . -743) T) ((-234 . -547) 104770) ((-617 . -25) T) ((-505 . -175) 104754) ((-492 . -175) 104738) ((-944 . -743) T) ((-790 . -815) T) ((-790 . -816) T) ((-535 . -1119) T) ((-790 . -743) T) ((-237 . -388) T) ((-1171 . -1119) 104716) ((-892 . -1235) T) ((-668 . -632) 104698) ((-892 . -582) T) ((-710 . -394) NIL) ((-384 . -1287) 104682) ((-687 . -125) T) ((-377 . -1287) 104666) ((-365 . -1287) 104650) ((-1301 . -1119) T) ((-552 . -869) 104629) ((-1275 . -1081) 104512) ((-839 . -477) 104491) ((-1072 . -1119) T) ((-1072 . -1094) 104420) ((-1055 . -1005) 104389) ((-841 . -1131) T) ((-1031 . -734) 104334) ((-1275 . -140) 104196) ((-255 . -158) T) ((-412 . -1131) T) ((-505 . -1005) 104165) ((-492 . -1005) 104134) ((-948 . -1117) T) ((-134 . -175) 104116) ((-78 . -632) 104098) ((-915 . -632) 104080) ((-1101 . -741) 104059) ((-760 . -1075) T) ((-1306 . -1075) T) ((-1227 . -303) 104034) ((-891 . -678) T) ((-838 . -654) 103982) ((-310 . -1082) 103924) ((-191 . -1235) 103829) ((-237 . -1131) T) ((-343 . -23) T) ((-1181 . -1021) 103781) ((-862 . -1119) T) ((-760 . -260) 103760) ((-1143 . -757) 103739) ((-1265 . -1081) 103628) ((-1263 . -943) 103607) ((-891 . -743) T) ((-191 . -582) 103518) ((-1242 . -943) 103497) ((-604 . -661) 103484) ((-433 . -1119) T) ((-592 . -661) 103471) ((-278 . -1119) T) ((-528 . -661) 103436) ((-237 . -23) T) ((-1242 . -842) 103389) ((-994 . -1119) T) ((-1300 . -125) T) ((-378 . -1297) 103366) ((-1298 . -125) T) ((-1265 . -140) 103216) ((-168 . -632) 103198) ((-1022 . -158) T) ((-49 . -125) T) ((-254 . -869) 103149) ((-1301 . -734) 103119) ((-1252 . -1235) 103098) ((-126 . -523) 103082) ((-1252 . -582) 102993) ((-1227 . -19) 102975) ((-1107 . -52) 102936) ((-1086 . -1131) T) ((-980 . -1131) T) ((-157 . -39) T) ((-151 . -39) T) ((-1231 . -39) T) ((-1229 . -305) 102911) ((-804 . -52) 102888) ((-802 . -52) 102860) ((-1227 . -625) 102835) ((-1187 . -158) T) ((-378 . -394) T) ((-516 . -1131) T) ((-1142 . -158) T) ((-1086 . -23) T) ((-479 . -52) 102814) ((-892 . -388) T) ((-873 . -158) T) ((-176 . -125) T) ((-761 . -477) 102745) ((-980 . -23) T) ((-599 . -582) T) ((-838 . -25) T) ((-838 . -21) T) ((-1156 . -547) 102678) ((-609 . -1065) 102662) ((-516 . -23) T) ((-375 . -1082) T) ((-1275 . -1075) T) ((-1220 . -922) 102643) ((-687 . -325) 102581) ((-1275 . -247) 102540) ((-1132 . -1287) 102510) ((-715 . -661) 102475) ((-1032 . -869) T) ((-1031 . -194) T) ((-992 . -169) 102454) ((-650 . -1119) T) ((-626 . -1119) T) ((-992 . -171) 102433) ((-884 . -943) T) ((-752 . -171) 102412) ((-752 . -169) 102391) ((-1000 . -869) T) ((-801 . -943) T) ((-503 . -943) 102370) ((-332 . -1081) 102280) ((-329 . -1081) 102209) ((-1027 . -303) 102167) ((-1185 . -931) 102146) ((-433 . -734) 102098) ((-717 . -867) T) ((-562 . -1117) T) ((-537 . -1119) T) ((-1265 . -346) 102042) ((-1265 . -1075) T) ((-604 . -678) T) ((-332 . -140) 101931) ((-329 . -140) 101816) ((-592 . -678) T) ((-528 . -678) T) ((-1185 . -661) 101741) ((-993 . -125) T) ((-837 . -125) 101531) ((-729 . -633) NIL) ((-729 . -632) 101513) ((-1063 . -305) 101488) ((-672 . -1065) 101384) ((-887 . -323) T) ((-604 . -743) T) ((-592 . -816) T) ((-592 . -813) T) ((-191 . -388) 101335) ((-592 . -743) T) ((-528 . -743) T) ((-258 . -1065) 101319) ((-882 . -323) T) ((-1160 . -523) 101303) ((-1107 . -908) NIL) ((-892 . -1131) T) ((-146 . -931) NIL) ((-1300 . -1299) 101279) ((-1298 . -1299) 101258) ((-804 . -908) NIL) ((-802 . -908) 101117) ((-1293 . -25) T) ((-1293 . -21) T) ((-1223 . -125) 101095) ((-1125 . -421) T) ((-639 . -661) 101082) ((-479 . -908) NIL) ((-691 . -125) 101060) ((-1107 . -1065) 100887) ((-892 . -23) T) ((-804 . -1065) 100746) ((-802 . -1065) 100603) ((-146 . -661) 100548) ((-479 . -1065) 100424) ((-662 . -1065) 100408) ((-642 . -125) T) ((-234 . -523) 100392) ((-1280 . -39) T) ((-650 . -734) 100376) ((-626 . -734) 100360) ((-687 . -43) 100320) ((-715 . -678) T) ((-336 . -125) T) ((-238 . -1119) T) ((-165 . -1119) T) ((-90 . -632) 100302) ((-55 . -1065) 100286) ((-1137 . -1081) 100273) ((-1107 . -403) 100257) ((-804 . -403) 100241) ((-65 . -62) 100203) ((-715 . -816) T) ((-715 . -813) T) ((-605 . -1065) 100190) ((-550 . -1065) 100167) ((-715 . -743) T) ((-343 . -158) T) ((-332 . -1075) 100057) ((-329 . -1075) T) ((-191 . -1131) T) ((-802 . -403) 100041) ((-50 . -175) 99991) ((-1032 . -1021) 99973) ((-1227 . -633) 99955) ((-1227 . -632) 99937) ((-479 . -403) 99921) ((-433 . -194) T) ((-332 . -260) 99900) ((-329 . -260) T) ((-329 . -247) NIL) ((-310 . -1119) 99682) ((-237 . -158) T) ((-1137 . -140) 99667) ((-191 . -23) T) ((-821 . -171) 99646) ((-821 . -169) 99625) ((-266 . -654) 99531) ((-265 . -654) 99437) ((-1185 . -678) 99368) ((-336 . -301) 99334) ((-1185 . -743) T) ((-1171 . -547) 99267) ((-1150 . -1119) T) ((-237 . -1084) T) ((-837 . -325) 99205) ((-1107 . -922) 99140) ((-804 . -922) 99083) ((-802 . -922) 99067) ((-1300 . -43) 99037) ((-1298 . -43) 99007) ((-1252 . -1131) T) ((-874 . -1131) T) ((-639 . -678) 98986) ((-479 . -922) 98963) ((-876 . -1119) T) ((-146 . -678) T) ((-1252 . -23) T) ((-599 . -1131) T) ((-874 . -23) T) ((-639 . -743) T) ((-379 . -943) T) ((-376 . -943) T) ((-306 . -125) T) ((-364 . -943) T) ((-1086 . -158) T) ((-980 . -158) T) ((-146 . -816) NIL) ((-146 . -813) NIL) ((-146 . -743) T) ((-710 . -931) NIL) ((-1072 . -547) 98847) ((-516 . -158) T) ((-599 . -23) T) ((-691 . -325) 98785) ((-650 . -780) T) ((-626 . -780) T) ((-1243 . -869) NIL) ((-1031 . -307) T) ((-266 . -21) T) ((-710 . -661) 98735) ((-375 . -1119) T) ((-266 . -25) T) ((-265 . -21) T) ((-265 . -25) T) ((-176 . -43) 98719) ((-2 . -125) T) ((-932 . -943) T) ((-517 . -1287) 98689) ((-235 . -1065) 98666) ((-1137 . -1075) T) ((-728 . -323) T) ((-310 . -734) 98608) ((-717 . -1082) T) ((-521 . -477) T) ((-433 . -547) 98520) ((-230 . -477) T) ((-1137 . -247) T) ((-311 . -175) 98470) ((-1027 . -633) 98431) ((-1027 . -632) 98413) ((-1018 . -632) 98395) ((-145 . -1082) T) ((-668 . -1081) 98379) ((-237 . -526) T) ((-489 . -632) 98361) ((-425 . -632) 98343) ((-425 . -633) 98320) ((-1079 . -1287) 98290) ((-668 . -140) 98269) ((-1156 . -523) 98253) ((-837 . -43) 98223) ((-68 . -466) T) ((-68 . -421) T) ((-1174 . -125) T) ((-892 . -158) T) ((-518 . -125) 98201) ((-1306 . -394) T) ((-761 . -977) 98170) ((-1101 . -125) T) ((-1085 . -125) T) ((-375 . -734) 98115) ((-748 . -171) 98094) ((-748 . -169) 98073) ((-1051 . -661) 98010) ((-555 . -1119) 97988) ((-384 . -125) T) ((-377 . -125) T) ((-710 . -678) T) ((-365 . -125) T) ((-255 . -21) T) ((-255 . -25) T) ((-132 . -125) T) ((-538 . -1119) T) ((-378 . -661) 97933) ((-1187 . -654) 97881) ((-1142 . -654) 97829) ((-411 . -542) 97808) ((-855 . -867) 97787) ((-405 . -1235) T) ((-710 . -743) T) ((-359 . -1082) T) ((-1243 . -1021) 97739) ((-195 . -1082) T) ((-126 . -632) 97706) ((-1189 . -169) 97685) ((-1189 . -171) 97664) ((-405 . -582) T) ((-1188 . -171) 97643) ((-1188 . -169) 97622) ((-1181 . -169) 97529) ((-433 . -307) T) ((-1181 . -171) 97436) ((-1143 . -171) 97415) ((-1143 . -169) 97394) ((-336 . -43) 97235) ((-191 . -158) T) ((-329 . -817) NIL) ((-329 . -814) NIL) ((-668 . -1075) T) ((-53 . -661) 97200) ((-1022 . -21) T) ((-157 . -1038) 97184) ((-151 . -1038) 97168) ((-1022 . -25) T) ((-923 . -148) 97152) ((-1173 . -125) T) ((-1252 . -158) T) ((-838 . -869) 97131) ((-1227 . -305) 97106) ((-1187 . -25) T) ((-1187 . -21) T) ((-1174 . -325) 96901) ((-1171 . -523) 96885) ((-874 . -158) T) ((-1142 . -25) T) ((-1142 . -21) T) ((-873 . -25) T) ((-873 . -21) T) ((-804 . -323) 96864) ((-35 . -37) 96848) ((-1164 . -175) 96798) ((-1160 . -632) 96760) ((-660 . -125) 96738) ((-647 . -125) T) ((-1160 . -633) 96699) ((-599 . -158) T) ((-637 . -867) 96678) ((-1051 . -813) T) ((-1051 . -816) T) ((-1051 . -678) T) ((-1051 . -743) T) ((-518 . -325) 96616) ((-478 . -443) 96586) ((-375 . -194) T) ((-238 . -547) NIL) ((-165 . -547) NIL) ((-306 . -43) 96573) ((-292 . -125) T) ((-291 . -125) T) ((-290 . -125) T) ((-289 . -125) T) ((-288 . -125) T) ((-287 . -125) T) ((-286 . -125) T) ((-226 . -125) T) ((-363 . -1065) 96550) ((-225 . -125) T) ((-223 . -125) T) ((-222 . -125) T) ((-221 . -125) T) ((-220 . -125) T) ((-378 . -678) T) ((-217 . -125) T) ((-216 . -125) T) ((-729 . -1081) 96373) ((-215 . -125) T) ((-214 . -125) T) ((-213 . -125) T) ((-212 . -125) T) ((-211 . -125) T) ((-210 . -125) T) ((-209 . -125) T) ((-208 . -125) T) ((-207 . -125) T) ((-378 . -743) T) ((-729 . -140) 96175) ((-687 . -245) 96159) ((-605 . -323) T) ((-550 . -323) T) ((-310 . -547) 96108) ((-132 . -325) NIL) ((-77 . -421) T) ((-1132 . -125) 95898) ((-855 . -437) 95882) ((-1137 . -817) T) ((-1137 . -814) T) ((-717 . -1119) T) ((-53 . -678) T) ((-405 . -388) T) ((-191 . -526) 95860) ((-234 . -632) 95827) ((-160 . -1119) T) ((-145 . -1119) T) ((-53 . -743) T) ((-1072 . -523) 95792) ((-163 . -451) 95774) ((-163 . -394) T) ((-1055 . -125) T) ((-545 . -542) 95753) ((-505 . -125) T) ((-492 . -125) T) ((-1062 . -1131) T) ((-761 . -1255) 95737) ((-1189 . -40) 95703) ((-1189 . -116) 95669) ((-1189 . -1214) 95635) ((-1189 . -1211) 95601) ((-1188 . -1211) 95567) ((-1173 . -325) NIL) ((-94 . -422) T) ((-94 . -421) T) ((-1101 . -1165) 95546) ((-1188 . -1214) 95512) ((-1188 . -116) 95478) ((-1062 . -23) T) ((-1188 . -40) 95444) ((-599 . -526) T) ((-1181 . -1211) 95410) ((-1181 . -1214) 95376) ((-1181 . -116) 95342) ((-1181 . -40) 95308) ((-386 . -1131) T) ((-384 . -1165) 95287) ((-377 . -1165) 95266) ((-365 . -1165) 95245) ((-1143 . -40) 95211) ((-1143 . -116) 95177) ((-1143 . -1214) 95143) ((-132 . -1165) T) ((-1143 . -1211) 95109) ((-855 . -1082) 95088) ((-660 . -325) 95026) ((-647 . -325) 94877) ((-1101 . -43) 94745) ((-729 . -1075) T) ((-1086 . -654) 94727) ((-1032 . -171) T) ((-980 . -654) 94675) ((-524 . -1119) T) ((-1032 . -169) NIL) ((-405 . -1131) T) ((-343 . -25) T) ((-341 . -23) T) ((-971 . -869) 94654) ((-729 . -346) 94631) ((-516 . -654) 94579) ((-45 . -1065) 94454) ((-717 . -734) 94441) ((-729 . -247) T) ((-359 . -1119) T) ((-195 . -1119) T) ((-351 . -869) T) ((-444 . -477) 94391) ((-405 . -23) T) ((-384 . -43) 94356) ((-377 . -43) 94321) ((-365 . -43) 94286) ((-85 . -466) T) ((-85 . -421) T) ((-237 . -25) T) ((-237 . -21) T) ((-856 . -1131) T) ((-132 . -43) 94236) ((-849 . -1131) T) ((-793 . -1119) T) ((-145 . -734) 94223) ((-688 . -1065) 94207) ((-631 . -125) T) ((-856 . -23) T) ((-849 . -23) T) ((-1230 . -125) T) ((-1171 . -303) 94184) ((-1132 . -325) 94122) ((-1121 . -249) 94106) ((-69 . -422) T) ((-69 . -421) T) ((-134 . -125) T) ((-45 . -403) 94083) ((-35 . -1119) T) ((-1229 . -664) 94065) ((-667 . -871) 94049) ((-1229 . -399) 94031) ((-1086 . -21) T) ((-1086 . -25) T) ((-837 . -245) 94000) ((-980 . -25) T) ((-980 . -21) T) ((-637 . -1082) T) ((-516 . -25) T) ((-516 . -21) T) ((-1055 . -325) 93938) ((-911 . -632) 93920) ((-907 . -632) 93902) ((-266 . -869) 93853) ((-265 . -869) 93804) ((-555 . -547) 93737) ((-892 . -654) 93714) ((-505 . -325) 93652) ((-492 . -325) 93590) ((-375 . -307) T) ((-1171 . -1267) 93574) ((-1156 . -632) 93536) ((-1156 . -633) 93497) ((-1154 . -125) T) ((-1027 . -1081) 93393) ((-45 . -922) 93345) ((-1171 . -625) 93322) ((-760 . -661) 93246) ((-1306 . -661) 93233) ((-1087 . -175) 93179) ((-893 . -1235) T) ((-1027 . -140) 93054) ((-359 . -734) 93038) ((-880 . -632) 93020) ((-195 . -734) 92952) ((-433 . -303) 92910) ((-893 . -582) T) ((-132 . -426) 92892) ((-89 . -410) T) ((-89 . -421) T) ((-887 . -943) T) ((-882 . -943) T) ((-717 . -194) T) ((-121 . -743) T) ((-517 . -125) 92682) ((-121 . -502) T) ((-145 . -194) T) ((-1132 . -43) 92652) ((-191 . -654) 92600) ((-238 . -523) 92582) ((-165 . -523) 92557) ((-1079 . -125) T) ((-892 . -25) T) ((-837 . -252) 92536) ((-892 . -21) T) ((-840 . -125) T) ((-1230 . -325) NIL) ((-440 . -125) T) ((-411 . -125) T) ((-134 . -325) NIL) ((-241 . -125) 92514) ((-157 . -1225) T) ((-151 . -1225) T) ((-1231 . -1225) T) ((-1062 . -158) T) ((-687 . -392) 92498) ((-1275 . -661) 92423) ((-1306 . -743) T) ((-1271 . -169) 92402) ((-1271 . -171) 92381) ((-1027 . -1075) T) ((-1264 . -171) 92360) ((-1252 . -654) 92308) ((-1123 . -632) 92290) ((-1031 . -632) 92272) ((-760 . -678) 92251) ((-548 . -23) T) ((-543 . -23) T) ((-363 . -323) T) ((-541 . -23) T) ((-341 . -158) T) ((-3 . -1119) T) ((-1031 . -633) 92235) ((-1027 . -260) 92214) ((-1027 . -247) 92193) ((-1264 . -169) 92172) ((-1263 . -1235) 92151) ((-855 . -1119) T) ((-1243 . -169) 92058) ((-1243 . -171) 91965) ((-1242 . -1235) 91944) ((-1237 . -169) 91923) ((-1237 . -171) 91902) ((-760 . -502) 91881) ((-760 . -743) T) ((-405 . -158) T) ((-592 . -908) 91863) ((0 . -1119) T) ((-195 . -194) T) ((-191 . -21) T) ((-191 . -25) T) ((-54 . -1119) T) ((-1265 . -661) 91752) ((-1263 . -582) 91703) ((-731 . -1131) T) ((-1242 . -582) 91654) ((-592 . -1065) 91636) ((-617 . -171) 91615) ((-617 . -169) 91594) ((-528 . -1065) 91537) ((-92 . -410) T) ((-92 . -421) T) ((-893 . -388) T) ((-1185 . -52) 91514) ((-856 . -158) T) ((-849 . -158) T) ((-731 . -23) T) ((-535 . -632) 91496) ((-1302 . -1082) T) ((-405 . -1084) T) ((-1054 . -1119) 91474) ((-923 . -39) T) ((-517 . -325) 91412) ((-1171 . -633) 91373) ((-1171 . -632) 91340) ((-281 . -39) T) ((-1187 . -869) 91319) ((-50 . -125) T) ((-1142 . -869) 91298) ((-839 . -125) T) ((-1252 . -25) T) ((-1252 . -21) T) ((-874 . -25) T) ((-49 . -392) 91282) ((-874 . -21) T) ((-748 . -477) 91233) ((-1301 . -632) 91215) ((-599 . -25) T) ((-599 . -21) T) ((-416 . -1119) T) ((-1079 . -325) 91153) ((-637 . -1119) T) ((-715 . -908) 91135) ((-1280 . -1225) T) ((-241 . -325) 91073) ((-168 . -394) T) ((-1072 . -633) 91015) ((-1072 . -632) 90958) ((-884 . -1235) T) ((-329 . -931) NIL) ((-801 . -1235) T) ((-1275 . -743) T) ((-715 . -1065) 90903) ((-728 . -943) T) ((-503 . -1235) 90882) ((-1188 . -477) 90861) ((-1181 . -477) 90840) ((-884 . -582) T) ((-350 . -125) T) ((-801 . -582) T) ((-893 . -1131) T) ((-332 . -661) 90661) ((-329 . -661) 90590) ((-503 . -582) 90541) ((-359 . -547) 90507) ((-575 . -175) 90457) ((-45 . -323) T) ((-1185 . -908) NIL) ((-862 . -632) 90439) ((-717 . -307) T) ((-893 . -23) T) ((-405 . -526) T) ((-1101 . -245) 90409) ((-545 . -125) T) ((-433 . -633) 90210) ((-433 . -632) 90192) ((-278 . -632) 90174) ((-145 . -307) T) ((-1185 . -1065) 90054) ((-994 . -632) 90036) ((-1265 . -743) T) ((-1263 . -388) 90015) ((-1242 . -388) 89994) ((-1291 . -39) T) ((-146 . -1225) T) ((-132 . -245) 89976) ((-1193 . -125) T) ((-513 . -1119) T) ((-555 . -523) 89960) ((-761 . -125) T) ((-754 . -39) T) ((-517 . -43) 89930) ((-163 . -39) T) ((-146 . -906) 89907) ((-146 . -908) NIL) ((-639 . -1065) 89790) ((-658 . -869) 89769) ((-1290 . -125) T) ((-311 . -125) T) ((-729 . -394) 89748) ((-146 . -1065) 89725) ((-416 . -734) 89709) ((-1185 . -403) 89693) ((-637 . -734) 89677) ((-50 . -325) 89481) ((-838 . -169) 89460) ((-838 . -171) 89439) ((-1301 . -408) 89418) ((-841 . -869) T) ((-1282 . -1119) T) ((-1271 . -40) 89384) ((-1271 . -116) 89350) ((-1271 . -1214) 89316) ((-1271 . -1211) 89282) ((-1264 . -1211) 89248) ((-1174 . -243) 89195) ((-1264 . -1214) 89161) ((-412 . -869) 89140) ((-1264 . -116) 89106) ((-1264 . -40) 89072) ((-1263 . -1131) T) ((-238 . -704) 89040) ((-165 . -704) 89001) ((-1243 . -1211) 88967) ((-1243 . -1214) 88933) ((-1243 . -116) 88899) ((-548 . -158) T) ((-1243 . -40) 88865) ((-1237 . -1214) 88831) ((-1237 . -1211) 88797) ((-1242 . -1131) T) ((-1237 . -40) 88763) ((-650 . -632) 88732) ((-626 . -632) 88701) ((-33 . -125) T) ((-237 . -869) T) ((-332 . -678) 88680) ((-329 . -678) T) ((-1237 . -116) 88646) ((-1137 . -661) 88633) ((-1185 . -922) 88576) ((-1101 . -373) 88555) ((-615 . -175) 88537) ((-891 . -323) T) ((-195 . -307) T) ((-146 . -403) 88514) ((-146 . -358) 88491) ((-884 . -388) T) ((-801 . -388) T) ((-329 . -816) NIL) ((-329 . -813) NIL) ((-332 . -743) 88340) ((-329 . -743) T) ((-537 . -632) 88322) ((-503 . -388) 88301) ((-384 . -373) 88280) ((-377 . -373) 88259) ((-365 . -373) 88238) ((-332 . -502) 88217) ((-1263 . -23) T) ((-1242 . -23) T) ((-735 . -1131) T) ((-731 . -158) T) ((-667 . -125) T) ((-513 . -734) 88182) ((-50 . -299) 88132) ((-129 . -1119) T) ((-73 . -632) 88114) ((-879 . -125) T) ((-639 . -922) 88073) ((-1302 . -1119) T) ((-407 . -1119) T) ((-1229 . -39) T) ((-1227 . -664) 88055) ((-1227 . -399) 88037) ((-87 . -1225) T) ((-1086 . -869) T) ((-980 . -869) 88016) ((-146 . -922) NIL) ((-804 . -943) 87995) ((-730 . -869) T) ((-558 . -1119) T) ((-533 . -1119) T) ((-379 . -1235) T) ((-376 . -1235) T) ((-364 . -1235) T) ((-279 . -1235) 87974) ((-264 . -1235) 87953) ((-1132 . -245) 87922) ((-516 . -869) 87901) ((-1173 . -850) T) ((-1156 . -1081) 87885) ((-416 . -780) T) ((-761 . -325) 87872) ((-710 . -1225) T) ((-379 . -582) T) ((-376 . -582) T) ((-364 . -582) T) ((-279 . -582) 87803) ((-264 . -582) 87734) ((-1156 . -140) 87713) ((-478 . -763) 87683) ((-880 . -1081) 87653) ((-839 . -43) 87590) ((-710 . -906) 87572) ((-710 . -908) 87554) ((-311 . -325) 87358) ((-932 . -1235) T) ((-884 . -1131) T) ((-880 . -140) 87323) ((-687 . -437) 87307) ((-801 . -1131) T) ((-710 . -1065) 87252) ((-1171 . -305) 87229) ((-1032 . -477) T) ((-932 . -582) T) ((-605 . -943) T) ((-503 . -1131) T) ((-550 . -943) T) ((-937 . -477) T) ((-238 . -632) 87211) ((-165 . -632) 87193) ((-70 . -632) 87175) ((-1137 . -678) T) ((-884 . -23) T) ((-647 . -243) 87121) ((-801 . -23) T) ((-503 . -23) T) ((-1137 . -816) T) ((-893 . -158) T) ((-1137 . -813) T) ((-1293 . -1295) 87100) ((-1137 . -743) T) ((-668 . -661) 87074) ((-310 . -632) 86815) ((-1063 . -39) T) ((-837 . -867) 86794) ((-604 . -323) T) ((-592 . -323) T) ((-528 . -323) T) ((-1302 . -734) 86764) ((-710 . -403) 86746) ((-710 . -358) 86728) ((-513 . -194) T) ((-407 . -734) 86698) ((-761 . -1165) 86676) ((-892 . -869) NIL) ((-592 . -1049) T) ((-528 . -1049) T) ((-1150 . -632) 86658) ((-1132 . -252) 86637) ((-227 . -125) T) ((-1164 . -125) T) ((-76 . -632) 86619) ((-1156 . -1075) T) ((-1193 . -43) 86516) ((-876 . -632) 86498) ((-592 . -574) T) ((-761 . -43) 86327) ((-687 . -1082) T) ((-748 . -977) 86280) ((-1156 . -247) 86259) ((-1103 . -1119) T) ((-1062 . -25) T) ((-1062 . -21) T) ((-1031 . -1081) 86204) ((-927 . -125) T) ((-880 . -1075) T) ((-797 . -1131) T) ((-710 . -922) NIL) ((-379 . -349) 86188) ((-379 . -388) T) ((-376 . -349) 86172) ((-376 . -388) T) ((-364 . -349) 86156) ((-364 . -388) T) ((-521 . -125) T) ((-1290 . -43) 86126) ((-555 . -704) 86076) ((-230 . -125) T) ((-1051 . -1065) 85956) ((-1031 . -140) 85873) ((-1189 . -1002) 85842) ((-1188 . -1002) 85804) ((-552 . -175) 85788) ((-1101 . -396) 85767) ((-375 . -632) 85749) ((-341 . -21) T) ((-378 . -1065) 85726) ((-341 . -25) T) ((-1181 . -1002) 85695) ((-1143 . -1002) 85662) ((-81 . -632) 85644) ((-715 . -323) T) ((-191 . -869) 85623) ((-932 . -388) T) ((-405 . -25) T) ((-405 . -21) T) ((-932 . -349) 85610) ((-91 . -632) 85592) ((-715 . -1049) T) ((-693 . -869) T) ((-1263 . -158) T) ((-1242 . -158) T) ((-923 . -1038) 85576) ((-856 . -21) T) ((-53 . -1065) 85519) ((-856 . -25) T) ((-849 . -25) T) ((-849 . -21) T) ((-1300 . -1082) T) ((-1298 . -1082) T) ((-668 . -743) T) ((-1185 . -323) 85498) ((-281 . -1038) 85482) ((-1301 . -1081) 85466) ((-1252 . -869) 85445) ((-837 . -437) 85414) ((-126 . -148) 85398) ((-57 . -1119) T) ((-953 . -632) 85380) ((-892 . -1021) 85357) ((-845 . -125) T) ((-1301 . -140) 85336) ((-667 . -43) 85306) ((-599 . -869) T) ((-379 . -1131) T) ((-376 . -1131) T) ((-364 . -1131) T) ((-279 . -1131) T) ((-264 . -1131) T) ((-639 . -323) 85285) ((-1164 . -325) 85089) ((-681 . -23) T) ((-517 . -245) 85058) ((-176 . -1082) T) ((-379 . -23) T) ((-376 . -23) T) ((-364 . -23) T) ((-146 . -323) T) ((-279 . -23) T) ((-264 . -23) T) ((-1031 . -1075) T) ((-729 . -931) 85037) ((-1031 . -247) 85009) ((-1031 . -260) T) ((-146 . -1049) NIL) ((-932 . -1131) T) ((-1264 . -477) 84988) ((-1243 . -477) 84967) ((-555 . -632) 84934) ((-729 . -661) 84859) ((-433 . -1081) 84811) ((-884 . -158) T) ((-538 . -632) 84793) ((-932 . -23) T) ((-801 . -158) T) ((-521 . -325) NIL) ((-503 . -158) T) ((-230 . -325) NIL) ((-433 . -140) 84724) ((-837 . -1082) 84654) ((-754 . -1116) 84638) ((-1263 . -526) 84604) ((-1242 . -526) 84570) ((-163 . -1116) 84552) ((-513 . -307) T) ((-1301 . -1075) T) ((-1087 . -125) T) ((-533 . -547) NIL) ((-719 . -125) T) ((-517 . -252) 84531) ((-1187 . -169) 84510) ((-1187 . -171) 84489) ((-1142 . -171) 84468) ((-1142 . -169) 84447) ((-650 . -1081) 84431) ((-626 . -1081) 84415) ((-1189 . -1270) 84399) ((-687 . -1119) T) ((-687 . -1078) 84339) ((-1189 . -1257) 84316) ((-1188 . -1262) 84277) ((-521 . -1165) T) ((-1188 . -1257) 84247) ((-1188 . -1260) 84231) ((-1181 . -1241) 84192) ((-230 . -1165) T) ((-363 . -943) T) ((-840 . -284) 84176) ((-650 . -140) 84155) ((-626 . -140) 84134) ((-1181 . -1257) 84111) ((-862 . -1075) 84090) ((-1181 . -1239) 84074) ((-548 . -25) T) ((-528 . -318) T) ((-544 . -23) T) ((-543 . -25) T) ((-541 . -25) T) ((-540 . -23) T) ((-729 . -678) 84005) ((-433 . -1075) T) ((-336 . -1082) T) ((-710 . -323) T) ((-132 . -867) T) ((-433 . -260) T) ((-433 . -247) 83984) ((-729 . -743) T) ((-521 . -43) 83934) ((-230 . -43) 83884) ((-503 . -526) 83850) ((-1173 . -1158) T) ((-1120 . -125) T) ((-717 . -632) 83832) ((-717 . -633) 83747) ((-731 . -21) T) ((-731 . -25) T) ((-160 . -632) 83729) ((-145 . -632) 83711) ((-179 . -25) T) ((-1300 . -1119) T) ((-893 . -654) 83659) ((-1298 . -1119) T) ((-992 . -125) T) ((-752 . -125) T) ((-732 . -125) T) ((-478 . -125) T) ((-1227 . -39) T) ((-838 . -477) 83610) ((-49 . -1119) T) ((-1108 . -869) T) ((-681 . -158) T) ((-1087 . -325) 83461) ((-687 . -734) 83445) ((-306 . -1082) T) ((-379 . -158) T) ((-376 . -158) T) ((-364 . -158) T) ((-279 . -158) T) ((-264 . -158) T) ((-760 . -1225) T) ((-444 . -125) T) ((-1275 . -52) 83422) ((-176 . -1119) T) ((-50 . -243) 83372) ((-761 . -245) 83356) ((-1027 . -661) 83294) ((-986 . -869) 83273) ((-760 . -906) 83257) ((-760 . -908) 83182) ((-254 . -1287) 83152) ((-1051 . -323) T) ((-310 . -1081) 83073) ((-932 . -158) T) ((-45 . -943) T) ((-760 . -1065) 82795) ((-521 . -426) 82777) ((-524 . -632) 82759) ((-378 . -323) T) ((-230 . -426) 82741) ((-1101 . -437) 82725) ((-310 . -140) 82641) ((-887 . -1235) T) ((-882 . -1235) T) ((-893 . -25) T) ((-893 . -21) T) ((-887 . -582) T) ((-882 . -582) T) ((-359 . -632) 82623) ((-1265 . -52) 82567) ((-237 . -171) T) ((-195 . -632) 82549) ((-1132 . -867) 82528) ((-793 . -632) 82510) ((-627 . -249) 82457) ((-504 . -249) 82407) ((-1300 . -734) 82377) ((-53 . -323) T) ((-1298 . -734) 82347) ((-993 . -1119) T) ((-837 . -1119) 82137) ((-327 . -125) T) ((-923 . -1225) T) ((-760 . -403) 82106) ((-53 . -1049) T) ((-1242 . -654) 82014) ((-706 . -125) 81992) ((-49 . -734) 81976) ((-575 . -125) T) ((-72 . -409) T) ((-281 . -1225) T) ((-72 . -421) T) ((-35 . -632) 81958) ((-676 . -23) T) ((-687 . -780) T) ((-1223 . -1119) 81936) ((-375 . -1081) 81881) ((-691 . -1119) 81859) ((-1086 . -171) T) ((-980 . -171) 81838) ((-980 . -169) 81817) ((-821 . -125) T) ((-176 . -734) 81801) ((-516 . -171) 81780) ((-516 . -169) 81759) ((-375 . -140) 81676) ((-1101 . -1082) T) ((-341 . -869) 81655) ((-995 . -1117) T) ((-1271 . -1002) 81624) ((-1264 . -1002) 81586) ((-1243 . -1002) 81555) ((-642 . -1119) T) ((-760 . -922) 81536) ((-544 . -158) T) ((-540 . -158) T) ((-311 . -243) 81486) ((-384 . -1082) T) ((-377 . -1082) T) ((-365 . -1082) T) ((-310 . -1075) 81428) ((-1237 . -1002) 81397) ((-405 . -869) T) ((-132 . -1082) T) ((-1027 . -743) T) ((-891 . -943) T) ((-862 . -817) 81376) ((-862 . -814) 81355) ((-444 . -325) 81294) ((-497 . -125) T) ((-617 . -1002) 81263) ((-336 . -1119) T) ((-433 . -817) 81242) ((-433 . -814) 81221) ((-533 . -523) 81203) ((-1265 . -1065) 81169) ((-1263 . -21) T) ((-1263 . -25) T) ((-1242 . -21) T) ((-1242 . -25) T) ((-837 . -734) 81111) ((-1228 . -125) T) ((-887 . -388) T) ((-882 . -388) T) ((-715 . -430) T) ((-1291 . -1225) T) ((-1132 . -437) 81080) ((-1031 . -394) NIL) ((-126 . -39) T) ((-754 . -1225) T) ((-49 . -780) T) ((-615 . -125) T) ((-82 . -422) T) ((-82 . -421) T) ((-667 . -670) 81064) ((-163 . -1225) T) ((-892 . -171) T) ((-892 . -169) NIL) ((-1275 . -922) 80977) ((-375 . -1075) T) ((-75 . -409) T) ((-75 . -421) T) ((-1180 . -125) T) ((-687 . -547) 80910) ((-706 . -325) 80848) ((-992 . -43) 80745) ((-752 . -43) 80715) ((-575 . -325) 80519) ((-332 . -1225) T) ((-375 . -247) T) ((-375 . -260) T) ((-329 . -1225) T) ((-306 . -1119) T) ((-1195 . -632) 80501) ((-728 . -1235) T) ((-1171 . -664) 80485) ((-1220 . -582) 80464) ((-884 . -25) T) ((-884 . -21) T) ((-728 . -582) T) ((-332 . -906) 80448) ((-332 . -908) 80373) ((-329 . -906) 80334) ((-329 . -908) NIL) ((-821 . -325) 80299) ((-801 . -25) T) ((-336 . -734) 80140) ((-801 . -21) T) ((-343 . -342) 80117) ((-519 . -125) T) ((-503 . -25) T) ((-503 . -21) T) ((-444 . -43) 80091) ((-332 . -1065) 79754) ((-237 . -1211) T) ((-237 . -1214) T) ((-3 . -632) 79736) ((-329 . -1065) 79666) ((-887 . -1131) T) ((-2 . -1119) T) ((-2 . |RecordCategory|) T) ((-882 . -1131) T) ((-855 . -632) 79648) ((-1132 . -1082) 79578) ((-604 . -943) T) ((-592 . -842) T) ((-592 . -943) T) ((-528 . -943) T) ((-162 . -1065) 79562) ((-237 . -116) T) ((-80 . -466) T) ((-80 . -421) T) ((0 . -632) 79544) ((-191 . -171) 79523) ((-191 . -169) 79474) ((-237 . -40) T) ((-54 . -632) 79456) ((-887 . -23) T) ((-513 . -1082) T) ((-882 . -23) T) ((-521 . -245) 79438) ((-518 . -997) 79422) ((-517 . -867) 79401) ((-230 . -245) 79383) ((-86 . -466) T) ((-86 . -421) T) ((-1160 . -39) T) ((-837 . -194) 79362) ((-748 . -125) T) ((-1054 . -632) 79329) ((-533 . -303) 79304) ((-332 . -403) 79273) ((-329 . -403) 79234) ((-329 . -358) 79195) ((-1228 . -325) NIL) ((-838 . -977) 79142) ((-676 . -158) T) ((-1252 . -169) 79121) ((-1252 . -171) 79100) ((-1229 . -1225) T) ((-1189 . -125) T) ((-1188 . -125) T) ((-1181 . -125) T) ((-1174 . -1119) T) ((-1143 . -125) T) ((-234 . -39) T) ((-306 . -734) 79087) ((-1174 . -629) 79063) ((-615 . -325) NIL) ((-1271 . -1270) 79047) ((-1271 . -1257) 79024) ((-518 . -1119) 79002) ((-1264 . -1262) 78963) ((-416 . -632) 78945) ((-543 . -869) T) ((-1164 . -243) 78895) ((-1264 . -1257) 78865) ((-1264 . -1260) 78849) ((-1243 . -1241) 78810) ((-1243 . -1257) 78787) ((-1243 . -1239) 78771) ((-1237 . -1270) 78755) ((-1237 . -1257) 78732) ((-637 . -632) 78714) ((-1189 . -301) 78680) ((-715 . -943) T) ((-1188 . -301) 78646) ((-1181 . -301) 78612) ((-1143 . -301) 78578) ((-1101 . -1119) T) ((-1085 . -1119) T) ((-53 . -318) T) ((-332 . -922) 78544) ((-329 . -922) NIL) ((-1085 . -1091) 78523) ((-1137 . -908) 78505) ((-821 . -43) 78489) ((-279 . -654) 78437) ((-264 . -654) 78385) ((-717 . -1081) 78372) ((-617 . -1257) 78349) ((-1137 . -1065) 78331) ((-336 . -194) 78262) ((-384 . -1119) T) ((-377 . -1119) T) ((-365 . -1119) T) ((-533 . -19) 78244) ((-1121 . -175) 78228) ((-760 . -323) 78207) ((-132 . -1119) T) ((-145 . -1081) 78194) ((-728 . -388) T) ((-533 . -625) 78169) ((-717 . -140) 78154) ((-462 . -125) T) ((-1185 . -943) 78133) ((-50 . -1163) 78083) ((-145 . -140) 78068) ((-240 . -869) T) ((-166 . -869) 78038) ((-650 . -737) T) ((-626 . -737) T) ((-837 . -547) 77971) ((-1063 . -1225) T) ((-971 . -175) 77955) ((-552 . -125) 77905) ((-1107 . -1235) 77884) ((-804 . -1235) 77863) ((-802 . -1235) 77842) ((-67 . -1225) T) ((-513 . -632) 77794) ((-513 . -633) 77716) ((-1187 . -477) 77647) ((-1173 . -1119) T) ((-1156 . -661) 77621) ((-1107 . -582) 77552) ((-517 . -437) 77521) ((-639 . -943) 77500) ((-479 . -1235) 77479) ((-1142 . -477) 77430) ((-804 . -582) 77341) ((-424 . -632) 77323) ((-802 . -582) 77254) ((-748 . -325) 77241) ((-691 . -547) 77174) ((-681 . -25) T) ((-681 . -21) T) ((-479 . -582) 77105) ((-146 . -943) T) ((-146 . -842) NIL) ((-379 . -25) T) ((-379 . -21) T) ((-376 . -25) T) ((-376 . -21) T) ((-364 . -25) T) ((-364 . -21) T) ((-279 . -25) T) ((-279 . -21) T) ((-88 . -410) T) ((-88 . -421) T) ((-264 . -25) T) ((-264 . -21) T) ((-1282 . -632) 77087) ((-1220 . -1131) T) ((-1220 . -23) T) ((-1181 . -325) 76972) ((-1143 . -325) 76959) ((-1101 . -734) 76827) ((-880 . -661) 76787) ((-971 . -1009) 76771) ((-932 . -21) T) ((-306 . -194) T) ((-932 . -25) T) ((-893 . -869) 76722) ((-887 . -158) T) ((-728 . -1131) T) ((-728 . -23) T) ((-660 . -1119) 76700) ((-647 . -629) 76675) ((-647 . -1119) T) ((-605 . -1235) T) ((-550 . -1235) T) ((-605 . -582) T) ((-550 . -582) T) ((-384 . -734) 76627) ((-377 . -734) 76579) ((-365 . -734) 76531) ((-359 . -1081) 76515) ((-195 . -140) 76414) ((-195 . -1081) 76346) ((-132 . -734) 76296) ((-359 . -140) 76275) ((-292 . -1119) T) ((-291 . -1119) T) ((-290 . -1119) T) ((-289 . -1119) T) ((-717 . -1075) T) ((-288 . -1119) T) ((-287 . -1119) T) ((-286 . -1119) T) ((-226 . -1119) T) ((-225 . -1119) T) ((-223 . -1119) T) ((-191 . -1214) 76253) ((-191 . -1211) 76231) ((-222 . -1119) T) ((-221 . -1119) T) ((-145 . -1075) T) ((-220 . -1119) T) ((-217 . -1119) T) ((-717 . -247) T) ((-216 . -1119) T) ((-215 . -1119) T) ((-214 . -1119) T) ((-213 . -1119) T) ((-212 . -1119) T) ((-211 . -1119) T) ((-210 . -1119) T) ((-209 . -1119) T) ((-208 . -1119) T) ((-207 . -1119) T) ((-254 . -125) 76021) ((-191 . -40) 75999) ((-191 . -116) 75977) ((-882 . -158) T) ((-668 . -1065) 75873) ((-517 . -1082) 75803) ((-1156 . -39) T) ((-1132 . -1119) 75593) ((-1106 . -125) T) ((-687 . -523) 75577) ((-78 . -1225) T) ((-129 . -632) 75559) ((-1302 . -632) 75541) ((-407 . -632) 75523) ((-748 . -43) 75372) ((-599 . -1214) T) ((-599 . -1211) T) ((-558 . -632) 75354) ((-552 . -325) 75292) ((-533 . -632) 75274) ((-533 . -633) 75256) ((-1181 . -1165) NIL) ((-1055 . -1094) 75225) ((-1055 . -1119) T) ((-1032 . -125) T) ((-1000 . -125) T) ((-937 . -125) T) ((-915 . -1065) 75202) ((-1156 . -743) T) ((-1031 . -661) 75147) ((-505 . -1119) T) ((-492 . -1119) T) ((-609 . -23) T) ((-599 . -40) T) ((-599 . -116) T) ((-453 . -125) T) ((-1087 . -243) 75093) ((-1189 . -43) 74990) ((-880 . -743) T) ((-710 . -943) T) ((-544 . -25) T) ((-540 . -21) T) ((-540 . -25) T) ((-1188 . -43) 74831) ((-359 . -1075) T) ((-1181 . -43) 74627) ((-1101 . -194) T) ((-195 . -1075) T) ((-1143 . -43) 74524) ((-729 . -52) 74501) ((-384 . -194) T) ((-377 . -194) T) ((-551 . -62) 74475) ((-530 . -62) 74425) ((-375 . -1297) 74402) ((-237 . -477) T) ((-336 . -307) 74353) ((-365 . -194) T) ((-195 . -260) T) ((-1242 . -869) 74252) ((-132 . -194) T) ((-893 . -1021) 74236) ((-672 . -1131) T) ((-605 . -388) T) ((-605 . -349) 74223) ((-550 . -349) 74200) ((-550 . -388) T) ((-332 . -323) 74179) ((-329 . -323) T) ((-623 . -869) 74158) ((-1132 . -734) 74100) ((-552 . -299) 74084) ((-672 . -23) T) ((-444 . -245) 74068) ((-1226 . -125) T) ((-329 . -1049) NIL) ((-356 . -23) T) ((-258 . -23) T) ((-126 . -1038) 74052) ((-50 . -41) 74031) ((-631 . -1119) T) ((-375 . -394) T) ((-528 . -27) T) ((-254 . -325) 73969) ((-1107 . -1131) T) ((-1301 . -661) 73943) ((-804 . -1131) T) ((-802 . -1131) T) ((-479 . -1131) T) ((-1086 . -477) T) ((-1230 . -1119) T) ((-980 . -477) 73894) ((-134 . -1119) T) ((-1107 . -23) T) ((-839 . -1082) T) ((-804 . -23) T) ((-802 . -23) T) ((-516 . -477) 73845) ((-1174 . -547) 73593) ((-407 . -408) 73572) ((-1193 . -437) 73556) ((-487 . -23) T) ((-479 . -23) T) ((-761 . -437) 73540) ((-760 . -318) T) ((-518 . -547) 73473) ((-1031 . -678) T) ((-306 . -307) T) ((-1103 . -632) 73455) ((-433 . -931) 73434) ((-55 . -1131) T) ((-1051 . -943) T) ((-1031 . -743) T) ((-729 . -908) NIL) ((-605 . -1131) T) ((-550 . -1131) T) ((-862 . -661) 73407) ((-1220 . -158) T) ((-1181 . -426) 73359) ((-1032 . -325) NIL) ((-837 . -523) 73343) ((-378 . -943) T) ((-1171 . -39) T) ((-433 . -661) 73295) ((-55 . -23) T) ((-728 . -158) T) ((-729 . -1065) 73175) ((-605 . -23) T) ((-132 . -547) NIL) ((-550 . -23) T) ((-191 . -435) 73146) ((-237 . -1153) T) ((-1154 . -1119) T) ((-1293 . -1292) 73130) ((-717 . -817) T) ((-717 . -814) T) ((-405 . -171) T) ((-1137 . -323) T) ((-1242 . -1021) 73100) ((-53 . -943) T) ((-691 . -523) 73084) ((-266 . -1287) 73054) ((-265 . -1287) 73024) ((-1191 . -869) T) ((-1132 . -194) 73003) ((-1137 . -1049) T) ((-1072 . -39) T) ((-856 . -171) 72982) ((-856 . -169) 72961) ((-754 . -131) 72945) ((-631 . -159) T) ((-517 . -1119) 72735) ((-1193 . -1082) T) ((-892 . -477) T) ((-90 . -1225) T) ((-254 . -43) 72705) ((-163 . -131) 72687) ((-950 . -1117) T) ((-729 . -403) 72671) ((-761 . -1082) T) ((-1137 . -574) T) ((-1226 . -325) NIL) ((-416 . -1081) 72655) ((-1301 . -743) T) ((-1290 . -1082) T) ((-1187 . -977) 72624) ((-57 . -632) 72606) ((-1142 . -977) 72573) ((-667 . -437) 72557) ((-1271 . -125) T) ((-1264 . -125) T) ((-637 . -1081) 72541) ((-676 . -25) T) ((-676 . -21) T) ((-1173 . -547) NIL) ((-1243 . -125) T) ((-1227 . -1225) T) ((-416 . -140) 72520) ((-234 . -269) 72504) ((-1237 . -125) T) ((-1079 . -1119) T) ((-1032 . -1165) T) ((-1079 . -1078) 72444) ((-840 . -1119) T) ((-363 . -1235) T) ((-650 . -661) 72428) ((-637 . -140) 72407) ((-626 . -661) 72391) ((-618 . -125) T) ((-609 . -158) T) ((-617 . -125) T) ((-440 . -1119) T) ((-411 . -1119) T) ((-241 . -1119) 72369) ((-660 . -547) 72302) ((-647 . -547) 72110) ((-855 . -1075) 72089) ((-658 . -175) 72073) ((-363 . -582) T) ((-729 . -922) 72016) ((-575 . -243) 71966) ((-1271 . -301) 71932) ((-1264 . -301) 71898) ((-1243 . -301) 71864) ((-1101 . -307) 71815) ((-521 . -867) T) ((-235 . -1131) T) ((-1237 . -301) 71781) ((-1220 . -526) 71747) ((-1032 . -43) 71697) ((-230 . -867) T) ((-433 . -678) T) ((-937 . -43) 71649) ((-862 . -816) 71628) ((-862 . -813) 71607) ((-862 . -743) 71586) ((-384 . -307) T) ((-377 . -307) T) ((-365 . -307) T) ((-191 . -477) 71517) ((-453 . -43) 71501) ((-132 . -307) T) ((-235 . -23) T) ((-433 . -816) 71480) ((-433 . -813) 71459) ((-433 . -743) T) ((-533 . -305) 71434) ((-513 . -1081) 71399) ((-672 . -158) T) ((-1132 . -547) 71332) ((-356 . -158) T) ((-191 . -428) 71311) ((-258 . -158) T) ((-517 . -734) 71253) ((-837 . -303) 71230) ((-513 . -140) 71179) ((-33 . -37) 71163) ((-667 . -1082) T) ((-1252 . -477) 71094) ((-1107 . -158) T) ((-279 . -869) 71073) ((-264 . -869) 71052) ((-804 . -158) T) ((-802 . -158) T) ((-599 . -477) T) ((-1079 . -734) 70994) ((-637 . -1075) T) ((-1055 . -547) 70927) ((-487 . -158) T) ((-479 . -158) T) ((-50 . -1119) T) ((-411 . -734) 70897) ((-839 . -1119) T) ((-505 . -547) 70830) ((-492 . -547) 70763) ((-478 . -392) 70733) ((-50 . -629) 70712) ((-332 . -318) T) ((-687 . -632) 70674) ((-64 . -869) 70653) ((-1243 . -325) 70538) ((-1032 . -426) 70520) ((-837 . -625) 70497) ((-549 . -869) 70476) ((-529 . -869) 70455) ((-45 . -1235) T) ((-1027 . -1065) 70351) ((-55 . -158) T) ((-605 . -158) T) ((-550 . -158) T) ((-310 . -661) 70211) ((-363 . -349) 70188) ((-363 . -388) T) ((-341 . -342) 70165) ((-336 . -303) 70150) ((-45 . -582) T) ((-405 . -1211) T) ((-405 . -1214) T) ((-1063 . -1202) 70125) ((-1199 . -249) 70075) ((-1181 . -245) 70027) ((-1063 . -131) 69973) ((-350 . -1119) T) ((-405 . -116) T) ((-405 . -40) T) ((-887 . -21) T) ((-887 . -25) T) ((-882 . -25) T) ((-513 . -1075) T) ((-562 . -560) 69917) ((-882 . -21) T) ((-514 . -249) 69867) ((-1174 . -523) 69801) ((-1302 . -1081) 69785) ((-407 . -1081) 69769) ((-513 . -260) T) ((-838 . -125) T) ((-731 . -171) 69748) ((-731 . -169) 69727) ((-518 . -523) 69711) ((-1302 . -140) 69690) ((-519 . -355) 69659) ((-1027 . -403) 69643) ((-545 . -1119) T) ((-517 . -194) 69622) ((-1027 . -358) 69606) ((-439 . -125) T) ((-407 . -140) 69585) ((-297 . -1012) 69569) ((-296 . -1012) 69553) ((-238 . -39) T) ((-165 . -39) T) ((-1230 . -547) NIL) ((-1300 . -632) 69535) ((-1298 . -632) 69517) ((-134 . -547) NIL) ((-1187 . -1255) 69501) ((-873 . -871) 69485) ((-1193 . -1119) T) ((-126 . -1225) T) ((-980 . -977) 69446) ((-761 . -1119) T) ((-839 . -734) 69383) ((-1243 . -1165) NIL) ((-516 . -977) 69328) ((-1086 . -167) T) ((-65 . -125) 69306) ((-49 . -632) 69288) ((-83 . -632) 69270) ((-375 . -661) 69215) ((-1290 . -1119) T) ((-544 . -869) T) ((-363 . -1131) T) ((-311 . -1119) T) ((-1027 . -922) 69174) ((-311 . -629) 69153) ((-1271 . -43) 69050) ((-1264 . -43) 68891) ((-561 . -1117) T) ((-1243 . -43) 68687) ((-521 . -1082) T) ((-1237 . -43) 68584) ((-230 . -1082) T) ((-363 . -23) T) ((-176 . -632) 68566) ((-855 . -817) 68545) ((-855 . -814) 68524) ((-760 . -943) 68503) ((-618 . -43) 68476) ((-617 . -43) 68373) ((-891 . -582) T) ((-235 . -158) T) ((-336 . -1030) 68339) ((-84 . -632) 68321) ((-729 . -323) 68300) ((-310 . -743) 68202) ((-846 . -125) T) ((-879 . -863) T) ((-310 . -502) 68181) ((-1293 . -125) T) ((-45 . -388) T) ((-893 . -171) 68160) ((-33 . -1119) T) ((-893 . -169) 68139) ((-1173 . -523) 68121) ((-1302 . -1075) T) ((-517 . -547) 68054) ((-1160 . -1225) T) ((-993 . -632) 68036) ((-660 . -523) 68020) ((-647 . -523) 67952) ((-837 . -632) 67710) ((-53 . -27) T) ((-1193 . -734) 67607) ((-667 . -1119) T) ((-462 . -389) 67581) ((-761 . -734) 67410) ((-1121 . -125) T) ((-838 . -325) 67397) ((-879 . -1119) T) ((-1298 . -408) 67369) ((-1079 . -547) 67302) ((-1174 . -303) 67278) ((-254 . -245) 67247) ((-1290 . -734) 67217) ((-839 . -194) 67196) ((-375 . -678) T) ((-241 . -547) 67129) ((-637 . -817) 67108) ((-637 . -814) 67087) ((-1223 . -632) 67034) ((-234 . -1225) T) ((-691 . -632) 67001) ((-1171 . -1038) 66985) ((-375 . -743) T) ((-971 . -125) 66935) ((-1243 . -426) 66887) ((-1132 . -523) 66871) ((-65 . -325) 66809) ((-351 . -125) T) ((-1220 . -21) T) ((-1220 . -25) T) ((-45 . -1131) T) ((-728 . -21) T) ((-642 . -632) 66791) ((-548 . -342) 66770) ((-728 . -25) T) ((-132 . -303) NIL) ((-944 . -1131) T) ((-45 . -23) T) ((-790 . -1131) T) ((-592 . -1235) T) ((-528 . -1235) T) ((-336 . -632) 66752) ((-1032 . -245) 66734) ((-191 . -188) 66718) ((-604 . -582) T) ((-592 . -582) T) ((-528 . -582) T) ((-790 . -23) T) ((-1263 . -171) 66697) ((-1174 . -625) 66673) ((-1263 . -169) 66652) ((-1055 . -523) 66636) ((-1242 . -169) 66561) ((-1242 . -171) 66486) ((-1293 . -1299) 66465) ((-505 . -523) 66449) ((-492 . -523) 66433) ((-555 . -39) T) ((-667 . -734) 66403) ((-676 . -869) 66382) ((-1193 . -194) 66333) ((-390 . -125) T) ((-254 . -252) 66312) ((-266 . -125) T) ((-265 . -125) T) ((-1252 . -977) 66281) ((-133 . -125) T) ((-262 . -869) 66260) ((-838 . -43) 66109) ((-761 . -194) 66000) ((-50 . -547) 65760) ((-1173 . -303) 65735) ((-227 . -1119) T) ((-1164 . -1119) T) ((-948 . -125) T) ((-1164 . -629) 65714) ((-609 . -25) T) ((-609 . -21) T) ((-1121 . -325) 65652) ((-992 . -437) 65636) ((-715 . -1235) T) ((-647 . -303) 65611) ((-1107 . -654) 65559) ((-804 . -654) 65507) ((-802 . -654) 65455) ((-363 . -158) T) ((-306 . -632) 65437) ((-948 . -947) 65409) ((-715 . -582) T) ((-927 . -1119) T) ((-891 . -1131) T) ((-479 . -654) 65357) ((-927 . -925) 65341) ((-884 . -883) T) ((-884 . -885) T) ((-971 . -325) 65279) ((-405 . -477) T) ((-891 . -23) T) ((-521 . -1119) T) ((-884 . -169) T) ((-717 . -661) 65266) ((-884 . -171) 65245) ((-230 . -1119) T) ((-332 . -943) 65224) ((-329 . -943) T) ((-329 . -842) NIL) ((-416 . -737) T) ((-801 . -169) 65203) ((-801 . -171) 65182) ((-1230 . -523) 65164) ((-145 . -661) 65151) ((-503 . -169) 65130) ((-444 . -437) 65114) ((-503 . -171) 65093) ((-134 . -523) 65075) ((-1185 . -1235) 65054) ((-2 . -632) 65036) ((-1173 . -19) 65018) ((-1185 . -582) 64929) ((-1173 . -625) 64904) ((-672 . -21) T) ((-672 . -25) T) ((-615 . -1158) T) ((-1132 . -303) 64881) ((-356 . -25) T) ((-356 . -21) T) ((-258 . -25) T) ((-258 . -21) T) ((-528 . -388) T) ((-1293 . -43) 64851) ((-1156 . -1225) T) ((-647 . -625) 64826) ((-1107 . -25) T) ((-1107 . -21) T) ((-992 . -1082) T) ((-761 . -547) 64772) ((-558 . -814) T) ((-558 . -817) T) ((-146 . -1235) T) ((-255 . -125) T) ((-639 . -582) T) ((-804 . -25) T) ((-804 . -21) T) ((-802 . -21) T) ((-802 . -25) T) ((-752 . -1082) T) ((-732 . -1082) T) ((-687 . -1081) 64756) ((-487 . -25) T) ((-146 . -582) T) ((-487 . -21) T) ((-479 . -25) T) ((-479 . -21) T) ((-1156 . -1065) 64652) ((-839 . -307) 64631) ((-760 . -456) 64615) ((-845 . -1119) T) ((-1300 . -1081) 64599) ((-1298 . -1081) 64583) ((-687 . -140) 64562) ((-311 . -547) 64322) ((-1263 . -1211) 64288) ((-1263 . -1214) 64254) ((-1246 . -125) 64232) ((-266 . -325) 64170) ((-265 . -325) 64108) ((-1243 . -245) 64060) ((-1174 . -633) NIL) ((-1174 . -632) 64042) ((-1242 . -1211) 64008) ((-1242 . -1214) 63974) ((-1156 . -403) 63958) ((-1137 . -842) T) ((-1137 . -943) T) ((-1132 . -625) 63935) ((-1101 . -633) 63919) ((-1101 . -632) 63901) ((-1085 . -632) 63883) ((-562 . -125) T) ((-518 . -632) 63850) ((-837 . -305) 63827) ((-627 . -175) 63774) ((-444 . -1082) T) ((-521 . -734) 63724) ((-517 . -523) 63708) ((-347 . -869) 63687) ((-359 . -661) 63661) ((-55 . -21) T) ((-55 . -25) T) ((-230 . -734) 63611) ((-191 . -741) 63582) ((-195 . -661) 63514) ((-605 . -21) T) ((-605 . -25) T) ((-550 . -25) T) ((-550 . -21) T) ((-504 . -175) 63464) ((-717 . -678) T) ((-1022 . -125) T) ((-877 . -125) T) ((-821 . -437) 63427) ((-45 . -158) T) ((-226 . -917) T) ((-715 . -388) T) ((-717 . -816) T) ((-717 . -813) T) ((-604 . -1131) T) ((-592 . -1131) T) ((-145 . -678) T) ((-528 . -1131) T) ((-717 . -743) T) ((-384 . -632) 63409) ((-377 . -632) 63391) ((-365 . -632) 63373) ((-71 . -422) T) ((-71 . -421) T) ((-132 . -633) 63303) ((-132 . -632) 63285) ((-225 . -917) T) ((-986 . -175) 63269) ((-1263 . -116) 63235) ((-790 . -158) T) ((-160 . -743) T) ((-145 . -743) T) ((-1263 . -40) 63201) ((-1079 . -523) 63185) ((-604 . -23) T) ((-592 . -23) T) ((-528 . -23) T) ((-1242 . -116) 63151) ((-1242 . -40) 63117) ((-1187 . -125) T) ((-1142 . -125) T) ((-873 . -125) T) ((-241 . -523) 63101) ((-1300 . -140) 63080) ((-1298 . -140) 63059) ((-49 . -1081) 63043) ((-1252 . -1255) 63027) ((-874 . -871) 63011) ((-1193 . -307) 62990) ((-134 . -303) 62965) ((-1156 . -922) 62924) ((-49 . -140) 62903) ((-761 . -307) 62814) ((-1300 . -1075) T) ((-687 . -1075) T) ((-1181 . -867) NIL) ((-1173 . -633) NIL) ((-1173 . -632) 62796) ((-1087 . -629) 62771) ((-1087 . -1119) T) ((-79 . -466) T) ((-79 . -421) T) ((-687 . -247) 62750) ((-176 . -1081) 62734) ((-599 . -579) 62718) ((-379 . -171) 62697) ((-379 . -169) 62648) ((-376 . -171) 62627) ((-719 . -1119) T) ((-376 . -169) 62578) ((-364 . -171) 62557) ((-364 . -169) 62508) ((-279 . -169) 62487) ((-279 . -171) 62466) ((-266 . -43) 62436) ((-264 . -171) 62415) ((-146 . -388) T) ((-264 . -169) 62394) ((-265 . -43) 62364) ((-176 . -140) 62343) ((-1031 . -1065) 62218) ((-949 . -1117) T) ((-710 . -1235) T) ((-821 . -1082) T) ((-715 . -1131) T) ((-1298 . -1075) T) ((-1185 . -1131) T) ((-1171 . -1225) T) ((-1031 . -403) 62195) ((-932 . -169) T) ((-932 . -171) 62177) ((-891 . -158) T) ((-837 . -1081) 62074) ((-715 . -23) T) ((-710 . -582) T) ((-660 . -632) 62041) ((-660 . -633) 62002) ((-647 . -633) NIL) ((-647 . -632) 61984) ((-521 . -194) T) ((-235 . -21) T) ((-195 . -678) T) ((-235 . -25) T) ((-230 . -194) T) ((-503 . -1214) 61950) ((-503 . -1211) 61916) ((-292 . -632) 61898) ((-291 . -632) 61880) ((-290 . -632) 61862) ((-289 . -632) 61844) ((-288 . -632) 61826) ((-533 . -664) 61808) ((-287 . -632) 61790) ((-359 . -743) T) ((-286 . -632) 61772) ((-134 . -19) 61754) ((-195 . -743) T) ((-533 . -399) 61736) ((-226 . -632) 61718) ((-552 . -1163) 61702) ((-533 . -153) T) ((-134 . -625) 61677) ((-225 . -632) 61659) ((-503 . -40) 61625) ((-503 . -116) 61591) ((-223 . -632) 61573) ((-222 . -632) 61555) ((-221 . -632) 61537) ((-220 . -632) 61519) ((-217 . -632) 61501) ((-216 . -632) 61483) ((-215 . -632) 61465) ((-214 . -632) 61447) ((-213 . -632) 61429) ((-212 . -632) 61411) ((-211 . -632) 61393) ((-565 . -1122) 61345) ((-210 . -632) 61327) ((-209 . -632) 61309) ((-50 . -523) 61246) ((-208 . -632) 61228) ((-207 . -632) 61210) ((-1185 . -23) T) ((-837 . -140) 61100) ((-658 . -125) 61050) ((-517 . -303) 61027) ((-1132 . -632) 60785) ((-1120 . -1119) T) ((-1072 . -1225) T) ((-639 . -1131) T) ((-1301 . -1065) 60769) ((-1187 . -325) 60756) ((-1142 . -325) 60743) ((-146 . -1131) T) ((-1230 . -704) 60709) ((-841 . -125) T) ((-639 . -23) T) ((-1164 . -547) 60469) ((-412 . -125) T) ((-343 . -125) T) ((-1031 . -922) 60421) ((-992 . -1119) T) ((-176 . -1075) T) ((-748 . -437) 60405) ((-146 . -23) T) ((-752 . -1119) T) ((-732 . -1119) T) ((-719 . -159) T) ((-478 . -1119) T) ((-332 . -456) 60389) ((-433 . -1225) T) ((-1055 . -633) 60350) ((-1055 . -632) 60312) ((-1051 . -1235) T) ((-237 . -125) T) ((-255 . -43) 60258) ((-838 . -245) 60242) ((-1051 . -582) T) ((-855 . -661) 60215) ((-378 . -1235) T) ((-505 . -632) 60177) ((-505 . -633) 60138) ((-492 . -633) 60099) ((-492 . -632) 60061) ((-433 . -906) 60045) ((-336 . -1081) 59880) ((-433 . -908) 59805) ((-862 . -1065) 59701) ((-521 . -547) NIL) ((-517 . -625) 59678) ((-378 . -582) T) ((-230 . -547) NIL) ((-893 . -477) T) ((-444 . -1119) T) ((-433 . -1065) 59542) ((-336 . -140) 59356) ((-710 . -388) T) ((-237 . -301) T) ((-53 . -1235) T) ((-837 . -1075) 59286) ((-604 . -158) T) ((-592 . -158) T) ((-528 . -158) T) ((-53 . -582) T) ((-1174 . -305) 59262) ((-1187 . -1165) 59240) ((-332 . -27) 59219) ((-1086 . -125) T) ((-837 . -247) 59171) ((-254 . -867) 59150) ((-980 . -125) T) ((-730 . -125) T) ((-311 . -523) 59087) ((-516 . -125) T) ((-748 . -1082) T) ((-631 . -632) 59069) ((-631 . -633) 58930) ((-433 . -403) 58914) ((-433 . -358) 58898) ((-1187 . -43) 58727) ((-1142 . -43) 58576) ((-873 . -43) 58546) ((-416 . -661) 58530) ((-658 . -325) 58468) ((-1230 . -632) 58450) ((-992 . -734) 58347) ((-752 . -734) 58317) ((-234 . -131) 58301) ((-50 . -303) 58226) ((-637 . -661) 58200) ((-327 . -1119) T) ((-306 . -1081) 58187) ((-134 . -632) 58169) ((-134 . -633) 58151) ((-478 . -734) 58121) ((-838 . -268) 58060) ((-706 . -1119) 58038) ((-575 . -1119) T) ((-1189 . -1082) T) ((-1188 . -1082) T) ((-306 . -140) 58023) ((-1181 . -1082) T) ((-1143 . -1082) T) ((-575 . -629) 58002) ((-1032 . -867) T) ((-241 . -704) 57960) ((-710 . -1131) T) ((-1220 . -757) 57936) ((-995 . -999) 57913) ((-336 . -1075) T) ((-363 . -25) T) ((-363 . -21) T) ((-433 . -922) 57872) ((-73 . -1225) T) ((-855 . -816) 57851) ((-444 . -734) 57825) ((-821 . -1119) T) ((-855 . -813) 57804) ((-715 . -158) T) ((-729 . -943) 57783) ((-710 . -23) T) ((-521 . -307) T) ((-855 . -743) 57762) ((-336 . -247) 57714) ((-336 . -260) 57693) ((-230 . -307) T) ((-1051 . -388) T) ((-1263 . -477) 57672) ((-1242 . -477) 57651) ((-378 . -349) 57628) ((-378 . -388) T) ((-1154 . -632) 57610) ((-50 . -1267) 57560) ((-892 . -125) T) ((-658 . -299) 57544) ((-715 . -1084) T) ((-513 . -661) 57509) ((-497 . -1119) T) ((-50 . -625) 57434) ((-1173 . -305) 57409) ((-1185 . -158) T) ((-45 . -654) 57343) ((-53 . -388) T) ((-1125 . -632) 57325) ((-1107 . -869) 57304) ((-647 . -305) 57279) ((-1228 . -1119) T) ((-980 . -325) 57266) ((-804 . -869) 57245) ((-802 . -869) 57224) ((-479 . -869) 57203) ((-517 . -632) 56961) ((-254 . -437) 56930) ((-238 . -1225) T) ((-165 . -1225) T) ((-240 . -175) 56912) ((-166 . -175) 56887) ((-70 . -1225) T) ((-761 . -303) 56814) ((-639 . -158) T) ((-516 . -325) 56801) ((-1087 . -547) 56609) ((-306 . -1075) T) ((-146 . -158) T) ((-478 . -780) T) ((-992 . -194) 56560) ((-1180 . -1119) T) ((-1132 . -305) 56537) ((-1101 . -1081) 56447) ((-637 . -816) 56426) ((-615 . -1119) T) ((-637 . -813) 56405) ((-637 . -743) T) ((-311 . -303) 56384) ((-310 . -1225) T) ((-1079 . -632) 56346) ((-1079 . -633) 56307) ((-1051 . -1131) T) ((-191 . -125) T) ((-293 . -869) T) ((-1121 . -243) 56291) ((-840 . -632) 56273) ((-1101 . -140) 56162) ((-1031 . -323) T) ((-884 . -477) T) ((-821 . -734) 56146) ((-384 . -1081) 56098) ((-378 . -1131) T) ((-377 . -1081) 56050) ((-440 . -632) 56032) ((-411 . -632) 56014) ((-365 . -1081) 55966) ((-241 . -632) 55933) ((-1051 . -23) T) ((-801 . -477) T) ((-132 . -1081) 55883) ((-920 . -125) T) ((-860 . -125) T) ((-830 . -125) T) ((-788 . -125) T) ((-693 . -125) T) ((-503 . -477) 55862) ((-444 . -194) T) ((-384 . -140) 55793) ((-377 . -140) 55724) ((-365 . -140) 55655) ((-266 . -245) 55624) ((-265 . -245) 55593) ((-378 . -23) T) ((-76 . -1225) T) ((-237 . -43) 55558) ((-132 . -140) 55485) ((-45 . -25) T) ((-45 . -21) T) ((-687 . -737) T) ((-191 . -301) 55463) ((-884 . -428) T) ((-53 . -1131) T) ((-944 . -25) T) ((-790 . -25) T) ((-1164 . -523) 55400) ((-513 . -678) T) ((-519 . -1119) T) ((-1302 . -661) 55374) ((-1252 . -125) T) ((-874 . -125) T) ((-254 . -1082) 55304) ((-1086 . -1165) T) ((-993 . -814) 55257) ((-407 . -661) 55241) ((-53 . -23) T) ((-993 . -817) 55194) ((-837 . -817) 55145) ((-837 . -814) 55096) ((-311 . -625) 55075) ((-513 . -743) T) ((-1185 . -526) 55053) ((-599 . -125) T) ((-1106 . -1082) T) ((-892 . -325) 54997) ((-667 . -303) 54976) ((-141 . -675) T) ((-81 . -1225) T) ((-1086 . -43) 54963) ((-681 . -400) 54942) ((-980 . -43) 54791) ((-748 . -1119) T) ((-516 . -43) 54640) ((-91 . -1225) T) ((-599 . -301) T) ((-1243 . -867) NIL) ((-1189 . -1119) T) ((-1188 . -1119) T) ((-1181 . -1119) T) ((-375 . -1065) 54617) ((-1101 . -1075) T) ((-1032 . -1082) T) ((-50 . -632) 54599) ((-50 . -633) NIL) ((-937 . -1082) T) ((-839 . -632) 54581) ((-1161 . -125) 54559) ((-1101 . -260) 54510) ((-453 . -1082) T) ((-384 . -1075) T) ((-377 . -1075) T) ((-390 . -389) 54487) ((-365 . -1075) T) ((-266 . -252) 54466) ((-265 . -252) 54445) ((-133 . -389) 54419) ((-1101 . -247) 54344) ((-1143 . -1119) T) ((-310 . -922) 54303) ((-132 . -1075) T) ((-760 . -1235) 54282) ((-710 . -158) T) ((-444 . -547) 54124) ((-384 . -247) 54103) ((-384 . -260) T) ((-49 . -737) T) ((-377 . -247) 54082) ((-377 . -260) T) ((-365 . -247) 54061) ((-365 . -260) T) ((-760 . -582) T) ((-191 . -325) 54026) ((-132 . -260) T) ((-132 . -247) T) ((-336 . -814) T) ((-891 . -21) T) ((-891 . -25) T) ((-433 . -323) T) ((-533 . -39) T) ((-134 . -305) 54001) ((-1132 . -1081) 53898) ((-892 . -1165) NIL) ((-887 . -886) T) ((-887 . -885) T) ((-882 . -881) T) ((-882 . -885) T) ((-882 . -886) T) ((-350 . -632) 53880) ((-433 . -1049) 53858) ((-1132 . -140) 53748) ((-887 . -169) 53718) ((-887 . -171) T) ((-882 . -171) T) ((-882 . -169) 53688) ((-462 . -1119) T) ((-1302 . -743) T) ((-68 . -632) 53670) ((-892 . -43) 53615) ((-555 . -1225) T) ((-623 . -175) 53599) ((-545 . -632) 53581) ((-1252 . -325) 53568) ((-748 . -734) 53417) ((-558 . -815) T) ((-558 . -816) T) ((-592 . -654) 53399) ((-528 . -654) 53359) ((-379 . -477) T) ((-376 . -477) T) ((-364 . -477) T) ((-279 . -477) 53310) ((-552 . -1119) 53260) ((-264 . -477) 53211) ((-1164 . -303) 53190) ((-1193 . -632) 53172) ((-706 . -547) 53105) ((-992 . -307) 53084) ((-575 . -547) 52844) ((-761 . -633) NIL) ((-761 . -632) 52826) ((-1290 . -632) 52808) ((-1187 . -245) 52792) ((-191 . -1165) 52771) ((-1275 . -582) 52750) ((-1189 . -734) 52647) ((-1188 . -734) 52488) ((-914 . -125) T) ((-1181 . -734) 52284) ((-1143 . -734) 52181) ((-1171 . -690) 52165) ((-379 . -428) 52116) ((-376 . -428) 52067) ((-364 . -428) 52018) ((-1051 . -158) T) ((-821 . -547) 51930) ((-311 . -633) NIL) ((-311 . -632) 51912) ((-932 . -477) T) ((-993 . -394) 51865) ((-837 . -394) 51844) ((-543 . -542) 51823) ((-541 . -542) 51802) ((-521 . -303) NIL) ((-517 . -305) 51779) ((-444 . -307) T) ((-378 . -158) T) ((-230 . -303) NIL) ((-710 . -526) NIL) ((-121 . -1131) T) ((-191 . -43) 51607) ((-1265 . -582) T) ((-1263 . -1002) 51569) ((-1161 . -325) 51507) ((-1242 . -1002) 51476) ((-932 . -428) T) ((-1132 . -1075) 51406) ((-1164 . -625) 51385) ((-760 . -388) 51364) ((-801 . -175) 51316) ((-141 . -869) T) ((-1087 . -523) 51248) ((-604 . -21) T) ((-604 . -25) T) ((-592 . -21) T) ((-592 . -25) T) ((-528 . -25) T) ((-528 . -21) T) ((-1252 . -1165) 51226) ((-1132 . -247) 51178) ((-53 . -158) T) ((-33 . -632) 51160) ((-996 . -1117) T) ((-1207 . -125) T) ((-254 . -1119) 50950) ((-892 . -426) 50927) ((-1108 . -125) T) ((-1097 . -125) T) ((-1228 . -547) NIL) ((-627 . -125) T) ((-504 . -125) T) ((-1252 . -43) 50756) ((-1106 . -1119) T) ((-874 . -43) 50726) ((-1185 . -654) 50674) ((-748 . -194) 50585) ((-667 . -632) 50567) ((-599 . -43) 50554) ((-986 . -125) 50504) ((-879 . -632) 50486) ((-879 . -633) 50408) ((-615 . -547) NIL) ((-1271 . -1082) T) ((-1264 . -1082) T) ((-1243 . -1082) T) ((-1237 . -1082) T) ((-1306 . -1131) T) ((-1220 . -171) 50387) ((-1189 . -194) 50338) ((-618 . -1082) T) ((-617 . -1082) T) ((-1188 . -194) 50269) ((-1181 . -194) 50200) ((-1143 . -194) 50151) ((-1032 . -1119) T) ((-1000 . -1119) T) ((-937 . -1119) T) ((-821 . -819) 50135) ((-801 . -665) 50119) ((-801 . -1002) 50088) ((-760 . -1131) T) ((-715 . -25) T) ((-715 . -21) T) ((-146 . -654) 50065) ((-717 . -908) 50047) ((-453 . -1119) T) ((-332 . -1235) 50026) ((-329 . -1235) T) ((-191 . -426) 50010) ((-1220 . -169) 49989) ((-503 . -1002) 49951) ((-77 . -632) 49933) ((-760 . -23) T) ((-132 . -817) T) ((-132 . -814) T) ((-332 . -582) 49912) ((-717 . -1065) 49894) ((-329 . -582) T) ((-1306 . -23) T) ((-160 . -1065) 49876) ((-517 . -1081) 49773) ((-50 . -305) 49698) ((-1185 . -25) T) ((-1185 . -21) T) ((-254 . -734) 49640) ((-517 . -140) 49530) ((-1111 . -125) 49508) ((-1062 . -125) T) ((-1106 . -734) 49485) ((-658 . -850) 49464) ((-1226 . -1119) T) ((-748 . -547) 49402) ((-1079 . -1081) 49386) ((-639 . -21) T) ((-639 . -25) T) ((-1087 . -303) 49361) ((-386 . -125) T) ((-341 . -125) T) ((-687 . -661) 49335) ((-411 . -1081) 49319) ((-1079 . -140) 49298) ((-838 . -437) 49282) ((-146 . -25) T) ((-94 . -632) 49264) ((-146 . -21) T) ((-627 . -325) 49059) ((-504 . -325) 48863) ((-1275 . -1131) T) ((-1164 . -633) NIL) ((-411 . -140) 48842) ((-405 . -125) T) ((-227 . -632) 48824) ((-1164 . -632) 48806) ((-1032 . -734) 48756) ((-1181 . -547) 48490) ((-937 . -734) 48442) ((-1143 . -547) 48412) ((-375 . -323) T) ((-1275 . -23) T) ((-1199 . -175) 48362) ((-986 . -325) 48300) ((-856 . -125) T) ((-453 . -734) 48284) ((-237 . -850) T) ((-849 . -125) T) ((-847 . -125) T) ((-514 . -175) 48234) ((-1263 . -1262) 48213) ((-1137 . -1235) T) ((-359 . -1065) 48180) ((-1263 . -1257) 48150) ((-1263 . -1260) 48134) ((-1242 . -1241) 48113) ((-85 . -632) 48095) ((-927 . -632) 48077) ((-1242 . -1257) 48054) ((-1137 . -582) T) ((-944 . -869) T) ((-790 . -869) T) ((-521 . -633) 47984) ((-521 . -632) 47966) ((-405 . -301) T) ((-688 . -869) T) ((-1242 . -1239) 47950) ((-1265 . -1131) T) ((-230 . -633) 47880) ((-230 . -632) 47862) ((-1087 . -625) 47837) ((-64 . -175) 47821) ((-549 . -175) 47805) ((-529 . -175) 47789) ((-384 . -1297) 47773) ((-377 . -1297) 47757) ((-365 . -1297) 47741) ((-332 . -388) 47720) ((-329 . -388) T) ((-517 . -1075) 47650) ((-710 . -654) 47632) ((-1300 . -661) 47606) ((-1298 . -661) 47580) ((-1265 . -23) T) ((-706 . -523) 47564) ((-69 . -632) 47546) ((-1132 . -817) 47497) ((-1132 . -814) 47448) ((-575 . -523) 47385) ((-687 . -39) T) ((-517 . -247) 47337) ((-311 . -305) 47316) ((-254 . -194) 47295) ((-884 . -1287) 47279) ((-838 . -1082) T) ((-49 . -661) 47237) ((-1101 . -394) 47188) ((-748 . -307) 47119) ((-552 . -547) 47052) ((-839 . -1081) 47003) ((-1107 . -169) 46982) ((-384 . -394) 46961) ((-377 . -394) 46940) ((-365 . -394) 46919) ((-1107 . -171) 46898) ((-892 . -245) 46875) ((-839 . -140) 46810) ((-804 . -169) 46789) ((-804 . -171) 46768) ((-279 . -977) 46735) ((-266 . -867) 46714) ((-264 . -977) 46659) ((-265 . -867) 46638) ((-802 . -169) 46617) ((-802 . -171) 46596) ((-176 . -661) 46570) ((-479 . -171) 46549) ((-479 . -169) 46528) ((-687 . -743) T) ((-845 . -632) 46510) ((-1271 . -1119) T) ((-1264 . -1119) T) ((-1243 . -1119) T) ((-1237 . -1119) T) ((-1220 . -1214) 46476) ((-1220 . -1211) 46442) ((-1189 . -307) 46421) ((-1188 . -307) 46372) ((-1181 . -307) 46323) ((-1143 . -307) 46302) ((-359 . -922) 46283) ((-1032 . -194) T) ((-937 . -194) T) ((-801 . -1257) 46260) ((-618 . -1119) T) ((-617 . -1119) T) ((-710 . -21) T) ((-710 . -25) T) ((-503 . -1260) 46244) ((-503 . -1257) 46214) ((-444 . -303) 46142) ((-332 . -1131) 45991) ((-329 . -1131) T) ((-1220 . -40) 45957) ((-1220 . -116) 45923) ((-89 . -632) 45905) ((-96 . -125) 45883) ((-1306 . -158) T) ((-1228 . -523) 45865) ((-760 . -158) T) ((-605 . -169) T) ((-605 . -171) 45847) ((-550 . -171) 45829) ((-550 . -169) T) ((-332 . -23) 45681) ((-45 . -362) 45655) ((-329 . -23) T) ((-1173 . -664) 45637) ((-837 . -661) 45485) ((-1293 . -1082) T) ((-1173 . -399) 45467) ((-191 . -245) 45451) ((-615 . -523) 45433) ((-254 . -547) 45366) ((-1300 . -743) T) ((-1298 . -743) T) ((-1193 . -1081) 45249) ((-761 . -1081) 45072) ((-1193 . -140) 44934) ((-839 . -1075) T) ((-761 . -140) 44736) ((-548 . -125) T) ((-53 . -654) 44696) ((-543 . -125) T) ((-541 . -125) T) ((-1290 . -1081) 44666) ((-1062 . -43) 44650) ((-839 . -247) T) ((-839 . -260) 44629) ((-575 . -303) 44608) ((-1290 . -140) 44573) ((-1252 . -245) 44557) ((-1271 . -734) 44454) ((-1264 . -734) 44295) ((-1087 . -633) NIL) ((-1087 . -632) 44277) ((-1243 . -734) 44073) ((-1237 . -734) 43970) ((-1031 . -943) T) ((-719 . -632) 43939) ((-176 . -743) T) ((-1275 . -158) T) ((-1231 . -869) T) ((-1132 . -394) 43918) ((-1032 . -547) NIL) ((-266 . -437) 43887) ((-265 . -437) 43856) ((-1051 . -25) T) ((-1051 . -21) T) ((-618 . -734) 43829) ((-617 . -734) 43726) ((-821 . -303) 43684) ((-156 . -125) 43662) ((-855 . -1065) 43558) ((-191 . -850) 43537) ((-336 . -661) 43434) ((-837 . -39) T) ((-731 . -125) T) ((-1137 . -1131) T) ((-1054 . -1225) T) ((-405 . -43) 43399) ((-378 . -25) T) ((-378 . -21) T) ((-240 . -125) T) ((-183 . -125) T) ((-179 . -125) T) ((-166 . -125) T) ((-379 . -1287) 43383) ((-376 . -1287) 43367) ((-364 . -1287) 43351) ((-887 . -477) T) ((-191 . -373) 43330) ((-592 . -869) T) ((-528 . -869) T) ((-882 . -477) T) ((-1137 . -23) T) ((-92 . -632) 43312) ((-717 . -323) T) ((-856 . -43) 43282) ((-849 . -43) 43252) ((-1265 . -158) T) ((-1164 . -305) 43231) ((-993 . -743) 43130) ((-993 . -815) 43083) ((-993 . -816) 43036) ((-837 . -813) 43015) ((-145 . -323) T) ((-96 . -325) 42953) ((-691 . -39) T) ((-575 . -625) 42932) ((-53 . -25) T) ((-53 . -21) T) ((-837 . -816) 42883) ((-837 . -815) 42862) ((-717 . -1049) T) ((-667 . -1081) 42846) ((-993 . -502) 42799) ((-837 . -743) 42709) ((-932 . -1287) 42696) ((-258 . -342) 42673) ((-887 . -428) 42643) ((-517 . -817) 42594) ((-517 . -814) 42545) ((-882 . -428) 42515) ((-1193 . -1075) T) ((-1226 . -547) NIL) ((-761 . -1075) T) ((-667 . -140) 42494) ((-1193 . -346) 42470) ((-1212 . -125) 42448) ((-1120 . -632) 42430) ((-717 . -574) T) ((-761 . -346) 42407) ((-838 . -1119) T) ((-761 . -247) T) ((-1290 . -1075) T) ((-439 . -1119) T) ((-266 . -1082) 42337) ((-265 . -1082) 42267) ((-306 . -661) 42254) ((-615 . -303) 42229) ((-706 . -704) 42187) ((-1271 . -194) 42138) ((-992 . -632) 42120) ((-893 . -125) T) ((-752 . -632) 42102) ((-732 . -632) 42084) ((-1264 . -194) 42015) ((-1243 . -194) 41946) ((-1237 . -194) 41897) ((-715 . -869) T) ((-1032 . -307) T) ((-478 . -632) 41879) ((-642 . -743) T) ((-65 . -1119) 41857) ((-262 . -175) 41841) ((-937 . -307) T) ((-1051 . -1040) T) ((-642 . -502) T) ((-729 . -1235) 41820) ((-336 . -678) 41799) ((-1275 . -526) 41765) ((-618 . -194) 41744) ((-617 . -194) 41695) ((-1280 . -869) 41674) ((-729 . -582) 41585) ((-433 . -943) T) ((-433 . -842) 41564) ((-336 . -816) T) ((-336 . -743) T) ((-444 . -632) 41546) ((-444 . -633) 41447) ((-658 . -1163) 41431) ((-134 . -664) 41413) ((-195 . -323) T) ((-156 . -325) 41351) ((-134 . -399) 41333) ((-424 . -1225) T) ((-332 . -158) 41204) ((-329 . -158) T) ((-74 . -421) T) ((-134 . -153) T) ((-1185 . -869) 41183) ((-552 . -523) 41167) ((-668 . -1131) T) ((-615 . -19) 41149) ((-240 . -325) NIL) ((-66 . -466) T) ((-166 . -325) NIL) ((-66 . -421) T) ((-846 . -1119) T) ((-615 . -625) 41124) ((-513 . -1065) 41084) ((-667 . -1075) T) ((-668 . -23) T) ((-1293 . -1119) T) ((-838 . -734) 40933) ((-1228 . -704) 40899) ((-150 . -869) T) ((-146 . -869) NIL) ((-1187 . -437) 40883) ((-1142 . -437) 40867) ((-873 . -437) 40851) ((-255 . -1082) T) ((-306 . -678) T) ((-1263 . -125) T) ((-1243 . -547) 40585) ((-1212 . -325) 40523) ((-327 . -632) 40505) ((-1242 . -125) T) ((-1121 . -1119) T) ((-1189 . -303) 40490) ((-1188 . -303) 40475) ((-306 . -743) T) ((-132 . -931) NIL) ((-706 . -632) 40442) ((-706 . -633) 40403) ((-1101 . -661) 40313) ((-622 . -632) 40295) ((-575 . -633) NIL) ((-575 . -632) 40277) ((-1181 . -303) 40125) ((-521 . -1081) 40075) ((-728 . -477) T) ((-544 . -542) 40054) ((-540 . -542) 40033) ((-230 . -1081) 39983) ((-384 . -661) 39935) ((-377 . -661) 39887) ((-237 . -867) T) ((-365 . -661) 39839) ((-623 . -125) 39789) ((-517 . -394) 39768) ((-132 . -661) 39718) ((-521 . -140) 39645) ((-254 . -523) 39629) ((-363 . -171) 39611) ((-363 . -169) T) ((-191 . -396) 39582) ((-971 . -1278) 39566) ((-230 . -140) 39493) ((-893 . -325) 39458) ((-971 . -1119) 39408) ((-821 . -633) 39369) ((-821 . -632) 39351) ((-735 . -125) T) ((-351 . -1119) T) ((-1137 . -158) T) ((-731 . -43) 39321) ((-332 . -526) 39300) ((-533 . -1225) T) ((-1263 . -301) 39266) ((-1242 . -301) 39232) ((-347 . -175) 39216) ((-1087 . -305) 39191) ((-1293 . -734) 39161) ((-1174 . -39) T) ((-1302 . -1065) 39138) ((-760 . -654) 39044) ((-497 . -632) 39026) ((-518 . -39) T) ((-407 . -1065) 39010) ((-1187 . -1082) T) ((-1142 . -1082) T) ((-873 . -1082) T) ((-1086 . -867) T) ((-838 . -194) 38921) ((-552 . -303) 38898) ((-1228 . -632) 38880) ((-1306 . -25) T) ((-1271 . -307) 38859) ((-1264 . -307) 38810) ((-146 . -1021) 38787) ((-884 . -125) T) ((-1243 . -307) 38738) ((-801 . -125) T) ((-1237 . -307) 38717) ((-1207 . -389) 38691) ((-1189 . -1030) 38657) ((-1188 . -1030) 38623) ((-1108 . -284) 38607) ((-503 . -125) T) ((-390 . -1119) T) ((-266 . -1119) T) ((-265 . -1119) T) ((-1181 . -1030) 38573) ((-133 . -1119) T) ((-1143 . -1030) 38539) ((-893 . -1165) 38517) ((-1101 . -678) 38468) ((-627 . -389) 38408) ((-1101 . -743) T) ((-627 . -243) 38355) ((-615 . -632) 38337) ((-615 . -633) NIL) ((-710 . -869) T) ((-504 . -243) 38287) ((-521 . -1075) T) ((-948 . -1119) T) ((-93 . -465) T) ((-93 . -421) T) ((-230 . -1075) T) ((-384 . -678) T) ((-34 . -1117) T) ((-377 . -678) T) ((-365 . -678) T) ((-729 . -1131) T) ((-618 . -307) 38266) ((-617 . -307) 38245) ((-132 . -678) T) ((-521 . -260) T) ((-521 . -247) T) ((-1180 . -632) 38227) ((-893 . -43) 38179) ((-230 . -260) T) ((-230 . -247) T) ((-760 . -25) T) ((-760 . -21) T) ((-384 . -743) T) ((-377 . -743) T) ((-365 . -743) T) ((-132 . -816) T) ((-132 . -813) T) ((-552 . -1267) 38163) ((-132 . -743) T) ((-729 . -23) T) ((-1226 . -523) 38145) ((-503 . -301) 38111) ((-1306 . -21) T) ((-1242 . -325) 38050) ((-1191 . -125) T) ((-45 . -169) 38022) ((-45 . -171) 37994) ((-552 . -625) 37971) ((-1132 . -661) 37819) ((-623 . -325) 37757) ((-50 . -664) 37707) ((-50 . -683) 37657) ((-50 . -399) 37607) ((-1173 . -39) T) ((-892 . -867) NIL) ((-668 . -158) T) ((-519 . -632) 37589) ((-254 . -303) 37566) ((-660 . -39) T) ((-647 . -39) T) ((-1107 . -477) 37517) ((-838 . -547) 37382) ((-804 . -477) 37313) ((-802 . -477) 37264) ((-797 . -125) T) ((-479 . -477) 37215) ((-980 . -437) 37199) ((-748 . -632) 37181) ((-266 . -734) 37123) ((-265 . -734) 37065) ((-748 . -633) 36926) ((-516 . -437) 36910) ((-359 . -318) T) ((-255 . -1119) T) ((-375 . -943) T) ((-1028 . -125) 36888) ((-1051 . -869) T) ((-65 . -547) 36821) ((-1275 . -25) T) ((-1275 . -21) T) ((-1242 . -1165) 36773) ((-1032 . -303) NIL) ((-237 . -1082) T) ((-405 . -850) T) ((-1132 . -39) T) ((-801 . -325) 36642) ((-605 . -477) T) ((-550 . -477) T) ((-1246 . -1112) 36626) ((-1246 . -1119) 36604) ((-254 . -625) 36581) ((-1246 . -1114) 36538) ((-1189 . -632) 36520) ((-1188 . -632) 36502) ((-1181 . -632) 36484) ((-1181 . -633) NIL) ((-1143 . -632) 36466) ((-893 . -426) 36450) ((-562 . -1119) T) ((-565 . -125) T) ((-1263 . -43) 36291) ((-1242 . -43) 36105) ((-891 . -171) T) ((-605 . -428) T) ((-53 . -869) T) ((-550 . -428) T) ((-1265 . -21) T) ((-1265 . -25) T) ((-1132 . -813) 36084) ((-1132 . -816) 36035) ((-1132 . -815) 36014) ((-1022 . -1119) T) ((-1055 . -39) T) ((-877 . -1119) T) ((-1276 . -125) T) ((-1132 . -743) 35924) ((-681 . -125) T) ((-575 . -305) 35903) ((-1199 . -125) T) ((-505 . -39) T) ((-492 . -39) T) ((-379 . -125) T) ((-376 . -125) T) ((-364 . -125) T) ((-279 . -125) T) ((-264 . -125) T) ((-513 . -323) T) ((-1086 . -1082) T) ((-980 . -1082) T) ((-332 . -654) 35809) ((-329 . -654) 35770) ((-516 . -1082) T) ((-514 . -125) T) ((-462 . -632) 35752) ((-1187 . -1119) T) ((-1142 . -1119) T) ((-873 . -1119) T) ((-1155 . -125) T) ((-838 . -307) 35683) ((-992 . -1081) 35566) ((-513 . -1049) T) ((-752 . -1081) 35536) ((-1161 . -1138) 35520) ((-1121 . -547) 35453) ((-995 . -125) T) ((-478 . -1081) 35423) ((-992 . -140) 35285) ((-887 . -1287) 35260) ((-882 . -1287) 35220) ((-932 . -125) T) ((-884 . -1165) T) ((-752 . -140) 35185) ((-255 . -734) 35131) ((-64 . -125) 35081) ((-552 . -633) 35042) ((-552 . -632) 34981) ((-551 . -125) 34959) ((-549 . -125) 34909) ((-530 . -125) 34887) ((-529 . -125) 34837) ((-478 . -140) 34788) ((-266 . -194) 34767) ((-265 . -194) 34746) ((-444 . -1081) 34720) ((-1220 . -1002) 34681) ((-1027 . -1131) T) ((-884 . -43) 34646) ((-801 . -43) 34584) ((-971 . -547) 34517) ((-521 . -817) T) ((-503 . -43) 34358) ((-444 . -140) 34325) ((-521 . -814) T) ((-1028 . -325) 34263) ((-230 . -817) T) ((-230 . -814) T) ((-1027 . -23) T) ((-729 . -158) T) ((-1242 . -426) 34233) ((-1230 . -39) T) ((-332 . -25) 34085) ((-191 . -437) 34069) ((-332 . -21) 33940) ((-329 . -25) T) ((-329 . -21) T) ((-879 . -394) T) ((-134 . -39) T) ((-517 . -661) 33788) ((-892 . -1082) T) ((-615 . -305) 33763) ((-604 . -171) T) ((-592 . -171) T) ((-528 . -171) T) ((-1187 . -734) 33592) ((-1142 . -734) 33441) ((-1137 . -654) 33423) ((-873 . -734) 33393) ((-687 . -1225) T) ((-1 . -125) T) ((-254 . -632) 33151) ((-1252 . -437) 33135) ((-1226 . -704) 33101) ((-1199 . -325) 32905) ((-992 . -1075) T) ((-752 . -1075) T) ((-732 . -1075) T) ((-658 . -1119) 32855) ((-1079 . -661) 32839) ((-874 . -437) 32823) ((-544 . -125) T) ((-540 . -125) T) ((-264 . -325) 32810) ((-279 . -325) 32797) ((-1106 . -632) 32779) ((-992 . -346) 32758) ((-411 . -661) 32742) ((-514 . -325) 32546) ((-266 . -547) 32479) ((-687 . -1065) 32375) ((-265 . -547) 32308) ((-1155 . -325) 32234) ((-255 . -194) 32213) ((-841 . -1119) T) ((-821 . -1081) 32197) ((-1271 . -303) 32182) ((-1264 . -303) 32167) ((-1243 . -303) 32015) ((-1237 . -303) 32000) ((-412 . -1119) T) ((-343 . -1119) T) ((-444 . -1075) T) ((-191 . -1082) T) ((-64 . -325) 31938) ((-821 . -140) 31917) ((-617 . -303) 31902) ((-551 . -325) 31840) ((-549 . -325) 31778) ((-530 . -325) 31716) ((-529 . -325) 31654) ((-444 . -247) 31633) ((-517 . -39) T) ((-1032 . -633) 31563) ((-237 . -1119) T) ((-1032 . -632) 31545) ((-1000 . -632) 31527) ((-1000 . -633) 31502) ((-937 . -632) 31484) ((-715 . -171) T) ((-717 . -943) T) ((-717 . -842) T) ((-453 . -632) 31466) ((-1137 . -21) T) ((-1137 . -25) T) ((-687 . -403) 31450) ((-145 . -943) T) ((-893 . -245) 31434) ((-83 . -1225) T) ((-156 . -155) 31418) ((-1079 . -39) T) ((-1300 . -1065) 31392) ((-1298 . -1065) 31349) ((-1252 . -1082) T) ((-1185 . -169) 31328) ((-1185 . -171) 31307) ((-874 . -1082) T) ((-517 . -813) 31286) ((-379 . -1165) 31265) ((-376 . -1165) 31244) ((-364 . -1165) 31223) ((-517 . -816) 31174) ((-517 . -815) 31153) ((-241 . -39) T) ((-517 . -743) 31063) ((-65 . -523) 31047) ((-599 . -1082) T) ((-1226 . -632) 31029) ((-1187 . -194) 30920) ((-1142 . -194) 30831) ((-1086 . -1119) T) ((-1107 . -977) 30776) ((-980 . -1119) T) ((-839 . -661) 30727) ((-804 . -977) 30696) ((-730 . -1119) T) ((-802 . -977) 30663) ((-549 . -299) 30647) ((-687 . -922) 30606) ((-516 . -1119) T) ((-479 . -977) 30573) ((-84 . -1225) T) ((-379 . -43) 30538) ((-376 . -43) 30503) ((-364 . -43) 30468) ((-279 . -43) 30317) ((-264 . -43) 30166) ((-932 . -1165) T) ((-639 . -171) 30145) ((-639 . -169) 30124) ((-146 . -171) T) ((-146 . -169) NIL) ((-440 . -743) T) ((-821 . -1075) T) ((-363 . -477) T) ((-1271 . -1030) 30090) ((-1264 . -1030) 30056) ((-1243 . -1030) 30022) ((-1237 . -1030) 29988) ((-932 . -43) 29953) ((-237 . -734) 29918) ((-760 . -869) T) ((-45 . -435) 29890) ((-336 . -52) 29860) ((-1027 . -158) T) ((-837 . -1225) T) ((-195 . -943) T) ((-363 . -428) T) ((-552 . -305) 29837) ((-50 . -39) T) ((-837 . -1065) 29664) ((-761 . -931) 29643) ((-676 . -125) T) ((-668 . -21) T) ((-668 . -25) T) ((-1121 . -523) 29627) ((-1242 . -245) 29597) ((-691 . -1225) T) ((-262 . -125) 29547) ((-892 . -1119) T) ((-1193 . -661) 29472) ((-1086 . -734) 29459) ((-748 . -1081) 29302) ((-1187 . -547) 29248) ((-980 . -734) 29097) ((-1142 . -547) 29049) ((-761 . -661) 28974) ((-516 . -734) 28823) ((-72 . -632) 28805) ((-748 . -140) 28627) ((-839 . -678) 28606) ((-971 . -523) 28590) ((-1290 . -661) 28550) ((-1189 . -1081) 28433) ((-839 . -743) T) ((-1188 . -1081) 28268) ((-1181 . -1081) 28058) ((-255 . -307) 28037) ((-1143 . -1081) 27920) ((-1031 . -1235) T) ((-1113 . -125) 27898) ((-837 . -403) 27867) ((-1031 . -582) T) ((-1189 . -140) 27729) ((-1188 . -140) 27543) ((-1181 . -140) 27289) ((-1143 . -140) 27151) ((-1124 . -1122) 27115) ((-405 . -867) T) ((-1271 . -632) 27097) ((-1264 . -632) 27079) ((-1243 . -632) 27061) ((-1243 . -633) NIL) ((-1237 . -632) 27043) ((-254 . -305) 27020) ((-45 . -477) T) ((-237 . -194) T) ((-191 . -1119) T) ((-710 . -171) T) ((-710 . -169) NIL) ((-618 . -632) 27002) ((-617 . -632) 26984) ((-920 . -1119) T) ((-860 . -1119) T) ((-830 . -1119) T) ((-788 . -1119) T) ((-672 . -871) 26968) ((-693 . -1119) T) ((-837 . -922) 26900) ((-1185 . -1211) 26878) ((-1185 . -1214) 26856) ((-45 . -428) NIL) ((-1137 . -675) T) ((-892 . -734) 26801) ((-266 . -523) 26785) ((-265 . -523) 26769) ((-729 . -654) 26717) ((-667 . -661) 26691) ((-311 . -39) T) ((-1185 . -116) 26669) ((-1185 . -40) 26647) ((-748 . -1075) T) ((-605 . -1287) 26634) ((-550 . -1287) 26611) ((-1252 . -1119) T) ((-1187 . -307) 26522) ((-1142 . -307) 26453) ((-1086 . -194) T) ((-761 . -678) 26384) ((-874 . -1119) T) ((-980 . -194) 26295) ((-804 . -1255) 26279) ((-658 . -547) 26212) ((-82 . -632) 26194) ((-748 . -346) 26159) ((-1193 . -743) T) ((-599 . -1119) T) ((-516 . -194) 26070) ((-761 . -743) T) ((-262 . -325) 26008) ((-1156 . -1131) T) ((-75 . -632) 25990) ((-1290 . -743) T) ((-1189 . -1075) T) ((-1188 . -1075) T) ((-347 . -125) 25940) ((-1181 . -1075) T) ((-1156 . -23) T) ((-1143 . -1075) T) ((-96 . -1138) 25924) ((-880 . -1131) T) ((-1189 . -247) 25883) ((-1188 . -260) 25862) ((-1188 . -247) 25814) ((-1181 . -247) 25701) ((-1181 . -260) 25680) ((-336 . -922) 25586) ((-887 . -125) T) ((-882 . -125) T) ((-880 . -23) T) ((-191 . -734) 25414) ((-1120 . -394) T) ((-433 . -1235) T) ((-1051 . -171) T) ((-1031 . -388) T) ((-971 . -303) 25391) ((-891 . -477) T) ((-884 . -373) T) ((-332 . -869) T) ((-329 . -869) NIL) ((-896 . -125) T) ((-561 . -560) 25245) ((-729 . -25) T) ((-433 . -582) T) ((-729 . -21) T) ((-378 . -171) 25227) ((-378 . -169) T) ((-1161 . -1119) 25205) ((-478 . -737) T) ((-80 . -632) 25187) ((-143 . -869) T) ((-262 . -299) 25171) ((-254 . -1081) 25068) ((-86 . -632) 25050) ((-752 . -394) 25003) ((-1191 . -850) T) ((-754 . -249) 24987) ((-1252 . -734) 24816) ((-1174 . -1225) T) ((-163 . -249) 24798) ((-254 . -140) 24688) ((-1106 . -1081) 24665) ((-53 . -171) T) ((-892 . -194) T) ((-874 . -734) 24635) ((-518 . -1225) T) ((-980 . -547) 24581) ((-667 . -743) T) ((-599 . -734) 24568) ((-1106 . -140) 24533) ((-1062 . -1082) T) ((-516 . -547) 24471) ((-971 . -19) 24455) ((-971 . -625) 24432) ((-838 . -633) NIL) ((-838 . -632) 24414) ((-1032 . -1081) 24364) ((-439 . -632) 24346) ((-266 . -303) 24323) ((-265 . -303) 24300) ((-521 . -931) NIL) ((-332 . -29) 24270) ((-132 . -1225) T) ((-1031 . -1131) T) ((-230 . -931) NIL) ((-937 . -1081) 24222) ((-1229 . -869) T) ((-1101 . -1065) 24118) ((-1032 . -140) 24045) ((-754 . -711) 24029) ((-279 . -245) 24013) ((-453 . -1081) 23997) ((-405 . -1082) T) ((-1031 . -23) T) ((-937 . -140) 23928) ((-710 . -1214) NIL) ((-521 . -661) 23878) ((-132 . -906) 23860) ((-132 . -908) 23842) ((-710 . -1211) NIL) ((-230 . -661) 23792) ((-384 . -1065) 23776) ((-377 . -1065) 23760) ((-347 . -325) 23698) ((-365 . -1065) 23682) ((-237 . -307) T) ((-453 . -140) 23661) ((-65 . -632) 23628) ((-191 . -194) T) ((-1137 . -869) T) ((-132 . -1065) 23588) ((-914 . -1119) T) ((-856 . -1082) T) ((-849 . -1082) T) ((-710 . -40) NIL) ((-710 . -116) NIL) ((-329 . -1021) 23549) ((-604 . -477) T) ((-592 . -477) T) ((-528 . -477) T) ((-433 . -388) T) ((-254 . -1075) 23479) ((-1164 . -39) T) ((-950 . -125) T) ((-513 . -943) T) ((-1027 . -654) 23427) ((-266 . -625) 23404) ((-265 . -625) 23381) ((-1101 . -403) 23365) ((-892 . -547) 23228) ((-254 . -247) 23180) ((-1173 . -1225) T) ((-846 . -632) 23162) ((-996 . -999) 23146) ((-1301 . -1131) T) ((-1293 . -632) 23128) ((-1252 . -194) 23019) ((-132 . -403) 23001) ((-132 . -358) 22983) ((-1086 . -307) T) ((-980 . -307) 22914) ((-821 . -394) 22893) ((-950 . -947) 22872) ((-660 . -1225) T) ((-647 . -1225) T) ((-516 . -307) 22803) ((-599 . -194) T) ((-347 . -299) 22787) ((-1301 . -23) T) ((-1220 . -125) T) ((-1207 . -1119) T) ((-1108 . -1119) T) ((-1097 . -1119) T) ((-88 . -632) 22769) ((-728 . -125) T) ((-379 . -373) 22748) ((-627 . -1119) T) ((-376 . -373) 22727) ((-364 . -373) 22706) ((-1199 . -243) 22656) ((-504 . -1119) T) ((-255 . -303) 22633) ((-279 . -268) 22595) ((-1156 . -158) T) ((-627 . -629) 22571) ((-1101 . -922) 22504) ((-1032 . -1075) T) ((-937 . -1075) T) ((-504 . -629) 22483) ((-1181 . -814) NIL) ((-1181 . -817) NIL) ((-1121 . -633) 22444) ((-1121 . -632) 22426) ((-514 . -243) 22376) ((-1032 . -260) T) ((-1032 . -247) T) ((-986 . -1119) 22326) ((-453 . -1075) T) ((-937 . -260) T) ((-880 . -158) T) ((-715 . -477) T) ((-521 . -678) T) ((-862 . -1131) 22305) ((-132 . -922) NIL) ((-1220 . -301) 22271) ((-230 . -678) T) ((-893 . -867) 22250) ((-1132 . -1225) T) ((-927 . -743) T) ((-191 . -547) 22162) ((-1027 . -25) T) ((-927 . -502) T) ((-433 . -1131) T) ((-521 . -816) T) ((-521 . -813) T) ((-932 . -373) T) ((-521 . -743) T) ((-230 . -816) T) ((-230 . -813) T) ((-1027 . -21) T) ((-230 . -743) T) ((-862 . -23) 22114) ((-336 . -323) 22093) ((-1063 . -249) 22039) ((-433 . -23) T) ((-971 . -633) 22000) ((-971 . -632) 21939) ((-658 . -523) 21923) ((-50 . -1038) 21873) ((-887 . -43) 21838) ((-882 . -43) 21803) ((-1185 . -477) 21734) ((-351 . -632) 21716) ((-1132 . -1065) 21543) ((-615 . -664) 21525) ((-615 . -399) 21507) ((-363 . -1287) 21484) ((-1055 . -1225) T) ((-892 . -307) T) ((-1252 . -547) 21430) ((-505 . -1225) T) ((-492 . -1225) T) ((-609 . -125) T) ((-1187 . -303) 21357) ((-639 . -477) 21336) ((-1028 . -1023) 21320) ((-1293 . -408) 21292) ((-146 . -477) T) ((-1206 . -125) T) ((-1111 . -1119) 21270) ((-1062 . -1119) T) ((-915 . -869) T) ((-1271 . -1081) 21153) ((-375 . -1235) T) ((-1264 . -1081) 20988) ((-1132 . -403) 20957) ((-1243 . -1081) 20747) ((-1237 . -1081) 20630) ((-1271 . -140) 20492) ((-1264 . -140) 20306) ((-1243 . -140) 20052) ((-1237 . -140) 19914) ((-1220 . -325) 19901) ((-375 . -582) T) ((-390 . -632) 19883) ((-306 . -323) T) ((-618 . -1081) 19856) ((-617 . -1081) 19739) ((-386 . -1119) T) ((-341 . -1119) T) ((-266 . -632) 19700) ((-265 . -632) 19661) ((-1031 . -158) T) ((-133 . -632) 19643) ((-650 . -23) T) ((-710 . -435) 19610) ((-626 . -23) T) ((-672 . -125) T) ((-618 . -140) 19581) ((-617 . -140) 19443) ((-405 . -1119) T) ((-356 . -125) T) ((-191 . -307) 19354) ((-258 . -125) T) ((-1242 . -867) 19307) ((-948 . -632) 19289) ((-731 . -1082) T) ((-1161 . -547) 19222) ((-1132 . -922) 19154) ((-856 . -1119) T) ((-849 . -1119) T) ((-847 . -1119) T) ((-118 . -125) T) ((-168 . -869) T) ((-760 . -171) 19133) ((-760 . -169) 19112) ((-631 . -906) 19096) ((-1230 . -1225) T) ((-1231 . -175) 19078) ((-134 . -1225) T) ((-1107 . -125) T) ((-1087 . -39) T) ((-804 . -125) T) ((-802 . -125) T) ((-487 . -125) T) ((-479 . -125) T) ((-254 . -817) 19029) ((-254 . -814) 18980) ((-801 . -1163) 18932) ((-662 . -125) T) ((-1252 . -307) 18843) ((-681 . -649) 18827) ((-658 . -303) 18804) ((-1062 . -734) 18788) ((-599 . -307) T) ((-992 . -661) 18713) ((-1301 . -158) T) ((-752 . -661) 18673) ((-732 . -661) 18660) ((-293 . -125) T) ((-478 . -661) 18590) ((-55 . -125) T) ((-605 . -125) T) ((-561 . -125) T) ((-550 . -125) T) ((-1271 . -1075) T) ((-1264 . -1075) T) ((-1243 . -1075) T) ((-1237 . -1075) T) ((-1271 . -247) 18549) ((-1264 . -260) 18528) ((-341 . -734) 18510) ((-1264 . -247) 18462) ((-1243 . -247) 18349) ((-1243 . -260) 18328) ((-1237 . -247) 18287) ((-1220 . -43) 18184) ((-1032 . -817) T) ((-618 . -1075) T) ((-617 . -1075) T) ((-1032 . -814) T) ((-1000 . -817) T) ((-1000 . -814) T) ((-255 . -632) 18166) ((-893 . -1082) T) ((-891 . -890) 18150) ((-710 . -477) T) ((-405 . -734) 18115) ((-444 . -661) 18089) ((-729 . -869) 18068) ((-728 . -43) 18033) ((-617 . -247) 17992) ((-45 . -741) 17964) ((-375 . -349) 17941) ((-375 . -388) T) ((-1275 . -169) 17920) ((-1275 . -171) 17899) ((-1101 . -323) 17850) ((-310 . -1131) 17731) ((-1125 . -1225) T) ((-193 . -125) T) ((-1246 . -632) 17698) ((-862 . -158) 17650) ((-658 . -1267) 17634) ((-856 . -734) 17604) ((-849 . -734) 17574) ((-517 . -1225) T) ((-384 . -323) T) ((-377 . -323) T) ((-365 . -323) T) ((-658 . -625) 17551) ((-433 . -158) T) ((-552 . -683) 17535) ((-132 . -323) T) ((-310 . -23) 17418) ((-552 . -664) 17402) ((-710 . -428) NIL) ((-552 . -399) 17386) ((-562 . -632) 17368) ((-96 . -1119) 17346) ((-132 . -1049) T) ((-592 . -167) T) ((-1280 . -175) 17330) ((-517 . -1065) 17157) ((-1265 . -169) 17118) ((-1265 . -171) 17079) ((-1079 . -1225) T) ((-1022 . -632) 17061) ((-877 . -632) 17043) ((-838 . -1081) 16886) ((-1107 . -325) 16873) ((-241 . -1225) T) ((-804 . -325) 16860) ((-802 . -325) 16847) ((-838 . -140) 16669) ((-479 . -325) 16656) ((-1187 . -633) NIL) ((-1187 . -632) 16638) ((-1142 . -632) 16620) ((-1142 . -633) 16368) ((-1062 . -194) T) ((-873 . -632) 16350) ((-971 . -305) 16327) ((-627 . -547) 16075) ((-840 . -1065) 16059) ((-504 . -547) 15819) ((-992 . -743) T) ((-752 . -743) T) ((-732 . -743) T) ((-375 . -1131) T) ((-1194 . -632) 15801) ((-235 . -125) T) ((-517 . -403) 15770) ((-548 . -1119) T) ((-543 . -1119) T) ((-541 . -1119) T) ((-821 . -661) 15744) ((-1051 . -477) T) ((-986 . -547) 15677) ((-375 . -23) T) ((-1227 . -869) T) ((-650 . -158) T) ((-626 . -158) T) ((-444 . -678) 15627) ((-378 . -477) T) ((-254 . -394) 15606) ((-405 . -194) T) ((-1263 . -1082) T) ((-1242 . -1082) T) ((-237 . -1030) T) ((-994 . -1117) T) ((-715 . -413) T) ((-444 . -743) T) ((-717 . -1235) T) ((-1156 . -654) 15554) ((-1293 . -1081) 15538) ((-604 . -890) 15522) ((-1174 . -1202) 15498) ((-731 . -1119) T) ((-717 . -582) T) ((-156 . -1119) 15476) ((-517 . -922) 15408) ((-240 . -1278) 15390) ((-240 . -1119) T) ((-166 . -1278) 15365) ((-183 . -1119) T) ((-672 . -43) 15335) ((-378 . -428) T) ((-332 . -171) 15314) ((-332 . -169) 15293) ((-145 . -582) T) ((-329 . -171) 15249) ((-329 . -169) 15205) ((-53 . -477) T) ((-179 . -1119) T) ((-166 . -1119) T) ((-1174 . -131) 15152) ((-1185 . -977) 15121) ((-804 . -1165) 15099) ((-706 . -39) T) ((-1293 . -140) 15078) ((-575 . -39) T) ((-518 . -131) 15062) ((-266 . -305) 15039) ((-265 . -305) 15016) ((-892 . -303) 14946) ((-50 . -1225) T) ((-838 . -1075) T) ((-1193 . -52) 14922) ((-838 . -346) 14884) ((-1107 . -43) 14733) ((-838 . -247) 14712) ((-804 . -43) 14541) ((-802 . -43) 14390) ((-761 . -52) 14367) ((-479 . -43) 14216) ((-658 . -633) 14177) ((-658 . -632) 14116) ((-605 . -1165) T) ((-550 . -1165) T) ((-1161 . -523) 14100) ((-1212 . -1119) 14078) ((-1156 . -25) T) ((-1156 . -21) T) ((-884 . -1082) T) ((-801 . -1082) T) ((-1275 . -1214) 14044) ((-1275 . -1211) 14010) ((-503 . -1082) T) ((-1243 . -814) NIL) ((-1243 . -817) NIL) ((-1027 . -869) 13989) ((-841 . -632) 13971) ((-880 . -21) T) ((-880 . -25) T) ((-821 . -743) T) ((-537 . -1117) T) ((-195 . -1235) T) ((-605 . -43) 13936) ((-550 . -43) 13901) ((-412 . -632) 13883) ((-343 . -632) 13865) ((-191 . -303) 13823) ((-1275 . -40) 13789) ((-1275 . -116) 13755) ((-68 . -1225) T) ((-141 . -125) T) ((-893 . -1119) T) ((-195 . -582) T) ((-731 . -734) 13725) ((-310 . -158) 13608) ((-237 . -632) 13590) ((-237 . -633) 13520) ((-1228 . -39) T) ((-1031 . -654) 13454) ((-1293 . -1075) T) ((-1137 . -171) T) ((-647 . -1202) 13429) ((-748 . -931) 13408) ((-615 . -39) T) ((-660 . -131) 13392) ((-647 . -131) 13338) ((-761 . -908) NIL) ((-1252 . -303) 13265) ((-748 . -661) 13190) ((-311 . -1225) T) ((-1193 . -1065) 13086) ((-761 . -1065) 12966) ((-1181 . -931) NIL) ((-1086 . -633) 12881) ((-1086 . -632) 12863) ((-363 . -125) T) ((-266 . -1081) 12760) ((-265 . -1081) 12657) ((-420 . -125) T) ((-980 . -632) 12639) ((-980 . -633) 12500) ((-730 . -632) 12482) ((-1291 . -1219) 12451) ((-516 . -632) 12433) ((-516 . -633) 12294) ((-279 . -437) 12278) ((-264 . -437) 12262) ((-266 . -140) 12152) ((-265 . -140) 12042) ((-1189 . -661) 11967) ((-1188 . -661) 11864) ((-1181 . -661) 11716) ((-1143 . -661) 11641) ((-375 . -158) T) ((-87 . -466) T) ((-87 . -421) T) ((-1031 . -25) T) ((-1031 . -21) T) ((-893 . -734) 11593) ((-405 . -307) T) ((-191 . -1030) 11544) ((-761 . -403) 11528) ((-710 . -413) T) ((-1027 . -1025) 11512) ((-717 . -1131) T) ((-710 . -188) 11494) ((-1263 . -1119) T) ((-1242 . -1119) T) ((-332 . -1211) 11473) ((-332 . -1214) 11452) ((-1179 . -125) T) ((-332 . -987) 11431) ((-160 . -1131) T) ((-145 . -1131) T) ((-623 . -1278) 11415) ((-717 . -23) T) ((-623 . -1119) 11365) ((-96 . -547) 11298) ((-195 . -388) T) ((-1185 . -1255) 11282) ((-332 . -116) 11261) ((-332 . -40) 11240) ((-627 . -523) 11174) ((-160 . -23) T) ((-145 . -23) T) ((-735 . -1119) T) ((-504 . -523) 11111) ((-433 . -654) 11059) ((-667 . -1065) 10955) ((-761 . -922) 10898) ((-986 . -523) 10882) ((-748 . -678) 10833) ((-379 . -1082) T) ((-376 . -1082) T) ((-364 . -1082) T) ((-279 . -1082) T) ((-264 . -1082) T) ((-892 . -633) NIL) ((-892 . -632) 10815) ((-1301 . -21) T) ((-599 . -1030) T) ((-748 . -743) T) ((-1301 . -25) T) ((-266 . -1075) 10745) ((-265 . -1075) 10675) ((-255 . -1081) 10621) ((-77 . -1225) T) ((-949 . -125) T) ((-266 . -247) 10573) ((-265 . -247) 10525) ((-255 . -140) 10464) ((-45 . -125) T) ((-932 . -1082) T) ((-1188 . -678) 10443) ((-1181 . -678) 10422) ((-1189 . -743) T) ((-1188 . -743) T) ((-1181 . -743) T) ((-1181 . -813) NIL) ((-1181 . -816) NIL) ((-1143 . -743) T) ((-949 . -947) 10380) ((-884 . -1119) T) ((-944 . -125) T) ((-801 . -1119) T) ((-790 . -125) T) ((-688 . -125) T) ((-503 . -1119) T) ((-359 . -1131) T) ((-1263 . -734) 10221) ((-195 . -1131) T) ((-336 . -943) 10200) ((-760 . -477) 10179) ((-893 . -194) T) ((-1242 . -734) 9993) ((-862 . -21) 9945) ((-862 . -25) 9897) ((-262 . -1163) 9881) ((-156 . -547) 9814) ((-433 . -25) T) ((-433 . -21) T) ((-359 . -23) T) ((-191 . -633) 9580) ((-191 . -632) 9562) ((-195 . -23) T) ((-658 . -305) 9539) ((-240 . -547) NIL) ((-166 . -547) NIL) ((-552 . -39) T) ((-920 . -632) 9521) ((-94 . -1225) T) ((-860 . -632) 9503) ((-830 . -632) 9485) ((-788 . -632) 9467) ((-693 . -632) 9449) ((-254 . -661) 9297) ((-1191 . -1119) T) ((-1187 . -1081) 9120) ((-1164 . -1225) T) ((-1142 . -1081) 8963) ((-873 . -1081) 8947) ((-1106 . -661) 8924) ((-1187 . -140) 8726) ((-1142 . -140) 8548) ((-873 . -140) 8527) ((-1252 . -633) NIL) ((-1252 . -632) 8509) ((-363 . -1165) T) ((-874 . -632) 8491) ((-1097 . -303) 8470) ((-255 . -1075) T) ((-85 . -1225) T) ((-1032 . -931) NIL) ((-627 . -303) 8446) ((-1212 . -547) 8379) ((-521 . -1225) T) ((-599 . -632) 8361) ((-504 . -303) 8340) ((-1107 . -245) 8324) ((-1032 . -661) 8274) ((-230 . -1225) T) ((-986 . -303) 8251) ((-937 . -661) 8203) ((-306 . -943) T) ((-839 . -323) 8182) ((-891 . -125) T) ((-804 . -245) 8166) ((-797 . -1119) T) ((-884 . -734) 8118) ((-801 . -734) 8056) ((-650 . -21) T) ((-650 . -25) T) ((-626 . -21) T) ((-363 . -43) 8021) ((-710 . -741) 7988) ((-521 . -906) 7970) ((-521 . -908) 7952) ((-503 . -734) 7793) ((-230 . -906) 7775) ((-69 . -1225) T) ((-230 . -908) 7757) ((-626 . -25) T) ((-453 . -661) 7731) ((-521 . -1065) 7691) ((-893 . -547) 7603) ((-230 . -1065) 7563) ((-254 . -39) T) ((-1028 . -1119) 7541) ((-1263 . -194) 7472) ((-1242 . -194) 7403) ((-729 . -169) 7382) ((-729 . -171) 7361) ((-717 . -158) T) ((-162 . -494) 7338) ((-488 . -125) T) ((-672 . -670) 7322) ((-1161 . -632) 7289) ((-145 . -158) T) ((-513 . -1235) T) ((-627 . -625) 7265) ((-504 . -625) 7244) ((-356 . -355) 7213) ((-565 . -1119) T) ((-1187 . -1075) T) ((-513 . -582) T) ((-258 . -257) 7197) ((-1142 . -1075) T) ((-873 . -1075) T) ((-254 . -813) 7176) ((-254 . -816) 7127) ((-254 . -815) 7106) ((-1187 . -346) 7083) ((-254 . -743) 6993) ((-986 . -19) 6977) ((-521 . -403) 6959) ((-521 . -358) 6941) ((-1142 . -346) 6913) ((-378 . -1287) 6890) ((-230 . -403) 6872) ((-230 . -358) 6854) ((-986 . -625) 6831) ((-1187 . -247) T) ((-681 . -1119) T) ((-1276 . -1119) T) ((-1199 . -1119) T) ((-1107 . -268) 6768) ((-379 . -1119) T) ((-376 . -1119) T) ((-364 . -1119) T) ((-279 . -1119) T) ((-264 . -1119) T) ((-89 . -1225) T) ((-157 . -125) 6746) ((-151 . -125) 6724) ((-761 . -323) 6703) ((-1199 . -629) 6682) ((-1231 . -125) T) ((-1155 . -1119) T) ((-514 . -1119) T) ((-1101 . -943) 6633) ((-1032 . -816) T) ((-514 . -629) 6612) ((-266 . -817) 6563) ((-266 . -814) 6514) ((-265 . -817) 6465) ((-45 . -1165) NIL) ((-265 . -814) 6416) ((-1032 . -813) T) ((-1032 . -678) T) ((-1032 . -743) T) ((-1000 . -816) T) ((-995 . -1119) T) ((-937 . -678) T) ((-937 . -743) T) ((-932 . -1119) T) ((-893 . -307) T) ((-96 . -523) 6400) ((-521 . -922) NIL) ((-884 . -194) T) ((-237 . -1081) 6365) ((-855 . -1131) 6344) ((-230 . -922) NIL) ((-801 . -194) T) ((-64 . -1119) 6294) ((-551 . -1119) 6272) ((-549 . -1119) 6222) ((-530 . -1119) 6200) ((-529 . -1119) 6150) ((-604 . -125) T) ((-592 . -125) T) ((-528 . -125) T) ((-503 . -194) 6081) ((-384 . -943) T) ((-377 . -943) T) ((-365 . -943) T) ((-237 . -140) 6030) ((-855 . -23) 5982) ((-453 . -743) T) ((-132 . -943) T) ((-45 . -43) 5927) ((-132 . -842) T) ((-605 . -373) T) ((-550 . -373) T) ((-1242 . -547) 5787) ((-332 . -477) 5766) ((-329 . -477) T) ((-1226 . -39) T) ((-856 . -303) 5745) ((-359 . -158) T) ((-195 . -158) T) ((-310 . -25) 5609) ((-310 . -21) 5492) ((-50 . -1202) 5471) ((-71 . -632) 5453) ((-914 . -632) 5435) ((-623 . -547) 5368) ((-50 . -131) 5318) ((-1121 . -451) 5302) ((-1121 . -394) 5281) ((-1087 . -1225) T) ((-1086 . -1081) 5268) ((-980 . -1081) 5111) ((-516 . -1081) 4954) ((-681 . -734) 4938) ((-1086 . -140) 4923) ((-980 . -140) 4745) ((-513 . -388) T) ((-379 . -734) 4697) ((-376 . -734) 4649) ((-364 . -734) 4601) ((-279 . -734) 4450) ((-264 . -734) 4299) ((-1281 . -125) T) ((-1280 . -125) 4249) ((-971 . -664) 4233) ((-1271 . -661) 4158) ((-516 . -140) 3980) ((-1264 . -661) 3877) ((-1243 . -661) 3729) ((-1243 . -931) NIL) ((-971 . -399) 3713) ((-1237 . -661) 3638) ((-79 . -632) 3620) ((-992 . -52) 3599) ((-637 . -1131) T) ((-1 . -1119) T) ((-727 . -125) T) ((-715 . -125) T) ((-1207 . -632) 3581) ((-1108 . -632) 3563) ((-1097 . -632) 3545) ((-932 . -734) 3510) ((-156 . -523) 3494) ((-801 . -547) 3326) ((-637 . -23) T) ((-416 . -23) T) ((-627 . -632) 3308) ((-92 . -1225) T) ((-627 . -633) NIL) ((-504 . -633) NIL) ((-504 . -632) 3290) ((-375 . -25) T) ((-375 . -21) T) ((-240 . -523) 3272) ((-157 . -325) 3210) ((-544 . -1119) T) ((-540 . -1119) T) ((-166 . -523) 3185) ((-151 . -325) 3123) ((-618 . -661) 3110) ((-238 . -62) 3078) ((-165 . -62) 3039) ((-237 . -1075) T) ((-617 . -661) 2964) ((-1231 . -325) NIL) ((-405 . -1030) T) ((-237 . -260) T) ((-237 . -247) T) ((-1185 . -125) T) ((-986 . -633) 2925) ((-986 . -632) 2864) ((-891 . -43) 2851) ((-1263 . -307) 2802) ((-1242 . -307) 2753) ((-1137 . -477) T) ((-535 . -869) T) ((-332 . -1153) 2732) ((-1027 . -171) 2711) ((-1027 . -169) 2690) ((-760 . -182) T) ((-760 . -167) T) ((-528 . -325) 2677) ((-311 . -1202) 2656) ((-513 . -1131) T) ((-892 . -1081) 2601) ((-639 . -125) T) ((-1212 . -523) 2585) ((-266 . -394) 2564) ((-265 . -394) 2543) ((-1185 . -301) 2521) ((-1086 . -1075) T) ((-311 . -131) 2471) ((-150 . -125) T) ((-146 . -125) T) ((-35 . -1117) T) ((-980 . -1075) T) ((-892 . -140) 2388) ((-513 . -23) T) ((-516 . -1075) T) ((-1086 . -247) T) ((-980 . -346) 2357) ((-516 . -346) 2314) ((-379 . -194) T) ((-376 . -194) T) ((-364 . -194) T) ((-279 . -194) 2225) ((-264 . -194) 2136) ((-992 . -1065) 2032) ((-752 . -1065) 2003) ((-1124 . -125) T) ((-1111 . -632) 1970) ((-1062 . -632) 1952) ((-1264 . -678) 1931) ((-1243 . -678) 1910) ((-1275 . -1002) 1879) ((-1271 . -743) T) ((-1264 . -743) T) ((-1243 . -743) T) ((-1243 . -813) NIL) ((-1243 . -816) NIL) ((-884 . -307) T) ((-191 . -1081) 1789) ((-932 . -194) T) ((-801 . -307) T) ((-1237 . -743) T) ((-1291 . -175) 1773) ((-1031 . -362) 1747) ((-1028 . -547) 1680) ((-862 . -869) 1659) ((-592 . -1165) T) ((-503 . -307) 1610) ((-618 . -743) T) ((-386 . -632) 1592) ((-341 . -632) 1574) ((-444 . -1065) 1470) ((-617 . -743) T) ((-433 . -869) 1421) ((-191 . -140) 1310) ((-887 . -1082) T) ((-882 . -1082) T) ((-855 . -158) 1262) ((-754 . -175) 1246) ((-1280 . -325) 1184) ((-521 . -323) T) ((-405 . -632) 1151) ((-552 . -1038) 1135) ((-405 . -633) 1049) ((-230 . -323) T) ((-163 . -175) 1031) ((-731 . -303) 1010) ((-1185 . -325) 997) ((-521 . -1049) T) ((-604 . -43) 984) ((-592 . -43) 971) ((-528 . -43) 936) ((-240 . -303) 911) ((-166 . -303) 879) ((-230 . -1049) T) ((-892 . -1075) T) ((-856 . -632) 861) ((-849 . -632) 843) ((-847 . -632) 825) ((-838 . -931) 804) ((-1302 . -1131) T) ((-1252 . -1081) 627) ((-874 . -1081) 611) ((-892 . -260) T) ((-892 . -247) NIL) ((-706 . -1225) T) ((-1302 . -23) T) ((-838 . -661) 536) ((-575 . -1225) T) ((-444 . -358) 520) ((-599 . -1081) 507) ((-1252 . -140) 309) ((-717 . -654) 291) ((-874 . -140) 270) ((-407 . -23) T) ((-1199 . -547) 30)) 
\ No newline at end of file
diff --git a/src/share/algebra/compress.daase b/src/share/algebra/compress.daase
index 6a1cc23..e194d48 100644
--- a/src/share/algebra/compress.daase
+++ b/src/share/algebra/compress.daase
@@ -1,3 +1,3 @@
 
-(30 . 3575754973)            
-(4605 |Enumeration| |Mapping| |Record| |Union| |ofCategory| |isDomain| ATTRIBUTE |package| |domain| |category| CATEGORY |nobranch| AND |Join| |ofType| SIGNATURE "failed" "algebra" |OneDimensionalArrayAggregate&| |OneDimensionalArrayAggregate| |AbelianGroup&| |AbelianGroup| |AbelianMonoid&| |AbelianMonoid| |AbelianSemiGroup&| |AbelianSemiGroup| |AlgebraicallyClosedField&| |AlgebraicallyClosedField| |AlgebraicallyClosedFunctionSpace&| |AlgebraicallyClosedFunctionSpace| |PlaneAlgebraicCurvePlot| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraicFunction| |AffineSpaceCategory| |Aggregate&| |Aggregate| |ArcHyperbolicFunctionCategory| |AssociationListAggregate| |Algebra&| |Algebra| |AlgFactor| |AlgebraicFunctionField| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraPackage| |AlgebraGivenByStructuralConstants| |AssociationList| |AbelianMonoidRing&| |AbelianMonoidRing| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |AnyFunctions1| |Any| |ApplicationProgramInterface| |ApplyUnivariateSkewPolynomial| |ApplyRules| |TwoDimensionalArrayCategory&| |TwoDimensionalArrayCategory| |OneDimensionalArrayFunctions2| |OneDimensionalArray| |TwoDimensionalArray| |Asp10| |Asp12| |Asp19| |Asp1| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp41| |Asp42| |Asp49| |Asp4| |Asp50| |Asp55| |Asp6| |Asp73| |Asp74| |Asp77| |Asp78| |Asp7| |Asp80| |Asp8| |Asp9| |AssociatedEquations| |ArrayStack| |ArcTrigonometricFunctionCategory&| |ArcTrigonometricFunctionCategory| |AttributeButtons| |AttributeRegistry| |Automorphism| |AxiomServer| |BalancedFactorisation| |BasicType&| |BasicType| |BalancedBinaryTree| |Bezier| |BezoutMatrix| |BasicFunctions| |BagAggregate&| |BagAggregate| |BinaryExpansion| |BinaryFile| |Bits| |BlasLevelOne| |BlowUpWithHamburgerNoether| |BlowUpMethodCategory| |BlowUpWithQuadTrans| |BlowUpPackage| |BiModule| |Boolean| |BasicOperatorFunctions1| |BasicOperator| |BoundIntegerRoots| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryRecursiveAggregate&| |BinaryRecursiveAggregate| |BrillhartTests| |BasicStochasticDifferential| |BinarySearchTree| |BitAggregate&| |BitAggregate| |BinaryTreeCategory&| |BinaryTreeCategory| |BinaryTournament| |BinaryTree| |CancellationAbelianMonoid| |CachableSet| |CardinalNumber| |CartesianTensorFunctions2| |CartesianTensor| |CharacterClass| |CommonDenominator| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |CombinatorialFunctionCategory| |Character| |CharacteristicNonZero| |CharacteristicPolynomialPackage| |CharacteristicZero| |ChangeOfVariable| |ComplexIntegerSolveLinearPolynomialEquation| |Collection&| |Collection| |CliffordAlgebra| |TwoDimensionalPlotClipping| |ComplexRootPackage| |Color| |CombinatorialFunction| |IntegerCombinatoricFunctions| |CombinatorialOpsCategory| |Commutator| |CommonOperators| |CommuteUnivariatePolynomialCategory| |Comparable| |ComplexCategory&| |ComplexCategory| |ComplexFactorization| |ComplexFunctions2| |Complex| |ComplexPattern| |SubSpaceComponentProperty| |CommutativeRing| |ContinuedFraction| |CoordinateSystems| |CharacteristicPolynomialInMonogenicalAlgebra| |ComplexPatternMatch| |CRApackage| |ComplexRootFindingPackage| |CyclicStreamTools| |ComplexTrigonometricManipulations| |CoerceVectorMatrixPackage| |CycleIndicators| |CyclotomicPolynomialPackage| |d01AgentsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d01TransformFunctionType| |d01WeightsPackage| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |Database| |DoubleResultantPackage| |DistinctDegreeFactorize| |DecimalExpansion| |ElementaryFunctionDefiniteIntegration| |RationalFunctionDefiniteIntegration| |DegreeReductionPackage| |Dequeue| |DeRhamComplex| |DefiniteIntegrationTools| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DenavitHartenbergMatrix| |Dictionary&| |Dictionary| |DifferentialExtension&| |DifferentialExtension| |DifferentialRing&| |DifferentialRing| |DictionaryOperations&| |DictionaryOperations| |DiophantineSolutionPackage| |DirectProductCategory&| |DirectProductCategory| |DirectProductFunctions2| |DirectProduct| |DirichletRing| |DisplayPackage| |DivisorCategory| |Divisor| |DivisionRing&| |DivisionRing| |DoublyLinkedAggregate| |DataList| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |DirectProductMatrixModule| |DirectProductModule| |DifferentialPolynomialCategory&| |DifferentialPolynomialCategory| |DequeueAggregate| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |DrawComplex| |DrawNumericHack| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForPoints| |DrawOptionFunctions0| |DrawOptionFunctions1| |DrawOption| |DifferentialSparseMultivariatePolynomial| |DesingTreeCategory| |DesingTree| |DesingTreePackage| |DifferentialVariableCategory&| |DifferentialVariableCategory| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType| |ExtAlgBasis| |ElementaryFunction| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ExtensibleLinearAggregate&| |ExtensibleLinearAggregate| |ElementaryFunctionCategory&| |ElementaryFunctionCategory| |EllipticFunctionsUnivariateTaylorSeries| |Eltable| |EltableAggregate&| |EltableAggregate| |EuclideanModularRing| |EntireRing| |EigenPackage| |EquationFunctions2| |Equation| |EqTable| |ErrorFunctions| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpertSystemContinuityPackage1| |ExpertSystemContinuityPackage| |ExpressionSpace&| |ExpressionSpace| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExpertSystemToolsPackage| |EuclideanDomain&| |EuclideanDomain| |Evalable&| |Evalable| |EvaluateCycleIndicators| |Exit| |Export3D| |ExponentialExpansion| |ExpressionFunctions2| |ExpressionToUnivariatePowerSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionSolve| |ExpressionTubePlot| |ExponentialOfUnivariatePuiseuxSeries| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactoredFunctions| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FactoringUtilities| |FreeAbelianGroup| |FreeAbelianMonoidCategory| |FreeAbelianMonoid| |FiniteAbelianMonoidRingFunctions2| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRing| |FlexibleArray| |FiniteAlgebraicExtensionField&| |FiniteAlgebraicExtensionField| |FortranCode| |FourierComponent| |FortranCodePackage1| |FiniteDivisorFunctions2| |FiniteDivisorCategory&| |FiniteDivisorCategory| |FiniteDivisor| |FullyEvalableOver&| |FullyEvalableOver| |FortranExpression| |FunctionFieldCategoryFunctions2| |FunctionFieldCategory&| |FunctionFieldCategory| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldCyclicGroupExtension| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FractionFreeFastGaussianFractions| |FractionFreeFastGaussian| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldCategory&| |FiniteFieldCategory| |FunctionFieldIntegralBasis| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldNormalBasisExtension| |FiniteField| |FiniteFieldExtensionByPolynomial| |FiniteFieldPolynomialPackage2| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteFieldExtension| |FGLMIfCanPackage| |FreeGroup| |Field&| |Field| |FileCategory| |File| |FiniteRankNonAssociativeAlgebra&| |FiniteRankNonAssociativeAlgebra| |Finite&| |Finite| |FiniteRankAlgebra&| |FiniteRankAlgebra| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregate&| |FiniteLinearAggregate| |FreeLieAlgebra| |FiniteLinearAggregateSort| |FullyLinearlyExplicitRingOver&| |FullyLinearlyExplicitRingOver| |FloatingComplexPackage| |Float| |FloatingRealPackage| |FreeModule1| |FreeModuleCat| |FortranMatrixCategory| |FortranMatrixFunctionCategory| |FreeModule| |FreeMonoid| |FortranMachineTypeCategory| |FileName| |FileNameCategory| |FreeNilpotentLie| |FortranOutputStackPackage| |FindOrderFinite| |ScriptFormulaFormat1| |ScriptFormulaFormat| |FortranProgramCategory| |FortranFunctionCategory| |FortranPackage| |FortranProgram| |FullPartialFractionExpansion| |FullyPatternMatchable| |FieldOfPrimeCharacteristic&| |FieldOfPrimeCharacteristic| |FloatingPointSystem&| |FloatingPointSystem| |FactoredFunctions2| |FractionFunctions2| |Fraction| |FramedAlgebra&| |FramedAlgebra| |FullyRetractableTo&| |FullyRetractableTo| |FractionalIdealFunctions2| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebraFunctions2| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebra| |Factored| |FactoredFunctionUtilities| |FunctionSpaceToExponentialExpansion| |FunctionSpaceFunctions2| |FunctionSpaceToUnivariatePowerSeries| |FiniteSetAggregateFunctions2| |FiniteSetAggregate&| |FiniteSetAggregate| |FunctionSpaceComplexIntegration| |FourierSeries| |FunctionSpaceIntegration| |FunctionSpace&| |FunctionSpace| |FunctionalSpecialFunction| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FortranScalarType| |FunctionSpaceUnivariatePolynomialFactor| |FortranTemplate| |FortranType| |FunctionCalled| |FortranVectorCategory| |FortranVectorFunctionCategory| |GaloisGroupFactorizer| |GaloisGroupFactorizationUtilities| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |EuclideanGroebnerBasisPackage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GcdDomain&| |GcdDomain| |GenericNonAssociativeAlgebra| |GeneralDistributedMultivariatePolynomial| |GnuDraw| |GenExEuclid| |GeneralizedMultivariateFactorize| |GeneralPolynomialGcdPackage| |GenUFactorize| |GenerateUnivariatePowerSeries| |GeneralHenselPackage| |GeneralModulePolynomial| |GuessOptionFunctions0| |GuessOption| |GosperSummationMethod| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GradedAlgebra&| |GradedAlgebra| |GrayCode| |GraphicsDefaults| |GraphImage| |GradedModule&| |GradedModule| |GroebnerSolve| |Group&| |Group| |GeneralUnivariatePowerSeries| |GeneralSparseTable| |GeneralTriangularSet| |GuessAlgebraicNumber| |GuessFiniteFunctions| |GuessFinite| |GuessInteger| |Guess| |GuessPolynomial| |GuessUnivariatePolynomial| |Pi| |HashTable| |HallBasis| |HomogeneousDistributedMultivariatePolynomial| |HomogeneousDirectProduct| |Heap| |HyperellipticFiniteDivisor| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousAggregate| |HTMLFormat| |HyperbolicFunctionCategory&| |HyperbolicFunctionCategory| |InnerAlgFactor| |InnerAlgebraicNumber| |IndexedOneDimensionalArray| |IndexedTwoDimensionalArray| |ChineseRemainderToolsForIntegralBases| |IntegralBasisTools| |IndexedBits| |IntegralBasisPolynomialTools| |IndexCard| |InnerCommonDenominator| |InfClsPt| |PolynomialIdeals| |IdealDecompositionPackage| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductCategory| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedDirectProductObject| |InnerEvalable&| |InnerEvalable| |InnerFreeAbelianMonoid| |IndexedFlexibleArray| |InnerFiniteField| |InnerIndexedTwoDimensionalArray| |IndexedList| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |IndexedMatrix| |InnerNormalBasisFieldFunctions| |IncrementingMaps| |IndexedExponents| |InnerNumericEigenPackage| |InfinitlyClosePointCategory| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InfinitlyClosePoint| |Infinity| |InputFormFunctions1| |InputForm| |InfiniteProductCharacteristicZero| |InnerNumericFloatSolvePackage| |InnerModularGcd| |InnerMultFact| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerPolySign| |IntegerNumberSystem&| |IntegerNumberSystem| |InnerTable| |AlgebraicIntegration| |AlgebraicIntegrate| |IntegerBits| |IntervalCategory| |IntersectionDivisorPackage| |IntegralDomain&| |IntegralDomain| |ElementaryIntegration| |InterfaceGroebnerPackage| |IntegerFactorizationPackage| |InterpolateFormsPackage| |IntegrationFunctionsTable| |GenusZeroIntegration| |IntegerNumberTheoryFunctions| |AlgebraicHermiteIntegration| |TranscendentalHermiteIntegration| |Integer| |AnnaNumericalIntegrationPackage| |PureAlgebraicIntegration| |PatternMatchIntegration| |RationalIntegration| |IntegerRetractions| |RationalFunctionIntegration| |Interval| |IntegerSolveLinearPolynomialEquation| |IntegrationTools| |TranscendentalIntegration| |InverseLaplaceTransform| |InnerPAdicInteger| |InnerPrimeField| |InternalPrintPackage| |IntegrationResultToFunction| |IntegrationResultFunctions2| |IntegrationResult| |IntegerRoots| |IrredPolyOverFiniteField| |IntegrationResultRFToFunction| |IrrRepSymNatPackage| |InternalRationalUnivariateRepresentationPackage| |IndexedString| |InnerPolySum| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InfiniteTupleFunctions2| |InfiniteTupleFunctions3| |InnerTrigonometricManipulations| |InfiniteTuple| |IndexedVector| |IndexedAggregate&| |IndexedAggregate| |AssociatedJordanAlgebra| |KeyedAccessFile| |KeyedDictionary&| |KeyedDictionary| |KernelFunctions2| |Kernel| |CoercibleTo| |ConvertibleTo| |Kovacic| |LeftAlgebra&| |LeftAlgebra| |LocalAlgebra| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LieExponentials| |LexTriangularPackage| |LiouvillianFunctionCategory| |LiouvillianFunction| |LinGroebnerPackage| |Library| |LieAlgebra&| |LieAlgebra| |AssociatedLieAlgebra| |PowerSeriesLimitPackage| |RationalFunctionLimitPackage| |LinearDependence| |LinearlyExplicitRingOver| |ListToMap| |ListFunctions2| |ListFunctions3| |List| |LinearSystemFromPowerSeriesPackage| |ListMultiDictionary| |LeftModule| |ListMonoidOps| |LinearAggregate&| |LinearAggregate| |LocalPowerSeriesCategory| |ElementaryFunctionLODESolver| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorCategory| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |Logic&| |Logic| |Localize| |LinesOpPack| |LocalParametrizationOfSimplePointPackage| |LinearPolynomialEquationByFractions| |LiePolynomial| |ListAggregate&| |ListAggregate| |LinearSystemMatrixPackage1| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LieSquareMatrix| |LyndonWord| |LazyStreamAggregate&| |LazyStreamAggregate| |ThreeDimensionalMatrix| |ModularAlgebraicGcdOperations| |Magma| |MatrixManipulation| |MappingPackageInternalHacks1| |MappingPackageInternalHacks2| |MappingPackageInternalHacks3| |MappingPackage1| |MappingPackage2| |MappingPackage3| |MappingPackage4| |MatrixCategoryFunctions2| |MatrixCategory&| |MatrixCategory| |MatrixLinearAlgebraFunctions| |Matrix| |StorageEfficientMatrixOperations| |MultiVariableCalculusFunctions| |MatrixCommonDenominator| |MachineComplex| |MultiDictionary| |ModularDistinctDegreeFactorizer| |MeshCreationRoutinesForThreeDimensions| |MultFiniteFactorize| |MachineFloat| |ModularHermitianRowReduction| |MachineInteger| |MakeBinaryCompiledFunction| |MakeCachableSet| |MakeFloatCompiledFunction| |MakeFunction| |MakeRecord| |MakeUnaryCompiledFunction| |MultivariateLifting| |MonogenicLinearOperator| |MultipleMap| |MathMLFormat| |ModularField| |ModMonic| |ModuleMonomial| |ModuleOperator| |ModularRing| |Module&| |Module| |MoebiusTransform| |Monad&| |Monad| |MonadWithUnit&| |MonadWithUnit| |MonogenicAlgebra&| |MonogenicAlgebra| |Monoid&| |Monoid| |MonomialExtensionTools| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MultivariatePolynomial| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MonoidRingFunctions2| |MonoidRing| |MultisetAggregate| |Multiset| |MoreSystemCommands| |MergeThing| |MultivariateTaylorSeriesCategory| |MultivariateFactorize| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NonAssociativeAlgebra&| |NonAssociativeAlgebra| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagIntegrationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagInterpolationPackage| |NagFittingPackage| |NagOptimisationPackage| |NagMatrixOperationsPackage| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagLapack| |NagSpecialFunctionsPackage| |NAGLinkSupportPackage| |NonAssociativeRng&| |NonAssociativeRng| |NonAssociativeRing&| |NonAssociativeRing| |NumericComplexEigenPackage| |NumericContinuedFraction| |NonCommutativeOperatorDivision| |NewtonInterpolation| |NumberFieldIntegralBasis| |NumericalIntegrationProblem| |NonLinearSolvePackage| |NonNegativeInteger| |NonLinearFirstOrderODESolver| |NoneFunctions1| |None| |NormInMonogenicAlgebra| |NormalizationPackage| |NormRetractPackage| |NottinghamGroup| |NPCoef| |NewtonPolygon| |NumericRealEigenPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2| |NewSparseUnivariatePolynomial| |NumberTheoreticPolynomialFunctions| |NormalizedTriangularSetCategory| |Numeric| |NumberFormats| |NumericalIntegrationCategory| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |NumericTubePlot| |OrderedAbelianGroup| |OrderedAbelianMonoid| |OrderedAbelianMonoidSup| |OrderedAbelianSemiGroup| |OrderedCancellationAbelianMonoid| |OctonionCategory&| |OctonionCategory| |OctonionCategoryFunctions2| |Octonion| |OrdinaryDifferentialEquationsSolverCategory| |ConstantLODE| |ElementaryFunctionODESolver| |ODEIntensityFunctionsTable| |ODEIntegration| |AnnaOrdinaryDifferentialEquationPackage| |PureAlgebraicLODE| |PrimitiveRatDE| |NumericalODEProblem| |PrimitiveRatRicDE| |RationalLODE| |ReduceLODE| |RationalRicDE| |SystemODESolver| |ODETools| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrderlyDifferentialVariable| |OrderedFreeMonoid| |OrderedIntegralDomain| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathErrorKind| |OpenMathError| |ExpressionToOpenMath| |OppositeMonogenicLinearOperator| |OpenMath| |OpenMathPackage| |OrderedMultisetAggregate| |OpenMathServerPackage| |OnePointCompletionFunctions2| |OnePointCompletion| |Operator| |OperationsQuery| |NumericalOptimizationCategory| |AnnaNumericalOptimizationPackage| |NumericalOptimizationProblem| |OrderedCompletionFunctions2| |OrderedCompletion| |OrderedFinite| |OrderingFunctions| |OrderedMonoid| |OrderedRing&| |OrderedRing| |OrderedSet&| |OrderedSet| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategory| |UnivariateSkewPolynomialCategoryOps| |SparseUnivariateSkewPolynomial| |UnivariateSkewPolynomial| |OrthogonalPolynomialFunctions| |OrdSetInts| |OutputForm| |OutputPackage| |OrderedVariableList| |OrdinaryWeightedPolynomials| |PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteFieldCategory| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfPerfectFieldCategory| |PseudoAlgebraicClosureOfRationalNumberCategory| |PseudoAlgebraicClosureOfRationalNumber| |PadeApproximants| |PadeApproximantPackage| |PAdicIntegerCategory| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForAlgebraicFunctionField| |Palette| |PolynomialAN2Expression| |ParametrizationPackage| |ParametricPlaneCurveFunctions2| |ParametricPlaneCurve| |ParametricSpaceCurveFunctions2| |ParametricSpaceCurve| |ParametricSurfaceFunctions2| |ParametricSurface| |PartitionsAndPermutations| |Patternable| |PatternMatchListResult| |PatternMatchable| |PatternMatch| |PatternMatchResultFunctions2| |PatternMatchResult| |PatternFunctions1| |PatternFunctions2| |Pattern| |PoincareBirkhoffWittLyndonBasis| |PolynomialComposition| |PartialDifferentialEquationsSolverCategory| |PolynomialDecomposition| |AnnaPartialDifferentialEquationPackage| |NumericalPDEProblem| |PartialDifferentialRing&| |PartialDifferentialRing| |PendantTree| |Permanent| |PermutationCategory| |PermutationGroup| |Permutation| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialFactorizationExplicit| |PrimeField| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PackageForPoly| |PointsOfFiniteOrderTools| |PartialFraction| |PartialFractionPackage| |PolynomialGcdPackage| |PermutationGroupExamples| |PolyGroebner| |PiCoercions| |PrincipalIdealDomain| |PositiveInteger| |PolynomialInterpolationAlgorithms| |PolynomialInterpolation| |PlacesCategory| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |ParametricLinearEquations| |PlotFunctions1| |Plot3D| |Plot| |PlotTools| |PolynomialPackageForCurve| |FunctionSpaceAssertions| |PatternMatchAssertions| |PatternMatchPushDown| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchPolynomialCategory| |FunctionSpaceAttachPredicates| |AttachPredicates| |PatternMatchQuotientFieldCategory| |PatternMatchSymbol| |PatternMatchTools| |PolynomialNumberTheoryFunctions| |Point| |PolToPol| |RealPolynomialUtilitiesPackage| |PolynomialFunctions2| |PolynomialToUnivariatePolynomial| |PolynomialCategory&| |PolynomialCategory| |PolynomialCategoryQuotientFunctions| |PolynomialCategoryLifting| |Polynomial| |PolynomialRoots| |U32VectorPolynomialOperations| |PlottablePlaneCurveCategory| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |PrimitiveArray| |PrimitiveFunctionCategory| |PrimitiveElement| |IntegerPrimesPackage| |PrintPackage| |ProjectiveAlgebraicSetPackage| |PolynomialRing| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PriorityQueueAggregate| |PseudoRemainderSequence| |ProjectiveSpaceCategory| |Partition| |PowerSeriesCategory&| |PowerSeriesCategory| |PlottableSpaceCurveCategory| |PolynomialSetCategory&| |PolynomialSetCategory| |PolynomialSetUtilitiesPackage| |PseudoLinearNormalForm| |PolynomialSquareFree| |PointCategory| |PointFunctions2| |PointPackage| |PartialTranscendentalFunctions| |PushVariables| |PAdicWildFunctionFieldIntegralBasis| |QuasiAlgebraicSet2| |QuasiAlgebraicSet| |QuasiComponentPackage| |QueryEquation| |QuotientFieldCategoryFunctions2| |QuotientFieldCategory&| |QuotientFieldCategory| |QuadraticForm| |QueueAggregate| |QuaternionCategory&| |QuaternionCategory| |QuaternionCategoryFunctions2| |Quaternion| |Queue| |RadicalCategory&| |RadicalCategory| |RadicalFunctionField| |RadixExpansion| |RadixUtilities| |RandomNumberSource| |RationalFactorize| |RationalRetractions| |RecursiveAggregate&| |RecursiveAggregate| |RealClosedField&| |RealClosedField| |ElementaryRischDE| |ElementaryRischDESystem| |TranscendentalRischDE| |TranscendentalRischDESystem| |RandomDistributions| |ReducedDivisor| |RealZeroPackage| |RealZeroPackageQ| |RealConstant| |RealSolvePackage| |RealClosure| |RecurrenceOperator| |ReductionOfOrder| |Reference| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |RepeatedDoubling| |RadicalEigenPackage| |RepeatedSquaring| |ResolveLatticeCompletion| |ResidueRing| |Result| |RetractableTo&| |RetractableTo| |RetractSolvePackage| |RandomFloatDistributions| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunction| |RootsFindingPackage| |RegularChain| |RandomIntegerDistributions| |Ring&| |Ring| |RationalInterpolation| |RectangularMatrixCategory&| |RectangularMatrixCategory| |RectangularMatrix| |RectangularMatrixCategoryFunctions2| |RightModule| |Rng| |RealNumberSystem&| |RealNumberSystem| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RecursivePolynomialCategory&| |RecursivePolynomialCategory| |RealRootCharacterizationCategory&| |RealRootCharacterizationCategory| |RegularSetDecompositionPackage| |RegularTriangularSetCategory&| |RegularTriangularSetCategory| |RegularTriangularSetGcdPackage| |RuleCalled| |RewriteRule| |Ruleset| |RationalUnivariateRepresentationPackage| |SimpleAlgebraicExtensionAlgFactor| |SimpleAlgebraicExtension| |SAERationalFunctionAlgFactor| |SingletonAsOrderedSet| |SortedCache| |StructuralConstantsPackage| |StochasticDifferential| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |SegmentFunctions2| |SegmentBindingFunctions2| |SegmentBinding| |SegmentCategory| |Segment| |SegmentExpansionCategory| |SetAggregate&| |SetAggregate| |SetCategoryWithDegree| |SetCategory&| |SetCategory| |SetOfMIntegersInOneToN| |Set| |SExpressionCategory| |SExpression| |SExpressionOf| |SimpleFortranProgram| |SquareFreeQuasiComponentPackage| |SquareFreeRegularTriangularSetGcdPackage| |SquareFreeRegularTriangularSetCategory| |SymmetricGroupCombinatoricFunctions| |SemiGroup&| |SemiGroup| |SplitHomogeneousDirectProduct| |SturmHabichtPackage| |ElementaryFunctionSign| |RationalFunctionSign| |SimplifyAlgebraicNumberConvertPackage| |SingleInteger| |StackAggregate| |SquareMatrixCategory&| |SquareMatrixCategory| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SquareFreeNormalizedTriangularSetCategory| |PolynomialSolveByFormulas| |RadicalSolvePackage| |TransSolvePackageService| |TransSolvePackage| |SortPackage| |ThreeSpace| |ThreeSpaceCategory| |SpecialOutputPackage| |SpecialFunctionCategory| |SplittingNode| |SplittingTree| |SquareMatrix| |StringAggregate&| |StringAggregate| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |Stack| |StreamAggregate&| |StreamAggregate| |SparseTable| |StepThrough| |StreamInfiniteProduct| |StreamTensor| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |Stream| |StringCategory| |String| |StringTable| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctionsNonCommutative| |StreamTranscendentalFunctions| |SubResultantPackage| |SubSpace| |SuchThat| |SparseUnivariateLaurentSeries| |FunctionSpaceSum| |RationalFunctionSum| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePolynomialExpressions| |SupFractionFactorizer| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |Switch| |Symbol| |SymmetricFunctions| |SymmetricPolynomial| |TheSymbolTable| |SymbolTable| |SystemSolvePackage| |TableauxBumpers| |Tableau| |Table| |TangentExpansions| |TableAggregate&| |TableAggregate| |TabulatedComputationPackage| |TemplateUtilities| |TexFormat1| |TexFormat| |TextFile| |ToolsForSign| |TopLevelThreeSpace| |TranscendentalFunctionCategory&| |TranscendentalFunctionCategory| |Tree| |TrigonometricFunctionCategory&| |TrigonometricFunctionCategory| |TrigonometricManipulations| |TriangularMatrixOperations| |TranscendentalManipulations| |TriangularSetCategory&| |TriangularSetCategory| |TaylorSeries| |TubePlot| |TubePlotTools| |Tuple| |TwoFactorize| |Type| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |UniqueFactorizationDomain&| |UniqueFactorizationDomain| |UnivariateFormalPowerSeriesFunctions| |UnivariateFormalPowerSeries| |UnivariateLaurentSeriesFunctions2| |UnivariateLaurentSeriesCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeries| |UnivariateFactorize| |UniversalSegmentFunctions2| |UniversalSegment| |UnivariatePolynomialFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomial| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategory| |UnivariatePowerSeriesCategory&| |UnivariatePowerSeriesCategory| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesCategory| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnaryRecursiveAggregate&| |UnaryRecursiveAggregate| |UnivariateTaylorSeriesFunctions2| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesCategory| |UnivariateTaylorSeries| |UnivariateTaylorSeriesODESolver| |UTSodetools| |TaylorSolve| |UnivariateTaylorSeriesCZero| |Variable| |VectorCategory&| |VectorCategory| |VectorFunctions2| |Vector| |TwoDimensionalViewport| |ThreeDimensionalViewport| |ViewDefaultsPackage| |ViewportPackage| |Void| |VectorSpace&| |VectorSpace| |WeierstrassPreparation| |WildFunctionFieldIntegralBasis| |WeightedPolynomials| |WuWenTsunTriangularSet| |XAlgebra| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |ExtensionField&| |ExtensionField| |XPBWPolynomial| |XPolynomialsCat| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ParadoxicalCombinatorsForStreams| |ZeroDimensionalSolvePackage| |IntegerLinearDependence| |IntegerMod| |Enumeration| |Mapping| |Record| |Union| |Category| |pointColorPalette| |acoshIfCan| |bivariateSLPEBR| |coerceP| |filterUpTo| |resetVariableOrder| |primitive?| |setErrorBound| |cRationalPower| |setOfMinN| |nullSpace| |solid| |node?| |squareMatrix| |fortranLinkerArgs| |irreducibleFactor| |zCoord| |deleteRoutine!| |translateToOrigin| |fractRadix| |lfintegrate| |top!| |call| |homogeneous| |withPredicates| |elem?| |representationType| |retract| |exptMod| |univariatePolynomialsGcds| |maxPower| |trace2PowMod| |subResultantChain| = |repeatUntilLoop| |sechIfCan| |fresnelC| |linearPart| |resetBadValues| |contractSolve| |nsqfree| |double| |nthCoef| < |insert!| |inGroundField?| |tower| > |subscript| |mapmult| |transform| |zero?| <= |clipSurface| |cyclotomicDecomposition| |mainVariable?| |pole?| |bit?| >= |uniform| |rotatex| |child| |sincos| |structuralConstants| |scale| |nextSubsetGray| |btwFact| |generalPosition| |vedf2vef| |vark| |nodeOf?| |transcendentalDecompose| |element?| |new| |middle| |purelyAlgebraic?| + |rk4qc| |mat| |OMopenFile| |iipolygamma| |subresultantSequence| - |setStatus| |polCase| |mix| |removeSquaresIfCan| |chiSquare1| / |hyperelliptic| |polyRing2UPUP| |supDimElseRittWu?| |powers| |rightFactorIfCan| |iicosh| |Is| |plus!| |fortranCharacter| |maxSubst| |iiasech| |close!| |identityMatrix| |iiBesselY| |ParCond| |getZechTable| |figureUnits| |antiCommutator| |yCoord| |normFactors| |coshIfCan| |generalSqFr| |alterDrift!| |normalise| |primintegrate| |rowEch| |makeSin| |radicalEigenvector| |numberOfChildren| |OMgetEndBind| |numFunEvals3D| |ffactor| |satisfy?| |projectivePoint| |reducedForm| |summation| |expandPower| |ldf2lst| |ramified?| |factorset| |scalarTypeOf| |nonLinearPart| |splitNodeOf!| |ode1| |setAttributeButtonStep| |sPol| |primlimintfrac| |stoseInvertibleSet| |open| |factorByRecursion| |numberOfDivisors| |root| |genericRightDiscriminant| |certainlySubVariety?| |qfactor| |mindegTerm| |dot| |contract| |exprex| |quasiMonic?| |tube| |range| |false| |clearDenominator| |transpose| |goto| |morphism| |alternative?| |integerIfCan| |pseudoDivide| |stirling2| |nthRoot| |removeConjugate| |ratDenom| |sqfree| |height| |leftRank| |topPredicate| |numberOfOperations| |polygamma| |label| |perfectSquare?| |intcompBasis| |addPoint| |opeval| |airyAi| |squareFree| |exactQuotient| |scalarMatrix| |operation| |mainVariable| |cycleLength| |SturmHabichtSequence| |randomR| |f2st| |subSet| |extension| |Ei6| |stiffnessAndStabilityFactor| |isamax| |sqfrFactor| |symmetricRemainder| |viewSizeDefault| |initiallyReduced?| |screenResolution3D| |complexForm| |transcendenceDegree| |f02akf| |insertBottom!| |super| |unary?| |showArrayValues| |cache| |lazy?| |f02ajf| |sequences| |genericLeftTraceForm| |yRange| |addmod| |stripCommentsAndBlanks| |f02agf| |daxpy| |algebraicVariables| |roughBasicSet| |associatedEquations| |pointData| |decreasePrecision| |commaSeparate| |tan2trig| |maxShift| |bipolarCylindrical| |f02aff| |ODESolve| |semiResultantReduitEuclidean| |permutationGroup| |readIfCan!| |systemSizeIF| |f02aef| |splitDenominator| |curryRight| |cCoth| |cyclicEntries| |minordet| |f02adf| |approxNthRoot| |printTypes| |prime?| |createMultiplicationMatrix| |f02abf| |primaryDecomp| |unrankImproperPartitions0| |constantCoefficientRicDE| |surface| |f02aaf| |parametrize| |dictionary| |compBound| F2EXPRR |mapExpon| |precision| |measure| |status| UP2UTS |heap| |remove!| |regime| |cond| |guessPade| |setRealSteps| |origin| |select!| |symmetricPower| |SturmHabichtCoefficients| |choosemon| |universe| |normal01| |cAcsch| D |eulerE| |lflimitedint| |infinityNorm| |addPointLast| |stepBlowUp| |resultantEuclideannaif| |depth| |mergeDifference| |rootOfIrreduciblePoly| |suppOfZero| |rowEchelonLocal| |torsion?| |physicalLength| |count| |subtractIfCan| |lfextlimint| |completeEchelonBasis| |trueEqual| |errorKind| |directory| |OMgetString| |createLowComplexityTable| |sinhIfCan| |semiResultantEuclidean2| |mask| |polygon?| |saturate| |split| |basicSet| |tValues| |ranges| |branchIfCan| |setMinPoints| |apply| |rarrow| |rightCharacteristicPolynomial| |rdregime| |isMult| |any| |showTheSymbolTable| |setAdaptive| |brace| |expint| |index?| |numberOfComponents| |cons| |imagj| |internalZeroSetSplit| |nthExpon| |copy| |selectNonFiniteRoutines| |totolex| |GospersMethod| |subPolSet?| |ipow| |numberPlacesDegExtDeg| |sup| |top| |df2fi| |zeroDimPrimary?| |number?| |leastAffineMultiple| |lastNonNull| |irreducibleRepresentation| |Ei| |fglmIfCan| |list| |evaluateInverse| |repeating| |zeroOf| |mulmod| |lcm| |notelem| |OMgetApp| |guess| |prem| |dflist| |hex| |blankSeparate| |identitySquareMatrix| |failed| |genusNeg| |positiveSolve| |monicCompleteDecompose| |product| |removeDuplicates| |mathieu12| |denomRicDE| |e02bcf| |fullOutput| |lieAdmissible?| |e02bbf| |collect| |rest| |pack!| |central?| |idealiserMatrix| |printHeader| |reverse| |e02baf| |latex| |affineRationalPoints| |printStatement| |setDifference| |e02akf| |leftTraceMatrix| |normalElement| |empty| |setIntersection| |e02ajf| |module| |lllip| |excpDivV| |permutations| |e04ycf| |reduceByQuasiMonic| |symmetricGroup| |limitedIntegrate| |setUnion| |rules| |stoseLastSubResultant| |e04ucf| |excepCoord| |swap| |exprHasLogarithmicWeights| |e04naf| |perspective| |size| |prevPrime| |basisOfLeftAnnihilator| |singular?| |substitute| |viewPosDefault| |e04mbf| |leadingSupport| |dihedral| |center| |setColumn!| |conditionP| |e04jaf| |exQuo| |replaceVarByOne| |inrootof| |symmetricProduct| |fullOut| |e04gcf| |reseed| |shiftHP| |purelyTranscendental?| |iroot| |e04fdf| |expandTrigProducts| |monicDecomposeIfCan| |doublyTransitive?| |schwerpunkt| |ratPoly| |e04dgf| |systemCommand| |floor| |evalADE| |seed| |f01ref| |weierstrass| |izamax| |complexEigenvalues| |aLinear| |f01rdf| |mapUnivariate| |cot2tan| |newtonPolySlope| |f01rcf| |degOneCoef| |ideal| |semiDiscriminantEuclidean| |f01qef| |iicos| |flush| |startTable!| |f01qdf| |postfix| |nilFactor| |conjug| |f01qcf| |regularRepresentation| |numeric| |OMgetEndAtp| |rootSplit| |f01mcf| |dmpToP| |basisOfRightAnnihilator| |radical| |hasTopPredicate?| |search| |f01maf| |ddot| |axes| |increase| |f01bsf| |mainValue| |infinity| |generators| |OMputSymbol| |f01brf| |affineAlgSetLocal| |elColumn2!| |index| |phiCoord| |maxDerivative| |divisors| |point| |selectMultiDimensionalRoutines| |OMconnInDevice| |zerosOf| |min| |lowerPolynomial| |init| |genus| |redpps| |subQuasiComponent?| |clearFortranOutputStack| |integralBasis| |basisOfRightNucleus| |createThreeSpace| |computeCycleEntry| |rotatey| |hadamard| |minimumDegree| |addMatchRestricted| |sncndn| |OMencodingBinary| |genericPosition| |bitTruth| |symbolIfCan| |cyclic?| |mvar| |expr| LE |conjugates| |leftTrim| |makeGraphImage| |ShiftAction| |recip| |property| |basisOfRightNucloid| |columnSpace| |exquo| |retractable?| |pol| |showScalarValues| |div| |vspace| |euclideanGroebner| |units| |stopTableGcd!| |radicalOfLeftTraceForm| |bits| |noncommutativeJordanAlgebra?| |showTypeInOutput| |cAcoth| |print| |leftFactorIfCan| ^= |univariateSolve| |nextColeman| |rischDE| |setRow!| |op| |branchPoint?| |collectUpper| |reduceRowOnList| |iomode| |rischNormalize| |numberOfCycles| |code| |shellSort| |halfExtendedSubResultantGcd1| |leadingIdeal| |primes| |solveid| |first| |OMgetInteger| NOT |ellipticCylindrical| OR |quasiRegular?| |infRittWu?| |subs2ndVar| |traceMatrix| |mergeFactors| |declare| AND |itsALeaf!| |bright| |pquo| |writable?| |qShiftC| |deleteProperty!| |associatedSystem| |maxint| |output| |hermite| |decrease| |SturmHabicht| |vertSplit| |right| |mkcomm| |fi2df| |horizConcat| |left| |parent| F2FG |Beta| |pointColor| |drawStyle| |stronglyReduce| |heapSort| |lambda| |FormatArabic| |constantOperator| |Gamma| |generic?| |dn| |OMopenString| |taylor| * |deref| |tracePowMod| |laurent| |axServer| |rightRemainder| |randomLC| |puiseux| |multiServ| |fixedPoint| |horizSplit| |bezoutResultant| GE |shuffle| |polynomial| |coordinate| |coerceImages| |Nul| |leftScalarTimes!| |lazyPrem| |bernoulliB| |leftUnits| |pointSizeDefault| |assoc| |ramifiedAtInfinity?| |createNormalPrimitivePoly| |positive?| |HenselLift| |typeList| |scan| |safeCeiling| |element| |printInfo!| |setCurve| |closedCurve?| |bfKeys| |critBonD| |compiledFunction| |dcabs1| |isTimes| |OMmakeConn| |LazardQuotient| |setVariableOrder| |columns| |RittWuCompare| |script| |extendIfCan| |mpsode| |interpret| |intersect| |OMputApp| |finiteSeries2Vector| |bezoutDiscriminant| |cosIfCan| |mainCoefficients| |df2st| |radicalSolve| |cyclicGroup| |delete| |multiplicity| |subscriptedVariables| |legendre| |ReduceOrder| |critM| |size?| |packModulus| |dasum| |double?| |fortran| |power| |subst| |icamax| |edf2fi| |OMgetEndAttr| |placesAbove| |dfRange| |coefficient| |coerceListOfPairs| |LiePoly| |cardinality| |iiacsch| |OMgetEndApp| |areEquivalent?| |OMReadError?| |level| |midpoints| |powmod| |setButtonValue| |cosh2sech| |definingEquations| |bivariatePolynomials| |oddlambert| |minimalForm| |anticoord| |gcdcofact| |extend| |polyRingToBlUpRing| |coercePreimagesImages| |color| |setsubmult!| |setClipValue| |exprHasWeightCosWXorSinWX| |viewThetaDefault| |minPoints| |critT| |returns| |pointValue| |leftCharacteristicPolynomial| |csc2sin| |cyclicSubmodule| |maxLevel| |d02bhf| |headReduced?| |numberOfPrimitivePoly| |unaryFunction| |divideExponents| |mathieu23| |resultantReduitEuclidean| |d02bbf| |fullPartialFraction| |e02ahf| |rectangularMatrix| ~ |tab1| |chiSquare| |trunc| |green| |whileLoop| |parts| |front| |separate| |substring?| |cylindrical| |char| |factorFraction| |numericIfCan| |neglist| |LiePolyIfCan| |constantKernel| |leadingBasisTerm| |limitPlus| |safety| |interReduce| |alternatingGroup| |maxIndex| |plenaryPower| |maxPoints| |karatsubaOnce| |getPickedPoints| |d03faf| |setTower!| |makeSketch| |affineAlgSet| |DiffAction| |leftUnit| |d03eef| |bernoulli| |leadingCoefficientRicDE| |froot| |sorted?| |droot| |next| |nextPrimitivePoly| |create3Space| |leftRecip| |PDESolve| |rightAlternative?| |d03edf| |numberOfComputedEntries| |rootPower| |doubleRank| |weakBiRank| |combineFeatureCompatibility| |crushedSet| |useSingleFactorBound?| |autoReduced?| |setPredicates| |rationalFunction| |biRank| |oneDimensionalArray| |linearBezier| |cAtan| |commutativeEquality| |graphStates| |suffix?| |getGoodPrime| |chainSubResultants| |mapUp!| |setleaves!| |normal| |mapBivariate| |commutative?| |Ei2| |localParamV| |logical?| |normalizeAtInfinity| |ramifMult| |applyTransform| |test| |listOfTerms| |semiResultantEuclidean1| |computeInt| |nand| |sbt| |blowUp| |input| |factorUsingMusser| |tex| |pile| |goppaCode| |closedCurve| |coerceL| |stoseInvertibleSetsqfreg| |rightUnit| |comparison| |nary?| |properties| |Ei3| |block| |solveLinear| |useSingleFactorBound| |countRealRoots| |acsch| |semicolonSeparate| |initial| |setright!| |printCode| |every?| |leftDiscriminant| |numberOfValuesNeeded| |OMgetSymbol| |vertConcat| |graphCurves| |brillhartIrreducible?| |noLinearFactor?| |nor| |taylorRep| |discriminant| |pointInIdeal?| |interval| |composites| |leftExtendedGcd| |setPosition| |alphabetic| |complexNormalize| |setPoly| |charClass| |upperCase?| |tryFunctionalDecomposition?| |var1StepsDefault| |hue| |permutation| |denominators| |rightMinimalPolynomial| |stoseInvertible?sqfreg| |LyndonCoordinates| |fillPascalTriangle| |complementaryBasis| |characteristic| |modularGcd| |numerators| |sparsityIF| |invmod| |delete!| |fracPart| |outputForm| |value| |readLine!| |symbol?| |reducedContinuedFraction| |spherical| |xRange| |KrullNumber| |setchildren!| |unitsColorDefault| |more?| |showAll?| |read!| |multiEuclideanTree| |wreath| |cyclotomicFactorization| |tubePoints| |pushup| |exteriorDifferential| |groebnerIdeal| |someBasis| |exponential1| |boundOfCauchy| |finiteBasis| |binaryFunction| |c05nbf| |invertibleSet| |prefix?| |solveRetract| |reverseLex| |virtualDegree| |wholeRadix| |machineFraction| |Ei4| |previous| |c05adf| |dimensions| |sinhcosh| |cAtanh| |realZeros| |logGamma| |inverseLaplace| |c06gsf| |rem| |addBadValue| |insertionSort!| |Lazard| |singularPoints| |bumprow| |monicLeftDivide| |rotatez| |c06gqf| |varList| |symmetricTensors| |placesOfDegree| |nodes| |move| |subTriSet?| |newTypeLists| |divOfPole| |fTable| |quo| |lieAlgebra?| |c06gcf| |sample| |OMgetEndObject| |algebraic?| |leadingIndex| |additive?| |sayLength| |lastSubResultantEuclidean| |rk4a| |removeSuperfluousQuasiComponents| |c06gbf| |palglimint0| |datalist| |guessAlg| |coefOfFirstNonZeroTerm| |prod| |/\\| |c06fuf| |pastel| |badNum| |backOldPos| |setImagSteps| |extract!| |foundZeroes| |acosIfCan| |\\/| |completeSmith| |basis| |c06frf| |OMcloseConn| |reduced?| |lazyPseudoDivide| |removeZero| |insertTop!| |optAttributes| |closed?| |getCode| |c06fqf| |OMputString| |var1Steps| |realElementary| |specialTrigs| |c06fpf| |padicFraction| |hspace| |countRealRootsMultiple| |OMgetAttr| |cfirst| |statusIto| |listOfLists| |c06ekf| |aQuartic| ~= |foundPlaces| |abs| |OMputError| |crest| |plot| |composite| |edf2ef| |encode| |determinant| |simplifyPower| |resetNew| |c06ecf| |listOfMonoms| |partition| |Vectorise| |createPrimitiveElement| |rightOne| |po| |increment| |iFTable| |c06ebf| |reducedSystem| |check| |createIrreduciblePoly| |quickSort| |divisorAtDesingTree| |iiasin| |expIfCan| |collectUnder| |c06eaf| |semiResultantEuclideannaif| |iisinh| |mathieu24| |constantIfCan| |stopMusserTrials| |s17def| |discriminantEuclidean| |algebraicSort| Y |simplifyExp| |components| |kmax| |LyndonBasis| |orderIfNegative| |generator| |s17dcf| |rroot| |normalForm| |rootNormalize| |besselJ| |univariatePolynomials| |useEisensteinCriterion?| |getMultiplicationTable| |guessBinRat| |computeBasis| |factorsOfDegree| |s17akf| |rewriteIdealWithHeadRemainder| |createLowComplexityNormalBasis| |evenInfiniteProduct| |cscIfCan| |factorAndSplit| |leftZero| |maxPoints3D| |socf2socdf| |s17ajf| |quotVecSpaceBasis| |makeViewport2D| |subCase?| |atom?| |att2Result| |makeEq| |OMputEndError| |isPlus| |s17ahf| |invertible?| |leftRankPolynomial| |leftNorm| |toseLastSubResultant| |arg1| |s17agf| |stopTable!| |thetaCoord| |OMgetType| |completeEval| |primeFactor| |rightLcm| |digamma| |arg2| |eq| |addMatch| |cyclePartition| |s17aff| |factorCantorZassenhaus| |totalDegree| UTS2UP |linearAssociatedExp| |symbNameV| |rightScalarTimes!| |s17aef| LT |variationOfParameters| |key?| |rightExtendedGcd| |multiple?| |s17adf| |indicialEquation| |makingStats?| |close| |diophantineSystem| |padecf| |probablyZeroDim?| |optimize| |transcendent?| |rowEchWoZeroLines| |Zero| |shallowCopy| |nonSingularModel| |signAround| |s17acf| |unmakeSUP| |lazyGintegrate| |roman| |shiftInfoRec| |iiBesselJ| |s15aef| |argumentListOf| |interpolateFormsForFact| |setCondition!| |controlPanel| |tableau| |triangSolve| |jordanAdmissible?| |s15adf| |listSD| |stoseSquareFreePart| |lo| |getCurve| |maxrank| |nthFlag| |rename| |pointV| |squareFreeFactors| |defineProperty| |LazardQuotient2| |incr| |s14baf| |fortranLiteralLine| |axesColorDefault| |normalDeriv| |totalGroebner| |zeroDimensional?| |display| |genericRightNorm| |hi| |s14abf| |checkOptions| |intersectionDivisor| |cCsc| |principal?| |s14aaf| |complete| |direction| |putGraph| |fractRagits| |divOfZero| |possiblyInfinite?| |swap!| |poisson| |s13adf| |sign| |showClipRegion| |map!| |refine| |compose| |rst| |complexLimit| |divideIfCan!| |iilog| |realEigenvalues| |epilogue| |s13acf| |removeRedundantFactorsInPols| |dequeue| |elliptic| |constantLeft| |actualExtensionV| |clipBoolean| |retractToGrn| |replaceDiffs| |symFunc| |s13aaf| |outputSpacing| |initializeParamOfPlaces| |integralDerivationMatrix| |leadingExponent| |fortranInteger| |maxdeg| |s01eaf| |solveLinearPolynomialEquation| |tubeRadiusDefault| |complexIntegrate| |s21bdf| |sturmVariationsOf| |quote| |or| |viewpoint| |bat1| |invertibleElseSplit?| |isPower| |elRow2!| |constantToUnaryFunction| |laurentIfCan| |LagrangeInterpolation| |expenseOfEvaluation| |makeCrit| |selectPolynomials| |seriesToOutputForm| |s21bcf| |selectfirst| |listexp| |nextNormalPrimitivePoly| |semiSubResultantGcdEuclidean1| |iiasinh| |validExponential| |integralMatrixAtInfinity| |generalCoefficient| |s21bbf| |problemPoints| |remainder| |companionBlocks| |diffHP| |polynomialZeros| |adaptive| |doubleDisc| |coHeight| |s21baf| |lineColorDefault| |ldf2vmf| |dimension| |factorsOfCyclicGroupSize| |log2| |OMParseError?| |limit| |meshPar1Var| |s20adf| |incrementBy| |outlineRender| |coth2tanh| |changeMeasure| |clearTheFTable| |cAcos| |plus| |generate| |e02agf| |messagePrint| |infieldint| |cLog| |strongGenerators| |leftMult| |imagE| |match?| |truncate| |s20acf| |adjoint| |lBasis| |hasPredicate?| |redmat| |quoByVar| |LowTriBddDenomInv| |slex| |expand| |d01aqf| |parametersOf| |viewDeltaYDefault| |mapUnivariateIfCan| |lyndonIfCan| |perfectSqrt| |divide| |OMUnknownCD?| |filterWhile| |s19adf| |directSum| |gradient| |movedPoints| |tensorMap| |d01apf| |lastSubResultantElseSplit| |wholePart| |filterUntil| |numericalIntegration| |palgRDE| |pmComplexintegrate| |lazyEvaluate| |exp1| |maxDegree| |overlabel| |setref| |select| |s19acf| |tryFunctionalDecomposition| |palgextint0| |binomThmExpt| |headRemainder| |gethi| |algebraicSet| |setsubMatrix!| |wordsForStrongGenerators| |d01anf| |solve1| |localPointV| |groebSolve| |rationalPoint?| |createPrimitiveNormalPoly| |d01amf| |radicalEigenvalues| |ref| |constant?| |UnVectorise| |reopen!| |setOrder| |extractProperty| |newReduc| |BumInSepFFE| |graphImage| |d01alf| |augment| |oddInfiniteProduct| |prinpolINFO| |monomRDEsys| |bumptab1| |minimize| |patternVariable| |s19abf| |quasiRegular| |complexEigenvectors| |rombergo| |outputArgs| |iiBeta| |factorSquareFree| |insert| |makeRecord| |d01akf| |lagrange| |hash| |selectSumOfSquaresRoutines| |inconsistent?| |quoted?| |Frobenius| |fortranLiteral| |gnuDraw| |univariate?| |uniform01| |s19aaf| |qShiftAction| |ocf2ocdf| |cycleTail| |viewZoomDefault| |setcurve!| |d01ajf| |showRegion| GT |besselK| |multinomial| |setLabelValue| |semiIndiceSubResultantEuclidean| |mapDown!| |multMonom| |s18def| |numberOfComposites| |nextsubResultant2| |ceiling| |complexElementary| |eigenvectors| |approximants| |besselI| |pdf2df| |terms| |realSolve| |s18dcf| |resize| |testDim| |padicallyExpand| |exprHasAlgebraicWeight| |hasHi| |functionNames| |complexNumericIfCan| |fresnelS| |s18aff| |create| |rationalPlaces| |cyclotomic| |evalIfCan| |setlast!| |elliptic?| |genusTree| |s18aef| |minRowIndex| |float?| |eyeDistance| |infiniteProduct| |baseRDEsys| |lllp| |iiexp| |rank| |critMonD1| |s18adf| |singularPointsWithRestriction| |moduloP| |stopTableInvSet!| |orthonormalBasis| |trapezoidal| |reshape| |lowerCase| |OMsend| |gbasis| |s18acf| |ShiftC| |findCycle| |functionIsContinuousAtEndPoints| |extractPoint| |pdf2ef| |inf| |updateStatus!| |f04qaf| |bumptab| |bombieriNorm| |xCoord| |outputList| |dscal| |credPol| |indiceSubResultant| |cycles| |lprop| |f04mcf| |drawCurves| |leaves| |createPrimitivePoly| |polyPart| |functionIsFracPolynomial?| |displayKind| |taylorQuoByVar| |f04mbf| |critB| |characteristicPolynomial| |stiffnessAndStabilityOfODEIF| |localize| |separateDegrees| |displayAsGF| |OMgetVariable| |f04maf| |pade| |findOrderOfDivisor| |hcrf| |simpleBounds?| |setDegree!| |indexName| |coord| |zRange| |f04jgf| |OMconnOutDevice| |subsInVar| |tRange| |linearDependence| |character?| |extensionDegree| |lifting| |f04faf| |tanh2trigh| |iitan| |changeWeightLevel| |innerint| |checkRur| |OMgetEndError| |infix| |f04axf| |indices| |oblateSpheroidal| |prologue| |flexibleArray| |exprToXXP| |setpoint!| |dark| |aQuadratic| |f04atf| |tanIfCan| |fortranLogical| |prepareSubResAlgo| |getButtonValue| |f04asf| |asimpson| |primitiveElement| |setMaxPoints| |antiAssociative?| |localUnquote| |removeRoughlyRedundantFactorsInPol| |distribute| |keys| |graphState| |OMlistCDs| |coefChoose| |clipWithRanges| |sech2cosh| |inRadical?| |lazyResidueClass| |bandedJacobian| |atoms| SEGMENT |f04arf| |polyRicDE| |antiCommutative?| |integrate| |radix| |iidprod| |copyIto| |iiacot| |charthRoot| |groebner?| |curryLeft| |prefixRagits| |palgextint| |f04adf| |stosePrepareSubResAlgo| |shiftRight| |showIntensityFunctions| |initiallyReduce| |imagI| |blowUpWithExcpDiv| |factor1| |addPoint2| |numberOfHues| |cosSinInfo| |rk4| |dmp2rfi| |appendPoint| |basisOfLeftNucleus| |prefix| |solve| |idealiser| FG2F |nonQsign| |common| |fprindINFO| |mesh| |setchart!| |quadTransform| |digit?| |OMreceive| |cothIfCan| |setStatus!| |characteristicSet| |integer?| |curveColorPalette| |MPtoMPT| |var2Steps| |continue| |fixedDivisor| |semiDegreeSubResultantEuclidean| |pattern| |sylvesterMatrix| |Hausdorff| |subResultantGcd| |internalSubPolSet?| |head| |evenlambert| |getEq| |objectOf| |definingPolynomial| |musserTrials| |modifyPointData| |generic| |guessRec| |isAbsolutelyIrreducible?| |drawComplex| |ScanFloatIgnoreSpacesIfCan| |plotPolar| |getGraph| |f07fef| |distinguishedCommonRootsOf| |rightFactorCandidate| |mightHaveRoots| |squareFreePart| |karatsubaDivide| |imagk| |setlocalPoint!| |rightRecip| |algint| |sh| |f07fdf| |dznrm2| |setFieldInfo| |balancedFactorisation| |flagFactor| |Si| |tanhIfCan| |f07aef| |wrregime| |palgintegrate| |low| |graeffe| |f07adf| |errorInfo| |stoseIntegralLastSubResultant| |differentialVariables| |guessADE| |zeroDim?| |OMputInteger| |startPolynomial| |lyndon?| |lighting| |harmonic| |curve?| |maxrow| |build| |s17dlf| |baseRDE| |singRicDE| |decompose| |cot2trig| |rightTraceMatrix| |s17dhf| |ScanFloatIgnoreSpaces| |psolve| |reindex| |secIfCan| |yellow| |matrixConcat3D| |option| |packageCall| |s17dgf| |omError| |unrankImproperPartitions1| |lowerCase!| |rootKerSimp| |inHallBasis?| |f02xef| |viewDefaults| |factorial| |rootRadius| |changeNameToObjf| |cubic| |f02wef| |getBadValues| |findCoef| |copyInto!| |OMputEndApp| |OMbindTCP| |prindINFO| |f02fjf| |newtonPolygon| |firstDenom| |And| |radicalSimplify| |changeThreshhold| |argument| |f02bjf| |recoverAfterFail| |update| |argumentList!| |idealSimplify| |weights| |minGbasis| |f02bbf| |setEpilogue!| |moreAlgebraic?| |associative?| |eisensteinIrreducible?| |f02axf| |numberRatPlacesExtDeg| |iiAiryAi| |enqueue!| |submod| |printingInfo?| |printInfo| |f02awf| |copyDrift| |mesh?| |isList| |pointPlot| |scripted?| |infClsPt?| |mainContent| |multiple| |overlap| |setScreenResolution| |exprToGenUPS| |decimal| |optional| |presuper| |failed?| |translate| |normDeriv2| |leftExactQuotient| |rationalIfCan| |entries| |OMputEndObject| |not| |lazyIntegrate| |listVariable| |domainOf| |rk4f| |groebnerFactorize| |tubePointsDefault| |mapCoef| |ignore?| |normalizeIfCan| |degreePartition| |univariatePolynomial| |insertRoot!| |copies| |applyQuote| |leastPower| |pureLex| |iflist2Result| |concat!| |factorSquareFreeByRecursion| |sturmSequence| |shufflein| |makeCos| |table| |extractTop!| |integralRepresents| |reverse!| |logIfCan| |copyBSD| |knownInfBasis| |purelyAlgebraicLeadingMonomial?| |fortranTypeOf| |loopPoints| |xor| |ode| |cTan| |null| |newton| |inverseColeman| |nullary| |firstUncouplingMatrix| |setAdaptive3D| |matrixDimensions| |member?| |viewport2D| |iicsch| |biringToPolyRing| |functionName| |raisePolynomial| |sort| |An| |Ei5| |elRow1!| |cAcosh| |zeta| |rightPower| EQ |singleFactorBound| |basisOfNucleus| |conjugate| |isExpt| |completeHermite| |edf2df| |space| |deepExpand| |divergence| |superHeight| |powern| |obj| |extendedResultant| |unit| |xn| |mainPrimitivePart| |string?| |traverse| |mkAnswer| |orbit| |ScanRoman| |qsetelt!| |allPairsAmong| |pseudoQuotient| |scaleRoots| |component| |bitLength| |quotient| |setPrologue!| |besselY| |jacobiIdentity?| |changeVar| |infinite?| |trivialIdeal?| |OMputBind| |colorDef| |comp| |cCos| |intermediateResultsIF| |iiacsc| |rootProduct| |wronskianMatrix| |bag| |removeSinSq| |showTheIFTable| |ef2edf| |ddFact| |trapezoidalo| |desingTreeWoFullParam| |deepestInitial| |consnewpol| |cTanh| |processTemplate| |gcd| |option?| |FormatRoman| |reduceLineOverLine| |weight| |hasSolution?| |janko2| |Not| |testModulus| |internalAugment| |ksec| |partialNumerators| |sizePascalTriangle| |karatsuba| |symmetric?| |exprToUPS| |debug3D| |unexpand| |extendedEuclidean| |inc| |relativeApprox| |rowEchWoZeroLinesWOVectorise| |Or| |minColIndex| |csch2sinh| |numberOfVariables| |nullity| |atanIfCan| |roughUnitIdeal?| |root?| |untab| |explimitedint| |makeVariable| |factorList| |patternMatch| |createHN| |definingField| |predicate| |palgint0| |toseInvertible?| |nextsousResultant2| |outputFixed| |lift| |sizeLess?| |leaf?| |setexcpDiv!| |OMserve| |reduce| |iCompose| |removeCosSq| |primPartElseUnitCanonical| |localParamOfSimplePt| |algintegrate| |returnTypeOf| |OMclose| |sin?| |matrixGcd| |cos2sec| |solveLinearPolynomialEquationByFractions| |cAsin| |toroidal| |generalLambert| |pointLists| |diagonalMatrix| |rule| |collectQuasiMonic| |stirling1| |setFoundPlacesToEmpty| |region| |gramschmidt| |differentiate| |initParLocLeaves| |bitCoef| |guessHolo| |stFuncN| |leviCivitaSymbol| |singularitiesOf| |checkPrecision| |ruleset| |pToDmp| |vectorcombination| |clearCache| |extractClosed| |OMputEndBind| |fixedPoints| |getDomains| |binaryTournament| |vector| |rightZero| |discreteLog| |identification| |coordinates| |qPot| |eigenvector| |perfectNthPower?| |OMputVariable| GF2FG |void| |entry?| |duplicates?| |magnitude| |beauzamyBound| |linearlyDependentOverZ?| |mainCharacterization| |explicitlyEmpty?| |vectoraddmul| |rational?| |lowerCase?| |setMaxPoints3D| |paraboloidal| |frst| |iiGamma| |primitivePart!| |singularAtInfinity?| |truncatedmultiplication| |setleft!| |removeFirstZeroes| |midpoint| |mr| |conditionsForIdempotents| |nextPartition| |resultant| |closeComponent| |listBranches| |coefficients| |rhs| |modulus| |selectsecond| |leftRemainder| |bezoutMatrix| |basisOfCommutingElements| |length| |name| |stoseInvertible?| |newElement| |rightRank| |extractBottom!| |scripts| |summary| |groebgen| |bsolve| |lazyPseudoQuotient| |constant| |show| |graphs| |createMultiplicationTable| |iprint| |fortranDouble| |tanAn| |truncatedmuladd| |e02aef| |makeResult| |bandedHessian| |redPol| |outputMeasure| |extractIndex| |clikeUniv| |trailingCoefficient| |maxColIndex| |belong?| |c02agf| |leftDivide| |unitNormalize| |setTopPredicate| |fffg| |c02aff| |lintgcd| |replaceKthElement| |squareFreePrim| |e02adf| |mapMatrixIfCan| |alphanumeric?| |tomodpa| |c05pbf| |createRandomElement| |numberOfIrreduciblePoly| |multiset| |mainSquareFreePart| |showAttributes| |minus!| |rootBound| |deepCopy| |minimalPolynomial| |credits| |last| |compile| |One| |hitherPlane| |lazyPseudoRemainder| |scanOneDimSubspaces| |removeDuplicates!| |remainder!| |setClosed| |ptree| |e01sef| |lazyVariations| |geometric| |OMputAtp| |wordInStrongGenerators| |e01saf| |viewWriteAvailable| |suppOfPole| |setelt!| |infix?| |e01daf| |oddintegers| |vectorise| |leftPower| |elt| |e01bhf| |merge!| |internalIntegrate| |mulbyscalar| |LPolynomial| |setelt| |cExp| |e01bgf| |random| |shanksDiscLogAlgorithm| |factorials| |triangular?| |e01bff| |is?| |rowEchelon| |int| |chebyshevU| |e01bef| |rightGcd| |chebyshevT| |curry| |fill!| |e01baf| |conditions| |sinIfCan| |kroneckerDelta| |canonicalIfCan| |e02zaf| |ord| |copy!| |splitSquarefree| |e02gaf| |intPatternMatch| |fmecg| |randnum| F |e02dff| |cSec| |cycleSplit!| |mulbybinomial| |e02def| |reset| |selectIntegrationRoutines| |dimensionsOf| |dswap| |e02ddf| |write| |vconcat| |principalIdeal| |mul| |e02dcf| |save| |pair?| |cAsech| |optional?| |e02daf| |firstExponent| |goodPoint| |solveLinearlyOverQ| |palginfieldint| |e02bef| |basisOfMiddleNucleus| |iiacos| |pow| |variable| |leftRegularRepresentation| |e02bdf| |preprocess| |fractionPart| |laplace| |numFunEvals| |outerProduct| |minusInfinity| |shift| |lazyIrreducibleFactors| |coth2trigh| |antisymmetric?| |plusInfinity| |rationalPoints| |over| |lambert| |real| |gderiv| |find| |frobenius| |complex| |approxSqrt| |htrigs| |stronglyReduced?| |extendedgcd| |guessPRec| |compactFraction| |innerSolve1| |drift| |declare!| |leftGcd| |alternating| |OMputEndAttr| |retractIfCan| |order| |integralMatrix| |affineSingularPoints| |OMUnknownSymbol?| |equality| |minset| |mindeg| |birth| |arrayStack| |dnrm2| |evalat| |laguerreL| |nil| |d01gbf| |theCurve| |bfEntry| |coleman| |binarySearchTree| |semiSubResultantGcdEuclidean2| |cSin| |d01gaf| |presub| |basisOfCentroid| |realRoots| |divideIfCan| |asecIfCan| |d01fcf| |hermiteH| |suchThat| |rotate| |bracket| |generateIrredPoly| |resetAttributeButtons| |approximate| |d01bbf| |clearTable!| |listRepresentation| |exponents| |divide!| |squareFreeLexTriangular| |d01asf| |acschIfCan| |isOp| |safeFloor| |unitVector| |generalizedEigenvectors| |anfactor| |hdmpToDmp| |denominator| |classNumber| |resultantnaif| |cn| |rightTrim| |genericRightMinimalPolynomial| |d02raf| |child?| |prinshINFO| |overset?| |sumOfSquares| |printStats!| |d02kef| |radicalRoots| |clip| |intensity| |jacobian| |newLine| |d02gbf| |ratpart| |remove| |monomialIntegrate| |copyslice| |antisymmetricTensors| |blockSplit| |d02gaf| |dcopy| |dioSolve| |wordInGenerators| |Lazard2| |readLineIfCan!| |variables| |d02ejf| |zaxpy| |currentSubProgram| |setnext!| |internalIntegrate0| |resultantReduit| |times| |d02cjf| |dim| |simpsono| |rightQuotient| |nthr| |initializeGroupForWordProblem| |contains?| |rewriteIdealWithQuasiMonicGenerators| |rdHack1| |particularSolution| |prepareDecompose| |numberOfMonomials| |dominantTerm| |shallowExpand| |copyfirst| |modTree| |Aleph| |Ci| |derivationCoordinates| |f2df| |OMgetBVar| |safetyMargin| |node| |rightTrace| |sn| |getOrder| |guessHP| |quatern| |getOp| |title| |removeConstantTerm| |clearTheSymbolTable| |leftOne| |box| |limitedint| |partialFraction| |powerSum| |any?| |integerDecode| |setFoundZeroes| |quadraticForm| |distFact| |maximumExponent| |transCoord| |finite?| |blockConcat| |constantRight| |resultantEuclidean| |t| |completeHensel| |basisOfLeftNucloid| |En| |algSplitSimple| |pointColorDefault| |union| |largest| |trace| |idamax| |findTerm| |monicRightFactorIfCan| |less?| |checkForZero| |indicialEquations| |lexGroebner| |fractionFreeGauss!| |npcoef| |df2mf| |listLoops| |rangePascalTriangle| |makeFR| |genericLeftMinimalPolynomial| |fixedPointExquo| |constantOpIfCan| |distance| |true| |log| |explicitlyFinite?| |finiteSeries2LinSysWOVectorise| |seriesSolve| |iisqrt2| |bandMatrix| |quadratic?| |overbar| |useNagFunctions| |desingTree| |modularGcdPrimitive| |leftTrace| |rowEchLocal| |setEmpty!| |startTableGcd!| |outputAsTex| |lp| |eigenvalues| |addiag| |physicalLength!| |commonDenominator| |henselFact| |lquo| |mapdiv| |complement| |doubleFloatFormat| |bipolar| |lists| |paren| |charpol| |quotedOperators| |multiEuclidean| |meshFun2Var| |aRow| |algDsolve| |diag| |degreeOfMinimalForm| |computeCycleLength| |generalInfiniteProduct| |simpson| |setProperty| |aromberg| |bivariate?| |rename!| |cAcot| |rootsOf| |has?| |bubbleSort!| |enumerate| |rightNorm| |rCoord| |llprop| |posExpnPart| |nextLatticePermutation| |aColumn| |OMwrite| |swapColumns!| |qnew| |matrix| |eq?| |round| |rangeIsFinite| |moebius| |leftAlternative?| |lSpaceBasis| |groebner| |youngGroup| |sin2csc| |append| |OMlistSymbols| |repeating?| |binomial| |updatD| |createZechTable| |doubleResultant| |mainKernel| |e01sff| |function| |tableForDiscreteLogarithm| |modularFactor| |iiatan| |fintegrate| |iter| |cycleEntry| |generalTwoFactor| |permutationRepresentation| |moduleSum| |selectODEIVPRoutines| |createNormalElement| |multisect| |mapGen| |totalDifferential| |const| |width| |lookup| |distdfact| |listYoungTableaus| |rightMult| |genericLeftNorm| |twist| |inverseIntegralMatrixAtInfinity| |branchPointAtInfinity?| |iiBesselI| |linear| |removeRoughlyRedundantFactorsInContents| |lfinfieldint| |cSinh| |symmetricSquare| |ZetaFunction| |affinePoint| |B1solve| |guessRat| |brillhartTrials| |inBetweenExcpDiv| |internal?| |unravel| |degreeSubResultant| |meshPar2Var| |putColorInfo| |monomials| |OMgetBind| |zeroSquareMatrix| |variableName| |firstSubsetGray| |expextendedint| |list?| |leftMinimalPolynomial| |extendedSubResultantGcd| |realEigenvectors| |basisOfInterpolateForms| |quadratic| E1 |colorFunction| |integerBound| |clipPointsDefault| |numberOfFractionalTerms| |aspFilename| |OMputBVar| |linearlyDependent?| |getSmgl| |in?| |alphabetic?| |elementary| |rows| |rewriteIdealWithRemainder| |quasiMonicPolynomials| |SFunction| |unit?| |complex?| |incrementKthElement| |readable?| |numericalOptimization| |tubeRadius| |lfextendedint| |drot| |content| |OMencodingSGML| |highCommonTerms| |integralCoordinates| |palgLODE| |condition| |rightRegularRepresentation| |uncorrelated?| |curve| |exponential| |nrows| |alphanumeric| |showAllElements| |type| |makeop| |pdct| |symmetricDifference| |interpolateForms| |ncols| |pushuconst| |primextendedint| |OMunhandledSymbol| |removeRedundantFactorsInContents| |leftFactor| |perfectNthRoot| |multiplicative?| |lazyPquo| |expandLog| |endOfFile?| |implies| |match| |quasiComponent| |makeMulti| |initials| |ptFunc| |removeZeroes| |euler| |denomLODE| |hexDigit| |rootOf| |upDateBranches| |fullDisplay| |hMonic| |mainMonomials| |digit| |asechIfCan| |queue| |updatF| |formula| |palglimint| |genericLeftDiscriminant| |identity| |UpTriBddDenomInv| |prinb| |gcdPrimitive| |setrest!| |inverse| |exponent| |nextIrreduciblePoly| |relationsIdeal| |rquo| |expt| |packExps| |write!| |wholeRagits| |polygon| |roughSubIdeal?| |splitLinear| |parabolic| |lexico| |dimensionOfIrreducibleRepresentation| |basisOfInterpolateFormsForFact| |toseSquareFreePart| |complexZeros| |drotg| |subNode?| |totalLex| |subset?| |pop!| |cyclicCopy| |associates?| |pmintegrate| |qroot| |stack| |showTheRoutinesTable| |cap| |cross| |UP2ifCan| |back| |corrPoly| |multV| |diagonal?| |factorSFBRlcUnit| |light| |iidigamma| |removeRoughlyRedundantFactorsInPols| |insertMatch| |selectOrPolynomials| |homogeneous?| |linears| |increasePrecision| |OMgetAtp| |eigenMatrix| |basisOfCenter| |selectAndPolynomials| |OMputObject| |polyred| |message| |makeTerm| |setprevious!| |airyBi| |setProperties| |hessian| |diagonalProduct| |replace| |getDatabase| |viewPhiDefault| |setParam!| |linear?| |primlimitedint| |reorder| |isobaric?| |RemainderList| |csubst| |extDegree| |roughEqualIdeals?| |twoFactor| |equation| |dzasum| |viewDeltaXDefault| |normalized?| |OMputFloat| |hasoln| |lazyPremWithDefault| |map| |integral?| |genericRightTrace| |sts2stst| |escape| |OMreadFile| |cschIfCan| |monicDivide| |e01sbf| |fullParamInit| |trigs| |getlo| |compdegd| |zeroMatrix| |getVariableOrder| |numberOfNormalPoly| |iiatanh| |critpOrder| |indiceSubResultantEuclidean| |finiteSeries2LinSys| |halfExtendedResultant2| |car| |tan2cot| |revert| |hclf| |monicModulo| |eulerPhi| |unparse| |cdr| |mainForm| |internalLastSubResultant| |OMsetEncoding| |totalfract| |swapRows!| |topFortranOutputStack| |assign| |algebraicOf| |repSq| |getMeasure| |trim| |rootSimp| |unprotectedRemoveRedundantFactors| |reciprocalPolynomial| |fibonacci| |mathieu22| |divisor| |leftQuotient| |pleskenSplit| |fortranCarriageReturn| |cSech| |euclideanNormalForm| |intChoose| |normal?| |say| |nextPrime| |external?| |listAllMonoExp| |cAcsc| |linearPolynomials| BY |parse| |debug| |pseudoRemainder| |cycleRagits| |solveLinearPolynomialEquationByRecursion| |one?| |definingInequation| |normalizedAssociate| |externalList| |monic?| |minrank| |innerSolve| |error| |shiftRoots| |semiLastSubResultantEuclidean| |diff| |medialSet| |gcdPolynomial| |conical| |laplacian| |usingTable?| |generalizedContinuumHypothesisAssumed| |applyRules| |stoseInvertibleSetreg| |style| |Yun| |reducedDiscriminant| |continuedFraction| |exactQuotient!| |mantissa| |mapExponents| |nlde| |absolutelyIrreducible?| |construct| |selectFiniteRoutines| |screenResolution| |mdeg| |simplify| |reducedQPowers| |maxRowIndex| |subresultantVector| |iisech| |mkIntegral| |varselect| |pascalTriangle| |abelianGroup| |meatAxe| |setmult!| |exponentialOrder| |nextSublist| |position!| |mainDefiningPolynomial| |minIndex| |divisorCascade| |nextNormalPoly| |nthFractionalTerm| |shiftLeft| |linearMatrix| |unitCanonical| |jacobi| |cyclicEqual?| |evaluate| |complexRoots| |infieldIntegrate| |recur| |sumSquares| |characteristicSerie| |simplifyLog| |coerceS| |superscript| |sumOfDivisors| |invmultisect| |minPol| |nextItem| |polar| |qinterval| |atrapezoidal| |multiplyExponents| |unvectorise| |typeLists| |stFunc1| |factorOfDegree| |yCoordinates| |rspace| |coerce| |rootPoly| |redPo| |ricDsolve| |parabolicCylindrical| |pomopo!| |isQuotient| |parametric?| |clipParametric| |stFunc2| |difference| |asinIfCan| |evalRec| |normalize| |sinh2csch| |OMencodingXML| |primitivePart| |objects| |comment| |homogenize| |factorPolynomial| |fortranDoubleComplex| |linkToFortran| |legendreP| |tanintegrate| |float| |cartesian| |internalInfRittWu?| |makeFloatFunction| |pseudoRem| |diagonals| |curveColor| |id| |iiAiryBi| |hexDigit?| |reduction| |leftLcm| |integralBasisAtInfinity| |allRootsOf| |makeSeries| |integer| |upperCase| |position| |cAsec| |removeIrreducibleRedundantFactors| |numberOfFactors| |chvar| |derivative| |arity| |leader| |palgint| |getExplanations| |internalSubQuasiComponent?| |makeYoungTableau| |se2rfi| |reduceRow| |and| |euclideanSize| |blue| |skewSFunction| |#| |internalDecompose| |recolor| |string| |subMultV| |empty?| |minPoints3D| |partialDenominators| |generalizedInverse| |setValue!| |expenseOfEvaluationIF| |elements| |square?| |OMputEndAtp| |rightDivide| |OMreadStr| |separant| |OMread| |sdf2lst| |relerror| |rur| |rischDEsys| |uncouplingMatrices| |setfirst!| |commutator| |accuracyIF| |connect| |slope| |firstNumer| |useEisensteinCriterion| |mainVariables| |adaptive3D?| |linearAssociatedOrder| |patternMatchTimes| |second| |maxMixedDegree| |cubicBezier| |HermiteIntegrate| |quotientByP| |OMencodingUnknown| |makeUnit| |squareFreePolynomial| |OMconnectTCP| |red| |mirror| |quartic| |infLex?| |univcase| |rotate!| |convert| |log10| |writeObj| |critMTonD1| |Ei1| |flatten| |makeprod| |OMsupportsCD?| |selectOptimizationRoutines| |polyRDE| |operators| |upperCase!| |iifact| |returnType!| |fortranReal| |ode2| |iisqrt3| |possiblyNewVariety?| |octon| |quasiAlgebraicSet| |integers| |iibinom| |lex| |listAllMono| |nullary?| |finiteBound| |push!| |triangulate| |unitNormal| |modifyPoint| |key| |iiabs| |halfExtendedResultant1| |var2StepsDefault| |outputFloating| |iExquo| |whatInfinity| |children| |deriv| |qqq| |adaptive?| |localIntegralBasis| |torsionIfCan| |degreeSubResultantEuclidean| |zeroSetSplitIntoTriangularSystems| |stop| |minPoly| |flexible?| |iipow| |imaginary| |sort!| |standardBasisOfCyclicSubmodule| |generalizedContinuumHypothesisAssumed?| |effective?| |sylvesterSequence| |leadingTerm| |optpair| |fortranComplex| |result| |outputGeneral| |dom| |fixPredicate| |shade| |zeroDimPrime?| |normalizedDivide| |rightDiscriminant| |OMgetEndBVar| |subs1stVar| |OMgetError| |complexExpand| |cyclicParents| |subMatrix| |duplicates| |symbol| |makeSUP| |negAndPosEdge| LODO2FUN |iicsc| |library| |powerAssociative?| |points| |getShiftRec| |acotIfCan| |one| |zeroSetSplit| |irreducibleFactors| |acothIfCan| |drawToScale| |zero| |laurentRep| |userOrdered?| |constDsolve| |chartCoord| ^ |OMgetFloat| |iteratedInitials| |sec2cos| |radicalEigenvectors| |exp| RF2UTS |OMgetObject| |iitanh| |numberOfPlacesOfDegree| |pi| |expintfldpoly| |setFormula!| |selectPDERoutines| |primPartElseUnitCanonical!| |iiacoth| |sqrt| |algebraicCoefficients?| |fullDesTree| ** |leastMonomial| |monomial2series| |iiBesselK| |DiffC| |li| |segment| |prime| |showTheFTable| |df2ef| |erf| |sumOfKthPowerDivisors| |functionIsOscillatory| |extendedint| |splitConstant| |quotValuation| |replaceVarByZero| |alterQuadVar!| |rubiksGroup| |qelt| |dilog| |changeName| |createGenericMatrix| |delay| |sin| |mathieu11| |jordanAlgebra?| |cos| |inspect| |changeBase| |logpart| |tan| |Somos| |schema| |separateFactors| |cot| |imagJ| |third| |mkPrim| |tail| |sec| |sub| |nextPrimitiveNormalPoly| |removeSinhSq| |csc| |max| |checkExtraValues| |odd?| |asin| |solveInField| |genericLeftTrace| |triangularSystems| |allDegrees| |acos| |even?| |factorSqFree| |explicitEntries?| |associator| |atan| |LyndonWordsList1| |LyndonWordsList| |d| |linearDependenceOverZ| |SturmHabichtMultiple| |acot| |romberg| |subResultantsChain| |toScale| |OMputEndBVar| |assert| |asec| |tanh2coth| |setSingularPoints| |writeLine!| |row| |acsc| |decomposeFunc| |null?| |lyndon| |taylorIfCan| |sinh| |cCsch| |iidsum| |routines| |extractSplittingLeaf| |cosh| |linSolve| |fullInfClsPt| |cup| |integral| |ScanArabic| |tanh| |complexNumeric| |imagi| |nthExponent| |linGenPos| |coth| |iisin| |kernels| |iisec| |trigs2explogs| |partialQuotients| |sech| |kovacic| |univariate| |setScreenResolution3D| |rational| |e| |primextintfrac| |csch| |badValues| |factor| |createNormalPoly| |expintegrate| |invertIfCan| |asinh| |supersub| |imag| |distinguishedRootsOf| |mainMonomial| |drawComplexVectorField| |acosh| |directProduct| |degree| |orbits| |zeroVector| |freeOf?| |entry| |atanh| |inverseIntegralMatrix| |destruct| |multiplyCoefficients| |tab| |doubleComplex?| |acoth| |monomial| |rationalPower| |stoseInternalLastSubResultant| |roughBase?| |symbolTable| |asech| |maxTower| |multivariate| |restorePrecision| |represents| |atanhIfCan| |pushFortranOutputStack| |dec| |balancedBinaryTree| |binaryTree| |curveV| |filename| |nthRootIfCan| |myDegree| |numerator| |BasicMethod| |popFortranOutputStack| |inv| |nthFactor| |lastNonNul| |factorUsingYun| |expressIdealMember| |outputAsFortran| |lexTriangular| |ground?| |monomRDE| |acscIfCan| |sum| |iiasec| |ground| |delta| |factorSquareFreePolynomial| |minimumExponent| |guessExpRat| |reduceLODE| |leadingMonomial| |squareTop| |palgRDE0| |numberOfImproperPartitions| |predicates| |leadingCoefficient| |initTable!| |removeRedundantFactors| |iicoth| |hdmpToP| |primitiveMonomials| |explogs2trigs| |aCubic| |symbolTableOf| |solid?| |reductum| |ratDsolve| |pushdown| |pushucoef| |lepol| |cycleElt| |setMinPoints3D| |split!| |subNodeOf?| |cPower| |base| |getAncestors| |slash| |showFortranOutputStack| |factorGroebnerBasis| |cyclic| |chineseRemainder| |gcdcofactprim| |getRef| |endSubProgram| |cCot| |extractIfCan| |copyQuadVar| |lifting1| |prolateSpheroidal| |Musser| |OMsupportsSymbol?| |subspace| |outputAsScript| |subResultantGcdEuclidean| |lhs| |associatorDependence| |localParam| |lastSubResultant| |moebiusMu| |sortConstraints| |makeViewport3D| |rewriteSetByReducingWithParticularGenerators| |bringDown| |power!| |zoom| |startTableInvSet!| |imagK| |deepestTail| |ridHack1| |rationalApproximation| |norm| |previousTower| |getMatch| |enterInCache| |enterPointData| |toseInvertibleSet| |interpolate| |setvalue!| |supRittWu?| |genericRightTraceForm| |pfaffian| |generalizedEigenvector| |monicRightDivide| |reduceBasisAtInfinity| |setLegalFortranSourceExtensions| |algebraicDecompose| |interpretString| |zag| |edf2efi| |point?| |iiperm| |tanQ| |ravel| |irreducible?| |calcRanges| |localReal?| |tubePlot| |complexSolve| |adjunctionDivisor| |primintfldpoly| |convertIfCan| |cotIfCan| |high| |set| |viewWriteDefault| |pointToPlace| |digits| |open?| |members| |pushdterm| |tanSum| |quadraticNorm| |viewport3D| |negative?| |sizeMultiplication| |laguerre| |merge| |cycle| |ran| |fortranCompilerName| |diagonal| |extendedIntegrate| |exists?| |newSubProgram| |halfExtendedSubResultantGcd2| |linearAssociatedLog| |eval| |primeFrobenius| |numer| |startStats!| |positiveRemainder| |cCosh| |PollardSmallFactor| |denom| |desingTreeAtPoint| |dequeue!| |genusTreeNeg| |kernel| |inR?| |headReduce| |removeCoshSq| |concat| |listConjugateBases| |draw| |integralAtInfinity?| |monomialIntPoly| |lfunc| |countable?| |makeObject| |expPot| |localAbs| |stoseInvertible?reg| |rightUnits| |integralLastSubResultant| |coef| |dAndcExp| |convergents| |hypergeometric0F1| |palgLODE0| |monom| |normalDenom| |introduce!| |series| |getMultiplicationMatrix| |real?| |gcdprim| |quadraticBezier| |ParCondList| |polarCoordinates| |OMputAttr| |tablePow| |options| |mapSolve| |tensorProduct| |indicialEquationAtInfinity| |repack1| |rightRankPolynomial| |clearTheIFTable| |radPoly| |shrinkable| |hconcat| |smith| |dihedralGroup| |goodnessOfFit| |pointDominateBy| |computePowers| |bat| |argscript| |factors| |setTex!| |rightExactQuotient| |pToHdmp| |asinhIfCan| |removeSuperfluousCases| |iiacosh| |normInvertible?| |binary| |partitions| |generalInterpolation| |setlocalParam!| |permanent| |chartV| |dmpToHdmp| |setsymbName!| |noKaratsuba| |operator| |tree| |measure2Result| |tanNa| |times!| |cAsinh| |subHeight| |weighted| |getStream| |innerEigenvectors| |smaller?| |supp| |iicot| |rewriteSetWithReduction| |pr2dmp| |bottom!| |column| |monomial?| |forLoop| |nil| |infinite| |arbitraryExponent| |approximate| |complex| |shallowMutable| |canonical| |noetherian| |central| |partiallyOrderedSet| |arbitraryPrecision| |canonicalsClosed| |noZeroDivisors| |rightUnitary| |leftUnitary| |additiveValuation| |unitsKnown| |canonicalUnitNormal| |multiplicativeValuation| |finiteAggregate| |shallowlyMutable| |commutative|) 
\ No newline at end of file
+(30 . 3613822954)            
+(4628 |Enumeration| |Mapping| |Record| |Union| |ofCategory| |isDomain| ATTRIBUTE |package| |domain| |category| CATEGORY |nobranch| AND |Join| |ofType| SIGNATURE "failed" "algebra" |OneDimensionalArrayAggregate&| |OneDimensionalArrayAggregate| |AbelianGroup&| |AbelianGroup| |AbelianMonoid&| |AbelianMonoid| |AbelianSemiGroup&| |AbelianSemiGroup| |AlgebraicallyClosedField&| |AlgebraicallyClosedField| |AlgebraicallyClosedFunctionSpace&| |AlgebraicallyClosedFunctionSpace| |PlaneAlgebraicCurvePlot| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraicFunction| |AffineSpaceCategory| |Aggregate&| |Aggregate| |ArcHyperbolicFunctionCategory| |AssociationListAggregate| |Algebra&| |Algebra| |AlgFactor| |AlgebraicFunctionField| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraPackage| |AlgebraGivenByStructuralConstants| |AssociationList| |AbelianMonoidRing&| |AbelianMonoidRing| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |AnyFunctions1| |Any| |ApplicationProgramInterface| |ApplyUnivariateSkewPolynomial| |ApplyRules| |TwoDimensionalArrayCategory&| |TwoDimensionalArrayCategory| |OneDimensionalArrayFunctions2| |OneDimensionalArray| |TwoDimensionalArray| |Asp10| |Asp12| |Asp19| |Asp1| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp41| |Asp42| |Asp49| |Asp4| |Asp50| |Asp55| |Asp6| |Asp73| |Asp74| |Asp77| |Asp78| |Asp7| |Asp80| |Asp8| |Asp9| |AssociatedEquations| |ArrayStack| |AdditiveValuationAttribute| |ApproximateAttribute| |ArbitraryExponentAttribute| |ArbitraryPrecisionAttribute| |CanonicalClosedAttribute| |CanonicalAttribute| |CentralAttribute| |CommutativeStarAttribute| |CanonicalUnitNormalAttribute| |FiniteAggregateAttribute| |JacobiIdentityAttribute| |LazyRepresentationAttribute| |LeftUnitaryAttribute| |MultiplicativeValuationAttribute| |NotherianAttribute| |NullSquareAttribute| |NoZeroDivisorsAttribute| |PartiallyOrderedSetAttribute| |ArcTrigonometricFunctionCategory&| |ArcTrigonometricFunctionCategory| |ShallowlyMutableAttribute| |AttributeButtons| |AttributeRegistry| |UnitsKnownAttribute| |Automorphism| |AxiomServer| |BalancedFactorisation| |BasicType&| |BasicType| |BalancedBinaryTree| |Bezier| |BezoutMatrix| |BasicFunctions| |BagAggregate&| |BagAggregate| |BinaryExpansion| |BinaryFile| |Bits| |BlasLevelOne| |BlowUpWithHamburgerNoether| |BlowUpMethodCategory| |BlowUpWithQuadTrans| |BlowUpPackage| |BiModule| |Boolean| |BasicOperatorFunctions1| |BasicOperator| |BoundIntegerRoots| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryRecursiveAggregate&| |BinaryRecursiveAggregate| |BrillhartTests| |BasicStochasticDifferential| |BinarySearchTree| |BitAggregate&| |BitAggregate| |BinaryTreeCategory&| |BinaryTreeCategory| |BinaryTournament| |BinaryTree| |CancellationAbelianMonoid| |CachableSet| |CardinalNumber| |CartesianTensorFunctions2| |CartesianTensor| |CharacterClass| |CommonDenominator| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |CombinatorialFunctionCategory| |Character| |CharacteristicNonZero| |CharacteristicPolynomialPackage| |CharacteristicZero| |ChangeOfVariable| |ComplexIntegerSolveLinearPolynomialEquation| |Collection&| |Collection| |CliffordAlgebra| |TwoDimensionalPlotClipping| |ComplexRootPackage| |Color| |CombinatorialFunction| |IntegerCombinatoricFunctions| |CombinatorialOpsCategory| |Commutator| |CommonOperators| |CommuteUnivariatePolynomialCategory| |Comparable| |ComplexCategory&| |ComplexCategory| |ComplexFactorization| |ComplexFunctions2| |Complex| |ComplexPattern| |SubSpaceComponentProperty| |CommutativeRing| |ContinuedFraction| |CoordinateSystems| |CharacteristicPolynomialInMonogenicalAlgebra| |ComplexPatternMatch| |CRApackage| |ComplexRootFindingPackage| |CyclicStreamTools| |ComplexTrigonometricManipulations| |CoerceVectorMatrixPackage| |CycleIndicators| |CyclotomicPolynomialPackage| |d01AgentsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d01TransformFunctionType| |d01WeightsPackage| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |Database| |DoubleResultantPackage| |DistinctDegreeFactorize| |DecimalExpansion| |ElementaryFunctionDefiniteIntegration| |RationalFunctionDefiniteIntegration| |DegreeReductionPackage| |Dequeue| |DeRhamComplex| |DefiniteIntegrationTools| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DenavitHartenbergMatrix| |Dictionary&| |Dictionary| |DifferentialExtension&| |DifferentialExtension| |DifferentialRing&| |DifferentialRing| |DictionaryOperations&| |DictionaryOperations| |DiophantineSolutionPackage| |DirectProductCategory&| |DirectProductCategory| |DirectProductFunctions2| |DirectProduct| |DirichletRing| |DisplayPackage| |DivisorCategory| |Divisor| |DivisionRing&| |DivisionRing| |DoublyLinkedAggregate| |DataList| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |DirectProductMatrixModule| |DirectProductModule| |DifferentialPolynomialCategory&| |DifferentialPolynomialCategory| |DequeueAggregate| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |DrawComplex| |DrawNumericHack| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForPoints| |DrawOptionFunctions0| |DrawOptionFunctions1| |DrawOption| |DifferentialSparseMultivariatePolynomial| |DesingTreeCategory| |DesingTree| |DesingTreePackage| |DifferentialVariableCategory&| |DifferentialVariableCategory| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType| |ExtAlgBasis| |ElementaryFunction| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ExtensibleLinearAggregate&| |ExtensibleLinearAggregate| |ElementaryFunctionCategory&| |ElementaryFunctionCategory| |EllipticFunctionsUnivariateTaylorSeries| |Eltable| |EltableAggregate&| |EltableAggregate| |EuclideanModularRing| |EntireRing| |EigenPackage| |EquationFunctions2| |Equation| |EqTable| |ErrorFunctions| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpertSystemContinuityPackage1| |ExpertSystemContinuityPackage| |ExpressionSpace&| |ExpressionSpace| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExpertSystemToolsPackage| |EuclideanDomain&| |EuclideanDomain| |Evalable&| |Evalable| |EvaluateCycleIndicators| |Exit| |Export3D| |ExponentialExpansion| |ExpressionFunctions2| |ExpressionToUnivariatePowerSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionSolve| |ExpressionTubePlot| |ExponentialOfUnivariatePuiseuxSeries| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactoredFunctions| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FactoringUtilities| |FreeAbelianGroup| |FreeAbelianMonoidCategory| |FreeAbelianMonoid| |FiniteAbelianMonoidRingFunctions2| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRing| |FlexibleArray| |FiniteAlgebraicExtensionField&| |FiniteAlgebraicExtensionField| |FortranCode| |FourierComponent| |FortranCodePackage1| |FiniteDivisorFunctions2| |FiniteDivisorCategory&| |FiniteDivisorCategory| |FiniteDivisor| |FullyEvalableOver&| |FullyEvalableOver| |FortranExpression| |FunctionFieldCategoryFunctions2| |FunctionFieldCategory&| |FunctionFieldCategory| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldCyclicGroupExtension| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FractionFreeFastGaussianFractions| |FractionFreeFastGaussian| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldCategory&| |FiniteFieldCategory| |FunctionFieldIntegralBasis| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldNormalBasisExtension| |FiniteField| |FiniteFieldExtensionByPolynomial| |FiniteFieldPolynomialPackage2| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteFieldExtension| |FGLMIfCanPackage| |FreeGroup| |Field&| |Field| |FileCategory| |File| |FiniteRankNonAssociativeAlgebra&| |FiniteRankNonAssociativeAlgebra| |Finite&| |Finite| |FiniteRankAlgebra&| |FiniteRankAlgebra| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregate&| |FiniteLinearAggregate| |FreeLieAlgebra| |FiniteLinearAggregateSort| |FullyLinearlyExplicitRingOver&| |FullyLinearlyExplicitRingOver| |FloatingComplexPackage| |Float| |FloatingRealPackage| |FreeModule1| |FreeModuleCat| |FortranMatrixCategory| |FortranMatrixFunctionCategory| |FreeModule| |FreeMonoid| |FortranMachineTypeCategory| |FileName| |FileNameCategory| |FreeNilpotentLie| |FortranOutputStackPackage| |FindOrderFinite| |ScriptFormulaFormat1| |ScriptFormulaFormat| |FortranProgramCategory| |FortranFunctionCategory| |FortranPackage| |FortranProgram| |FullPartialFractionExpansion| |FullyPatternMatchable| |FieldOfPrimeCharacteristic&| |FieldOfPrimeCharacteristic| |FloatingPointSystem&| |FloatingPointSystem| |FactoredFunctions2| |FractionFunctions2| |Fraction| |FramedAlgebra&| |FramedAlgebra| |FullyRetractableTo&| |FullyRetractableTo| |FractionalIdealFunctions2| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebraFunctions2| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebra| |Factored| |FactoredFunctionUtilities| |FunctionSpaceToExponentialExpansion| |FunctionSpaceFunctions2| |FunctionSpaceToUnivariatePowerSeries| |FiniteSetAggregateFunctions2| |FiniteSetAggregate&| |FiniteSetAggregate| |FunctionSpaceComplexIntegration| |FourierSeries| |FunctionSpaceIntegration| |FunctionSpace&| |FunctionSpace| |FunctionalSpecialFunction| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FortranScalarType| |FunctionSpaceUnivariatePolynomialFactor| |FortranTemplate| |FortranType| |FunctionCalled| |FortranVectorCategory| |FortranVectorFunctionCategory| |GaloisGroupFactorizer| |GaloisGroupFactorizationUtilities| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |EuclideanGroebnerBasisPackage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GcdDomain&| |GcdDomain| |GenericNonAssociativeAlgebra| |GeneralDistributedMultivariatePolynomial| |GnuDraw| |GenExEuclid| |GeneralizedMultivariateFactorize| |GeneralPolynomialGcdPackage| |GenUFactorize| |GenerateUnivariatePowerSeries| |GeneralHenselPackage| |GeneralModulePolynomial| |GuessOptionFunctions0| |GuessOption| |GosperSummationMethod| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GradedAlgebra&| |GradedAlgebra| |GrayCode| |GraphicsDefaults| |GraphImage| |GradedModule&| |GradedModule| |GroebnerSolve| |Group&| |Group| |GeneralUnivariatePowerSeries| |GeneralSparseTable| |GeneralTriangularSet| |GuessAlgebraicNumber| |GuessFiniteFunctions| |GuessFinite| |GuessInteger| |Guess| |GuessPolynomial| |GuessUnivariatePolynomial| |Pi| |HashTable| |HallBasis| |HomogeneousDistributedMultivariatePolynomial| |HomogeneousDirectProduct| |Heap| |HyperellipticFiniteDivisor| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousAggregate| |HTMLFormat| |HyperbolicFunctionCategory&| |HyperbolicFunctionCategory| |InnerAlgFactor| |InnerAlgebraicNumber| |IndexedOneDimensionalArray| |IndexedTwoDimensionalArray| |ChineseRemainderToolsForIntegralBases| |IntegralBasisTools| |IndexedBits| |IntegralBasisPolynomialTools| |IndexCard| |InnerCommonDenominator| |InfClsPt| |PolynomialIdeals| |IdealDecompositionPackage| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductCategory| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedDirectProductObject| |InnerEvalable&| |InnerEvalable| |InnerFreeAbelianMonoid| |IndexedFlexibleArray| |InnerFiniteField| |InnerIndexedTwoDimensionalArray| |IndexedList| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |IndexedMatrix| |InnerNormalBasisFieldFunctions| |IncrementingMaps| |IndexedExponents| |InnerNumericEigenPackage| |InfinitlyClosePointCategory| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InfinitlyClosePoint| |Infinity| |InputFormFunctions1| |InputForm| |InfiniteProductCharacteristicZero| |InnerNumericFloatSolvePackage| |InnerModularGcd| |InnerMultFact| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerPolySign| |IntegerNumberSystem&| |IntegerNumberSystem| |InnerTable| |AlgebraicIntegration| |AlgebraicIntegrate| |IntegerBits| |IntervalCategory| |IntersectionDivisorPackage| |IntegralDomain&| |IntegralDomain| |ElementaryIntegration| |InterfaceGroebnerPackage| |IntegerFactorizationPackage| |InterpolateFormsPackage| |IntegrationFunctionsTable| |GenusZeroIntegration| |IntegerNumberTheoryFunctions| |AlgebraicHermiteIntegration| |TranscendentalHermiteIntegration| |Integer| |AnnaNumericalIntegrationPackage| |PureAlgebraicIntegration| |PatternMatchIntegration| |RationalIntegration| |IntegerRetractions| |RationalFunctionIntegration| |Interval| |IntegerSolveLinearPolynomialEquation| |IntegrationTools| |TranscendentalIntegration| |InverseLaplaceTransform| |InnerPAdicInteger| |InnerPrimeField| |InternalPrintPackage| |IntegrationResultToFunction| |IntegrationResultFunctions2| |IntegrationResult| |IntegerRoots| |IrredPolyOverFiniteField| |IntegrationResultRFToFunction| |IrrRepSymNatPackage| |InternalRationalUnivariateRepresentationPackage| |IndexedString| |InnerPolySum| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InfiniteTupleFunctions2| |InfiniteTupleFunctions3| |InnerTrigonometricManipulations| |InfiniteTuple| |IndexedVector| |IndexedAggregate&| |IndexedAggregate| |AssociatedJordanAlgebra| |KeyedAccessFile| |KeyedDictionary&| |KeyedDictionary| |KernelFunctions2| |Kernel| |CoercibleTo| |ConvertibleTo| |Kovacic| |LeftAlgebra&| |LeftAlgebra| |LocalAlgebra| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LieExponentials| |LexTriangularPackage| |LiouvillianFunctionCategory| |LiouvillianFunction| |LinGroebnerPackage| |Library| |LieAlgebra&| |LieAlgebra| |AssociatedLieAlgebra| |PowerSeriesLimitPackage| |RationalFunctionLimitPackage| |LinearDependence| |LinearlyExplicitRingOver| |ListToMap| |ListFunctions2| |ListFunctions3| |List| |LinearSystemFromPowerSeriesPackage| |ListMultiDictionary| |LeftModule| |ListMonoidOps| |LinearAggregate&| |LinearAggregate| |LocalPowerSeriesCategory| |ElementaryFunctionLODESolver| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorCategory| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |Logic&| |Logic| |Localize| |LinesOpPack| |LeftOreRing| |LocalParametrizationOfSimplePointPackage| |LinearPolynomialEquationByFractions| |LiePolynomial| |ListAggregate&| |ListAggregate| |LinearSystemMatrixPackage1| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LieSquareMatrix| |LyndonWord| |LazyStreamAggregate&| |LazyStreamAggregate| |ThreeDimensionalMatrix| |ModularAlgebraicGcdOperations| |Magma| |MatrixManipulation| |MappingPackageInternalHacks1| |MappingPackageInternalHacks2| |MappingPackageInternalHacks3| |MappingPackage1| |MappingPackage2| |MappingPackage3| |MappingPackage4| |MatrixCategoryFunctions2| |MatrixCategory&| |MatrixCategory| |MatrixLinearAlgebraFunctions| |Matrix| |StorageEfficientMatrixOperations| |MultiVariableCalculusFunctions| |MatrixCommonDenominator| |MachineComplex| |MultiDictionary| |ModularDistinctDegreeFactorizer| |MeshCreationRoutinesForThreeDimensions| |MultFiniteFactorize| |MachineFloat| |ModularHermitianRowReduction| |MachineInteger| |MakeBinaryCompiledFunction| |MakeCachableSet| |MakeFloatCompiledFunction| |MakeFunction| |MakeRecord| |MakeUnaryCompiledFunction| |MultivariateLifting| |MonogenicLinearOperator| |MultipleMap| |MathMLFormat| |ModularField| |ModMonic| |ModuleMonomial| |ModuleOperator| |ModularRing| |Module&| |Module| |MoebiusTransform| |Monad&| |Monad| |MonadWithUnit&| |MonadWithUnit| |MonogenicAlgebra&| |MonogenicAlgebra| |Monoid&| |Monoid| |MonomialExtensionTools| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MultivariatePolynomial| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MonoidRingFunctions2| |MonoidRing| |MultisetAggregate| |Multiset| |MoreSystemCommands| |MergeThing| |MultivariateTaylorSeriesCategory| |MultivariateFactorize| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NonAssociativeAlgebra&| |NonAssociativeAlgebra| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagIntegrationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagInterpolationPackage| |NagFittingPackage| |NagOptimisationPackage| |NagMatrixOperationsPackage| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagLapack| |NagSpecialFunctionsPackage| |NAGLinkSupportPackage| |NonAssociativeRng&| |NonAssociativeRng| |NonAssociativeRing&| |NonAssociativeRing| |NumericComplexEigenPackage| |NumericContinuedFraction| |NonCommutativeOperatorDivision| |NewtonInterpolation| |NumberFieldIntegralBasis| |NumericalIntegrationProblem| |NonLinearSolvePackage| |NonNegativeInteger| |NonLinearFirstOrderODESolver| |NoneFunctions1| |None| |NormInMonogenicAlgebra| |NormalizationPackage| |NormRetractPackage| |NottinghamGroup| |NPCoef| |NewtonPolygon| |NumericRealEigenPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2| |NewSparseUnivariatePolynomial| |NumberTheoreticPolynomialFunctions| |NormalizedTriangularSetCategory| |Numeric| |NumberFormats| |NumericalIntegrationCategory| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |NumericTubePlot| |OrderedAbelianGroup| |OrderedAbelianMonoid| |OrderedAbelianMonoidSup| |OrderedAbelianSemiGroup| |OrderedCancellationAbelianMonoid| |OctonionCategory&| |OctonionCategory| |OctonionCategoryFunctions2| |Octonion| |OrdinaryDifferentialEquationsSolverCategory| |ConstantLODE| |ElementaryFunctionODESolver| |ODEIntensityFunctionsTable| |ODEIntegration| |AnnaOrdinaryDifferentialEquationPackage| |PureAlgebraicLODE| |PrimitiveRatDE| |NumericalODEProblem| |PrimitiveRatRicDE| |RationalLODE| |ReduceLODE| |RationalRicDE| |SystemODESolver| |ODETools| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrderlyDifferentialVariable| |OrderedFreeMonoid| |OrderedIntegralDomain| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathErrorKind| |OpenMathError| |ExpressionToOpenMath| |OppositeMonogenicLinearOperator| |OpenMath| |OpenMathPackage| |OrderedMultisetAggregate| |OpenMathServerPackage| |OnePointCompletionFunctions2| |OnePointCompletion| |Operator| |OperationsQuery| |NumericalOptimizationCategory| |AnnaNumericalOptimizationPackage| |NumericalOptimizationProblem| |OrderedCompletionFunctions2| |OrderedCompletion| |OrderedFinite| |OrderingFunctions| |OrderedMonoid| |OrderedRing&| |OrderedRing| |OrderedSet&| |OrderedSet| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategory| |UnivariateSkewPolynomialCategoryOps| |SparseUnivariateSkewPolynomial| |UnivariateSkewPolynomial| |OrthogonalPolynomialFunctions| |OrdSetInts| |OutputForm| |OutputPackage| |OrderedVariableList| |OrdinaryWeightedPolynomials| |PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteFieldCategory| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfPerfectFieldCategory| |PseudoAlgebraicClosureOfRationalNumberCategory| |PseudoAlgebraicClosureOfRationalNumber| |PadeApproximants| |PadeApproximantPackage| |PAdicIntegerCategory| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForAlgebraicFunctionField| |Palette| |PolynomialAN2Expression| |ParametrizationPackage| |ParametricPlaneCurveFunctions2| |ParametricPlaneCurve| |ParametricSpaceCurveFunctions2| |ParametricSpaceCurve| |ParametricSurfaceFunctions2| |ParametricSurface| |PartitionsAndPermutations| |Patternable| |PatternMatchListResult| |PatternMatchable| |PatternMatch| |PatternMatchResultFunctions2| |PatternMatchResult| |PatternFunctions1| |PatternFunctions2| |Pattern| |PoincareBirkhoffWittLyndonBasis| |PolynomialComposition| |PartialDifferentialEquationsSolverCategory| |PolynomialDecomposition| |AnnaPartialDifferentialEquationPackage| |NumericalPDEProblem| |PartialDifferentialRing&| |PartialDifferentialRing| |PendantTree| |Permanent| |PermutationCategory| |PermutationGroup| |Permutation| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialFactorizationExplicit| |PrimeField| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PackageForPoly| |PointsOfFiniteOrderTools| |PartialFraction| |PartialFractionPackage| |PolynomialGcdPackage| |PermutationGroupExamples| |PolyGroebner| |PiCoercions| |PrincipalIdealDomain| |PositiveInteger| |PolynomialInterpolationAlgorithms| |PolynomialInterpolation| |PlacesCategory| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |ParametricLinearEquations| |PlotFunctions1| |Plot3D| |Plot| |PlotTools| |PolynomialPackageForCurve| |FunctionSpaceAssertions| |PatternMatchAssertions| |PatternMatchPushDown| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchPolynomialCategory| |FunctionSpaceAttachPredicates| |AttachPredicates| |PatternMatchQuotientFieldCategory| |PatternMatchSymbol| |PatternMatchTools| |PolynomialNumberTheoryFunctions| |Point| |PolToPol| |RealPolynomialUtilitiesPackage| |PolynomialFunctions2| |PolynomialToUnivariatePolynomial| |PolynomialCategory&| |PolynomialCategory| |PolynomialCategoryQuotientFunctions| |PolynomialCategoryLifting| |Polynomial| |PolynomialRoots| |U32VectorPolynomialOperations| |PlottablePlaneCurveCategory| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |PrimitiveArray| |PrimitiveFunctionCategory| |PrimitiveElement| |IntegerPrimesPackage| |PrintPackage| |ProjectiveAlgebraicSetPackage| |PolynomialRing| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PriorityQueueAggregate| |PseudoRemainderSequence| |ProjectiveSpaceCategory| |Partition| |PowerSeriesCategory&| |PowerSeriesCategory| |PlottableSpaceCurveCategory| |PolynomialSetCategory&| |PolynomialSetCategory| |PolynomialSetUtilitiesPackage| |PseudoLinearNormalForm| |PolynomialSquareFree| |PointCategory| |PointFunctions2| |PointPackage| |PartialTranscendentalFunctions| |PushVariables| |PAdicWildFunctionFieldIntegralBasis| |QuasiAlgebraicSet2| |QuasiAlgebraicSet| |QuasiComponentPackage| |QueryEquation| |QuotientFieldCategoryFunctions2| |QuotientFieldCategory&| |QuotientFieldCategory| |QuadraticForm| |QueueAggregate| |QuaternionCategory&| |QuaternionCategory| |QuaternionCategoryFunctions2| |Quaternion| |Queue| |RadicalCategory&| |RadicalCategory| |RadicalFunctionField| |RadixExpansion| |RadixUtilities| |RandomNumberSource| |RationalFactorize| |RationalRetractions| |RecursiveAggregate&| |RecursiveAggregate| |RealClosedField&| |RealClosedField| |ElementaryRischDE| |ElementaryRischDESystem| |TranscendentalRischDE| |TranscendentalRischDESystem| |RandomDistributions| |ReducedDivisor| |RealZeroPackage| |RealZeroPackageQ| |RealConstant| |RealSolvePackage| |RealClosure| |RecurrenceOperator| |ReductionOfOrder| |Reference| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |RepeatedDoubling| |RadicalEigenPackage| |RepeatedSquaring| |ResolveLatticeCompletion| |ResidueRing| |Result| |RetractableTo&| |RetractableTo| |RetractSolvePackage| |RandomFloatDistributions| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunction| |RootsFindingPackage| |RegularChain| |RandomIntegerDistributions| |Ring&| |Ring| |RationalInterpolation| |RectangularMatrixCategory&| |RectangularMatrixCategory| |RectangularMatrix| |RectangularMatrixCategoryFunctions2| |RightModule| |Rng| |RealNumberSystem&| |RealNumberSystem| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RecursivePolynomialCategory&| |RecursivePolynomialCategory| |RealRootCharacterizationCategory&| |RealRootCharacterizationCategory| |RegularSetDecompositionPackage| |RegularTriangularSetCategory&| |RegularTriangularSetCategory| |RegularTriangularSetGcdPackage| |RuleCalled| |RewriteRule| |Ruleset| |RationalUnivariateRepresentationPackage| |SimpleAlgebraicExtensionAlgFactor| |SimpleAlgebraicExtension| |SAERationalFunctionAlgFactor| |SingletonAsOrderedSet| |SortedCache| |StructuralConstantsPackage| |StochasticDifferential| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |SegmentFunctions2| |SegmentBindingFunctions2| |SegmentBinding| |SegmentCategory| |Segment| |SegmentExpansionCategory| |SetAggregate&| |SetAggregate| |SetCategoryWithDegree| |SetCategory&| |SetCategory| |SetOfMIntegersInOneToN| |Set| |SExpressionCategory| |SExpression| |SExpressionOf| |SimpleFortranProgram| |SquareFreeQuasiComponentPackage| |SquareFreeRegularTriangularSetGcdPackage| |SquareFreeRegularTriangularSetCategory| |SymmetricGroupCombinatoricFunctions| |SemiGroup&| |SemiGroup| |SplitHomogeneousDirectProduct| |SturmHabichtPackage| |ElementaryFunctionSign| |RationalFunctionSign| |SimplifyAlgebraicNumberConvertPackage| |SingleInteger| |StackAggregate| |SquareMatrixCategory&| |SquareMatrixCategory| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SquareFreeNormalizedTriangularSetCategory| |PolynomialSolveByFormulas| |RadicalSolvePackage| |TransSolvePackageService| |TransSolvePackage| |SortPackage| |ThreeSpace| |ThreeSpaceCategory| |SpecialOutputPackage| |SpecialFunctionCategory| |SplittingNode| |SplittingTree| |SquareMatrix| |StringAggregate&| |StringAggregate| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |Stack| |StreamAggregate&| |StreamAggregate| |SparseTable| |StepThrough| |StreamInfiniteProduct| |StreamTensor| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |Stream| |StringCategory| |String| |StringTable| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctionsNonCommutative| |StreamTranscendentalFunctions| |SubResultantPackage| |SubSpace| |SuchThat| |SparseUnivariateLaurentSeries| |FunctionSpaceSum| |RationalFunctionSum| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePolynomialExpressions| |SupFractionFactorizer| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |Switch| |Symbol| |SymmetricFunctions| |SymmetricPolynomial| |TheSymbolTable| |SymbolTable| |SystemSolvePackage| |TableauxBumpers| |Tableau| |Table| |TangentExpansions| |TableAggregate&| |TableAggregate| |TabulatedComputationPackage| |TemplateUtilities| |TexFormat1| |TexFormat| |TextFile| |ToolsForSign| |TopLevelThreeSpace| |TranscendentalFunctionCategory&| |TranscendentalFunctionCategory| |Tree| |TrigonometricFunctionCategory&| |TrigonometricFunctionCategory| |TrigonometricManipulations| |TriangularMatrixOperations| |TranscendentalManipulations| |TriangularSetCategory&| |TriangularSetCategory| |TaylorSeries| |TubePlot| |TubePlotTools| |Tuple| |TwoFactorize| |Type| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |UniqueFactorizationDomain&| |UniqueFactorizationDomain| |UnivariateFormalPowerSeriesFunctions| |UnivariateFormalPowerSeries| |UnivariateLaurentSeriesFunctions2| |UnivariateLaurentSeriesCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeries| |UnivariateFactorize| |UniversalSegmentFunctions2| |UniversalSegment| |UnivariatePolynomialFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomial| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategory| |UnivariatePowerSeriesCategory&| |UnivariatePowerSeriesCategory| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesCategory| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnaryRecursiveAggregate&| |UnaryRecursiveAggregate| |UnivariateTaylorSeriesFunctions2| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesCategory| |UnivariateTaylorSeries| |UnivariateTaylorSeriesODESolver| |UTSodetools| |TaylorSolve| |UnivariateTaylorSeriesCZero| |Variable| |VectorCategory&| |VectorCategory| |VectorFunctions2| |Vector| |TwoDimensionalViewport| |ThreeDimensionalViewport| |ViewDefaultsPackage| |ViewportPackage| |Void| |VectorSpace&| |VectorSpace| |WeierstrassPreparation| |WildFunctionFieldIntegralBasis| |WeightedPolynomials| |WuWenTsunTriangularSet| |XAlgebra| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |ExtensionField&| |ExtensionField| |XPBWPolynomial| |XPolynomialsCat| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ParadoxicalCombinatorsForStreams| |ZeroDimensionalSolvePackage| |IntegerLinearDependence| |IntegerMod| |Enumeration| |Mapping| |Record| |Union| |Category| |recoverAfterFail| |unit?| |cSec| |OMUnknownCD?| |rootsOf| |monomRDE| |append| |freeOf?| |selectPDERoutines| |truncatedmultiplication| |basisOfRightAnnihilator| |lazy?| |negative?| |function| |rectangularMatrix| |sts2stst| |removeConjugate| |saturate| |graphCurves| |eyeDistance| |diagonal| |list| |fortranLiteralLine| |aQuartic| |mkAnswer| |cycleSplit!| |shuffle| |showTheIFTable| |argumentList!| |complex?| |primPartElseUnitCanonical!| |directSum| |removeRedundantFactorsInContents| |has?| |inverseIntegralMatrix| |tab1| |setleft!| |acscIfCan| |key| |sizeMultiplication| |sequences| |infiniteProduct| |escape| |ef2edf| |split| |brillhartIrreducible?| |mulbybinomial| |extendedIntegrate| |removeDuplicates| |hasTopPredicate?| |foundPlaces| |orbit| |iiacoth| |coordinate| |rest| |axesColorDefault| |idealSimplify| |incrementKthElement| |chiSquare| |gradient| |createMultiplicationTable| |reverse| |surface| |bubbleSort!| |multiplyCoefficients| |baseRDEsys| |removeFirstZeroes| |setDifference| |leftFactor| |laguerre| |genericLeftTraceForm| |selectIntegrationRoutines| |OMreadFile| |setIntersection| |iiasec| |basicSet| |noLinearFactor?| |lcmCoef| |exists?| |ddot| |abs| |ScanRoman| |trunc| |coerceImages| |normalDeriv| |setUnion| |symbol| |weights| |readable?| |lllp| |movedPoints| |size| |ddFact| |enumerate| |tab| |dimensionsOf| |midpoint| |one| |substitute| |perfectNthRoot| |tValues| |yRange| |divisorCascade| |cschIfCan| |factorSquareFreePolynomial| |zero| |OMputError| |nor| |green| |newSubProgram| |Not| |ratDenom| ^ |minGbasis| |qsetelt!| |iiexp| |Nul| |trapezoidalo| |exp| |rightNorm| |numericalOptimization| |dswap| |mr| |pi| |axes| |algebraicCoefficients?| |doubleComplex?| |nextNormalPoly| |tensorMap| |totalGroebner| |sqrt| |ranges| |taylorRep| |whileLoop| |monicDivide| |Or| |numer| |parametrize| |crest| |allPairsAmong| |critMonD1| |halfExtendedSubResultantGcd2| |multiplicative?| |tubeRadius| |denom| |li| |setEpilogue!| |leftScalarTimes!| |vconcat| |removeDuplicates!| |kernel| |erf| |minimumExponent| EQ |nthFractionalTerm| |rCoord| |rationalPower| |monic?| |lastSubResultantElseSplit| |increase| |draw| |conditionsForIdempotents| |fullDesTree| |addmod| |front| |rightExactQuotient| |makeObject| |fullParamInit| |zeroDimensional?| |branchIfCan| |discriminant| |singularPointsWithRestriction| |cardinality| |ocf2ocdf| |dilog| |coef| |desingTreeWoFullParam| |plot| |lfextendedint| |principalIdeal| |linearAssociatedLog| |monom| |lazyPquo| |sin| |moreAlgebraic?| |stoseInternalLastSubResultant| |shiftLeft| |lazyPrem| |guessExpRat| |cos| |llprop| |stripCommentsAndBlanks| |separate| |wholePart| |sqfree| |tan| |leastMonomial| |pointInIdeal?| |acoshIfCan| |nextPartition| |rule| |OMsetEncoding| |mainValue| |cot| |associative?| |charthRoot| |moduloP| |trigs| |genericRightNorm| |sec| |setMinPoints| |drot| |mul| |primeFrobenius| |deepestInitial| |csc| |composite| |roughBase?| |linearMatrix| |bernoulliB| |ruleset| |asin| |expandLog| |monomial2series| |daxpy| |cylindrical| |numericalIntegration| |reduceLODE| |acos| |posExpnPart| |interval| |stopTableInvSet!| |resultant| |checkOptions| |atan| |rarrow| |groebner?| |pair?| |getlo| |generators| |acot| |edf2ef| |content| |unitCanonical| |startStats!| |consnewpol| |car| |asec| |eisensteinIrreducible?| |maxTower| |factorFraction| |leftUnits| |expr| |cdr| |rules| |acsc| |endOfFile?| |nextLatticePermutation| |composites| |orthonormalBasis| |palgRDE| |reportInstantiations| |squareTop| |sinh| |iiBesselK| |curryLeft| |cAsech| |closeComponent| |OMputSymbol| |cosh| |rightCharacteristicPolynomial| |OMencodingSGML| |jacobi| |compdegd| |rem| |intersectionDivisor| |tanh| |encode| |restorePrecision| |numericIfCan| |positiveRemainder| |cTanh| |coth| |numberRatPlacesExtDeg| |algebraicVariables| |trapezoidal| |pointSizeDefault| |quo| |match| |sech| |aColumn| |leftExtendedGcd| |optional?| |pmComplexintegrate| |palgRDE0| |OMputAttr| |op| |csch| |DiffC| |prefixRagits| |zCoord| |listBranches| |leftRank| |error| |/\\| |asinh| |rdregime| |highCommonTerms| |cyclicEqual?| |zeroMatrix| |affineAlgSetLocal| |\\/| |acosh| |determinant| |represents| |neglist| |cCosh| |cCsc| |atanh| |iiAiryAi| |setPosition| |lowerCase| |ramifiedAtInfinity?| |processTemplate| |acoth| |OMwrite| |palgextint| |firstExponent| |lazyEvaluate| ~= |asech| |quasiComponent| |prime| |integralCoordinates| |evaluate| |coefficients| |numberOfImproperPartitions| |isMult| |atanhIfCan| |LiePolyIfCan| |getVariableOrder| |dictionary| |simplifyPower| |roughBasicSet| |OMsend| |PollardSmallFactor| |elColumn2!| |enqueue!| |alphabetic| |goodPoint| |createNormalPrimitivePoly| |principal?| |swapColumns!| |stosePrepareSubResAlgo| |complexRoots| |exp1| |lists| |option?| |showTheFTable| |palgLODE| |constantKernel| |rhs| |makeMulti| |showTheSymbolTable| |dec| |gbasis| |numberOfNormalPoly| |ptree| |associatedEquations| |predicates| |resetNew| |coerce| |solveLinearlyOverQ| |desingTreeAtPoint| |submod| |topPredicate| |isQuotient| |complexNormalize| |infieldIntegrate| |positive?| |leader| |leadingBasisTerm| |phiCoord| |qnew| |shiftRight| |prinpolINFO| |maxDegree| |#| |complete| |df2ef| |balancedBinaryTree| |ShiftC| |modulus| |cyclicGroup| |FormatRoman| |setAdaptive| |pointData| |palginfieldint| |iiatanh| |monomRDEsys| |initials| |listOfMonoms| |setPoly| |recur| |dequeue!| |setTopPredicate| |showIntensityFunctions| |initTable!| |printingInfo?| |position| |limitPlus| |HenselLift| |eq?| |currentSubProgram| |findCycle| |overlabel| |tablePow| |dot| |binaryTree| |sumOfKthPowerDivisors| |and| |basisOfMiddleNucleus| |selectsecond| |symmetricPower| |fullOut| |expint| |decreasePrecision| |sumSquares| |critpOrder| |fffg| |testDim| |charClass| |partition| |unitNormalize| |safety| |genusTreeNeg| |multiplicity| |int| |copyDrift| |initiallyReduce| |functionIsContinuousAtEndPoints| |typeList| |selectFiniteRoutines| |round| |setnext!| |iiacos| |setref| |getStream| |functionIsOscillatory| |curveV| |characteristicSerie| |leftRemainder| |contract| |second| |upperCase?| |interReduce| |indiceSubResultantEuclidean| |reseed| |subs2ndVar| |imagI| |extractPoint| |inR?| |open| |polynomialZeros| |internalIntegrate0| |pow| |convert| |scan| |initParLocLeaves| |padicallyExpand| |formula| |flatten| |nthRootIfCan| |simplifyLog| |tryFunctionalDecomposition| |chebyshevU| |selectOrPolynomials| |tryFunctionalDecomposition?| |alternatingGroup| |bezoutMatrix| |bumptab1| |screenResolution| |pfaffian| |blowUpWithExcpDiv| |pdf2ef| |finiteSeries2LinSys| |fortranCarriageReturn| |innerEigenvectors| |traceMatrix| |resultantReduit| |leftRegularRepresentation| |headReduce| |adaptive| |exprex| |numeric| |coerceS| |safeCeiling| |shiftHP| |radical| |bitCoef| |limitedIntegrate| |maxIndex| |exprHasAlgebraicWeight| |homogeneous?| |rowEch| |inf| |SturmHabichtCoefficients| |rightGcd| |generalizedEigenvector| |thetaCoord| |preprocess| |mergeFactors| |mdeg| |index| |viewport2D| |superscript| |smaller?| |mapSolve| |doubleDisc| |point| |zeroSquareMatrix| |plenaryPower| |subscriptedVariables| |guessHolo| |purelyTranscendental?| |min| |cup| |updateStatus!| |hasHi| |linears| |makeSin| |chebyshevT| |monicRightDivide| |stoseLastSubResultant| |modularGcdPrimitive| |minimize| |library| |simplify| |itsALeaf!| |OMgetType| |normalizedDivide| |call| |supp| |lintgcd| |iicsch| |coHeight| ^= |removeSuperfluousQuasiComponents| |cSech| |iroot| |stFuncN| |variableName| |baseRDE| |choosemon| |functionNames| |increasePrecision| |integral| |leftTrace| |tensorProduct| |curry| |reduceBasisAtInfinity| |excepCoord| |rightDiscriminant| |universe| |reducedQPowers| |pquo| |radicalEigenvector| |palglimint0| |legendre| |iicot| |lineColorDefault| |completeEval| |singRicDE| |separant| |expandTrigProducts| |leviCivitaSymbol| |biringToPolyRing| |rowEchLocal| |sechIfCan| |firstSubsetGray| |fill!| |hermite| |OMgetAtp| |OMgetEndBVar| |segment| |options| |maxRowIndex| |setLegalFortranSourceExtensions| |ScanArabic| |datalist| |copyIto| |rewriteSetWithReduction| |writable?| |swap| |decompose| |copyslice| |ldf2vmf| |monicDecomposeIfCan| |definingInequation| |numberOfChildren| |setEmpty!| |OMread| |singularitiesOf| |third| |patternVariable| |transcendent?| |first| |primeFactor| |subs1stVar| |decrease| |raisePolynomial| |sinIfCan| |eigenMatrix| |argscript| |guessAlg| |fresnelC| |subresultantVector| |algebraicDecompose| |expextendedint| |cot2trig| |iiacot| |imagi| |replaceKthElement| |pr2dmp| |dimension| |coefficient| |startTableGcd!| |antisymmetricTensors| D |doublyTransitive?| |pToDmp| |exprHasLogarithmicWeights| |OMgetError| |sdf2lst| |euclideanNormalForm| |normal| |rowEchWoZeroLines| |basisOfCenter| |OMgetEndBind| |rightTraceMatrix| |linearPart| |kroneckerDelta| |right| |interpretString| |rightLcm| |complexExpand| |SturmHabicht| |iisech| |normal01| |left| |An| |coefOfFirstNonZeroTerm| |blockSplit| |indicialEquationAtInfinity| |bottom!| |factorsOfCyclicGroupSize| |list?| |outputAsTex| |relerror| |schwerpunkt| |nthExponent| |vectorcombination| |univariate?| |prod| |vertSplit| |ReduceOrder| |shallowCopy| |selectAndPolynomials| |isamax| |ScanFloatIgnoreSpaces| |resetBadValues| |mkIntegral| |quasiRegular| |zag| |taylor| |numFunEvals3D| |lp| |coth2tanh| |operation| |cAcsch| |canonicalIfCan| |lazyPseudoRemainder| |laurent| |perspective| |cyclicParents| |dcopy| |log2| |normalizedAssociate| |column| |puiseux| |digamma| |pastel| |rur| |ratPoly| |extractClosed| |Ei5| |psolve| |mkcomm| |nonSingularModel| |OMputObject| |polynomial| |leftMinimalPolynomial| |eigenvalues| |contractSolve| |ord| |edf2efi| |linGenPos| |subMatrix| |changeMeasure| |dioSolve| |varselect| |eulerE| |ffactor| |badNum| |delta| |monomial?| |OMParseError?| |elRow1!| |reindex| |elem?| |zeta| |factors| |quasiMonic?| |OMputEndBind| |prevPrime| |addiag| |rischDEsys| |floor| |polyred| |coerceListOfPairs| |eq| |duplicates| |fi2df| |signAround| |squareFreePrim| |uniform01| |point?| |extendedSubResultantGcd| |backOldPos| |nsqfree| |iisin| |copy!| |lflimitedint| |scanOneDimSubspaces| |physicalLength!| |clearTheFTable| |sqfrFactor| |intChoose| |pascalTriangle| |limit| |externalList| |secIfCan| |wordInGenerators| |basisOfLeftAnnihilator| |uncouplingMatrices| |forLoop| |fixedPoints| |setTex!| |makeSUP| |lambda| |LiePoly| |tube| |message| |cAcosh| |setImagSteps| |nthCoef| |repack1| |evalADE| |iiperm| |satisfy?| |yellow| |horizConcat| |qShiftAction| |unmakeSUP| |infinityNorm| |addMatch| |commonDenominator| |cAcos| |sum| |splitSquarefree| |meshPar1Var| |realEigenvectors| |negAndPosEdge| |Lazard2| |critM| |abelianGroup| |getDomains| |iisec| |matrixConcat3D| |setfirst!| |complexEigenvectors| |seed| |makeTerm| |singular?| |extract!| |parent| |mapMatrixIfCan| |lazyGintegrate| |tanQ| |rightPower| |henselFact| |insert!| |normal?| |meatAxe| |addPointLast| |projectivePoint| LODO2FUN |plus| |rightRankPolynomial| |weierstrass| |outlineRender| |cyclePartition| |iicsc| |readLineIfCan!| |size?| |roman| |binaryTournament| |basisOfInterpolateForms| |foundZeroes| |commutator| |rombergo| |pseudoQuotient| |setprevious!| |trigs2explogs| |packageCall| F2FG |setmult!| |irreducible?| |reducedForm| |lquo| |inGroundField?| |alphanumeric?| |izamax| |stepBlowUp| |viewPosDefault| |fortranLinkerArgs| |messagePrint| |nextPrime| |shiftInfoRec| |rightZero| |factorCantorZassenhaus| |acosIfCan| |zaxpy| |scaleRoots| |airyBi| |singleFactorBound| |omError| |accuracyIF| |exponentialOrder| |calcRanges| |pattern| |quadratic| |mapdiv| |tower| |range| |resultantEuclideannaif| |partialQuotients| |powerAssociative?| |Beta| |complexEigenvalues| |reduced?| |basisOfNucleus| |completeSmith| |infieldint| |iiBesselJ| |discreteLog| |summation| |unrankImproperPartitions1| |connect| |component| |setProperties| |leadingSupport| |complement| |pointColor| |localReal?| |nextSublist| |cache| |totalDegree| |points| |subscript| |aLinear| |mergeDifference| E1 |basis| |cLog| |argumentListOf| |lazyPseudoDivide| |kovacic| |lowerCase!| |OMputVariable| |bitLength| |identification| |symmetricRemainder| |doubleFloatFormat| |slope| |e01sbf| |position!| |ravel| |hessian| |dihedral| |getShiftRec| |mapmult| |mapUnivariate| |tubePlot| |expandPower| |OMcloseConn| |drawStyle| |clearDenominator| |rootOfIrreduciblePoly| UTS2UP |rootKerSimp| |strongGenerators| |set| |interpolateFormsForFact| |removeZero| |conjugate| |bipolar| GF2FG |quotient| |coordinates| |colorFunction| |acotIfCan| |firstNumer| |mainDefiningPolynomial| |diagonalProduct| |setScreenResolution3D| |inHallBasis?| |transform| |cot2tan| |complexSolve| |setColumn!| |paren| |stronglyReduce| |transpose| |suppOfZero| |ldf2lst| |zeroSetSplit| |leftMult| |setCondition!| |insertTop!| |linearAssociatedExp| |setClipValue| |entry?| |setPrologue!| |qPot| |isExpt| |viewDefaults| |useEisensteinCriterion| |clearTheIFTable| |minIndex| |replace| |integerBound| |charpol| |heapSort| |concat| |packModulus| |newtonPolySlope| |adjunctionDivisor| |rational| |irreducibleFactors| |zero?| |pole?| |controlPanel| |rowEchelonLocal| |viewSizeDefault| |exprHasWeightCosWXorSinWX| |imagE| |outputArgs| |besselY| |optAttributes| |ramified?| |factorial| |duplicates?| |tomodpa| |degOneCoef| |eigenvector| |conditionP| |quotedOperators| |mainVariables| |external?| |tableau| |getDatabase| |symbNameV| |acothIfCan| |FormatArabic| |jacobiIdentity?| |primintfldpoly| |completeHermite| |viewThetaDefault| |clipSurface| |rightRegularRepresentation| |torsion?| |clipPointsDefault| |rootRadius| |truncate| |goto| |closed?| |primextintfrac| |multiEuclidean| |magnitude| |ideal| |perfectNthPower?| |exQuo| |drawToScale| |adaptive3D?| |triangSolve| |viewPhiDefault| |factorset| |minPoints| |constantOperator| |convertIfCan| |changeVar| |value| |rightScalarTimes!| |changeNameToObjf| |cyclotomicDecomposition| |uncorrelated?| |physicalLength| |edf2df| |meshFun2Var| |adjoint| |morphism| |properties| |getCode| |numberOfFractionalTerms| |laurentRep| |beauzamyBound| |jordanAdmissible?| |setParam!| |badValues| |critT| |linearAssociatedOrder| |semiDiscriminantEuclidean| |cotIfCan| |initiallyReduced?| |aRow| |Gamma| |infinite?| |subtractIfCan| |scalarTypeOf| |cubic| |lBasis| |curve| |OMputString| |replaceVarByOne| |userOrdered?| |linearlyDependentOverZ?| |alternative?| |findCoef| |variationOfParameters| |returns| |generic?| |iicos| |linear?| |space| |getBadValues| |hasPredicate?| |high| |aspFilename| |algDsolve| |mainCharacterization| |remainder!| |script| |lfextlimint| |createNormalPoly| |constDsolve| |extDegree| |minrank| |var1Steps| |inrootof| |pointValue| |dn| |pToHdmp| |copyInto!| |nonLinearPart| |diag| |redmat| |iiacsch| |primlimitedint| |deepExpand| |chartCoord| |explicitlyEmpty?| |numberOfDivisors| |viewWriteDefault| |key?| |leftCharacteristicPolynomial| |roughEqualIdeals?| |cycleTail| |retract| |completeEchelonBasis| |OMputBVar| |complexNumericIfCan| |OMopenString| |setClosed| |fortran| |expintegrate| BY |degreeOfMinimalForm| |quoByVar| |innerSolve| |subNode?| |screenResolution3D| |OMgetFloat| |vectoraddmul| |asinhIfCan| |moebiusMu| |divergence| |csc2sin| |twoFactor| |OMgetEndApp| |cAcoth| |rightExtendedGcd| |fresnelS| |deref| |viewZoomDefault| |isPower| |linearlyDependent?| |computeCycleLength| |LowTriBddDenomInv| |lazyVariations| |iCompose| |invertIfCan| |iteratedInitials| |rational?| |shiftRoots| |totalLex| |complexForm| |cyclicSubmodule| |dzasum| |removeSuperfluousCases| |sortConstraints| |create| |tracePowMod| |areEquivalent?| |leftFactorIfCan| |evenInfiniteProduct| |generalInfiniteProduct| |slex| |setcurve!| |elRow2!| |extractTop!| |sec2cos| |lowerCase?| |geometric| |removeCosSq| |branchPointAtInfinity?| |maxLevel| |viewDeltaXDefault| |semiLastSubResultantEuclidean| |subset?| |SturmHabichtMultiple| |rationalPlaces| |axServer| |iiacosh| |makeViewport3D| |lieAdmissible?| |simpson| |parametersOf| |lfunc| |OMReadError?| |univariateSolve| |plus!| |radicalEigenvectors| |setMaxPoints3D| |showRegion| |constantToUnaryFunction| |cscIfCan| |normalized?| |OMputAtp| |primPartElseUnitCanonical| |integralRepresents| |setlocalPoint!| |rightRemainder| |diff| |pop!| |iiBesselI| |idamax| |viewDeltaYDefault| |normInvertible?| |rewriteSetByReducingWithParticularGenerators| |romberg| |children| |paraboloidal| |midpoints| |nextColeman| |factorAndSplit| |inverseLaplace| |OMputFloat| |besselK| |laurentIfCan| |fortranCharacter| |rightRecip| |randomLC| |wordInStrongGenerators| |localParamOfSimplePt| |collect| |findTerm| |mapUnivariateIfCan| |medialSet| |cyclicCopy| |reverse!| |deriv| |binary| |tex| |bringDown| |removeRoughlyRedundantFactorsInContents| |addBadValue| |aQuadratic| |powmod| |rischDE| |subResultantsChain| |algint| |exponents| |multinomial| |LagrangeInterpolation| |leftZero| |monicRightFactorIfCan| |chvar| |maxSubst| |viewWriteAvailable| |algintegrate| |pile| |qqq| |height| |gcdPolynomial| |associates?| |pack!| |approxNthRoot| |tanIfCan| |partitions| |power!| |lfinfieldint| |insertionSort!| |divide!| |setButtonValue| |setRow!| |logIfCan| |sh| |derivative| |setLabelValue| |expenseOfEvaluation| |toScale| |less?| |fortranLogical| |f02awf| |suppOfPole| |returnTypeOf| |copyBSD| |adaptive?| |goppaCode| |f02akf| |conical| |pmintegrate| |central?| |dznrm2| |squareFreeLexTriangular| |f02ajf| |generalInterpolation| |zoom| |iiasech| |Lazard| |arity| |f02agf| |cosh2sech| |branchPoint?| |maxPoints3D| |checkForZero| |closedCurve| |semiIndiceSubResultantEuclidean| |makeCrit| |univariatePolynomialsGcds| |localIntegralBasis| |prepareSubResAlgo| |f02aff| |setelt!| |OMclose| |cSinh| |singularPoints| |acschIfCan| |f02aef| |laplacian| |qroot| |OMputEndBVar| |setFieldInfo| |palgint| |f02adf| |setlocalParam!| |startTableInvSet!| |idealiserMatrix| |indicialEquations| |getButtonValue| |f02abf| |rightUnits| |definingEquations| |randomR| |close!| |torsionIfCan| |coerceL| |f02aaf| |mapDown!| |OMmakeConn| |collectUpper| |socf2socdf| |bumprow| |top!| |measure| |knownInfBasis| |rationalPoint?| |oddintegers| |selectPolynomials| |balancedFactorisation| |nil| |isOp| |iprint| |usingTable?| |sin?| |symmetricSquare| |lexGroebner| |getExplanations| |totalfract| |permanent| |stack| |tanh2coth| |degreeSubResultantEuclidean| |stoseInvertibleSetsqfreg| |identityMatrix| |bivariatePolynomials| |integralLastSubResultant| |imagK| |monicLeftDivide| |approximate| |asimpson| |multMonom| |mainVariable?| |f2st| |printHeader| |flagFactor| |safeFloor| |LazardQuotient| |vectorise| |reduceRowOnList| |quotVecSpaceBasis| |fractionFreeGauss!| |internalSubQuasiComponent?| |generalizedContinuumHypothesisAssumed| |createPrimitiveNormalPoly| |seriesToOutputForm| |purelyAlgebraicLeadingMonomial?| |zeroSetSplitIntoTriangularSystems| |rightUnit| |fortranDouble| |chartV| |matrixGcd| |ZetaFunction| |rotatez| |primitiveElement| |swapRows!| |oddlambert| |showTheRoutinesTable| |setSingularPoints| |Si| |unitVector| |dAndcExp| |numberOfComposites| |deepestTail| |iiBesselY| |npcoef| |makeYoungTableau| |true| |comparison| |leftPower| |setVariableOrder| |subSet| |latex| |stop| ** |applyRules| |radicalEigenvalues| |iomode| |makeViewport2D| |varList| |generalizedEigenvectors| |dmpToHdmp| |tanAn| |selectfirst| |fortranTypeOf| |tanhIfCan| |setMaxPoints| |topFortranOutputStack| |minimalForm| |cos2sec| |affinePoint| |df2mf| |withPredicates| |convergents| |nextsubResultant2| |cap| |writeLine!| |minPoly| |se2rfi| |columns| |merge!| |ridHack1| |affineRationalPoints| |flexible?| |nary?| |ref| |stoseInvertibleSetreg| |extension| |ParCond| |symmetricTensors| |antiAssociative?| |equation| |setsymbName!| |truncatedmuladd| |rischNormalize| |subCase?| |wrregime| |anfactor| |map| |style| |assign| |listexp| |loopPoints| |listLoops| |reduceRow| |hypergeometric0F1| |anticoord| |solveLinearPolynomialEquationByFractions| |B1solve| |placesOfDegree| |Ei3| |ceiling| |RittWuCompare| |cross| |row| |palgintegrate| |root| |lcm| |internalIntegrate| |constant?| |rationalApproximation| |printStatement| |rangePascalTriangle| |localUnquote| |bfKeys| |makeResult| |noKaratsuba| |Ei6| |getZechTable| |iipow| |hdmpToDmp| |gcdcofact| |algebraicOf| |numberOfCycles| |atom?| |printTypes| |euclideanSize| |palgLODE0| |complexElementary| |nextNormalPrimitivePoly| |xor| |nodes| |block| |e02bcf| |mulbyscalar| |extendIfCan| |cAsin| |guessRat| |low| |denominator| |e02bbf| |Yun| |UnVectorise| |UP2ifCan| |decomposeFunc| |makeFR| |removeRoughlyRedundantFactorsInPol| |e02baf| |operator| |bandedHessian| |norm| |leftTraceMatrix| |imaginary| |blue| |e02akf| |eigenvectors| |repSq| |stiffnessAndStabilityFactor| |figureUnits| |prime?| |skewSFunction| |e02ajf| |normalDenom| |eval| |extend| |shellSort| |att2Result| |move| |solveLinear| |e04ycf| |reducedDiscriminant| |mpsode| |semiSubResultantGcdEuclidean1| |ode| |graeffe| |distribute| |e04ucf| |reopen!| |LPolynomial| |toroidal| |brillhartTrials| |genericLeftMinimalPolynomial| |classNumber| |e04naf| |redPol| |stoseInvertibleSet| |back| |null?| |sort!| |useSingleFactorBound| |e04mbf| |normalElement| |getMeasure| |tree| |previousTower| |center| |createMultiplicationMatrix| |keys| |e04jaf| |polyRingToBlUpRing| |introduce!| |antiCommutator| |halfExtendedSubResultantGcd1| |subTriSet?| |condition| |resultantnaif| |e04gcf| |approximants| |iiasinh| |intersect| |makeEq| |setsubMatrix!| |errorInfo| |internalDecompose| |e04fdf| |cExp| |setOrder| |generalLambert| |cTan| |fixedPointExquo| |countRealRoots| |e04dgf| |systemCommand| |outputMeasure| |continuedFraction| |corrPoly| |inBetweenExcpDiv| |standardBasisOfCyclicSubmodule| |graphState| |f01ref| |measure2Result| |trim| |getMatch| |lyndon| |newTypeLists| |cn| |f01rdf| |genericRightDiscriminant| |series| |leadingIdeal| |yCoord| |stoseIntegralLastSubResultant| |recolor| |f01rcf| |OMputApp| |coercePreimagesImages| |validExponential| |empty| |constantOpIfCan| |acsch| |f01qef| |besselI| |extractProperty| |pointLists| |OMputEndError| |generalizedContinuumHypothesisAssumed?| |OMlistCDs| |f01qdf| |shanksDiscLogAlgorithm| |extractIndex| |multV| |newton| |divOfPole| |genericRightMinimalPolynomial| |f01qcf| |rootSimp| |exactQuotient!| |enterInCache| |internal?| |differentialVariables| |subMultV| |f01mcf| |getMultiplicationMatrix| |search| |tanNa| |primes| |taylorIfCan| |distance| |coefChoose| |f01maf| |finiteSeries2Vector| |certainlySubVariety?| |integralMatrixAtInfinity| |unravel| |effective?| |semicolonSeparate| |f01bsf| |module| |newReduc| |color| |diagonalMatrix| |generator| |primaryDecomp| |child?| |f01brf| |pdf2df| |clikeUniv| |diagonal?| |normFactors| |fTable| |empty?| |factorials| |unprotectedRemoveRedundantFactors| |enterPointData| |isPlus| |guessADE| |setright!| |mantissa| |hash| |real?| |solveid| |inverseColeman| |explicitlyFinite?| |clipWithRanges| |bezoutDiscriminant| |times!| |generalCoefficient| |cCsch| |sylvesterSequence| |prinshINFO| |qfactor| |BumInSepFFE| |collectQuasiMonic| |coshIfCan| |unrankImproperPartitions0| |minPoints3D| |setsubmult!| |trailingCoefficient| |factorSFBRlcUnit| |lllip| |lieAlgebra?| |printCode| |reciprocalPolynomial| |mapExponents| |toseInvertibleSet| |invertible?| |zeroDim?| |sech2cosh| |gcdprim| |terms| |OMgetInteger| |nullary| |finiteSeries2LinSysWOVectorise| |overset?| |radPoly| |triangular?| |cosIfCan| |problemPoints| |degreeSubResultant| |leadingTerm| |partialDenominators| |iidsum| |stirling1| LE |graphImage| |cAsinh| |leftTrim| |lo| |sample| |every?| |dasum| |leftRankPolynomial| |maxColIndex| |realSolve| |light| |incr| |OMputInteger| |inRadical?| |excpDivV| |fibonacci| |is?| |interpolate| |hi| |seriesSolve| |sumOfSquares| |quadraticBezier| |nlde| |ellipticCylindrical| |generalSqFr| |optpair| |generalizedInverse| |startPolynomial| |subHeight| |mainCoefficients| |remainder| |firstUncouplingMatrix| |print| |leftDiscriminant| |iiBeta| |augment| |mindegTerm| |setFoundPlacesToEmpty| |meshPar2Var| |iisqrt2| |lazyResidueClass| |belong?| |symmetricProduct| |iidigamma| |routines| |OMgetEndObject| |printStats!| |createRandomElement| |mathieu22| |resize| |setvalue!| |permutations| |fortranComplex| |setValue!| |ParCondList| |rowEchelon| |quasiRegular?| |alterDrift!| |node?| |numberOfValuesNeeded| |listAllMonoExp| |df2st| |absolutelyIrreducible?| |companionBlocks| |leftNorm| |lyndon?| |bandedJacobian| |declare| |weighted| |oddInfiniteProduct| |region| |setAdaptive3D| |algebraic?| |radicalRoots| |shrinkable| |putColorInfo| |removeRoughlyRedundantFactorsInPols| |bright| |bandMatrix| |expenseOfEvaluationIF| |double?| |supRittWu?| |extractSplittingLeaf| |result| |factorByRecursion| |factorSquareFree| |squareMatrix| |normalise| |infRittWu?| |generate| |output| |OMgetSymbol| |numberOfIrreduciblePoly| |diffHP| |incrementBy| |reduceByQuasiMonic| |leadingIndex| |atoms| |cAcsc| |toseLastSubResultant| |gramschmidt| |expand| |lighting| |clip| |matrixDimensions| |insertMatch| |filterWhile| |quadratic?| |elements| |hconcat| |genericRightTraceForm| |monomials| |filterUntil| |outputGeneral| |polyRicDE| |linSolve| |select| |additive?| |intensity| |power| |csch2sinh| |primintegrate| |harmonic| |square?| |lagrange| |gcdPrimitive| |symmetricGroup| |overbar| |qShiftC| |multiset| |showFortranOutputStack| |stopTable!| |fixPredicate| |maxPower| |linearPolynomials| |airyAi| |member?| |sayLength| |antiCommutative?| |smith| GE |genericPosition| |makeRecord| |OMgetBind| |curve?| |jacobian| |elliptic| |fullInfClsPt| |useNagFunctions| |OMputEndAtp| |subst| |numberOfVariables| |assoc| |shade| |deleteProperty!| |selectSumOfSquaresRoutines| |setrest!| |iter| |homogeneous| |lastSubResultantEuclidean| |trace2PowMod| |mainSquareFreePart| |factorGroebnerBasis| |mkPrim| |maxrow| |integrate| ~ |squareFree| |evaluateInverse| |desingTree| |newLine| |parse| |bitTruth| |middle| |zeroDimPrime?| |rightDivide| |constantLeft| |algebraicSort| |rk4a| |associatedSystem| |dihedralGroup| |nullity| |rk4f| |build| |subResultantChain| |icamax| |inverse| |cycleEntry| |radix| |inconsistent?| |cyclic| |tail| |semiDegreeSubResultantEuclidean| |label| |ratpart| |minus!| |interpret| |exactQuotient| |purelyAlgebraic?| |getOp| |OMreadStr| |initial| |option| |symbolIfCan| |repeating| |upperCase!| |repeatUntilLoop| |actualExtensionV| |simplifyExp| |multiEuclideanTree| |maxint| |delete| |atanIfCan| |groebnerFactorize| |sylvesterMatrix| |iidprod| |pseudoRemainder| |And| |exponent| |generalTwoFactor| |removeConstantTerm| |monomialIntegrate| |chineseRemainder| |sub| |iifact| |goodnessOfFit| |scalarMatrix| |zeroOf| |wreath| |setPredicates| |edf2fi| |cyclic?| |rk4qc| |Hausdorff| |simpleBounds?| |clipBoolean| |components| |clearTheSymbolTable| |equality| |OMencodingXML| |multiple| |level| |roughUnitIdeal?| |tubePointsDefault| |returnType!| |new| |optional| |nextIrreduciblePoly| |permutationRepresentation| |cyclotomicFactorization| |rationalFunction| |gcdcofactprim| |nextPrimitiveNormalPoly| |subResultantGcd| |setDegree!| |not| |mat| |mainVariable| = |leftOne| |minset| |null| |mvar| |mulmod| |fortranReal| |primitivePart| |d02cjf| |kmax| |retractToGrn| < |tubePoints| |biRank| |d02bhf| |applyQuote| |mapCoef| |root?| > |internalSubPolSet?| |indexName| |d02bbf| |moduleSum| |relationsIdeal| <= |box| |mindeg| |e02ahf| |getRef| |objects| |removeSinhSq| >= |ode2| |substring?| |char| |conjugates| |notelem| |pushup| |primitive?| |replaceDiffs| |OMopenFile| |head| |oneDimensionalArray| |LyndonBasis| |untab| + |limitedint| |coord| |d03faf| |ignore?| |rquo| - |iisqrt3| |birth| |d03eef| |exteriorDifferential| |selectODEIVPRoutines| |endSubProgram| / |next| |homogenize| |d03edf| |linearBezier| |cycleLength| |max| |possiblyNewVariety?| |declare!| |iipolygamma| |makeGraphImage| |splitNodeOf!| |evenlambert| |suffix?| |false| |symFunc| |OMgetApp| |partialFraction| |zRange| |explimitedint| |orderIfNegative| |bipolarCylindrical| |arrayStack| |expt| |normalizeIfCan| |groebnerIdeal| |factorPolynomial| |dnrm2| |cCot| |createNormalElement| |getEq| |listConjugateBases| |SturmHabichtSequence| |checkExtraValues| |powerSum| |cAtan| |top| |ShiftAction| |guess| |octon| |OMconnOutDevice| |outputSpacing| |subresultantSequence| |ODESolve| |lfintegrate| |makeVariable| |rroot| |someBasis| |fortranDoubleComplex| |packExps| |degreePartition| |objectOf| |ode1| |assert| |extractIfCan| |multisect| |any?| |commutativeEquality| |recip| |odd?| |quasiAlgebraicSet| |subsInVar| |initializeParamOfPlaces| |evalat| |setStatus| |semiResultantReduitEuclidean| |prefix?| |c05nbf| |quoted?| |factorList| |prem| |exponential1| |linkToFortran| |c05adf| |rootBound| |write!| |normalForm| |definingPolynomial| |graphStates| |c06gsf| |cycleRagits| |copyQuadVar| |univariatePolynomial| |integerDecode| |tRange| |c06gqf| |translate| |basisOfRightNucloid| |mapGen| |integers| |laguerreL| |c06gcf| |pointDominateBy| |integralDerivationMatrix| |solveInField| |boundOfCauchy| |legendreP| |c06gbf| |OMgetEndAttr| |patternMatch| |dflist| |musserTrials| |getGoodPrime| |c06fuf| |Frobenius| |cond| |wholeRagits| |polCase| |setFoundZeroes| |linearDependence| |c06frf| |lifting1| |rootNormalize| |iibinom| |theCurve| |c06fqf| |insertRoot!| |columnSpace| |tanintegrate| |permutationGroup| |printInfo!| |c06fpf| |totalDifferential| |leadingExponent| |finiteBasis| |chainSubResultants| |depth| |c06ekf| |createHN| |genericLeftTrace| |modifyPointData| |character?| |c06ecf| |deepCopy| |dom| |bfEntry| |polygon| |copies| |quadraticForm| |count| |c06ebf| |solveLinearPolynomialEquationByRecursion| |prolateSpheroidal| |hex| |lex| |cartesian| |c06eaf| |computePowers| |retractable?| |mix| |readIfCan!| |mapUp!| |s17def| |placesAbove| |fortranInteger| |besselJ| |binaryFunction| |extensionDegree| |s17dcf| |definingField| |exptMod| |generic| |coleman| |s17akf| |distFact| |roughSubIdeal?| |const| |headRemainder| |internalInfRittWu?| |s17ajf| |fortranLiteral| |Musser| |triangularSystems| |listAllMono| |setAttributeButtonStep| |s17ahf| |pol| |blankSeparate| |systemSizeIF| |setleaves!| |s17agf| |maxdeg| |removeSquaresIfCan| |nullary?| |lifting| |s17aff| |predicate| |univariatePolynomials| |invertibleSet| |binarySearchTree| |s17aef| |minimalPolynomial| |splitLinear| |leastPower| |guessRec| |makeFloatFunction| |s17adf| |sPol| |close| |optimize| |OMsupportsSymbol?| |Zero| |width| |maximumExponent| LT |s17acf| |showScalarValues| |allDegrees| |solveRetract| |mapBivariate| |s15aef| |solveLinearPolynomialEquation| |identitySquareMatrix| |isAbsolutelyIrreducible?| |tanh2trigh| |s15adf| |palgint0| |chiSquare1| |transCoord| |semiSubResultantGcdEuclidean2| |s14baf| |parabolic| |useEisensteinCriterion?| |display| |finiteBound| |pseudoRem| |s14abf| |subspace| |pureLex| |drawComplex| |setErrorBound| |s14aaf| |commutative?| |lookup| |lexico| |gcd| |reverseLex| |failed| |s13adf| |entry| |vspace| |even?| |nullSpace| |iitan| |s13acf| |one?| |tubeRadiusDefault| |hyperelliptic| |finite?| |cSin| |s13aaf| |bat| |symbolTable| |toseInvertible?| |genusNeg| |push!| |diagonals| |s01eaf| |dfRange| |pushFortranOutputStack| |or| |outputAsScript| |getMultiplicationTable| |virtualDegree| |Ei2| |s21bdf| |filename| |euclideanGroebner| |iflist2Result| |blockConcat| |changeWeightLevel| |s21bcf| |popFortranOutputStack| |complexIntegrate| |distdfact| |ScanFloatIgnoreSpacesIfCan| |presub| |s21bbf| |gnuDraw| |outputAsFortran| |nextsousResultant2| |factorSqFree| |triangulate| |curveColor| |s21baf| |hitherPlane| |dimensionOfIrreducibleRepresentation| |polyRing2UPUP| |wholeRadix| |primlimintfrac| |s20adf| |subResultantGcdEuclidean| |positiveSolve| |plotPolar| |localParamV| |e02agf| |innerint| |guessBinRat| |stopTableGcd!| |constantRight| |newElement| |match?| |s20acf| |exquo| |basisOfCentroid| |sturmVariationsOf| |concat!| |unitNormal| |revert| |d01aqf| |div| |outputFixed| |listYoungTableaus| |splitDenominator| |iiAiryBi| |s19adf| |basisOfInterpolateFormsForFact| |explicitEntries?| |machineFraction| |logical?| |d01apf| |lhs| |supDimElseRittWu?| |getGraph| |checkRur| |s19acf| |radicalOfLeftTraceForm| |monicCompleteDecompose| |resultantEuclidean| |realRoots| |d01anf| |differentiate| |quote| |computeBasis| |modifyPoint| |hexDigit?| |d01amf| |lift| |shift| |sizeLess?| |factorSquareFreeByRecursion| |curryRight| |normalizeAtInfinity| |d01alf| |reduce| |toseSquareFreePart| |rightMult| |Ei4| |OMgetEndError| |s19abf| |property| |associatorDependence| |vector| |insert| |associator| |distinguishedCommonRootsOf| |divideIfCan| |d01akf| |bits| |powers| |completeHensel| |reduction| |s19aaf| |ramifMult| |iiabs| |viewpoint| |product| |d01ajf| GT |units| |leaf?| |factorsOfDegree| |cCoth| |infix| |s18def| |complexZeros| |sturmSequence| |previous| |asecIfCan| |s18dcf| |localParam| |genericLeftNorm| |rightFactorCandidate| |leftLcm| |s18aff| |basisOfLeftNucloid| |applyTransform| |noncommutativeJordanAlgebra?| |LyndonWordsList1| |code| |init| |s18aef| |bat1| |mathieu12| |halfExtendedResultant1| |indices| |s18adf| |setexcpDiv!| |reshape| |rightFactorIfCan| |cyclicEntries| |hermiteH| |s18acf| |drotg| |integralAtInfinity?| |rewriteIdealWithHeadRemainder| |dimensions| |integralBasisAtInfinity| |f04qaf| |lastSubResultant| |shufflein| |mightHaveRoots| |listOfTerms| |f04mcf| |showTypeInOutput| |twist| |En| |oblateSpheroidal| |f04mbf| |invertibleElseSplit?| |LyndonWordsList| |var2StepsDefault| |rotate| |f04maf| |OMserve| |iicosh| |sinhcosh| |allRootsOf| |f04jgf| |denomRicDE| |squareFreePart| |semiResultantEuclidean1| |f04faf| |numberOfOperations| |createLowComplexityNormalBasis| |algSplitSimple| |prologue| |f04axf| |maxDerivative| |makeCos| |outputFloating| |bracket| |f04atf| |direction| |inverseIntegralMatrixAtInfinity| |solid| |makeSeries| |f04asf| |reduceLineOverLine| |linearDependenceOverZ| |cAtanh| |computeInt| |ptFunc| SEGMENT |fullOutput| |karatsubaDivide| |flexibleArray| |f04arf| |removeRedundantFactors| |Is| |pointColorDefault| |generateIrredPoly| |weight| |iExquo| |upperCase| |f04adf| |divisors| |index?| |minordet| |nand| |putGraph| |Vectorise| |realZeros| |exprToXXP| |compBound| |mesh?| |imagk| |resetAttributeButtons| |digit?| |removeZeroes| |rangeIsFinite| |cAsec| |largest| |reset| |continue| |iicoth| |extendedint| |sbt| |whatInfinity| |write| F2EXPRR |numberOfComponents| |logGamma| |save| |setpoint!| |selectMultiDimensionalRoutines| |createPrimitiveElement| |clearTable!| |f07fef| |fractRagits| |isList| |myDegree| |removeIrreducibleRedundantFactors| |f07fdf| |hasSolution?| |moebius| |var1StepsDefault| Y |blowUp| |setCurve| |f07aef| |euler| |splitConstant| |factor1| |dark| |f07adf| |hdmpToP| NOT |imagj| |dim| |listRepresentation| |d| |OMconnInDevice| OR |rightOne| |numerator| |numberOfFactors| |s17dlf| |divOfZero| AND |pointPlot| |commaSeparate| |factorUsingMusser| |s17dhf| |leftAlternative?| |janko2| |arg1| |hue| |s17dgf| |quotValuation| |denomLODE| |arg2| |addPoint2| |fractionPart| |f02xef| |explogs2trigs| |internalZeroSetSplit| |simpsono| |sumOfDivisors| |f02wef| |zerosOf| |po| |BasicMethod| |maxPoints| |f02fjf| |possiblyInfinite?| |scripted?| |permutation| |bumptab| |f02bjf| |update| |lSpaceBasis| |testModulus| |palgextint0| |numberOfHues| |laplace| |f02bbf| |hexDigit| |e| |replaceVarByZero| |rightQuotient| |invmultisect| |f02axf| |double| |aCubic| |nthExpon| |tan2trig| |karatsubaOnce| |printInfo| |denominators| |lowerPolynomial| * |increment| |gethi| |bombieriNorm| |swap!| |infClsPt?| |cosSinInfo| |numFunEvals| |internalAugment| |groebner| |nthr| |minPol| |rootOf| |alterQuadVar!| |patternMatchTimes| |getPickedPoints| |symbolTableOf| |bit?| |maxShift| |xCoord| |solid?| |selectNonFiniteRoutines| |rightMinimalPolynomial| |lazyIrreducibleFactors| |genus| |iFTable| |rk4| |nextItem| |poisson| |mainContent| |initializeGroupForWordProblem| |setTower!| |ksec| |elt| |youngGroup| |maxMixedDegree| |outputList| |upDateBranches| |setelt| |rubiksGroup| |stoseInvertible?sqfreg| |coth2trigh| |redpps| |totolex| |dmp2rfi| |polar| |sign| |uniform| |contains?| |makeSketch| |partialNumerators| |reducedSystem| |cubicBezier| |dscal| |fullDisplay| |overlap| |appendPoint| |antisymmetric?| |ratDsolve| |sin2csc| |LyndonCoordinates| |qinterval| |sizePascalTriangle| |HermiteIntegrate| F |qelt| |sort| |affineAlgSet| |subQuasiComponent?| |rotatex| |rewriteIdealWithQuasiMonicGenerators| |credPol| |showClipRegion| |GospersMethod| |fillPascalTriangle| |rationalPoints| |mapExpon| |check| |basisOfLeftNucleus| |atrapezoidal| |hMonic| |setScreenResolution| |rdHack1| |DiffAction| |pushdown| |OMlistSymbols| |quotientByP| |indiceSubResultant| |clearFortranOutputStack| |variable| |changeName| |complementaryBasis| |over| |map!| |subPolSet?| |prefix| |multiplyExponents| UP2UTS |child| |particularSolution| |leftUnit| |createIrreduciblePoly| |real| |karatsuba| |OMencodingUnknown| |cycles| |traverse| |complex| |exprToGenUPS| |mainMonomials| |parts| |solve| |lambert| |input| |pushucoef| |repeating?| |characteristic| |unvectorise| |test| |heap| |createGenericMatrix| |prepareDecompose| |table| |bernoulli| |polygamma| |ipow| |makeUnit| |lprop| |basisOfCommutingElements| |integralBasis| |sincos| |modularGcd| |gderiv| |quickSort| |refine| |idealiser| |comp| |typeLists| |halfExtendedResultant2| |rightRank| |symmetric?| |decimal| |numberOfMonomials| |leadingCoefficientRicDE| |removeCoshSq| |type| |digit| |hclf| |binomial| |squareFreePolynomial| |drawCurves| |numerators| |lepol| |precision| |delay| |functionName| |find| |basisOfRightNucleus| |divisorAtDesingTree| FG2F |stFunc1| |exprToUPS| |numberPlacesDegExtDeg| |dominantTerm| |froot| |monomialIntPoly| |compose| |structuralConstants| |OMconnectTCP| |leaves| |binomThmExpt| |remove!| |updatD| |sparsityIF| |frobenius| |asechIfCan| |presuper| |nonQsign| |factorOfDegree| |cycleElt| |mathieu11| |shallowExpand| |sorted?| |element| |perfectSquare?| |sup| |red| |createPrimitivePoly| |directory| |rst| |leftDivide| |variables| |scale| |common| |approxSqrt| |iiasin| |times| |createThreeSpace| |invmod| |closedCurve?| |yCoordinates| |name| |divisor| |regime| |failed?| |copyfirst| |droot| |debug3D| |createZechTable| |mirror| |polyPart| |queue| |jordanAlgebra?| |modTree| |htrigs| |infinity| |any| |setMinPoints3D| |df2fi| |delete!| |rspace| |computeCycleEntry| |title| |nextSubsetGray| |fprindINFO| |rootPoly| |polarCoordinates| |updatF| |expIfCan| |quartic| |nextPrimitivePoly| |select!| |guessPade| |normDeriv2| |Aleph| |functionIsFracPolynomial?| |stoseInvertible?| |complexLimit| |t| |doubleResultant| |fracPart| |stronglyReduced?| |unexpand| |inspect| |mesh| |displayKind| |checkPrecision| |clearCache| |radicalSolve| |split!| |btwFact| |infLex?| |create3Space| |rotatey| |zeroDimPrimary?| |outputForm| |extendedgcd| |setRealSteps| |collectUnder| |setchart!| |redPo| |divideIfCan!| |leftExactQuotient| |Ci| |leftRecip| |extendedEuclidean| |mainKernel| |univcase| |taylorQuoByVar| |palglimint| |changeBase| |quadTransform| |guessPRec| |subNodeOf?| |number?| |readLine!| |ricDsolve| |implies| |generalPosition| |intcompBasis| |derivationCoordinates| |rank| |critB| |hadamard| |semiResultantEuclideannaif| |rotate!| |PDESolve| |iilog| |rationalIfCan| |OMreceive| |compactFraction| |inc| |matrix| |e01sff| |symbol?| |parabolicCylindrical| |genericLeftDiscriminant| |void| |logpart| |f2df| |rightAlternative?| |cPower| |vedf2vef| |log10| |characteristicPolynomial| |summary| |origin| |reducedContinuedFraction| |leastAffineMultiple| |conditions| |innerSolve1| |show| |minimumDegree| |iisinh| |cothIfCan| |pomopo!| |entries| |realEigenvalues| |OMgetBVar| |algebraicSet| |bivariateSLPEBR| |e02aef| |relativeApprox| |tableForDiscreteLogarithm| |writeObj| |numberOfComputedEntries| |identity| |Somos| |spherical| |stiffnessAndStabilityOfODEIF| |c02agf| |extractBottom!| |base| |vark| |safetyMargin| |drift| |c02aff| |addMatchRestricted| |linear| |length| |lastNonNull| |setStatus!| |parametric?| |e02adf| |pleskenSplit| |scripts| |epilogue| |mathieu24| |critMTonD1| |rootPower| |c05pbf| |node| |showAttributes| |rowEchWoZeroLinesWOVectorise| |OMputEndObject| |constant| |clipParametric| |modularFactor| |UpTriBddDenomInv| |localize| |xRange| |last| |credits| |One| |compile| |getAncestors| |schema| |characteristicSet| |leftGcd| |addPoint| |iiatan| |Ei1| |coerceP| |e01sef| |sncndn| |irreducibleRepresentation| |KrullNumber| |doubleRank| |e01saf| |alternating| |rows| |removeRedundantFactorsInPols| |nodeOf?| |integer?| |infix?| |e01daf| |minColIndex| |constantIfCan| |rightTrace| |separateDegrees| |e01bhf| |prinb| |lazyIntegrate| |makeprod| |deleteRoutine!| |e01bgf| |random| |slash| |nrows| |separateFactors| |setchildren!| |stFunc2| |e01bff| |opeval| |ncols| |Ei| |curveColorPalette| |filterUpTo| |e01bef| |OMencodingBinary| |transcendentalDecompose| |sn| |weakBiRank| |e01baf| |leftQuotient| |dequeue| |stopMusserTrials| |OMsupportsCD?| |displayAsGF| |e02zaf| |listVariable| |unitsColorDefault| |OMputEndAttr| |e02gaf| |groebgen| |listSD| |fintegrate| |MPtoMPT| |translateToOrigin| |e02dff| |eulerPhi| |trivialIdeal?| |imagJ| |getOrder| |difference| |e02def| |countable?| |exponential| |element?| |selectOptimizationRoutines| |combineFeatureCompatibility| |e02ddf| |critBonD| |integerIfCan| |fglmIfCan| |var2Steps| |OMgetVariable| |e02dcf| |flush| |wordsForStrongGenerators| |discriminantEuclidean| |more?| |order| |e02daf| |bsolve| |stoseSquareFreePart| |domainOf| |guessHP| |asinIfCan| |e02bef| |unparse| |suchThat| |OMputBind| |polyRDE| |crushedSet| |e02bdf| |alphanumeric| |expPot| |realElementary| |outerProduct| |setOfMinN| |pade| |minusInfinity| |compiledFunction| |retractIfCan| |pseudoDivide| |OMputEndApp| |monicModulo| |showAll?| |integralMatrix| |plusInfinity| |solve1| |startTable!| |reorder| |fixedDivisor| |evalRec| |lazyPseudoQuotient| |getCurve| |pointToPlace| |quatern| |useSingleFactorBound?| |mainForm| |colorDef| |trueEqual| |operators| |findOrderOfDivisor| |localAbs| |showAllElements| |specialTrigs| |read!| |affineSingularPoints| |dcabs1| |stirling2| |OMbindTCP| |normalize| |localPointV| |postfix| |isobaric?| |multiple?| |hcrf| |maxrank| |graphs| |digits| |superHeight| |autoReduced?| |cCos| |internalLastSubResultant| |errorKind| |getSmgl| |OMUnknownSymbol?| |d01gbf| |makeop| |stoseInvertible?reg| |padicFraction| |supersub| |fractRadix| |d01gaf| |isTimes| |nthRoot| |prindINFO| |transcendenceDegree| |sinh2csch| |d01fcf| |nilFactor| |groebSolve| |RemainderList| |in?| |resetVariableOrder| |d01bbf| |say| |nthFlag| |open?| |indicialEquation| |d01asf| |intermediateResultsIF| |debug| |representationType| |powern| |headReduced?| |pdct| |OMgetString| |distinguishedRootsOf| |cyclotomic| |rightTrim| |d02raf| |nthFactor| |hspace| |insertBottom!| |setProperty| |d02kef| |conjug| |newtonPolygon| |obj| RF2UTS |d02gbf| |remove| |rename| |csubst| |makingStats?| |pointColorPalette| |d02gaf| |iiacsc| |construct| |members| |alphabetic?| |numberOfPrimitivePoly| |d02ejf| |symmetricDifference| |createLowComplexityTable| |mainMonomial| |evalIfCan| |lastNonNul| |countRealRootsMultiple| |super| |aromberg| |frst| |complexNumeric| |rootProduct| |firstDenom| |extendedResultant| |OMgetObject| |hasoln| |kernels| |factorUsingYun| |pushdterm| |diophantineSystem| |unaryFunction| |merge| |univariate| |regularRepresentation| |sinhIfCan| |elementary| |setlast!| |multiServ| |tan2cot| |status| |factor| |pointV| |OMgetAttr| |drawComplexVectorField| |iitanh| |lyndonIfCan| |imag| |interpolateForms| |radicalSimplify| |unit| |divideExponents| |iiGamma| |directProduct| |OMgetEndAtp| |bivariate?| |padecf| |elliptic?| |lazyPremWithDefault| |destruct| |squareFreeFactors| |tanSum| |rewriteIdealWithRemainder| |intPatternMatch| |cycle| |wronskianMatrix| |degree| |monomial| |semiResultantEuclidean2| |union| |trace| |numberOfPlacesOfDegree| |fixedPoint| |comment| |multivariate| |pushuconst| |cfirst| |unary?| |genusTree| |perfectSqrt| |expressIdealMember| |float| |changeThreshhold| |xn| |mathieu23| |primitivePart!| |rootSplit| |log| |id| |rename!| |probablyZeroDim?| |fmecg| |integral?| |inv| |integer| |defineProperty| |quadraticNorm| |quasiMonicPolynomials| |irreducibleFactor| |ran| |ground?| |bag| |mask| |orbits| |expintfldpoly| |horizSplit| |ground| |primextendedint| |statusIto| |mainPrimitivePart| |resultantReduitEuclidean| |divide| |lexTriangular| |apply| |leadingMonomial| |string| |argument| |SFunction| |minRowIndex| |singularAtInfinity?| |leadingCoefficient| |constantCoefficientRicDE| |cAcot| |zeroVector| |randnum| |genericRightTrace| |primitiveMonomials| |brace| |dmpToP| |viewport3D| |showArrayValues| |setFormula!| |fortranCompilerName| |cons| |reductum| |LazardQuotient2| |polygon?| |vertConcat| |fullPartialFraction| |cRationalPower| |copy| |removeSinSq| |listOfLists| |string?| |float?| |bezoutResultant| |OMunhandledSymbol| |nil| |infinite| |arbitraryExponent| |approximate| |complex| |shallowMutable| |canonical| |noetherian| |central| |partiallyOrderedSet| |arbitraryPrecision| |canonicalsClosed| |noZeroDivisors| |rightUnitary| |leftUnitary| |additiveValuation| |unitsKnown| |canonicalUnitNormal| |multiplicativeValuation| |finiteAggregate| |shallowlyMutable| |commutative|) 
\ No newline at end of file
diff --git a/src/share/algebra/dependents.daase/index.kaf b/src/share/algebra/dependents.daase/index.kaf
index 65fc862..426e4e3 100644
--- a/src/share/algebra/dependents.daase/index.kaf
+++ b/src/share/algebra/dependents.daase/index.kaf
@@ -1,4 +1,4 @@
-76913               (|AbelianGroup&| |FourierSeries| |FreeAbelianGroup| |IndexedDirectProductAbelianGroup| |QuadraticForm|)
+77354               (|AbelianGroup&| |FourierSeries| |FreeAbelianGroup| |IndexedDirectProductAbelianGroup| |QuadraticForm|)
 (|AbelianMonoid&| |CardinalNumber| |EuclideanModularRing| |GradedAlgebra| |GradedAlgebra&| |GradedModule| |GradedModule&| |IndexedDirectProductAbelianMonoid| |ListMonoidOps| |ModularField| |ModularRing| |RecurrenceOperator|)
 (|AbelianMonoidRing&| |FractionFreeFastGaussian|)
 (|AbelianSemiGroup&| |Color| |IncrementingMaps| |PositiveInteger|)
@@ -57,21 +57,21 @@
 (|CRApackage| |ComplexFactorization| |ConstantLODE| |ContinuedFraction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |FractionalIdeal| |FractionalIdealFunctions2| |FramedModule| |FunctionFieldIntegralBasis| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |GenExEuclid| |GenUFactorize| |GeneralHenselPackage| |GroebnerFactorizationPackage| |InnerModularGcd| |InnerMultFact| |IntegralBasisTools| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |LaplaceTransform| |LeadingCoefDetermination| |MPolyCatPolyFactorizer| |MRationalFactorize| |ModularHermitianRowReduction| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |NPCoef| |NonLinearFirstOrderODESolver| |ODEIntegration| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |PolynomialGcdPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionFactorizer| |RationalUnivariateRepresentationPackage| |SmithNormalForm| |TransSolvePackage| |ZeroDimensionalSolvePackage|)
 (|Evalable&|)
 (|UnivariatePuiseuxSeriesWithExponentialSingularity|)
-(|DeRhamComplex|)
+(|DeRhamComplex| |StochasticDifferential|)
 (|AlgebraicManipulations| |AlgebraicNumber| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |FortranExpression| |InnerAlgebraicNumber|)
 (|ExtensibleLinearAggregate&| |FlexibleArray| |IndexedFlexibleArray|)
 (|ExtensionField&| |PseudoAlgebraicClosureOfFiniteField|)
-(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffineSpace| |AffineSpaceCategory| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicManipulations| |BlowUpPackage| |BoundIntegerRoots| |CliffordAlgebra| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |DenavitHartenbergMatrix| |DesingTreePackage| |DoubleResultantPackage| |EllipticFunctionsUnivariateTaylorSeries| |ExponentialOfUnivariatePuiseuxSeries| |ExtensionField| |ExtensionField&| |Field&| |FindOrderFinite| |FiniteAlgebraicExtensionField| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FloatingComplexPackage| |FloatingRealPackage| |FullPartialFractionExpansion| |FunctionSpaceToUnivariatePowerSeries| |GaloisGroupFactorizationUtilities| |GeneralPackageForAlgebraicFunctionField| |GosperSummationMethod| |Guess| |HyperellipticFiniteDivisor| |InfClsPt| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InnerAlgFactor| |InnerMatrixLinearAlgebraFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |IntegrationResult| |IntegrationResultFunctions2| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinesOpPack| |LocalParametrizationOfSimplePointPackage| |LocalPowerSeriesCategory| |MachineFloat| |ModularField| |MoebiusTransform| |MonomialExtensionTools| |NeitherSparseOrDensePowerSeries| |NonCommutativeOperatorDivision| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODETools| |PackageForAlgebraicFunctionField| |PadeApproximantPackage| |PadeApproximants| |ParametrizationPackage| |PartialFraction| |Pi| |Places| |PlacesCategory| |Plcs| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialPackageForCurve| |PolynomialRoots| |PolynomialSolveByFormulas| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectiveSpace| |ProjectiveSpaceCategory| |PseudoLinearNormalForm| |PureAlgebraicLODE| |QuadraticForm| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |ResidueRing| |RightOpenIntervalRootCharacterization| |RootsFindingPackage| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor| |StructuralConstantsPackage| |SystemODESolver| |TangentExpansions| |TaylorSolve| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |VectorSpace| |VectorSpace&| |WeierstrassPreparation|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffineSpace| |AffineSpaceCategory| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicManipulations| |BlowUpPackage| |BoundIntegerRoots| |CliffordAlgebra| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |DenavitHartenbergMatrix| |DesingTreePackage| |DoubleResultantPackage| |EllipticFunctionsUnivariateTaylorSeries| |ExponentialOfUnivariatePuiseuxSeries| |ExtensionField| |ExtensionField&| |Field&| |FindOrderFinite| |FiniteAlgebraicExtensionField| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FloatingComplexPackage| |FloatingRealPackage| |FullPartialFractionExpansion| |FunctionSpaceToUnivariatePowerSeries| |GaloisGroupFactorizationUtilities| |GeneralPackageForAlgebraicFunctionField| |GosperSummationMethod| |Guess| |HyperellipticFiniteDivisor| |InfClsPt| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InnerAlgFactor| |InnerMatrixLinearAlgebraFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |IntegrationResult| |IntegrationResultFunctions2| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinesOpPack| |LocalParametrizationOfSimplePointPackage| |LocalPowerSeriesCategory| |MachineFloat| |MatrixManipulation| |ModularField| |MoebiusTransform| |MonomialExtensionTools| |NeitherSparseOrDensePowerSeries| |NonCommutativeOperatorDivision| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODETools| |PackageForAlgebraicFunctionField| |PadeApproximantPackage| |PadeApproximants| |ParametrizationPackage| |PartialFraction| |Pi| |Places| |PlacesCategory| |Plcs| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialPackageForCurve| |PolynomialRoots| |PolynomialSolveByFormulas| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectiveSpace| |ProjectiveSpaceCategory| |PseudoLinearNormalForm| |PureAlgebraicLODE| |QuadraticForm| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |ResidueRing| |RightOpenIntervalRootCharacterization| |RootsFindingPackage| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor| |StructuralConstantsPackage| |SystemODESolver| |TangentExpansions| |TaylorSolve| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |VectorSpace| |VectorSpace&| |WeierstrassPreparation|)
 (|FieldOfPrimeCharacteristic&| |FiniteFieldPolynomialPackage2|)
 (|BinaryFile| |File| |FortranTemplate| |KeyedAccessFile| |TextFile|)
 (|BinaryFile| |File| |FortranTemplate| |KeyedAccessFile| |TextFile|)
 (|FileName|)
-(|Boolean| |DiscreteLogarithmPackage| |FindOrderFinite| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |IntegerMod| |ReducedDivisor| |SetOfMIntegersInOneToN|)
+(|Boolean| |DiscreteLogarithmPackage| |FindOrderFinite| |Finite&| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |IntegerMod| |ReducedDivisor| |SetOfMIntegersInOneToN|)
 (|BlowUpPackage| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FractionFreeFastGaussianFractions| |NewtonPolygon| |PackageForPoly| |PolynomialPackageForCurve| |PolynomialRing| |SymmetricPolynomial| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |InnerFiniteField| |InnerPrimeField| |NormRetractPackage| |PrimeField|)
 (|FiniteDivisor| |FiniteDivisorCategory&| |HyperellipticFiniteDivisor|)
-(|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |ChineseRemainderToolsForIntegralBases| |DistinctDegreeFactorize| |FiniteFieldCategory&| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |GuessFinite| |GuessFiniteFunctions| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerNormalBasisFieldFunctions| |InnerPrimeField| |IrredPolyOverFiniteField| |MultFiniteFactorize| |NormRetractPackage| |NottinghamGroup| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionFieldOverFiniteField| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PrimeField| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfFiniteField| |TwoFactorize| |WildFunctionFieldIntegralBasis|)
-(|BezoutMatrix| |CommonDenominator| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |InnerCommonDenominator| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |LinearSystemMatrixPackage| |MatrixCategory| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MultiVariableCalculusFunctions| |SmithNormalForm| |TriangularMatrixOperations| |TwoDimensionalArrayCategory| |TwoDimensionalArrayCategory&|)
+(|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |ChineseRemainderToolsForIntegralBases| |DistinctDegreeFactorize| |FiniteFieldCategory&| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |GuessFinite| |GuessFiniteFunctions| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerNormalBasisFieldFunctions| |InnerPrimeField| |IrredPolyOverFiniteField| |MultFiniteFactorize| |NormRetractPackage| |NottinghamGroup| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionFieldOverFiniteField| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PrimeField| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfFiniteField| |TwoFactorize| |WildFunctionFieldIntegralBasis|)
+(|BezoutMatrix| |CommonDenominator| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |InnerCommonDenominator| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |LinearSystemMatrixPackage| |MatrixCategory| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MultiVariableCalculusFunctions| |SmithNormalForm| |TriangularMatrixOperations| |TwoDimensionalArrayCategory| |TwoDimensionalArrayCategory&|)
 (|FiniteRankAlgebra&|)
 (|FiniteRankNonAssociativeAlgebra&|)
 (|CharacterClass| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |Set|)
@@ -112,9 +112,9 @@
 (|InnerEvalable&|)
 (|InnerFiniteField|)
 (|Boolean| |DoubleFloat| |ExpressionSolve| |ExpressionSpaceODESolver| |Float| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |OrderedVariableList| |Pi| |PlotFunctions1| |RecurrenceOperator| |Symbol| |TopLevelDrawFunctions|)
-(|AlgebraicIntegrate| |AlgebraicNumber| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |BrillhartTests| |CartesianTensor| |CartesianTensorFunctions2| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |DecimalExpansion| |DefiniteIntegrationTools| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FourierSeries| |FreeAbelianGroup| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |GuessFinite| |GuessFiniteFunctions| |HeuGcd| |HexadecimalExpansion| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerAlgebraicNumber| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InputForm| |IntegerLinearDependence| |IntegerMod| |IntegerRetractions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LieExponentials| |LinearOrdinaryDifferentialOperatorFactorizer| |MachineFloat| |ModularDistinctDegreeFactorizer| |MyExpression| |NeitherSparseOrDensePowerSeries| |NonLinearFirstOrderODESolver| |NumberFieldIntegralBasis| |ODEIntegration| |OrderedVariableList| |PAdicInteger| |PAdicIntegerCategory| |PAdicRational| |PAdicRationalConstructor| |Partition| |PatternMatchIntegration| |Pi| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RadixExpansion| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionSum| |RationalIntegration| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealZeroPackage| |RealZeroPackageQ| |RecurrenceOperator| |SAERationalFunctionAlgFactor| |SExpression| |SimpleAlgebraicExtensionAlgFactor| |SortPackage| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |Symbol| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |TrigonometricManipulations| |U32Vector| |UnivariateFactorize| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateTaylorSeriesODESolver| |XExponentialPackage|)
+(|AlgebraicIntegrate| |AlgebraicNumber| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |BrillhartTests| |CartesianTensor| |CartesianTensorFunctions2| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |DecimalExpansion| |DefiniteIntegrationTools| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FourierSeries| |FreeAbelianGroup| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |GuessFinite| |GuessFiniteFunctions| |HeuGcd| |HexadecimalExpansion| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerAlgebraicNumber| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InputForm| |IntegerLinearDependence| |IntegerMod| |IntegerRetractions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LieExponentials| |LinearOrdinaryDifferentialOperatorFactorizer| |MachineFloat| |ModularDistinctDegreeFactorizer| |MyExpression| |NeitherSparseOrDensePowerSeries| |NonLinearFirstOrderODESolver| |NumberFieldIntegralBasis| |ODEIntegration| |OrderedVariableList| |PAdicInteger| |PAdicIntegerCategory| |PAdicRational| |PAdicRationalConstructor| |Partition| |PatternMatchIntegration| |Pi| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RadixExpansion| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionSum| |RationalIntegration| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealZeroPackage| |RealZeroPackageQ| |RecurrenceOperator| |SAERationalFunctionAlgFactor| |SExpression| |SimpleAlgebraicExtensionAlgFactor| |SortPackage| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |Symbol| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |TrigonometricManipulations| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UnivariateFactorize| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateTaylorSeriesODESolver| |XExponentialPackage|)
 (|ComplexIntegerSolveLinearPolynomialEquation| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerNumberSystem&| |IntegerPrimesPackage| |IntegerRoots| |MachineInteger| |PatternMatchIntegerNumberSystem| |RomanNumeral| |SingleInteger|)
-(|AlgebraPackage| |AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicallyClosedFunctionSpace| |AlgebraicallyClosedFunctionSpace&| |AssociatedEquations| |CombinatorialFunction| |CommonDenominator| |ComplexTrigonometricManipulations| |DegreeReductionPackage| |DrawNumericHack| |ElementaryFunction| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ExpressionSolve| |ExpressionSpaceODESolver| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GenerateUnivariatePowerSeries| |GosperSummationMethod| |Guess| |InfiniteProductCharacteristicZero| |InnerCommonDenominator| |InnerMatrixQuotientFieldFunctions| |InnerPolySum| |InnerTrigonometricManipulations| |IntegralDomain&| |LaurentPolynomial| |LinearDependence| |LinearSystemPolynomialPackage| |LiouvillianFunction| |MPolyCatRationalFunctionFactorizer| |MatrixCommonDenominator| |MultipleMap| |MyExpression| |NewtonInterpolation| |NonLinearSolvePackage| |PatternMatchFunctionSpace| |PatternMatchQuotientFieldCategory| |PiCoercions| |PointsOfFiniteOrder| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PrecomputedAssociatedEquations| |PseudoRemainderSequence| |QuotientFieldCategory| |QuotientFieldCategory&| |QuotientFieldCategoryFunctions2| |RationalFunction| |RationalFunctionIntegration| |RationalFunctionSum| |RecurrenceOperator| |RetractSolvePackage| |StreamInfiniteProduct| |SubResultantPackage| |SystemSolvePackage| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackageService| |TriangularMatrixOperations| |TriangularSetCategory| |TriangularSetCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeriesWithExponentialSingularity| |WuWenTsunTriangularSet|)
+(|AlgebraPackage| |AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicallyClosedFunctionSpace| |AlgebraicallyClosedFunctionSpace&| |AssociatedEquations| |CombinatorialFunction| |CommonDenominator| |ComplexTrigonometricManipulations| |DegreeReductionPackage| |DrawNumericHack| |ElementaryFunction| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ExpressionSolve| |ExpressionSpaceODESolver| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GenerateUnivariatePowerSeries| |GosperSummationMethod| |Guess| |InfiniteProductCharacteristicZero| |InnerCommonDenominator| |InnerMatrixQuotientFieldFunctions| |InnerPolySum| |InnerTrigonometricManipulations| |IntegralDomain&| |LaurentPolynomial| |LinearDependence| |LinearSystemPolynomialPackage| |LiouvillianFunction| |MPolyCatRationalFunctionFactorizer| |MatrixCommonDenominator| |MultipleMap| |MyExpression| |NewtonInterpolation| |NonLinearSolvePackage| |PatternMatchFunctionSpace| |PatternMatchQuotientFieldCategory| |PiCoercions| |PointsOfFiniteOrder| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PrecomputedAssociatedEquations| |PseudoRemainderSequence| |QuotientFieldCategory| |QuotientFieldCategory&| |QuotientFieldCategoryFunctions2| |RationalFunction| |RationalFunctionIntegration| |RationalFunctionSum| |RecurrenceOperator| |RetractSolvePackage| |StochasticDifferential| |StreamInfiniteProduct| |SubResultantPackage| |SystemSolvePackage| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackageService| |TriangularMatrixOperations| |TriangularSetCategory| |TriangularSetCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeriesWithExponentialSingularity| |WuWenTsunTriangularSet|)
 (|Interval|)
 (|PatternMatchFunctionSpace| |PatternMatchKernel|)
 (|KeyedDictionary&|)
@@ -132,8 +132,8 @@
 (|LiePolynomial| |PoincareBirkhoffWittLyndonBasis|)
 (|MachineComplex|)
 (|AlgebraGivenByStructuralConstants| |GenericNonAssociativeAlgebra| |LieSquareMatrix| |RectangularMatrix| |SquareMatrix|)
-(|BezoutMatrix| |ComplexDoubleFloatMatrix| |DenavitHartenbergMatrix| |DoubleFloatMatrix| |IndexedMatrix| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |LinearSystemMatrixPackage| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |SmithNormalForm| |TriangularMatrixOperations|)
-(|FreeAbelianGroup| |GeneralModulePolynomial| |IntegrationResult| |LieExponentials| |Localize| |Module&| |XExponentialPackage|)
+(|BezoutMatrix| |ComplexDoubleFloatMatrix| |DenavitHartenbergMatrix| |DoubleFloatMatrix| |IndexedMatrix| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |LinearSystemMatrixPackage| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |SmithNormalForm| |TriangularMatrixOperations| |U16Matrix| |U32Matrix| |U8Matrix|)
+(|FreeAbelianGroup| |GeneralModulePolynomial| |IntegrationResult| |LieExponentials| |Localize| |Module&| |StochasticDifferential| |XExponentialPackage|)
 (|Monad&|)
 (|MonadWithUnit&|)
 (|CharacteristicPolynomialInMonogenicalAlgebra| |InfiniteProductFiniteField| |InnerAlgFactor| |MonogenicAlgebra&| |NormInMonogenicAlgebra| |PAdicWildFunctionFieldIntegralBasis| |ReduceLODE| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor|)
@@ -153,7 +153,7 @@
 (|e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|Octonion| |OctonionCategory&| |OctonionCategoryFunctions2|)
 (|TwoDimensionalArray|)
-(|FlexibleArray| |IndexedFlexibleArray| |IndexedOneDimensionalArray| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |PrimitiveArray| |U32Vector|)
+(|FlexibleArray| |IndexedFlexibleArray| |IndexedOneDimensionalArray| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |PrimitiveArray| |U16Vector| |U32Vector| |U8Vector|)
 (|DoubleFloat| |ExpressionToOpenMath| |Float| |Integer| |SingleInteger| |Symbol|)
 (|AbelianMonoidRing| |AbelianMonoidRing&| |ExponentialOfUnivariatePuiseuxSeries| |FiniteAbelianMonoidRing| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |IndexedDirectProductOrderedAbelianMonoid| |OrderingFunctions| |PolynomialRing| |PowerSeriesCategory| |PowerSeriesCategory&| |UnivariatePowerSeriesCategory| |UnivariatePowerSeriesCategory&|)
 (|AlgebraicMultFact| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |EuclideanGroebnerBasisPackage| |FactoringUtilities| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |HomogeneousDirectProduct| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |InnerMultFact| |InnerPolySum| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LinearSystemPolynomialPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |NPCoef| |NonNegativeInteger| |NormalizationPackage| |NormalizedTriangularSetCategory| |OrderedDirectProduct| |ParametricLinearEquations| |PatternMatchPolynomialCategory| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSquareFree| |PushVariables| |QuasiAlgebraicSet| |QuasiComponentPackage| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |ResidueRing| |SplitHomogeneousDirectProduct| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |TriangularSetCategory| |TriangularSetCategory&| |WeightedPolynomials| |WuWenTsunTriangularSet|)
@@ -163,7 +163,7 @@
 (|SturmHabichtPackage|)
 (|OrderedFreeMonoid| |XPolynomialRing|)
 (|ComplexRootFindingPackage| |ComplexRootPackage| |ExpertSystemToolsPackage1| |FloatingComplexPackage| |FloatingRealPackage| |FunctionSpaceToUnivariatePowerSeries| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderedRing&| |RealClosure| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |RightOpenIntervalRootCharacterization| |SegmentExpansionCategory| |ZeroDimensionalSolvePackage|)
-(|AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicMultFact| |AlgebraicallyClosedFunctionSpace| |AlgebraicallyClosedFunctionSpace&| |ApplyRules| |BasicOperator| |BasicStochasticDifferential| |BinarySearchTree| |BinaryTournament| |Boolean| |CardinalNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |ConstantLODE| |DataList| |Database| |DeRhamComplex| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory| |DifferentialVariableCategory&| |DrawNumericHack| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EuclideanGroebnerBasisPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionFunctions2| |ExpressionSolve| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |FactoringUtilities| |FourierComponent| |FourierSeries| |FreeLieAlgebra| |FreeModule| |FreeModule1| |FunctionSpace| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceFunctions2| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GeneralModulePolynomial| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |Heap| |IndexCard| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductCategory| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |InnerMultFact| |InnerPolySum| |InnerTrigonometricManipulations| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |Kernel| |KernelFunctions2| |LaplaceTransform| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LieExponentials| |LiePolynomial| |LinearSystemPolynomialPackage| |LiouvillianFunction| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |Magma| |MergeThing| |ModuleMonomial| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |MultivariateTaylorSeriesCategory| |MyExpression| |NPCoef| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |NormalizationPackage| |NormalizedTriangularSetCategory| |ODEIntegration| |OrdSetInts| |OrderedFreeMonoid| |OrderedMultisetAggregate| |OrderedSet&| |OrderlyDifferentialVariable| |ParametricLinearEquations| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchTools| |PiCoercions| |PoincareBirkhoffWittLyndonBasis| |PointsOfFiniteOrder| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PriorityQueueAggregate| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiComponentPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |RecurrenceOperator| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |ResidueRing| |RewriteRule| |Ruleset| |SequentialDifferentialVariable| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |Symbol| |TableauxBumpers| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TriangularSetCategory| |TriangularSetCategory&| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |XPBWPolynomial| |XPolynomialsCat| |XRecursivePolynomial|)
+(|AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicMultFact| |AlgebraicallyClosedFunctionSpace| |AlgebraicallyClosedFunctionSpace&| |ApplyRules| |BasicOperator| |BasicStochasticDifferential| |BinarySearchTree| |BinaryTournament| |Boolean| |CardinalNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |ConstantLODE| |DataList| |Database| |DeRhamComplex| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory| |DifferentialVariableCategory&| |DrawNumericHack| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EuclideanGroebnerBasisPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionFunctions2| |ExpressionSolve| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |FactoringUtilities| |FourierComponent| |FourierSeries| |FreeLieAlgebra| |FreeModule| |FreeModule1| |FunctionSpace| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceFunctions2| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GeneralModulePolynomial| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |Heap| |IndexCard| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductCategory| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |InnerMultFact| |InnerPolySum| |InnerTrigonometricManipulations| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |Kernel| |KernelFunctions2| |LaplaceTransform| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LieExponentials| |LiePolynomial| |LinearSystemPolynomialPackage| |LiouvillianFunction| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |Magma| |MergeThing| |ModuleMonomial| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |MultivariateTaylorSeriesCategory| |MyExpression| |NPCoef| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |NormalizationPackage| |NormalizedTriangularSetCategory| |ODEIntegration| |OrdSetInts| |OrderedFreeMonoid| |OrderedMultisetAggregate| |OrderedSet&| |OrderlyDifferentialVariable| |ParametricLinearEquations| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchTools| |PiCoercions| |PoincareBirkhoffWittLyndonBasis| |PointsOfFiniteOrder| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PriorityQueueAggregate| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiComponentPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |RecurrenceOperator| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |ResidueRing| |RewriteRule| |Ruleset| |SequentialDifferentialVariable| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |StochasticDifferential| |SupFractionFactorizer| |Symbol| |TableauxBumpers| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TriangularSetCategory| |TriangularSetCategory&| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |XPBWPolynomial| |XPolynomialsCat| |XRecursivePolynomial|)
 (|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |DesingTreePackage| |DistributedMultivariatePolynomial| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |HomogeneousDistributedMultivariatePolynomial| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LocalParametrizationOfSimplePointPackage| |MultivariatePolynomial| |ParametrizationPackage| |ProjectiveAlgebraicSetPackage| |RegularChain|)
 (|OrderlyDifferentialPolynomial|)
 (|d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType|)
@@ -219,7 +219,7 @@
 (|LazardSetSolvingPackage| |NormalizationPackage| |QuasiComponentPackage| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |SquareFreeQuasiComponentPackage| |SquareFreeRegularTriangularSetGcdPackage|)
 (|AlgebraicIntegrate| |AlgebraicNumber| |AntiSymm| |BoundIntegerRoots| |CardinalNumber| |ComplexTrigonometricManipulations| |ConstantLODE| |DeRhamComplex| |DefiniteIntegrationTools| |DifferentialSparseMultivariatePolynomial| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FortranExpression| |FractionalIdeal| |FractionalIdealFunctions2| |FreeGroup| |FreeMonoid| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |InnerAlgebraicNumber| |IntegerRetractions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ListMonoidOps| |LyndonWord| |MachineFloat| |Magma| |ModuleOperator| |MonoidRing| |MyExpression| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |ODEIntegration| |Operator| |OrderedFreeMonoid| |OrderlyDifferentialPolynomial| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchTools| |Pi| |PoincareBirkhoffWittLyndonBasis| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSum| |RationalIntegration| |RationalLODE| |RationalRetractions| |RationalRicDE| |RecurrenceOperator| |RetractSolvePackage| |RetractableTo&| |RewriteRule| |SequentialDifferentialPolynomial| |SparseUnivariatePuiseuxSeries| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |TrigonometricManipulations| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|AbelianMonoidRing| |AbelianMonoidRing&| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |Automorphism| |Bezier| |BezoutMatrix| |BiModule| |CliffordAlgebra| |CommuteUnivariatePolynomialCategory| |DeRhamComplex| |DegreeReductionPackage| |DifferentialExtension| |DifferentialExtension&| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DistributedMultivariatePolynomial| |ExpertSystemToolsPackage2| |ExpressionToOpenMath| |FactoringUtilities| |FiniteAbelianMonoidRing| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FreeModule| |FreeModule1| |FreeModuleCat| |FullyLinearlyExplicitRingOver| |FullyLinearlyExplicitRingOver&| |FunctionSpaceFunctions2| |GaloisGroupFactorizationUtilities| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralUnivariatePowerSeries| |HomogeneousDistributedMultivariatePolynomial| |IndexedMatrix| |InnerPolySign| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |IntegralBasisPolynomialTools| |LeftAlgebra| |LeftAlgebra&| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorCategory| |LinearOrdinaryDifferentialOperatorCategory&| |LinearlyExplicitRingOver| |MPolyCatFunctions2| |MPolyCatFunctions3| |MappingPackage4| |Matrix| |MatrixCategory| |MatrixCategory&| |MatrixCategoryFunctions2| |ModMonic| |ModularRing| |ModuleOperator| |MonogenicLinearOperator| |MonoidRing| |MonoidRingFunctions2| |MultivariatePolynomial| |MultivariateTaylorSeriesCategory| |MyExpression| |MyUnivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2| |NewtonPolygon| |Operator| |OppositeMonogenicLinearOperator| |OrderlyDifferentialPolynomial| |OrdinaryWeightedPolynomials| |PackageForPoly| |PatternMatchPolynomialCategory| |PatternMatchTools| |Permanent| |Point| |PointCategory| |PointFunctions2| |PointPackage| |PolToPol| |Polynomial| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialFunctions2| |PolynomialRing| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialToUnivariatePolynomial| |PowerSeriesCategory| |PowerSeriesCategory&| |PushVariables| |RectangularMatrix| |RectangularMatrixCategory| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RepresentationPackage1| |RepresentationPackage2| |RewriteRule| |Ring&| |Ruleset| |SequentialDifferentialPolynomial| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SquareMatrix| |SquareMatrixCategory| |SquareMatrixCategory&| |StorageEfficientMatrixOperations| |StreamTaylorSeriesOperations| |SubSpace| |SymmetricFunctions| |SymmetricPolynomial| |TaylorSeries| |ThreeSpace| |ThreeSpaceCategory| |ToolsForSign| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateFormalPowerSeriesFunctions| |UnivariateLaurentSeries| |UnivariateLaurentSeriesCategory| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialFunctions2| |UnivariatePolynomialMultiplicationPackage| |UnivariatePowerSeriesCategory| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesCategory| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesFunctions2| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesFunctions2| |WeightedPolynomials| |XAlgebra| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |XPolynomial| |XPolynomialRing| |XPolynomialsCat| |XRecursivePolynomial|)
-(|LeftModule| |RightModule|)
+(|LeftModule| |RightModule| |StochasticDifferential|)
 (|InputForm|)
 (|InputForm| |SExpression| |SExpressionOf|)
 (|Segment| |UniversalSegment|)
@@ -253,13 +253,16 @@
 (|GeneralTriangularSet| |TriangularSetCategory&| |WuWenTsunTriangularSet|)
 (|TrigonometricFunctionCategory&|)
 (|IndexedTwoDimensionalArray| |InnerIndexedTwoDimensionalArray| |TwoDimensionalArray| |TwoDimensionalArrayCategory&|)
-(|AnyFunctions1| |AttachPredicates| |BagAggregate| |BagAggregate&| |BinaryRecursiveAggregate| |BinaryRecursiveAggregate&| |CoercibleTo| |Collection| |Collection&| |ConvertibleTo| |CyclicStreamTools| |DequeueAggregate| |DirectProduct| |DirectProductCategory| |DirectProductCategory&| |DirectProductFunctions2| |DoublyLinkedAggregate| |DrawOptionFunctions1| |Eltable| |EltableAggregate| |EltableAggregate&| |Equation| |EquationFunctions2| |ExpressionSpaceFunctions1| |ExtensibleLinearAggregate| |ExtensibleLinearAggregate&| |FiniteLinearAggregate| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FlexibleArray| |FullyPatternMatchable| |FullyRetractableTo| |FullyRetractableTo&| |FunctionSpaceAttachPredicates| |HomogeneousAggregate| |HomogeneousAggregate&| |IndexedAggregate| |IndexedAggregate&| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteTuple| |InfiniteTupleFunctions2| |InfiniteTupleFunctions3| |InnerEvalable| |InnerEvalable&| |InnerIndexedTwoDimensionalArray| |InputFormFunctions1| |LazyStreamAggregate| |LazyStreamAggregate&| |LinearAggregate| |LinearAggregate&| |List| |ListAggregate| |ListAggregate&| |ListFunctions2| |ListFunctions3| |ListToMap| |MakeBinaryCompiledFunction| |MakeRecord| |MakeUnaryCompiledFunction| |NoneFunctions1| |OneDimensionalArray| |OneDimensionalArrayAggregate| |OneDimensionalArrayAggregate&| |OneDimensionalArrayFunctions2| |ParadoxicalCombinatorsForStreams| |ParametricPlaneCurve| |ParametricPlaneCurveFunctions2| |ParametricSpaceCurve| |ParametricSpaceCurveFunctions2| |ParametricSurface| |ParametricSurfaceFunctions2| |PatternFunctions1| |Patternable| |PrimitiveArray| |PrimitiveArrayFunctions2| |QueueAggregate| |RecursiveAggregate| |RecursiveAggregate&| |Reference| |ResolveLatticeCompletion| |RetractableTo| |RetractableTo&| |Segment| |SegmentBinding| |SegmentBindingFunctions2| |SegmentCategory| |SegmentFunctions2| |SortPackage| |StackAggregate| |Stream| |StreamAggregate| |StreamAggregate&| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamTensor| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory| |TwoDimensionalArrayCategory&| |UnaryRecursiveAggregate| |UnaryRecursiveAggregate&| |UniversalSegment| |UniversalSegmentFunctions2| |Vector| |VectorCategory| |VectorCategory&| |VectorFunctions2|)
+(|AnyFunctions1| |AttachPredicates| |BagAggregate| |BagAggregate&| |BinaryRecursiveAggregate| |BinaryRecursiveAggregate&| |CoercibleTo| |Collection| |Collection&| |ConvertibleTo| |CyclicStreamTools| |DequeueAggregate| |DirectProduct| |DirectProductCategory| |DirectProductCategory&| |DirectProductFunctions2| |DoublyLinkedAggregate| |DrawOptionFunctions1| |Eltable| |EltableAggregate| |EltableAggregate&| |Equation| |EquationFunctions2| |ExpressionSpaceFunctions1| |ExtensibleLinearAggregate| |ExtensibleLinearAggregate&| |FiniteLinearAggregate| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FlexibleArray| |FullyPatternMatchable| |FullyRetractableTo| |FullyRetractableTo&| |FunctionSpaceAttachPredicates| |HomogeneousAggregate| |HomogeneousAggregate&| |IndexedAggregate| |IndexedAggregate&| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteTuple| |InfiniteTupleFunctions2| |InfiniteTupleFunctions3| |InnerEvalable| |InnerEvalable&| |InnerIndexedTwoDimensionalArray| |InputFormFunctions1| |LazyStreamAggregate| |LazyStreamAggregate&| |LinearAggregate| |LinearAggregate&| |List| |ListAggregate| |ListAggregate&| |ListFunctions2| |ListFunctions3| |ListToMap| |MakeBinaryCompiledFunction| |MakeRecord| |MakeUnaryCompiledFunction| |ModularAlgebraicGcdOperations| |NoneFunctions1| |OneDimensionalArray| |OneDimensionalArrayAggregate| |OneDimensionalArrayAggregate&| |OneDimensionalArrayFunctions2| |ParadoxicalCombinatorsForStreams| |ParametricPlaneCurve| |ParametricPlaneCurveFunctions2| |ParametricSpaceCurve| |ParametricSpaceCurveFunctions2| |ParametricSurface| |ParametricSurfaceFunctions2| |PatternFunctions1| |Patternable| |PrimitiveArray| |PrimitiveArrayFunctions2| |QueueAggregate| |RecursiveAggregate| |RecursiveAggregate&| |Reference| |ResolveLatticeCompletion| |RetractableTo| |RetractableTo&| |Segment| |SegmentBinding| |SegmentBindingFunctions2| |SegmentCategory| |SegmentFunctions2| |SortPackage| |StackAggregate| |Stream| |StreamAggregate| |StreamAggregate&| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamTensor| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory| |TwoDimensionalArrayCategory&| |UnaryRecursiveAggregate| |UnaryRecursiveAggregate&| |UniversalSegment| |UniversalSegmentFunctions2| |Vector| |VectorCategory| |VectorCategory&| |VectorFunctions2|)
+(|U16Matrix|)
+(|U32Matrix|)
+(|U8Matrix|)
 (|UnaryRecursiveAggregate&|)
 (|ChangeOfVariable| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |RadicalFunctionField| |UniqueFactorizationDomain&|)
 (|UnivariatePuiseuxSeries|)
 (|ElementaryFunctionsUnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructorCategory&|)
 (|ElementaryFunctionsUnivariateLaurentSeries| |SparseUnivariateLaurentSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&|)
-(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |BalancedFactorisation| |BezoutMatrix| |BoundIntegerRoots| |BrillhartTests| |ChangeOfVariable| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |CommuteUnivariatePolynomialCategory| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |DistinctDegreeFactorize| |DoubleResultantPackage| |EuclideanModularRing| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra| |FramedAlgebra&| |FramedModule| |FullPartialFractionExpansion| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |FunctionFieldIntegralBasis| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GenExEuclid| |GeneralHenselPackage| |HeuGcd| |HyperellipticFiniteDivisor| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerModularGcd| |InnerPolySign| |IntegralBasisPolynomialTools| |IntegralBasisTools| |Kovacic| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ModMonic| |ModularDistinctDegreeFactorizer| |MonogenicAlgebra| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MyUnivariatePolynomial| |NPCoef| |NewSparseUnivariatePolynomial| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberFieldIntegralBasis| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximants| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursionUnivariate| |PolynomialInterpolationAlgorithms| |PolynomialSolveByFormulas| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoRemainderSequence| |PureAlgebraicLODE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalIntegration| |RationalLODE| |RationalRicDE| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |RealZeroPackage| |RealZeroPackageQ| |ReduceLODE| |ReducedDivisor| |RightOpenIntervalRootCharacterization| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SubResultantPackage| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |UTSodetools| |UnivariateFactorize| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |WildFunctionFieldIntegralBasis|)
+(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |BalancedFactorisation| |BezoutMatrix| |BoundIntegerRoots| |BrillhartTests| |ChangeOfVariable| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |CommuteUnivariatePolynomialCategory| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |DistinctDegreeFactorize| |DoubleResultantPackage| |EuclideanModularRing| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra| |FramedAlgebra&| |FramedModule| |FullPartialFractionExpansion| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |FunctionFieldIntegralBasis| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GenExEuclid| |GeneralHenselPackage| |HeuGcd| |HyperellipticFiniteDivisor| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerModularGcd| |InnerPolySign| |IntegralBasisPolynomialTools| |IntegralBasisTools| |Kovacic| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ModMonic| |ModularDistinctDegreeFactorizer| |MonogenicAlgebra| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MyUnivariatePolynomial| |NPCoef| |NewSparseUnivariatePolynomial| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberFieldIntegralBasis| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximants| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursionUnivariate| |PolynomialInterpolationAlgorithms| |PolynomialSolveByFormulas| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoRemainderSequence| |PureAlgebraicLODE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalIntegration| |RationalLODE| |RationalRicDE| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |RealZeroPackage| |RealZeroPackageQ| |ReduceLODE| |ReducedDivisor| |RightOpenIntervalRootCharacterization| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SubResultantPackage| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |UTSodetools| |UnivariateFactorize| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |WildFunctionFieldIntegralBasis|)
 (|FunctionSpaceToUnivariatePowerSeries| |InnerSparseUnivariatePowerSeries| |UnivariatePowerSeriesCategory&|)
 (|ExponentialExpansion| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|ExponentialOfUnivariatePuiseuxSeries| |GeneralUnivariatePowerSeries|)
@@ -273,4 +276,4 @@
 (|CliffordAlgebra| |VectorSpace&|)
 (|XPolynomialRing|)
 (|XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XRecursivePolynomial|)
-(("XPolynomialsCat" 0 76810) ("XAlgebra" 0 76790) ("VectorSpace" 0 76755) ("VectorCategory" 0 76663) ("Vector" 0 76475) ("UnivariateTaylorSeriesCategory" 0 75881) ("UnivariateTaylorSeries" 0 75827) ("UnivariateSkewPolynomialCategory" 0 75659) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 75634) ("UnivariatePuiseuxSeriesConstructorCategory" 0 75446) ("UnivariatePuiseuxSeriesCategory" 0 75374) ("UnivariatePuiseuxSeries" 0 75297) ("UnivariatePowerSeriesCategory" 0 75188) ("UnivariatePolynomialCategory" 0 72155) ("UnivariateLaurentSeriesConstructorCategory" 0 71967) ("UnivariateLaurentSeriesCategory" 0 71792) ("UnivariateLaurentSeries" 0 71764) ("UniqueFactorizationDomain" 0 71608) ("UnaryRecursiveAggregate" 0 71579) ("Type" 0 69201) ("TwoDimensionalArrayCategory" 0 69083) ("TrigonometricFunctionCategory" 0 69048) ("TriangularSetCategory" 0 68973) ("TranscendentalFunctionCategory" 0 67819) ("ThreeSpaceCategory" 0 67804) ("TableAggregate" 0 67639) ("SymbolTable" 0 67620) ("Symbol" 0 65195) ("StringCategory" 0 65184) ("StringAggregate" 0 65147) ("String" 0 65001) ("StreamAggregate" 0 64953) ("StepThrough" 0 64938) ("StackAggregate" 0 64915) ("SquareMatrixCategory" 0 64828) ("SquareMatrix" 0 64759) ("SquareFreeRegularTriangularSetCategory" 0 64605) ("SplittingNode" 0 64587) ("SpecialFunctionCategory" 0 64545) ("SparseUnivariateTaylorSeries" 0 64479) ("SparseUnivariatePolynomialExpressions" 0 64445) ("SparseUnivariatePolynomial" 0 64279) ("SparseUnivariateLaurentSeries" 0 64245) ("SparseMultivariatePolynomial" 0 64099) ("SingleInteger" 0 64038) ("SetCategoryWithDegree" 0 64026) ("SetCategory" 0 60927) ("SetAggregate" 0 60909) ("SequentialDifferentialVariable" 0 60872) ("SemiGroup" 0 60857) ("SegmentCategory" 0 60826) ("SExpressionCategory" 0 60782) ("SExpression" 0 60768) ("Rng" 0 60739) ("Ring" 0 56252) ("RetractableTo" 0 53949) ("RegularTriangularSetCategory" 0 53661) ("RecursivePolynomialCategory" 0 52846) ("RecursiveAggregate" 0 52799) ("RectangularMatrixCategory" 0 52710) ("RealRootCharacterizationCategory" 0 52632) ("RealNumberSystem" 0 52610) ("RealConstant" 0 52518) ("RealClosedField" 0 52483) ("RadicalCategory" 0 52365) ("QuotientFieldCategory" 0 51882) ("QueueAggregate" 0 51872) ("QuaternionCategory" 0 51804) ("Quaternion" 0 51791) ("QuadraticForm" 0 51771) ("PseudoAlgebraicClosureOfRationalNumberCategory" 0 51670) ("PseudoAlgebraicClosureOfRationalNumber" 0 51619) ("PseudoAlgebraicClosureOfFiniteFieldCategory" 0 51579) ("PseudoAlgebraicClosureOfFiniteField" 0 51358) ("PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory" 0 51241) ("ProjectiveSpaceCategory" 0 50763) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 50700) ("ProjectivePlane" 0 50687) ("PriorityQueueAggregate" 0 50678) ("PrimitiveFunctionCategory" 0 50440) ("PrimitiveArray" 0 50430) ("PrimeField" 0 50364) ("PowerSeriesCategory" 0 50339) ("PositiveInteger" 0 49869) ("PolynomialSetCategory" 0 49819) ("PolynomialFactorizationExplicit" 0 49630) ("PolynomialCategory" 0 48073) ("Polynomial" 0 47906) ("PointCategory" 0 47896) ("PoincareBirkhoffWittLyndonBasis" 0 47877) ("PlottableSpaceCurveCategory" 0 47837) ("PlottablePlaneCurveCategory" 0 47802) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 47739) ("PlacesCategory" 0 47436) ("Places" 0 47423) ("PermutationCategory" 0 47407) ("Patternable" 0 47396) ("PatternMatchable" 0 47142) ("Pattern" 0 46902) ("Partition" 0 46878) ("PartialTranscendentalFunctions" 0 46747) ("PartialDifferentialRing" 0 46594) ("PartialDifferentialEquationsSolverCategory" 0 46558) ("PAdicIntegerCategory" 0 46471) ("PAdicInteger" 0 46453) ("OutputForm" 0 46313) ("OrdinaryDifferentialEquationsSolverCategory" 0 46243) ("OrderlyDifferentialVariable" 0 46209) ("OrderedVariableList" 0 45660) ("OrderedSet" 0 40518) ("OrderedRing" 0 40042) ("OrderedMonoid" 0 40002) ("OrderedIntegralDomain" 0 39978) ("OrderedFreeMonoid" 0 39951) ("OrderedFinite" 0 39915) ("OrderedCancellationAbelianMonoid" 0 39901) ("OrderedAbelianMonoidSup" 0 37888) ("OrderedAbelianMonoid" 0 37527) ("OpenMath" 0 37445) ("OneDimensionalArrayAggregate" 0 37292) ("OneDimensionalArray" 0 37268) ("OctonionCategory" 0 37206) ("NumericalOptimizationCategory" 0 37085) ("NumericalIntegrationCategory" 0 36886) ("NonNegativeInteger" 0 35478) ("NonAssociativeRng" 0 35455) ("NonAssociativeRing" 0 35431) ("NonAssociativeAlgebra" 0 35336) ("NewSparseMultivariatePolynomial" 0 35319) ("NeitherSparseOrDensePowerSeries" 0 35188) ("MyUnivariatePolynomial" 0 35171) ("MultivariateTaylorSeriesCategory" 0 35121) ("MultisetAggregate" 0 35108) ("MultiDictionary" 0 35084) ("Monoid" 0 34880) ("MonogenicLinearOperator" 0 34811) ("MonogenicAlgebra" 0 34526) ("MonadWithUnit" 0 34507) ("Monad" 0 34496) ("Module" 0 34368) ("MatrixCategory" 0 34030) ("Matrix" 0 33908) ("MachineFloat" 0 33889) ("LyndonWord" 0 33837) ("Logic" 0 33800) ("LocalPowerSeriesCategory" 0 33466) ("ListAggregate" 0 33362) ("List" 0 32108) ("LinearlyExplicitRingOver" 0 31101) ("LinearOrdinaryDifferentialOperatorCategory" 0 30686) ("LinearAggregate" 0 30665) ("LieAlgebra" 0 30649) ("LeftModule" 0 30443) ("LeftAlgebra" 0 30399) ("LazyStreamAggregate" 0 30311) ("KeyedDictionary" 0 30290) ("Kernel" 0 30239) ("IntervalCategory" 0 30226) ("IntegralDomain" 0 28088) ("IntegerNumberSystem" 0 27826) ("Integer" 0 24782) ("InputForm" 0 24505) ("InnerPrimeField" 0 24484) ("InnerEvalable" 0 24465) ("InfinitlyClosePointCategory" 0 24278) ("IndexedVector" 0 24260) ("IndexedOneDimensionalArray" 0 24229) ("IndexedExponents" 0 23966) ("IndexedDirectProductCategory" 0 23743) ("IndexedAggregate" 0 23707) ("HyperbolicFunctionCategory" 0 23675) ("HomogeneousDirectProduct" 0 23626) ("HomogeneousAggregate" 0 23575) ("Group" 0 23464) ("GradedModule" 0 23428) ("GradedAlgebra" 0 23391) ("GcdDomain" 0 21905) ("FunctionSpace" 0 20672) ("FunctionFieldCategory" 0 20260) ("FullyRetractableTo" 0 20139) ("FullyLinearlyExplicitRingOver" 0 20104) ("FullyEvalableOver" 0 20070) ("FreeModuleCat" 0 19978) ("FreeLieAlgebra" 0 19960) ("FreeAbelianMonoidCategory" 0 19894) ("FramedNonAssociativeAlgebra" 0 19719) ("FramedAlgebra" 0 19529) ("Fraction" 0 18150) ("FortranVectorFunctionCategory" 0 18054) ("FortranVectorCategory" 0 18045) ("FortranScalarType" 0 18026) ("FortranProgramCategory" 0 17960) ("FortranMatrixFunctionCategory" 0 17926) ("FortranMatrixCategory" 0 17892) ("FortranMachineTypeCategory" 0 17821) ("FortranFunctionCategory" 0 17782) ("FloatingPointSystem" 0 17627) ("Float" 0 17505) ("FiniteSetAggregate" 0 17427) ("FiniteRankNonAssociativeAlgebra" 0 17390) ("FiniteRankAlgebra" 0 17367) ("FiniteLinearAggregate" 0 16850) ("FiniteFieldCategory" 0 15714) ("FiniteDivisorCategory" 0 15642) ("FiniteAlgebraicExtensionField" 0 15227) ("FiniteAbelianMonoidRing" 0 14958) ("Finite" 0 14789) ("FileNameCategory" 0 14776) ("FileName" 0 14707) ("FileCategory" 0 14638) ("FieldOfPrimeCharacteristic" 0 14574) ("Field" 0 11485) ("ExtensionField" 0 11427) ("ExtensibleLinearAggregate" 0 11357) ("ExpressionSpace" 0 11194) ("Expression" 0 11176) ("ExponentialOfUnivariatePuiseuxSeries" 0 11122) ("Evalable" 0 11108) ("EuclideanDomain" 0 9950) ("Equation" 0 9934) ("EltableAggregate" 0 9912) ("Eltable" 0 9789) ("ElementaryFunctionCategory" 0 9721) ("DoubleFloatVector" 0 9699) ("DoubleFloat" 0 9531) ("DivisorCategory" 0 9350) ("Divisor" 0 9276) ("DivisionRing" 0 9258) ("DistributedMultivariatePolynomial" 0 9184) ("DirectProductCategory" 0 8366) ("DirectProduct" 0 8175) ("DifferentialVariableCategory" 0 7968) ("DifferentialRing" 0 7780) ("DifferentialPolynomialCategory" 0 7634) ("DifferentialExtension" 0 7576) ("DictionaryOperations" 0 7550) ("Dictionary" 0 7534) ("DesingTreeCategory" 0 7428) ("DequeueAggregate" 0 7416) ("ConvertibleTo" 0 6595) ("ComplexDoubleFloatVector" 0 6566) ("ComplexCategory" 0 6433) ("Complex" 0 6194) ("CommutativeRing" 0 4843) ("CombinatorialOpsCategory" 0 4778) ("Collection" 0 4762) ("CoercibleTo" 0 4430) ("CharacteristicZero" 0 3086) ("Character" 0 3067) ("CancellationAbelianMonoid" 0 3012) ("CachableSet" 0 2969) ("Boolean" 0 2881) ("BlowUpMethodCategory" 0 2512) ("BitAggregate" 0 2473) ("BinaryTreeCategory" 0 2377) ("BinaryRecursiveAggregate" 0 2333) ("BiModule" 0 2291) ("BasicType" 0 2276) ("BasicOperator" 0 2246) ("BalancedPAdicInteger" 0 2220) ("BagAggregate" 0 2202) ("Automorphism" 0 2140) ("AssociationListAggregate" 0 2120) ("ArcTrigonometricFunctionCategory" 0 2082) ("Any" 0 2045) ("AlgebraicallyClosedFunctionSpace" 0 1680) ("AlgebraicallyClosedField" 0 1017) ("AlgebraicNumber" 0 983) ("Algebra" 0 596) ("Aggregate" 0 549) ("AffineSpaceCategory" 0 466) ("AbelianSemiGroup" 0 399) ("AbelianMonoidRing" 0 349) ("AbelianMonoid" 0 124) ("AbelianGroup" 0 20))
\ No newline at end of file
+(("XPolynomialsCat" 0 77251) ("XAlgebra" 0 77231) ("VectorSpace" 0 77196) ("VectorCategory" 0 77104) ("Vector" 0 76916) ("UnivariateTaylorSeriesCategory" 0 76322) ("UnivariateTaylorSeries" 0 76268) ("UnivariateSkewPolynomialCategory" 0 76100) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 76075) ("UnivariatePuiseuxSeriesConstructorCategory" 0 75887) ("UnivariatePuiseuxSeriesCategory" 0 75815) ("UnivariatePuiseuxSeries" 0 75738) ("UnivariatePowerSeriesCategory" 0 75629) ("UnivariatePolynomialCategory" 0 72569) ("UnivariateLaurentSeriesConstructorCategory" 0 72381) ("UnivariateLaurentSeriesCategory" 0 72206) ("UnivariateLaurentSeries" 0 72178) ("UniqueFactorizationDomain" 0 72022) ("UnaryRecursiveAggregate" 0 71993) ("U8Vector" 0 71980) ("U32Vector" 0 71966) ("U16Vector" 0 71952) ("Type" 0 69542) ("TwoDimensionalArrayCategory" 0 69424) ("TrigonometricFunctionCategory" 0 69389) ("TriangularSetCategory" 0 69314) ("TranscendentalFunctionCategory" 0 68160) ("ThreeSpaceCategory" 0 68145) ("TableAggregate" 0 67980) ("SymbolTable" 0 67961) ("Symbol" 0 65536) ("StringCategory" 0 65525) ("StringAggregate" 0 65488) ("String" 0 65342) ("StreamAggregate" 0 65294) ("StepThrough" 0 65279) ("StackAggregate" 0 65256) ("SquareMatrixCategory" 0 65169) ("SquareMatrix" 0 65100) ("SquareFreeRegularTriangularSetCategory" 0 64946) ("SplittingNode" 0 64928) ("SpecialFunctionCategory" 0 64886) ("SparseUnivariateTaylorSeries" 0 64820) ("SparseUnivariatePolynomialExpressions" 0 64786) ("SparseUnivariatePolynomial" 0 64620) ("SparseUnivariateLaurentSeries" 0 64586) ("SparseMultivariatePolynomial" 0 64440) ("SingleInteger" 0 64379) ("SetCategoryWithDegree" 0 64367) ("SetCategory" 0 61268) ("SetAggregate" 0 61250) ("SequentialDifferentialVariable" 0 61213) ("SemiGroup" 0 61198) ("SegmentCategory" 0 61167) ("SExpressionCategory" 0 61123) ("SExpression" 0 61109) ("Rng" 0 61055) ("Ring" 0 56568) ("RetractableTo" 0 54265) ("RegularTriangularSetCategory" 0 53977) ("RecursivePolynomialCategory" 0 53162) ("RecursiveAggregate" 0 53115) ("RectangularMatrixCategory" 0 53026) ("RealRootCharacterizationCategory" 0 52948) ("RealNumberSystem" 0 52926) ("RealConstant" 0 52834) ("RealClosedField" 0 52799) ("RadicalCategory" 0 52681) ("QuotientFieldCategory" 0 52198) ("QueueAggregate" 0 52188) ("QuaternionCategory" 0 52120) ("Quaternion" 0 52107) ("QuadraticForm" 0 52087) ("PseudoAlgebraicClosureOfRationalNumberCategory" 0 51986) ("PseudoAlgebraicClosureOfRationalNumber" 0 51935) ("PseudoAlgebraicClosureOfFiniteFieldCategory" 0 51895) ("PseudoAlgebraicClosureOfFiniteField" 0 51674) ("PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory" 0 51557) ("ProjectiveSpaceCategory" 0 51079) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 51016) ("ProjectivePlane" 0 51003) ("PriorityQueueAggregate" 0 50994) ("PrimitiveFunctionCategory" 0 50756) ("PrimitiveArray" 0 50746) ("PrimeField" 0 50680) ("PowerSeriesCategory" 0 50655) ("PositiveInteger" 0 50185) ("PolynomialSetCategory" 0 50135) ("PolynomialFactorizationExplicit" 0 49946) ("PolynomialCategory" 0 48389) ("Polynomial" 0 48222) ("PointCategory" 0 48212) ("PoincareBirkhoffWittLyndonBasis" 0 48193) ("PlottableSpaceCurveCategory" 0 48153) ("PlottablePlaneCurveCategory" 0 48118) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 48055) ("PlacesCategory" 0 47752) ("Places" 0 47739) ("PermutationCategory" 0 47723) ("Patternable" 0 47712) ("PatternMatchable" 0 47458) ("Pattern" 0 47218) ("Partition" 0 47194) ("PartialTranscendentalFunctions" 0 47063) ("PartialDifferentialRing" 0 46910) ("PartialDifferentialEquationsSolverCategory" 0 46874) ("PAdicIntegerCategory" 0 46787) ("PAdicInteger" 0 46769) ("OutputForm" 0 46629) ("OrdinaryDifferentialEquationsSolverCategory" 0 46559) ("OrderlyDifferentialVariable" 0 46525) ("OrderedVariableList" 0 45976) ("OrderedSet" 0 40809) ("OrderedRing" 0 40333) ("OrderedMonoid" 0 40293) ("OrderedIntegralDomain" 0 40269) ("OrderedFreeMonoid" 0 40242) ("OrderedFinite" 0 40206) ("OrderedCancellationAbelianMonoid" 0 40192) ("OrderedAbelianMonoidSup" 0 38179) ("OrderedAbelianMonoid" 0 37818) ("OpenMath" 0 37736) ("OneDimensionalArrayAggregate" 0 37560) ("OneDimensionalArray" 0 37536) ("OctonionCategory" 0 37474) ("NumericalOptimizationCategory" 0 37353) ("NumericalIntegrationCategory" 0 37154) ("NonNegativeInteger" 0 35746) ("NonAssociativeRng" 0 35723) ("NonAssociativeRing" 0 35699) ("NonAssociativeAlgebra" 0 35604) ("NewSparseMultivariatePolynomial" 0 35587) ("NeitherSparseOrDensePowerSeries" 0 35456) ("MyUnivariatePolynomial" 0 35439) ("MultivariateTaylorSeriesCategory" 0 35389) ("MultisetAggregate" 0 35376) ("MultiDictionary" 0 35352) ("Monoid" 0 35148) ("MonogenicLinearOperator" 0 35079) ("MonogenicAlgebra" 0 34794) ("MonadWithUnit" 0 34775) ("Monad" 0 34764) ("Module" 0 34611) ("MatrixCategory" 0 34217) ("Matrix" 0 34095) ("MachineFloat" 0 34076) ("LyndonWord" 0 34024) ("Logic" 0 33987) ("LocalPowerSeriesCategory" 0 33653) ("ListAggregate" 0 33549) ("List" 0 32295) ("LinearlyExplicitRingOver" 0 31288) ("LinearOrdinaryDifferentialOperatorCategory" 0 30873) ("LinearAggregate" 0 30852) ("LieAlgebra" 0 30836) ("LeftModule" 0 30630) ("LeftAlgebra" 0 30586) ("LazyStreamAggregate" 0 30498) ("KeyedDictionary" 0 30477) ("Kernel" 0 30426) ("IntervalCategory" 0 30413) ("IntegralDomain" 0 28250) ("IntegerNumberSystem" 0 27988) ("Integer" 0 24886) ("InputForm" 0 24609) ("InnerPrimeField" 0 24588) ("InnerEvalable" 0 24569) ("InfinitlyClosePointCategory" 0 24382) ("IndexedVector" 0 24364) ("IndexedOneDimensionalArray" 0 24333) ("IndexedExponents" 0 24070) ("IndexedDirectProductCategory" 0 23847) ("IndexedAggregate" 0 23811) ("HyperbolicFunctionCategory" 0 23779) ("HomogeneousDirectProduct" 0 23730) ("HomogeneousAggregate" 0 23679) ("Group" 0 23568) ("GradedModule" 0 23532) ("GradedAlgebra" 0 23495) ("GcdDomain" 0 22009) ("FunctionSpace" 0 20776) ("FunctionFieldCategory" 0 20364) ("FullyRetractableTo" 0 20243) ("FullyLinearlyExplicitRingOver" 0 20208) ("FullyEvalableOver" 0 20174) ("FreeModuleCat" 0 20082) ("FreeLieAlgebra" 0 20064) ("FreeAbelianMonoidCategory" 0 19998) ("FramedNonAssociativeAlgebra" 0 19823) ("FramedAlgebra" 0 19633) ("Fraction" 0 18254) ("FortranVectorFunctionCategory" 0 18158) ("FortranVectorCategory" 0 18149) ("FortranScalarType" 0 18130) ("FortranProgramCategory" 0 18064) ("FortranMatrixFunctionCategory" 0 18030) ("FortranMatrixCategory" 0 17996) ("FortranMachineTypeCategory" 0 17925) ("FortranFunctionCategory" 0 17886) ("FloatingPointSystem" 0 17731) ("Float" 0 17609) ("FiniteSetAggregate" 0 17531) ("FiniteRankNonAssociativeAlgebra" 0 17494) ("FiniteRankAlgebra" 0 17471) ("FiniteLinearAggregate" 0 16933) ("FiniteFieldCategory" 0 15770) ("FiniteDivisorCategory" 0 15698) ("FiniteAlgebraicExtensionField" 0 15283) ("FiniteAbelianMonoidRing" 0 15014) ("Finite" 0 14835) ("FileNameCategory" 0 14822) ("FileName" 0 14753) ("FileCategory" 0 14684) ("FieldOfPrimeCharacteristic" 0 14620) ("Field" 0 11510) ("ExtensionField" 0 11452) ("ExtensibleLinearAggregate" 0 11382) ("ExpressionSpace" 0 11219) ("Expression" 0 11176) ("ExponentialOfUnivariatePuiseuxSeries" 0 11122) ("Evalable" 0 11108) ("EuclideanDomain" 0 9950) ("Equation" 0 9934) ("EltableAggregate" 0 9912) ("Eltable" 0 9789) ("ElementaryFunctionCategory" 0 9721) ("DoubleFloatVector" 0 9699) ("DoubleFloat" 0 9531) ("DivisorCategory" 0 9350) ("Divisor" 0 9276) ("DivisionRing" 0 9258) ("DistributedMultivariatePolynomial" 0 9184) ("DirectProductCategory" 0 8366) ("DirectProduct" 0 8175) ("DifferentialVariableCategory" 0 7968) ("DifferentialRing" 0 7780) ("DifferentialPolynomialCategory" 0 7634) ("DifferentialExtension" 0 7576) ("DictionaryOperations" 0 7550) ("Dictionary" 0 7534) ("DesingTreeCategory" 0 7428) ("DequeueAggregate" 0 7416) ("ConvertibleTo" 0 6595) ("ComplexDoubleFloatVector" 0 6566) ("ComplexCategory" 0 6433) ("Complex" 0 6194) ("CommutativeRing" 0 4843) ("CombinatorialOpsCategory" 0 4778) ("Collection" 0 4762) ("CoercibleTo" 0 4430) ("CharacteristicZero" 0 3086) ("Character" 0 3067) ("CancellationAbelianMonoid" 0 3012) ("CachableSet" 0 2969) ("Boolean" 0 2881) ("BlowUpMethodCategory" 0 2512) ("BitAggregate" 0 2473) ("BinaryTreeCategory" 0 2377) ("BinaryRecursiveAggregate" 0 2333) ("BiModule" 0 2291) ("BasicType" 0 2276) ("BasicOperator" 0 2246) ("BalancedPAdicInteger" 0 2220) ("BagAggregate" 0 2202) ("Automorphism" 0 2140) ("AssociationListAggregate" 0 2120) ("ArcTrigonometricFunctionCategory" 0 2082) ("Any" 0 2045) ("AlgebraicallyClosedFunctionSpace" 0 1680) ("AlgebraicallyClosedField" 0 1017) ("AlgebraicNumber" 0 983) ("Algebra" 0 596) ("Aggregate" 0 549) ("AffineSpaceCategory" 0 466) ("AbelianSemiGroup" 0 399) ("AbelianMonoidRing" 0 349) ("AbelianMonoid" 0 124) ("AbelianGroup" 0 20))
\ No newline at end of file
diff --git a/src/share/algebra/interp.daase b/src/share/algebra/interp.daase
index 2e5ca61..1678315 100644
--- a/src/share/algebra/interp.daase
+++ b/src/share/algebra/interp.daase
@@ -1,5289 +1,5374 @@
 
-(3635150 . 3575754991)       
-((-2041 (((-121) (-1 (-121) |#2| |#2|) $) 62) (((-121) $) NIL)) (-4131 (($ (-1 (-121) |#2| |#2|) $) 17) (($ $) NIL)) (-3283 ((|#2| $ (-572) |#2|) NIL) ((|#2| $ (-1225 (-572)) |#2|) 34)) (-2985 (($ $) 58)) (-3116 ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 40) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 38) ((|#2| (-1 |#2| |#2| |#2|) $) 37)) (-4014 (((-572) (-1 (-121) |#2|) $) 22) (((-572) |#2| $) NIL) (((-572) |#2| $ (-572)) 70)) (-2010 (((-638 |#2|) $) 13)) (-4475 (($ (-1 (-121) |#2| |#2|) $ $) 47) (($ $ $) NIL)) (-2435 (($ (-1 |#2| |#2|) $) 29)) (-3828 (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) 44)) (-2603 (($ |#2| $ (-572)) NIL) (($ $ $ (-572)) 49)) (-3361 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 24)) (-2109 (((-121) (-1 (-121) |#2|) $) 21)) (-3277 ((|#2| $ (-572) |#2|) NIL) ((|#2| $ (-572)) NIL) (($ $ (-1225 (-572))) 48)) (-1940 (($ $ (-572)) 55) (($ $ (-1225 (-572))) 54)) (-1571 (((-769) (-1 (-121) |#2|) $) 26) (((-769) |#2| $) NIL)) (-2907 (($ $ $ (-572)) 51)) (-1607 (($ $) 50)) (-3921 (($ (-638 |#2|)) 52)) (-4500 (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ $ $) 63) (($ (-638 $)) 61)) (-3972 (((-856) $) 69)) (-3501 (((-121) (-1 (-121) |#2|) $) 20)) (-1324 (((-121) $ $) 64)) (-1334 (((-121) $ $) 72))) 
-(((-18 |#1| |#2|) (-10 -8 (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -4131 (|#1| |#1|)) (-15 -4131 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -2985 (|#1| |#1|)) (-15 -2907 (|#1| |#1| |#1| (-572))) (-15 -2041 ((-121) |#1|)) (-15 -4475 (|#1| |#1| |#1|)) (-15 -4014 ((-572) |#2| |#1| (-572))) (-15 -4014 ((-572) |#2| |#1|)) (-15 -4014 ((-572) (-1 (-121) |#2|) |#1|)) (-15 -2041 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -4475 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -3283 (|#2| |#1| (-1225 (-572)) |#2|)) (-15 -2603 (|#1| |#1| |#1| (-572))) (-15 -2603 (|#1| |#2| |#1| (-572))) (-15 -1940 (|#1| |#1| (-1225 (-572)))) (-15 -1940 (|#1| |#1| (-572))) (-15 -3277 (|#1| |#1| (-1225 (-572)))) (-15 -3828 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -4500 (|#1| (-638 |#1|))) (-15 -4500 (|#1| |#1| |#1|)) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#2|)) (-15 -3921 (|#1| (-638 |#2|))) (-15 -3361 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3277 (|#2| |#1| (-572))) (-15 -3277 (|#2| |#1| (-572) |#2|)) (-15 -3283 (|#2| |#1| (-572) |#2|)) (-15 -1571 ((-769) |#2| |#1|)) (-15 -2010 ((-638 |#2|) |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -2435 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1607 (|#1| |#1|))) (-19 |#2|) (-1204)) (T -18)) 
-NIL 
-(-10 -8 (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -4131 (|#1| |#1|)) (-15 -4131 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -2985 (|#1| |#1|)) (-15 -2907 (|#1| |#1| |#1| (-572))) (-15 -2041 ((-121) |#1|)) (-15 -4475 (|#1| |#1| |#1|)) (-15 -4014 ((-572) |#2| |#1| (-572))) (-15 -4014 ((-572) |#2| |#1|)) (-15 -4014 ((-572) (-1 (-121) |#2|) |#1|)) (-15 -2041 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -4475 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -3283 (|#2| |#1| (-1225 (-572)) |#2|)) (-15 -2603 (|#1| |#1| |#1| (-572))) (-15 -2603 (|#1| |#2| |#1| (-572))) (-15 -1940 (|#1| |#1| (-1225 (-572)))) (-15 -1940 (|#1| |#1| (-572))) (-15 -3277 (|#1| |#1| (-1225 (-572)))) (-15 -3828 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -4500 (|#1| (-638 |#1|))) (-15 -4500 (|#1| |#1| |#1|)) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#2|)) (-15 -3921 (|#1| (-638 |#2|))) (-15 -3361 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3277 (|#2| |#1| (-572))) (-15 -3277 (|#2| |#1| (-572) |#2|)) (-15 -3283 (|#2| |#1| (-572) |#2|)) (-15 -1571 ((-769) |#2| |#1|)) (-15 -2010 ((-638 |#2|) |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -2435 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1607 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4603))) (($ $) 81 (-12 (|has| |#1| (-848)) (|has| $ (-6 -4603))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#1| $ (-572) |#1|) 49 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 53 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-2985 (($ $) 83 (|has| $ (-6 -4603)))) (-1656 (($ $) 93)) (-1643 (($ $) 73 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#1| $) 72 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) 50 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 48)) (-4014 (((-572) (-1 (-121) |#1|) $) 90) (((-572) |#1| $) 89 (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) 88 (|has| |#1| (-1098)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-1364 (($ (-769) |#1|) 64)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-1771 (($ $ $) 80 (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-4238 (($ $ $) 79 (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) 55) (($ $ $ (-572)) 54)) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 39 (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3299 (($ $ |#1|) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ (-572) |#1|) 47) ((|#1| $ (-572)) 46) (($ $ (-1225 (-572))) 58)) (-1940 (($ $ (-572)) 57) (($ $ (-1225 (-572))) 56)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2907 (($ $ $ (-572)) 84 (|has| $ (-6 -4603)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 74 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 65)) (-4500 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-638 $)) 60)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) 77 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 76 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-1343 (((-121) $ $) 78 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 75 (|has| |#1| (-848)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-19 |#1|) (-1290) (-1204)) (T -19)) 
-NIL 
-(-13 (-379 |t#1|) (-10 -7 (-6 -4603))) 
-(((-39) . T) ((-105) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-612 (-856)) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-379 |#1|) . T) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-644 |#1|) . T) ((-848) |has| |#1| (-848)) ((-1098) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-1204) . T)) 
-((-1572 (((-3 $ "failed") $ $) 12)) (-1373 (($ $) NIL) (($ $ $) 9)) (* (($ (-923) $) NIL) (($ (-769) $) 16) (($ (-572) $) 21))) 
-(((-20 |#1|) (-10 -8 (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 -1572 ((-3 |#1| "failed") |#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) (-21)) (T -20)) 
-NIL 
-(-10 -8 (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 -1572 ((-3 |#1| "failed") |#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19))) 
-(((-21) (-1290)) (T -21)) 
-((-1373 (*1 *1 *1) (-4 *1 (-21))) (-1373 (*1 *1 *1 *1) (-4 *1 (-21))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-21)) (-5 *2 (-572))))) 
-(-13 (-138) (-10 -8 (-15 -1373 ($ $)) (-15 -1373 ($ $ $)) (-15 * ($ (-572) $)))) 
-(((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-1342 (((-121) $) 10)) (-2211 (($) 15)) (* (($ (-923) $) 14) (($ (-769) $) 18))) 
-(((-22 |#1|) (-10 -8 (-15 * (|#1| (-769) |#1|)) (-15 -1342 ((-121) |#1|)) (-15 -2211 (|#1|)) (-15 * (|#1| (-923) |#1|))) (-23)) (T -22)) 
-NIL 
-(-10 -8 (-15 * (|#1| (-769) |#1|)) (-15 -1342 ((-121) |#1|)) (-15 -2211 (|#1|)) (-15 * (|#1| (-923) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14))) 
-(((-23) (-1290)) (T -23)) 
-((-2378 (*1 *1) (-4 *1 (-23))) (-2211 (*1 *1) (-4 *1 (-23))) (-1342 (*1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-121)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-769))))) 
-(-13 (-25) (-10 -8 (-15 (-2378) ($) -3211) (-15 -2211 ($) -3211) (-15 -1342 ((-121) $)) (-15 * ($ (-769) $)))) 
-(((-25) . T) ((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((* (($ (-923) $) 10))) 
-(((-24 |#1|) (-10 -8 (-15 * (|#1| (-923) |#1|))) (-25)) (T -24)) 
-NIL 
-(-10 -8 (-15 * (|#1| (-923) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12))) 
-(((-25) (-1290)) (T -25)) 
-((-1367 (*1 *1 *1 *1) (-4 *1 (-25))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-25)) (-5 *2 (-923))))) 
-(-13 (-1098) (-10 -8 (-15 -1367 ($ $ $)) (-15 * ($ (-923) $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-1770 (((-638 $) (-959 $)) 29) (((-638 $) (-1166 $)) 16) (((-638 $) (-1166 $) (-1170)) 20)) (-1627 (($ (-959 $)) 27) (($ (-1166 $)) 11) (($ (-1166 $) (-1170)) 54)) (-3584 (((-638 $) (-959 $)) 30) (((-638 $) (-1166 $)) 18) (((-638 $) (-1166 $) (-1170)) 19)) (-3733 (($ (-959 $)) 28) (($ (-1166 $)) 13) (($ (-1166 $) (-1170)) NIL))) 
-(((-26 |#1|) (-10 -8 (-15 -1770 ((-638 |#1|) (-1166 |#1|) (-1170))) (-15 -1770 ((-638 |#1|) (-1166 |#1|))) (-15 -1770 ((-638 |#1|) (-959 |#1|))) (-15 -1627 (|#1| (-1166 |#1|) (-1170))) (-15 -1627 (|#1| (-1166 |#1|))) (-15 -1627 (|#1| (-959 |#1|))) (-15 -3584 ((-638 |#1|) (-1166 |#1|) (-1170))) (-15 -3584 ((-638 |#1|) (-1166 |#1|))) (-15 -3584 ((-638 |#1|) (-959 |#1|))) (-15 -3733 (|#1| (-1166 |#1|) (-1170))) (-15 -3733 (|#1| (-1166 |#1|))) (-15 -3733 (|#1| (-959 |#1|)))) (-27)) (T -26)) 
-NIL 
-(-10 -8 (-15 -1770 ((-638 |#1|) (-1166 |#1|) (-1170))) (-15 -1770 ((-638 |#1|) (-1166 |#1|))) (-15 -1770 ((-638 |#1|) (-959 |#1|))) (-15 -1627 (|#1| (-1166 |#1|) (-1170))) (-15 -1627 (|#1| (-1166 |#1|))) (-15 -1627 (|#1| (-959 |#1|))) (-15 -3584 ((-638 |#1|) (-1166 |#1|) (-1170))) (-15 -3584 ((-638 |#1|) (-1166 |#1|))) (-15 -3584 ((-638 |#1|) (-959 |#1|))) (-15 -3733 (|#1| (-1166 |#1|) (-1170))) (-15 -3733 (|#1| (-1166 |#1|))) (-15 -3733 (|#1| (-959 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1770 (((-638 $) (-959 $)) 76) (((-638 $) (-1166 $)) 75) (((-638 $) (-1166 $) (-1170)) 74)) (-1627 (($ (-959 $)) 79) (($ (-1166 $)) 78) (($ (-1166 $) (-1170)) 77)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-4190 (($ $) 88)) (-3112 (((-121) $ $) 57)) (-2211 (($) 16 T CONST)) (-3584 (((-638 $) (-959 $)) 82) (((-638 $) (-1166 $)) 81) (((-638 $) (-1166 $) (-1170)) 80)) (-3733 (($ (-959 $)) 85) (($ (-1166 $)) 84) (($ (-1166 $) (-1170)) 83)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-1526 (((-121) $) 69)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 87)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66) (($ $ (-413 (-572))) 86)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64))) 
-(((-27) (-1290)) (T -27)) 
-((-3733 (*1 *1 *2) (-12 (-5 *2 (-959 *1)) (-4 *1 (-27)))) (-3733 (*1 *1 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-27)))) (-3733 (*1 *1 *2 *3) (-12 (-5 *2 (-1166 *1)) (-5 *3 (-1170)) (-4 *1 (-27)))) (-3584 (*1 *2 *3) (-12 (-5 *3 (-959 *1)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) (-3584 (*1 *2 *3) (-12 (-5 *3 (-1166 *1)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) (-3584 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 *1)) (-5 *4 (-1170)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) (-1627 (*1 *1 *2) (-12 (-5 *2 (-959 *1)) (-4 *1 (-27)))) (-1627 (*1 *1 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-27)))) (-1627 (*1 *1 *2 *3) (-12 (-5 *2 (-1166 *1)) (-5 *3 (-1170)) (-4 *1 (-27)))) (-1770 (*1 *2 *3) (-12 (-5 *3 (-959 *1)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) (-1770 (*1 *2 *3) (-12 (-5 *3 (-1166 *1)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) (-1770 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 *1)) (-5 *4 (-1170)) (-4 *1 (-27)) (-5 *2 (-638 *1))))) 
-(-13 (-368) (-1009) (-10 -8 (-15 -3733 ($ (-959 $))) (-15 -3733 ($ (-1166 $))) (-15 -3733 ($ (-1166 $) (-1170))) (-15 -3584 ((-638 $) (-959 $))) (-15 -3584 ((-638 $) (-1166 $))) (-15 -3584 ((-638 $) (-1166 $) (-1170))) (-15 -1627 ($ (-959 $))) (-15 -1627 ($ (-1166 $))) (-15 -1627 ($ (-1166 $) (-1170))) (-15 -1770 ((-638 $) (-959 $))) (-15 -1770 ((-638 $) (-1166 $))) (-15 -1770 ((-638 $) (-1166 $) (-1170))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1009) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T)) 
-((-1770 (((-638 $) (-959 $)) NIL) (((-638 $) (-1166 $)) NIL) (((-638 $) (-1166 $) (-1170)) 50) (((-638 $) $) 19) (((-638 $) $ (-1170)) 41)) (-1627 (($ (-959 $)) NIL) (($ (-1166 $)) NIL) (($ (-1166 $) (-1170)) 52) (($ $) 17) (($ $ (-1170)) 37)) (-3584 (((-638 $) (-959 $)) NIL) (((-638 $) (-1166 $)) NIL) (((-638 $) (-1166 $) (-1170)) 48) (((-638 $) $) 15) (((-638 $) $ (-1170)) 43)) (-3733 (($ (-959 $)) NIL) (($ (-1166 $)) NIL) (($ (-1166 $) (-1170)) NIL) (($ $) 12) (($ $ (-1170)) 39))) 
-(((-28 |#1| |#2|) (-10 -8 (-15 -1770 ((-638 |#1|) |#1| (-1170))) (-15 -1627 (|#1| |#1| (-1170))) (-15 -1770 ((-638 |#1|) |#1|)) (-15 -1627 (|#1| |#1|)) (-15 -3584 ((-638 |#1|) |#1| (-1170))) (-15 -3733 (|#1| |#1| (-1170))) (-15 -3584 ((-638 |#1|) |#1|)) (-15 -3733 (|#1| |#1|)) (-15 -1770 ((-638 |#1|) (-1166 |#1|) (-1170))) (-15 -1770 ((-638 |#1|) (-1166 |#1|))) (-15 -1770 ((-638 |#1|) (-959 |#1|))) (-15 -1627 (|#1| (-1166 |#1|) (-1170))) (-15 -1627 (|#1| (-1166 |#1|))) (-15 -1627 (|#1| (-959 |#1|))) (-15 -3584 ((-638 |#1|) (-1166 |#1|) (-1170))) (-15 -3584 ((-638 |#1|) (-1166 |#1|))) (-15 -3584 ((-638 |#1|) (-959 |#1|))) (-15 -3733 (|#1| (-1166 |#1|) (-1170))) (-15 -3733 (|#1| (-1166 |#1|))) (-15 -3733 (|#1| (-959 |#1|)))) (-29 |#2|) (-13 (-848) (-562))) (T -28)) 
-NIL 
-(-10 -8 (-15 -1770 ((-638 |#1|) |#1| (-1170))) (-15 -1627 (|#1| |#1| (-1170))) (-15 -1770 ((-638 |#1|) |#1|)) (-15 -1627 (|#1| |#1|)) (-15 -3584 ((-638 |#1|) |#1| (-1170))) (-15 -3733 (|#1| |#1| (-1170))) (-15 -3584 ((-638 |#1|) |#1|)) (-15 -3733 (|#1| |#1|)) (-15 -1770 ((-638 |#1|) (-1166 |#1|) (-1170))) (-15 -1770 ((-638 |#1|) (-1166 |#1|))) (-15 -1770 ((-638 |#1|) (-959 |#1|))) (-15 -1627 (|#1| (-1166 |#1|) (-1170))) (-15 -1627 (|#1| (-1166 |#1|))) (-15 -1627 (|#1| (-959 |#1|))) (-15 -3584 ((-638 |#1|) (-1166 |#1|) (-1170))) (-15 -3584 ((-638 |#1|) (-1166 |#1|))) (-15 -3584 ((-638 |#1|) (-959 |#1|))) (-15 -3733 (|#1| (-1166 |#1|) (-1170))) (-15 -3733 (|#1| (-1166 |#1|))) (-15 -3733 (|#1| (-959 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1770 (((-638 $) (-959 $)) 76) (((-638 $) (-1166 $)) 75) (((-638 $) (-1166 $) (-1170)) 74) (((-638 $) $) 120) (((-638 $) $ (-1170)) 118)) (-1627 (($ (-959 $)) 79) (($ (-1166 $)) 78) (($ (-1166 $) (-1170)) 77) (($ $) 121) (($ $ (-1170)) 119)) (-1342 (((-121) $) 15)) (-3456 (((-638 (-1170)) $) 195)) (-4297 (((-413 (-1166 $)) $ (-611 $)) 227 (|has| |#1| (-562)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1337 (((-638 (-611 $)) $) 158)) (-1572 (((-3 $ "failed") $ $) 18)) (-1952 (($ $ (-638 (-611 $)) (-638 $)) 148) (($ $ (-638 (-290 $))) 147) (($ $ (-290 $)) 146)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-4190 (($ $) 88)) (-3112 (((-121) $ $) 57)) (-2211 (($) 16 T CONST)) (-3584 (((-638 $) (-959 $)) 82) (((-638 $) (-1166 $)) 81) (((-638 $) (-1166 $) (-1170)) 80) (((-638 $) $) 124) (((-638 $) $ (-1170)) 122)) (-3733 (($ (-959 $)) 85) (($ (-1166 $)) 84) (($ (-1166 $) (-1170)) 83) (($ $) 125) (($ $ (-1170)) 123)) (-3376 (((-3 (-959 |#1|) "failed") $) 245 (|has| |#1| (-1054))) (((-3 (-413 (-959 |#1|)) "failed") $) 229 (|has| |#1| (-562))) (((-3 |#1| "failed") $) 191) (((-3 (-572) "failed") $) 189 (|has| |#1| (-1044 (-572)))) (((-3 (-1170) "failed") $) 182) (((-3 (-611 $) "failed") $) 133) (((-3 (-413 (-572)) "failed") $) 117 (-1841 (-12 (|has| |#1| (-1044 (-572))) (|has| |#1| (-562))) (|has| |#1| (-1044 (-413 (-572))))))) (-1318 (((-959 |#1|) $) 246 (|has| |#1| (-1054))) (((-413 (-959 |#1|)) $) 230 (|has| |#1| (-562))) ((|#1| $) 192) (((-572) $) 188 (|has| |#1| (-1044 (-572)))) (((-1170) $) 183) (((-611 $) $) 134) (((-413 (-572)) $) 116 (-1841 (-12 (|has| |#1| (-1044 (-572))) (|has| |#1| (-562))) (|has| |#1| (-1044 (-413 (-572))))))) (-2190 (($ $ $) 53)) (-2284 (((-685 |#1|) (-685 $)) 235 (|has| |#1| (-1054))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 234 (|has| |#1| (-1054))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 115 (-1841 (-4028 (|has| |#1| (-1054)) (|has| |#1| (-634 (-572)))) (-4028 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))))) (((-685 (-572)) (-685 $)) 114 (-1841 (-4028 (|has| |#1| (-1054)) (|has| |#1| (-634 (-572)))) (-4028 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))))) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-1526 (((-121) $) 69)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 187 (|has| |#1| (-887 (-385)))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 186 (|has| |#1| (-887 (-572))))) (-3567 (($ (-638 $)) 152) (($ $) 151)) (-4091 (((-638 (-123)) $) 159)) (-4564 (((-123) (-123)) 160)) (-3893 (((-121) $) 30)) (-4240 (((-121) $) 180 (|has| $ (-1044 (-572))))) (-4347 (($ $) 212 (|has| |#1| (-1054)))) (-4487 (((-1121 |#1| (-611 $)) $) 211 (|has| |#1| (-1054)))) (-1451 (($ $ (-572)) 87)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-4127 (((-1166 $) (-611 $)) 177 (|has| $ (-1054)))) (-1771 (($ $ $) 131)) (-4238 (($ $ $) 130)) (-3828 (($ (-1 $ $) (-611 $)) 166)) (-3614 (((-3 (-611 $) "failed") $) 156)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4291 (((-638 (-611 $)) $) 157)) (-4496 (($ (-123) (-638 $)) 165) (($ (-123) $) 164)) (-1921 (((-3 (-638 $) "failed") $) 206 (|has| |#1| (-1110)))) (-2472 (((-3 (-2 (|:| |val| $) (|:| -3751 (-572))) "failed") $) 215 (|has| |#1| (-1054)))) (-2336 (((-3 (-638 $) "failed") $) 208 (|has| |#1| (-25)))) (-1595 (((-3 (-2 (|:| -4513 (-572)) (|:| |var| (-611 $))) "failed") $) 209 (|has| |#1| (-25)))) (-3019 (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-1170)) 214 (|has| |#1| (-1054))) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-123)) 213 (|has| |#1| (-1054))) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $) 207 (|has| |#1| (-1110)))) (-3291 (((-121) $ (-1170)) 163) (((-121) $ (-123)) 162)) (-4350 (($ $) 68)) (-1455 (((-769) $) 155)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 193)) (-4362 ((|#1| $) 194)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-4319 (((-121) $ (-1170)) 168) (((-121) $ $) 167)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4247 (((-121) $) 179 (|has| $ (-1044 (-572))))) (-4485 (($ $ (-1170) (-769) (-1 $ $)) 219 (|has| |#1| (-1054))) (($ $ (-1170) (-769) (-1 $ (-638 $))) 218 (|has| |#1| (-1054))) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ (-638 $)))) 217 (|has| |#1| (-1054))) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ $))) 216 (|has| |#1| (-1054))) (($ $ (-638 (-123)) (-638 $) (-1170)) 205 (|has| |#1| (-613 (-545)))) (($ $ (-123) $ (-1170)) 204 (|has| |#1| (-613 (-545)))) (($ $) 203 (|has| |#1| (-613 (-545)))) (($ $ (-638 (-1170))) 202 (|has| |#1| (-613 (-545)))) (($ $ (-1170)) 201 (|has| |#1| (-613 (-545)))) (($ $ (-123) (-1 $ $)) 176) (($ $ (-123) (-1 $ (-638 $))) 175) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) 174) (($ $ (-638 (-123)) (-638 (-1 $ $))) 173) (($ $ (-1170) (-1 $ $)) 172) (($ $ (-1170) (-1 $ (-638 $))) 171) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) 170) (($ $ (-638 (-1170)) (-638 (-1 $ $))) 169) (($ $ (-638 $) (-638 $)) 140) (($ $ $ $) 139) (($ $ (-290 $)) 138) (($ $ (-638 (-290 $))) 137) (($ $ (-638 (-611 $)) (-638 $)) 136) (($ $ (-611 $) $) 135)) (-4029 (((-769) $) 56)) (-3277 (($ (-123) (-638 $)) 145) (($ (-123) $ $ $ $) 144) (($ (-123) $ $ $) 143) (($ (-123) $ $) 142) (($ (-123) $) 141)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-2759 (($ $ $) 154) (($ $) 153)) (-3139 (($ $ (-1170)) 243 (|has| |#1| (-1054))) (($ $ (-638 (-1170))) 242 (|has| |#1| (-1054))) (($ $ (-1170) (-769)) 241 (|has| |#1| (-1054))) (($ $ (-638 (-1170)) (-638 (-769))) 240 (|has| |#1| (-1054)))) (-3425 (($ $) 222 (|has| |#1| (-562)))) (-4492 (((-1121 |#1| (-611 $)) $) 221 (|has| |#1| (-562)))) (-2830 (($ $) 178 (|has| $ (-1054)))) (-4081 (((-545) $) 249 (|has| |#1| (-613 (-545)))) (($ (-424 $)) 220 (|has| |#1| (-562))) (((-893 (-385)) $) 185 (|has| |#1| (-613 (-893 (-385))))) (((-893 (-572)) $) 184 (|has| |#1| (-613 (-893 (-572)))))) (-3018 (($ $ $) 248 (|has| |#1| (-482)))) (-4056 (($ $ $) 247 (|has| |#1| (-482)))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ (-959 |#1|)) 244 (|has| |#1| (-1054))) (($ (-413 (-959 |#1|))) 228 (|has| |#1| (-562))) (($ (-413 (-959 (-413 |#1|)))) 226 (|has| |#1| (-562))) (($ (-959 (-413 |#1|))) 225 (|has| |#1| (-562))) (($ (-413 |#1|)) 224 (|has| |#1| (-562))) (($ (-1121 |#1| (-611 $))) 210 (|has| |#1| (-1054))) (($ |#1|) 190) (($ (-1170)) 181) (($ (-611 $)) 132)) (-2779 (((-3 $ "failed") $) 233 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-3497 (($ (-638 $)) 150) (($ $) 149)) (-3228 (((-121) (-123)) 161)) (-3774 (((-121) $ $) 38)) (-2973 (($ (-1170) (-638 $)) 200) (($ (-1170) $ $ $ $) 199) (($ (-1170) $ $ $) 198) (($ (-1170) $ $) 197) (($ (-1170) $) 196)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-1170)) 239 (|has| |#1| (-1054))) (($ $ (-638 (-1170))) 238 (|has| |#1| (-1054))) (($ $ (-1170) (-769)) 237 (|has| |#1| (-1054))) (($ $ (-638 (-1170)) (-638 (-769))) 236 (|has| |#1| (-1054)))) (-1349 (((-121) $ $) 128)) (-1338 (((-121) $ $) 127)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 129)) (-1334 (((-121) $ $) 126)) (-1379 (($ $ $) 62) (($ (-1121 |#1| (-611 $)) (-1121 |#1| (-611 $))) 223 (|has| |#1| (-562)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66) (($ $ (-413 (-572))) 86)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64) (($ $ |#1|) 232 (|has| |#1| (-174))) (($ |#1| $) 231 (|has| |#1| (-174))))) 
-(((-29 |#1|) (-1290) (-13 (-848) (-562))) (T -29)) 
-((-3733 (*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-848) (-562))))) (-3584 (*1 *2 *1) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *2 (-638 *1)) (-4 *1 (-29 *3)))) (-3733 (*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-848) (-562))))) (-3584 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-638 *1)) (-4 *1 (-29 *4)))) (-1627 (*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-848) (-562))))) (-1770 (*1 *2 *1) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *2 (-638 *1)) (-4 *1 (-29 *3)))) (-1627 (*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-848) (-562))))) (-1770 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-638 *1)) (-4 *1 (-29 *4))))) 
-(-13 (-27) (-436 |t#1|) (-10 -8 (-15 -3733 ($ $)) (-15 -3584 ((-638 $) $)) (-15 -3733 ($ $ (-1170))) (-15 -3584 ((-638 $) $ (-1170))) (-15 -1627 ($ $)) (-15 -1770 ((-638 $) $)) (-15 -1627 ($ $ (-1170))) (-15 -1770 ((-638 $) $ (-1170))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) . T) ((-27) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 |#1| |#1|) |has| |#1| (-174)) ((-120 $ $) . T) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-613 (-893 (-385))) |has| |#1| (-613 (-893 (-385)))) ((-613 (-893 (-572))) |has| |#1| (-613 (-893 (-572)))) ((-240) . T) ((-287) . T) ((-303) . T) ((-305 $) . T) ((-298) . T) ((-368) . T) ((-383 |#1|) |has| |#1| (-1054)) ((-406 |#1|) . T) ((-417 |#1|) . T) ((-436 |#1|) . T) ((-457) . T) ((-482) |has| |#1| (-482)) ((-527 (-611 $) $) . T) ((-527 $ $) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 |#1|) |has| |#1| (-174)) ((-641 $) . T) ((-634 (-572)) -12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) ((-634 |#1|) |has| |#1| (-1054)) ((-713 (-413 (-572))) . T) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) . T) ((-722) . T) ((-848) . T) ((-901 (-1170)) |has| |#1| (-1054)) ((-887 (-385)) |has| |#1| (-887 (-385))) ((-887 (-572)) |has| |#1| (-887 (-572))) ((-885 |#1|) . T) ((-922) . T) ((-1009) . T) ((-1044 (-413 (-572))) -1841 (|has| |#1| (-1044 (-413 (-572)))) (-12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572))))) ((-1044 (-413 (-959 |#1|))) |has| |#1| (-562)) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 (-611 $)) . T) ((-1044 (-959 |#1|)) |has| |#1| (-1054)) ((-1044 (-1170)) . T) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) . T) ((-1060 |#1|) |has| |#1| (-174)) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1204) . T) ((-1214) . T)) 
-((-1497 (((-1092 (-217)) $) NIL)) (-2153 (((-1092 (-217)) $) NIL)) (-2436 (($ $ (-217)) 122)) (-2033 (($ (-959 (-572)) (-1170) (-1170) (-1092 (-413 (-572))) (-1092 (-413 (-572)))) 84)) (-3192 (((-638 (-638 (-950 (-217)))) $) 134)) (-3972 (((-856) $) 146))) 
-(((-30) (-13 (-962) (-10 -8 (-15 -2033 ($ (-959 (-572)) (-1170) (-1170) (-1092 (-413 (-572))) (-1092 (-413 (-572))))) (-15 -2436 ($ $ (-217)))))) (T -30)) 
-((-2033 (*1 *1 *2 *3 *3 *4 *4) (-12 (-5 *2 (-959 (-572))) (-5 *3 (-1170)) (-5 *4 (-1092 (-413 (-572)))) (-5 *1 (-30)))) (-2436 (*1 *1 *1 *2) (-12 (-5 *2 (-217)) (-5 *1 (-30))))) 
-(-13 (-962) (-10 -8 (-15 -2033 ($ (-959 (-572)) (-1170) (-1170) (-1092 (-413 (-572))) (-1092 (-413 (-572))))) (-15 -2436 ($ $ (-217))))) 
-((-3379 (((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3|) 38)) (-1659 (((-638 |#5|) |#3| (-923)) 33)) (-2034 (((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 |#3|)) 40))) 
-(((-31 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2034 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 |#3|))) (-15 -3379 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3|)) (-15 -1659 ((-638 |#5|) |#3| (-923)))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|)) (T -31)) 
-((-1659 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-5 *2 (-638 *8)) (-5 *1 (-31 *5 *6 *3 *7 *8)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)))) (-3379 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *2 (-3 (-638 *7) "failed" "Infinite" (-572))) (-5 *1 (-31 *4 *5 *3 *6 *7)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *7 (-978 *4)))) (-2034 (*1 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-31 *4 *5 *6 *7 *8)) (-4 *8 (-978 *4))))) 
-(-10 -7 (-15 -2034 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 |#3|))) (-15 -3379 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3|)) (-15 -1659 ((-638 |#5|) |#3| (-923)))) 
-((-1381 (((-1166 (-1166 |#1|)) |#3|) 35)) (-3038 (((-638 (-638 (-1166 (-1166 |#1|)))) (-638 (-1166 (-1166 |#1|)))) 54)) (-3379 (((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-1166 (-1166 |#1|))) 56) (((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3|) 57)) (-1659 (((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3| (-923)) 51)) (-1761 (((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 (-1166 (-1166 |#1|)))) 70)) (-2034 (((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 |#3|)) 50))) 
-(((-32 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3379 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3|)) (-15 -3379 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-1166 (-1166 |#1|)))) (-15 -1761 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 (-1166 (-1166 |#1|))))) (-15 -2034 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 |#3|))) (-15 -1381 ((-1166 (-1166 |#1|)) |#3|)) (-15 -3038 ((-638 (-638 (-1166 (-1166 |#1|)))) (-638 (-1166 (-1166 |#1|))))) (-15 -1659 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3| (-923)))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|)) (T -32)) 
-((-1659 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-32 *5 *6 *3 *7 *8)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)))) (-3038 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-5 *2 (-638 (-638 (-1166 (-1166 *4))))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-5 *3 (-638 (-1166 (-1166 *4)))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *8 (-978 *4)))) (-1381 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *2 (-1166 (-1166 *4))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *7 (-978 *4)))) (-2034 (*1 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *8 (-978 *4)))) (-1761 (*1 *2 *3) (-12 (-5 *3 (-638 (-1166 (-1166 *4)))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *8 (-978 *4)))) (-3379 (*1 *2 *3) (-12 (-5 *3 (-1166 (-1166 *4))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *8 (-978 *4)))) (-3379 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *2 (-3 (-638 *7) "failed" "Infinite" (-572))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *7 (-978 *4))))) 
-(-10 -7 (-15 -3379 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3|)) (-15 -3379 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-1166 (-1166 |#1|)))) (-15 -1761 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 (-1166 (-1166 |#1|))))) (-15 -2034 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) (-638 |#3|))) (-15 -1381 ((-1166 (-1166 |#1|)) |#3|)) (-15 -3038 ((-638 (-638 (-1166 (-1166 |#1|)))) (-638 (-1166 (-1166 |#1|))))) (-15 -1659 ((-3 (-638 |#5|) "failed" "Infinite" (-572)) |#3| (-923)))) 
-((-2262 (((-121) $ $) NIL)) (-3283 ((|#1| $ (-572) |#1|) NIL)) (-1452 (((-638 $) (-638 $) (-769)) NIL) (((-638 $) (-638 $)) NIL)) (-3175 (((-121) $ (-769)) NIL) (((-121) $) NIL)) (-1988 (((-638 |#1|) $) NIL)) (-1549 (($) NIL)) (-3035 (((-638 $) $) NIL) (((-638 $) $ (-769)) NIL)) (-1624 (((-638 |#1|) $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3277 ((|#1| $ (-572)) NIL)) (-4316 (((-923) $) NIL)) (-3105 ((|#1| $) NIL)) (-3018 (($ $ (-769)) NIL) (($ $) NIL)) (-3972 (((-856) $) NIL) (((-638 |#1|) $) NIL) (($ (-638 |#1|)) NIL)) (-3648 (($ (-638 |#1|)) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-33 |#1|) (-37 |#1|) (-368)) (T -33)) 
+(3640270 . 3613822976)       
+((-4076 (((-141) (-1 (-141) |#2| |#2|) $) 62) (((-141) $) NIL)) (-2831 (($ (-1 (-141) |#2| |#2|) $) 17) (($ $) NIL)) (-3932 ((|#2| $ (-592) |#2|) NIL) ((|#2| $ (-1246 (-592)) |#2|) 34)) (-2512 (($ $) 58)) (-3657 ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 40) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 38) ((|#2| (-1 |#2| |#2| |#2|) $) 37)) (-1721 (((-592) (-1 (-141) |#2|) $) 22) (((-592) |#2| $) NIL) (((-592) |#2| $ (-592)) 70)) (-4004 (((-658 |#2|) $) 13)) (-4491 (($ (-1 (-141) |#2| |#2|) $ $) 47) (($ $ $) NIL)) (-3987 (($ (-1 |#2| |#2|) $) 29)) (-2731 (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) 44)) (-3666 (($ |#2| $ (-592)) NIL) (($ $ $ (-592)) 49)) (-4050 (((-3 |#2| "failed") (-1 (-141) |#2|) $) 24)) (-3002 (((-141) (-1 (-141) |#2|) $) 21)) (-3927 ((|#2| $ (-592) |#2|) NIL) ((|#2| $ (-592)) NIL) (($ $ (-1246 (-592))) 48)) (-3208 (($ $ (-592)) 55) (($ $ (-1246 (-592))) 54)) (-3452 (((-790) (-1 (-141) |#2|) $) 26) (((-790) |#2| $) NIL)) (-2385 (($ $ $ (-592)) 51)) (-4599 (($ $) 50)) (-4466 (($ (-658 |#2|)) 52)) (-2266 (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ $ $) 63) (($ (-658 $)) 61)) (-1683 (((-877) $) 69)) (-3369 (((-141) (-1 (-141) |#2|) $) 20)) (-3255 (((-141) $ $) 64)) (-3266 (((-141) $ $) 72))) 
+(((-18 |#1| |#2|) (-10 -8 (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -2831 (|#1| |#1|)) (-15 -2831 (|#1| (-1 (-141) |#2| |#2|) |#1|)) (-15 -2512 (|#1| |#1|)) (-15 -2385 (|#1| |#1| |#1| (-592))) (-15 -4076 ((-141) |#1|)) (-15 -4491 (|#1| |#1| |#1|)) (-15 -1721 ((-592) |#2| |#1| (-592))) (-15 -1721 ((-592) |#2| |#1|)) (-15 -1721 ((-592) (-1 (-141) |#2|) |#1|)) (-15 -4076 ((-141) (-1 (-141) |#2| |#2|) |#1|)) (-15 -4491 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|)) (-15 -3932 (|#2| |#1| (-1246 (-592)) |#2|)) (-15 -3666 (|#1| |#1| |#1| (-592))) (-15 -3666 (|#1| |#2| |#1| (-592))) (-15 -3208 (|#1| |#1| (-1246 (-592)))) (-15 -3208 (|#1| |#1| (-592))) (-15 -3927 (|#1| |#1| (-1246 (-592)))) (-15 -2731 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2266 (|#1| (-658 |#1|))) (-15 -2266 (|#1| |#1| |#1|)) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#2|)) (-15 -4466 (|#1| (-658 |#2|))) (-15 -4050 ((-3 |#2| "failed") (-1 (-141) |#2|) |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3927 (|#2| |#1| (-592))) (-15 -3927 (|#2| |#1| (-592) |#2|)) (-15 -3932 (|#2| |#1| (-592) |#2|)) (-15 -3452 ((-790) |#2| |#1|)) (-15 -4004 ((-658 |#2|) |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3987 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4599 (|#1| |#1|))) (-19 |#2|) (-1225)) (T -18)) 
+NIL 
+(-10 -8 (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -2831 (|#1| |#1|)) (-15 -2831 (|#1| (-1 (-141) |#2| |#2|) |#1|)) (-15 -2512 (|#1| |#1|)) (-15 -2385 (|#1| |#1| |#1| (-592))) (-15 -4076 ((-141) |#1|)) (-15 -4491 (|#1| |#1| |#1|)) (-15 -1721 ((-592) |#2| |#1| (-592))) (-15 -1721 ((-592) |#2| |#1|)) (-15 -1721 ((-592) (-1 (-141) |#2|) |#1|)) (-15 -4076 ((-141) (-1 (-141) |#2| |#2|) |#1|)) (-15 -4491 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|)) (-15 -3932 (|#2| |#1| (-1246 (-592)) |#2|)) (-15 -3666 (|#1| |#1| |#1| (-592))) (-15 -3666 (|#1| |#2| |#1| (-592))) (-15 -3208 (|#1| |#1| (-1246 (-592)))) (-15 -3208 (|#1| |#1| (-592))) (-15 -3927 (|#1| |#1| (-1246 (-592)))) (-15 -2731 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2266 (|#1| (-658 |#1|))) (-15 -2266 (|#1| |#1| |#1|)) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#2|)) (-15 -4466 (|#1| (-658 |#2|))) (-15 -4050 ((-3 |#2| "failed") (-1 (-141) |#2|) |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3927 (|#2| |#1| (-592))) (-15 -3927 (|#2| |#1| (-592) |#2|)) (-15 -3932 (|#2| |#1| (-592) |#2|)) (-15 -3452 ((-790) |#2| |#1|)) (-15 -4004 ((-658 |#2|) |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3987 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4599 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) 91) (((-141) $) 85 (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) 82 (|has| $ (-6 -4626))) (($ $) 81 (-12 (|has| |#1| (-869)) (|has| $ (-6 -4626))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#1| $ (-592) |#1|) 49 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 53 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) 70 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-2512 (($ $) 83 (|has| $ (-6 -4626)))) (-1373 (($ $) 93)) (-1360 (($ $) 73 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#1| $) 72 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 69 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) 50 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 48)) (-1721 (((-592) (-1 (-141) |#1|) $) 90) (((-592) |#1| $) 89 (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) 88 (|has| |#1| (-1119)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-3242 (($ (-790) |#1|) 64)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-1837 (($ $ $) 80 (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3319 (($ $ $) 79 (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) 55) (($ $ $ (-592)) 54)) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 39 (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 66)) (-1892 (($ $ |#1|) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 42 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ (-592) |#1|) 47) ((|#1| $ (-592)) 46) (($ $ (-1246 (-592))) 58)) (-3208 (($ $ (-592)) 57) (($ $ (-1246 (-592))) 56)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-2385 (($ $ $ (-592)) 84 (|has| $ (-6 -4626)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 74 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 65)) (-2266 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-658 $)) 60)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) 77 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 76 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-3279 (((-141) $ $) 78 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 75 (|has| |#1| (-869)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-19 |#1|) (-1311) (-1225)) (T -19)) 
+NIL 
+(-13 (-399 |t#1|) (-10 -7 (-6 -4626))) 
+(((-39) . T) ((-125) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-632 (-877)) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-399 |#1|) . T) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-664 |#1|) . T) ((-869) |has| |#1| (-869)) ((-1119) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-1225) . T)) 
+((-2350 (((-3 $ "failed") $ $) 12)) (-3306 (($ $) NIL) (($ $ $) 9)) (* (($ (-944) $) NIL) (($ (-790) $) 16) (($ (-592) $) 21))) 
+(((-20 |#1|) (-10 -8 (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 -2350 ((-3 |#1| "failed") |#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) (-21)) (T -20)) 
+NIL 
+(-10 -8 (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 -2350 ((-3 |#1| "failed") |#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19))) 
+(((-21) (-1311)) (T -21)) 
+((-3306 (*1 *1 *1) (-4 *1 (-21))) (-3306 (*1 *1 *1 *1) (-4 *1 (-21))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-21)) (-5 *2 (-592))))) 
+(-13 (-158) (-10 -8 (-15 -3306 ($ $)) (-15 -3306 ($ $ $)) (-15 * ($ (-592) $)))) 
+(((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-2272 (((-141) $) 10)) (-3001 (($) 15)) (* (($ (-944) $) 14) (($ (-790) $) 18))) 
+(((-22 |#1|) (-10 -8 (-15 * (|#1| (-790) |#1|)) (-15 -2272 ((-141) |#1|)) (-15 -3001 (|#1|)) (-15 * (|#1| (-944) |#1|))) (-23)) (T -22)) 
+NIL 
+(-10 -8 (-15 * (|#1| (-790) |#1|)) (-15 -2272 ((-141) |#1|)) (-15 -3001 (|#1|)) (-15 * (|#1| (-944) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14))) 
+(((-23) (-1311)) (T -23)) 
+((-3514 (*1 *1) (-4 *1 (-23))) (-3001 (*1 *1) (-4 *1 (-23))) (-2272 (*1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-141)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-790))))) 
+(-13 (-25) (-10 -8 (-15 (-3514) ($) -4249) (-15 -3001 ($) -4249) (-15 -2272 ((-141) $)) (-15 * ($ (-790) $)))) 
+(((-25) . T) ((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((* (($ (-944) $) 10))) 
+(((-24 |#1|) (-10 -8 (-15 * (|#1| (-944) |#1|))) (-25)) (T -24)) 
+NIL 
+(-10 -8 (-15 * (|#1| (-944) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12))) 
+(((-25) (-1311)) (T -25)) 
+((-3300 (*1 *1 *1 *1) (-4 *1 (-25))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-25)) (-5 *2 (-944))))) 
+(-13 (-1119) (-10 -8 (-15 -3300 ($ $ $)) (-15 * ($ (-944) $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-3863 (((-658 $) (-980 $)) 29) (((-658 $) (-1187 $)) 16) (((-658 $) (-1187 $) (-1191)) 20)) (-3224 (($ (-980 $)) 27) (($ (-1187 $)) 11) (($ (-1187 $) (-1191)) 54)) (-1316 (((-658 $) (-980 $)) 30) (((-658 $) (-1187 $)) 18) (((-658 $) (-1187 $) (-1191)) 19)) (-3906 (($ (-980 $)) 28) (($ (-1187 $)) 13) (($ (-1187 $) (-1191)) NIL))) 
+(((-26 |#1|) (-10 -8 (-15 -3863 ((-658 |#1|) (-1187 |#1|) (-1191))) (-15 -3863 ((-658 |#1|) (-1187 |#1|))) (-15 -3863 ((-658 |#1|) (-980 |#1|))) (-15 -3224 (|#1| (-1187 |#1|) (-1191))) (-15 -3224 (|#1| (-1187 |#1|))) (-15 -3224 (|#1| (-980 |#1|))) (-15 -1316 ((-658 |#1|) (-1187 |#1|) (-1191))) (-15 -1316 ((-658 |#1|) (-1187 |#1|))) (-15 -1316 ((-658 |#1|) (-980 |#1|))) (-15 -3906 (|#1| (-1187 |#1|) (-1191))) (-15 -3906 (|#1| (-1187 |#1|))) (-15 -3906 (|#1| (-980 |#1|)))) (-27)) (T -26)) 
+NIL 
+(-10 -8 (-15 -3863 ((-658 |#1|) (-1187 |#1|) (-1191))) (-15 -3863 ((-658 |#1|) (-1187 |#1|))) (-15 -3863 ((-658 |#1|) (-980 |#1|))) (-15 -3224 (|#1| (-1187 |#1|) (-1191))) (-15 -3224 (|#1| (-1187 |#1|))) (-15 -3224 (|#1| (-980 |#1|))) (-15 -1316 ((-658 |#1|) (-1187 |#1|) (-1191))) (-15 -1316 ((-658 |#1|) (-1187 |#1|))) (-15 -1316 ((-658 |#1|) (-980 |#1|))) (-15 -3906 (|#1| (-1187 |#1|) (-1191))) (-15 -3906 (|#1| (-1187 |#1|))) (-15 -3906 (|#1| (-980 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-3863 (((-658 $) (-980 $)) 76) (((-658 $) (-1187 $)) 75) (((-658 $) (-1187 $) (-1191)) 74)) (-3224 (($ (-980 $)) 79) (($ (-1187 $)) 78) (($ (-1187 $) (-1191)) 77)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-1442 (($ $) 88)) (-3652 (((-141) $ $) 57)) (-3001 (($) 16 T CONST)) (-1316 (((-658 $) (-980 $)) 82) (((-658 $) (-1187 $)) 81) (((-658 $) (-1187 $) (-1191)) 80)) (-3906 (($ (-980 $)) 85) (($ (-1187 $)) 84) (($ (-1187 $) (-1191)) 83)) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2802 (((-141) $) 69)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 87)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66) (($ $ (-433 (-592))) 86)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64))) 
+(((-27) (-1311)) (T -27)) 
+((-3906 (*1 *1 *2) (-12 (-5 *2 (-980 *1)) (-4 *1 (-27)))) (-3906 (*1 *1 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-27)))) (-3906 (*1 *1 *2 *3) (-12 (-5 *2 (-1187 *1)) (-5 *3 (-1191)) (-4 *1 (-27)))) (-1316 (*1 *2 *3) (-12 (-5 *3 (-980 *1)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) (-1316 (*1 *2 *3) (-12 (-5 *3 (-1187 *1)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) (-1316 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 *1)) (-5 *4 (-1191)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) (-3224 (*1 *1 *2) (-12 (-5 *2 (-980 *1)) (-4 *1 (-27)))) (-3224 (*1 *1 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-27)))) (-3224 (*1 *1 *2 *3) (-12 (-5 *2 (-1187 *1)) (-5 *3 (-1191)) (-4 *1 (-27)))) (-3863 (*1 *2 *3) (-12 (-5 *3 (-980 *1)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) (-3863 (*1 *2 *3) (-12 (-5 *3 (-1187 *1)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) (-3863 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 *1)) (-5 *4 (-1191)) (-4 *1 (-27)) (-5 *2 (-658 *1))))) 
+(-13 (-388) (-1030) (-10 -8 (-15 -3906 ($ (-980 $))) (-15 -3906 ($ (-1187 $))) (-15 -3906 ($ (-1187 $) (-1191))) (-15 -1316 ((-658 $) (-980 $))) (-15 -1316 ((-658 $) (-1187 $))) (-15 -1316 ((-658 $) (-1187 $) (-1191))) (-15 -3224 ($ (-980 $))) (-15 -3224 ($ (-1187 $))) (-15 -3224 ($ (-1187 $) (-1191))) (-15 -3863 ((-658 $) (-980 $))) (-15 -3863 ((-658 $) (-1187 $))) (-15 -3863 ((-658 $) (-1187 $) (-1191))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1030) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T)) 
+((-3863 (((-658 $) (-980 $)) NIL) (((-658 $) (-1187 $)) NIL) (((-658 $) (-1187 $) (-1191)) 50) (((-658 $) $) 19) (((-658 $) $ (-1191)) 41)) (-3224 (($ (-980 $)) NIL) (($ (-1187 $)) NIL) (($ (-1187 $) (-1191)) 52) (($ $) 17) (($ $ (-1191)) 37)) (-1316 (((-658 $) (-980 $)) NIL) (((-658 $) (-1187 $)) NIL) (((-658 $) (-1187 $) (-1191)) 48) (((-658 $) $) 15) (((-658 $) $ (-1191)) 43)) (-3906 (($ (-980 $)) NIL) (($ (-1187 $)) NIL) (($ (-1187 $) (-1191)) NIL) (($ $) 12) (($ $ (-1191)) 39))) 
+(((-28 |#1| |#2|) (-10 -8 (-15 -3863 ((-658 |#1|) |#1| (-1191))) (-15 -3224 (|#1| |#1| (-1191))) (-15 -3863 ((-658 |#1|) |#1|)) (-15 -3224 (|#1| |#1|)) (-15 -1316 ((-658 |#1|) |#1| (-1191))) (-15 -3906 (|#1| |#1| (-1191))) (-15 -1316 ((-658 |#1|) |#1|)) (-15 -3906 (|#1| |#1|)) (-15 -3863 ((-658 |#1|) (-1187 |#1|) (-1191))) (-15 -3863 ((-658 |#1|) (-1187 |#1|))) (-15 -3863 ((-658 |#1|) (-980 |#1|))) (-15 -3224 (|#1| (-1187 |#1|) (-1191))) (-15 -3224 (|#1| (-1187 |#1|))) (-15 -3224 (|#1| (-980 |#1|))) (-15 -1316 ((-658 |#1|) (-1187 |#1|) (-1191))) (-15 -1316 ((-658 |#1|) (-1187 |#1|))) (-15 -1316 ((-658 |#1|) (-980 |#1|))) (-15 -3906 (|#1| (-1187 |#1|) (-1191))) (-15 -3906 (|#1| (-1187 |#1|))) (-15 -3906 (|#1| (-980 |#1|)))) (-29 |#2|) (-13 (-869) (-582))) (T -28)) 
+NIL 
+(-10 -8 (-15 -3863 ((-658 |#1|) |#1| (-1191))) (-15 -3224 (|#1| |#1| (-1191))) (-15 -3863 ((-658 |#1|) |#1|)) (-15 -3224 (|#1| |#1|)) (-15 -1316 ((-658 |#1|) |#1| (-1191))) (-15 -3906 (|#1| |#1| (-1191))) (-15 -1316 ((-658 |#1|) |#1|)) (-15 -3906 (|#1| |#1|)) (-15 -3863 ((-658 |#1|) (-1187 |#1|) (-1191))) (-15 -3863 ((-658 |#1|) (-1187 |#1|))) (-15 -3863 ((-658 |#1|) (-980 |#1|))) (-15 -3224 (|#1| (-1187 |#1|) (-1191))) (-15 -3224 (|#1| (-1187 |#1|))) (-15 -3224 (|#1| (-980 |#1|))) (-15 -1316 ((-658 |#1|) (-1187 |#1|) (-1191))) (-15 -1316 ((-658 |#1|) (-1187 |#1|))) (-15 -1316 ((-658 |#1|) (-980 |#1|))) (-15 -3906 (|#1| (-1187 |#1|) (-1191))) (-15 -3906 (|#1| (-1187 |#1|))) (-15 -3906 (|#1| (-980 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-3863 (((-658 $) (-980 $)) 76) (((-658 $) (-1187 $)) 75) (((-658 $) (-1187 $) (-1191)) 74) (((-658 $) $) 120) (((-658 $) $ (-1191)) 118)) (-3224 (($ (-980 $)) 79) (($ (-1187 $)) 78) (($ (-1187 $) (-1191)) 77) (($ $) 121) (($ $ (-1191)) 119)) (-2272 (((-141) $) 15)) (-4085 (((-658 (-1191)) $) 195)) (-4492 (((-433 (-1187 $)) $ (-631 $)) 227 (|has| |#1| (-582)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2165 (((-658 (-631 $)) $) 158)) (-2350 (((-3 $ "failed") $ $) 18)) (-3147 (($ $ (-658 (-631 $)) (-658 $)) 148) (($ $ (-658 (-310 $))) 147) (($ $ (-310 $)) 146)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-1442 (($ $) 88)) (-3652 (((-141) $ $) 57)) (-3001 (($) 16 T CONST)) (-1316 (((-658 $) (-980 $)) 82) (((-658 $) (-1187 $)) 81) (((-658 $) (-1187 $) (-1191)) 80) (((-658 $) $) 124) (((-658 $) $ (-1191)) 122)) (-3906 (($ (-980 $)) 85) (($ (-1187 $)) 84) (($ (-1187 $) (-1191)) 83) (($ $) 125) (($ $ (-1191)) 123)) (-4368 (((-3 (-980 |#1|) "failed") $) 245 (|has| |#1| (-1075))) (((-3 (-433 (-980 |#1|)) "failed") $) 229 (|has| |#1| (-582))) (((-3 |#1| "failed") $) 191) (((-3 (-592) "failed") $) 189 (|has| |#1| (-1065 (-592)))) (((-3 (-1191) "failed") $) 182) (((-3 (-631 $) "failed") $) 133) (((-3 (-433 (-592)) "failed") $) 117 (-3836 (-12 (|has| |#1| (-1065 (-592))) (|has| |#1| (-582))) (|has| |#1| (-1065 (-433 (-592))))))) (-2400 (((-980 |#1|) $) 246 (|has| |#1| (-1075))) (((-433 (-980 |#1|)) $) 230 (|has| |#1| (-582))) ((|#1| $) 192) (((-592) $) 188 (|has| |#1| (-1065 (-592)))) (((-1191) $) 183) (((-631 $) $) 134) (((-433 (-592)) $) 116 (-3836 (-12 (|has| |#1| (-1065 (-592))) (|has| |#1| (-582))) (|has| |#1| (-1065 (-433 (-592))))))) (-1586 (($ $ $) 53)) (-3945 (((-706 |#1|) (-706 $)) 235 (|has| |#1| (-1075))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 234 (|has| |#1| (-1075))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 115 (-3836 (-1732 (|has| |#1| (-1075)) (|has| |#1| (-654 (-592)))) (-1732 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))))) (((-706 (-592)) (-706 $)) 114 (-3836 (-1732 (|has| |#1| (-1075)) (|has| |#1| (-654 (-592)))) (-1732 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))))) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2802 (((-141) $) 69)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 187 (|has| |#1| (-908 (-405)))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 186 (|has| |#1| (-908 (-592))))) (-2243 (($ (-658 $)) 152) (($ $) 151)) (-4388 (((-658 (-143)) $) 159)) (-2791 (((-143) (-143)) 160)) (-3558 (((-141) $) 30)) (-3372 (((-141) $) 180 (|has| $ (-1065 (-592))))) (-3838 (($ $) 212 (|has| |#1| (-1075)))) (-1448 (((-1142 |#1| (-631 $)) $) 211 (|has| |#1| (-1075)))) (-4422 (($ $ (-592)) 87)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-2710 (((-1187 $) (-631 $)) 177 (|has| $ (-1075)))) (-1837 (($ $ $) 131)) (-3319 (($ $ $) 130)) (-2731 (($ (-1 $ $) (-631 $)) 166)) (-4160 (((-3 (-631 $) "failed") $) 156)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4486 (((-658 (-631 $)) $) 157)) (-1462 (($ (-143) (-658 $)) 165) (($ (-143) $) 164)) (-4421 (((-3 (-658 $) "failed") $) 206 (|has| |#1| (-1131)))) (-2427 (((-3 (-2 (|:| |val| $) (|:| -3215 (-592))) "failed") $) 215 (|has| |#1| (-1075)))) (-2947 (((-3 (-658 $) "failed") $) 208 (|has| |#1| (-25)))) (-1649 (((-3 (-2 (|:| -1487 (-592)) (|:| |var| (-631 $))) "failed") $) 209 (|has| |#1| (-25)))) (-2257 (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-1191)) 214 (|has| |#1| (-1075))) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-143)) 213 (|has| |#1| (-1075))) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $) 207 (|has| |#1| (-1131)))) (-3013 (((-141) $ (-1191)) 163) (((-141) $ (-143)) 162)) (-4552 (($ $) 68)) (-2535 (((-790) $) 155)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 193)) (-4565 ((|#1| $) 194)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-1319 (((-141) $ (-1191)) 168) (((-141) $ $) 167)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-3554 (((-141) $) 179 (|has| $ (-1065 (-592))))) (-2806 (($ $ (-1191) (-790) (-1 $ $)) 219 (|has| |#1| (-1075))) (($ $ (-1191) (-790) (-1 $ (-658 $))) 218 (|has| |#1| (-1075))) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ (-658 $)))) 217 (|has| |#1| (-1075))) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ $))) 216 (|has| |#1| (-1075))) (($ $ (-658 (-143)) (-658 $) (-1191)) 205 (|has| |#1| (-633 (-565)))) (($ $ (-143) $ (-1191)) 204 (|has| |#1| (-633 (-565)))) (($ $) 203 (|has| |#1| (-633 (-565)))) (($ $ (-658 (-1191))) 202 (|has| |#1| (-633 (-565)))) (($ $ (-1191)) 201 (|has| |#1| (-633 (-565)))) (($ $ (-143) (-1 $ $)) 176) (($ $ (-143) (-1 $ (-658 $))) 175) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) 174) (($ $ (-658 (-143)) (-658 (-1 $ $))) 173) (($ $ (-1191) (-1 $ $)) 172) (($ $ (-1191) (-1 $ (-658 $))) 171) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) 170) (($ $ (-658 (-1191)) (-658 (-1 $ $))) 169) (($ $ (-658 $) (-658 $)) 140) (($ $ $ $) 139) (($ $ (-310 $)) 138) (($ $ (-658 (-310 $))) 137) (($ $ (-658 (-631 $)) (-658 $)) 136) (($ $ (-631 $) $) 135)) (-2769 (((-790) $) 56)) (-3927 (($ (-143) (-658 $)) 145) (($ (-143) $ $ $ $) 144) (($ (-143) $ $ $) 143) (($ (-143) $ $) 142) (($ (-143) $) 141)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-2818 (($ $ $) 154) (($ $) 153)) (-3644 (($ $ (-1191)) 243 (|has| |#1| (-1075))) (($ $ (-658 (-1191))) 242 (|has| |#1| (-1075))) (($ $ (-1191) (-790)) 241 (|has| |#1| (-1075))) (($ $ (-658 (-1191)) (-658 (-790))) 240 (|has| |#1| (-1075)))) (-2782 (($ $) 222 (|has| |#1| (-582)))) (-1456 (((-1142 |#1| (-631 $)) $) 221 (|has| |#1| (-582)))) (-3390 (($ $) 178 (|has| $ (-1075)))) (-1778 (((-565) $) 249 (|has| |#1| (-633 (-565)))) (($ (-444 $)) 220 (|has| |#1| (-582))) (((-914 (-405)) $) 185 (|has| |#1| (-633 (-914 (-405))))) (((-914 (-592)) $) 184 (|has| |#1| (-633 (-914 (-592)))))) (-2227 (($ $ $) 248 (|has| |#1| (-502)))) (-2131 (($ $ $) 247 (|has| |#1| (-502)))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63) (($ (-980 |#1|)) 244 (|has| |#1| (-1075))) (($ (-433 (-980 |#1|))) 228 (|has| |#1| (-582))) (($ (-433 (-980 (-433 |#1|)))) 226 (|has| |#1| (-582))) (($ (-980 (-433 |#1|))) 225 (|has| |#1| (-582))) (($ (-433 |#1|)) 224 (|has| |#1| (-582))) (($ (-1142 |#1| (-631 $))) 210 (|has| |#1| (-1075))) (($ |#1|) 190) (($ (-1191)) 181) (($ (-631 $)) 132)) (-1517 (((-3 $ "failed") $) 233 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-3280 (($ (-658 $)) 150) (($ $) 149)) (-3038 (((-141) (-143)) 161)) (-2537 (((-141) $ $) 38)) (-3270 (($ (-1191) (-658 $)) 200) (($ (-1191) $ $ $ $) 199) (($ (-1191) $ $ $) 198) (($ (-1191) $ $) 197) (($ (-1191) $) 196)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-1191)) 239 (|has| |#1| (-1075))) (($ $ (-658 (-1191))) 238 (|has| |#1| (-1075))) (($ $ (-1191) (-790)) 237 (|has| |#1| (-1075))) (($ $ (-658 (-1191)) (-658 (-790))) 236 (|has| |#1| (-1075)))) (-3286 (((-141) $ $) 128)) (-3273 (((-141) $ $) 127)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 129)) (-3266 (((-141) $ $) 126)) (-3313 (($ $ $) 62) (($ (-1142 |#1| (-631 $)) (-1142 |#1| (-631 $))) 223 (|has| |#1| (-582)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66) (($ $ (-433 (-592))) 86)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64) (($ $ |#1|) 232 (|has| |#1| (-194))) (($ |#1| $) 231 (|has| |#1| (-194))))) 
+(((-29 |#1|) (-1311) (-13 (-869) (-582))) (T -29)) 
+((-3906 (*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-869) (-582))))) (-1316 (*1 *2 *1) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *2 (-658 *1)) (-4 *1 (-29 *3)))) (-3906 (*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-869) (-582))))) (-1316 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-658 *1)) (-4 *1 (-29 *4)))) (-3224 (*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-869) (-582))))) (-3863 (*1 *2 *1) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *2 (-658 *1)) (-4 *1 (-29 *3)))) (-3224 (*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-869) (-582))))) (-3863 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-658 *1)) (-4 *1 (-29 *4))))) 
+(-13 (-27) (-456 |t#1|) (-10 -8 (-15 -3906 ($ $)) (-15 -1316 ((-658 $) $)) (-15 -3906 ($ $ (-1191))) (-15 -1316 ((-658 $) $ (-1191))) (-15 -3224 ($ $)) (-15 -3863 ((-658 $) $)) (-15 -3224 ($ $ (-1191))) (-15 -3863 ((-658 $) $ (-1191))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) . T) ((-27) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 |#1| |#1|) |has| |#1| (-194)) ((-140 $ $) . T) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-633 (-914 (-405))) |has| |#1| (-633 (-914 (-405)))) ((-633 (-914 (-592))) |has| |#1| (-633 (-914 (-592)))) ((-260) . T) ((-307) . T) ((-323) . T) ((-325 $) . T) ((-318) . T) ((-388) . T) ((-403 |#1|) |has| |#1| (-1075)) ((-426 |#1|) . T) ((-437 |#1|) . T) ((-456 |#1|) . T) ((-477) . T) ((-502) |has| |#1| (-502)) ((-547 (-631 $) $) . T) ((-547 $ $) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 |#1|) |has| |#1| (-194)) ((-661 $) . T) ((-678) . T) ((-654 (-592)) -12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) ((-654 |#1|) |has| |#1| (-1075)) ((-734 (-433 (-592))) . T) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) . T) ((-743) . T) ((-869) . T) ((-922 (-1191)) |has| |#1| (-1075)) ((-908 (-405)) |has| |#1| (-908 (-405))) ((-908 (-592)) |has| |#1| (-908 (-592))) ((-906 |#1|) . T) ((-943) . T) ((-1030) . T) ((-1065 (-433 (-592))) -3836 (|has| |#1| (-1065 (-433 (-592)))) (-12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592))))) ((-1065 (-433 (-980 |#1|))) |has| |#1| (-582)) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 (-631 $)) . T) ((-1065 (-980 |#1|)) |has| |#1| (-1075)) ((-1065 (-1191)) . T) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) . T) ((-1081 |#1|) |has| |#1| (-194)) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1225) . T) ((-1235) . T)) 
+((-1413 (((-1113 (-237)) $) NIL)) (-4254 (((-1113 (-237)) $) NIL)) (-4028 (($ $ (-237)) 122)) (-3943 (($ (-980 (-592)) (-1191) (-1191) (-1113 (-433 (-592))) (-1113 (-433 (-592)))) 84)) (-1613 (((-658 (-658 (-971 (-237)))) $) 134)) (-1683 (((-877) $) 146))) 
+(((-30) (-13 (-983) (-10 -8 (-15 -3943 ($ (-980 (-592)) (-1191) (-1191) (-1113 (-433 (-592))) (-1113 (-433 (-592))))) (-15 -4028 ($ $ (-237)))))) (T -30)) 
+((-3943 (*1 *1 *2 *3 *3 *4 *4) (-12 (-5 *2 (-980 (-592))) (-5 *3 (-1191)) (-5 *4 (-1113 (-433 (-592)))) (-5 *1 (-30)))) (-4028 (*1 *1 *1 *2) (-12 (-5 *2 (-237)) (-5 *1 (-30))))) 
+(-13 (-983) (-10 -8 (-15 -3943 ($ (-980 (-592)) (-1191) (-1191) (-1113 (-433 (-592))) (-1113 (-433 (-592))))) (-15 -4028 ($ $ (-237))))) 
+((-4394 (((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3|) 38)) (-2715 (((-658 |#5|) |#3| (-944)) 33)) (-3961 (((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 |#3|)) 40))) 
+(((-31 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3961 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 |#3|))) (-15 -4394 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3|)) (-15 -2715 ((-658 |#5|) |#3| (-944)))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|)) (T -31)) 
+((-2715 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-5 *2 (-658 *8)) (-5 *1 (-31 *5 *6 *3 *7 *8)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)))) (-4394 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *2 (-3 (-658 *7) "failed" "Infinite" (-592))) (-5 *1 (-31 *4 *5 *3 *6 *7)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *7 (-999 *4)))) (-3961 (*1 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-31 *4 *5 *6 *7 *8)) (-4 *8 (-999 *4))))) 
+(-10 -7 (-15 -3961 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 |#3|))) (-15 -4394 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3|)) (-15 -2715 ((-658 |#5|) |#3| (-944)))) 
+((-3600 (((-1187 (-1187 |#1|)) |#3|) 35)) (-1451 (((-658 (-658 (-1187 (-1187 |#1|)))) (-658 (-1187 (-1187 |#1|)))) 54)) (-4394 (((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-1187 (-1187 |#1|))) 56) (((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3|) 57)) (-2715 (((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3| (-944)) 51)) (-1622 (((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 (-1187 (-1187 |#1|)))) 70)) (-3961 (((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 |#3|)) 50))) 
+(((-32 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4394 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3|)) (-15 -4394 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-1187 (-1187 |#1|)))) (-15 -1622 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 (-1187 (-1187 |#1|))))) (-15 -3961 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 |#3|))) (-15 -3600 ((-1187 (-1187 |#1|)) |#3|)) (-15 -1451 ((-658 (-658 (-1187 (-1187 |#1|)))) (-658 (-1187 (-1187 |#1|))))) (-15 -2715 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3| (-944)))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|)) (T -32)) 
+((-2715 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-32 *5 *6 *3 *7 *8)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)))) (-1451 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-5 *2 (-658 (-658 (-1187 (-1187 *4))))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-5 *3 (-658 (-1187 (-1187 *4)))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *8 (-999 *4)))) (-3600 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *2 (-1187 (-1187 *4))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *7 (-999 *4)))) (-3961 (*1 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *8 (-999 *4)))) (-1622 (*1 *2 *3) (-12 (-5 *3 (-658 (-1187 (-1187 *4)))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *8 (-999 *4)))) (-4394 (*1 *2 *3) (-12 (-5 *3 (-1187 (-1187 *4))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *8 (-999 *4)))) (-4394 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *2 (-3 (-658 *7) "failed" "Infinite" (-592))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *7 (-999 *4))))) 
+(-10 -7 (-15 -4394 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3|)) (-15 -4394 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-1187 (-1187 |#1|)))) (-15 -1622 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 (-1187 (-1187 |#1|))))) (-15 -3961 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) (-658 |#3|))) (-15 -3600 ((-1187 (-1187 |#1|)) |#3|)) (-15 -1451 ((-658 (-658 (-1187 (-1187 |#1|)))) (-658 (-1187 (-1187 |#1|))))) (-15 -2715 ((-3 (-658 |#5|) "failed" "Infinite" (-592)) |#3| (-944)))) 
+((-1641 (((-141) $ $) NIL)) (-3932 ((|#1| $ (-592) |#1|) NIL)) (-1328 (((-658 $) (-658 $) (-790)) NIL) (((-658 $) (-658 $)) NIL)) (-2435 (((-141) $ (-790)) NIL) (((-141) $) NIL)) (-2382 (((-658 |#1|) $) NIL)) (-4200 (($) NIL)) (-1363 (((-658 $) $) NIL) (((-658 $) $ (-790)) NIL)) (-1333 (((-658 |#1|) $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3927 ((|#1| $ (-592)) NIL)) (-4525 (((-944) $) NIL)) (-3472 ((|#1| $) NIL)) (-2227 (($ $ (-790)) NIL) (($ $) NIL)) (-1683 (((-877) $) NIL) (((-658 |#1|) $) NIL) (($ (-658 |#1|)) NIL)) (-2703 (($ (-658 |#1|)) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-33 |#1|) (-37 |#1|) (-388)) (T -33)) 
 NIL 
 (-37 |#1|) 
-((-2262 (((-121) $ $) NIL)) (-3283 (((-863 |#1|) $ (-572) (-863 |#1|)) NIL)) (-1452 (((-638 $) (-638 $) (-769)) NIL) (((-638 $) (-638 $)) NIL)) (-3175 (((-121) $ (-769)) NIL) (((-121) $) NIL)) (-1988 (((-638 (-863 |#1|)) $) NIL)) (-1549 (($) NIL)) (-3035 (((-638 $) $) NIL) (((-638 $) $ (-769)) NIL)) (-1624 (((-638 (-863 |#1|)) $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3277 (((-863 |#1|) $ (-572)) NIL)) (-4316 (((-923) $) NIL)) (-3105 (((-863 |#1|) $) NIL)) (-3018 (($ $ (-769)) NIL) (($ $) NIL)) (-3972 (((-856) $) NIL) (((-638 (-863 |#1|)) $) NIL) (($ (-638 (-863 |#1|))) NIL)) (-3648 (($ (-638 (-863 |#1|))) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-34 |#1|) (-37 (-863 |#1|)) (-353)) (T -34)) 
+((-1641 (((-141) $ $) NIL)) (-3932 (((-884 |#1|) $ (-592) (-884 |#1|)) NIL)) (-1328 (((-658 $) (-658 $) (-790)) NIL) (((-658 $) (-658 $)) NIL)) (-2435 (((-141) $ (-790)) NIL) (((-141) $) NIL)) (-2382 (((-658 (-884 |#1|)) $) NIL)) (-4200 (($) NIL)) (-1363 (((-658 $) $) NIL) (((-658 $) $ (-790)) NIL)) (-1333 (((-658 (-884 |#1|)) $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3927 (((-884 |#1|) $ (-592)) NIL)) (-4525 (((-944) $) NIL)) (-3472 (((-884 |#1|) $) NIL)) (-2227 (($ $ (-790)) NIL) (($ $) NIL)) (-1683 (((-877) $) NIL) (((-658 (-884 |#1|)) $) NIL) (($ (-658 (-884 |#1|))) NIL)) (-2703 (($ (-658 (-884 |#1|))) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-34 |#1|) (-37 (-884 |#1|)) (-373)) (T -34)) 
 NIL 
-(-37 (-863 |#1|)) 
-((-2262 (((-121) $ $) NIL)) (-3283 ((|#2| $ (-572) |#2|) NIL)) (-1452 (((-638 $) (-638 $) (-769)) 39) (((-638 $) (-638 $)) 40)) (-3175 (((-121) $ (-769)) 36) (((-121) $) 38)) (-1988 (((-638 |#2|) $) 31)) (-1549 (($) 12)) (-3035 (((-638 $) $) 48) (((-638 $) $ (-769)) 45)) (-1624 (((-638 |#2|) $) 30)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3277 ((|#2| $ (-572)) NIL)) (-4316 (((-923) $) 20)) (-3105 ((|#2| $) 26)) (-3018 (($ $ (-769)) 33) (($ $) 47)) (-3972 (((-856) $) 23) (((-638 |#2|) $) 28) (($ (-638 |#2|)) 51)) (-3648 (($ (-638 |#2|)) 29)) (-1324 (((-121) $ $) 35))) 
-(((-35 |#1| |#2|) (-37 |#2|) (-769) (-368)) (T -35)) 
+(-37 (-884 |#1|)) 
+((-1641 (((-141) $ $) NIL)) (-3932 ((|#2| $ (-592) |#2|) NIL)) (-1328 (((-658 $) (-658 $) (-790)) 39) (((-658 $) (-658 $)) 40)) (-2435 (((-141) $ (-790)) 36) (((-141) $) 38)) (-2382 (((-658 |#2|) $) 31)) (-4200 (($) 12)) (-1363 (((-658 $) $) 48) (((-658 $) $ (-790)) 45)) (-1333 (((-658 |#2|) $) 30)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3927 ((|#2| $ (-592)) NIL)) (-4525 (((-944) $) 20)) (-3472 ((|#2| $) 26)) (-2227 (($ $ (-790)) 33) (($ $) 47)) (-1683 (((-877) $) 23) (((-658 |#2|) $) 28) (($ (-658 |#2|)) 51)) (-2703 (($ (-658 |#2|)) 29)) (-3255 (((-141) $ $) 35))) 
+(((-35 |#1| |#2|) (-37 |#2|) (-790) (-388)) (T -35)) 
 NIL 
 (-37 |#2|) 
-((-3733 ((|#2| (-1166 |#2|) (-1170)) 42)) (-4564 (((-123) (-123)) 54)) (-4127 (((-1166 |#2|) (-611 |#2|)) 129 (|has| |#1| (-1044 (-572))))) (-1707 ((|#2| |#1| (-572)) 108 (|has| |#1| (-1044 (-572))))) (-1700 ((|#2| (-1166 |#2|) |#2|) 30)) (-2042 (((-856) (-638 |#2|)) 84)) (-2830 ((|#2| |#2|) 125 (|has| |#1| (-1044 (-572))))) (-3228 (((-121) (-123)) 18)) (** ((|#2| |#2| (-413 (-572))) 89 (|has| |#1| (-1044 (-572)))))) 
-(((-36 |#1| |#2|) (-10 -7 (-15 -3733 (|#2| (-1166 |#2|) (-1170))) (-15 -4564 ((-123) (-123))) (-15 -3228 ((-121) (-123))) (-15 -1700 (|#2| (-1166 |#2|) |#2|)) (-15 -2042 ((-856) (-638 |#2|))) (IF (|has| |#1| (-1044 (-572))) (PROGN (-15 ** (|#2| |#2| (-413 (-572)))) (-15 -4127 ((-1166 |#2|) (-611 |#2|))) (-15 -2830 (|#2| |#2|)) (-15 -1707 (|#2| |#1| (-572)))) |noBranch|)) (-13 (-848) (-562)) (-436 |#1|)) (T -36)) 
-((-1707 (*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *2 (-436 *3)) (-5 *1 (-36 *3 *2)) (-4 *3 (-1044 *4)) (-4 *3 (-13 (-848) (-562))))) (-2830 (*1 *2 *2) (-12 (-4 *3 (-1044 (-572))) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-36 *3 *2)) (-4 *2 (-436 *3)))) (-4127 (*1 *2 *3) (-12 (-5 *3 (-611 *5)) (-4 *5 (-436 *4)) (-4 *4 (-1044 (-572))) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-1166 *5)) (-5 *1 (-36 *4 *5)))) (** (*1 *2 *2 *3) (-12 (-5 *3 (-413 (-572))) (-4 *4 (-1044 (-572))) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-36 *4 *2)) (-4 *2 (-436 *4)))) (-2042 (*1 *2 *3) (-12 (-5 *3 (-638 *5)) (-4 *5 (-436 *4)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-856)) (-5 *1 (-36 *4 *5)))) (-1700 (*1 *2 *3 *2) (-12 (-5 *3 (-1166 *2)) (-4 *2 (-436 *4)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-36 *4 *2)))) (-3228 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-36 *4 *5)) (-4 *5 (-436 *4)))) (-4564 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-36 *3 *4)) (-4 *4 (-436 *3)))) (-3733 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 *2)) (-5 *4 (-1170)) (-4 *2 (-436 *5)) (-5 *1 (-36 *5 *2)) (-4 *5 (-13 (-848) (-562)))))) 
-(-10 -7 (-15 -3733 (|#2| (-1166 |#2|) (-1170))) (-15 -4564 ((-123) (-123))) (-15 -3228 ((-121) (-123))) (-15 -1700 (|#2| (-1166 |#2|) |#2|)) (-15 -2042 ((-856) (-638 |#2|))) (IF (|has| |#1| (-1044 (-572))) (PROGN (-15 ** (|#2| |#2| (-413 (-572)))) (-15 -4127 ((-1166 |#2|) (-611 |#2|))) (-15 -2830 (|#2| |#2|)) (-15 -1707 (|#2| |#1| (-572)))) |noBranch|)) 
-((-2262 (((-121) $ $) 7)) (-3283 ((|#1| $ (-572) |#1|) 14)) (-1452 (((-638 $) (-638 $) (-769)) 20) (((-638 $) (-638 $)) 19)) (-3175 (((-121) $ (-769)) 18) (((-121) $) 17)) (-1988 (((-638 |#1|) $) 13)) (-1549 (($) 29)) (-3035 (((-638 $) $) 24) (((-638 $) $ (-769)) 23)) (-1624 (((-638 |#1|) $) 16)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3277 ((|#1| $ (-572)) 15)) (-4316 (((-923) $) 12)) (-3105 ((|#1| $) 27)) (-3018 (($ $ (-769)) 22) (($ $) 21)) (-3972 (((-856) $) 11) (((-638 |#1|) $) 26) (($ (-638 |#1|)) 25)) (-3648 (($ (-638 |#1|)) 28)) (-1324 (((-121) $ $) 6))) 
-(((-37 |#1|) (-1290) (-368)) (T -37)) 
-((-1549 (*1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-368)))) (-3648 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-37 *3)))) (-3105 (*1 *2 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-368)))) (-3972 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-37 *3)))) (-3035 (*1 *2 *1) (-12 (-4 *3 (-368)) (-5 *2 (-638 *1)) (-4 *1 (-37 *3)))) (-3035 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *4 (-368)) (-5 *2 (-638 *1)) (-4 *1 (-37 *4)))) (-3018 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-37 *3)) (-4 *3 (-368)))) (-3018 (*1 *1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-368)))) (-1452 (*1 *2 *2 *3) (-12 (-5 *2 (-638 *1)) (-5 *3 (-769)) (-4 *1 (-37 *4)) (-4 *4 (-368)))) (-1452 (*1 *2 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-37 *3)) (-4 *3 (-368)))) (-3175 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-37 *4)) (-4 *4 (-368)) (-5 *2 (-121)))) (-3175 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-368)) (-5 *2 (-121)))) (-1624 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-37 *2)) (-4 *2 (-368)))) (-3283 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-37 *2)) (-4 *2 (-368)))) (-1988 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3))))) 
-(-13 (-1096) (-10 -8 (-15 -1549 ($)) (-15 -3648 ($ (-638 |t#1|))) (-15 -3105 (|t#1| $)) (-15 -3972 ((-638 |t#1|) $)) (-15 -3972 ($ (-638 |t#1|))) (-15 -3035 ((-638 $) $)) (-15 -3035 ((-638 $) $ (-769))) (-15 -3018 ($ $ (-769))) (-15 -3018 ($ $)) (-15 -1452 ((-638 $) (-638 $) (-769))) (-15 -1452 ((-638 $) (-638 $))) (-15 -3175 ((-121) $ (-769))) (-15 -3175 ((-121) $)) (-15 -1624 ((-638 |t#1|) $)) (-15 -3277 (|t#1| $ (-572))) (-15 -3283 (|t#1| $ (-572) |t#1|)) (-15 -1988 ((-638 |t#1|) $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T) ((-1096) . T)) 
-((-1946 (((-121) $ (-769)) 16)) (-2211 (($) 10)) (-2157 (((-121) $ (-769)) 15)) (-3524 (((-121) $ (-769)) 14)) (-3598 (((-121) $ $) 8)) (-4037 (((-121) $) 13))) 
-(((-38 |#1|) (-10 -8 (-15 -2211 (|#1|)) (-15 -1946 ((-121) |#1| (-769))) (-15 -2157 ((-121) |#1| (-769))) (-15 -3524 ((-121) |#1| (-769))) (-15 -4037 ((-121) |#1|)) (-15 -3598 ((-121) |#1| |#1|))) (-39)) (T -38)) 
-NIL 
-(-10 -8 (-15 -2211 (|#1|)) (-15 -1946 ((-121) |#1| (-769))) (-15 -2157 ((-121) |#1| (-769))) (-15 -3524 ((-121) |#1| (-769))) (-15 -4037 ((-121) |#1|)) (-15 -3598 ((-121) |#1| |#1|))) 
-((-1946 (((-121) $ (-769)) 8)) (-2211 (($) 7 T CONST)) (-2157 (((-121) $ (-769)) 9)) (-3524 (((-121) $ (-769)) 10)) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1607 (($ $) 13)) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-39) (-1290)) (T -39)) 
-((-3598 (*1 *2 *1 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) (-1607 (*1 *1 *1) (-4 *1 (-39))) (-1665 (*1 *1) (-4 *1 (-39))) (-4037 (*1 *2 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) (-3524 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-769)) (-5 *2 (-121)))) (-2157 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-769)) (-5 *2 (-121)))) (-1946 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-769)) (-5 *2 (-121)))) (-2211 (*1 *1) (-4 *1 (-39))) (-4032 (*1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-39)) (-5 *2 (-769))))) 
-(-13 (-1204) (-10 -8 (-15 -3598 ((-121) $ $)) (-15 -1607 ($ $)) (-15 -1665 ($)) (-15 -4037 ((-121) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -2211 ($) -3211) (IF (|has| $ (-6 -4602)) (-15 -4032 ((-769) $)) |noBranch|))) 
-(((-1204) . T)) 
-((-4321 (($ $) 11)) (-4308 (($ $) 10)) (-4333 (($ $) 9)) (-2104 (($ $) 8)) (-4327 (($ $) 7)) (-4314 (($ $) 6))) 
-(((-40) (-1290)) (T -40)) 
-((-4321 (*1 *1 *1) (-4 *1 (-40))) (-4308 (*1 *1 *1) (-4 *1 (-40))) (-4333 (*1 *1 *1) (-4 *1 (-40))) (-2104 (*1 *1 *1) (-4 *1 (-40))) (-4327 (*1 *1 *1) (-4 *1 (-40))) (-4314 (*1 *1 *1) (-4 *1 (-40)))) 
-(-13 (-10 -8 (-15 -4314 ($ $)) (-15 -4327 ($ $)) (-15 -2104 ($ $)) (-15 -4333 ($ $)) (-15 -4308 ($ $)) (-15 -4321 ($ $)))) 
-((-2262 (((-121) $ $) 18 (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-2148 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 117)) (-4230 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 140)) (-4232 (($ $) 138)) (-2982 (($) 66) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 65)) (-2430 (((-1264) $ |#1| |#1|) 93 (|has| $ (-6 -4603))) (((-1264) $ (-572) (-572)) 170 (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) 151 (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 201) (((-121) $) 195 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-4131 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 192 (|has| $ (-6 -4603))) (($ $) 191 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)) (|has| $ (-6 -4603))))) (-3008 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 202) (($ $) 196 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-1946 (((-121) $ (-769)) 8)) (-4436 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 126 (|has| $ (-6 -4603)))) (-3749 (($ $ $) 147 (|has| $ (-6 -4603)))) (-2656 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 149 (|has| $ (-6 -4603)))) (-4055 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 145 (|has| $ (-6 -4603)))) (-3283 ((|#2| $ |#1| |#2|) 67) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 181 (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-1225 (-572)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 152 (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "last" (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 150 (|has| $ (-6 -4603))) (($ $ "rest" $) 148 (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "first" (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 146 (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "value" (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 125 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 124 (|has| $ (-6 -4603)))) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 42 (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 208)) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 52 (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 167 (|has| $ (-6 -4602)))) (-4066 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 139)) (-1750 (((-3 |#2| "failed") |#1| $) 57)) (-2211 (($) 7 T CONST)) (-2985 (($ $) 193 (|has| $ (-6 -4603)))) (-1656 (($ $) 203)) (-1651 (($ $ (-769)) 134) (($ $) 132)) (-3259 (($ $) 206 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-1643 (($ $) 55 (-1841 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602))) (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 43 (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) 58) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 212) (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 207 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 54 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 51 (|has| $ (-6 -4602))) (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 169 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 166 (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 53 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 50 (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 49 (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 168 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 165 (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 164 (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) 81 (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 182 (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) 82) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) 180)) (-2429 (((-121) $) 184)) (-4014 (((-572) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 200) (((-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 199 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) (((-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) 198 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 30 (|has| $ (-6 -4602))) (((-638 |#2|) $) 73 (|has| $ (-6 -4602))) (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 106 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 115)) (-1303 (((-121) $ $) 123 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-1364 (($ (-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 161)) (-2157 (((-121) $ (-769)) 9)) (-3940 ((|#1| $) 90 (|has| |#1| (-848))) (((-572) $) 172 (|has| (-572) (-848)))) (-1771 (($ $ $) 190 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-3279 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ $) 209) (($ $ $) 205 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-4475 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ $) 204) (($ $ $) 197 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 29 (|has| $ (-6 -4602))) (((-638 |#2|) $) 74 (|has| $ (-6 -4602))) (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 107 (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 27 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-121) |#2| $) 76 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602)))) (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 109 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602))))) (-2026 ((|#1| $) 89 (|has| |#1| (-848))) (((-572) $) 173 (|has| (-572) (-848)))) (-4238 (($ $ $) 189 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 34 (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) 69 (|has| $ (-6 -4603))) (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 102 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 35) (($ (-1 |#2| |#2|) $) 68) (($ (-1 |#2| |#2| |#2|) $ $) 64) (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ $) 158) (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 101)) (-1624 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 217)) (-3524 (((-121) $ (-769)) 10)) (-2699 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 120)) (-3113 (((-121) $) 116)) (-1658 (((-1152) $) 22 (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-3253 (($ $ (-769)) 137) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 135)) (-2760 (((-638 |#1|) $) 59)) (-2365 (((-121) |#1| $) 60)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 36)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 37) (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) 211) (($ $ $ (-572)) 210)) (-2603 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) 154) (($ $ $ (-572)) 153)) (-2739 (((-638 |#1|) $) 87) (((-638 (-572)) $) 175)) (-1601 (((-121) |#1| $) 86) (((-121) (-572) $) 176)) (-2607 (((-1116) $) 21 (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1837 ((|#2| $) 91 (|has| |#1| (-848))) (($ $ (-769)) 131) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 129)) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 48) (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 163)) (-3299 (($ $ |#2|) 92 (|has| $ (-6 -4603))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 171 (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 38)) (-3540 (((-121) $) 183)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 32 (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) 71 (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 104 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 26 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 25 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 24 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 23 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) 80 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) 79 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) 78 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) 77 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 113 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 112 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 111 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 110 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#2| $) 88 (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 174 (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-2957 (((-638 |#2|) $) 85) (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 177)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#2| $ |#1|) 84) ((|#2| $ |#1| |#2|) 83) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 179) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) 178) (($ $ (-1225 (-572))) 157) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "last") 136) (($ $ "rest") 133) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "first") 130) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "value") 118)) (-3537 (((-572) $ $) 121)) (-1535 (($) 46) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 45)) (-2145 (($ $ (-572)) 214) (($ $ (-1225 (-572))) 213)) (-1940 (($ $ (-572)) 156) (($ $ (-1225 (-572))) 155)) (-1791 (((-121) $) 119)) (-2619 (($ $) 143)) (-3316 (($ $) 144 (|has| $ (-6 -4603)))) (-1471 (((-769) $) 142)) (-3622 (($ $) 141)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 31 (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 28 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-769) |#2| $) 75 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#2|) $) 72 (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 108 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 105 (|has| $ (-6 -4602)))) (-2907 (($ $ $ (-572)) 194 (|has| $ (-6 -4603)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545)))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 47) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 162)) (-2977 (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 216) (($ $ $) 215)) (-4500 (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 160) (($ (-638 $)) 159) (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 128) (($ $ $) 127)) (-3972 (((-856) $) 20 (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-4118 (((-638 $) $) 114)) (-3432 (((-121) $ $) 122 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 39)) (-1905 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") |#1| $) 100)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 33 (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) 70 (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 103 (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) 187 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-1338 (((-121) $ $) 186 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-1324 (((-121) $ $) 19 (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1343 (((-121) $ $) 188 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-1334 (((-121) $ $) 185 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-41 |#1| |#2|) (-1290) (-1098) (-1098)) (T -41)) 
-((-1905 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-41 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-2 (|:| -4111 *3) (|:| -4320 *4)))))) 
-(-13 (-1181 |t#1| |t#2|) (-662 (-2 (|:| -4111 |t#1|) (|:| -4320 |t#2|))) (-10 -8 (-15 -1905 ((-3 (-2 (|:| -4111 |t#1|) (|:| -4320 |t#2|)) "failed") |t#1| $)))) 
-(((-39) . T) ((-111 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-105) -1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848))) ((-612 (-856)) -1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848))) ((-155 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-613 (-545)) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))) ((-223 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-229 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-283 (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-283 |#1| |#2|) . T) ((-285 (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-285 |#1| |#2|) . T) ((-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) -12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-305 |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-279 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-379 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-503 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-503 |#2|) . T) ((-605 (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-605 |#1| |#2|) . T) ((-527 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) -12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-527 |#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-609 |#1| |#2|) . T) ((-644 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-662 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-848) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)) ((-1017 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-1098) -1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848))) ((-1142 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-1181 |#1| |#2|) . T) ((-1204) . T) ((-1246 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T)) 
-((-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) 10))) 
-(((-42 |#1| |#2|) (-10 -8 (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) (-43 |#2|) (-174)) (T -42)) 
-NIL 
-(-10 -8 (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 36)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
-(((-43 |#1|) (-1290) (-174)) (T -43)) 
-((-3972 (*1 *1 *2) (-12 (-4 *1 (-43 *2)) (-4 *2 (-174))))) 
-(-13 (-1054) (-713 |t#1|) (-10 -8 (-15 -3972 ($ |t#1|)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 |#1|) . T) ((-722) . T) ((-1060 |#1|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-1585 (((-424 |#1|) |#1|) 38)) (-4304 (((-424 |#1|) |#1|) 27) (((-424 |#1|) |#1| (-638 (-53))) 30)) (-1711 (((-121) |#1|) 54))) 
-(((-44 |#1|) (-10 -7 (-15 -4304 ((-424 |#1|) |#1| (-638 (-53)))) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -1585 ((-424 |#1|) |#1|)) (-15 -1711 ((-121) |#1|))) (-1234 (-53))) (T -44)) 
-((-1711 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-44 *3)) (-4 *3 (-1234 (-53))))) (-1585 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1234 (-53))))) (-4304 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1234 (-53))))) (-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-53))) (-5 *2 (-424 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1234 (-53)))))) 
-(-10 -7 (-15 -4304 ((-424 |#1|) |#1| (-638 (-53)))) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -1585 ((-424 |#1|) |#1|)) (-15 -1711 ((-121) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3970 (((-2 (|:| |num| (-1259 |#2|)) (|:| |den| |#2|)) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| (-413 |#2|) (-368)))) (-3946 (($ $) NIL (|has| (-413 |#2|) (-368)))) (-3686 (((-121) $) NIL (|has| (-413 |#2|) (-368)))) (-1845 (((-685 (-413 |#2|)) (-1259 $)) NIL) (((-685 (-413 |#2|))) NIL)) (-3520 (((-413 |#2|) $) NIL)) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| (-413 |#2|) (-353)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| (-413 |#2|) (-368)))) (-1466 (((-424 $) $) NIL (|has| (-413 |#2|) (-368)))) (-3112 (((-121) $ $) NIL (|has| (-413 |#2|) (-368)))) (-1685 (((-769)) NIL (|has| (-413 |#2|) (-374)))) (-3182 (((-121)) NIL)) (-1688 (((-121) |#1|) NIL) (((-121) |#2|) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| (-413 |#2|) (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-413 |#2|) (-1044 (-413 (-572))))) (((-3 (-413 |#2|) "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| (-413 |#2|) (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| (-413 |#2|) (-1044 (-413 (-572))))) (((-413 |#2|) $) NIL)) (-4337 (($ (-1259 (-413 |#2|)) (-1259 $)) NIL) (($ (-1259 (-413 |#2|))) 57) (($ (-1259 |#2|) |#2|) 124)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-413 |#2|) (-353)))) (-2190 (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-1741 (((-685 (-413 |#2|)) $ (-1259 $)) NIL) (((-685 (-413 |#2|)) $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-413 |#2|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-413 |#2|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-413 |#2|))) (|:| |vec| (-1259 (-413 |#2|)))) (-685 $) (-1259 $)) NIL) (((-685 (-413 |#2|)) (-685 $)) NIL)) (-4442 (((-1259 $) (-1259 $)) NIL)) (-3116 (($ |#3|) NIL) (((-3 $ "failed") (-413 |#3|)) NIL (|has| (-413 |#2|) (-368)))) (-1799 (((-3 $ "failed") $) NIL)) (-3356 (((-638 (-638 |#1|))) NIL (|has| |#1| (-374)))) (-2575 (((-121) |#1| |#1|) NIL)) (-2667 (((-923)) NIL)) (-3286 (($) NIL (|has| (-413 |#2|) (-374)))) (-1906 (((-121)) NIL)) (-1418 (((-121) |#1|) NIL) (((-121) |#2|) NIL)) (-2208 (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| (-413 |#2|) (-368)))) (-3988 (($ $) NIL)) (-2754 (($) NIL (|has| (-413 |#2|) (-353)))) (-1297 (((-121) $) NIL (|has| (-413 |#2|) (-353)))) (-4486 (($ $ (-769)) NIL (|has| (-413 |#2|) (-353))) (($ $) NIL (|has| (-413 |#2|) (-353)))) (-1526 (((-121) $) NIL (|has| (-413 |#2|) (-368)))) (-3377 (((-923) $) NIL (|has| (-413 |#2|) (-353))) (((-834 (-923)) $) NIL (|has| (-413 |#2|) (-353)))) (-3893 (((-121) $) NIL)) (-1602 (((-769)) NIL)) (-2077 (((-1259 $) (-1259 $)) 100)) (-4429 (((-413 |#2|) $) NIL)) (-2380 (((-638 (-959 |#1|)) (-1170)) NIL (|has| |#1| (-368)))) (-3961 (((-3 $ "failed") $) NIL (|has| (-413 |#2|) (-353)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| (-413 |#2|) (-368)))) (-3251 ((|#3| $) NIL (|has| (-413 |#2|) (-368)))) (-3633 (((-923) $) NIL (|has| (-413 |#2|) (-374)))) (-3111 ((|#3| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| (-413 |#2|) (-368))) (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-1658 (((-1152) $) NIL)) (-2988 (((-1264) (-769)) 78)) (-3639 (((-685 (-413 |#2|))) 51)) (-4322 (((-685 (-413 |#2|))) 44)) (-4350 (($ $) NIL (|has| (-413 |#2|) (-368)))) (-2984 (($ (-1259 |#2|) |#2|) 125)) (-2488 (((-685 (-413 |#2|))) 45)) (-3378 (((-685 (-413 |#2|))) 43)) (-2457 (((-2 (|:| |num| (-685 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 122)) (-3697 (((-2 (|:| |num| (-1259 |#2|)) (|:| |den| |#2|)) $) 63)) (-4009 (((-1259 $)) 42)) (-1778 (((-1259 $)) 41)) (-4503 (((-121) $) NIL)) (-3829 (((-121) $) NIL) (((-121) $ |#1|) NIL) (((-121) $ |#2|) NIL)) (-1773 (($) NIL (|has| (-413 |#2|) (-353)) CONST)) (-1763 (($ (-923)) NIL (|has| (-413 |#2|) (-374)))) (-1380 (((-3 |#2| "failed")) NIL)) (-2607 (((-1116) $) NIL)) (-1774 (((-769)) NIL)) (-2307 (($) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| (-413 |#2|) (-368)))) (-3069 (($ (-638 $)) NIL (|has| (-413 |#2|) (-368))) (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| (-413 |#2|) (-353)))) (-4304 (((-424 $) $) NIL (|has| (-413 |#2|) (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-413 |#2|) (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| (-413 |#2|) (-368)))) (-1803 (((-3 $ "failed") $ $) NIL (|has| (-413 |#2|) (-368)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| (-413 |#2|) (-368)))) (-4029 (((-769) $) NIL (|has| (-413 |#2|) (-368)))) (-3587 (((-638 $)) NIL (|has| (-413 |#2|) (-374)))) (-3277 ((|#1| $ |#1| |#1|) NIL)) (-2447 (((-3 |#2| "failed")) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| (-413 |#2|) (-368)))) (-2119 (((-413 |#2|) (-1259 $)) NIL) (((-413 |#2|)) 39)) (-3158 (((-769) $) NIL (|has| (-413 |#2|) (-353))) (((-3 (-769) "failed") $ $) NIL (|has| (-413 |#2|) (-353)))) (-3139 (($ $ (-1 (-413 |#2|) (-413 |#2|)) (-769)) NIL (|has| (-413 |#2|) (-368))) (($ $ (-1 (-413 |#2|) (-413 |#2|))) NIL (|has| (-413 |#2|) (-368))) (($ $ (-1 |#2| |#2|)) 118) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-769)) NIL (-1841 (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353)))) (($ $) NIL (-1841 (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353))))) (-3482 (((-685 (-413 |#2|)) (-1259 $) (-1 (-413 |#2|) (-413 |#2|))) NIL (|has| (-413 |#2|) (-368)))) (-2830 ((|#3|) 50)) (-2278 (($) NIL (|has| (-413 |#2|) (-353)))) (-3160 (((-1259 (-413 |#2|)) $ (-1259 $)) NIL) (((-685 (-413 |#2|)) (-1259 $) (-1259 $)) NIL) (((-1259 (-413 |#2|)) $) 58) (((-685 (-413 |#2|)) (-1259 $)) 101)) (-4081 (((-1259 (-413 |#2|)) $) NIL) (($ (-1259 (-413 |#2|))) NIL) ((|#3| $) NIL) (($ |#3|) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| (-413 |#2|) (-353)))) (-2139 (((-1259 $) (-1259 $)) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 |#2|)) NIL) (($ (-413 (-572))) NIL (-1841 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-1044 (-413 (-572)))))) (($ $) NIL (|has| (-413 |#2|) (-368)))) (-2779 (($ $) NIL (|has| (-413 |#2|) (-353))) (((-3 $ "failed") $) NIL (|has| (-413 |#2|) (-149)))) (-2707 ((|#3| $) NIL)) (-2140 (((-769)) NIL)) (-3640 (((-121)) 37)) (-1825 (((-121) |#1|) 49) (((-121) |#2|) 130)) (-2237 (((-1259 $)) 91)) (-3774 (((-121) $ $) NIL (|has| (-413 |#2|) (-368)))) (-3516 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) NIL)) (-3920 (((-121)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-413 |#2|) (-368)))) (-2378 (($) 16 T CONST)) (-3255 (($) 26 T CONST)) (-1557 (($ $ (-1 (-413 |#2|) (-413 |#2|)) (-769)) NIL (|has| (-413 |#2|) (-368))) (($ $ (-1 (-413 |#2|) (-413 |#2|))) NIL (|has| (-413 |#2|) (-368))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-769)) NIL (-1841 (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353)))) (($ $) NIL (-1841 (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-413 |#2|) (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 |#2|)) NIL) (($ (-413 |#2|) $) NIL) (($ (-413 (-572)) $) NIL (|has| (-413 |#2|) (-368))) (($ $ (-413 (-572))) NIL (|has| (-413 |#2|) (-368))))) 
-(((-45 |#1| |#2| |#3| |#4|) (-13 (-342 |#1| |#2| |#3|) (-10 -7 (-15 -2988 ((-1264) (-769))))) (-368) (-1234 |#1|) (-1234 (-413 |#2|)) |#3|) (T -45)) 
-((-2988 (*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-368)) (-4 *5 (-1234 *4)) (-5 *2 (-1264)) (-5 *1 (-45 *4 *5 *6 *7)) (-4 *6 (-1234 (-413 *5))) (-14 *7 *6)))) 
-(-13 (-342 |#1| |#2| |#3|) (-10 -7 (-15 -2988 ((-1264) (-769))))) 
-((-1744 ((|#2| |#2|) 47)) (-3868 ((|#2| |#2|) 116 (-12 (|has| |#2| (-436 |#1|)) (|has| |#1| (-457)) (|has| |#1| (-848)) (|has| |#1| (-1044 (-572)))))) (-3056 ((|#2| |#2|) 85 (-12 (|has| |#2| (-436 |#1|)) (|has| |#1| (-457)) (|has| |#1| (-848)) (|has| |#1| (-1044 (-572)))))) (-2051 ((|#2| |#2|) 86 (-12 (|has| |#2| (-436 |#1|)) (|has| |#1| (-457)) (|has| |#1| (-848)) (|has| |#1| (-1044 (-572)))))) (-2896 ((|#2| (-123) |#2| (-769)) 73 (-12 (|has| |#2| (-436 |#1|)) (|has| |#1| (-457)) (|has| |#1| (-848)) (|has| |#1| (-1044 (-572)))))) (-1713 (((-1166 |#2|) |#2|) 44)) (-1453 ((|#2| |#2| (-638 (-611 |#2|))) 17) ((|#2| |#2| (-638 |#2|)) 19) ((|#2| |#2| |#2|) 20) ((|#2| |#2|) 15))) 
-(((-46 |#1| |#2|) (-10 -7 (-15 -1744 (|#2| |#2|)) (-15 -1453 (|#2| |#2|)) (-15 -1453 (|#2| |#2| |#2|)) (-15 -1453 (|#2| |#2| (-638 |#2|))) (-15 -1453 (|#2| |#2| (-638 (-611 |#2|)))) (-15 -1713 ((-1166 |#2|) |#2|)) (IF (|has| |#1| (-848)) (IF (|has| |#1| (-457)) (IF (|has| |#1| (-1044 (-572))) (IF (|has| |#2| (-436 |#1|)) (PROGN (-15 -2051 (|#2| |#2|)) (-15 -3056 (|#2| |#2|)) (-15 -3868 (|#2| |#2|)) (-15 -2896 (|#2| (-123) |#2| (-769)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) (-562) (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 |#1| (-611 $)) $)) (-15 -4492 ((-1121 |#1| (-611 $)) $)) (-15 -3972 ($ (-1121 |#1| (-611 $))))))) (T -46)) 
-((-2896 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-123)) (-5 *4 (-769)) (-4 *5 (-457)) (-4 *5 (-848)) (-4 *5 (-1044 (-572))) (-4 *5 (-562)) (-5 *1 (-46 *5 *2)) (-4 *2 (-436 *5)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *5 (-611 $)) $)) (-15 -4492 ((-1121 *5 (-611 $)) $)) (-15 -3972 ($ (-1121 *5 (-611 $))))))))) (-3868 (*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *3 (-848)) (-4 *3 (-1044 (-572))) (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-436 *3)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $))))))))) (-3056 (*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *3 (-848)) (-4 *3 (-1044 (-572))) (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-436 *3)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $))))))))) (-2051 (*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *3 (-848)) (-4 *3 (-1044 (-572))) (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-436 *3)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $))))))))) (-1713 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-1166 *3)) (-5 *1 (-46 *4 *3)) (-4 *3 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *4 (-611 $)) $)) (-15 -4492 ((-1121 *4 (-611 $)) $)) (-15 -3972 ($ (-1121 *4 (-611 $))))))))) (-1453 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-611 *2))) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *4 (-611 $)) $)) (-15 -4492 ((-1121 *4 (-611 $)) $)) (-15 -3972 ($ (-1121 *4 (-611 $))))))) (-4 *4 (-562)) (-5 *1 (-46 *4 *2)))) (-1453 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *4 (-611 $)) $)) (-15 -4492 ((-1121 *4 (-611 $)) $)) (-15 -3972 ($ (-1121 *4 (-611 $))))))) (-4 *4 (-562)) (-5 *1 (-46 *4 *2)))) (-1453 (*1 *2 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $))))))))) (-1453 (*1 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $))))))))) (-1744 (*1 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $)))))))))) 
-(-10 -7 (-15 -1744 (|#2| |#2|)) (-15 -1453 (|#2| |#2|)) (-15 -1453 (|#2| |#2| |#2|)) (-15 -1453 (|#2| |#2| (-638 |#2|))) (-15 -1453 (|#2| |#2| (-638 (-611 |#2|)))) (-15 -1713 ((-1166 |#2|) |#2|)) (IF (|has| |#1| (-848)) (IF (|has| |#1| (-457)) (IF (|has| |#1| (-1044 (-572))) (IF (|has| |#2| (-436 |#1|)) (PROGN (-15 -2051 (|#2| |#2|)) (-15 -3056 (|#2| |#2|)) (-15 -3868 (|#2| |#2|)) (-15 -2896 (|#2| (-123) |#2| (-769)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) 
-((-4304 (((-424 (-1166 |#3|)) (-1166 |#3|) (-638 (-53))) 22) (((-424 |#3|) |#3| (-638 (-53))) 18))) 
-(((-47 |#1| |#2| |#3|) (-10 -7 (-15 -4304 ((-424 |#3|) |#3| (-638 (-53)))) (-15 -4304 ((-424 (-1166 |#3|)) (-1166 |#3|) (-638 (-53))))) (-848) (-794) (-956 (-53) |#2| |#1|)) (T -47)) 
-((-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-53))) (-4 *5 (-848)) (-4 *6 (-794)) (-4 *7 (-956 (-53) *6 *5)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-47 *5 *6 *7)) (-5 *3 (-1166 *7)))) (-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-53))) (-4 *5 (-848)) (-4 *6 (-794)) (-5 *2 (-424 *3)) (-5 *1 (-47 *5 *6 *3)) (-4 *3 (-956 (-53) *6 *5))))) 
-(-10 -7 (-15 -4304 ((-424 |#3|) |#3| (-638 (-53)))) (-15 -4304 ((-424 (-1166 |#3|)) (-1166 |#3|) (-638 (-53))))) 
-((-2053 (((-769) |#2|) 65)) (-3204 (((-769) |#2|) 68)) (-1812 (((-638 |#2|)) 33)) (-1456 (((-769) |#2|) 67)) (-2052 (((-769) |#2|) 64)) (-2060 (((-769) |#2|) 66)) (-1801 (((-638 (-685 |#1|))) 60)) (-1779 (((-638 |#2|)) 55)) (-1747 (((-638 |#2|) |#2|) 43)) (-3017 (((-638 |#2|)) 57)) (-3339 (((-638 |#2|)) 56)) (-3514 (((-638 (-685 |#1|))) 48)) (-2798 (((-638 |#2|)) 54)) (-1687 (((-638 |#2|) |#2|) 42)) (-3199 (((-638 |#2|)) 50)) (-3399 (((-638 (-685 |#1|))) 61)) (-3797 (((-638 |#2|)) 59)) (-2237 (((-1259 |#2|) (-1259 |#2|)) 83 (|has| |#1| (-303))))) 
-(((-48 |#1| |#2|) (-10 -7 (-15 -1456 ((-769) |#2|)) (-15 -3204 ((-769) |#2|)) (-15 -2052 ((-769) |#2|)) (-15 -2053 ((-769) |#2|)) (-15 -2060 ((-769) |#2|)) (-15 -3199 ((-638 |#2|))) (-15 -1687 ((-638 |#2|) |#2|)) (-15 -1747 ((-638 |#2|) |#2|)) (-15 -2798 ((-638 |#2|))) (-15 -1779 ((-638 |#2|))) (-15 -3339 ((-638 |#2|))) (-15 -3017 ((-638 |#2|))) (-15 -3797 ((-638 |#2|))) (-15 -3514 ((-638 (-685 |#1|)))) (-15 -1801 ((-638 (-685 |#1|)))) (-15 -3399 ((-638 (-685 |#1|)))) (-15 -1812 ((-638 |#2|))) (IF (|has| |#1| (-303)) (-15 -2237 ((-1259 |#2|) (-1259 |#2|))) |noBranch|)) (-562) (-423 |#1|)) (T -48)) 
-((-2237 (*1 *2 *2) (-12 (-5 *2 (-1259 *4)) (-4 *4 (-423 *3)) (-4 *3 (-303)) (-4 *3 (-562)) (-5 *1 (-48 *3 *4)))) (-1812 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-3399 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 (-685 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-1801 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 (-685 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-3514 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 (-685 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-3797 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-3017 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-3339 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-1779 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-2798 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-1747 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4)))) (-1687 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4)))) (-3199 (*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3)))) (-2060 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4)))) (-2053 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4)))) (-2052 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4)))) (-3204 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4)))) (-1456 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4))))) 
-(-10 -7 (-15 -1456 ((-769) |#2|)) (-15 -3204 ((-769) |#2|)) (-15 -2052 ((-769) |#2|)) (-15 -2053 ((-769) |#2|)) (-15 -2060 ((-769) |#2|)) (-15 -3199 ((-638 |#2|))) (-15 -1687 ((-638 |#2|) |#2|)) (-15 -1747 ((-638 |#2|) |#2|)) (-15 -2798 ((-638 |#2|))) (-15 -1779 ((-638 |#2|))) (-15 -3339 ((-638 |#2|))) (-15 -3017 ((-638 |#2|))) (-15 -3797 ((-638 |#2|))) (-15 -3514 ((-638 (-685 |#1|)))) (-15 -1801 ((-638 (-685 |#1|)))) (-15 -3399 ((-638 (-685 |#1|)))) (-15 -1812 ((-638 |#2|))) (IF (|has| |#1| (-303)) (-15 -2237 ((-1259 |#2|) (-1259 |#2|))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3029 (((-3 $ "failed")) NIL (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-1354 (((-1259 (-685 |#1|)) (-1259 $)) NIL) (((-1259 (-685 |#1|))) 24)) (-2167 (((-1259 $)) 50)) (-2211 (($) NIL T CONST)) (-4511 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL (|has| |#1| (-562)))) (-2095 (((-3 $ "failed")) NIL (|has| |#1| (-562)))) (-2882 (((-685 |#1|) (-1259 $)) NIL) (((-685 |#1|)) NIL)) (-3487 ((|#1| $) NIL)) (-3700 (((-685 |#1|) $ (-1259 $)) NIL) (((-685 |#1|) $) NIL)) (-2848 (((-3 $ "failed") $) NIL (|has| |#1| (-562)))) (-4535 (((-1166 (-959 |#1|))) NIL (|has| |#1| (-368)))) (-3014 (($ $ (-923)) NIL)) (-3588 ((|#1| $) NIL)) (-2135 (((-1166 |#1|) $) NIL (|has| |#1| (-562)))) (-4146 ((|#1| (-1259 $)) NIL) ((|#1|) NIL)) (-1593 (((-1166 |#1|) $) NIL)) (-2048 (((-121)) 86)) (-4337 (($ (-1259 |#1|) (-1259 $)) NIL) (($ (-1259 |#1|)) NIL)) (-1799 (((-3 $ "failed") $) 14 (|has| |#1| (-562)))) (-2667 (((-923)) 51)) (-4160 (((-121)) NIL)) (-2027 (($ $ (-923)) NIL)) (-1814 (((-121)) NIL)) (-2209 (((-121)) NIL)) (-1648 (((-121)) 88)) (-1903 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL (|has| |#1| (-562)))) (-2036 (((-3 $ "failed")) NIL (|has| |#1| (-562)))) (-1663 (((-685 |#1|) (-1259 $)) NIL) (((-685 |#1|)) NIL)) (-3550 ((|#1| $) NIL)) (-3343 (((-685 |#1|) $ (-1259 $)) NIL) (((-685 |#1|) $) NIL)) (-2046 (((-3 $ "failed") $) NIL (|has| |#1| (-562)))) (-2339 (((-1166 (-959 |#1|))) NIL (|has| |#1| (-368)))) (-3276 (($ $ (-923)) NIL)) (-2340 ((|#1| $) NIL)) (-3665 (((-1166 |#1|) $) NIL (|has| |#1| (-562)))) (-2110 ((|#1| (-1259 $)) NIL) ((|#1|) NIL)) (-1989 (((-1166 |#1|) $) NIL)) (-3602 (((-121)) 85)) (-1658 (((-1152) $) NIL)) (-4219 (((-121)) 92)) (-2395 (((-121)) 91)) (-3046 (((-121)) 93)) (-2607 (((-1116) $) NIL)) (-4128 (((-121)) 87)) (-3277 ((|#1| $ (-572)) 53)) (-3160 (((-1259 |#1|) $ (-1259 $)) 47) (((-685 |#1|) (-1259 $) (-1259 $)) NIL) (((-1259 |#1|) $) 28) (((-685 |#1|) (-1259 $)) NIL)) (-4081 (((-1259 |#1|) $) NIL) (($ (-1259 |#1|)) NIL)) (-3188 (((-638 (-959 |#1|)) (-1259 $)) NIL) (((-638 (-959 |#1|))) NIL)) (-4056 (($ $ $) NIL)) (-2073 (((-121)) 83)) (-3972 (((-856) $) 68) (($ (-1259 |#1|)) 22)) (-2237 (((-1259 $)) 44)) (-4414 (((-638 (-1259 |#1|))) NIL (|has| |#1| (-562)))) (-4250 (($ $ $ $) NIL)) (-2928 (((-121)) 81)) (-1591 (($ (-685 |#1|) $) 18)) (-1397 (($ $ $) NIL)) (-2773 (((-121)) 84)) (-2756 (((-121)) 82)) (-1447 (((-121)) 80)) (-2378 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 75) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-1135 |#2| |#1|) $) 19))) 
-(((-49 |#1| |#2| |#3| |#4|) (-13 (-423 |#1|) (-641 (-1135 |#2| |#1|)) (-10 -8 (-15 -3972 ($ (-1259 |#1|))))) (-368) (-923) (-638 (-1170)) (-1259 (-685 |#1|))) (T -49)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-368)) (-14 *6 (-1259 (-685 *3))) (-5 *1 (-49 *3 *4 *5 *6)) (-14 *4 (-923)) (-14 *5 (-638 (-1170)))))) 
-(-13 (-423 |#1|) (-641 (-1135 |#2| |#1|)) (-10 -8 (-15 -3972 ($ (-1259 |#1|))))) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2148 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-4230 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-4232 (($ $) NIL)) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2430 (((-1264) $ |#1| |#1|) NIL (|has| $ (-6 -4603))) (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (((-121) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-4131 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848))))) (-3008 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-4436 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603)))) (-3749 (($ $ $) 27 (|has| $ (-6 -4603)))) (-2656 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603)))) (-4055 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 29 (|has| $ (-6 -4603)))) (-3283 ((|#2| $ |#1| |#2|) 45) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-1225 (-572)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "last" (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603))) (($ $ "rest" $) NIL (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "first" (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "value" (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-4066 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-1750 (((-3 |#2| "failed") |#1| $) 37)) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1651 (($ $ (-769)) NIL) (($ $) 24)) (-3259 (($ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) 46) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4603))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) NIL) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) NIL)) (-2429 (((-121) $) NIL)) (-4014 (((-572) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (((-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) (((-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 18 (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602))) (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 18 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-1364 (($ (-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 ((|#1| $) NIL (|has| |#1| (-848))) (((-572) $) 32 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-3279 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ $) NIL) (($ $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-4475 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ $) NIL) (($ $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602))) (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-2026 ((|#1| $) NIL (|has| |#1| (-848))) (((-572) $) 34 (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603))) (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ $) NIL) (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-1624 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-2699 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) 41 (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-3253 (($ $ (-769)) NIL) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2760 (((-638 |#1|) $) 20)) (-2365 (((-121) |#1| $) NIL)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL) (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2603 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 |#1|) $) NIL) (((-638 (-572)) $) NIL)) (-1601 (((-121) |#1| $) NIL) (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-1837 ((|#2| $) NIL (|has| |#1| (-848))) (($ $ (-769)) NIL) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 23)) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-3540 (((-121) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-2957 (((-638 |#2|) $) NIL) (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 17)) (-4037 (((-121) $) 16)) (-1665 (($) 13)) (-3277 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ (-572)) NIL) (($ $ (-1225 (-572))) NIL) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "last") NIL) (($ $ "rest") NIL) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "first") NIL) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $ "value") NIL)) (-3537 (((-572) $ $) NIL)) (-1535 (($) 12) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2145 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1791 (((-121) $) NIL)) (-2619 (($ $) NIL)) (-3316 (($ $) NIL (|has| $ (-6 -4603)))) (-1471 (((-769) $) NIL)) (-3622 (($ $) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2977 (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL) (($ $ $) NIL)) (-4500 (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL) (($ (-638 $)) NIL) (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 25) (($ $ $) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-1905 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") |#1| $) 43)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-1343 (((-121) $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-848)))) (-4032 (((-769) $) 22 (|has| $ (-6 -4602))))) 
-(((-50 |#1| |#2|) (-41 |#1| |#2|) (-1098) (-1098)) (T -50)) 
+((-3906 ((|#2| (-1187 |#2|) (-1191)) 42)) (-2791 (((-143) (-143)) 54)) (-2710 (((-1187 |#2|) (-631 |#2|)) 129 (|has| |#1| (-1065 (-592))))) (-1861 ((|#2| |#1| (-592)) 108 (|has| |#1| (-1065 (-592))))) (-2381 ((|#2| (-1187 |#2|) |#2|) 30)) (-4100 (((-877) (-658 |#2|)) 84)) (-3390 ((|#2| |#2|) 125 (|has| |#1| (-1065 (-592))))) (-3038 (((-141) (-143)) 18)) (** ((|#2| |#2| (-433 (-592))) 89 (|has| |#1| (-1065 (-592)))))) 
+(((-36 |#1| |#2|) (-10 -7 (-15 -3906 (|#2| (-1187 |#2|) (-1191))) (-15 -2791 ((-143) (-143))) (-15 -3038 ((-141) (-143))) (-15 -2381 (|#2| (-1187 |#2|) |#2|)) (-15 -4100 ((-877) (-658 |#2|))) (IF (|has| |#1| (-1065 (-592))) (PROGN (-15 ** (|#2| |#2| (-433 (-592)))) (-15 -2710 ((-1187 |#2|) (-631 |#2|))) (-15 -3390 (|#2| |#2|)) (-15 -1861 (|#2| |#1| (-592)))) |noBranch|)) (-13 (-869) (-582)) (-456 |#1|)) (T -36)) 
+((-1861 (*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *2 (-456 *3)) (-5 *1 (-36 *3 *2)) (-4 *3 (-1065 *4)) (-4 *3 (-13 (-869) (-582))))) (-3390 (*1 *2 *2) (-12 (-4 *3 (-1065 (-592))) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-36 *3 *2)) (-4 *2 (-456 *3)))) (-2710 (*1 *2 *3) (-12 (-5 *3 (-631 *5)) (-4 *5 (-456 *4)) (-4 *4 (-1065 (-592))) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-1187 *5)) (-5 *1 (-36 *4 *5)))) (** (*1 *2 *2 *3) (-12 (-5 *3 (-433 (-592))) (-4 *4 (-1065 (-592))) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-36 *4 *2)) (-4 *2 (-456 *4)))) (-4100 (*1 *2 *3) (-12 (-5 *3 (-658 *5)) (-4 *5 (-456 *4)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-877)) (-5 *1 (-36 *4 *5)))) (-2381 (*1 *2 *3 *2) (-12 (-5 *3 (-1187 *2)) (-4 *2 (-456 *4)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-36 *4 *2)))) (-3038 (*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-36 *4 *5)) (-4 *5 (-456 *4)))) (-2791 (*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-36 *3 *4)) (-4 *4 (-456 *3)))) (-3906 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 *2)) (-5 *4 (-1191)) (-4 *2 (-456 *5)) (-5 *1 (-36 *5 *2)) (-4 *5 (-13 (-869) (-582)))))) 
+(-10 -7 (-15 -3906 (|#2| (-1187 |#2|) (-1191))) (-15 -2791 ((-143) (-143))) (-15 -3038 ((-141) (-143))) (-15 -2381 (|#2| (-1187 |#2|) |#2|)) (-15 -4100 ((-877) (-658 |#2|))) (IF (|has| |#1| (-1065 (-592))) (PROGN (-15 ** (|#2| |#2| (-433 (-592)))) (-15 -2710 ((-1187 |#2|) (-631 |#2|))) (-15 -3390 (|#2| |#2|)) (-15 -1861 (|#2| |#1| (-592)))) |noBranch|)) 
+((-1641 (((-141) $ $) 7)) (-3932 ((|#1| $ (-592) |#1|) 14)) (-1328 (((-658 $) (-658 $) (-790)) 20) (((-658 $) (-658 $)) 19)) (-2435 (((-141) $ (-790)) 18) (((-141) $) 17)) (-2382 (((-658 |#1|) $) 13)) (-4200 (($) 29)) (-1363 (((-658 $) $) 24) (((-658 $) $ (-790)) 23)) (-1333 (((-658 |#1|) $) 16)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3927 ((|#1| $ (-592)) 15)) (-4525 (((-944) $) 12)) (-3472 ((|#1| $) 27)) (-2227 (($ $ (-790)) 22) (($ $) 21)) (-1683 (((-877) $) 11) (((-658 |#1|) $) 26) (($ (-658 |#1|)) 25)) (-2703 (($ (-658 |#1|)) 28)) (-3255 (((-141) $ $) 6))) 
+(((-37 |#1|) (-1311) (-388)) (T -37)) 
+((-4200 (*1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-388)))) (-2703 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-37 *3)))) (-3472 (*1 *2 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-388)))) (-1683 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-37 *3)))) (-1363 (*1 *2 *1) (-12 (-4 *3 (-388)) (-5 *2 (-658 *1)) (-4 *1 (-37 *3)))) (-1363 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *4 (-388)) (-5 *2 (-658 *1)) (-4 *1 (-37 *4)))) (-2227 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-37 *3)) (-4 *3 (-388)))) (-2227 (*1 *1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-388)))) (-1328 (*1 *2 *2 *3) (-12 (-5 *2 (-658 *1)) (-5 *3 (-790)) (-4 *1 (-37 *4)) (-4 *4 (-388)))) (-1328 (*1 *2 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-37 *3)) (-4 *3 (-388)))) (-2435 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-37 *4)) (-4 *4 (-388)) (-5 *2 (-141)))) (-2435 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-388)) (-5 *2 (-141)))) (-1333 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-37 *2)) (-4 *2 (-388)))) (-3932 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-37 *2)) (-4 *2 (-388)))) (-2382 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3))))) 
+(-13 (-1117) (-10 -8 (-15 -4200 ($)) (-15 -2703 ($ (-658 |t#1|))) (-15 -3472 (|t#1| $)) (-15 -1683 ((-658 |t#1|) $)) (-15 -1683 ($ (-658 |t#1|))) (-15 -1363 ((-658 $) $)) (-15 -1363 ((-658 $) $ (-790))) (-15 -2227 ($ $ (-790))) (-15 -2227 ($ $)) (-15 -1328 ((-658 $) (-658 $) (-790))) (-15 -1328 ((-658 $) (-658 $))) (-15 -2435 ((-141) $ (-790))) (-15 -2435 ((-141) $)) (-15 -1333 ((-658 |t#1|) $)) (-15 -3927 (|t#1| $ (-592))) (-15 -3932 (|t#1| $ (-592) |t#1|)) (-15 -2382 ((-658 |t#1|) $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T) ((-1117) . T)) 
+((-2126 (((-141) $ (-790)) 16)) (-3001 (($) 10)) (-4345 (((-141) $ (-790)) 15)) (-2554 (((-141) $ (-790)) 14)) (-1724 (((-141) $ $) 8)) (-2943 (((-141) $) 13))) 
+(((-38 |#1|) (-10 -8 (-15 -3001 (|#1|)) (-15 -2126 ((-141) |#1| (-790))) (-15 -4345 ((-141) |#1| (-790))) (-15 -2554 ((-141) |#1| (-790))) (-15 -2943 ((-141) |#1|)) (-15 -1724 ((-141) |#1| |#1|))) (-39)) (T -38)) 
+NIL 
+(-10 -8 (-15 -3001 (|#1|)) (-15 -2126 ((-141) |#1| (-790))) (-15 -4345 ((-141) |#1| (-790))) (-15 -2554 ((-141) |#1| (-790))) (-15 -2943 ((-141) |#1|)) (-15 -1724 ((-141) |#1| |#1|))) 
+((-2126 (((-141) $ (-790)) 8)) (-3001 (($) 7 T CONST)) (-4345 (((-141) $ (-790)) 9)) (-2554 (((-141) $ (-790)) 10)) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-4599 (($ $) 13)) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-39) (-1311)) (T -39)) 
+((-1724 (*1 *2 *1 *1) (-12 (-4 *1 (-39)) (-5 *2 (-141)))) (-4599 (*1 *1 *1) (-4 *1 (-39))) (-2890 (*1 *1) (-4 *1 (-39))) (-2943 (*1 *2 *1) (-12 (-4 *1 (-39)) (-5 *2 (-141)))) (-2554 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-790)) (-5 *2 (-141)))) (-4345 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-790)) (-5 *2 (-141)))) (-2126 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-790)) (-5 *2 (-141)))) (-3001 (*1 *1) (-4 *1 (-39))) (-1699 (*1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-39)) (-5 *2 (-790))))) 
+(-13 (-1225) (-10 -8 (-15 -1724 ((-141) $ $)) (-15 -4599 ($ $)) (-15 -2890 ($)) (-15 -2943 ((-141) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -3001 ($) -4249) (IF (|has| $ (-6 -4625)) (-15 -1699 ((-790) $)) |noBranch|))) 
+(((-1225) . T)) 
+((-1630 (($ $) 11)) (-1617 (($ $) 10)) (-1642 (($ $) 9)) (-2892 (($ $) 8)) (-1636 (($ $) 7)) (-1624 (($ $) 6))) 
+(((-40) (-1311)) (T -40)) 
+((-1630 (*1 *1 *1) (-4 *1 (-40))) (-1617 (*1 *1 *1) (-4 *1 (-40))) (-1642 (*1 *1 *1) (-4 *1 (-40))) (-2892 (*1 *1 *1) (-4 *1 (-40))) (-1636 (*1 *1 *1) (-4 *1 (-40))) (-1624 (*1 *1 *1) (-4 *1 (-40)))) 
+(-13 (-10 -8 (-15 -1624 ($ $)) (-15 -1636 ($ $)) (-15 -2892 ($ $)) (-15 -1642 ($ $)) (-15 -1617 ($ $)) (-15 -1630 ($ $)))) 
+((-1641 (((-141) $ $) 18 (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-2324 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 117)) (-1915 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 140)) (-3188 (($ $) 138)) (-4016 (($) 66) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 65)) (-3898 (((-1285) $ |#1| |#1|) 93 (|has| $ (-6 -4626))) (((-1285) $ (-592) (-592)) 170 (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) 151 (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 201) (((-141) $) 195 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-2831 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 192 (|has| $ (-6 -4626))) (($ $) 191 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)) (|has| $ (-6 -4626))))) (-3960 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 202) (($ $) 196 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-2126 (((-141) $ (-790)) 8)) (-3047 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 126 (|has| $ (-6 -4626)))) (-3153 (($ $ $) 147 (|has| $ (-6 -4626)))) (-4496 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 149 (|has| $ (-6 -4626)))) (-2101 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 145 (|has| $ (-6 -4626)))) (-3932 ((|#2| $ |#1| |#2|) 67) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 181 (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-1246 (-592)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 152 (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "last" (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 150 (|has| $ (-6 -4626))) (($ $ "rest" $) 148 (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "first" (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 146 (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "value" (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 125 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 124 (|has| $ (-6 -4626)))) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 42 (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 208)) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 52 (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 167 (|has| $ (-6 -4625)))) (-1765 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 139)) (-2916 (((-3 |#2| "failed") |#1| $) 57)) (-3001 (($) 7 T CONST)) (-2512 (($ $) 193 (|has| $ (-6 -4626)))) (-1373 (($ $) 203)) (-1366 (($ $ (-790)) 134) (($ $) 132)) (-1461 (($ $) 206 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-1360 (($ $) 55 (-3836 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625))) (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 43 (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) 58) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 212) (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 207 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 54 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 51 (|has| $ (-6 -4625))) (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 169 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 166 (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 53 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 50 (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 49 (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 168 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 165 (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 164 (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) 81 (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 182 (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) 82) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) 180)) (-3868 (((-141) $) 184)) (-1721 (((-592) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 200) (((-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 199 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) (((-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) 198 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 30 (|has| $ (-6 -4625))) (((-658 |#2|) $) 73 (|has| $ (-6 -4625))) (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 106 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 115)) (-3055 (((-141) $ $) 123 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-3242 (($ (-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 161)) (-4345 (((-141) $ (-790)) 9)) (-2261 ((|#1| $) 90 (|has| |#1| (-869))) (((-592) $) 172 (|has| (-592) (-869)))) (-1837 (($ $ $) 190 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-2713 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ $) 209) (($ $ $) 205 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-4491 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ $) 204) (($ $ $) 197 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 29 (|has| $ (-6 -4625))) (((-658 |#2|) $) 74 (|has| $ (-6 -4625))) (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 107 (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 27 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-141) |#2| $) 76 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625)))) (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 109 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625))))) (-1813 ((|#1| $) 89 (|has| |#1| (-869))) (((-592) $) 173 (|has| (-592) (-869)))) (-3319 (($ $ $) 189 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 34 (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) 69 (|has| $ (-6 -4626))) (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 102 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 35) (($ (-1 |#2| |#2|) $) 68) (($ (-1 |#2| |#2| |#2|) $ $) 64) (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ $) 158) (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 101)) (-1333 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 217)) (-2554 (((-141) $ (-790)) 10)) (-4063 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 120)) (-3683 (((-141) $) 116)) (-2685 (((-1173) $) 22 (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4255 (($ $ (-790)) 137) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 135)) (-2840 (((-658 |#1|) $) 59)) (-2396 (((-141) |#1| $) 60)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 36)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 37) (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) 211) (($ $ $ (-592)) 210)) (-3666 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) 154) (($ $ $ (-592)) 153)) (-3708 (((-658 |#1|) $) 87) (((-658 (-592)) $) 175)) (-3780 (((-141) |#1| $) 86) (((-141) (-592) $) 176)) (-2951 (((-1137) $) 21 (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-1918 ((|#2| $) 91 (|has| |#1| (-869))) (($ $ (-790)) 131) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 129)) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 48) (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 163)) (-1892 (($ $ |#2|) 92 (|has| $ (-6 -4626))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 171 (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 38)) (-2955 (((-141) $) 183)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 32 (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) 71 (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 104 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 26 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 25 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 24 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 23 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) 80 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) 79 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) 78 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) 77 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 113 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 112 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 111 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 110 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#2| $) 88 (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 174 (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4210 (((-658 |#2|) $) 85) (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 177)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#2| $ |#1|) 84) ((|#2| $ |#1| |#2|) 83) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 179) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) 178) (($ $ (-1246 (-592))) 157) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "last") 136) (($ $ "rest") 133) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "first") 130) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "value") 118)) (-2920 (((-592) $ $) 121)) (-1653 (($) 46) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 45)) (-4113 (($ $ (-592)) 214) (($ $ (-1246 (-592))) 213)) (-3208 (($ $ (-592)) 156) (($ $ (-1246 (-592))) 155)) (-3228 (((-141) $) 119)) (-2399 (($ $) 143)) (-1337 (($ $) 144 (|has| $ (-6 -4626)))) (-3318 (((-790) $) 142)) (-3184 (($ $) 141)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 31 (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 28 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-790) |#2| $) 75 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#2|) $) 72 (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 108 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 105 (|has| $ (-6 -4625)))) (-2385 (($ $ $ (-592)) 194 (|has| $ (-6 -4626)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565)))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 47) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 162)) (-3619 (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 216) (($ $ $) 215)) (-2266 (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 160) (($ (-658 $)) 159) (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 128) (($ $ $) 127)) (-1683 (((-877) $) 20 (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-2493 (((-658 $) $) 114)) (-2936 (((-141) $ $) 122 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 39)) (-3149 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") |#1| $) 100)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 33 (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) 70 (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 103 (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) 187 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-3273 (((-141) $ $) 186 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-3255 (((-141) $ $) 19 (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-3279 (((-141) $ $) 188 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-3266 (((-141) $ $) 185 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-41 |#1| |#2|) (-1311) (-1119) (-1119)) (T -41)) 
+((-3149 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-41 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-2 (|:| -1350 *3) (|:| -3552 *4)))))) 
+(-13 (-1202 |t#1| |t#2|) (-683 (-2 (|:| -1350 |t#1|) (|:| -3552 |t#2|))) (-10 -8 (-15 -3149 ((-3 (-2 (|:| -1350 |t#1|) (|:| -3552 |t#2|)) "failed") |t#1| $)))) 
+(((-39) . T) ((-131 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-125) -3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869))) ((-632 (-877)) -3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869))) ((-175 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-633 (-565)) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))) ((-243 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-249 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-303 (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-303 |#1| |#2|) . T) ((-305 (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-305 |#1| |#2|) . T) ((-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) -12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-325 |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-299 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-399 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-523 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-523 |#2|) . T) ((-625 (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-625 |#1| |#2|) . T) ((-547 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) -12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-547 |#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-629 |#1| |#2|) . T) ((-664 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-683 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-869) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)) ((-1038 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-1119) -3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869))) ((-1163 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-1202 |#1| |#2|) . T) ((-1225) . T) ((-1267 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T)) 
+((-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) 10))) 
+(((-42 |#1| |#2|) (-10 -8 (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) (-43 |#2|) (-194)) (T -42)) 
+NIL 
+(-10 -8 (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 36)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
+(((-43 |#1|) (-1311) (-194)) (T -43)) 
+((-1683 (*1 *1 *2) (-12 (-4 *1 (-43 *2)) (-4 *2 (-194))))) 
+(-13 (-1075) (-734 |t#1|) (-10 -8 (-15 -1683 ($ |t#1|)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-734 |#1|) . T) ((-743) . T) ((-1081 |#1|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1356 (((-444 |#1|) |#1|) 38)) (-4500 (((-444 |#1|) |#1|) 27) (((-444 |#1|) |#1| (-658 (-53))) 30)) (-1941 (((-141) |#1|) 54))) 
+(((-44 |#1|) (-10 -7 (-15 -4500 ((-444 |#1|) |#1| (-658 (-53)))) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -1356 ((-444 |#1|) |#1|)) (-15 -1941 ((-141) |#1|))) (-1255 (-53))) (T -44)) 
+((-1941 (*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-44 *3)) (-4 *3 (-1255 (-53))))) (-1356 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1255 (-53))))) (-4500 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1255 (-53))))) (-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-53))) (-5 *2 (-444 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1255 (-53)))))) 
+(-10 -7 (-15 -4500 ((-444 |#1|) |#1| (-658 (-53)))) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -1356 ((-444 |#1|) |#1|)) (-15 -1941 ((-141) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4094 (((-2 (|:| |num| (-1280 |#2|)) (|:| |den| |#2|)) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| (-433 |#2|) (-388)))) (-1555 (($ $) NIL (|has| (-433 |#2|) (-388)))) (-1313 (((-141) $) NIL (|has| (-433 |#2|) (-388)))) (-1800 (((-706 (-433 |#2|)) (-1280 $)) NIL) (((-706 (-433 |#2|))) NIL)) (-4529 (((-433 |#2|) $) NIL)) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| (-433 |#2|) (-373)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| (-433 |#2|) (-388)))) (-3164 (((-444 $) $) NIL (|has| (-433 |#2|) (-388)))) (-3652 (((-141) $ $) NIL (|has| (-433 |#2|) (-388)))) (-1403 (((-790)) NIL (|has| (-433 |#2|) (-394)))) (-4578 (((-141)) NIL)) (-2105 (((-141) |#1|) NIL) (((-141) |#2|) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| (-433 |#2|) (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-433 |#2|) (-1065 (-433 (-592))))) (((-3 (-433 |#2|) "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| (-433 |#2|) (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| (-433 |#2|) (-1065 (-433 (-592))))) (((-433 |#2|) $) NIL)) (-1626 (($ (-1280 (-433 |#2|)) (-1280 $)) NIL) (($ (-1280 (-433 |#2|))) 57) (($ (-1280 |#2|) |#2|) 124)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-433 |#2|) (-373)))) (-1586 (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-4493 (((-706 (-433 |#2|)) $ (-1280 $)) NIL) (((-706 (-433 |#2|)) $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-433 |#2|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-433 |#2|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-433 |#2|))) (|:| |vec| (-1280 (-433 |#2|)))) (-706 $) (-1280 $)) NIL) (((-706 (-433 |#2|)) (-706 $)) NIL)) (-1872 (((-1280 $) (-1280 $)) NIL)) (-3657 (($ |#3|) NIL) (((-3 $ "failed") (-433 |#3|)) NIL (|has| (-433 |#2|) (-388)))) (-3371 (((-3 $ "failed") $) NIL)) (-3969 (((-658 (-658 |#1|))) NIL (|has| |#1| (-394)))) (-2619 (((-141) |#1| |#1|) NIL)) (-4175 (((-944)) NIL)) (-4290 (($) NIL (|has| (-433 |#2|) (-394)))) (-1634 (((-141)) NIL)) (-2282 (((-141) |#1|) NIL) (((-141) |#2|) NIL)) (-1599 (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| (-433 |#2|) (-388)))) (-3262 (($ $) NIL)) (-2667 (($) NIL (|has| (-433 |#2|) (-373)))) (-3293 (((-141) $) NIL (|has| (-433 |#2|) (-373)))) (-1525 (($ $ (-790)) NIL (|has| (-433 |#2|) (-373))) (($ $) NIL (|has| (-433 |#2|) (-373)))) (-2802 (((-141) $) NIL (|has| (-433 |#2|) (-388)))) (-4346 (((-944) $) NIL (|has| (-433 |#2|) (-373))) (((-855 (-944)) $) NIL (|has| (-433 |#2|) (-373)))) (-3558 (((-141) $) NIL)) (-3804 (((-790)) NIL)) (-3655 (((-1280 $) (-1280 $)) 100)) (-2793 (((-433 |#2|) $) NIL)) (-2010 (((-658 (-980 |#1|)) (-1191)) NIL (|has| |#1| (-388)))) (-3921 (((-3 $ "failed") $) NIL (|has| (-433 |#2|) (-373)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| (-433 |#2|) (-388)))) (-3504 ((|#3| $) NIL (|has| (-433 |#2|) (-388)))) (-3546 (((-944) $) NIL (|has| (-433 |#2|) (-394)))) (-3650 ((|#3| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| (-433 |#2|) (-388))) (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-2685 (((-1173) $) NIL)) (-2618 (((-1285) (-790)) 78)) (-3757 (((-706 (-433 |#2|))) 51)) (-1346 (((-706 (-433 |#2|))) 44)) (-4552 (($ $) NIL (|has| (-433 |#2|) (-388)))) (-2482 (($ (-1280 |#2|) |#2|) 125)) (-2925 (((-706 (-433 |#2|))) 45)) (-4373 (((-706 (-433 |#2|))) 43)) (-3406 (((-2 (|:| |num| (-706 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 122)) (-1645 (((-2 (|:| |num| (-1280 |#2|)) (|:| |den| |#2|)) $) 63)) (-3720 (((-1280 $)) 42)) (-4023 (((-1280 $)) 41)) (-3717 (((-141) $) NIL)) (-4551 (((-141) $) NIL) (((-141) $ |#1|) NIL) (((-141) $ |#2|) NIL)) (-3703 (($) NIL (|has| (-433 |#2|) (-373)) CONST)) (-1825 (($ (-944)) NIL (|has| (-433 |#2|) (-394)))) (-3560 (((-3 |#2| "failed")) NIL)) (-2951 (((-1137) $) NIL)) (-3918 (((-790)) NIL)) (-2934 (($) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| (-433 |#2|) (-388)))) (-3548 (($ (-658 $)) NIL (|has| (-433 |#2|) (-388))) (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| (-433 |#2|) (-373)))) (-4500 (((-444 $) $) NIL (|has| (-433 |#2|) (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-433 |#2|) (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| (-433 |#2|) (-388)))) (-3616 (((-3 $ "failed") $ $) NIL (|has| (-433 |#2|) (-388)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| (-433 |#2|) (-388)))) (-2769 (((-790) $) NIL (|has| (-433 |#2|) (-388)))) (-1405 (((-658 $)) NIL (|has| (-433 |#2|) (-394)))) (-3927 ((|#1| $ |#1| |#1|) NIL)) (-3143 (((-3 |#2| "failed")) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| (-433 |#2|) (-388)))) (-1482 (((-433 |#2|) (-1280 $)) NIL) (((-433 |#2|)) 39)) (-2177 (((-790) $) NIL (|has| (-433 |#2|) (-373))) (((-3 (-790) "failed") $ $) NIL (|has| (-433 |#2|) (-373)))) (-3644 (($ $ (-1 (-433 |#2|) (-433 |#2|)) (-790)) NIL (|has| (-433 |#2|) (-388))) (($ $ (-1 (-433 |#2|) (-433 |#2|))) NIL (|has| (-433 |#2|) (-388))) (($ $ (-1 |#2| |#2|)) 118) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-790)) NIL (-3836 (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373)))) (($ $) NIL (-3836 (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373))))) (-4174 (((-706 (-433 |#2|)) (-1280 $) (-1 (-433 |#2|) (-433 |#2|))) NIL (|has| (-433 |#2|) (-388)))) (-3390 ((|#3|) 50)) (-3809 (($) NIL (|has| (-433 |#2|) (-373)))) (-2231 (((-1280 (-433 |#2|)) $ (-1280 $)) NIL) (((-706 (-433 |#2|)) (-1280 $) (-1280 $)) NIL) (((-1280 (-433 |#2|)) $) 58) (((-706 (-433 |#2|)) (-1280 $)) 101)) (-1778 (((-1280 (-433 |#2|)) $) NIL) (($ (-1280 (-433 |#2|))) NIL) ((|#3| $) NIL) (($ |#3|) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| (-433 |#2|) (-373)))) (-3985 (((-1280 $) (-1280 $)) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 |#2|)) NIL) (($ (-433 (-592))) NIL (-3836 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-1065 (-433 (-592)))))) (($ $) NIL (|has| (-433 |#2|) (-388)))) (-1517 (($ $) NIL (|has| (-433 |#2|) (-373))) (((-3 $ "failed") $) NIL (|has| (-433 |#2|) (-169)))) (-4198 ((|#3| $) NIL)) (-4010 (((-790)) NIL)) (-2457 (((-141)) 37)) (-2576 (((-141) |#1|) 49) (((-141) |#2|) 130)) (-2195 (((-1280 $)) 91)) (-2537 (((-141) $ $) NIL (|has| (-433 |#2|) (-388)))) (-3748 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) NIL)) (-3059 (((-141)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-433 |#2|) (-388)))) (-3514 (($) 16 T CONST)) (-4257 (($) 26 T CONST)) (-1940 (($ $ (-1 (-433 |#2|) (-433 |#2|)) (-790)) NIL (|has| (-433 |#2|) (-388))) (($ $ (-1 (-433 |#2|) (-433 |#2|))) NIL (|has| (-433 |#2|) (-388))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-790)) NIL (-3836 (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373)))) (($ $) NIL (-3836 (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-433 |#2|) (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 |#2|)) NIL) (($ (-433 |#2|) $) NIL) (($ (-433 (-592)) $) NIL (|has| (-433 |#2|) (-388))) (($ $ (-433 (-592))) NIL (|has| (-433 |#2|) (-388))))) 
+(((-45 |#1| |#2| |#3| |#4|) (-13 (-362 |#1| |#2| |#3|) (-10 -7 (-15 -2618 ((-1285) (-790))))) (-388) (-1255 |#1|) (-1255 (-433 |#2|)) |#3|) (T -45)) 
+((-2618 (*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-388)) (-4 *5 (-1255 *4)) (-5 *2 (-1285)) (-5 *1 (-45 *4 *5 *6 *7)) (-4 *6 (-1255 (-433 *5))) (-14 *7 *6)))) 
+(-13 (-362 |#1| |#2| |#3|) (-10 -7 (-15 -2618 ((-1285) (-790))))) 
+((-4545 ((|#2| |#2|) 47)) (-2908 ((|#2| |#2|) 116 (-12 (|has| |#2| (-456 |#1|)) (|has| |#1| (-477)) (|has| |#1| (-869)) (|has| |#1| (-1065 (-592)))))) (-4481 ((|#2| |#2|) 85 (-12 (|has| |#2| (-456 |#1|)) (|has| |#1| (-477)) (|has| |#1| (-869)) (|has| |#1| (-1065 (-592)))))) (-4243 ((|#2| |#2|) 86 (-12 (|has| |#2| (-456 |#1|)) (|has| |#1| (-477)) (|has| |#1| (-869)) (|has| |#1| (-1065 (-592)))))) (-2222 ((|#2| (-143) |#2| (-790)) 73 (-12 (|has| |#2| (-456 |#1|)) (|has| |#1| (-477)) (|has| |#1| (-869)) (|has| |#1| (-1065 (-592)))))) (-2005 (((-1187 |#2|) |#2|) 44)) (-1423 ((|#2| |#2| (-658 (-631 |#2|))) 17) ((|#2| |#2| (-658 |#2|)) 19) ((|#2| |#2| |#2|) 20) ((|#2| |#2|) 15))) 
+(((-46 |#1| |#2|) (-10 -7 (-15 -4545 (|#2| |#2|)) (-15 -1423 (|#2| |#2|)) (-15 -1423 (|#2| |#2| |#2|)) (-15 -1423 (|#2| |#2| (-658 |#2|))) (-15 -1423 (|#2| |#2| (-658 (-631 |#2|)))) (-15 -2005 ((-1187 |#2|) |#2|)) (IF (|has| |#1| (-869)) (IF (|has| |#1| (-477)) (IF (|has| |#1| (-1065 (-592))) (IF (|has| |#2| (-456 |#1|)) (PROGN (-15 -4243 (|#2| |#2|)) (-15 -4481 (|#2| |#2|)) (-15 -2908 (|#2| |#2|)) (-15 -2222 (|#2| (-143) |#2| (-790)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) (-582) (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 |#1| (-631 $)) $)) (-15 -1456 ((-1142 |#1| (-631 $)) $)) (-15 -1683 ($ (-1142 |#1| (-631 $))))))) (T -46)) 
+((-2222 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-143)) (-5 *4 (-790)) (-4 *5 (-477)) (-4 *5 (-869)) (-4 *5 (-1065 (-592))) (-4 *5 (-582)) (-5 *1 (-46 *5 *2)) (-4 *2 (-456 *5)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *5 (-631 $)) $)) (-15 -1456 ((-1142 *5 (-631 $)) $)) (-15 -1683 ($ (-1142 *5 (-631 $))))))))) (-2908 (*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *3 (-869)) (-4 *3 (-1065 (-592))) (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-456 *3)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $))))))))) (-4481 (*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *3 (-869)) (-4 *3 (-1065 (-592))) (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-456 *3)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $))))))))) (-4243 (*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *3 (-869)) (-4 *3 (-1065 (-592))) (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-456 *3)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $))))))))) (-2005 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-1187 *3)) (-5 *1 (-46 *4 *3)) (-4 *3 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *4 (-631 $)) $)) (-15 -1456 ((-1142 *4 (-631 $)) $)) (-15 -1683 ($ (-1142 *4 (-631 $))))))))) (-1423 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-631 *2))) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *4 (-631 $)) $)) (-15 -1456 ((-1142 *4 (-631 $)) $)) (-15 -1683 ($ (-1142 *4 (-631 $))))))) (-4 *4 (-582)) (-5 *1 (-46 *4 *2)))) (-1423 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *4 (-631 $)) $)) (-15 -1456 ((-1142 *4 (-631 $)) $)) (-15 -1683 ($ (-1142 *4 (-631 $))))))) (-4 *4 (-582)) (-5 *1 (-46 *4 *2)))) (-1423 (*1 *2 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $))))))))) (-1423 (*1 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $))))))))) (-4545 (*1 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $)))))))))) 
+(-10 -7 (-15 -4545 (|#2| |#2|)) (-15 -1423 (|#2| |#2|)) (-15 -1423 (|#2| |#2| |#2|)) (-15 -1423 (|#2| |#2| (-658 |#2|))) (-15 -1423 (|#2| |#2| (-658 (-631 |#2|)))) (-15 -2005 ((-1187 |#2|) |#2|)) (IF (|has| |#1| (-869)) (IF (|has| |#1| (-477)) (IF (|has| |#1| (-1065 (-592))) (IF (|has| |#2| (-456 |#1|)) (PROGN (-15 -4243 (|#2| |#2|)) (-15 -4481 (|#2| |#2|)) (-15 -2908 (|#2| |#2|)) (-15 -2222 (|#2| (-143) |#2| (-790)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) 
+((-4500 (((-444 (-1187 |#3|)) (-1187 |#3|) (-658 (-53))) 22) (((-444 |#3|) |#3| (-658 (-53))) 18))) 
+(((-47 |#1| |#2| |#3|) (-10 -7 (-15 -4500 ((-444 |#3|) |#3| (-658 (-53)))) (-15 -4500 ((-444 (-1187 |#3|)) (-1187 |#3|) (-658 (-53))))) (-869) (-815) (-977 (-53) |#2| |#1|)) (T -47)) 
+((-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-53))) (-4 *5 (-869)) (-4 *6 (-815)) (-4 *7 (-977 (-53) *6 *5)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-47 *5 *6 *7)) (-5 *3 (-1187 *7)))) (-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-53))) (-4 *5 (-869)) (-4 *6 (-815)) (-5 *2 (-444 *3)) (-5 *1 (-47 *5 *6 *3)) (-4 *3 (-977 (-53) *6 *5))))) 
+(-10 -7 (-15 -4500 ((-444 |#3|) |#3| (-658 (-53)))) (-15 -4500 ((-444 (-1187 |#3|)) (-1187 |#3|) (-658 (-53))))) 
+((-4306 (((-790) |#2|) 65)) (-4033 (((-790) |#2|) 68)) (-3639 (((-658 |#2|)) 33)) (-1614 (((-790) |#2|) 67)) (-4271 (((-790) |#2|) 64)) (-3268 (((-790) |#2|) 66)) (-3400 (((-658 (-706 |#1|))) 60)) (-4051 (((-658 |#2|)) 55)) (-1322 (((-658 |#2|) |#2|) 43)) (-2173 (((-658 |#2|)) 57)) (-1733 (((-658 |#2|)) 56)) (-3698 (((-658 (-706 |#1|))) 48)) (-3972 (((-658 |#2|)) 54)) (-2065 (((-658 |#2|) |#2|) 42)) (-4022 (((-658 |#2|)) 50)) (-3617 (((-658 (-706 |#1|))) 61)) (-1949 (((-658 |#2|)) 59)) (-2195 (((-1280 |#2|) (-1280 |#2|)) 83 (|has| |#1| (-323))))) 
+(((-48 |#1| |#2|) (-10 -7 (-15 -1614 ((-790) |#2|)) (-15 -4033 ((-790) |#2|)) (-15 -4271 ((-790) |#2|)) (-15 -4306 ((-790) |#2|)) (-15 -3268 ((-790) |#2|)) (-15 -4022 ((-658 |#2|))) (-15 -2065 ((-658 |#2|) |#2|)) (-15 -1322 ((-658 |#2|) |#2|)) (-15 -3972 ((-658 |#2|))) (-15 -4051 ((-658 |#2|))) (-15 -1733 ((-658 |#2|))) (-15 -2173 ((-658 |#2|))) (-15 -1949 ((-658 |#2|))) (-15 -3698 ((-658 (-706 |#1|)))) (-15 -3400 ((-658 (-706 |#1|)))) (-15 -3617 ((-658 (-706 |#1|)))) (-15 -3639 ((-658 |#2|))) (IF (|has| |#1| (-323)) (-15 -2195 ((-1280 |#2|) (-1280 |#2|))) |noBranch|)) (-582) (-443 |#1|)) (T -48)) 
+((-2195 (*1 *2 *2) (-12 (-5 *2 (-1280 *4)) (-4 *4 (-443 *3)) (-4 *3 (-323)) (-4 *3 (-582)) (-5 *1 (-48 *3 *4)))) (-3639 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-3617 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 (-706 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-3400 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 (-706 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-3698 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 (-706 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-1949 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-2173 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-1733 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-4051 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-3972 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-1322 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4)))) (-2065 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4)))) (-4022 (*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3)))) (-3268 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4)))) (-4306 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4)))) (-4271 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4)))) (-4033 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4)))) (-1614 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4))))) 
+(-10 -7 (-15 -1614 ((-790) |#2|)) (-15 -4033 ((-790) |#2|)) (-15 -4271 ((-790) |#2|)) (-15 -4306 ((-790) |#2|)) (-15 -3268 ((-790) |#2|)) (-15 -4022 ((-658 |#2|))) (-15 -2065 ((-658 |#2|) |#2|)) (-15 -1322 ((-658 |#2|) |#2|)) (-15 -3972 ((-658 |#2|))) (-15 -4051 ((-658 |#2|))) (-15 -1733 ((-658 |#2|))) (-15 -2173 ((-658 |#2|))) (-15 -1949 ((-658 |#2|))) (-15 -3698 ((-658 (-706 |#1|)))) (-15 -3400 ((-658 (-706 |#1|)))) (-15 -3617 ((-658 (-706 |#1|)))) (-15 -3639 ((-658 |#2|))) (IF (|has| |#1| (-323)) (-15 -2195 ((-1280 |#2|) (-1280 |#2|))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4509 (((-3 $ "failed")) NIL (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4061 (((-1280 (-706 |#1|)) (-1280 $)) NIL) (((-1280 (-706 |#1|))) 24)) (-3360 (((-1280 $)) 50)) (-3001 (($) NIL T CONST)) (-2604 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL (|has| |#1| (-582)))) (-2661 (((-3 $ "failed")) NIL (|has| |#1| (-582)))) (-1951 (((-706 |#1|) (-1280 $)) NIL) (((-706 |#1|)) NIL)) (-4282 ((|#1| $) NIL)) (-2302 (((-706 |#1|) $ (-1280 $)) NIL) (((-706 |#1|) $) NIL)) (-2503 (((-3 $ "failed") $) NIL (|has| |#1| (-582)))) (-2120 (((-1187 (-980 |#1|))) NIL (|has| |#1| (-388)))) (-2111 (($ $ (-944)) NIL)) (-1431 ((|#1| $) NIL)) (-3916 (((-1187 |#1|) $) NIL (|has| |#1| (-582)))) (-1874 ((|#1| (-1280 $)) NIL) ((|#1|) NIL)) (-1582 (((-1187 |#1|) $) NIL)) (-4194 (((-141)) 86)) (-1626 (($ (-1280 |#1|) (-1280 $)) NIL) (($ (-1280 |#1|)) NIL)) (-3371 (((-3 $ "failed") $) 14 (|has| |#1| (-582)))) (-4175 (((-944)) 51)) (-2169 (((-141)) NIL)) (-1833 (($ $ (-944)) NIL)) (-3700 (((-141)) NIL)) (-2973 (((-141)) NIL)) (-2467 (((-141)) 88)) (-1563 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL (|has| |#1| (-582)))) (-3994 (((-3 $ "failed")) NIL (|has| |#1| (-582)))) (-2794 (((-706 |#1|) (-1280 $)) NIL) (((-706 |#1|)) NIL)) (-1869 ((|#1| $) NIL)) (-1802 (((-706 |#1|) $ (-1280 $)) NIL) (((-706 |#1|) $) NIL)) (-4158 (((-3 $ "failed") $) NIL (|has| |#1| (-582)))) (-3004 (((-1187 (-980 |#1|))) NIL (|has| |#1| (-388)))) (-2682 (($ $ (-944)) NIL)) (-3061 ((|#1| $) NIL)) (-2013 (((-1187 |#1|) $) NIL (|has| |#1| (-582)))) (-3030 ((|#1| (-1280 $)) NIL) ((|#1|) NIL)) (-2397 (((-1187 |#1|) $) NIL)) (-3847 (((-141)) 85)) (-2685 (((-1173) $) NIL)) (-4106 (((-141)) 92)) (-2339 (((-141)) 91)) (-2297 (((-141)) 93)) (-2951 (((-1137) $) NIL)) (-2716 (((-141)) 87)) (-3927 ((|#1| $ (-592)) 53)) (-2231 (((-1280 |#1|) $ (-1280 $)) 47) (((-706 |#1|) (-1280 $) (-1280 $)) NIL) (((-1280 |#1|) $) 28) (((-706 |#1|) (-1280 $)) NIL)) (-1778 (((-1280 |#1|) $) NIL) (($ (-1280 |#1|)) NIL)) (-1473 (((-658 (-980 |#1|)) (-1280 $)) NIL) (((-658 (-980 |#1|))) NIL)) (-2131 (($ $ $) NIL)) (-3545 (((-141)) 83)) (-1683 (((-877) $) 68) (($ (-1280 |#1|)) 22)) (-2195 (((-1280 $)) 44)) (-3664 (((-658 (-1280 |#1|))) NIL (|has| |#1| (-582)))) (-3667 (($ $ $ $) NIL)) (-1516 (((-141)) 81)) (-4572 (($ (-706 |#1|) $) 18)) (-2844 (($ $ $) NIL)) (-3135 (((-141)) 84)) (-2723 (((-141)) 82)) (-2359 (((-141)) 80)) (-3514 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 75) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-1156 |#2| |#1|) $) 19))) 
+(((-49 |#1| |#2| |#3| |#4|) (-13 (-443 |#1|) (-661 (-1156 |#2| |#1|)) (-10 -8 (-15 -1683 ($ (-1280 |#1|))))) (-388) (-944) (-658 (-1191)) (-1280 (-706 |#1|))) (T -49)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-388)) (-14 *6 (-1280 (-706 *3))) (-5 *1 (-49 *3 *4 *5 *6)) (-14 *4 (-944)) (-14 *5 (-658 (-1191)))))) 
+(-13 (-443 |#1|) (-661 (-1156 |#2| |#1|)) (-10 -8 (-15 -1683 ($ (-1280 |#1|))))) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-2324 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-1915 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3188 (($ $) NIL)) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3898 (((-1285) $ |#1| |#1|) NIL (|has| $ (-6 -4626))) (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (((-141) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-2831 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869))))) (-3960 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3047 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626)))) (-3153 (($ $ $) 27 (|has| $ (-6 -4626)))) (-4496 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626)))) (-2101 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 29 (|has| $ (-6 -4626)))) (-3932 ((|#2| $ |#1| |#2|) 45) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-1246 (-592)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "last" (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626))) (($ $ "rest" $) NIL (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "first" (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "value" (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1765 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2916 (((-3 |#2| "failed") |#1| $) 37)) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1366 (($ $ (-790)) NIL) (($ $) 24)) (-1461 (($ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) 46) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4626))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) NIL) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) NIL)) (-3868 (((-141) $) NIL)) (-1721 (((-592) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (((-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) (((-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 18 (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625))) (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 18 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-3242 (($ (-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 ((|#1| $) NIL (|has| |#1| (-869))) (((-592) $) 32 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-2713 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ $) NIL) (($ $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-4491 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ $) NIL) (($ $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625))) (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-1813 ((|#1| $) NIL (|has| |#1| (-869))) (((-592) $) 34 (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626))) (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ $) NIL) (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-1333 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-4063 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) 41 (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4255 (($ $ (-790)) NIL) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2840 (((-658 |#1|) $) 20)) (-2396 (((-141) |#1| $) NIL)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL) (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3666 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 |#1|) $) NIL) (((-658 (-592)) $) NIL)) (-3780 (((-141) |#1| $) NIL) (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1918 ((|#2| $) NIL (|has| |#1| (-869))) (($ $ (-790)) NIL) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 23)) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2955 (((-141) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4210 (((-658 |#2|) $) NIL) (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 17)) (-2943 (((-141) $) 16)) (-2890 (($) 13)) (-3927 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ (-592)) NIL) (($ $ (-1246 (-592))) NIL) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "last") NIL) (($ $ "rest") NIL) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "first") NIL) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $ "value") NIL)) (-2920 (((-592) $ $) NIL)) (-1653 (($) 12) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-4113 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3228 (((-141) $) NIL)) (-2399 (($ $) NIL)) (-1337 (($ $) NIL (|has| $ (-6 -4626)))) (-3318 (((-790) $) NIL)) (-3184 (($ $) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3619 (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL) (($ $ $) NIL)) (-2266 (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL) (($ (-658 $)) NIL) (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 25) (($ $ $) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3149 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") |#1| $) 43)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-3279 (((-141) $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-869)))) (-1699 (((-790) $) 22 (|has| $ (-6 -4625))))) 
+(((-50 |#1| |#2|) (-41 |#1| |#2|) (-1119) (-1119)) (T -50)) 
 NIL 
 (-41 |#1| |#2|) 
-((-4581 (((-121) $) 12)) (-3828 (($ (-1 |#2| |#2|) $) 21)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ (-413 (-572)) $) 24) (($ $ (-413 (-572))) NIL))) 
-(((-51 |#1| |#2| |#3|) (-10 -8 (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 -4581 ((-121) |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) (-52 |#2| |#3|) (-1054) (-793)) (T -51)) 
-NIL 
-(-10 -8 (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 -4581 ((-121) |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-4383 (($ $) 59)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-4581 (((-121) $) 61)) (-4328 (($ |#1| |#2|) 60)) (-3828 (($ (-1 |#1| |#1|) $) 62)) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562)))) (-4316 ((|#2| $) 63)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 56 (|has| |#1| (-43 (-413 (-572))))) (($ $) 48 (|has| |#1| (-562))) (($ |#1|) 46 (|has| |#1| (-174)))) (-1958 ((|#1| $ |#2|) 58)) (-2779 (((-3 $ "failed") $) 47 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-52 |#1| |#2|) (-1290) (-1054) (-793)) (T -52)) 
-((-4373 (*1 *2 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) (-4368 (*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)))) (-4316 (*1 *2 *1) (-12 (-4 *1 (-52 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-52 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)))) (-4581 (*1 *2 *1) (-12 (-4 *1 (-52 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-121)))) (-4328 (*1 *1 *2 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)))) (-4383 (*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)))) (-1958 (*1 *2 *1 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) (-1379 (*1 *1 *1 *2) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *2 (-368))))) 
-(-13 (-1054) (-120 |t#1| |t#1|) (-10 -8 (-15 -4373 (|t#1| $)) (-15 -4368 ($ $)) (-15 -4316 (|t#2| $)) (-15 -3828 ($ (-1 |t#1| |t#1|) $)) (-15 -4581 ((-121) $)) (-15 -4328 ($ |t#1| |t#2|)) (-15 -4383 ($ $)) (-15 -1958 (|t#1| $ |t#2|)) (IF (|has| |t#1| (-368)) (-15 -1379 ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-174)) (PROGN (-6 (-174)) (-6 (-43 |t#1|))) |noBranch|) (IF (|has| |t#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |t#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |t#1| (-562)) (-6 (-562)) |noBranch|) (IF (|has| |t#1| (-43 (-413 (-572)))) (-6 (-43 (-413 (-572)))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) |has| |#1| (-562)) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-287) |has| |#1| (-562)) ((-562) |has| |#1| (-562)) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) |has| |#1| (-562)) ((-722) . T) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1770 (((-638 $) (-1166 $) (-1170)) NIL) (((-638 $) (-1166 $)) NIL) (((-638 $) (-959 $)) NIL)) (-1627 (($ (-1166 $) (-1170)) NIL) (($ (-1166 $)) NIL) (($ (-959 $)) NIL)) (-1342 (((-121) $) 11)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1337 (((-638 (-611 $)) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1952 (($ $ (-290 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4190 (($ $) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-3584 (((-638 $) (-1166 $) (-1170)) NIL) (((-638 $) (-1166 $)) NIL) (((-638 $) (-959 $)) NIL)) (-3733 (($ (-1166 $) (-1170)) NIL) (($ (-1166 $)) NIL) (($ (-959 $)) NIL)) (-3376 (((-3 (-611 $) "failed") $) NIL) (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL)) (-1318 (((-611 $) $) NIL) (((-572) $) NIL) (((-413 (-572)) $) NIL)) (-2190 (($ $ $) NIL)) (-2284 (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-685 (-572)) (-685 $)) NIL) (((-2 (|:| -1369 (-685 (-413 (-572)))) (|:| |vec| (-1259 (-413 (-572))))) (-685 $) (-1259 $)) NIL) (((-685 (-413 (-572))) (-685 $)) NIL)) (-3116 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-3567 (($ $) NIL) (($ (-638 $)) NIL)) (-4091 (((-638 (-123)) $) NIL)) (-4564 (((-123) (-123)) NIL)) (-3893 (((-121) $) 14)) (-4240 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4487 (((-1121 (-572) (-611 $)) $) NIL)) (-1451 (($ $ (-572)) NIL)) (-4429 (((-1166 $) (-1166 $) (-611 $)) NIL) (((-1166 $) (-1166 $) (-638 (-611 $))) NIL) (($ $ (-611 $)) NIL) (($ $ (-638 (-611 $))) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4127 (((-1166 $) (-611 $)) NIL (|has| $ (-1054)))) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 $ $) (-611 $)) NIL)) (-3614 (((-3 (-611 $) "failed") $) NIL)) (-1629 (($ (-638 $)) NIL) (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-4291 (((-638 (-611 $)) $) NIL)) (-4496 (($ (-123) $) NIL) (($ (-123) (-638 $)) NIL)) (-3291 (((-121) $ (-123)) NIL) (((-121) $ (-1170)) NIL)) (-4350 (($ $) NIL)) (-1455 (((-769) $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ (-638 $)) NIL) (($ $ $) NIL)) (-4319 (((-121) $ $) NIL) (((-121) $ (-1170)) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4247 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4485 (($ $ (-611 $) $) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-1170) (-1 $ (-638 $))) NIL) (($ $ (-1170) (-1 $ $)) NIL) (($ $ (-638 (-123)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-123) (-1 $ (-638 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-4029 (((-769) $) NIL)) (-3277 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-638 $)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-2759 (($ $) NIL) (($ $ $) NIL)) (-3139 (($ $ (-769)) NIL) (($ $) NIL)) (-4492 (((-1121 (-572) (-611 $)) $) NIL)) (-2830 (($ $) NIL (|has| $ (-1054)))) (-4081 (((-385) $) NIL) (((-217) $) NIL) (((-171 (-385)) $) NIL)) (-3972 (((-856) $) NIL) (($ (-611 $)) NIL) (($ (-413 (-572))) NIL) (($ $) NIL) (($ (-572)) NIL) (($ (-1121 (-572) (-611 $))) NIL)) (-2140 (((-769)) NIL)) (-3497 (($ $) NIL) (($ (-638 $)) NIL)) (-3228 (((-121) (-123)) NIL)) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-572)) NIL) (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (-2378 (($) 7 T CONST)) (-3255 (($) 12 T CONST)) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 16)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL)) (-1373 (($ $ $) 15) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-413 (-572))) NIL) (($ $ (-572)) NIL) (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (* (($ (-413 (-572)) $) NIL) (($ $ (-413 (-572))) NIL) (($ $ $) NIL) (($ (-572) $) NIL) (($ (-769) $) NIL) (($ (-923) $) NIL))) 
-(((-53) (-13 (-298) (-27) (-1044 (-572)) (-1044 (-413 (-572))) (-634 (-572)) (-1028) (-634 (-413 (-572))) (-151) (-613 (-171 (-385))) (-227) (-10 -8 (-15 -3972 ($ (-1121 (-572) (-611 $)))) (-15 -4487 ((-1121 (-572) (-611 $)) $)) (-15 -4492 ((-1121 (-572) (-611 $)) $)) (-15 -3116 ($ $)) (-15 -4429 ((-1166 $) (-1166 $) (-611 $))) (-15 -4429 ((-1166 $) (-1166 $) (-638 (-611 $)))) (-15 -4429 ($ $ (-611 $))) (-15 -4429 ($ $ (-638 (-611 $))))))) (T -53)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1121 (-572) (-611 (-53)))) (-5 *1 (-53)))) (-4487 (*1 *2 *1) (-12 (-5 *2 (-1121 (-572) (-611 (-53)))) (-5 *1 (-53)))) (-4492 (*1 *2 *1) (-12 (-5 *2 (-1121 (-572) (-611 (-53)))) (-5 *1 (-53)))) (-3116 (*1 *1 *1) (-5 *1 (-53))) (-4429 (*1 *2 *2 *3) (-12 (-5 *2 (-1166 (-53))) (-5 *3 (-611 (-53))) (-5 *1 (-53)))) (-4429 (*1 *2 *2 *3) (-12 (-5 *2 (-1166 (-53))) (-5 *3 (-638 (-611 (-53)))) (-5 *1 (-53)))) (-4429 (*1 *1 *1 *2) (-12 (-5 *2 (-611 (-53))) (-5 *1 (-53)))) (-4429 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-611 (-53)))) (-5 *1 (-53))))) 
-(-13 (-298) (-27) (-1044 (-572)) (-1044 (-413 (-572))) (-634 (-572)) (-1028) (-634 (-413 (-572))) (-151) (-613 (-171 (-385))) (-227) (-10 -8 (-15 -3972 ($ (-1121 (-572) (-611 $)))) (-15 -4487 ((-1121 (-572) (-611 $)) $)) (-15 -4492 ((-1121 (-572) (-611 $)) $)) (-15 -3116 ($ $)) (-15 -4429 ((-1166 $) (-1166 $) (-611 $))) (-15 -4429 ((-1166 $) (-1166 $) (-638 (-611 $)))) (-15 -4429 ($ $ (-611 $))) (-15 -4429 ($ $ (-638 (-611 $)))))) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 7)) (-1324 (((-121) $ $) NIL))) 
-(((-54) (-1098)) (T -54)) 
-NIL 
-(-1098) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 60)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1804 (((-121) $) 20)) (-3376 (((-3 |#1| "failed") $) 23)) (-1318 ((|#1| $) 24)) (-4383 (($ $) 27)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-4373 ((|#1| $) 21)) (-2021 (($ $) 49)) (-1658 (((-1152) $) NIL)) (-3792 (((-121) $) 28)) (-2607 (((-1116) $) NIL)) (-2307 (($ (-769)) 47)) (-4179 (($ (-638 (-572))) 48)) (-4316 (((-769) $) 29)) (-3972 (((-856) $) 63) (($ (-572)) 44) (($ |#1|) 42)) (-1958 ((|#1| $ $) 19)) (-2140 (((-769)) 46)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 30 T CONST)) (-3255 (($) 14 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 40)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 41) (($ |#1| $) 35))) 
-(((-55 |#1| |#2|) (-13 (-616 |#1|) (-1044 |#1|) (-10 -8 (-15 -4373 (|#1| $)) (-15 -2021 ($ $)) (-15 -4383 ($ $)) (-15 -1958 (|#1| $ $)) (-15 -2307 ($ (-769))) (-15 -4179 ($ (-638 (-572)))) (-15 -3792 ((-121) $)) (-15 -1804 ((-121) $)) (-15 -4316 ((-769) $)) (-15 -3828 ($ (-1 |#1| |#1|) $)))) (-1054) (-638 (-1170))) (T -55)) 
-((-4373 (*1 *2 *1) (-12 (-4 *2 (-1054)) (-5 *1 (-55 *2 *3)) (-14 *3 (-638 (-1170))))) (-2021 (*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-638 (-1170))))) (-4383 (*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-638 (-1170))))) (-1958 (*1 *2 *1 *1) (-12 (-4 *2 (-1054)) (-5 *1 (-55 *2 *3)) (-14 *3 (-638 (-1170))))) (-2307 (*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) (-4179 (*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) (-3792 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) (-1804 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) (-4316 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-55 *3 *4)) (-14 *4 (-638 (-1170)))))) 
-(-13 (-616 |#1|) (-1044 |#1|) (-10 -8 (-15 -4373 (|#1| $)) (-15 -2021 ($ $)) (-15 -4383 ($ $)) (-15 -1958 (|#1| $ $)) (-15 -2307 ($ (-769))) (-15 -4179 ($ (-638 (-572)))) (-15 -3792 ((-121) $)) (-15 -1804 ((-121) $)) (-15 -4316 ((-769) $)) (-15 -3828 ($ (-1 |#1| |#1|) $)))) 
-((-1804 (((-121) (-57)) 13)) (-3376 (((-3 |#1| "failed") (-57)) 21)) (-1318 ((|#1| (-57)) 22)) (-3972 (((-57) |#1|) 18))) 
-(((-56 |#1|) (-10 -7 (-15 -3972 ((-57) |#1|)) (-15 -3376 ((-3 |#1| "failed") (-57))) (-15 -1804 ((-121) (-57))) (-15 -1318 (|#1| (-57)))) (-1204)) (T -56)) 
-((-1318 (*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1204)))) (-1804 (*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *2 (-121)) (-5 *1 (-56 *4)) (-4 *4 (-1204)))) (-3376 (*1 *2 *3) (|partial| -12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1204)))) (-3972 (*1 *2 *3) (-12 (-5 *2 (-57)) (-5 *1 (-56 *3)) (-4 *3 (-1204))))) 
-(-10 -7 (-15 -3972 ((-57) |#1|)) (-15 -3376 ((-3 |#1| "failed") (-57))) (-15 -1804 ((-121) (-57))) (-15 -1318 (|#1| (-57)))) 
-((-2262 (((-121) $ $) NIL)) (-1815 (((-1152) (-121)) 25)) (-2829 (((-856) $) 24)) (-3027 (((-772) $) 12)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2962 (((-856) $) 16)) (-4141 (((-1102) $) 14)) (-3972 (((-856) $) 32)) (-1596 (($ (-1102) (-772)) 33)) (-1324 (((-121) $ $) 18))) 
-(((-57) (-13 (-1098) (-10 -8 (-15 -1596 ($ (-1102) (-772))) (-15 -2962 ((-856) $)) (-15 -2829 ((-856) $)) (-15 -4141 ((-1102) $)) (-15 -3027 ((-772) $)) (-15 -1815 ((-1152) (-121)))))) (T -57)) 
-((-1596 (*1 *1 *2 *3) (-12 (-5 *2 (-1102)) (-5 *3 (-772)) (-5 *1 (-57)))) (-2962 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-57)))) (-2829 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-57)))) (-4141 (*1 *2 *1) (-12 (-5 *2 (-1102)) (-5 *1 (-57)))) (-3027 (*1 *2 *1) (-12 (-5 *2 (-772)) (-5 *1 (-57)))) (-1815 (*1 *2 *3) (-12 (-5 *3 (-121)) (-5 *2 (-1152)) (-5 *1 (-57))))) 
-(-13 (-1098) (-10 -8 (-15 -1596 ($ (-1102) (-772))) (-15 -2962 ((-856) $)) (-15 -2829 ((-856) $)) (-15 -4141 ((-1102) $)) (-15 -3027 ((-772) $)) (-15 -1815 ((-1152) (-121))))) 
-((-3207 (((-1264)) 20)) (-3154 (((-1100 (-1170)) (-1170)) 15)) (-4394 (((-1100 (-1170)) (-1170)) 16)) (-3252 (((-1264)) 19))) 
-(((-58) (-10 -7 (-15 -3154 ((-1100 (-1170)) (-1170))) (-15 -4394 ((-1100 (-1170)) (-1170))) (-15 -3252 ((-1264))) (-15 -3207 ((-1264))))) (T -58)) 
-((-3207 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-58)))) (-3252 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-58)))) (-4394 (*1 *2 *3) (-12 (-5 *2 (-1100 (-1170))) (-5 *1 (-58)) (-5 *3 (-1170)))) (-3154 (*1 *2 *3) (-12 (-5 *2 (-1100 (-1170))) (-5 *1 (-58)) (-5 *3 (-1170))))) 
-(-10 -7 (-15 -3154 ((-1100 (-1170)) (-1170))) (-15 -4394 ((-1100 (-1170)) (-1170))) (-15 -3252 ((-1264))) (-15 -3207 ((-1264)))) 
-((-1591 ((|#2| |#3| (-1 |#2| |#2|) |#2|) 16))) 
-(((-59 |#1| |#2| |#3|) (-10 -7 (-15 -1591 (|#2| |#3| (-1 |#2| |#2|) |#2|))) (-1054) (-641 |#1|) (-850 |#1|)) (T -59)) 
-((-1591 (*1 *2 *3 *4 *2) (-12 (-5 *4 (-1 *2 *2)) (-4 *2 (-641 *5)) (-4 *5 (-1054)) (-5 *1 (-59 *5 *2 *3)) (-4 *3 (-850 *5))))) 
-(-10 -7 (-15 -1591 (|#2| |#3| (-1 |#2| |#2|) |#2|))) 
-((-2757 ((|#3| |#3| (-638 (-1170))) 35)) (-3910 ((|#3| (-638 (-1076 |#1| |#2| |#3|)) |#3| (-923)) 22) ((|#3| (-638 (-1076 |#1| |#2| |#3|)) |#3|) 20))) 
-(((-60 |#1| |#2| |#3|) (-10 -7 (-15 -3910 (|#3| (-638 (-1076 |#1| |#2| |#3|)) |#3|)) (-15 -3910 (|#3| (-638 (-1076 |#1| |#2| |#3|)) |#3| (-923))) (-15 -2757 (|#3| |#3| (-638 (-1170))))) (-1098) (-13 (-1054) (-887 |#1|) (-848) (-613 (-893 |#1|))) (-13 (-436 |#2|) (-887 |#1|) (-613 (-893 |#1|)))) (T -60)) 
-((-2757 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-60 *4 *5 *2)) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))))) (-3910 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-638 (-1076 *5 *6 *2))) (-5 *4 (-923)) (-4 *5 (-1098)) (-4 *6 (-13 (-1054) (-887 *5) (-848) (-613 (-893 *5)))) (-4 *2 (-13 (-436 *6) (-887 *5) (-613 (-893 *5)))) (-5 *1 (-60 *5 *6 *2)))) (-3910 (*1 *2 *3 *2) (-12 (-5 *3 (-638 (-1076 *4 *5 *2))) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))) (-5 *1 (-60 *4 *5 *2))))) 
-(-10 -7 (-15 -3910 (|#3| (-638 (-1076 |#1| |#2| |#3|)) |#3|)) (-15 -3910 (|#3| (-638 (-1076 |#1| |#2| |#3|)) |#3| (-923))) (-15 -2757 (|#3| |#3| (-638 (-1170))))) 
-((-1946 (((-121) $ (-769)) 23)) (-1823 (($ $ (-572) |#3|) 45)) (-1695 (($ $ (-572) |#4|) 49)) (-4267 ((|#3| $ (-572)) 58)) (-2010 (((-638 |#2|) $) 30)) (-2157 (((-121) $ (-769)) 25)) (-3002 (((-121) |#2| $) 53)) (-2435 (($ (-1 |#2| |#2|) $) 37)) (-3828 (($ (-1 |#2| |#2|) $) 36) (($ (-1 |#2| |#2| |#2|) $ $) 39) (($ (-1 |#2| |#2| |#2|) $ $ |#2|) 41)) (-3524 (((-121) $ (-769)) 24)) (-3299 (($ $ |#2|) 34)) (-2109 (((-121) (-1 (-121) |#2|) $) 19)) (-3277 ((|#2| $ (-572) (-572)) NIL) ((|#2| $ (-572) (-572) |#2|) 27)) (-1571 (((-769) (-1 (-121) |#2|) $) 28) (((-769) |#2| $) 55)) (-1607 (($ $) 33)) (-4580 ((|#4| $ (-572)) 61)) (-3972 (((-856) $) 66)) (-3501 (((-121) (-1 (-121) |#2|) $) 18)) (-1324 (((-121) $ $) 52)) (-4032 (((-769) $) 26))) 
-(((-61 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3828 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1| |#2|)) (-15 -3828 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2435 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1695 (|#1| |#1| (-572) |#4|)) (-15 -1823 (|#1| |#1| (-572) |#3|)) (-15 -2010 ((-638 |#2|) |#1|)) (-15 -4580 (|#4| |#1| (-572))) (-15 -4267 (|#3| |#1| (-572))) (-15 -3277 (|#2| |#1| (-572) (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572) (-572))) (-15 -3299 (|#1| |#1| |#2|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -3002 ((-121) |#2| |#1|)) (-15 -1571 ((-769) |#2| |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4032 ((-769) |#1|)) (-15 -1946 ((-121) |#1| (-769))) (-15 -2157 ((-121) |#1| (-769))) (-15 -3524 ((-121) |#1| (-769))) (-15 -1607 (|#1| |#1|))) (-62 |#2| |#3| |#4|) (-1204) (-379 |#2|) (-379 |#2|)) (T -61)) 
-NIL 
-(-10 -8 (-15 -3828 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1| |#2|)) (-15 -3828 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2435 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1695 (|#1| |#1| (-572) |#4|)) (-15 -1823 (|#1| |#1| (-572) |#3|)) (-15 -2010 ((-638 |#2|) |#1|)) (-15 -4580 (|#4| |#1| (-572))) (-15 -4267 (|#3| |#1| (-572))) (-15 -3277 (|#2| |#1| (-572) (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572) (-572))) (-15 -3299 (|#1| |#1| |#2|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -3002 ((-121) |#2| |#1|)) (-15 -1571 ((-769) |#2| |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4032 ((-769) |#1|)) (-15 -1946 ((-121) |#1| (-769))) (-15 -2157 ((-121) |#1| (-769))) (-15 -3524 ((-121) |#1| (-769))) (-15 -1607 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#1| $ (-572) (-572) |#1|) 41)) (-1823 (($ $ (-572) |#2|) 39)) (-1695 (($ $ (-572) |#3|) 38)) (-2211 (($) 7 T CONST)) (-4267 ((|#2| $ (-572)) 43)) (-3037 ((|#1| $ (-572) (-572) |#1|) 40)) (-4212 ((|#1| $ (-572) (-572)) 45)) (-2010 (((-638 |#1|) $) 30)) (-3704 (((-769) $) 48)) (-1364 (($ (-769) (-769) |#1|) 54)) (-3712 (((-769) $) 47)) (-2157 (((-121) $ (-769)) 9)) (-2660 (((-572) $) 52)) (-3092 (((-572) $) 50)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3927 (((-572) $) 51)) (-3227 (((-572) $) 49)) (-2435 (($ (-1 |#1| |#1|) $) 34)) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 37) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) 36)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-3299 (($ $ |#1|) 53)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ (-572) (-572)) 46) ((|#1| $ (-572) (-572) |#1|) 44)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4580 ((|#3| $ (-572)) 42)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-62 |#1| |#2| |#3|) (-1290) (-1204) (-379 |t#1|) (-379 |t#1|)) (T -62)) 
-((-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-1364 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-769)) (-4 *3 (-1204)) (-4 *1 (-62 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3299 (*1 *1 *1 *2) (-12 (-4 *1 (-62 *2 *3 *4)) (-4 *2 (-1204)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (-2660 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-572)))) (-3927 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-572)))) (-3092 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-572)))) (-3227 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-572)))) (-3704 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-769)))) (-3712 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-769)))) (-3277 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-1204)))) (-4212 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-1204)))) (-3277 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1204)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)))) (-4267 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-62 *4 *2 *5)) (-4 *4 (-1204)) (-4 *5 (-379 *4)) (-4 *2 (-379 *4)))) (-4580 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-62 *4 *5 *2)) (-4 *4 (-1204)) (-4 *5 (-379 *4)) (-4 *2 (-379 *4)))) (-2010 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-638 *3)))) (-3283 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1204)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)))) (-3037 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1204)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)))) (-1823 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-572)) (-4 *1 (-62 *4 *3 *5)) (-4 *4 (-1204)) (-4 *3 (-379 *4)) (-4 *5 (-379 *4)))) (-1695 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-572)) (-4 *1 (-62 *4 *5 *3)) (-4 *4 (-1204)) (-4 *5 (-379 *4)) (-4 *3 (-379 *4)))) (-2435 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3828 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3828 (*1 *1 *2 *1 *1 *3) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3))))) 
-(-13 (-503 |t#1|) (-10 -8 (-6 -4603) (-6 -4602) (-15 -1364 ($ (-769) (-769) |t#1|)) (-15 -3299 ($ $ |t#1|)) (-15 -2660 ((-572) $)) (-15 -3927 ((-572) $)) (-15 -3092 ((-572) $)) (-15 -3227 ((-572) $)) (-15 -3704 ((-769) $)) (-15 -3712 ((-769) $)) (-15 -3277 (|t#1| $ (-572) (-572))) (-15 -4212 (|t#1| $ (-572) (-572))) (-15 -3277 (|t#1| $ (-572) (-572) |t#1|)) (-15 -4267 (|t#2| $ (-572))) (-15 -4580 (|t#3| $ (-572))) (-15 -2010 ((-638 |t#1|) $)) (-15 -3283 (|t#1| $ (-572) (-572) |t#1|)) (-15 -3037 (|t#1| $ (-572) (-572) |t#1|)) (-15 -1823 ($ $ (-572) |t#2|)) (-15 -1695 ($ $ (-572) |t#3|)) (-15 -3828 ($ (-1 |t#1| |t#1|) $)) (-15 -2435 ($ (-1 |t#1| |t#1|) $)) (-15 -3828 ($ (-1 |t#1| |t#1| |t#1|) $ $)) (-15 -3828 ($ (-1 |t#1| |t#1| |t#1|) $ $ |t#1|)))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-1911 (((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|) 16)) (-3116 ((|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|) 18)) (-3828 (((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)) 13))) 
-(((-63 |#1| |#2|) (-10 -7 (-15 -1911 ((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3116 (|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3828 ((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)))) (-1204) (-1204)) (T -63)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-64 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-64 *6)) (-5 *1 (-63 *5 *6)))) (-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-64 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-63 *5 *2)))) (-1911 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-64 *6)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-5 *2 (-64 *5)) (-5 *1 (-63 *6 *5))))) 
-(-10 -7 (-15 -1911 ((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3116 (|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3828 ((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) |#1|) 11 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-4014 (((-572) (-1 (-121) |#1|) $) NIL) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098)))) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2061 (($ (-638 |#1|)) 13) (($ (-769) |#1|) 14)) (-1364 (($ (-769) |#1|) 9)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) NIL (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 7)) (-3277 ((|#1| $ (-572) |#1|) NIL) ((|#1| $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-4500 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-64 |#1|) (-13 (-19 |#1|) (-10 -8 (-15 -2061 ($ (-638 |#1|))) (-15 -2061 ($ (-769) |#1|)))) (-1204)) (T -64)) 
-((-2061 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-64 *3)))) (-2061 (*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *1 (-64 *3)) (-4 *3 (-1204))))) 
-(-13 (-19 |#1|) (-10 -8 (-15 -2061 ($ (-638 |#1|))) (-15 -2061 ($ (-769) |#1|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) (-572) |#1|) NIL)) (-1823 (($ $ (-572) (-64 |#1|)) NIL)) (-1695 (($ $ (-572) (-64 |#1|)) NIL)) (-2211 (($) NIL T CONST)) (-4267 (((-64 |#1|) $ (-572)) NIL)) (-3037 ((|#1| $ (-572) (-572) |#1|) NIL)) (-4212 ((|#1| $ (-572) (-572)) NIL)) (-2010 (((-638 |#1|) $) NIL)) (-3704 (((-769) $) NIL)) (-1364 (($ (-769) (-769) |#1|) NIL)) (-3712 (((-769) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-2660 (((-572) $) NIL)) (-3092 (((-572) $) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3927 (((-572) $) NIL)) (-3227 (((-572) $) NIL)) (-2435 (($ (-1 |#1| |#1|) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3299 (($ $ |#1|) NIL)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) (-572)) NIL) ((|#1| $ (-572) (-572) |#1|) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-4580 (((-64 |#1|) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-65 |#1|) (-13 (-62 |#1| (-64 |#1|) (-64 |#1|)) (-10 -7 (-6 -4603))) (-1204)) (T -65)) 
-NIL 
-(-13 (-62 |#1| (-64 |#1|) (-64 |#1|)) (-10 -7 (-6 -4603))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 69) (((-3 $ "failed") (-1259 (-312 (-572)))) 58) (((-3 $ "failed") (-1259 (-959 (-385)))) 91) (((-3 $ "failed") (-1259 (-959 (-572)))) 80) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 47) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 36)) (-1318 (($ (-1259 (-312 (-385)))) 65) (($ (-1259 (-312 (-572)))) 54) (($ (-1259 (-959 (-385)))) 87) (($ (-1259 (-959 (-572)))) 76) (($ (-1259 (-413 (-959 (-385))))) 43) (($ (-1259 (-413 (-959 (-572))))) 29)) (-4355 (((-1264) $) 118)) (-3972 (((-856) $) 111) (($ (-638 (-330))) 100) (($ (-330)) 94) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 97) (($ (-1259 (-339 (-3921 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-3921) (-694)))) 28))) 
-(((-66 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-3921) (-694))))))) (-1170)) (T -66)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-3921) (-694)))) (-5 *1 (-66 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-3921) (-694))))))) 
-((-4355 (((-1264) $) 48) (((-1264)) 49)) (-3972 (((-856) $) 45))) 
-(((-67 |#1|) (-13 (-401) (-10 -7 (-15 -4355 ((-1264))))) (-1170)) (T -67)) 
-((-4355 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-67 *3)) (-14 *3 (-1170))))) 
-(-13 (-401) (-10 -7 (-15 -4355 ((-1264))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 142) (((-3 $ "failed") (-1259 (-312 (-572)))) 132) (((-3 $ "failed") (-1259 (-959 (-385)))) 163) (((-3 $ "failed") (-1259 (-959 (-572)))) 152) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 121) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 110)) (-1318 (($ (-1259 (-312 (-385)))) 138) (($ (-1259 (-312 (-572)))) 128) (($ (-1259 (-959 (-385)))) 159) (($ (-1259 (-959 (-572)))) 148) (($ (-1259 (-413 (-959 (-385))))) 117) (($ (-1259 (-413 (-959 (-572))))) 103)) (-4355 (((-1264) $) 96)) (-3972 (((-856) $) 90) (($ (-638 (-330))) 28) (($ (-330)) 34) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 31) (($ (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694)))) 88))) 
-(((-68 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694))))))) (-1170)) (T -68)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694)))) (-5 *1 (-68 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-312 (-385))) 36) (((-3 $ "failed") (-312 (-572))) 41) (((-3 $ "failed") (-959 (-385))) 46) (((-3 $ "failed") (-959 (-572))) 51) (((-3 $ "failed") (-413 (-959 (-385)))) 31) (((-3 $ "failed") (-413 (-959 (-572)))) 26)) (-1318 (($ (-312 (-385))) 34) (($ (-312 (-572))) 39) (($ (-959 (-385))) 44) (($ (-959 (-572))) 49) (($ (-413 (-959 (-385)))) 29) (($ (-413 (-959 (-572)))) 23)) (-4355 (((-1264) $) 73)) (-3972 (((-856) $) 66) (($ (-638 (-330))) 57) (($ (-330)) 63) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 60) (($ (-339 (-3921 (QUOTE X)) (-3921) (-694))) 22))) 
-(((-69 |#1|) (-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921 (QUOTE X)) (-3921) (-694)))))) (-1170)) (T -69)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-339 (-3921 (QUOTE X)) (-3921) (-694))) (-5 *1 (-69 *3)) (-14 *3 (-1170))))) 
-(-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921 (QUOTE X)) (-3921) (-694)))))) 
-((-3376 (((-3 $ "failed") (-685 (-312 (-385)))) 100) (((-3 $ "failed") (-685 (-312 (-572)))) 89) (((-3 $ "failed") (-685 (-959 (-385)))) 122) (((-3 $ "failed") (-685 (-959 (-572)))) 111) (((-3 $ "failed") (-685 (-413 (-959 (-385))))) 78) (((-3 $ "failed") (-685 (-413 (-959 (-572))))) 67)) (-1318 (($ (-685 (-312 (-385)))) 96) (($ (-685 (-312 (-572)))) 85) (($ (-685 (-959 (-385)))) 118) (($ (-685 (-959 (-572)))) 107) (($ (-685 (-413 (-959 (-385))))) 74) (($ (-685 (-413 (-959 (-572))))) 60)) (-4355 (((-1264) $) 130)) (-3972 (((-856) $) 124) (($ (-638 (-330))) 27) (($ (-330)) 33) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 30) (($ (-685 (-339 (-3921) (-3921 (QUOTE X) (QUOTE HESS)) (-694)))) 53))) 
-(((-70 |#1|) (-13 (-390) (-10 -8 (-15 -3972 ($ (-685 (-339 (-3921) (-3921 (QUOTE X) (QUOTE HESS)) (-694))))))) (-1170)) (T -70)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-685 (-339 (-3921) (-3921 (QUOTE X) (QUOTE HESS)) (-694)))) (-5 *1 (-70 *3)) (-14 *3 (-1170))))) 
-(-13 (-390) (-10 -8 (-15 -3972 ($ (-685 (-339 (-3921) (-3921 (QUOTE X) (QUOTE HESS)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-312 (-385))) 54) (((-3 $ "failed") (-312 (-572))) 59) (((-3 $ "failed") (-959 (-385))) 64) (((-3 $ "failed") (-959 (-572))) 69) (((-3 $ "failed") (-413 (-959 (-385)))) 49) (((-3 $ "failed") (-413 (-959 (-572)))) 44)) (-1318 (($ (-312 (-385))) 52) (($ (-312 (-572))) 57) (($ (-959 (-385))) 62) (($ (-959 (-572))) 67) (($ (-413 (-959 (-385)))) 47) (($ (-413 (-959 (-572)))) 41)) (-4355 (((-1264) $) 78)) (-3972 (((-856) $) 72) (($ (-638 (-330))) 27) (($ (-330)) 33) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 30) (($ (-339 (-3921) (-3921 (QUOTE XC)) (-694))) 38))) 
-(((-71 |#1|) (-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921) (-3921 (QUOTE XC)) (-694)))))) (-1170)) (T -71)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-339 (-3921) (-3921 (QUOTE XC)) (-694))) (-5 *1 (-71 *3)) (-14 *3 (-1170))))) 
-(-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921) (-3921 (QUOTE XC)) (-694)))))) 
-((-4355 (((-1264) $) 63)) (-3972 (((-856) $) 57) (($ (-685 (-694))) 49) (($ (-638 (-330))) 48) (($ (-330)) 55) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 53))) 
-(((-72 |#1|) (-389) (-1170)) (T -72)) 
-NIL 
-(-389) 
-((-4355 (((-1264) $) 64)) (-3972 (((-856) $) 58) (($ (-685 (-694))) 50) (($ (-638 (-330))) 49) (($ (-330)) 52) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 55))) 
-(((-73 |#1|) (-389) (-1170)) (T -73)) 
-NIL 
-(-389) 
-((-4355 (((-1264) $) NIL) (((-1264)) 32)) (-3972 (((-856) $) NIL))) 
-(((-74 |#1|) (-13 (-401) (-10 -7 (-15 -4355 ((-1264))))) (-1170)) (T -74)) 
-((-4355 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-74 *3)) (-14 *3 (-1170))))) 
-(-13 (-401) (-10 -7 (-15 -4355 ((-1264))))) 
-((-4355 (((-1264) $) 68)) (-3972 (((-856) $) 62) (($ (-685 (-694))) 53) (($ (-638 (-330))) 56) (($ (-330)) 59) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 52))) 
-(((-75 |#1|) (-389) (-1170)) (T -75)) 
-NIL 
-(-389) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 98) (((-3 $ "failed") (-1259 (-312 (-572)))) 87) (((-3 $ "failed") (-1259 (-959 (-385)))) 119) (((-3 $ "failed") (-1259 (-959 (-572)))) 108) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 76) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 65)) (-1318 (($ (-1259 (-312 (-385)))) 94) (($ (-1259 (-312 (-572)))) 83) (($ (-1259 (-959 (-385)))) 115) (($ (-1259 (-959 (-572)))) 104) (($ (-1259 (-413 (-959 (-385))))) 72) (($ (-1259 (-413 (-959 (-572))))) 58)) (-4355 (((-1264) $) 133)) (-3972 (((-856) $) 127) (($ (-638 (-330))) 122) (($ (-330)) 125) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 50) (($ (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694)))) 51))) 
-(((-76 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694))))))) (-1170)) (T -76)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694)))) (-5 *1 (-76 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694))))))) 
-((-4355 (((-1264) $) 32) (((-1264)) 31)) (-3972 (((-856) $) 35))) 
-(((-77 |#1|) (-13 (-401) (-10 -7 (-15 -4355 ((-1264))))) (-1170)) (T -77)) 
-((-4355 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-77 *3)) (-14 *3 (-1170))))) 
-(-13 (-401) (-10 -7 (-15 -4355 ((-1264))))) 
-((-4355 (((-1264) $) 62)) (-3972 (((-856) $) 56) (($ (-685 (-694))) 47) (($ (-638 (-330))) 50) (($ (-330)) 53) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 46))) 
-(((-78 |#1|) (-389) (-1170)) (T -78)) 
-NIL 
-(-389) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 119) (((-3 $ "failed") (-1259 (-312 (-572)))) 108) (((-3 $ "failed") (-1259 (-959 (-385)))) 141) (((-3 $ "failed") (-1259 (-959 (-572)))) 130) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 98) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 87)) (-1318 (($ (-1259 (-312 (-385)))) 115) (($ (-1259 (-312 (-572)))) 104) (($ (-1259 (-959 (-385)))) 137) (($ (-1259 (-959 (-572)))) 126) (($ (-1259 (-413 (-959 (-385))))) 94) (($ (-1259 (-413 (-959 (-572))))) 80)) (-4355 (((-1264) $) 73)) (-3972 (((-856) $) 27) (($ (-638 (-330))) 63) (($ (-330)) 59) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 66) (($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) 60))) 
-(((-79 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694))))))) (-1170)) (T -79)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) (-5 *1 (-79 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 125) (((-3 $ "failed") (-1259 (-312 (-572)))) 114) (((-3 $ "failed") (-1259 (-959 (-385)))) 147) (((-3 $ "failed") (-1259 (-959 (-572)))) 136) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 103) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 92)) (-1318 (($ (-1259 (-312 (-385)))) 121) (($ (-1259 (-312 (-572)))) 110) (($ (-1259 (-959 (-385)))) 143) (($ (-1259 (-959 (-572)))) 132) (($ (-1259 (-413 (-959 (-385))))) 99) (($ (-1259 (-413 (-959 (-572))))) 85)) (-4355 (((-1264) $) 78)) (-3972 (((-856) $) 70) (($ (-638 (-330))) NIL) (($ (-330)) NIL) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) NIL) (($ (-1259 (-339 (-3921 (QUOTE X) (QUOTE EPS)) (-3921 (QUOTE -2301)) (-694)))) 65))) 
-(((-80 |#1| |#2| |#3|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X) (QUOTE EPS)) (-3921 (QUOTE -2301)) (-694))))))) (-1170) (-1170) (-1170)) (T -80)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X) (QUOTE EPS)) (-3921 (QUOTE -2301)) (-694)))) (-5 *1 (-80 *3 *4 *5)) (-14 *3 (-1170)) (-14 *4 (-1170)) (-14 *5 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X) (QUOTE EPS)) (-3921 (QUOTE -2301)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 129) (((-3 $ "failed") (-1259 (-312 (-572)))) 118) (((-3 $ "failed") (-1259 (-959 (-385)))) 151) (((-3 $ "failed") (-1259 (-959 (-572)))) 140) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 107) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 96)) (-1318 (($ (-1259 (-312 (-385)))) 125) (($ (-1259 (-312 (-572)))) 114) (($ (-1259 (-959 (-385)))) 147) (($ (-1259 (-959 (-572)))) 136) (($ (-1259 (-413 (-959 (-385))))) 103) (($ (-1259 (-413 (-959 (-572))))) 89)) (-4355 (((-1264) $) 82)) (-3972 (((-856) $) 74) (($ (-638 (-330))) NIL) (($ (-330)) NIL) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) NIL) (($ (-1259 (-339 (-3921 (QUOTE EPS)) (-3921 (QUOTE YA) (QUOTE YB)) (-694)))) 69))) 
-(((-81 |#1| |#2| |#3|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE EPS)) (-3921 (QUOTE YA) (QUOTE YB)) (-694))))))) (-1170) (-1170) (-1170)) (T -81)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE EPS)) (-3921 (QUOTE YA) (QUOTE YB)) (-694)))) (-5 *1 (-81 *3 *4 *5)) (-14 *3 (-1170)) (-14 *4 (-1170)) (-14 *5 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE EPS)) (-3921 (QUOTE YA) (QUOTE YB)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-312 (-385))) 77) (((-3 $ "failed") (-312 (-572))) 82) (((-3 $ "failed") (-959 (-385))) 87) (((-3 $ "failed") (-959 (-572))) 92) (((-3 $ "failed") (-413 (-959 (-385)))) 72) (((-3 $ "failed") (-413 (-959 (-572)))) 67)) (-1318 (($ (-312 (-385))) 75) (($ (-312 (-572))) 80) (($ (-959 (-385))) 85) (($ (-959 (-572))) 90) (($ (-413 (-959 (-385)))) 70) (($ (-413 (-959 (-572)))) 64)) (-4355 (((-1264) $) 61)) (-3972 (((-856) $) 49) (($ (-638 (-330))) 45) (($ (-330)) 55) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 53) (($ (-339 (-3921) (-3921 (QUOTE X)) (-694))) 46))) 
-(((-82 |#1|) (-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921) (-3921 (QUOTE X)) (-694)))))) (-1170)) (T -82)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-339 (-3921) (-3921 (QUOTE X)) (-694))) (-5 *1 (-82 *3)) (-14 *3 (-1170))))) 
-(-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921) (-3921 (QUOTE X)) (-694)))))) 
-((-3376 (((-3 $ "failed") (-312 (-385))) 41) (((-3 $ "failed") (-312 (-572))) 46) (((-3 $ "failed") (-959 (-385))) 51) (((-3 $ "failed") (-959 (-572))) 56) (((-3 $ "failed") (-413 (-959 (-385)))) 36) (((-3 $ "failed") (-413 (-959 (-572)))) 31)) (-1318 (($ (-312 (-385))) 39) (($ (-312 (-572))) 44) (($ (-959 (-385))) 49) (($ (-959 (-572))) 54) (($ (-413 (-959 (-385)))) 34) (($ (-413 (-959 (-572)))) 28)) (-4355 (((-1264) $) 77)) (-3972 (((-856) $) 71) (($ (-638 (-330))) 62) (($ (-330)) 68) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 65) (($ (-339 (-3921) (-3921 (QUOTE X)) (-694))) 27))) 
-(((-83 |#1|) (-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921) (-3921 (QUOTE X)) (-694)))))) (-1170)) (T -83)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-339 (-3921) (-3921 (QUOTE X)) (-694))) (-5 *1 (-83 *3)) (-14 *3 (-1170))))) 
-(-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921) (-3921 (QUOTE X)) (-694)))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 84) (((-3 $ "failed") (-1259 (-312 (-572)))) 73) (((-3 $ "failed") (-1259 (-959 (-385)))) 106) (((-3 $ "failed") (-1259 (-959 (-572)))) 95) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 62) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 51)) (-1318 (($ (-1259 (-312 (-385)))) 80) (($ (-1259 (-312 (-572)))) 69) (($ (-1259 (-959 (-385)))) 102) (($ (-1259 (-959 (-572)))) 91) (($ (-1259 (-413 (-959 (-385))))) 58) (($ (-1259 (-413 (-959 (-572))))) 44)) (-4355 (((-1264) $) 122)) (-3972 (((-856) $) 116) (($ (-638 (-330))) 109) (($ (-330)) 36) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 112) (($ (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694)))) 37))) 
-(((-84 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694))))))) (-1170)) (T -84)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694)))) (-5 *1 (-84 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 137) (((-3 $ "failed") (-1259 (-312 (-572)))) 126) (((-3 $ "failed") (-1259 (-959 (-385)))) 158) (((-3 $ "failed") (-1259 (-959 (-572)))) 147) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 116) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 105)) (-1318 (($ (-1259 (-312 (-385)))) 133) (($ (-1259 (-312 (-572)))) 122) (($ (-1259 (-959 (-385)))) 154) (($ (-1259 (-959 (-572)))) 143) (($ (-1259 (-413 (-959 (-385))))) 112) (($ (-1259 (-413 (-959 (-572))))) 98)) (-4355 (((-1264) $) 91)) (-3972 (((-856) $) 85) (($ (-638 (-330))) 76) (($ (-330)) 83) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 81) (($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) 77))) 
-(((-85 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694))))))) (-1170)) (T -85)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) (-5 *1 (-85 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 73) (((-3 $ "failed") (-1259 (-312 (-572)))) 62) (((-3 $ "failed") (-1259 (-959 (-385)))) 95) (((-3 $ "failed") (-1259 (-959 (-572)))) 84) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 51) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 40)) (-1318 (($ (-1259 (-312 (-385)))) 69) (($ (-1259 (-312 (-572)))) 58) (($ (-1259 (-959 (-385)))) 91) (($ (-1259 (-959 (-572)))) 80) (($ (-1259 (-413 (-959 (-385))))) 47) (($ (-1259 (-413 (-959 (-572))))) 33)) (-4355 (((-1264) $) 121)) (-3972 (((-856) $) 115) (($ (-638 (-330))) 106) (($ (-330)) 112) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 110) (($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) 32))) 
-(((-86 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694))))))) (-1170)) (T -86)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) (-5 *1 (-86 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 90) (((-3 $ "failed") (-1259 (-312 (-572)))) 79) (((-3 $ "failed") (-1259 (-959 (-385)))) 112) (((-3 $ "failed") (-1259 (-959 (-572)))) 101) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 68) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 57)) (-1318 (($ (-1259 (-312 (-385)))) 86) (($ (-1259 (-312 (-572)))) 75) (($ (-1259 (-959 (-385)))) 108) (($ (-1259 (-959 (-572)))) 97) (($ (-1259 (-413 (-959 (-385))))) 64) (($ (-1259 (-413 (-959 (-572))))) 50)) (-4355 (((-1264) $) 43)) (-3972 (((-856) $) 36) (($ (-638 (-330))) 26) (($ (-330)) 29) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 32) (($ (-1259 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694)))) 27))) 
-(((-87 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694))))))) (-1170)) (T -87)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694)))) (-5 *1 (-87 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694))))))) 
-((-3376 (((-3 $ "failed") (-685 (-312 (-385)))) 103) (((-3 $ "failed") (-685 (-312 (-572)))) 92) (((-3 $ "failed") (-685 (-959 (-385)))) 125) (((-3 $ "failed") (-685 (-959 (-572)))) 114) (((-3 $ "failed") (-685 (-413 (-959 (-385))))) 82) (((-3 $ "failed") (-685 (-413 (-959 (-572))))) 71)) (-1318 (($ (-685 (-312 (-385)))) 99) (($ (-685 (-312 (-572)))) 88) (($ (-685 (-959 (-385)))) 121) (($ (-685 (-959 (-572)))) 110) (($ (-685 (-413 (-959 (-385))))) 78) (($ (-685 (-413 (-959 (-572))))) 64)) (-4355 (((-1264) $) 57)) (-3972 (((-856) $) 43) (($ (-638 (-330))) 50) (($ (-330)) 39) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 47) (($ (-685 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694)))) 40))) 
-(((-88 |#1|) (-13 (-390) (-10 -8 (-15 -3972 ($ (-685 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694))))))) (-1170)) (T -88)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-685 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694)))) (-5 *1 (-88 *3)) (-14 *3 (-1170))))) 
-(-13 (-390) (-10 -8 (-15 -3972 ($ (-685 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694))))))) 
-((-3376 (((-3 $ "failed") (-685 (-312 (-385)))) 103) (((-3 $ "failed") (-685 (-312 (-572)))) 92) (((-3 $ "failed") (-685 (-959 (-385)))) 124) (((-3 $ "failed") (-685 (-959 (-572)))) 113) (((-3 $ "failed") (-685 (-413 (-959 (-385))))) 81) (((-3 $ "failed") (-685 (-413 (-959 (-572))))) 70)) (-1318 (($ (-685 (-312 (-385)))) 99) (($ (-685 (-312 (-572)))) 88) (($ (-685 (-959 (-385)))) 120) (($ (-685 (-959 (-572)))) 109) (($ (-685 (-413 (-959 (-385))))) 77) (($ (-685 (-413 (-959 (-572))))) 63)) (-4355 (((-1264) $) 56)) (-3972 (((-856) $) 50) (($ (-638 (-330))) 44) (($ (-330)) 47) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 40) (($ (-685 (-339 (-3921 (QUOTE X)) (-3921) (-694)))) 41))) 
-(((-89 |#1|) (-13 (-390) (-10 -8 (-15 -3972 ($ (-685 (-339 (-3921 (QUOTE X)) (-3921) (-694))))))) (-1170)) (T -89)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-685 (-339 (-3921 (QUOTE X)) (-3921) (-694)))) (-5 *1 (-89 *3)) (-14 *3 (-1170))))) 
-(-13 (-390) (-10 -8 (-15 -3972 ($ (-685 (-339 (-3921 (QUOTE X)) (-3921) (-694))))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 99) (((-3 $ "failed") (-1259 (-312 (-572)))) 88) (((-3 $ "failed") (-1259 (-959 (-385)))) 121) (((-3 $ "failed") (-1259 (-959 (-572)))) 110) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 77) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 66)) (-1318 (($ (-1259 (-312 (-385)))) 95) (($ (-1259 (-312 (-572)))) 84) (($ (-1259 (-959 (-385)))) 117) (($ (-1259 (-959 (-572)))) 106) (($ (-1259 (-413 (-959 (-385))))) 73) (($ (-1259 (-413 (-959 (-572))))) 59)) (-4355 (((-1264) $) 45)) (-3972 (((-856) $) 39) (($ (-638 (-330))) 48) (($ (-330)) 35) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 51) (($ (-1259 (-339 (-3921 (QUOTE X)) (-3921) (-694)))) 36))) 
-(((-90 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X)) (-3921) (-694))))))) (-1170)) (T -90)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X)) (-3921) (-694)))) (-5 *1 (-90 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X)) (-3921) (-694))))))) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 74) (((-3 $ "failed") (-1259 (-312 (-572)))) 63) (((-3 $ "failed") (-1259 (-959 (-385)))) 96) (((-3 $ "failed") (-1259 (-959 (-572)))) 85) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 52) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 41)) (-1318 (($ (-1259 (-312 (-385)))) 70) (($ (-1259 (-312 (-572)))) 59) (($ (-1259 (-959 (-385)))) 92) (($ (-1259 (-959 (-572)))) 81) (($ (-1259 (-413 (-959 (-385))))) 48) (($ (-1259 (-413 (-959 (-572))))) 34)) (-4355 (((-1264) $) 122)) (-3972 (((-856) $) 116) (($ (-638 (-330))) 107) (($ (-330)) 113) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 111) (($ (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694)))) 33))) 
-(((-91 |#1|) (-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694))))))) (-1170)) (T -91)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694)))) (-5 *1 (-91 *3)) (-14 *3 (-1170))))) 
-(-13 (-446) (-10 -8 (-15 -3972 ($ (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694))))))) 
-((-3376 (((-3 $ "failed") (-685 (-312 (-385)))) 105) (((-3 $ "failed") (-685 (-312 (-572)))) 94) (((-3 $ "failed") (-685 (-959 (-385)))) 127) (((-3 $ "failed") (-685 (-959 (-572)))) 116) (((-3 $ "failed") (-685 (-413 (-959 (-385))))) 83) (((-3 $ "failed") (-685 (-413 (-959 (-572))))) 72)) (-1318 (($ (-685 (-312 (-385)))) 101) (($ (-685 (-312 (-572)))) 90) (($ (-685 (-959 (-385)))) 123) (($ (-685 (-959 (-572)))) 112) (($ (-685 (-413 (-959 (-385))))) 79) (($ (-685 (-413 (-959 (-572))))) 65)) (-4355 (((-1264) $) 58)) (-3972 (((-856) $) 52) (($ (-638 (-330))) 42) (($ (-330)) 49) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 47) (($ (-685 (-339 (-3921 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-3921) (-694)))) 43))) 
-(((-92 |#1|) (-13 (-390) (-10 -8 (-15 -3972 ($ (-685 (-339 (-3921 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-3921) (-694))))))) (-1170)) (T -92)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-685 (-339 (-3921 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-3921) (-694)))) (-5 *1 (-92 *3)) (-14 *3 (-1170))))) 
-(-13 (-390) (-10 -8 (-15 -3972 ($ (-685 (-339 (-3921 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-3921) (-694))))))) 
-((-4355 (((-1264) $) 44)) (-3972 (((-856) $) 38) (($ (-1259 (-694))) 88) (($ (-638 (-330))) 29) (($ (-330)) 35) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 32))) 
-(((-93 |#1|) (-445) (-1170)) (T -93)) 
-NIL 
-(-445) 
-((-3376 (((-3 $ "failed") (-312 (-385))) 42) (((-3 $ "failed") (-312 (-572))) 47) (((-3 $ "failed") (-959 (-385))) 52) (((-3 $ "failed") (-959 (-572))) 57) (((-3 $ "failed") (-413 (-959 (-385)))) 37) (((-3 $ "failed") (-413 (-959 (-572)))) 32)) (-1318 (($ (-312 (-385))) 40) (($ (-312 (-572))) 45) (($ (-959 (-385))) 50) (($ (-959 (-572))) 55) (($ (-413 (-959 (-385)))) 35) (($ (-413 (-959 (-572)))) 29)) (-4355 (((-1264) $) 88)) (-3972 (((-856) $) 82) (($ (-638 (-330))) 76) (($ (-330)) 79) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 73) (($ (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694))) 28))) 
-(((-94 |#1|) (-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694)))))) (-1170)) (T -94)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694))) (-5 *1 (-94 *3)) (-14 *3 (-1170))))) 
-(-13 (-402) (-10 -8 (-15 -3972 ($ (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694)))))) 
-((-4054 (((-1259 (-685 |#1|)) (-685 |#1|)) 54)) (-1855 (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 (-638 (-923))))) |#2| (-923)) 44)) (-1504 (((-2 (|:| |minor| (-638 (-923))) (|:| -2352 |#2|) (|:| |minors| (-638 (-638 (-923)))) (|:| |ops| (-638 |#2|))) |#2| (-923)) 62 (|has| |#1| (-368))))) 
-(((-95 |#1| |#2|) (-10 -7 (-15 -1855 ((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 (-638 (-923))))) |#2| (-923))) (-15 -4054 ((-1259 (-685 |#1|)) (-685 |#1|))) (IF (|has| |#1| (-368)) (-15 -1504 ((-2 (|:| |minor| (-638 (-923))) (|:| -2352 |#2|) (|:| |minors| (-638 (-638 (-923)))) (|:| |ops| (-638 |#2|))) |#2| (-923))) |noBranch|)) (-562) (-650 |#1|)) (T -95)) 
-((-1504 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |minor| (-638 (-923))) (|:| -2352 *3) (|:| |minors| (-638 (-638 (-923)))) (|:| |ops| (-638 *3)))) (-5 *1 (-95 *5 *3)) (-5 *4 (-923)) (-4 *3 (-650 *5)))) (-4054 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-1259 (-685 *4))) (-5 *1 (-95 *4 *5)) (-5 *3 (-685 *4)) (-4 *5 (-650 *4)))) (-1855 (*1 *2 *3 *4) (-12 (-4 *5 (-562)) (-5 *2 (-2 (|:| -1369 (-685 *5)) (|:| |vec| (-1259 (-638 (-923)))))) (-5 *1 (-95 *5 *3)) (-5 *4 (-923)) (-4 *3 (-650 *5))))) 
-(-10 -7 (-15 -1855 ((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 (-638 (-923))))) |#2| (-923))) (-15 -4054 ((-1259 (-685 |#1|)) (-685 |#1|))) (IF (|has| |#1| (-368)) (-15 -1504 ((-2 (|:| |minor| (-638 (-923))) (|:| -2352 |#2|) (|:| |minors| (-638 (-638 (-923)))) (|:| |ops| (-638 |#2|))) |#2| (-923))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1615 ((|#1| $) 34)) (-1946 (((-121) $ (-769)) NIL)) (-2211 (($) NIL T CONST)) (-4107 ((|#1| |#1| $) 30)) (-3772 ((|#1| $) 28)) (-2010 (((-638 |#1|) $) 39 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) 43 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 41)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-4221 ((|#1| $) 45)) (-1335 (($ |#1| $) 31)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2232 ((|#1| $) 29)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 16)) (-1665 (($) 38)) (-1564 (((-769) $) 26)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) 15)) (-3972 (((-856) $) 25 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) NIL)) (-3385 (($ (-638 |#1|)) 36)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 13 (|has| |#1| (-1098)))) (-4032 (((-769) $) 10 (|has| $ (-6 -4602))))) 
-(((-96 |#1|) (-13 (-1117 |#1|) (-10 -8 (-15 -3385 ($ (-638 |#1|))) (-15 -3772 (|#1| $)) (-15 -2232 (|#1| $)) (-15 -4107 (|#1| |#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -1615 (|#1| $)) (-15 -1564 ((-769) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -3058 ($ (-638 |#1|))) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -2211 ($)) (-15 -1607 ($ $)) (-15 -3598 ((-121) $ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) (-1098)) (T -96)) 
-((-3598 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) (-1607 (*1 *1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-1665 (*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-4037 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) (-3524 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1098)))) (-2157 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1098)))) (-1946 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1098)))) (-2211 (*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-4032 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-96 *3)))) (-2435 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-1098)) (-5 *1 (-96 *3)))) (-3501 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) (-2109 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) (-1571 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-96 *4)))) (-2010 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) (-1571 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3002 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-1658 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-2607 (*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-1324 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-2262 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3058 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-96 *3)))) (-2232 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-1335 (*1 *1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-4221 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-4107 (*1 *2 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-3772 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-1615 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) (-1564 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) (-3385 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-96 *3))))) 
-(-13 (-1117 |#1|) (-10 -8 (-15 -3385 ($ (-638 |#1|))) (-15 -3772 (|#1| $)) (-15 -2232 (|#1| $)) (-15 -4107 (|#1| |#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -1615 (|#1| $)) (-15 -1564 ((-769) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -3058 ($ (-638 |#1|))) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -2211 ($)) (-15 -1607 ($ $)) (-15 -3598 ((-121) $ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) 
-((-4263 (($ $) 10)) (-4268 (($ $) 12))) 
-(((-97 |#1|) (-10 -8 (-15 -4268 (|#1| |#1|)) (-15 -4263 (|#1| |#1|))) (-98)) (T -97)) 
-NIL 
-(-10 -8 (-15 -4268 (|#1| |#1|)) (-15 -4263 (|#1| |#1|))) 
-((-4251 (($ $) 11)) (-4241 (($ $) 10)) (-4263 (($ $) 9)) (-4268 (($ $) 8)) (-4257 (($ $) 7)) (-4246 (($ $) 6))) 
-(((-98) (-1290)) (T -98)) 
-((-4251 (*1 *1 *1) (-4 *1 (-98))) (-4241 (*1 *1 *1) (-4 *1 (-98))) (-4263 (*1 *1 *1) (-4 *1 (-98))) (-4268 (*1 *1 *1) (-4 *1 (-98))) (-4257 (*1 *1 *1) (-4 *1 (-98))) (-4246 (*1 *1 *1) (-4 *1 (-98)))) 
-(-13 (-10 -8 (-15 -4246 ($ $)) (-15 -4257 ($ $)) (-15 -4268 ($ $)) (-15 -4263 ($ $)) (-15 -4241 ($ $)) (-15 -4251 ($ $)))) 
-((-2262 (((-121) $ $) NIL)) (-1969 (((-385) (-1152) (-385)) 42) (((-385) (-1152) (-1152) (-385)) 41)) (-1424 (((-385) (-385)) 33)) (-3409 (((-1264)) 36)) (-1658 (((-1152) $) NIL)) (-1754 (((-385) (-1152) (-1152)) 46) (((-385) (-1152)) 48)) (-2607 (((-1116) $) NIL)) (-2751 (((-385) (-1152) (-1152)) 47)) (-1859 (((-385) (-1152) (-1152)) 49) (((-385) (-1152)) 50)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-99) (-13 (-1098) (-10 -7 (-15 -1754 ((-385) (-1152) (-1152))) (-15 -1754 ((-385) (-1152))) (-15 -1859 ((-385) (-1152) (-1152))) (-15 -1859 ((-385) (-1152))) (-15 -2751 ((-385) (-1152) (-1152))) (-15 -3409 ((-1264))) (-15 -1424 ((-385) (-385))) (-15 -1969 ((-385) (-1152) (-385))) (-15 -1969 ((-385) (-1152) (-1152) (-385))) (-6 -4602)))) (T -99)) 
-((-1754 (*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99)))) (-1754 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99)))) (-1859 (*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99)))) (-1859 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99)))) (-2751 (*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99)))) (-3409 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-99)))) (-1424 (*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-99)))) (-1969 (*1 *2 *3 *2) (-12 (-5 *2 (-385)) (-5 *3 (-1152)) (-5 *1 (-99)))) (-1969 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-385)) (-5 *3 (-1152)) (-5 *1 (-99))))) 
-(-13 (-1098) (-10 -7 (-15 -1754 ((-385) (-1152) (-1152))) (-15 -1754 ((-385) (-1152))) (-15 -1859 ((-385) (-1152) (-1152))) (-15 -1859 ((-385) (-1152))) (-15 -2751 ((-385) (-1152) (-1152))) (-15 -3409 ((-1264))) (-15 -1424 ((-385) (-385))) (-15 -1969 ((-385) (-1152) (-385))) (-15 -1969 ((-385) (-1152) (-1152) (-385))) (-6 -4602))) 
-NIL 
-(((-100) (-1290)) (T -100)) 
-NIL 
-(-13 (-10 -7 (-6 -4602) (-6 (-4604 "*")) (-6 -4603) (-6 -4599) (-6 -4597) (-6 -4596) (-6 -4595) (-6 -4600) (-6 -4594) (-6 -4593) (-6 -4592) (-6 -4591) (-6 -4590) (-6 -4598) (-6 -4601) (-6 |NullSquare|) (-6 |JacobiIdentity|) (-6 -4589) (-6 -3410))) 
-((-2262 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-1446 (($ (-1 |#1| |#1|)) 25) (($ (-1 |#1| |#1|) (-1 |#1| |#1|)) 24) (($ (-1 |#1| |#1| (-572))) 22)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 14)) (-2607 (((-1116) $) NIL)) (-3277 ((|#1| $ |#1|) 11)) (-3018 (($ $ $) NIL)) (-4056 (($ $ $) NIL)) (-3972 (((-856) $) 20)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-3255 (($) 8 T CONST)) (-1324 (((-121) $ $) 10)) (-1379 (($ $ $) NIL)) (** (($ $ (-923)) 28) (($ $ (-769)) NIL) (($ $ (-572)) 16)) (* (($ $ $) 29))) 
-(((-101 |#1|) (-13 (-482) (-283 |#1| |#1|) (-10 -8 (-15 -1446 ($ (-1 |#1| |#1|))) (-15 -1446 ($ (-1 |#1| |#1|) (-1 |#1| |#1|))) (-15 -1446 ($ (-1 |#1| |#1| (-572)))))) (-1054)) (T -101)) 
-((-1446 (*1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-101 *3)))) (-1446 (*1 *1 *2 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-101 *3)))) (-1446 (*1 *1 *2) (-12 (-5 *2 (-1 *3 *3 (-572))) (-4 *3 (-1054)) (-5 *1 (-101 *3))))) 
-(-13 (-482) (-283 |#1| |#1|) (-10 -8 (-15 -1446 ($ (-1 |#1| |#1|))) (-15 -1446 ($ (-1 |#1| |#1|) (-1 |#1| |#1|))) (-15 -1446 ($ (-1 |#1| |#1| (-572)))))) 
-((-1890 (((-1264) (-1102)) 20)) (-3809 (((-1152) (-1152) (-1152)) 7)) (-1886 (((-1264) (-572) (-1 (-1264) (-1102))) 14))) 
-(((-102) (-10 -7 (-15 -1886 ((-1264) (-572) (-1 (-1264) (-1102)))) (-15 -1890 ((-1264) (-1102))) (-15 -3809 ((-1152) (-1152) (-1152))))) (T -102)) 
-((-3809 (*1 *2 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-102)))) (-1890 (*1 *2 *3) (-12 (-5 *3 (-1102)) (-5 *2 (-1264)) (-5 *1 (-102)))) (-1886 (*1 *2 *3 *4) (-12 (-5 *3 (-572)) (-5 *4 (-1 (-1264) (-1102))) (-5 *2 (-1264)) (-5 *1 (-102))))) 
-(-10 -7 (-15 -1886 ((-1264) (-572) (-1 (-1264) (-1102)))) (-15 -1890 ((-1264) (-1102))) (-15 -3809 ((-1152) (-1152) (-1152)))) 
-((-2854 (((-424 |#2|) |#2| (-638 |#2|)) 10) (((-424 |#2|) |#2| |#2|) 11))) 
-(((-103 |#1| |#2|) (-10 -7 (-15 -2854 ((-424 |#2|) |#2| |#2|)) (-15 -2854 ((-424 |#2|) |#2| (-638 |#2|)))) (-13 (-457) (-151)) (-1234 |#1|)) (T -103)) 
-((-2854 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-13 (-457) (-151))) (-5 *2 (-424 *3)) (-5 *1 (-103 *5 *3)))) (-2854 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-457) (-151))) (-5 *2 (-424 *3)) (-5 *1 (-103 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -2854 ((-424 |#2|) |#2| |#2|)) (-15 -2854 ((-424 |#2|) |#2| (-638 |#2|)))) 
-((-2262 (((-121) $ $) 9))) 
-(((-104 |#1|) (-10 -8 (-15 -2262 ((-121) |#1| |#1|))) (-105)) (T -104)) 
-NIL 
-(-10 -8 (-15 -2262 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1324 (((-121) $ $) 6))) 
-(((-105) (-1290)) (T -105)) 
-((-2262 (*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121)))) (-1324 (*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121))))) 
-(-13 (-10 -8 (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) 13 (|has| $ (-6 -4603)))) (-2107 (($ $ $) NIL (|has| $ (-6 -4603)))) (-3184 (($ $ $) NIL (|has| $ (-6 -4603)))) (-2070 (($ $ (-638 |#1|)) 15)) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) (($ $ "left" $) NIL (|has| $ (-6 -4603))) (($ $ "right" $) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-1862 (($ $) 11)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3486 (($ $ |#1| $) 17)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2069 ((|#1| $ (-1 |#1| |#1| |#1|)) 25) (($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|)) 30)) (-2629 (($ $ |#1| (-1 |#1| |#1| |#1|)) 31) (($ $ |#1| (-1 (-638 |#1|) |#1| |#1| |#1|)) 35)) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1866 (($ $) 10)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) 12)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 9)) (-1665 (($) 16)) (-3277 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-3537 (((-572) $ $) NIL)) (-1791 (((-121) $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4341 (($ (-769) |#1|) 19)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-106 |#1|) (-13 (-135 |#1|) (-10 -8 (-6 -4602) (-6 -4603) (-15 -4341 ($ (-769) |#1|)) (-15 -2070 ($ $ (-638 |#1|))) (-15 -2069 (|#1| $ (-1 |#1| |#1| |#1|))) (-15 -2069 ($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|))) (-15 -2629 ($ $ |#1| (-1 |#1| |#1| |#1|))) (-15 -2629 ($ $ |#1| (-1 (-638 |#1|) |#1| |#1| |#1|))))) (-1098)) (T -106)) 
-((-4341 (*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *1 (-106 *3)) (-4 *3 (-1098)))) (-2070 (*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-106 *3)))) (-2069 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *1 (-106 *2)) (-4 *2 (-1098)))) (-2069 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3 *3 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-106 *3)))) (-2629 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1098)) (-5 *1 (-106 *2)))) (-2629 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 (-638 *2) *2 *2 *2)) (-4 *2 (-1098)) (-5 *1 (-106 *2))))) 
-(-13 (-135 |#1|) (-10 -8 (-6 -4602) (-6 -4603) (-15 -4341 ($ (-769) |#1|)) (-15 -2070 ($ $ (-638 |#1|))) (-15 -2069 (|#1| $ (-1 |#1| |#1| |#1|))) (-15 -2069 ($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|))) (-15 -2629 ($ $ |#1| (-1 |#1| |#1| |#1|))) (-15 -2629 ($ $ |#1| (-1 (-638 |#1|) |#1| |#1| |#1|))))) 
-((-4525 (((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|)) 20)) (-2062 (((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|)) 17)) (-4068 (((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|)) 21))) 
-(((-107 |#1|) (-10 -7 (-15 -2062 ((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|))) (-15 -4525 ((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|))) (-15 -4068 ((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|)))) (-1054)) (T -107)) 
-((-4068 (*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-1 (-638 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-638 *4)))) (-4525 (*1 *2 *3 *3 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-1 (-638 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-638 *4)))) (-2062 (*1 *2 *3 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-1 (-638 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-638 *4))))) 
-(-10 -7 (-15 -2062 ((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|))) (-15 -4525 ((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|))) (-15 -4068 ((-1 (-638 |#1|) |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|) (-638 |#1|)))) 
-((-2822 ((|#3| |#2| |#2|) 28)) (-1893 ((|#1| |#2| |#2|) 36 (|has| |#1| (-6 (-4604 "*"))))) (-3198 ((|#3| |#2| |#2|) 29)) (-1934 ((|#1| |#2|) 40 (|has| |#1| (-6 (-4604 "*")))))) 
-(((-108 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2822 (|#3| |#2| |#2|)) (-15 -3198 (|#3| |#2| |#2|)) (IF (|has| |#1| (-6 (-4604 "*"))) (PROGN (-15 -1893 (|#1| |#2| |#2|)) (-15 -1934 (|#1| |#2|))) |noBranch|)) (-1054) (-1234 |#1|) (-683 |#1| |#4| |#5|) (-379 |#1|) (-379 |#1|)) (T -108)) 
-((-1934 (*1 *2 *3) (-12 (|has| *2 (-6 (-4604 "*"))) (-4 *5 (-379 *2)) (-4 *6 (-379 *2)) (-4 *2 (-1054)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1234 *2)) (-4 *4 (-683 *2 *5 *6)))) (-1893 (*1 *2 *3 *3) (-12 (|has| *2 (-6 (-4604 "*"))) (-4 *5 (-379 *2)) (-4 *6 (-379 *2)) (-4 *2 (-1054)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1234 *2)) (-4 *4 (-683 *2 *5 *6)))) (-3198 (*1 *2 *3 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1234 *4)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)))) (-2822 (*1 *2 *3 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1234 *4)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4))))) 
-(-10 -7 (-15 -2822 (|#3| |#2| |#2|)) (-15 -3198 (|#3| |#2| |#2|)) (IF (|has| |#1| (-6 (-4604 "*"))) (PROGN (-15 -1893 (|#1| |#2| |#2|)) (-15 -1934 (|#1| |#2|))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1917 (((-638 (-1170))) 32)) (-3392 (((-2 (|:| |zeros| (-1150 (-217))) (|:| |ones| (-1150 (-217))) (|:| |singularities| (-1150 (-217)))) (-1170)) 35)) (-1324 (((-121) $ $) NIL))) 
-(((-109) (-13 (-1098) (-10 -7 (-15 -1917 ((-638 (-1170)))) (-15 -3392 ((-2 (|:| |zeros| (-1150 (-217))) (|:| |ones| (-1150 (-217))) (|:| |singularities| (-1150 (-217)))) (-1170))) (-6 -4602)))) (T -109)) 
-((-1917 (*1 *2) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-109)))) (-3392 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-2 (|:| |zeros| (-1150 (-217))) (|:| |ones| (-1150 (-217))) (|:| |singularities| (-1150 (-217))))) (-5 *1 (-109))))) 
-(-13 (-1098) (-10 -7 (-15 -1917 ((-638 (-1170)))) (-15 -3392 ((-2 (|:| |zeros| (-1150 (-217))) (|:| |ones| (-1150 (-217))) (|:| |singularities| (-1150 (-217)))) (-1170))) (-6 -4602))) 
-((-3058 (($ (-638 |#2|)) 11))) 
-(((-110 |#1| |#2|) (-10 -8 (-15 -3058 (|#1| (-638 |#2|)))) (-111 |#2|) (-1204)) (T -110)) 
-NIL 
-(-10 -8 (-15 -3058 (|#1| (-638 |#2|)))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-2211 (($) 7 T CONST)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-111 |#1|) (-1290) (-1204)) (T -111)) 
-((-3058 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-4 *1 (-111 *3)))) (-2232 (*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1204)))) (-1335 (*1 *1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1204)))) (-4221 (*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1204))))) 
-(-13 (-503 |t#1|) (-10 -8 (-6 -4603) (-15 -3058 ($ (-638 |t#1|))) (-15 -2232 (|t#1| $)) (-15 -1335 ($ |t#1| $)) (-15 -4221 (|t#1| $)))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 (((-572) $) NIL (|has| (-572) (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| (-572) (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL (|has| (-572) (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-572) (-1044 (-572)))) (((-3 (-572) "failed") $) NIL (|has| (-572) (-1044 (-572))))) (-1318 (((-572) $) NIL) (((-1170) $) NIL (|has| (-572) (-1044 (-1170)))) (((-413 (-572)) $) NIL (|has| (-572) (-1044 (-572)))) (((-572) $) NIL (|has| (-572) (-1044 (-572))))) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-572) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-572) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-685 (-572)) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-572) (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) NIL (|has| (-572) (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| (-572) (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| (-572) (-887 (-385))))) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL)) (-4487 (((-572) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| (-572) (-1144)))) (-4472 (((-121) $) NIL (|has| (-572) (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-572) (-848)))) (-3828 (($ (-1 (-572) (-572)) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-572) (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| (-572) (-303))) (((-413 (-572)) $) NIL)) (-1716 (((-572) $) NIL (|has| (-572) (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 (-572)) (-638 (-572))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-572) (-572)) NIL (|has| (-572) (-305 (-572)))) (($ $ (-290 (-572))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-638 (-290 (-572)))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-638 (-1170)) (-638 (-572))) NIL (|has| (-572) (-527 (-1170) (-572)))) (($ $ (-1170) (-572)) NIL (|has| (-572) (-527 (-1170) (-572))))) (-4029 (((-769) $) NIL)) (-3277 (($ $ (-572)) NIL (|has| (-572) (-283 (-572) (-572))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL (|has| (-572) (-227))) (($ $ (-769)) NIL (|has| (-572) (-227))) (($ $ (-1170)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1 (-572) (-572)) (-769)) NIL) (($ $ (-1 (-572) (-572))) NIL)) (-3425 (($ $) NIL)) (-4492 (((-572) $) NIL)) (-4081 (((-893 (-572)) $) NIL (|has| (-572) (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| (-572) (-613 (-893 (-385))))) (((-545) $) NIL (|has| (-572) (-613 (-545)))) (((-385) $) NIL (|has| (-572) (-1028))) (((-217) $) NIL (|has| (-572) (-1028)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-572) (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) 7) (($ (-572)) NIL) (($ (-1170)) NIL (|has| (-572) (-1044 (-1170)))) (((-413 (-572)) $) NIL) (((-1011 2) $) 9)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-572) (-910))) (|has| (-572) (-149))))) (-2140 (((-769)) NIL)) (-2634 (((-572) $) NIL (|has| (-572) (-554)))) (-4555 (($ (-413 (-572))) 8)) (-3774 (((-121) $ $) NIL)) (-2264 (($ $) NIL (|has| (-572) (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $) NIL (|has| (-572) (-227))) (($ $ (-769)) NIL (|has| (-572) (-227))) (($ $ (-1170)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1 (-572) (-572)) (-769)) NIL) (($ $ (-1 (-572) (-572))) NIL)) (-1349 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1379 (($ $ $) NIL) (($ (-572) (-572)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ (-572) $) NIL) (($ $ (-572)) NIL))) 
-(((-112) (-13 (-1000 (-572)) (-10 -8 (-15 -3972 ((-413 (-572)) $)) (-15 -3972 ((-1011 2) $)) (-15 -3346 ((-413 (-572)) $)) (-15 -4555 ($ (-413 (-572))))))) (T -112)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-112)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1011 2)) (-5 *1 (-112)))) (-3346 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-112)))) (-4555 (*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-112))))) 
-(-13 (-1000 (-572)) (-10 -8 (-15 -3972 ((-413 (-572)) $)) (-15 -3972 ((-1011 2) $)) (-15 -3346 ((-413 (-572)) $)) (-15 -4555 ($ (-413 (-572)))))) 
-((-2262 (((-121) $ $) NIL)) (-3757 (((-1116) $ (-1116)) 23)) (-2582 (($ $ (-1152)) 17)) (-1515 (((-3 (-1116) "failed") $) 22)) (-2159 (((-1116) $) 20)) (-3938 (((-1116) $ (-1116)) 25)) (-4014 (((-1116) $) 24)) (-1428 (($ (-394)) NIL) (($ (-394) (-1152)) 16)) (-3201 (((-394) $) NIL)) (-1658 (((-1152) $) NIL)) (-1828 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1734 (((-1264) $) NIL)) (-3972 (((-856) $) NIL)) (-1391 (($ $) 18)) (-1324 (((-121) $ $) NIL))) 
-(((-113) (-13 (-369 (-394) (-1116)) (-10 -8 (-15 -1515 ((-3 (-1116) "failed") $)) (-15 -4014 ((-1116) $)) (-15 -3938 ((-1116) $ (-1116)))))) (T -113)) 
-((-1515 (*1 *2 *1) (|partial| -12 (-5 *2 (-1116)) (-5 *1 (-113)))) (-4014 (*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-113)))) (-3938 (*1 *2 *1 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-113))))) 
-(-13 (-369 (-394) (-1116)) (-10 -8 (-15 -1515 ((-3 (-1116) "failed") $)) (-15 -4014 ((-1116) $)) (-15 -3938 ((-1116) $ (-1116))))) 
-((-2262 (((-121) $ $) NIL)) (-2004 (($ $) NIL)) (-2992 (($ $ $) NIL)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) $) NIL (|has| (-121) (-848))) (((-121) (-1 (-121) (-121) (-121)) $) NIL)) (-4131 (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-121) (-848)))) (($ (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4603)))) (-3008 (($ $) NIL (|has| (-121) (-848))) (($ (-1 (-121) (-121) (-121)) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-121) $ (-1225 (-572)) (-121)) NIL (|has| $ (-6 -4603))) (((-121) $ (-572) (-121)) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-3445 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602))) (($ (-121) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-3116 (((-121) (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-3037 (((-121) $ (-572) (-121)) NIL (|has| $ (-6 -4603)))) (-4212 (((-121) $ (-572)) NIL)) (-4014 (((-572) (-121) $ (-572)) NIL (|has| (-121) (-1098))) (((-572) (-121) $) NIL (|has| (-121) (-1098))) (((-572) (-1 (-121) (-121)) $) NIL)) (-2010 (((-638 (-121)) $) NIL (|has| $ (-6 -4602)))) (-2468 (($ $ $) NIL)) (-2959 (($ $) NIL)) (-2117 (($ $ $) NIL)) (-1364 (($ (-769) (-121)) 8)) (-2084 (($ $ $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL)) (-4475 (($ $ $) NIL (|has| (-121) (-848))) (($ (-1 (-121) (-121) (-121)) $ $) NIL)) (-4467 (((-638 (-121)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL)) (-2435 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-121) (-121) (-121)) $ $) NIL) (($ (-1 (-121) (-121)) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2603 (($ $ $ (-572)) NIL) (($ (-121) $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-121) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-121) "failed") (-1 (-121) (-121)) $) NIL)) (-3299 (($ $ (-121)) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-121)) (-638 (-121))) NIL (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-121) (-121)) NIL (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-290 (-121))) NIL (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-638 (-290 (-121)))) NIL (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-2957 (((-638 (-121)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 (($ $ (-1225 (-572))) NIL) (((-121) $ (-572)) NIL) (((-121) $ (-572) (-121)) NIL)) (-1940 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-1571 (((-769) (-121) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098)))) (((-769) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602)))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-121) (-613 (-545))))) (-3921 (($ (-638 (-121))) NIL)) (-4500 (($ (-638 $)) NIL) (($ $ $) NIL) (($ (-121) $) NIL) (($ $ (-121)) NIL)) (-3972 (((-856) $) NIL)) (-1813 (($ (-769) (-121)) 9)) (-3501 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602)))) (-4028 (($ $ $) NIL)) (-4174 (($ $) NIL)) (-2235 (($ $ $) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-2226 (($ $ $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-114) (-13 (-133) (-10 -8 (-15 -1813 ($ (-769) (-121)))))) (T -114)) 
-((-1813 (*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-121)) (-5 *1 (-114))))) 
-(-13 (-133) (-10 -8 (-15 -1813 ($ (-769) (-121))))) 
-((-3458 (((-965 (-171 (-217))) (-1116) (-171 (-217)) (-965 (-171 (-217))) (-1116) (-965 (-171 (-217))) (-1116)) 33)) (-1721 (((-572) (-1116) (-965 (-171 (-217))) (-1116)) 32)) (-1479 (((-572) (-572) (-965 (-385)) (-572)) 31)) (-3521 (((-572) (-572) (-965 (-217)) (-572)) 29)) (-1953 (((-572) (-572) (-965 (-171 (-385))) (-572)) 28)) (-2852 (((-217) (-1116) (-965 (-171 (-217))) (-1116)) 25)) (-3822 (((-217) (-1116) (-965 (-171 (-217))) (-1116)) 24)) (-3322 (((-638 (-965 (-217))) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116)) 22)) (-2692 (((-965 (-217)) (-1116) (-217) (-965 (-217)) (-1116)) 21)) (-3768 (((-965 (-217)) (-217) (-217) (-217) (-217)) 18)) (-3693 (((-638 (-965 (-217))) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116) (-217) (-217)) 20)) (-3386 (((-217) (-1116) (-965 (-217)) (-1116)) 17)) (-1752 (((-217) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116)) 16)) (-3451 (((-965 (-217)) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116)) 15)) (-1920 (((-217) (-171 (-217))) 10)) (-1501 (((-965 (-217)) (-1116) (-217) (-965 (-217)) (-1116) (-965 (-217)) (-1116)) 14)) (-1948 (((-217) (-1116) (-965 (-217)) (-1116)) 13))) 
-(((-115) (-10 -7 (-15 -1920 ((-217) (-171 (-217)))) (-15 -1948 ((-217) (-1116) (-965 (-217)) (-1116))) (-15 -1501 ((-965 (-217)) (-1116) (-217) (-965 (-217)) (-1116) (-965 (-217)) (-1116))) (-15 -3451 ((-965 (-217)) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116))) (-15 -1752 ((-217) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116))) (-15 -3386 ((-217) (-1116) (-965 (-217)) (-1116))) (-15 -3768 ((-965 (-217)) (-217) (-217) (-217) (-217))) (-15 -3693 ((-638 (-965 (-217))) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116) (-217) (-217))) (-15 -2692 ((-965 (-217)) (-1116) (-217) (-965 (-217)) (-1116))) (-15 -3322 ((-638 (-965 (-217))) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116))) (-15 -3822 ((-217) (-1116) (-965 (-171 (-217))) (-1116))) (-15 -2852 ((-217) (-1116) (-965 (-171 (-217))) (-1116))) (-15 -1953 ((-572) (-572) (-965 (-171 (-385))) (-572))) (-15 -3521 ((-572) (-572) (-965 (-217)) (-572))) (-15 -1479 ((-572) (-572) (-965 (-385)) (-572))) (-15 -1721 ((-572) (-1116) (-965 (-171 (-217))) (-1116))) (-15 -3458 ((-965 (-171 (-217))) (-1116) (-171 (-217)) (-965 (-171 (-217))) (-1116) (-965 (-171 (-217))) (-1116))))) (T -115)) 
-((-3458 (*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-965 (-171 (-217)))) (-5 *3 (-1116)) (-5 *4 (-171 (-217))) (-5 *1 (-115)))) (-1721 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-171 (-217)))) (-5 *2 (-572)) (-5 *1 (-115)))) (-1479 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-572)) (-5 *3 (-965 (-385))) (-5 *1 (-115)))) (-3521 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-572)) (-5 *3 (-965 (-217))) (-5 *1 (-115)))) (-1953 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-572)) (-5 *3 (-965 (-171 (-385)))) (-5 *1 (-115)))) (-2852 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-171 (-217)))) (-5 *2 (-217)) (-5 *1 (-115)))) (-3822 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-171 (-217)))) (-5 *2 (-217)) (-5 *1 (-115)))) (-3322 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *2 (-638 (-965 (-217)))) (-5 *1 (-115)) (-5 *4 (-965 (-217))))) (-2692 (*1 *2 *3 *4 *2 *3) (-12 (-5 *2 (-965 (-217))) (-5 *3 (-1116)) (-5 *4 (-217)) (-5 *1 (-115)))) (-3693 (*1 *2 *3 *4 *3 *4 *3 *5 *5) (-12 (-5 *3 (-1116)) (-5 *5 (-217)) (-5 *2 (-638 (-965 *5))) (-5 *1 (-115)) (-5 *4 (-965 *5)))) (-3768 (*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-965 (-217))) (-5 *1 (-115)) (-5 *3 (-217)))) (-3386 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-217))) (-5 *2 (-217)) (-5 *1 (-115)))) (-1752 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-217))) (-5 *2 (-217)) (-5 *1 (-115)))) (-3451 (*1 *2 *3 *2 *3 *2 *3) (-12 (-5 *2 (-965 (-217))) (-5 *3 (-1116)) (-5 *1 (-115)))) (-1501 (*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-965 (-217))) (-5 *3 (-1116)) (-5 *4 (-217)) (-5 *1 (-115)))) (-1948 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-217))) (-5 *2 (-217)) (-5 *1 (-115)))) (-1920 (*1 *2 *3) (-12 (-5 *3 (-171 (-217))) (-5 *2 (-217)) (-5 *1 (-115))))) 
-(-10 -7 (-15 -1920 ((-217) (-171 (-217)))) (-15 -1948 ((-217) (-1116) (-965 (-217)) (-1116))) (-15 -1501 ((-965 (-217)) (-1116) (-217) (-965 (-217)) (-1116) (-965 (-217)) (-1116))) (-15 -3451 ((-965 (-217)) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116))) (-15 -1752 ((-217) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116))) (-15 -3386 ((-217) (-1116) (-965 (-217)) (-1116))) (-15 -3768 ((-965 (-217)) (-217) (-217) (-217) (-217))) (-15 -3693 ((-638 (-965 (-217))) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116) (-217) (-217))) (-15 -2692 ((-965 (-217)) (-1116) (-217) (-965 (-217)) (-1116))) (-15 -3322 ((-638 (-965 (-217))) (-1116) (-965 (-217)) (-1116) (-965 (-217)) (-1116))) (-15 -3822 ((-217) (-1116) (-965 (-171 (-217))) (-1116))) (-15 -2852 ((-217) (-1116) (-965 (-171 (-217))) (-1116))) (-15 -1953 ((-572) (-572) (-965 (-171 (-385))) (-572))) (-15 -3521 ((-572) (-572) (-965 (-217)) (-572))) (-15 -1479 ((-572) (-572) (-965 (-385)) (-572))) (-15 -1721 ((-572) (-1116) (-965 (-171 (-217))) (-1116))) (-15 -3458 ((-965 (-171 (-217))) (-1116) (-171 (-217)) (-965 (-171 (-217))) (-1116) (-965 (-171 (-217))) (-1116)))) 
-((-2262 (((-121) $ $) NIL)) (-3707 (((-3 "left" "center" "right" "vertical" "horizontal") $) 17)) (-3507 (((-572) $) 14)) (-2078 (((-572) $) 15)) (-4208 (((-572) $) 16)) (-1658 (((-1152) $) NIL)) (-2943 (((-121) $) 8)) (-2607 (((-1116) $) NIL)) (-1680 (((-572) $) 12)) (-3104 (($ (-572) (-572) (-572) (-572) (-572) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) 11)) (-3972 (((-856) $) 19) (($ (-638 (-572))) NIL)) (-4173 (((-572) $) 13)) (-1324 (((-121) $ $) NIL))) 
-(((-116) (-13 (-117) (-10 -7 (-6 |HamburgerNoether|)))) (T -116)) 
-NIL 
-(-13 (-117) (-10 -7 (-6 |HamburgerNoether|))) 
-((-2262 (((-121) $ $) 7)) (-3707 (((-3 "left" "center" "right" "vertical" "horizontal") $) 12)) (-3507 (((-572) $) 17)) (-2078 (((-572) $) 15)) (-4208 (((-572) $) 13)) (-1658 (((-1152) $) 9)) (-2943 (((-121) $) 14)) (-2607 (((-1116) $) 10)) (-1680 (((-572) $) 19)) (-3104 (($ (-572) (-572) (-572) (-572) (-572) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) 16)) (-3972 (((-856) $) 11) (($ (-638 (-572))) 20)) (-4173 (((-572) $) 18)) (-1324 (((-121) $ $) 6))) 
-(((-117) (-1290)) (T -117)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-4 *1 (-117)))) (-1680 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572)))) (-4173 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572)))) (-3507 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572)))) (-3104 (*1 *1 *2 *2 *2 *2 *2 *3 *4) (-12 (-5 *2 (-572)) (-5 *3 (-121)) (-5 *4 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *1 (-117)))) (-2078 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572)))) (-2943 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-121)))) (-4208 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572)))) (-3707 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-3 "left" "center" "right" "vertical" "horizontal"))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-638 (-572)))) (-15 -1680 ((-572) $)) (-15 -4173 ((-572) $)) (-15 -3507 ((-572) $)) (-15 -3104 ($ (-572) (-572) (-572) (-572) (-572) (-121) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -2078 ((-572) $)) (-15 -2943 ((-121) $)) (-15 -4208 ((-572) $)) (-15 -3707 ((-3 "left" "center" "right" "vertical" "horizontal") $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-3707 (((-3 "left" "center" "right" "vertical" "horizontal") $) NIL)) (-3507 (((-572) $) 14)) (-2078 (((-572) $) 11)) (-4208 (((-572) $) 15)) (-1658 (((-1152) $) NIL)) (-2943 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-1680 (((-572) $) 12)) (-3104 (($ (-572) (-572) (-572) (-572) (-572) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) NIL)) (-3972 (((-856) $) 17) (($ (-638 (-572))) 10)) (-4173 (((-572) $) 13)) (-1324 (((-121) $ $) NIL))) 
-(((-118) (-13 (-117) (-10 -7 (-6 |QuadraticTransform|)))) (T -118)) 
-NIL 
-(-13 (-117) (-10 -7 (-6 |QuadraticTransform|))) 
-((-1562 (((-2 (|:| |mult| (-769)) (|:| |subMult| (-769)) (|:| |blUpRec| (-638 (-2 (|:| |recTransStr| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-33 |#1|) |#5| |#1|) 70)) (-2808 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-769) |#5|) 54)) (-1978 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) |#3| |#5|) 99)) (-1727 (((-638 (-638 (-769))) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|)) NIL)) (-3005 ((|#3| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) |#5|) 105)) (-2079 ((|#3| |#3| |#5|) 107))) 
-(((-119 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2079 (|#3| |#3| |#5|)) (-15 -2808 ((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-769) |#5|)) (-15 -1562 ((-2 (|:| |mult| (-769)) (|:| |subMult| (-769)) (|:| |blUpRec| (-638 (-2 (|:| |recTransStr| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-33 |#1|) |#5| |#1|)) (-15 -1727 ((-638 (-638 (-769))) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|))) (-15 -1978 ((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) |#3| |#5|)) (-15 -3005 (|#3| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) |#5|))) (-368) (-638 (-1170)) (-326 |#1| |#4|) (-232 (-4032 |#2|) (-769)) (-117)) (T -119)) 
-((-3005 (*1 *2 *3 *4) (-12 (-5 *3 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *5)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *2 (-326 *5 *7)) (-5 *1 (-119 *5 *6 *2 *7 *4)) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *4 (-117)))) (-1978 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-5 *2 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *5)) (-5 *1 (-119 *5 *6 *3 *7 *4)) (-4 *3 (-326 *5 *7)) (-4 *4 (-117)))) (-1727 (*1 *2 *3) (-12 (-5 *3 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *4)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-5 *2 (-638 (-638 (-769)))) (-5 *1 (-119 *4 *5 *6 *7 *8)) (-4 *6 (-326 *4 *7)) (-4 *8 (-117)))) (-1562 (*1 *2 *3 *4 *5 *6) (-12 (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *9 (-232 (-4032 *7) (-769))) (-5 *2 (-2 (|:| |mult| (-769)) (|:| |subMult| (-769)) (|:| |blUpRec| (-638 (-2 (|:| |recTransStr| (-244 (-3921 (QUOTE X) (QUOTE -2301)) *6)) (|:| |recPoint| (-33 *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (-5 *1 (-119 *6 *7 *8 *9 *5)) (-5 *3 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *6)) (-5 *4 (-33 *6)) (-4 *8 (-326 *6 *9)) (-4 *5 (-117)))) (-2808 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *5)) (-4 *5 (-368)) (-5 *3 (-769)) (-14 *6 (-638 (-1170))) (-4 *8 (-232 (-4032 *6) *3)) (-5 *1 (-119 *5 *6 *7 *8 *4)) (-4 *7 (-326 *5 *8)) (-4 *4 (-117)))) (-2079 (*1 *2 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *1 (-119 *4 *5 *2 *6 *3)) (-4 *2 (-326 *4 *6)) (-4 *3 (-117))))) 
-(-10 -7 (-15 -2079 (|#3| |#3| |#5|)) (-15 -2808 ((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-769) |#5|)) (-15 -1562 ((-2 (|:| |mult| (-769)) (|:| |subMult| (-769)) (|:| |blUpRec| (-638 (-2 (|:| |recTransStr| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-33 |#1|) |#5| |#1|)) (-15 -1727 ((-638 (-638 (-769))) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|))) (-15 -1978 ((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) |#3| |#5|)) (-15 -3005 (|#3| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) |#5|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ |#1| $) 22) (($ $ |#2|) 24))) 
-(((-120 |#1| |#2|) (-1290) (-1054) (-1054)) (T -120)) 
-NIL 
-(-13 (-641 |t#1|) (-1060 |t#2|) (-10 -7 (-6 -4597) (-6 -4596))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-1060 |#2|) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-2004 (($ $) 12)) (-2992 (($ $ $) 17)) (-3538 (($) 8 T CONST)) (-2080 (((-121) $) 7)) (-1685 (((-769)) 24)) (-3286 (($) 30)) (-2468 (($ $ $) 15)) (-2959 (($ $) 10)) (-2117 (($ $ $) 18)) (-2084 (($ $ $) 19)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3633 (((-923) $) 29)) (-1658 (((-1152) $) NIL)) (-1763 (($ (-923)) 28)) (-3723 (($ $ $) 21)) (-2607 (((-1116) $) NIL)) (-1442 (($) 9 T CONST)) (-3587 (((-638 $)) NIL)) (-4081 (((-545) $) 36)) (-3972 (((-856) $) 39)) (-4028 (($ $ $) 13)) (-4174 (($ $) 11)) (-2235 (($ $ $) 16)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 20)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 22)) (-2226 (($ $ $) 14))) 
-(((-121) (-13 (-848) (-374) (-655) (-613 (-545)) (-10 -8 (-15 -3538 ($) -3211) (-15 -1442 ($) -3211) (-15 -4174 ($ $)) (-15 -2959 ($ $)) (-15 -4028 ($ $ $)) (-15 -2468 ($ $ $)) (-15 -2992 ($ $ $)) (-15 -2084 ($ $ $)) (-15 -2117 ($ $ $)) (-15 -3723 ($ $ $)) (-15 -2080 ((-121) $))))) (T -121)) 
-((-3538 (*1 *1) (-5 *1 (-121))) (-1442 (*1 *1) (-5 *1 (-121))) (-4174 (*1 *1 *1) (-5 *1 (-121))) (-2959 (*1 *1 *1) (-5 *1 (-121))) (-4028 (*1 *1 *1 *1) (-5 *1 (-121))) (-2468 (*1 *1 *1 *1) (-5 *1 (-121))) (-2992 (*1 *1 *1 *1) (-5 *1 (-121))) (-2084 (*1 *1 *1 *1) (-5 *1 (-121))) (-2117 (*1 *1 *1 *1) (-5 *1 (-121))) (-3723 (*1 *1 *1 *1) (-5 *1 (-121))) (-2080 (*1 *1 *1) (-5 *1 (-121)))) 
-(-13 (-848) (-374) (-655) (-613 (-545)) (-10 -8 (-15 -3538 ($) -3211) (-15 -1442 ($) -3211) (-15 -4174 ($ $)) (-15 -2959 ($ $)) (-15 -4028 ($ $ $)) (-15 -2468 ($ $ $)) (-15 -2992 ($ $ $)) (-15 -2084 ($ $ $)) (-15 -2117 ($ $ $)) (-15 -3723 ($ $ $)) (-15 -2080 ((-121) $)))) 
-((-3949 (((-3 (-1 |#1| (-638 |#1|)) "failed") (-123)) 18) (((-123) (-123) (-1 |#1| |#1|)) 13) (((-123) (-123) (-1 |#1| (-638 |#1|))) 11) (((-3 |#1| "failed") (-123) (-638 |#1|)) 20)) (-4019 (((-3 (-638 (-1 |#1| (-638 |#1|))) "failed") (-123)) 24) (((-123) (-123) (-1 |#1| |#1|)) 30) (((-123) (-123) (-638 (-1 |#1| (-638 |#1|)))) 26)) (-1876 (((-123) |#1|) 53 (|has| |#1| (-848)))) (-3536 (((-3 |#1| "failed") (-123)) 48 (|has| |#1| (-848))))) 
-(((-122 |#1|) (-10 -7 (-15 -3949 ((-3 |#1| "failed") (-123) (-638 |#1|))) (-15 -3949 ((-123) (-123) (-1 |#1| (-638 |#1|)))) (-15 -3949 ((-123) (-123) (-1 |#1| |#1|))) (-15 -3949 ((-3 (-1 |#1| (-638 |#1|)) "failed") (-123))) (-15 -4019 ((-123) (-123) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4019 ((-123) (-123) (-1 |#1| |#1|))) (-15 -4019 ((-3 (-638 (-1 |#1| (-638 |#1|))) "failed") (-123))) (IF (|has| |#1| (-848)) (PROGN (-15 -1876 ((-123) |#1|)) (-15 -3536 ((-3 |#1| "failed") (-123)))) |noBranch|)) (-1098)) (T -122)) 
-((-3536 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-4 *2 (-1098)) (-4 *2 (-848)) (-5 *1 (-122 *2)))) (-1876 (*1 *2 *3) (-12 (-5 *2 (-123)) (-5 *1 (-122 *3)) (-4 *3 (-848)) (-4 *3 (-1098)))) (-4019 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-638 (-1 *4 (-638 *4)))) (-5 *1 (-122 *4)) (-4 *4 (-1098)))) (-4019 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1098)) (-5 *1 (-122 *4)))) (-4019 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-638 (-1 *4 (-638 *4)))) (-4 *4 (-1098)) (-5 *1 (-122 *4)))) (-3949 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-1 *4 (-638 *4))) (-5 *1 (-122 *4)) (-4 *4 (-1098)))) (-3949 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1098)) (-5 *1 (-122 *4)))) (-3949 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 (-638 *4))) (-4 *4 (-1098)) (-5 *1 (-122 *4)))) (-3949 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-638 *2)) (-5 *1 (-122 *2)) (-4 *2 (-1098))))) 
-(-10 -7 (-15 -3949 ((-3 |#1| "failed") (-123) (-638 |#1|))) (-15 -3949 ((-123) (-123) (-1 |#1| (-638 |#1|)))) (-15 -3949 ((-123) (-123) (-1 |#1| |#1|))) (-15 -3949 ((-3 (-1 |#1| (-638 |#1|)) "failed") (-123))) (-15 -4019 ((-123) (-123) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4019 ((-123) (-123) (-1 |#1| |#1|))) (-15 -4019 ((-3 (-638 (-1 |#1| (-638 |#1|))) "failed") (-123))) (IF (|has| |#1| (-848)) (PROGN (-15 -1876 ((-123) |#1|)) (-15 -3536 ((-3 |#1| "failed") (-123)))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-3073 (((-769) $) 68) (($ $ (-769)) 30)) (-1490 (((-121) $) 32)) (-3579 (($ $ (-1152) (-772)) 26)) (-3805 (($ $ (-50 (-1152) (-772))) 13)) (-1800 (((-3 (-772) "failed") $ (-1152)) 24)) (-2098 (((-50 (-1152) (-772)) $) 12)) (-4564 (($ (-1170)) 15) (($ (-1170) (-769)) 20)) (-4105 (((-121) $) 31)) (-2097 (((-121) $) 33)) (-3201 (((-1170) $) 8)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-3291 (((-121) $ (-1170)) 10)) (-2087 (($ $ (-1 (-545) (-638 (-545)))) 50) (((-3 (-1 (-545) (-638 (-545))) "failed") $) 54)) (-2607 (((-1116) $) NIL)) (-3585 (((-121) $ (-1152)) 29)) (-3381 (($ $ (-1 (-121) $ $)) 35)) (-2415 (((-3 (-1 (-856) (-638 (-856))) "failed") $) 52) (($ $ (-1 (-856) (-638 (-856)))) 41) (($ $ (-1 (-856) (-856))) 43)) (-1854 (($ $ (-1152)) 45)) (-1607 (($ $) 61)) (-2096 (($ $ (-1 (-121) $ $)) 36)) (-3972 (((-856) $) 48)) (-4262 (($ $ (-1152)) 27)) (-4020 (((-3 (-769) "failed") $) 56)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 67)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 72))) 
-(((-123) (-13 (-848) (-10 -8 (-15 -3201 ((-1170) $)) (-15 -2098 ((-50 (-1152) (-772)) $)) (-15 -1607 ($ $)) (-15 -4564 ($ (-1170))) (-15 -4564 ($ (-1170) (-769))) (-15 -4020 ((-3 (-769) "failed") $)) (-15 -4105 ((-121) $)) (-15 -1490 ((-121) $)) (-15 -2097 ((-121) $)) (-15 -3073 ((-769) $)) (-15 -3073 ($ $ (-769))) (-15 -3381 ($ $ (-1 (-121) $ $))) (-15 -2096 ($ $ (-1 (-121) $ $))) (-15 -2415 ((-3 (-1 (-856) (-638 (-856))) "failed") $)) (-15 -2415 ($ $ (-1 (-856) (-638 (-856))))) (-15 -2415 ($ $ (-1 (-856) (-856)))) (-15 -2087 ($ $ (-1 (-545) (-638 (-545))))) (-15 -2087 ((-3 (-1 (-545) (-638 (-545))) "failed") $)) (-15 -3291 ((-121) $ (-1170))) (-15 -3585 ((-121) $ (-1152))) (-15 -4262 ($ $ (-1152))) (-15 -1854 ($ $ (-1152))) (-15 -1800 ((-3 (-772) "failed") $ (-1152))) (-15 -3579 ($ $ (-1152) (-772))) (-15 -3805 ($ $ (-50 (-1152) (-772))))))) (T -123)) 
-((-3201 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-123)))) (-2098 (*1 *2 *1) (-12 (-5 *2 (-50 (-1152) (-772))) (-5 *1 (-123)))) (-1607 (*1 *1 *1) (-5 *1 (-123))) (-4564 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-123)))) (-4564 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-769)) (-5 *1 (-123)))) (-4020 (*1 *2 *1) (|partial| -12 (-5 *2 (-769)) (-5 *1 (-123)))) (-4105 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-1490 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-2097 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-3073 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-123)))) (-3073 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-123)))) (-3381 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123)))) (-2096 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123)))) (-2415 (*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-856) (-638 (-856)))) (-5 *1 (-123)))) (-2415 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-856) (-638 (-856)))) (-5 *1 (-123)))) (-2415 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-856) (-856))) (-5 *1 (-123)))) (-2087 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-545) (-638 (-545)))) (-5 *1 (-123)))) (-2087 (*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-545) (-638 (-545)))) (-5 *1 (-123)))) (-3291 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-121)) (-5 *1 (-123)))) (-3585 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-121)) (-5 *1 (-123)))) (-4262 (*1 *1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-123)))) (-1854 (*1 *1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-123)))) (-1800 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1152)) (-5 *2 (-772)) (-5 *1 (-123)))) (-3579 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1152)) (-5 *3 (-772)) (-5 *1 (-123)))) (-3805 (*1 *1 *1 *2) (-12 (-5 *2 (-50 (-1152) (-772))) (-5 *1 (-123))))) 
-(-13 (-848) (-10 -8 (-15 -3201 ((-1170) $)) (-15 -2098 ((-50 (-1152) (-772)) $)) (-15 -1607 ($ $)) (-15 -4564 ($ (-1170))) (-15 -4564 ($ (-1170) (-769))) (-15 -4020 ((-3 (-769) "failed") $)) (-15 -4105 ((-121) $)) (-15 -1490 ((-121) $)) (-15 -2097 ((-121) $)) (-15 -3073 ((-769) $)) (-15 -3073 ($ $ (-769))) (-15 -3381 ($ $ (-1 (-121) $ $))) (-15 -2096 ($ $ (-1 (-121) $ $))) (-15 -2415 ((-3 (-1 (-856) (-638 (-856))) "failed") $)) (-15 -2415 ($ $ (-1 (-856) (-638 (-856))))) (-15 -2415 ($ $ (-1 (-856) (-856)))) (-15 -2087 ($ $ (-1 (-545) (-638 (-545))))) (-15 -2087 ((-3 (-1 (-545) (-638 (-545))) "failed") $)) (-15 -3291 ((-121) $ (-1170))) (-15 -3585 ((-121) $ (-1152))) (-15 -4262 ($ $ (-1152))) (-15 -1854 ($ $ (-1152))) (-15 -1800 ((-3 (-772) "failed") $ (-1152))) (-15 -3579 ($ $ (-1152) (-772))) (-15 -3805 ($ $ (-50 (-1152) (-772)))))) 
-((-3672 (((-572) |#2|) 36))) 
-(((-124 |#1| |#2|) (-10 -7 (-15 -3672 ((-572) |#2|))) (-13 (-368) (-1044 (-413 (-572)))) (-1234 |#1|)) (T -124)) 
-((-3672 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-1044 (-413 *2)))) (-5 *2 (-572)) (-5 *1 (-124 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -3672 ((-572) |#2|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $ (-572)) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-1431 (($ (-1166 (-572)) (-572)) NIL)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-4070 (($ $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-3377 (((-769) $) NIL)) (-3893 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3195 (((-572)) NIL)) (-2671 (((-572) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1977 (($ $ (-572)) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-4465 (((-1150 (-572)) $) NIL)) (-2424 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL)) (-2140 (((-769)) NIL)) (-3774 (((-121) $ $) NIL)) (-3410 (((-572) $ (-572)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL))) 
-(((-125 |#1|) (-869 |#1|) (-572)) (T -125)) 
-NIL 
-(-869 |#1|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-125 |#1|) (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| (-125 |#1|) (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| (-125 |#1|) (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-125 |#1|) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL (|has| (-125 |#1|) (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-125 |#1|) (-1044 (-572)))) (((-3 (-572) "failed") $) NIL (|has| (-125 |#1|) (-1044 (-572))))) (-1318 (((-125 |#1|) $) NIL) (((-1170) $) NIL (|has| (-125 |#1|) (-1044 (-1170)))) (((-413 (-572)) $) NIL (|has| (-125 |#1|) (-1044 (-572)))) (((-572) $) NIL (|has| (-125 |#1|) (-1044 (-572))))) (-3729 (($ $) NIL) (($ (-572) $) NIL)) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-125 |#1|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-125 |#1|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-125 |#1|))) (|:| |vec| (-1259 (-125 |#1|)))) (-685 $) (-1259 $)) NIL) (((-685 (-125 |#1|)) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-125 |#1|) (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) NIL (|has| (-125 |#1|) (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| (-125 |#1|) (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| (-125 |#1|) (-887 (-385))))) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL)) (-4487 (((-125 |#1|) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| (-125 |#1|) (-1144)))) (-4472 (((-121) $) NIL (|has| (-125 |#1|) (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| (-125 |#1|) (-848)))) (-4238 (($ $ $) NIL (|has| (-125 |#1|) (-848)))) (-3828 (($ (-1 (-125 |#1|) (-125 |#1|)) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-125 |#1|) (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| (-125 |#1|) (-303)))) (-1716 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-125 |#1|) (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-125 |#1|) (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 (-125 |#1|)) (-638 (-125 |#1|))) NIL (|has| (-125 |#1|) (-305 (-125 |#1|)))) (($ $ (-125 |#1|) (-125 |#1|)) NIL (|has| (-125 |#1|) (-305 (-125 |#1|)))) (($ $ (-290 (-125 |#1|))) NIL (|has| (-125 |#1|) (-305 (-125 |#1|)))) (($ $ (-638 (-290 (-125 |#1|)))) NIL (|has| (-125 |#1|) (-305 (-125 |#1|)))) (($ $ (-638 (-1170)) (-638 (-125 |#1|))) NIL (|has| (-125 |#1|) (-527 (-1170) (-125 |#1|)))) (($ $ (-1170) (-125 |#1|)) NIL (|has| (-125 |#1|) (-527 (-1170) (-125 |#1|))))) (-4029 (((-769) $) NIL)) (-3277 (($ $ (-125 |#1|)) NIL (|has| (-125 |#1|) (-283 (-125 |#1|) (-125 |#1|))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL (|has| (-125 |#1|) (-227))) (($ $ (-769)) NIL (|has| (-125 |#1|) (-227))) (($ $ (-1170)) NIL (|has| (-125 |#1|) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-125 |#1|) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-125 |#1|) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-125 |#1|) (-901 (-1170)))) (($ $ (-1 (-125 |#1|) (-125 |#1|)) (-769)) NIL) (($ $ (-1 (-125 |#1|) (-125 |#1|))) NIL)) (-3425 (($ $) NIL)) (-4492 (((-125 |#1|) $) NIL)) (-4081 (((-893 (-572)) $) NIL (|has| (-125 |#1|) (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| (-125 |#1|) (-613 (-893 (-385))))) (((-545) $) NIL (|has| (-125 |#1|) (-613 (-545)))) (((-385) $) NIL (|has| (-125 |#1|) (-1028))) (((-217) $) NIL (|has| (-125 |#1|) (-1028)))) (-3915 (((-175 (-413 (-572))) $) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-125 |#1|) (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-125 |#1|)) NIL) (($ (-1170)) NIL (|has| (-125 |#1|) (-1044 (-1170))))) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-125 |#1|) (-910))) (|has| (-125 |#1|) (-149))))) (-2140 (((-769)) NIL)) (-2634 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-554)))) (-3774 (((-121) $ $) NIL)) (-3410 (((-413 (-572)) $ (-572)) NIL)) (-2264 (($ $) NIL (|has| (-125 |#1|) (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $) NIL (|has| (-125 |#1|) (-227))) (($ $ (-769)) NIL (|has| (-125 |#1|) (-227))) (($ $ (-1170)) NIL (|has| (-125 |#1|) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-125 |#1|) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-125 |#1|) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-125 |#1|) (-901 (-1170)))) (($ $ (-1 (-125 |#1|) (-125 |#1|)) (-769)) NIL) (($ $ (-1 (-125 |#1|) (-125 |#1|))) NIL)) (-1349 (((-121) $ $) NIL (|has| (-125 |#1|) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-125 |#1|) (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| (-125 |#1|) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-125 |#1|) (-848)))) (-1379 (($ $ $) NIL) (($ (-125 |#1|) (-125 |#1|)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ (-125 |#1|) $) NIL) (($ $ (-125 |#1|)) NIL))) 
-(((-126 |#1|) (-13 (-1000 (-125 |#1|)) (-10 -8 (-15 -3410 ((-413 (-572)) $ (-572))) (-15 -3915 ((-175 (-413 (-572))) $)) (-15 -3729 ($ $)) (-15 -3729 ($ (-572) $)))) (-572)) (T -126)) 
-((-3410 (*1 *2 *1 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-126 *4)) (-14 *4 *3) (-5 *3 (-572)))) (-3915 (*1 *2 *1) (-12 (-5 *2 (-175 (-413 (-572)))) (-5 *1 (-126 *3)) (-14 *3 (-572)))) (-3729 (*1 *1 *1) (-12 (-5 *1 (-126 *2)) (-14 *2 (-572)))) (-3729 (*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-126 *3)) (-14 *3 *2)))) 
-(-13 (-1000 (-125 |#1|)) (-10 -8 (-15 -3410 ((-413 (-572)) $ (-572))) (-15 -3915 ((-175 (-413 (-572))) $)) (-15 -3729 ($ $)) (-15 -3729 ($ (-572) $)))) 
-((-3283 ((|#2| $ "value" |#2|) NIL) (($ $ "left" $) 48) (($ $ "right" $) 50)) (-2202 (((-638 $) $) 27)) (-1303 (((-121) $ $) 32)) (-3002 (((-121) |#2| $) 36)) (-2699 (((-638 |#2|) $) 22)) (-3113 (((-121) $) 16)) (-3277 ((|#2| $ "value") NIL) (($ $ "left") 10) (($ $ "right") 13)) (-1791 (((-121) $) 45)) (-3972 (((-856) $) 41)) (-4118 (((-638 $) $) 28)) (-1324 (((-121) $ $) 34)) (-4032 (((-769) $) 43))) 
-(((-127 |#1| |#2|) (-10 -8 (-15 -3283 (|#1| |#1| "right" |#1|)) (-15 -3283 (|#1| |#1| "left" |#1|)) (-15 -3277 (|#1| |#1| "right")) (-15 -3277 (|#1| |#1| "left")) (-15 -3283 (|#2| |#1| "value" |#2|)) (-15 -1303 ((-121) |#1| |#1|)) (-15 -2699 ((-638 |#2|) |#1|)) (-15 -1791 ((-121) |#1|)) (-15 -3277 (|#2| |#1| "value")) (-15 -3113 ((-121) |#1|)) (-15 -2202 ((-638 |#1|) |#1|)) (-15 -4118 ((-638 |#1|) |#1|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -3002 ((-121) |#2| |#1|)) (-15 -4032 ((-769) |#1|))) (-128 |#2|) (-1204)) (T -127)) 
-NIL 
-(-10 -8 (-15 -3283 (|#1| |#1| "right" |#1|)) (-15 -3283 (|#1| |#1| "left" |#1|)) (-15 -3277 (|#1| |#1| "right")) (-15 -3277 (|#1| |#1| "left")) (-15 -3283 (|#2| |#1| "value" |#2|)) (-15 -1303 ((-121) |#1| |#1|)) (-15 -2699 ((-638 |#2|) |#1|)) (-15 -1791 ((-121) |#1|)) (-15 -3277 (|#2| |#1| "value")) (-15 -3113 ((-121) |#1|)) (-15 -2202 ((-638 |#1|) |#1|)) (-15 -4118 ((-638 |#1|) |#1|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -3002 ((-121) |#2| |#1|)) (-15 -4032 ((-769) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-2107 (($ $ $) 49 (|has| $ (-6 -4603)))) (-3184 (($ $ $) 51 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603))) (($ $ "left" $) 52 (|has| $ (-6 -4603))) (($ $ "right" $) 50 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-2211 (($) 7 T CONST)) (-1862 (($ $) 54)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1866 (($ $) 56)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44) (($ $ "left") 55) (($ $ "right") 53)) (-3537 (((-572) $ $) 41)) (-1791 (((-121) $) 43)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-128 |#1|) (-1290) (-1204)) (T -128)) 
-((-1866 (*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1204)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 "left") (-4 *1 (-128 *3)) (-4 *3 (-1204)))) (-1862 (*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1204)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 "right") (-4 *1 (-128 *3)) (-4 *3 (-1204)))) (-3283 (*1 *1 *1 *2 *1) (-12 (-5 *2 "left") (|has| *1 (-6 -4603)) (-4 *1 (-128 *3)) (-4 *3 (-1204)))) (-3184 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-128 *2)) (-4 *2 (-1204)))) (-3283 (*1 *1 *1 *2 *1) (-12 (-5 *2 "right") (|has| *1 (-6 -4603)) (-4 *1 (-128 *3)) (-4 *3 (-1204)))) (-2107 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-128 *2)) (-4 *2 (-1204))))) 
-(-13 (-1017 |t#1|) (-10 -8 (-15 -1866 ($ $)) (-15 -3277 ($ $ "left")) (-15 -1862 ($ $)) (-15 -3277 ($ $ "right")) (IF (|has| $ (-6 -4603)) (PROGN (-15 -3283 ($ $ "left" $)) (-15 -3184 ($ $ $)) (-15 -3283 ($ $ "right" $)) (-15 -2107 ($ $ $))) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1017 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-2116 (((-121) |#1|) 24)) (-3651 (((-769) (-769)) 23) (((-769)) 22)) (-2115 (((-121) |#1| (-121)) 25) (((-121) |#1|) 26))) 
-(((-129 |#1|) (-10 -7 (-15 -2115 ((-121) |#1|)) (-15 -2115 ((-121) |#1| (-121))) (-15 -3651 ((-769))) (-15 -3651 ((-769) (-769))) (-15 -2116 ((-121) |#1|))) (-1234 (-572))) (T -129)) 
-((-2116 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572))))) (-3651 (*1 *2 *2) (-12 (-5 *2 (-769)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572))))) (-3651 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572))))) (-2115 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572))))) (-2115 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572)))))) 
-(-10 -7 (-15 -2115 ((-121) |#1|)) (-15 -2115 ((-121) |#1| (-121))) (-15 -3651 ((-769))) (-15 -3651 ((-769) (-769))) (-15 -2116 ((-121) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-4520 (((-3 $ "failed") (-1170) (-1170)) 31)) (-2607 (((-1116) $) NIL)) (-3678 (((-3 (-1170) "failed") $) 45)) (-4254 (((-3 $ (-572)) (-1170)) 36)) (-2777 (((-1178 (-1170) $)) 42)) (-2987 (((-638 $)) 40)) (-4459 (((-3 $ "failed") (-1170)) 19)) (-4081 (($ (-1170)) 27) (((-1170) $) NIL)) (-3972 (((-856) $) 21)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL))) 
-(((-130) (-13 (-848) (-10 -8 (-6 (-613 (-1170))) (-15 -4459 ((-3 $ "failed") (-1170))) (-15 -4081 ($ (-1170))) (-15 -4520 ((-3 $ "failed") (-1170) (-1170))) (-15 -4254 ((-3 $ (-572)) (-1170))) (-15 -2987 ((-638 $))) (-15 -2777 ((-1178 (-1170) $))) (-15 -3678 ((-3 (-1170) "failed") $))))) (T -130)) 
-((-4459 (*1 *1 *2) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-130)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-130)))) (-4520 (*1 *1 *2 *2) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-130)))) (-4254 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-3 (-130) (-572))) (-5 *1 (-130)))) (-2987 (*1 *2) (-12 (-5 *2 (-638 (-130))) (-5 *1 (-130)))) (-2777 (*1 *2) (-12 (-5 *2 (-1178 (-1170) (-130))) (-5 *1 (-130)))) (-3678 (*1 *2 *1) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-130))))) 
-(-13 (-848) (-10 -8 (-6 (-613 (-1170))) (-15 -4459 ((-3 $ "failed") (-1170))) (-15 -4081 ($ (-1170))) (-15 -4520 ((-3 $ "failed") (-1170) (-1170))) (-15 -4254 ((-3 $ (-572)) (-1170))) (-15 -2987 ((-638 $))) (-15 -2777 ((-1178 (-1170) $))) (-15 -3678 ((-3 (-1170) "failed") $)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) 15)) (-1585 (((-2 (|:| |less| $) (|:| |greater| $)) |#1| $) 22)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-2107 (($ $ $) 18 (|has| $ (-6 -4603)))) (-3184 (($ $ $) 20 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) (($ $ "left" $) NIL (|has| $ (-6 -4603))) (($ $ "right" $) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-1862 (($ $) 17)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3486 (($ $ |#1| $) 23)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1866 (($ $) 19)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2971 (($ |#1| $) 24)) (-1335 (($ |#1| $) 10)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 14)) (-1665 (($) 8)) (-3277 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-3537 (((-572) $ $) NIL)) (-1791 (((-121) $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3394 (($ (-638 |#1|)) 12)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-131 |#1|) (-13 (-135 |#1|) (-10 -8 (-6 -4603) (-6 -4602) (-15 -3394 ($ (-638 |#1|))) (-15 -1335 ($ |#1| $)) (-15 -2971 ($ |#1| $)) (-15 -1585 ((-2 (|:| |less| $) (|:| |greater| $)) |#1| $)))) (-848)) (T -131)) 
-((-3394 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-131 *3)))) (-1335 (*1 *1 *2 *1) (-12 (-5 *1 (-131 *2)) (-4 *2 (-848)))) (-2971 (*1 *1 *2 *1) (-12 (-5 *1 (-131 *2)) (-4 *2 (-848)))) (-1585 (*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |less| (-131 *3)) (|:| |greater| (-131 *3)))) (-5 *1 (-131 *3)) (-4 *3 (-848))))) 
-(-13 (-135 |#1|) (-10 -8 (-6 -4603) (-6 -4602) (-15 -3394 ($ (-638 |#1|))) (-15 -1335 ($ |#1| $)) (-15 -2971 ($ |#1| $)) (-15 -1585 ((-2 (|:| |less| $) (|:| |greater| $)) |#1| $)))) 
-((-2004 (($ $) 14)) (-2959 (($ $) 11)) (-2117 (($ $ $) 24)) (-2084 (($ $ $) 22)) (-4174 (($ $) 12)) (-2235 (($ $ $) 20)) (-2226 (($ $ $) 18))) 
-(((-132 |#1|) (-10 -8 (-15 -2117 (|#1| |#1| |#1|)) (-15 -2084 (|#1| |#1| |#1|)) (-15 -4174 (|#1| |#1|)) (-15 -2959 (|#1| |#1|)) (-15 -2004 (|#1| |#1|)) (-15 -2226 (|#1| |#1| |#1|)) (-15 -2235 (|#1| |#1| |#1|))) (-133)) (T -132)) 
-NIL 
-(-10 -8 (-15 -2117 (|#1| |#1| |#1|)) (-15 -2084 (|#1| |#1| |#1|)) (-15 -4174 (|#1| |#1|)) (-15 -2959 (|#1| |#1|)) (-15 -2004 (|#1| |#1|)) (-15 -2226 (|#1| |#1| |#1|)) (-15 -2235 (|#1| |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-2004 (($ $) 103)) (-2992 (($ $ $) 24)) (-2430 (((-1264) $ (-572) (-572)) 66 (|has| $ (-6 -4603)))) (-2041 (((-121) $) 98 (|has| (-121) (-848))) (((-121) (-1 (-121) (-121) (-121)) $) 92)) (-4131 (($ $) 102 (-12 (|has| (-121) (-848)) (|has| $ (-6 -4603)))) (($ (-1 (-121) (-121) (-121)) $) 101 (|has| $ (-6 -4603)))) (-3008 (($ $) 97 (|has| (-121) (-848))) (($ (-1 (-121) (-121) (-121)) $) 91)) (-1946 (((-121) $ (-769)) 37)) (-3283 (((-121) $ (-1225 (-572)) (-121)) 88 (|has| $ (-6 -4603))) (((-121) $ (-572) (-121)) 54 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-121)) $) 71 (|has| $ (-6 -4602)))) (-2211 (($) 38 T CONST)) (-2985 (($ $) 100 (|has| $ (-6 -4603)))) (-1656 (($ $) 90)) (-1643 (($ $) 68 (-12 (|has| (-121) (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ (-1 (-121) (-121)) $) 72 (|has| $ (-6 -4602))) (($ (-121) $) 69 (-12 (|has| (-121) (-1098)) (|has| $ (-6 -4602))))) (-3116 (((-121) (-1 (-121) (-121) (-121)) $) 74 (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) 73 (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) 70 (-12 (|has| (-121) (-1098)) (|has| $ (-6 -4602))))) (-3037 (((-121) $ (-572) (-121)) 53 (|has| $ (-6 -4603)))) (-4212 (((-121) $ (-572)) 55)) (-4014 (((-572) (-121) $ (-572)) 95 (|has| (-121) (-1098))) (((-572) (-121) $) 94 (|has| (-121) (-1098))) (((-572) (-1 (-121) (-121)) $) 93)) (-2010 (((-638 (-121)) $) 45 (|has| $ (-6 -4602)))) (-2468 (($ $ $) 25)) (-2959 (($ $) 30)) (-2117 (($ $ $) 27)) (-1364 (($ (-769) (-121)) 77)) (-2084 (($ $ $) 28)) (-2157 (((-121) $ (-769)) 36)) (-3940 (((-572) $) 63 (|has| (-572) (-848)))) (-1771 (($ $ $) 12)) (-4475 (($ $ $) 96 (|has| (-121) (-848))) (($ (-1 (-121) (-121) (-121)) $ $) 89)) (-4467 (((-638 (-121)) $) 46 (|has| $ (-6 -4602)))) (-3002 (((-121) (-121) $) 48 (-12 (|has| (-121) (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 62 (|has| (-572) (-848)))) (-4238 (($ $ $) 13)) (-2435 (($ (-1 (-121) (-121)) $) 41 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-121) (-121) (-121)) $ $) 82) (($ (-1 (-121) (-121)) $) 40)) (-3524 (((-121) $ (-769)) 35)) (-1658 (((-1152) $) 9)) (-2603 (($ $ $ (-572)) 87) (($ (-121) $ (-572)) 86)) (-2739 (((-638 (-572)) $) 60)) (-1601 (((-121) (-572) $) 59)) (-2607 (((-1116) $) 10)) (-1837 (((-121) $) 64 (|has| (-572) (-848)))) (-3361 (((-3 (-121) "failed") (-1 (-121) (-121)) $) 75)) (-3299 (($ $ (-121)) 65 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-121)) $) 43 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-121)) (-638 (-121))) 52 (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-121) (-121)) 51 (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-290 (-121))) 50 (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-638 (-290 (-121)))) 49 (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098))))) (-3598 (((-121) $ $) 31)) (-3167 (((-121) (-121) $) 61 (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-2957 (((-638 (-121)) $) 58)) (-4037 (((-121) $) 34)) (-1665 (($) 33)) (-3277 (($ $ (-1225 (-572))) 83) (((-121) $ (-572)) 57) (((-121) $ (-572) (-121)) 56)) (-1940 (($ $ (-1225 (-572))) 85) (($ $ (-572)) 84)) (-1571 (((-769) (-121) $) 47 (-12 (|has| (-121) (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) (-121)) $) 44 (|has| $ (-6 -4602)))) (-2907 (($ $ $ (-572)) 99 (|has| $ (-6 -4603)))) (-1607 (($ $) 32)) (-4081 (((-545) $) 67 (|has| (-121) (-613 (-545))))) (-3921 (($ (-638 (-121))) 76)) (-4500 (($ (-638 $)) 81) (($ $ $) 80) (($ (-121) $) 79) (($ $ (-121)) 78)) (-3972 (((-856) $) 11)) (-3501 (((-121) (-1 (-121) (-121)) $) 42 (|has| $ (-6 -4602)))) (-4028 (($ $ $) 26)) (-4174 (($ $) 29)) (-2235 (($ $ $) 105)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (-2226 (($ $ $) 104)) (-4032 (((-769) $) 39 (|has| $ (-6 -4602))))) 
-(((-133) (-1290)) (T -133)) 
-((-2959 (*1 *1 *1) (-4 *1 (-133))) (-4174 (*1 *1 *1) (-4 *1 (-133))) (-2084 (*1 *1 *1 *1) (-4 *1 (-133))) (-2117 (*1 *1 *1 *1) (-4 *1 (-133))) (-4028 (*1 *1 *1 *1) (-4 *1 (-133))) (-2468 (*1 *1 *1 *1) (-4 *1 (-133))) (-2992 (*1 *1 *1 *1) (-4 *1 (-133)))) 
-(-13 (-848) (-655) (-19 (-121)) (-10 -8 (-15 -2959 ($ $)) (-15 -4174 ($ $)) (-15 -2084 ($ $ $)) (-15 -2117 ($ $ $)) (-15 -4028 ($ $ $)) (-15 -2468 ($ $ $)) (-15 -2992 ($ $ $)))) 
-(((-39) . T) ((-105) . T) ((-612 (-856)) . T) ((-155 (-121)) . T) ((-613 (-545)) |has| (-121) (-613 (-545))) ((-283 (-572) (-121)) . T) ((-285 (-572) (-121)) . T) ((-305 (-121)) -12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098))) ((-379 (-121)) . T) ((-503 (-121)) . T) ((-605 (-572) (-121)) . T) ((-527 (-121) (-121)) -12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098))) ((-644 (-121)) . T) ((-655) . T) ((-19 (-121)) . T) ((-848) . T) ((-1098) . T) ((-1204) . T)) 
-((-2435 (($ (-1 |#2| |#2|) $) 22)) (-1607 (($ $) 16)) (-4032 (((-769) $) 24))) 
-(((-134 |#1| |#2|) (-10 -8 (-15 -2435 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4032 ((-769) |#1|)) (-15 -1607 (|#1| |#1|))) (-135 |#2|) (-1098)) (T -134)) 
-NIL 
-(-10 -8 (-15 -2435 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4032 ((-769) |#1|)) (-15 -1607 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-2107 (($ $ $) 49 (|has| $ (-6 -4603)))) (-3184 (($ $ $) 51 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603))) (($ $ "left" $) 52 (|has| $ (-6 -4603))) (($ $ "right" $) 50 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-2211 (($) 7 T CONST)) (-1862 (($ $) 54)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-3486 (($ $ |#1| $) 57)) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1866 (($ $) 56)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44) (($ $ "left") 55) (($ $ "right") 53)) (-3537 (((-572) $ $) 41)) (-1791 (((-121) $) 43)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-135 |#1|) (-1290) (-1098)) (T -135)) 
-((-3486 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-135 *2)) (-4 *2 (-1098))))) 
-(-13 (-128 |t#1|) (-10 -8 (-6 -4603) (-6 -4602) (-15 -3486 ($ $ |t#1| $)))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-128 |#1|) . T) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1017 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) 15)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) 19 (|has| $ (-6 -4603)))) (-2107 (($ $ $) 20 (|has| $ (-6 -4603)))) (-3184 (($ $ $) 18 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) (($ $ "left" $) NIL (|has| $ (-6 -4603))) (($ $ "right" $) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-1862 (($ $) 21)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3486 (($ $ |#1| $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1866 (($ $) NIL)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-1335 (($ |#1| $) 10)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 14)) (-1665 (($) 8)) (-3277 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-3537 (((-572) $ $) NIL)) (-1791 (((-121) $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) 17)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3155 (($ (-638 |#1|)) 12)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-136 |#1|) (-13 (-135 |#1|) (-10 -8 (-6 -4603) (-15 -3155 ($ (-638 |#1|))) (-15 -1335 ($ |#1| $)))) (-848)) (T -136)) 
-((-3155 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-136 *3)))) (-1335 (*1 *1 *2 *1) (-12 (-5 *1 (-136 *2)) (-4 *2 (-848))))) 
-(-13 (-135 |#1|) (-10 -8 (-6 -4603) (-15 -3155 ($ (-638 |#1|))) (-15 -1335 ($ |#1| $)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) 24)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) 26 (|has| $ (-6 -4603)))) (-2107 (($ $ $) 30 (|has| $ (-6 -4603)))) (-3184 (($ $ $) 28 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) (($ $ "left" $) NIL (|has| $ (-6 -4603))) (($ $ "right" $) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-1862 (($ $) 20)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3486 (($ $ |#1| $) 15)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1866 (($ $) 19)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) 21)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 18)) (-1665 (($) 11)) (-3277 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-3537 (((-572) $ $) NIL)) (-1791 (((-121) $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4342 (($ |#1|) 17) (($ $ |#1| $) 16)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 10 (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-137 |#1|) (-13 (-135 |#1|) (-10 -8 (-15 -4342 ($ |#1|)) (-15 -4342 ($ $ |#1| $)))) (-1098)) (T -137)) 
-((-4342 (*1 *1 *2) (-12 (-5 *1 (-137 *2)) (-4 *2 (-1098)))) (-4342 (*1 *1 *1 *2 *1) (-12 (-5 *1 (-137 *2)) (-4 *2 (-1098))))) 
-(-13 (-135 |#1|) (-10 -8 (-15 -4342 ($ |#1|)) (-15 -4342 ($ $ |#1| $)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14))) 
-(((-138) (-1290)) (T -138)) 
-((-1572 (*1 *1 *1 *1) (|partial| -4 *1 (-138)))) 
-(-13 (-23) (-10 -8 (-15 -1572 ((-3 $ "failed") $ $)))) 
-(((-23) . T) ((-25) . T) ((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) 7)) (-2124 (((-1264) $ (-769)) 18)) (-4014 (((-769) $) 19)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17))) 
-(((-139) (-1290)) (T -139)) 
-((-4014 (*1 *2 *1) (-12 (-4 *1 (-139)) (-5 *2 (-769)))) (-2124 (*1 *2 *1 *3) (-12 (-4 *1 (-139)) (-5 *3 (-769)) (-5 *2 (-1264))))) 
-(-13 (-848) (-10 -8 (-15 -4014 ((-769) $)) (-15 -2124 ((-1264) $ (-769))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-848) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-769) "failed") $) 38)) (-1318 (((-769) $) 36)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) 26)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4133 (((-121)) 39)) (-3909 (((-121) (-121)) 41)) (-3508 (((-121) $) 23)) (-4506 (((-121) $) 35)) (-3972 (((-856) $) 22) (($ (-769)) 14)) (-4174 (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (-2378 (($) 12 T CONST)) (-3255 (($) 11 T CONST)) (-3480 (($ (-769)) 15)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 24)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 25)) (-1373 (((-3 $ "failed") $ $) 29)) (-1367 (($ $ $) 27)) (** (($ $ (-769)) NIL) (($ $ (-923)) NIL) (($ $ $) 34)) (* (($ (-769) $) 32) (($ (-923) $) NIL) (($ $ $) 30))) 
-(((-140) (-13 (-848) (-23) (-722) (-1044 (-769)) (-10 -8 (-6 (-4604 "*")) (-15 -1373 ((-3 $ "failed") $ $)) (-15 ** ($ $ $)) (-15 -3480 ($ (-769))) (-15 -3508 ((-121) $)) (-15 -4506 ((-121) $)) (-15 -4133 ((-121))) (-15 -3909 ((-121) (-121)))))) (T -140)) 
-((-1373 (*1 *1 *1 *1) (|partial| -5 *1 (-140))) (** (*1 *1 *1 *1) (-5 *1 (-140))) (-3480 (*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-140)))) (-3508 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-140)))) (-4506 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-140)))) (-4133 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-140)))) (-3909 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-140))))) 
-(-13 (-848) (-23) (-722) (-1044 (-769)) (-10 -8 (-6 (-4604 "*")) (-15 -1373 ((-3 $ "failed") $ $)) (-15 ** ($ $ $)) (-15 -3480 ($ (-769))) (-15 -3508 ((-121) $)) (-15 -4506 ((-121) $)) (-15 -4133 ((-121))) (-15 -3909 ((-121) (-121))))) 
-((-2675 (((-142 |#1| |#2| |#4|) (-638 |#4|) (-142 |#1| |#2| |#3|)) 14)) (-3828 (((-142 |#1| |#2| |#4|) (-1 |#4| |#3|) (-142 |#1| |#2| |#3|)) 18))) 
-(((-141 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2675 ((-142 |#1| |#2| |#4|) (-638 |#4|) (-142 |#1| |#2| |#3|))) (-15 -3828 ((-142 |#1| |#2| |#4|) (-1 |#4| |#3|) (-142 |#1| |#2| |#3|)))) (-572) (-769) (-174) (-174)) (T -141)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *7)) (-5 *4 (-142 *5 *6 *7)) (-14 *5 (-572)) (-14 *6 (-769)) (-4 *7 (-174)) (-4 *8 (-174)) (-5 *2 (-142 *5 *6 *8)) (-5 *1 (-141 *5 *6 *7 *8)))) (-2675 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-142 *5 *6 *7)) (-14 *5 (-572)) (-14 *6 (-769)) (-4 *7 (-174)) (-4 *8 (-174)) (-5 *2 (-142 *5 *6 *8)) (-5 *1 (-141 *5 *6 *7 *8))))) 
-(-10 -7 (-15 -2675 ((-142 |#1| |#2| |#4|) (-638 |#4|) (-142 |#1| |#2| |#3|))) (-15 -3828 ((-142 |#1| |#2| |#4|) (-1 |#4| |#3|) (-142 |#1| |#2| |#3|)))) 
-((-2262 (((-121) $ $) NIL)) (-3654 (($ (-638 |#3|)) 38)) (-1444 (($ $) 97) (($ $ (-572) (-572)) 96)) (-2211 (($) 17)) (-3376 (((-3 |#3| "failed") $) 58)) (-1318 ((|#3| $) NIL)) (-2886 (($ $ (-638 (-572))) 98)) (-4451 (((-638 |#3|) $) 34)) (-2667 (((-769) $) 42)) (-1642 (($ $ $) 91)) (-3144 (($) 41)) (-1658 (((-1152) $) NIL)) (-3303 (($) 16)) (-2607 (((-1116) $) NIL)) (-3277 ((|#3| $) 44) ((|#3| $ (-572)) 45) ((|#3| $ (-572) (-572)) 46) ((|#3| $ (-572) (-572) (-572)) 47) ((|#3| $ (-572) (-572) (-572) (-572)) 48) ((|#3| $ (-638 (-572))) 50)) (-4316 (((-769) $) 43)) (-1437 (($ $ (-572) $ (-572)) 92) (($ $ (-572) (-572)) 94)) (-3972 (((-856) $) 65) (($ |#3|) 66) (($ (-234 |#2| |#3|)) 73) (($ (-1135 |#2| |#3|)) 76) (($ (-638 |#3|)) 51) (($ (-638 $)) 56)) (-2378 (($) 67 T CONST)) (-3255 (($) 68 T CONST)) (-1324 (((-121) $ $) 78)) (-1373 (($ $) 84) (($ $ $) 82)) (-1367 (($ $ $) 80)) (* (($ |#3| $) 89) (($ $ |#3|) 90) (($ $ (-572)) 87) (($ (-572) $) 86) (($ $ $) 93))) 
-(((-142 |#1| |#2| |#3|) (-13 (-474 |#3| (-769)) (-479 (-572) (-769)) (-10 -8 (-15 -3972 ($ (-234 |#2| |#3|))) (-15 -3972 ($ (-1135 |#2| |#3|))) (-15 -3972 ($ (-638 |#3|))) (-15 -3972 ($ (-638 $))) (-15 -2667 ((-769) $)) (-15 -3277 (|#3| $)) (-15 -3277 (|#3| $ (-572))) (-15 -3277 (|#3| $ (-572) (-572))) (-15 -3277 (|#3| $ (-572) (-572) (-572))) (-15 -3277 (|#3| $ (-572) (-572) (-572) (-572))) (-15 -3277 (|#3| $ (-638 (-572)))) (-15 -1642 ($ $ $)) (-15 * ($ $ $)) (-15 -1437 ($ $ (-572) $ (-572))) (-15 -1437 ($ $ (-572) (-572))) (-15 -1444 ($ $)) (-15 -1444 ($ $ (-572) (-572))) (-15 -2886 ($ $ (-638 (-572)))) (-15 -3303 ($)) (-15 -3144 ($)) (-15 -4451 ((-638 |#3|) $)) (-15 -3654 ($ (-638 |#3|))) (-15 -2211 ($)))) (-572) (-769) (-174)) (T -142)) 
-((-1642 (*1 *1 *1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-234 *4 *5)) (-14 *4 (-769)) (-4 *5 (-174)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1135 *4 *5)) (-14 *4 (-769)) (-4 *5 (-174)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 *5)) (-4 *5 (-174)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-142 *3 *4 *5))) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)) (-4 *5 (-174)))) (-2667 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 *2) (-4 *5 (-174)))) (-3277 (*1 *2 *1) (-12 (-4 *2 (-174)) (-5 *1 (-142 *3 *4 *2)) (-14 *3 (-572)) (-14 *4 (-769)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-769)))) (-3277 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-769)))) (-3277 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-572)) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-769)))) (-3277 (*1 *2 *1 *3 *3 *3 *3) (-12 (-5 *3 (-572)) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-769)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-638 (-572))) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 (-572)) (-14 *5 (-769)))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) (-1437 (*1 *1 *1 *2 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-769)) (-4 *5 (-174)))) (-1437 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-769)) (-4 *5 (-174)))) (-1444 (*1 *1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) (-1444 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-769)) (-4 *5 (-174)))) (-2886 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)) (-4 *5 (-174)))) (-3303 (*1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) (-3144 (*1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) (-4451 (*1 *2 *1) (-12 (-5 *2 (-638 *5)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)) (-4 *5 (-174)))) (-3654 (*1 *1 *2) (-12 (-5 *2 (-638 *5)) (-4 *5 (-174)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)))) (-2211 (*1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174))))) 
-(-13 (-474 |#3| (-769)) (-479 (-572) (-769)) (-10 -8 (-15 -3972 ($ (-234 |#2| |#3|))) (-15 -3972 ($ (-1135 |#2| |#3|))) (-15 -3972 ($ (-638 |#3|))) (-15 -3972 ($ (-638 $))) (-15 -2667 ((-769) $)) (-15 -3277 (|#3| $)) (-15 -3277 (|#3| $ (-572))) (-15 -3277 (|#3| $ (-572) (-572))) (-15 -3277 (|#3| $ (-572) (-572) (-572))) (-15 -3277 (|#3| $ (-572) (-572) (-572) (-572))) (-15 -3277 (|#3| $ (-638 (-572)))) (-15 -1642 ($ $ $)) (-15 * ($ $ $)) (-15 -1437 ($ $ (-572) $ (-572))) (-15 -1437 ($ $ (-572) (-572))) (-15 -1444 ($ $)) (-15 -1444 ($ $ (-572) (-572))) (-15 -2886 ($ $ (-638 (-572)))) (-15 -3303 ($)) (-15 -3144 ($)) (-15 -4451 ((-638 |#3|) $)) (-15 -3654 ($ (-638 |#3|))) (-15 -2211 ($)))) 
-((-2262 (((-121) $ $) NIL)) (-4013 (($) 15 T CONST)) (-1554 (($) NIL (|has| (-148) (-374)))) (-3518 (($ $ $) 17) (($ $ (-148)) NIL) (($ (-148) $) NIL)) (-3710 (($ $ $) NIL)) (-3771 (((-121) $ $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-1685 (((-769)) NIL (|has| (-148) (-374)))) (-4462 (($) NIL) (($ (-638 (-148))) NIL)) (-1550 (($ (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-1544 (($ (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602))) (($ (-148) $) 51 (|has| $ (-6 -4602)))) (-3445 (($ (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602))) (($ (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-3116 (((-148) (-1 (-148) (-148) (-148)) $) NIL (|has| $ (-6 -4602))) (((-148) (-1 (-148) (-148) (-148)) $ (-148)) NIL (|has| $ (-6 -4602))) (((-148) (-1 (-148) (-148) (-148)) $ (-148) (-148)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-3286 (($) NIL (|has| (-148) (-374)))) (-2010 (((-638 (-148)) $) 60 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-1771 (((-148) $) NIL (|has| (-148) (-848)))) (-4467 (((-638 (-148)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-148) $) 26 (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-4238 (((-148) $) NIL (|has| (-148) (-848)))) (-2435 (($ (-1 (-148) (-148)) $) 59 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-148) (-148)) $) 55)) (-2676 (($) 16 T CONST)) (-3633 (((-923) $) NIL (|has| (-148) (-374)))) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-1931 (($ $ $) 29)) (-4221 (((-148) $) 52)) (-1335 (($ (-148) $) 50)) (-1763 (($ (-923)) NIL (|has| (-148) (-374)))) (-3732 (($) 14 T CONST)) (-2607 (((-1116) $) NIL)) (-3361 (((-3 (-148) "failed") (-1 (-121) (-148)) $) NIL)) (-2232 (((-148) $) 53)) (-2109 (((-121) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-148)) (-638 (-148))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-148) (-148)) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-290 (-148))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-638 (-290 (-148)))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3587 (((-638 $)) NIL (|has| (-148) (-374)))) (-4037 (((-121) $) NIL)) (-1665 (($) 48)) (-3738 (($) 13 T CONST)) (-3982 (($ $ $) 31) (($ $ (-148)) NIL)) (-1535 (($ (-638 (-148))) NIL) (($) NIL)) (-1571 (((-769) (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098)))) (((-769) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-1152) $) 36) (((-545) $) NIL (|has| (-148) (-613 (-545)))) (((-638 (-148)) $) 34)) (-3921 (($ (-638 (-148))) NIL)) (-3563 (($ $) 32 (|has| (-148) (-374)))) (-3972 (((-856) $) 46)) (-2128 (($ (-1152)) 12) (($ (-638 (-148))) 43)) (-1961 (((-769) $) NIL)) (-1599 (($) 49) (($ (-638 (-148))) NIL)) (-3058 (($ (-638 (-148))) NIL)) (-3501 (((-121) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-3705 (($) 19 T CONST)) (-2125 (($) 18 T CONST)) (-1324 (((-121) $ $) 22)) (-1334 (((-121) $ $) NIL)) (-4032 (((-769) $) 47 (|has| $ (-6 -4602))))) 
-(((-143) (-13 (-1098) (-613 (-1152)) (-431 (-148)) (-613 (-638 (-148))) (-10 -8 (-15 -2128 ($ (-1152))) (-15 -2128 ($ (-638 (-148)))) (-15 -3738 ($) -3211) (-15 -3732 ($) -3211) (-15 -4013 ($) -3211) (-15 -2676 ($) -3211) (-15 -2125 ($) -3211) (-15 -3705 ($) -3211)))) (T -143)) 
-((-2128 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-143)))) (-2128 (*1 *1 *2) (-12 (-5 *2 (-638 (-148))) (-5 *1 (-143)))) (-3738 (*1 *1) (-5 *1 (-143))) (-3732 (*1 *1) (-5 *1 (-143))) (-4013 (*1 *1) (-5 *1 (-143))) (-2676 (*1 *1) (-5 *1 (-143))) (-2125 (*1 *1) (-5 *1 (-143))) (-3705 (*1 *1) (-5 *1 (-143)))) 
-(-13 (-1098) (-613 (-1152)) (-431 (-148)) (-613 (-638 (-148))) (-10 -8 (-15 -2128 ($ (-1152))) (-15 -2128 ($ (-638 (-148)))) (-15 -3738 ($) -3211) (-15 -3732 ($) -3211) (-15 -4013 ($) -3211) (-15 -2676 ($) -3211) (-15 -2125 ($) -3211) (-15 -3705 ($) -3211))) 
-((-1518 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) 17)) (-3559 ((|#1| |#3|) 9)) (-1443 ((|#3| |#3|) 15))) 
-(((-144 |#1| |#2| |#3|) (-10 -7 (-15 -3559 (|#1| |#3|)) (-15 -1443 (|#3| |#3|)) (-15 -1518 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) (-562) (-1000 |#1|) (-379 |#2|)) (T -144)) 
-((-1518 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-1000 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-144 *4 *5 *3)) (-4 *3 (-379 *5)))) (-1443 (*1 *2 *2) (-12 (-4 *3 (-562)) (-4 *4 (-1000 *3)) (-5 *1 (-144 *3 *4 *2)) (-4 *2 (-379 *4)))) (-3559 (*1 *2 *3) (-12 (-4 *4 (-1000 *2)) (-4 *2 (-562)) (-5 *1 (-144 *2 *4 *3)) (-4 *3 (-379 *4))))) 
-(-10 -7 (-15 -3559 (|#1| |#3|)) (-15 -1443 (|#3| |#3|)) (-15 -1518 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) 
-((-2262 (((-121) $ $) NIL (|has| (-171 (-217)) (-1098)))) (-4169 (($ (-769) (-769)) NIL)) (-2113 (($ $ $) NIL)) (-1444 (($ (-146)) NIL) (($ $) NIL)) (-3083 (((-121) $) NIL)) (-3861 (($ $ (-572) (-572)) NIL)) (-3595 (($ $ (-572) (-572)) NIL)) (-4152 (($ $ (-572) (-572) (-572) (-572)) NIL)) (-4369 (($ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2569 (($ $ (-572) (-572) $) NIL)) (-3283 (((-171 (-217)) $ (-572) (-572) (-171 (-217))) NIL) (($ $ (-638 (-572)) (-638 (-572)) $) NIL)) (-1823 (($ $ (-572) (-146)) NIL)) (-1695 (($ $ (-572) (-146)) NIL)) (-1468 (($ (-769) (-171 (-217))) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) NIL (|has| (-171 (-217)) (-303)))) (-4267 (((-146) $ (-572)) NIL)) (-2667 (((-769) $) NIL (|has| (-171 (-217)) (-562)))) (-3037 (((-171 (-217)) $ (-572) (-572) (-171 (-217))) 16)) (-3596 (($ (-572) (-572)) 18)) (-4212 (((-171 (-217)) $ (-572) (-572)) 15)) (-4439 (((-171 (-217)) $) NIL (|has| (-171 (-217)) (-174)))) (-2010 (((-638 (-171 (-217))) $) NIL)) (-3095 (((-769) $) NIL (|has| (-171 (-217)) (-562)))) (-1301 (((-638 (-146)) $) NIL (|has| (-171 (-217)) (-562)))) (-3704 (((-769) $) 10)) (-1364 (($ (-769) (-769) (-171 (-217))) 19)) (-3712 (((-769) $) 11)) (-2157 (((-121) $ (-769)) NIL)) (-1522 (((-171 (-217)) $) NIL (|has| (-171 (-217)) (-6 (-4604 "*"))))) (-2660 (((-572) $) 7)) (-3092 (((-572) $) 8)) (-4467 (((-638 (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-171 (-217)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-171 (-217)) (-1098))))) (-3927 (((-572) $) 12)) (-3227 (((-572) $) 13)) (-3597 (($ (-638 (-638 (-171 (-217))))) NIL) (($ (-769) (-769) (-1 (-171 (-217)) (-572) (-572))) NIL)) (-2435 (($ (-1 (-171 (-217)) (-171 (-217))) $) NIL)) (-3828 (($ (-1 (-171 (-217)) (-171 (-217))) $) NIL) (($ (-1 (-171 (-217)) (-171 (-217)) (-171 (-217))) $ $) NIL) (($ (-1 (-171 (-217)) (-171 (-217)) (-171 (-217))) $ $ (-171 (-217))) NIL)) (-2259 (((-638 (-638 (-171 (-217)))) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| (-171 (-217)) (-1098)))) (-3750 (((-3 $ "failed") $) NIL (|has| (-171 (-217)) (-368)))) (-1865 (($ $ $) NIL)) (-2607 (((-1116) $) NIL (|has| (-171 (-217)) (-1098)))) (-3299 (($ $ (-171 (-217))) NIL)) (-1803 (((-3 $ "failed") $ (-171 (-217))) NIL (|has| (-171 (-217)) (-562)))) (-2109 (((-121) (-1 (-121) (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-171 (-217))))) NIL (-12 (|has| (-171 (-217)) (-305 (-171 (-217)))) (|has| (-171 (-217)) (-1098)))) (($ $ (-290 (-171 (-217)))) NIL (-12 (|has| (-171 (-217)) (-305 (-171 (-217)))) (|has| (-171 (-217)) (-1098)))) (($ $ (-171 (-217)) (-171 (-217))) NIL (-12 (|has| (-171 (-217)) (-305 (-171 (-217)))) (|has| (-171 (-217)) (-1098)))) (($ $ (-638 (-171 (-217))) (-638 (-171 (-217)))) NIL (-12 (|has| (-171 (-217)) (-305 (-171 (-217)))) (|has| (-171 (-217)) (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 17)) (-3277 (((-171 (-217)) $ (-572) (-572)) NIL) (((-171 (-217)) $ (-572) (-572) (-171 (-217))) NIL) (($ $ (-638 (-572)) (-638 (-572))) NIL)) (-3132 (($ (-638 (-171 (-217)))) NIL) (($ (-638 $)) NIL)) (-3785 (((-121) $) NIL)) (-2271 (((-171 (-217)) $) NIL (|has| (-171 (-217)) (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) (-171 (-217))) $) NIL (|has| $ (-6 -4602))) (((-769) (-171 (-217)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-171 (-217)) (-1098))))) (-1607 (($ $) NIL)) (-1802 (((-638 (-146)) $) NIL (|has| (-171 (-217)) (-303)))) (-4580 (((-146) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| (-171 (-217)) (-1098))) (($ (-146)) NIL)) (-3501 (((-121) (-1 (-121) (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL (|has| (-171 (-217)) (-1098)))) (-1379 (($ $ (-171 (-217))) NIL (|has| (-171 (-217)) (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-171 (-217)) (-368)))) (* (($ $ $) NIL) (($ (-171 (-217)) $) NIL) (($ $ (-171 (-217))) NIL) (($ (-572) $) NIL) (((-146) $ (-146)) NIL) (((-146) (-146) $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-145) (-13 (-683 (-171 (-217)) (-146) (-146)) (-10 -8 (-15 -3596 ($ (-572) (-572)))))) (T -145)) 
-((-3596 (*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-145))))) 
-(-13 (-683 (-171 (-217)) (-146) (-146)) (-10 -8 (-15 -3596 ($ (-572) (-572))))) 
-((-2262 (((-121) $ $) NIL (|has| (-171 (-217)) (-1098)))) (-4169 (($ (-769)) NIL (|has| (-171 (-217)) (-23)))) (-3156 (($ (-638 (-171 (-217)))) NIL)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) (-171 (-217)) (-171 (-217))) $) NIL) (((-121) $) NIL (|has| (-171 (-217)) (-848)))) (-4131 (($ (-1 (-121) (-171 (-217)) (-171 (-217))) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-171 (-217)) (-848))))) (-3008 (($ (-1 (-121) (-171 (-217)) (-171 (-217))) $) NIL) (($ $) NIL (|has| (-171 (-217)) (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-171 (-217)) $ (-572) (-171 (-217))) 18 (|has| $ (-6 -4603))) (((-171 (-217)) $ (-1225 (-572)) (-171 (-217))) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-171 (-217)) (-1098))))) (-3445 (($ (-171 (-217)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-171 (-217)) (-1098)))) (($ (-1 (-121) (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-171 (-217)) (-1 (-171 (-217)) (-171 (-217)) (-171 (-217))) $ (-171 (-217)) (-171 (-217))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-171 (-217)) (-1098)))) (((-171 (-217)) (-1 (-171 (-217)) (-171 (-217)) (-171 (-217))) $ (-171 (-217))) NIL (|has| $ (-6 -4602))) (((-171 (-217)) (-1 (-171 (-217)) (-171 (-217)) (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-171 (-217)) $ (-572) (-171 (-217))) 9 (|has| $ (-6 -4603)))) (-3596 (($ (-572)) 14)) (-4212 (((-171 (-217)) $ (-572)) 8)) (-4014 (((-572) (-1 (-121) (-171 (-217))) $) NIL) (((-572) (-171 (-217)) $) NIL (|has| (-171 (-217)) (-1098))) (((-572) (-171 (-217)) $ (-572)) NIL (|has| (-171 (-217)) (-1098)))) (-2010 (((-638 (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-3349 (((-685 (-171 (-217))) $ $) NIL (|has| (-171 (-217)) (-1054)))) (-1364 (($ (-769) (-171 (-217))) 16)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 12 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| (-171 (-217)) (-848)))) (-4475 (($ (-1 (-121) (-171 (-217)) (-171 (-217))) $ $) NIL) (($ $ $) NIL (|has| (-171 (-217)) (-848)))) (-4467 (((-638 (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-171 (-217)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-171 (-217)) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-171 (-217)) (-848)))) (-2435 (($ (-1 (-171 (-217)) (-171 (-217))) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-171 (-217)) (-171 (-217))) $) NIL) (($ (-1 (-171 (-217)) (-171 (-217)) (-171 (-217))) $ $) NIL)) (-3169 (((-171 (-217)) $) NIL (-12 (|has| (-171 (-217)) (-1009)) (|has| (-171 (-217)) (-1054))))) (-3524 (((-121) $ (-769)) NIL)) (-3200 (((-171 (-217)) $) NIL (-12 (|has| (-171 (-217)) (-1009)) (|has| (-171 (-217)) (-1054))))) (-1658 (((-1152) $) NIL (|has| (-171 (-217)) (-1098)))) (-2603 (($ (-171 (-217)) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| (-171 (-217)) (-1098)))) (-1837 (((-171 (-217)) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-171 (-217)) "failed") (-1 (-121) (-171 (-217))) $) NIL)) (-3299 (($ $ (-171 (-217))) 15 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-171 (-217))))) NIL (-12 (|has| (-171 (-217)) (-305 (-171 (-217)))) (|has| (-171 (-217)) (-1098)))) (($ $ (-290 (-171 (-217)))) NIL (-12 (|has| (-171 (-217)) (-305 (-171 (-217)))) (|has| (-171 (-217)) (-1098)))) (($ $ (-171 (-217)) (-171 (-217))) NIL (-12 (|has| (-171 (-217)) (-305 (-171 (-217)))) (|has| (-171 (-217)) (-1098)))) (($ $ (-638 (-171 (-217))) (-638 (-171 (-217)))) NIL (-12 (|has| (-171 (-217)) (-305 (-171 (-217)))) (|has| (-171 (-217)) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-171 (-217)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-171 (-217)) (-1098))))) (-2957 (((-638 (-171 (-217))) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 13)) (-3277 (((-171 (-217)) $ (-572) (-171 (-217))) NIL) (((-171 (-217)) $ (-572)) 17) (($ $ (-1225 (-572))) NIL)) (-1436 (((-171 (-217)) $ $) NIL (|has| (-171 (-217)) (-1054)))) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-3780 (($ $ $) NIL (|has| (-171 (-217)) (-1054)))) (-1571 (((-769) (-1 (-121) (-171 (-217))) $) NIL (|has| $ (-6 -4602))) (((-769) (-171 (-217)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-171 (-217)) (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-171 (-217)) (-613 (-545))))) (-3921 (($ (-638 (-171 (-217)))) NIL)) (-4500 (($ $ (-171 (-217))) NIL) (($ (-171 (-217)) $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| (-171 (-217)) (-1098)))) (-3501 (((-121) (-1 (-121) (-171 (-217))) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| (-171 (-217)) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-171 (-217)) (-848)))) (-1324 (((-121) $ $) NIL (|has| (-171 (-217)) (-1098)))) (-1343 (((-121) $ $) NIL (|has| (-171 (-217)) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-171 (-217)) (-848)))) (-1373 (($ $) NIL (|has| (-171 (-217)) (-21))) (($ $ $) NIL (|has| (-171 (-217)) (-21)))) (-1367 (($ $ $) NIL (|has| (-171 (-217)) (-25)))) (* (($ (-572) $) NIL (|has| (-171 (-217)) (-21))) (($ (-171 (-217)) $) NIL (|has| (-171 (-217)) (-722))) (($ $ (-171 (-217))) NIL (|has| (-171 (-217)) (-722)))) (-4032 (((-769) $) 11 (|has| $ (-6 -4602))))) 
-(((-146) (-13 (-1257 (-171 (-217))) (-10 -8 (-15 -3596 ($ (-572))) (-15 -3156 ($ (-638 (-171 (-217)))))))) (T -146)) 
-((-3596 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-146)))) (-3156 (*1 *1 *2) (-12 (-5 *2 (-638 (-171 (-217)))) (-5 *1 (-146))))) 
-(-13 (-1257 (-171 (-217))) (-10 -8 (-15 -3596 ($ (-572))) (-15 -3156 ($ (-638 (-171 (-217))))))) 
-((-2133 (($ $ $) 8)) (-2900 (($ $) 7)) (-3610 (($ $ $) 6))) 
-(((-147) (-1290)) (T -147)) 
-((-2133 (*1 *1 *1 *1) (-4 *1 (-147))) (-2900 (*1 *1 *1) (-4 *1 (-147))) (-3610 (*1 *1 *1 *1) (-4 *1 (-147)))) 
-(-13 (-10 -8 (-15 -3610 ($ $ $)) (-15 -2900 ($ $)) (-15 -2133 ($ $ $)))) 
-((-2262 (((-121) $ $) NIL)) (-2129 (((-121) $) 38)) (-4013 (($ $) 50)) (-3022 (($) 25)) (-1685 (((-769)) 16)) (-3286 (($) 24)) (-2467 (($) 26)) (-3306 (((-572) $) 21)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3176 (((-121) $) 40)) (-2676 (($ $) 51)) (-3633 (((-923) $) 22)) (-1658 (((-1152) $) 46)) (-1763 (($ (-923)) 20)) (-4006 (((-121) $) 36)) (-2607 (((-1116) $) NIL)) (-3832 (($) 27)) (-3587 (((-638 $)) NIL)) (-2809 (((-121) $) 34)) (-3972 (((-856) $) 29)) (-2015 (($ (-572)) 18) (($ (-1152)) 49)) (-3240 (((-121) $) 44)) (-3680 (((-121) $) 42)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 13)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 14))) 
-(((-148) (-13 (-842) (-10 -8 (-15 -3306 ((-572) $)) (-15 -2015 ($ (-572))) (-15 -2015 ($ (-1152))) (-15 -3022 ($)) (-15 -2467 ($)) (-15 -3832 ($)) (-15 -4013 ($ $)) (-15 -2676 ($ $)) (-15 -2809 ((-121) $)) (-15 -4006 ((-121) $)) (-15 -3680 ((-121) $)) (-15 -2129 ((-121) $)) (-15 -3176 ((-121) $)) (-15 -3240 ((-121) $))))) (T -148)) 
-((-3306 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-148)))) (-2015 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-148)))) (-2015 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-148)))) (-3022 (*1 *1) (-5 *1 (-148))) (-2467 (*1 *1) (-5 *1 (-148))) (-3832 (*1 *1) (-5 *1 (-148))) (-4013 (*1 *1 *1) (-5 *1 (-148))) (-2676 (*1 *1 *1) (-5 *1 (-148))) (-2809 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148)))) (-4006 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148)))) (-3680 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148)))) (-2129 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148)))) (-3176 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148)))) (-3240 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148))))) 
-(-13 (-842) (-10 -8 (-15 -3306 ((-572) $)) (-15 -2015 ($ (-572))) (-15 -2015 ($ (-1152))) (-15 -3022 ($)) (-15 -2467 ($)) (-15 -3832 ($)) (-15 -4013 ($ $)) (-15 -2676 ($ $)) (-15 -2809 ((-121) $)) (-15 -4006 ((-121) $)) (-15 -3680 ((-121) $)) (-15 -2129 ((-121) $)) (-15 -3176 ((-121) $)) (-15 -3240 ((-121) $)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2779 (((-3 $ "failed") $) 34)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-149) (-1290)) (T -149)) 
-((-2779 (*1 *1 *1) (|partial| -4 *1 (-149)))) 
-(-13 (-1054) (-10 -8 (-15 -2779 ((-3 $ "failed") $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2707 ((|#1| (-685 |#1|) |#1|) 17))) 
-(((-150 |#1|) (-10 -7 (-15 -2707 (|#1| (-685 |#1|) |#1|))) (-174)) (T -150)) 
-((-2707 (*1 *2 *3 *2) (-12 (-5 *3 (-685 *2)) (-4 *2 (-174)) (-5 *1 (-150 *2))))) 
-(-10 -7 (-15 -2707 (|#1| (-685 |#1|) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-151) (-1290)) (T -151)) 
-NIL 
-(-13 (-1054)) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3973 (((-2 (|:| -3751 (-769)) (|:| -4513 (-413 |#2|)) (|:| |radicand| |#2|)) (-413 |#2|) (-769)) 69)) (-4537 (((-3 (-2 (|:| |radicand| (-413 |#2|)) (|:| |deg| (-769))) "failed") |#3|) 51)) (-3930 (((-2 (|:| -4513 (-413 |#2|)) (|:| |poly| |#3|)) |#3|) 36)) (-3335 ((|#1| |#3| |#3|) 39)) (-4485 ((|#3| |#3| (-413 |#2|) (-413 |#2|)) 19)) (-4018 (((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-413 |#2|)) (|:| |c2| (-413 |#2|)) (|:| |deg| (-769))) |#3| |#3|) 48))) 
-(((-152 |#1| |#2| |#3|) (-10 -7 (-15 -3930 ((-2 (|:| -4513 (-413 |#2|)) (|:| |poly| |#3|)) |#3|)) (-15 -4537 ((-3 (-2 (|:| |radicand| (-413 |#2|)) (|:| |deg| (-769))) "failed") |#3|)) (-15 -3973 ((-2 (|:| -3751 (-769)) (|:| -4513 (-413 |#2|)) (|:| |radicand| |#2|)) (-413 |#2|) (-769))) (-15 -3335 (|#1| |#3| |#3|)) (-15 -4485 (|#3| |#3| (-413 |#2|) (-413 |#2|))) (-15 -4018 ((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-413 |#2|)) (|:| |c2| (-413 |#2|)) (|:| |deg| (-769))) |#3| |#3|))) (-1214) (-1234 |#1|) (-1234 (-413 |#2|))) (T -152)) 
-((-4018 (*1 *2 *3 *3) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (-413 *5)) (|:| |c2| (-413 *5)) (|:| |deg| (-769)))) (-5 *1 (-152 *4 *5 *3)) (-4 *3 (-1234 (-413 *5))))) (-4485 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-413 *5)) (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-5 *1 (-152 *4 *5 *2)) (-4 *2 (-1234 *3)))) (-3335 (*1 *2 *3 *3) (-12 (-4 *4 (-1234 *2)) (-4 *2 (-1214)) (-5 *1 (-152 *2 *4 *3)) (-4 *3 (-1234 (-413 *4))))) (-3973 (*1 *2 *3 *4) (-12 (-5 *3 (-413 *6)) (-4 *5 (-1214)) (-4 *6 (-1234 *5)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *3) (|:| |radicand| *6))) (-5 *1 (-152 *5 *6 *7)) (-5 *4 (-769)) (-4 *7 (-1234 *3)))) (-4537 (*1 *2 *3) (|partial| -12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| |radicand| (-413 *5)) (|:| |deg| (-769)))) (-5 *1 (-152 *4 *5 *3)) (-4 *3 (-1234 (-413 *5))))) (-3930 (*1 *2 *3) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -4513 (-413 *5)) (|:| |poly| *3))) (-5 *1 (-152 *4 *5 *3)) (-4 *3 (-1234 (-413 *5)))))) 
-(-10 -7 (-15 -3930 ((-2 (|:| -4513 (-413 |#2|)) (|:| |poly| |#3|)) |#3|)) (-15 -4537 ((-3 (-2 (|:| |radicand| (-413 |#2|)) (|:| |deg| (-769))) "failed") |#3|)) (-15 -3973 ((-2 (|:| -3751 (-769)) (|:| -4513 (-413 |#2|)) (|:| |radicand| |#2|)) (-413 |#2|) (-769))) (-15 -3335 (|#1| |#3| |#3|)) (-15 -4485 (|#3| |#3| (-413 |#2|) (-413 |#2|))) (-15 -4018 ((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-413 |#2|)) (|:| |c2| (-413 |#2|)) (|:| |deg| (-769))) |#3| |#3|))) 
-((-2462 (((-3 (-638 (-1166 |#2|)) "failed") (-638 (-1166 |#2|)) (-1166 |#2|)) 31))) 
-(((-153 |#1| |#2|) (-10 -7 (-15 -2462 ((-3 (-638 (-1166 |#2|)) "failed") (-638 (-1166 |#2|)) (-1166 |#2|)))) (-554) (-168 |#1|)) (T -153)) 
-((-2462 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *5))) (-5 *3 (-1166 *5)) (-4 *5 (-168 *4)) (-4 *4 (-554)) (-5 *1 (-153 *4 *5))))) 
-(-10 -7 (-15 -2462 ((-3 (-638 (-1166 |#2|)) "failed") (-638 (-1166 |#2|)) (-1166 |#2|)))) 
-((-2561 (($ (-1 (-121) |#2|) $) 29)) (-1643 (($ $) 36)) (-3445 (($ (-1 (-121) |#2|) $) 27) (($ |#2| $) 32)) (-3116 ((|#2| (-1 |#2| |#2| |#2|) $) 22) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 24) ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 34)) (-3361 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 19)) (-2109 (((-121) (-1 (-121) |#2|) $) 16)) (-1571 (((-769) (-1 (-121) |#2|) $) 13) (((-769) |#2| $) NIL)) (-3501 (((-121) (-1 (-121) |#2|) $) 15)) (-4032 (((-769) $) 11))) 
-(((-154 |#1| |#2|) (-10 -8 (-15 -1643 (|#1| |#1|)) (-15 -3445 (|#1| |#2| |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2561 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3445 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3361 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -1571 ((-769) |#2| |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -4032 ((-769) |#1|))) (-155 |#2|) (-1204)) (T -154)) 
-NIL 
-(-10 -8 (-15 -1643 (|#1| |#1|)) (-15 -3445 (|#1| |#2| |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2561 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3445 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3361 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -1571 ((-769) |#2| |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -4032 ((-769) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-2561 (($ (-1 (-121) |#1|) $) 41 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-1643 (($ $) 38 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4602))) (($ |#1| $) 39 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $) 44 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 43 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 40 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 45)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 37 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 46)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-155 |#1|) (-1290) (-1204)) (T -155)) 
-((-3921 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-4 *1 (-155 *3)))) (-3361 (*1 *2 *3 *1) (|partial| -12 (-5 *3 (-1 (-121) *2)) (-4 *1 (-155 *2)) (-4 *2 (-1204)))) (-3116 (*1 *2 *3 *1) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)))) (-3116 (*1 *2 *3 *1 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)))) (-3445 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *3)) (-4 *3 (-1204)))) (-2561 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *3)) (-4 *3 (-1204)))) (-3116 (*1 *2 *3 *1 *2 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1098)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)))) (-3445 (*1 *1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)) (-4 *2 (-1098)))) (-1643 (*1 *1 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)) (-4 *2 (-1098))))) 
-(-13 (-503 |t#1|) (-10 -8 (-15 -3921 ($ (-638 |t#1|))) (-15 -3361 ((-3 |t#1| "failed") (-1 (-121) |t#1|) $)) (IF (|has| $ (-6 -4602)) (PROGN (-15 -3116 (|t#1| (-1 |t#1| |t#1| |t#1|) $)) (-15 -3116 (|t#1| (-1 |t#1| |t#1| |t#1|) $ |t#1|)) (-15 -3445 ($ (-1 (-121) |t#1|) $)) (-15 -2561 ($ (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1098)) (PROGN (-15 -3116 (|t#1| (-1 |t#1| |t#1| |t#1|) $ |t#1| |t#1|)) (-15 -3445 ($ |t#1| $)) (-15 -1643 ($ $))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) 85)) (-3893 (((-121) $) NIL)) (-4328 (($ |#2| (-638 (-923))) 56)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4300 (($ (-923)) 48)) (-2502 (((-140)) 23)) (-3972 (((-856) $) 68) (($ (-572)) 46) (($ |#2|) 47)) (-1958 ((|#2| $ (-638 (-923))) 58)) (-2140 (((-769)) 20)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 40 T CONST)) (-3255 (($) 44 T CONST)) (-1324 (((-121) $ $) 26)) (-1379 (($ $ |#2|) NIL)) (-1373 (($ $) 34) (($ $ $) 32)) (-1367 (($ $ $) 30)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 37) (($ $ $) 52) (($ |#2| $) 39) (($ $ |#2|) NIL))) 
-(((-156 |#1| |#2| |#3|) (-13 (-1054) (-43 |#2|) (-1266 |#2|) (-10 -8 (-15 -4300 ($ (-923))) (-15 -4328 ($ |#2| (-638 (-923)))) (-15 -1958 (|#2| $ (-638 (-923)))) (-15 -1799 ((-3 $ "failed") $)))) (-923) (-368) (-1001 |#1| |#2|)) (T -156)) 
-((-1799 (*1 *1 *1) (|partial| -12 (-5 *1 (-156 *2 *3 *4)) (-14 *2 (-923)) (-4 *3 (-368)) (-14 *4 (-1001 *2 *3)))) (-4300 (*1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-156 *3 *4 *5)) (-14 *3 *2) (-4 *4 (-368)) (-14 *5 (-1001 *3 *4)))) (-4328 (*1 *1 *2 *3) (-12 (-5 *3 (-638 (-923))) (-5 *1 (-156 *4 *2 *5)) (-14 *4 (-923)) (-4 *2 (-368)) (-14 *5 (-1001 *4 *2)))) (-1958 (*1 *2 *1 *3) (-12 (-5 *3 (-638 (-923))) (-4 *2 (-368)) (-5 *1 (-156 *4 *2 *5)) (-14 *4 (-923)) (-14 *5 (-1001 *4 *2))))) 
-(-13 (-1054) (-43 |#2|) (-1266 |#2|) (-10 -8 (-15 -4300 ($ (-923))) (-15 -4328 ($ |#2| (-638 (-923)))) (-15 -1958 (|#2| $ (-638 (-923)))) (-15 -1799 ((-3 $ "failed") $)))) 
-((-2764 (((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-638 (-950 (-217)))) (-217) (-217) (-217) (-217)) 38)) (-3980 (((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933) (-413 (-572)) (-413 (-572))) 62) (((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933)) 63)) (-3439 (((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-638 (-950 (-217))))) 66) (((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-950 (-217)))) 65) (((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933) (-413 (-572)) (-413 (-572))) 57) (((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933)) 58))) 
-(((-157) (-10 -7 (-15 -3439 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933))) (-15 -3439 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933) (-413 (-572)) (-413 (-572)))) (-15 -3980 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933))) (-15 -3980 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933) (-413 (-572)) (-413 (-572)))) (-15 -2764 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-638 (-950 (-217)))) (-217) (-217) (-217) (-217))) (-15 -3439 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-950 (-217))))) (-15 -3439 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-638 (-950 (-217)))))))) (T -157)) 
-((-3439 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)) (-5 *3 (-638 (-638 (-950 (-217))))))) (-3439 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)) (-5 *3 (-638 (-950 (-217)))))) (-2764 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *4 (-217)) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 *4)))) (|:| |xValues| (-1092 *4)) (|:| |yValues| (-1092 *4)))) (-5 *1 (-157)) (-5 *3 (-638 (-638 (-950 *4)))))) (-3980 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-933)) (-5 *4 (-413 (-572))) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)))) (-3980 (*1 *2 *3) (-12 (-5 *3 (-933)) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)))) (-3439 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-933)) (-5 *4 (-413 (-572))) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)))) (-3439 (*1 *2 *3) (-12 (-5 *3 (-933)) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157))))) 
-(-10 -7 (-15 -3439 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933))) (-15 -3439 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933) (-413 (-572)) (-413 (-572)))) (-15 -3980 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933))) (-15 -3980 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-933) (-413 (-572)) (-413 (-572)))) (-15 -2764 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-638 (-950 (-217)))) (-217) (-217) (-217) (-217))) (-15 -3439 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-950 (-217))))) (-15 -3439 ((-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217)))) (-638 (-638 (-950 (-217))))))) 
-((-3767 (((-638 (-171 |#2|)) |#1| |#2|) 45))) 
-(((-158 |#1| |#2|) (-10 -7 (-15 -3767 ((-638 (-171 |#2|)) |#1| |#2|))) (-1234 (-171 (-572))) (-13 (-368) (-846))) (T -158)) 
-((-3767 (*1 *2 *3 *4) (-12 (-5 *2 (-638 (-171 *4))) (-5 *1 (-158 *3 *4)) (-4 *3 (-1234 (-171 (-572)))) (-4 *4 (-13 (-368) (-846)))))) 
-(-10 -7 (-15 -3767 ((-638 (-171 |#2|)) |#1| |#2|))) 
-((-2262 (((-121) $ $) NIL)) (-2888 (($) 15)) (-4075 (($) 14)) (-2793 (((-923)) 22)) (-1658 (((-1152) $) NIL)) (-2132 (((-572) $) 19)) (-2607 (((-1116) $) NIL)) (-2008 (($) 16)) (-1980 (($ (-572)) 23)) (-3972 (((-856) $) 29)) (-4030 (($) 17)) (-1324 (((-121) $ $) 13)) (-1367 (($ $ $) 11)) (* (($ (-923) $) 21) (($ (-217) $) 8))) 
-(((-159) (-13 (-25) (-10 -8 (-15 * ($ (-923) $)) (-15 * ($ (-217) $)) (-15 -1367 ($ $ $)) (-15 -4075 ($)) (-15 -2888 ($)) (-15 -2008 ($)) (-15 -4030 ($)) (-15 -2132 ((-572) $)) (-15 -2793 ((-923))) (-15 -1980 ($ (-572)))))) (T -159)) 
-((-1367 (*1 *1 *1 *1) (-5 *1 (-159))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-923)) (-5 *1 (-159)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-217)) (-5 *1 (-159)))) (-4075 (*1 *1) (-5 *1 (-159))) (-2888 (*1 *1) (-5 *1 (-159))) (-2008 (*1 *1) (-5 *1 (-159))) (-4030 (*1 *1) (-5 *1 (-159))) (-2132 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-159)))) (-2793 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-159)))) (-1980 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-159))))) 
-(-13 (-25) (-10 -8 (-15 * ($ (-923) $)) (-15 * ($ (-217) $)) (-15 -1367 ($ $ $)) (-15 -4075 ($)) (-15 -2888 ($)) (-15 -2008 ($)) (-15 -4030 ($)) (-15 -2132 ((-572) $)) (-15 -2793 ((-923))) (-15 -1980 ($ (-572))))) 
-((-1415 ((|#2| |#2| (-1090 |#2|)) 87) ((|#2| |#2| (-1170)) 67)) (-1642 ((|#2| |#2| (-1090 |#2|)) 86) ((|#2| |#2| (-1170)) 66)) (-2133 ((|#2| |#2| |#2|) 27)) (-4564 (((-123) (-123)) 97)) (-1612 ((|#2| (-638 |#2|)) 116)) (-4129 ((|#2| (-638 |#2|)) 134)) (-4449 ((|#2| (-638 |#2|)) 124)) (-4093 ((|#2| |#2|) 122)) (-4275 ((|#2| (-638 |#2|)) 109)) (-2776 ((|#2| (-638 |#2|)) 110)) (-4102 ((|#2| (-638 |#2|)) 132)) (-3288 ((|#2| |#2| (-1170)) 54) ((|#2| |#2|) 53)) (-2900 ((|#2| |#2|) 23)) (-3610 ((|#2| |#2| |#2|) 26)) (-3228 (((-121) (-123)) 47)) (** ((|#2| |#2| |#2|) 38))) 
-(((-160 |#1| |#2|) (-10 -7 (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 ** (|#2| |#2| |#2|)) (-15 -3610 (|#2| |#2| |#2|)) (-15 -2133 (|#2| |#2| |#2|)) (-15 -2900 (|#2| |#2|)) (-15 -3288 (|#2| |#2|)) (-15 -3288 (|#2| |#2| (-1170))) (-15 -1415 (|#2| |#2| (-1170))) (-15 -1415 (|#2| |#2| (-1090 |#2|))) (-15 -1642 (|#2| |#2| (-1170))) (-15 -1642 (|#2| |#2| (-1090 |#2|))) (-15 -4093 (|#2| |#2|)) (-15 -4102 (|#2| (-638 |#2|))) (-15 -4449 (|#2| (-638 |#2|))) (-15 -4129 (|#2| (-638 |#2|))) (-15 -4275 (|#2| (-638 |#2|))) (-15 -2776 (|#2| (-638 |#2|))) (-15 -1612 (|#2| (-638 |#2|)))) (-13 (-848) (-562)) (-436 |#1|)) (T -160)) 
-((-1612 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-2776 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-4275 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-4129 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-4449 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-4102 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-4093 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) (-1642 (*1 *2 *2 *3) (-12 (-5 *3 (-1090 *2)) (-4 *2 (-436 *4)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)))) (-1642 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)) (-4 *2 (-436 *4)))) (-1415 (*1 *2 *2 *3) (-12 (-5 *3 (-1090 *2)) (-4 *2 (-436 *4)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)))) (-1415 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)) (-4 *2 (-436 *4)))) (-3288 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)) (-4 *2 (-436 *4)))) (-3288 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) (-2900 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) (-2133 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) (-3610 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) (** (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) (-4564 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *4)) (-4 *4 (-436 *3)))) (-3228 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-160 *4 *5)) (-4 *5 (-436 *4))))) 
-(-10 -7 (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 ** (|#2| |#2| |#2|)) (-15 -3610 (|#2| |#2| |#2|)) (-15 -2133 (|#2| |#2| |#2|)) (-15 -2900 (|#2| |#2|)) (-15 -3288 (|#2| |#2|)) (-15 -3288 (|#2| |#2| (-1170))) (-15 -1415 (|#2| |#2| (-1170))) (-15 -1415 (|#2| |#2| (-1090 |#2|))) (-15 -1642 (|#2| |#2| (-1170))) (-15 -1642 (|#2| |#2| (-1090 |#2|))) (-15 -4093 (|#2| |#2|)) (-15 -4102 (|#2| (-638 |#2|))) (-15 -4449 (|#2| (-638 |#2|))) (-15 -4129 (|#2| (-638 |#2|))) (-15 -4275 (|#2| (-638 |#2|))) (-15 -2776 (|#2| (-638 |#2|))) (-15 -1612 (|#2| (-638 |#2|)))) 
-((-1450 ((|#1| |#1| |#1|) 52)) (-3135 ((|#1| |#1| |#1|) 49)) (-2133 ((|#1| |#1| |#1|) 43)) (-2276 ((|#1| |#1|) 34)) (-2626 ((|#1| |#1| (-638 |#1|)) 42)) (-2900 ((|#1| |#1|) 36)) (-3610 ((|#1| |#1| |#1|) 39))) 
-(((-161 |#1|) (-10 -7 (-15 -3610 (|#1| |#1| |#1|)) (-15 -2900 (|#1| |#1|)) (-15 -2626 (|#1| |#1| (-638 |#1|))) (-15 -2276 (|#1| |#1|)) (-15 -2133 (|#1| |#1| |#1|)) (-15 -3135 (|#1| |#1| |#1|)) (-15 -1450 (|#1| |#1| |#1|))) (-554)) (T -161)) 
-((-1450 (*1 *2 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554)))) (-3135 (*1 *2 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554)))) (-2133 (*1 *2 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554)))) (-2276 (*1 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554)))) (-2626 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-554)) (-5 *1 (-161 *2)))) (-2900 (*1 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554)))) (-3610 (*1 *2 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554))))) 
-(-10 -7 (-15 -3610 (|#1| |#1| |#1|)) (-15 -2900 (|#1| |#1|)) (-15 -2626 (|#1| |#1| (-638 |#1|))) (-15 -2276 (|#1| |#1|)) (-15 -2133 (|#1| |#1| |#1|)) (-15 -3135 (|#1| |#1| |#1|)) (-15 -1450 (|#1| |#1| |#1|))) 
-((-1415 (($ $ (-1170)) 12) (($ $ (-1090 $)) 11)) (-1642 (($ $ (-1170)) 10) (($ $ (-1090 $)) 9)) (-2133 (($ $ $) 8)) (-3288 (($ $) 14) (($ $ (-1170)) 13)) (-2900 (($ $) 7)) (-3610 (($ $ $) 6))) 
-(((-162) (-1290)) (T -162)) 
-((-3288 (*1 *1 *1) (-4 *1 (-162))) (-3288 (*1 *1 *1 *2) (-12 (-4 *1 (-162)) (-5 *2 (-1170)))) (-1415 (*1 *1 *1 *2) (-12 (-4 *1 (-162)) (-5 *2 (-1170)))) (-1415 (*1 *1 *1 *2) (-12 (-5 *2 (-1090 *1)) (-4 *1 (-162)))) (-1642 (*1 *1 *1 *2) (-12 (-4 *1 (-162)) (-5 *2 (-1170)))) (-1642 (*1 *1 *1 *2) (-12 (-5 *2 (-1090 *1)) (-4 *1 (-162))))) 
-(-13 (-147) (-10 -8 (-15 -3288 ($ $)) (-15 -3288 ($ $ (-1170))) (-15 -1415 ($ $ (-1170))) (-15 -1415 ($ $ (-1090 $))) (-15 -1642 ($ $ (-1170))) (-15 -1642 ($ $ (-1090 $))))) 
-(((-147) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1863 (($ (-572)) 13) (($ $ $) 14)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 17)) (-1324 (((-121) $ $) 9))) 
-(((-163) (-13 (-1098) (-10 -8 (-15 -1863 ($ (-572))) (-15 -1863 ($ $ $))))) (T -163)) 
-((-1863 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-163)))) (-1863 (*1 *1 *1 *1) (-5 *1 (-163)))) 
-(-13 (-1098) (-10 -8 (-15 -1863 ($ (-572))) (-15 -1863 ($ $ $)))) 
-((-4564 (((-123) (-1170)) 99))) 
-(((-164) (-10 -7 (-15 -4564 ((-123) (-1170))))) (T -164)) 
-((-4564 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-123)) (-5 *1 (-164))))) 
-(-10 -7 (-15 -4564 ((-123) (-1170)))) 
-((-1681 ((|#3| |#3|) 19))) 
-(((-165 |#1| |#2| |#3|) (-10 -7 (-15 -1681 (|#3| |#3|))) (-1054) (-1234 |#1|) (-1234 |#2|)) (T -165)) 
-((-1681 (*1 *2 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-1234 *3)) (-5 *1 (-165 *3 *4 *2)) (-4 *2 (-1234 *4))))) 
-(-10 -7 (-15 -1681 (|#3| |#3|))) 
-((-2262 (((-121) $ $) 7)) (-4574 (((-121) $ $) 12)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-166) (-1290)) (T -166)) 
-((-4574 (*1 *2 *1 *1) (-12 (-4 *1 (-166)) (-5 *2 (-121))))) 
-(-13 (-1098) (-10 -8 (-15 -4574 ((-121) $ $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 215)) (-3520 ((|#2| $) 95)) (-4284 (($ $) 242)) (-4224 (($ $) 236)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 39)) (-4273 (($ $) 240)) (-4217 (($ $) 234)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 |#2| "failed") $) 139)) (-1318 (((-572) $) NIL) (((-413 (-572)) $) NIL) ((|#2| $) 137)) (-2190 (($ $ $) 220)) (-2284 (((-685 (-572)) (-685 $)) NIL) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) 153) (((-685 |#2|) (-685 $)) 147)) (-3116 (($ (-1166 |#2|)) 118) (((-3 $ "failed") (-413 (-1166 |#2|))) NIL)) (-1799 (((-3 $ "failed") $) 207)) (-2956 (((-3 (-413 (-572)) "failed") $) 197)) (-3175 (((-121) $) 192)) (-4299 (((-413 (-572)) $) 195)) (-2667 (((-923)) 88)) (-2208 (($ $ $) 222)) (-4527 (((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) $) 258)) (-4184 (($) 231)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 184) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 189)) (-4429 ((|#2| $) 93)) (-3251 (((-1166 |#2|) $) 120)) (-3828 (($ (-1 |#2| |#2|) $) 101)) (-3539 (($ $) 233)) (-3111 (((-1166 |#2|) $) 119)) (-4350 (($ $) 200)) (-4130 (($) 96)) (-4364 (((-424 (-1166 $)) (-1166 $)) 87)) (-3992 (((-424 (-1166 $)) (-1166 $)) 56)) (-1803 (((-3 $ "failed") $ |#2|) 202) (((-3 $ "failed") $ $) 205)) (-4179 (($ $) 232)) (-4029 (((-769) $) 217)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 226)) (-2119 ((|#2| (-1259 $)) NIL) ((|#2|) 90)) (-3139 (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) 112) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL) (($ $ (-769)) NIL) (($ $) NIL)) (-2830 (((-1166 |#2|)) 113)) (-4278 (($ $) 241)) (-4220 (($ $) 235)) (-3160 (((-1259 |#2|) $ (-1259 $)) 126) (((-685 |#2|) (-1259 $) (-1259 $)) NIL) (((-1259 |#2|) $) 109) (((-685 |#2|) (-1259 $)) NIL)) (-4081 (((-1259 |#2|) $) NIL) (($ (-1259 |#2|)) NIL) (((-1166 |#2|) $) NIL) (($ (-1166 |#2|)) NIL) (((-893 (-572)) $) 175) (((-893 (-385)) $) 179) (((-171 (-385)) $) 165) (((-171 (-217)) $) 160) (((-545) $) 171)) (-3018 (($ $) 97)) (-3972 (((-856) $) 136) (($ (-572)) NIL) (($ |#2|) NIL) (($ (-413 (-572))) NIL) (($ $) NIL)) (-2707 (((-1166 |#2|) $) 23)) (-2140 (((-769)) 99)) (-4321 (($ $) 245)) (-4251 (($ $) 239)) (-4308 (($ $) 243)) (-4241 (($ $) 237)) (-2917 ((|#2| $) 230)) (-4314 (($ $) 244)) (-4246 (($ $) 238)) (-2264 (($ $) 155)) (-1324 (((-121) $ $) 103)) (-1334 (((-121) $ $) 191)) (-1373 (($ $) 105) (($ $ $) NIL)) (-1367 (($ $ $) 104)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-413 (-572))) 264) (($ $ $) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 111) (($ $ $) 140) (($ $ |#2|) NIL) (($ |#2| $) 107) (($ (-413 (-572)) $) NIL) (($ $ (-413 (-572))) NIL))) 
-(((-167 |#1| |#2|) (-10 -8 (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3972 (|#1| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4109 ((-2 (|:| -3029 |#1|) (|:| -4589 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -4029 ((-769) |#1|)) (-15 -2541 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -2208 (|#1| |#1| |#1|)) (-15 -2190 (|#1| |#1| |#1|)) (-15 -4350 (|#1| |#1|)) (-15 ** (|#1| |#1| (-572))) (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -1334 ((-121) |#1| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -4081 ((-171 (-217)) |#1|)) (-15 -4081 ((-171 (-385)) |#1|)) (-15 -4224 (|#1| |#1|)) (-15 -4217 (|#1| |#1|)) (-15 -4220 (|#1| |#1|)) (-15 -4246 (|#1| |#1|)) (-15 -4241 (|#1| |#1|)) (-15 -4251 (|#1| |#1|)) (-15 -4278 (|#1| |#1|)) (-15 -4273 (|#1| |#1|)) (-15 -4284 (|#1| |#1|)) (-15 -4314 (|#1| |#1|)) (-15 -4308 (|#1| |#1|)) (-15 -4321 (|#1| |#1|)) (-15 -3539 (|#1| |#1|)) (-15 -4179 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 -4184 (|#1|)) (-15 ** (|#1| |#1| (-413 (-572)))) (-15 -3992 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -4364 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -2462 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|))) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -4527 ((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) |#1|)) (-15 -2917 (|#2| |#1|)) (-15 -2264 (|#1| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#2|)) (-15 -3018 (|#1| |#1|)) (-15 -4130 (|#1|)) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -3103 ((-890 (-385) |#1|) |#1| (-893 (-385)) (-890 (-385) |#1|))) (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|))) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3116 ((-3 |#1| "failed") (-413 (-1166 |#2|)))) (-15 -3111 ((-1166 |#2|) |#1|)) (-15 -4081 (|#1| (-1166 |#2|))) (-15 -3116 (|#1| (-1166 |#2|))) (-15 -2830 ((-1166 |#2|))) (-15 -2284 ((-685 |#2|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -4081 ((-1166 |#2|) |#1|)) (-15 -2119 (|#2|)) (-15 -4081 (|#1| (-1259 |#2|))) (-15 -4081 ((-1259 |#2|) |#1|)) (-15 -3160 ((-685 |#2|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1|)) (-15 -3251 ((-1166 |#2|) |#1|)) (-15 -2707 ((-1166 |#2|) |#1|)) (-15 -2119 (|#2| (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -4429 (|#2| |#1|)) (-15 -3520 (|#2| |#1|)) (-15 -2667 ((-923))) (-15 -3972 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 ** (|#1| |#1| (-769))) (-15 -1799 ((-3 |#1| "failed") |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-923))) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|)) (-15 -1367 (|#1| |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) (-168 |#2|) (-174)) (T -167)) 
-((-2140 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-769)) (-5 *1 (-167 *3 *4)) (-4 *3 (-168 *4)))) (-2667 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-923)) (-5 *1 (-167 *3 *4)) (-4 *3 (-168 *4)))) (-2119 (*1 *2) (-12 (-4 *2 (-174)) (-5 *1 (-167 *3 *2)) (-4 *3 (-168 *2)))) (-2830 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-1166 *4)) (-5 *1 (-167 *3 *4)) (-4 *3 (-168 *4))))) 
-(-10 -8 (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3972 (|#1| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4109 ((-2 (|:| -3029 |#1|) (|:| -4589 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -4029 ((-769) |#1|)) (-15 -2541 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -2208 (|#1| |#1| |#1|)) (-15 -2190 (|#1| |#1| |#1|)) (-15 -4350 (|#1| |#1|)) (-15 ** (|#1| |#1| (-572))) (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -1334 ((-121) |#1| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -4081 ((-171 (-217)) |#1|)) (-15 -4081 ((-171 (-385)) |#1|)) (-15 -4224 (|#1| |#1|)) (-15 -4217 (|#1| |#1|)) (-15 -4220 (|#1| |#1|)) (-15 -4246 (|#1| |#1|)) (-15 -4241 (|#1| |#1|)) (-15 -4251 (|#1| |#1|)) (-15 -4278 (|#1| |#1|)) (-15 -4273 (|#1| |#1|)) (-15 -4284 (|#1| |#1|)) (-15 -4314 (|#1| |#1|)) (-15 -4308 (|#1| |#1|)) (-15 -4321 (|#1| |#1|)) (-15 -3539 (|#1| |#1|)) (-15 -4179 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 -4184 (|#1|)) (-15 ** (|#1| |#1| (-413 (-572)))) (-15 -3992 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -4364 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -2462 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|))) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -4527 ((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) |#1|)) (-15 -2917 (|#2| |#1|)) (-15 -2264 (|#1| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#2|)) (-15 -3018 (|#1| |#1|)) (-15 -4130 (|#1|)) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -3103 ((-890 (-385) |#1|) |#1| (-893 (-385)) (-890 (-385) |#1|))) (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|))) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3116 ((-3 |#1| "failed") (-413 (-1166 |#2|)))) (-15 -3111 ((-1166 |#2|) |#1|)) (-15 -4081 (|#1| (-1166 |#2|))) (-15 -3116 (|#1| (-1166 |#2|))) (-15 -2830 ((-1166 |#2|))) (-15 -2284 ((-685 |#2|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -4081 ((-1166 |#2|) |#1|)) (-15 -2119 (|#2|)) (-15 -4081 (|#1| (-1259 |#2|))) (-15 -4081 ((-1259 |#2|) |#1|)) (-15 -3160 ((-685 |#2|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1|)) (-15 -3251 ((-1166 |#2|) |#1|)) (-15 -2707 ((-1166 |#2|) |#1|)) (-15 -2119 (|#2| (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -4429 (|#2| |#1|)) (-15 -3520 (|#2| |#1|)) (-15 -2667 ((-923))) (-15 -3972 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 ** (|#1| |#1| (-769))) (-15 -1799 ((-3 |#1| "failed") |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-923))) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|)) (-15 -1367 (|#1| |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 88 (-1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-3946 (($ $) 89 (-1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-3686 (((-121) $) 91 (-1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-1845 (((-685 |#1|) (-1259 $)) 44) (((-685 |#1|)) 55)) (-3520 ((|#1| $) 50)) (-4284 (($ $) 213 (|has| |#1| (-1190)))) (-4224 (($ $) 196 (|has| |#1| (-1190)))) (-3617 (((-1178 (-923) (-769)) (-572)) 142 (|has| |#1| (-353)))) (-1572 (((-3 $ "failed") $ $) 18)) (-4073 (((-424 (-1166 $)) (-1166 $)) 227 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (-2844 (($ $) 108 (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368))))) (-1466 (((-424 $) $) 109 (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368))))) (-4190 (($ $) 226 (-12 (|has| |#1| (-1009)) (|has| |#1| (-1190))))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 230 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (-3112 (((-121) $ $) 99 (|has| |#1| (-303)))) (-1685 (((-769)) 81 (|has| |#1| (-374)))) (-4273 (($ $) 212 (|has| |#1| (-1190)))) (-4217 (($ $) 197 (|has| |#1| (-1190)))) (-4295 (($ $) 211 (|has| |#1| (-1190)))) (-4233 (($ $) 198 (|has| |#1| (-1190)))) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 164 (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 162 (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 161)) (-1318 (((-572) $) 165 (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) 163 (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 160)) (-4337 (($ (-1259 |#1|) (-1259 $)) 46) (($ (-1259 |#1|)) 58)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 148 (|has| |#1| (-353)))) (-2190 (($ $ $) 103 (|has| |#1| (-303)))) (-1741 (((-685 |#1|) $ (-1259 $)) 51) (((-685 |#1|) $) 53)) (-2284 (((-685 (-572)) (-685 $)) 159 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 158 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 157) (((-685 |#1|) (-685 $)) 156)) (-3116 (($ (-1166 |#1|)) 153) (((-3 $ "failed") (-413 (-1166 |#1|))) 150 (|has| |#1| (-368)))) (-1799 (((-3 $ "failed") $) 33)) (-3359 ((|#1| $) 238)) (-2956 (((-3 (-413 (-572)) "failed") $) 231 (|has| |#1| (-554)))) (-3175 (((-121) $) 233 (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) 232 (|has| |#1| (-554)))) (-2667 (((-923)) 52)) (-3286 (($) 84 (|has| |#1| (-374)))) (-2208 (($ $ $) 102 (|has| |#1| (-303)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 97 (|has| |#1| (-303)))) (-2754 (($) 144 (|has| |#1| (-353)))) (-1297 (((-121) $) 145 (|has| |#1| (-353)))) (-4486 (($ $ (-769)) 136 (|has| |#1| (-353))) (($ $) 135 (|has| |#1| (-353)))) (-1526 (((-121) $) 110 (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368))))) (-4527 (((-2 (|:| |r| |#1|) (|:| |phi| |#1|)) $) 234 (-12 (|has| |#1| (-1063)) (|has| |#1| (-1190))))) (-4184 (($) 223 (|has| |#1| (-1190)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 246 (|has| |#1| (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 245 (|has| |#1| (-887 (-385))))) (-3377 (((-923) $) 147 (|has| |#1| (-353))) (((-834 (-923)) $) 133 (|has| |#1| (-353)))) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 225 (-12 (|has| |#1| (-1009)) (|has| |#1| (-1190))))) (-4429 ((|#1| $) 49)) (-3961 (((-3 $ "failed") $) 137 (|has| |#1| (-353)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 106 (|has| |#1| (-303)))) (-3251 (((-1166 |#1|) $) 42 (|has| |#1| (-368)))) (-1771 (($ $ $) 192 (|has| |#1| (-848)))) (-4238 (($ $ $) 191 (|has| |#1| (-848)))) (-3828 (($ (-1 |#1| |#1|) $) 247)) (-3633 (((-923) $) 83 (|has| |#1| (-374)))) (-3539 (($ $) 220 (|has| |#1| (-1190)))) (-3111 (((-1166 |#1|) $) 151)) (-1629 (($ (-638 $)) 95 (-1841 (|has| |#1| (-303)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (($ $ $) 94 (-1841 (|has| |#1| (-303)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-1658 (((-1152) $) 9)) (-4350 (($ $) 111 (|has| |#1| (-368)))) (-1773 (($) 138 (|has| |#1| (-353)) CONST)) (-1763 (($ (-923)) 82 (|has| |#1| (-374)))) (-4130 (($) 242)) (-4310 ((|#1| $) 239)) (-2607 (((-1116) $) 10)) (-2307 (($) 155)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 96 (-1841 (|has| |#1| (-303)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-3069 (($ (-638 $)) 93 (-1841 (|has| |#1| (-303)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (($ $ $) 92 (-1841 (|has| |#1| (-303)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 141 (|has| |#1| (-353)))) (-4364 (((-424 (-1166 $)) (-1166 $)) 229 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (-3992 (((-424 (-1166 $)) (-1166 $)) 228 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (-4304 (((-424 $) $) 107 (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368))))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105 (|has| |#1| (-303))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 104 (|has| |#1| (-303)))) (-1803 (((-3 $ "failed") $ |#1|) 237 (|has| |#1| (-562))) (((-3 $ "failed") $ $) 87 (-1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 98 (|has| |#1| (-303)))) (-4179 (($ $) 221 (|has| |#1| (-1190)))) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) 253 (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) 252 (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) 251 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) 250 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) 249 (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) 248 (|has| |#1| (-527 (-1170) |#1|)))) (-4029 (((-769) $) 100 (|has| |#1| (-303)))) (-3587 (((-638 $)) 85 (|has| |#1| (-374)))) (-3277 (($ $ |#1|) 254 (|has| |#1| (-283 |#1| |#1|)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 101 (|has| |#1| (-303)))) (-2119 ((|#1| (-1259 $)) 45) ((|#1|) 54)) (-3158 (((-769) $) 146 (|has| |#1| (-353))) (((-3 (-769) "failed") $ $) 134 (|has| |#1| (-353)))) (-3139 (($ $ (-1 |#1| |#1|) (-769)) 118) (($ $ (-1 |#1| |#1|)) 117) (($ $ (-638 (-1170)) (-638 (-769))) 125 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 126 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 127 (|has| |#1| (-901 (-1170)))) (($ $ (-1170)) 128 (|has| |#1| (-901 (-1170)))) (($ $ (-769)) 130 (-1841 (-4028 (|has| |#1| (-368)) (|has| |#1| (-227))) (|has| |#1| (-227)) (-4028 (|has| |#1| (-227)) (|has| |#1| (-368))))) (($ $) 132 (-1841 (-4028 (|has| |#1| (-368)) (|has| |#1| (-227))) (|has| |#1| (-227)) (-4028 (|has| |#1| (-227)) (|has| |#1| (-368)))))) (-3482 (((-685 |#1|) (-1259 $) (-1 |#1| |#1|)) 149 (|has| |#1| (-368)))) (-2830 (((-1166 |#1|)) 154)) (-4302 (($ $) 210 (|has| |#1| (-1190)))) (-4237 (($ $) 199 (|has| |#1| (-1190)))) (-2278 (($) 143 (|has| |#1| (-353)))) (-4289 (($ $) 209 (|has| |#1| (-1190)))) (-4228 (($ $) 200 (|has| |#1| (-1190)))) (-4278 (($ $) 208 (|has| |#1| (-1190)))) (-4220 (($ $) 201 (|has| |#1| (-1190)))) (-3160 (((-1259 |#1|) $ (-1259 $)) 48) (((-685 |#1|) (-1259 $) (-1259 $)) 47) (((-1259 |#1|) $) 60) (((-685 |#1|) (-1259 $)) 59)) (-4081 (((-1259 |#1|) $) 57) (($ (-1259 |#1|)) 56) (((-1166 |#1|) $) 166) (($ (-1166 |#1|)) 152) (((-893 (-572)) $) 244 (|has| |#1| (-613 (-893 (-572))))) (((-893 (-385)) $) 243 (|has| |#1| (-613 (-893 (-385))))) (((-171 (-385)) $) 195 (|has| |#1| (-1028))) (((-171 (-217)) $) 194 (|has| |#1| (-1028))) (((-545) $) 193 (|has| |#1| (-613 (-545))))) (-3018 (($ $) 241)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 140 (-1841 (-4028 (|has| $ (-149)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))) (|has| |#1| (-353))))) (-3363 (($ |#1| |#1|) 240)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 36) (($ (-413 (-572))) 80 (-1841 (|has| |#1| (-368)) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) 86 (-1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-2779 (($ $) 139 (|has| |#1| (-353))) (((-3 $ "failed") $) 41 (-1841 (-4028 (|has| $ (-149)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))) (|has| |#1| (-149))))) (-2707 (((-1166 |#1|) $) 43)) (-2140 (((-769)) 28)) (-2237 (((-1259 $)) 61)) (-4321 (($ $) 219 (|has| |#1| (-1190)))) (-4251 (($ $) 207 (|has| |#1| (-1190)))) (-3774 (((-121) $ $) 90 (-1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910)))))) (-4308 (($ $) 218 (|has| |#1| (-1190)))) (-4241 (($ $) 206 (|has| |#1| (-1190)))) (-4333 (($ $) 217 (|has| |#1| (-1190)))) (-4263 (($ $) 205 (|has| |#1| (-1190)))) (-2917 ((|#1| $) 235 (|has| |#1| (-1190)))) (-2104 (($ $) 216 (|has| |#1| (-1190)))) (-4268 (($ $) 204 (|has| |#1| (-1190)))) (-4327 (($ $) 215 (|has| |#1| (-1190)))) (-4257 (($ $) 203 (|has| |#1| (-1190)))) (-4314 (($ $) 214 (|has| |#1| (-1190)))) (-4246 (($ $) 202 (|has| |#1| (-1190)))) (-2264 (($ $) 236 (|has| |#1| (-1063)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 112 (|has| |#1| (-368)))) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-1 |#1| |#1|) (-769)) 120) (($ $ (-1 |#1| |#1|)) 119) (($ $ (-638 (-1170)) (-638 (-769))) 121 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 122 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 123 (|has| |#1| (-901 (-1170)))) (($ $ (-1170)) 124 (|has| |#1| (-901 (-1170)))) (($ $ (-769)) 129 (-1841 (-4028 (|has| |#1| (-368)) (|has| |#1| (-227))) (|has| |#1| (-227)) (-4028 (|has| |#1| (-227)) (|has| |#1| (-368))))) (($ $) 131 (-1841 (-4028 (|has| |#1| (-368)) (|has| |#1| (-227))) (|has| |#1| (-227)) (-4028 (|has| |#1| (-227)) (|has| |#1| (-368)))))) (-1349 (((-121) $ $) 189 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 188 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 190 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 187 (|has| |#1| (-848)))) (-1379 (($ $ $) 116 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-413 (-572))) 224 (-12 (|has| |#1| (-1009)) (|has| |#1| (-1190)))) (($ $ $) 222 (|has| |#1| (-1190))) (($ $ (-572)) 113 (|has| |#1| (-368)))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ (-413 (-572)) $) 115 (|has| |#1| (-368))) (($ $ (-413 (-572))) 114 (|has| |#1| (-368))))) 
-(((-168 |#1|) (-1290) (-174)) (T -168)) 
-((-4429 (*1 *2 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) (-4130 (*1 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) (-3018 (*1 *1 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) (-3363 (*1 *1 *2 *2) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) (-4310 (*1 *2 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) (-3359 (*1 *2 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) (-1803 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-168 *2)) (-4 *2 (-174)) (-4 *2 (-562)))) (-2264 (*1 *1 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)) (-4 *2 (-1063)))) (-2917 (*1 *2 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)) (-4 *2 (-1190)))) (-4527 (*1 *2 *1) (-12 (-4 *1 (-168 *3)) (-4 *3 (-174)) (-4 *3 (-1063)) (-4 *3 (-1190)) (-5 *2 (-2 (|:| |r| *3) (|:| |phi| *3))))) (-3175 (*1 *2 *1) (-12 (-4 *1 (-168 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-121)))) (-4299 (*1 *2 *1) (-12 (-4 *1 (-168 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) (-2956 (*1 *2 *1) (|partial| -12 (-4 *1 (-168 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572)))))) 
-(-13 (-720 |t#1| (-1166 |t#1|)) (-417 |t#1|) (-225 |t#1|) (-338 |t#1|) (-406 |t#1|) (-885 |t#1|) (-383 |t#1|) (-174) (-10 -8 (-6 -3363) (-15 -4130 ($)) (-15 -3018 ($ $)) (-15 -3363 ($ |t#1| |t#1|)) (-15 -4310 (|t#1| $)) (-15 -3359 (|t#1| $)) (-15 -4429 (|t#1| $)) (IF (|has| |t#1| (-848)) (-6 (-848)) |noBranch|) (IF (|has| |t#1| (-562)) (PROGN (-6 (-562)) (-15 -1803 ((-3 $ "failed") $ |t#1|))) |noBranch|) (IF (|has| |t#1| (-303)) (-6 (-303)) |noBranch|) (IF (|has| |t#1| (-6 -4601)) (-6 -4601) |noBranch|) (IF (|has| |t#1| (-6 -4598)) (-6 -4598) |noBranch|) (IF (|has| |t#1| (-368)) (-6 (-368)) |noBranch|) (IF (|has| |t#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (IF (|has| |t#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |t#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |t#1| (-1028)) (PROGN (-6 (-613 (-171 (-217)))) (-6 (-613 (-171 (-385))))) |noBranch|) (IF (|has| |t#1| (-1063)) (-15 -2264 ($ $)) |noBranch|) (IF (|has| |t#1| (-1190)) (PROGN (-6 (-1190)) (-15 -2917 (|t#1| $)) (IF (|has| |t#1| (-1009)) (-6 (-1009)) |noBranch|) (IF (|has| |t#1| (-1063)) (-15 -4527 ((-2 (|:| |r| |t#1|) (|:| |phi| |t#1|)) $)) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|) (IF (|has| |t#1| (-910)) (IF (|has| |t#1| (-303)) (-6 (-910)) |noBranch|) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-43 |#1|) . T) ((-43 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-353)) (|has| |#1| (-368)) (|has| |#1| (-303))) ((-40) |has| |#1| (-1190)) ((-98) |has| |#1| (-1190)) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-138) . T) ((-149) -1841 (|has| |#1| (-353)) (|has| |#1| (-149))) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) . T) ((-613 (-171 (-217))) |has| |#1| (-1028)) ((-613 (-171 (-385))) |has| |#1| (-1028)) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-613 (-893 (-385))) |has| |#1| (-613 (-893 (-385)))) ((-613 (-893 (-572))) |has| |#1| (-613 (-893 (-572)))) ((-613 (-1166 |#1|)) . T) ((-225 |#1|) . T) ((-227) -1841 (|has| |#1| (-353)) (|has| |#1| (-227))) ((-240) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-281) |has| |#1| (-1190)) ((-283 |#1| $) |has| |#1| (-283 |#1| |#1|)) ((-287) -1841 (|has| |#1| (-562)) (|has| |#1| (-353)) (|has| |#1| (-368)) (|has| |#1| (-303))) ((-303) -1841 (|has| |#1| (-353)) (|has| |#1| (-368)) (|has| |#1| (-303))) ((-305 |#1|) |has| |#1| (-305 |#1|)) ((-368) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-408) |has| |#1| (-353)) ((-374) -1841 (|has| |#1| (-374)) (|has| |#1| (-353))) ((-353) |has| |#1| (-353)) ((-376 |#1| (-1166 |#1|)) . T) ((-415 |#1| (-1166 |#1|)) . T) ((-338 |#1|) . T) ((-383 |#1|) . T) ((-406 |#1|) . T) ((-417 |#1|) . T) ((-457) -1841 (|has| |#1| (-353)) (|has| |#1| (-368)) (|has| |#1| (-303))) ((-506) |has| |#1| (-1190)) ((-527 (-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((-527 |#1| |#1|) |has| |#1| (-305 |#1|)) ((-562) -1841 (|has| |#1| (-562)) (|has| |#1| (-353)) (|has| |#1| (-368)) (|has| |#1| (-303))) ((-641 (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-641 |#1|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-713 (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-713 |#1|) . T) ((-713 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-353)) (|has| |#1| (-368)) (|has| |#1| (-303))) ((-720 |#1| (-1166 |#1|)) . T) ((-722) . T) ((-848) |has| |#1| (-848)) ((-901 (-1170)) |has| |#1| (-901 (-1170))) ((-887 (-385)) |has| |#1| (-887 (-385))) ((-887 (-572)) |has| |#1| (-887 (-572))) ((-885 |#1|) . T) ((-910) -12 (|has| |#1| (-303)) (|has| |#1| (-910))) ((-922) -1841 (|has| |#1| (-353)) (|has| |#1| (-368)) (|has| |#1| (-303))) ((-1009) -12 (|has| |#1| (-1009)) (|has| |#1| (-1190))) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-1060 |#1|) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) |has| |#1| (-353)) ((-1190) |has| |#1| (-1190)) ((-1193) |has| |#1| (-1190)) ((-1204) . T) ((-1214) -1841 (|has| |#1| (-353)) (|has| |#1| (-368)) (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) 
-((-4304 (((-424 |#2|) |#2|) 63))) 
-(((-169 |#1| |#2|) (-10 -7 (-15 -4304 ((-424 |#2|) |#2|))) (-303) (-1234 (-171 |#1|))) (T -169)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-169 *4 *3)) (-4 *3 (-1234 (-171 *4)))))) 
-(-10 -7 (-15 -4304 ((-424 |#2|) |#2|))) 
-((-3828 (((-171 |#2|) (-1 |#2| |#1|) (-171 |#1|)) 14))) 
-(((-170 |#1| |#2|) (-10 -7 (-15 -3828 ((-171 |#2|) (-1 |#2| |#1|) (-171 |#1|)))) (-174) (-174)) (T -170)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-171 *5)) (-4 *5 (-174)) (-4 *6 (-174)) (-5 *2 (-171 *6)) (-5 *1 (-170 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-171 |#2|) (-1 |#2| |#1|) (-171 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 33)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-562))))) (-3946 (($ $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-562))))) (-3686 (((-121) $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-562))))) (-1845 (((-685 |#1|) (-1259 $)) NIL) (((-685 |#1|)) NIL)) (-3520 ((|#1| $) NIL)) (-4284 (($ $) NIL (|has| |#1| (-1190)))) (-4224 (($ $) NIL (|has| |#1| (-1190)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| |#1| (-353)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (-2844 (($ $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368))))) (-1466 (((-424 $) $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368))))) (-4190 (($ $) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1190))))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-303)))) (-1685 (((-769)) NIL (|has| |#1| (-374)))) (-4273 (($ $) NIL (|has| |#1| (-1190)))) (-4217 (($ $) NIL (|has| |#1| (-1190)))) (-4295 (($ $) NIL (|has| |#1| (-1190)))) (-4233 (($ $) NIL (|has| |#1| (-1190)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-4337 (($ (-1259 |#1|) (-1259 $)) NIL) (($ (-1259 |#1|)) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-353)))) (-2190 (($ $ $) NIL (|has| |#1| (-303)))) (-1741 (((-685 |#1|) $ (-1259 $)) NIL) (((-685 |#1|) $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-3116 (($ (-1166 |#1|)) NIL) (((-3 $ "failed") (-413 (-1166 |#1|))) NIL (|has| |#1| (-368)))) (-1799 (((-3 $ "failed") $) NIL)) (-3359 ((|#1| $) 13)) (-2956 (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-554)))) (-3175 (((-121) $) NIL (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) NIL (|has| |#1| (-554)))) (-2667 (((-923)) NIL)) (-3286 (($) NIL (|has| |#1| (-374)))) (-2208 (($ $ $) NIL (|has| |#1| (-303)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-303)))) (-2754 (($) NIL (|has| |#1| (-353)))) (-1297 (((-121) $) NIL (|has| |#1| (-353)))) (-4486 (($ $ (-769)) NIL (|has| |#1| (-353))) (($ $) NIL (|has| |#1| (-353)))) (-1526 (((-121) $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368))))) (-4527 (((-2 (|:| |r| |#1|) (|:| |phi| |#1|)) $) NIL (-12 (|has| |#1| (-1063)) (|has| |#1| (-1190))))) (-4184 (($) NIL (|has| |#1| (-1190)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| |#1| (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| |#1| (-887 (-385))))) (-3377 (((-923) $) NIL (|has| |#1| (-353))) (((-834 (-923)) $) NIL (|has| |#1| (-353)))) (-3893 (((-121) $) 35)) (-1451 (($ $ (-572)) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1190))))) (-4429 ((|#1| $) 46)) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-353)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-303)))) (-3251 (((-1166 |#1|) $) NIL (|has| |#1| (-368)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3633 (((-923) $) NIL (|has| |#1| (-374)))) (-3539 (($ $) NIL (|has| |#1| (-1190)))) (-3111 (((-1166 |#1|) $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-303))) (($ $ $) NIL (|has| |#1| (-303)))) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-1773 (($) NIL (|has| |#1| (-353)) CONST)) (-1763 (($ (-923)) NIL (|has| |#1| (-374)))) (-4130 (($) NIL)) (-4310 ((|#1| $) 15)) (-2607 (((-1116) $) NIL)) (-2307 (($) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-303)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-303))) (($ $ $) NIL (|has| |#1| (-303)))) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| |#1| (-353)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| |#1| (-303)) (|has| |#1| (-910))))) (-4304 (((-424 $) $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-368))))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-303))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-303)))) (-1803 (((-3 $ "failed") $ |#1|) 44 (|has| |#1| (-562))) (((-3 $ "failed") $ $) 47 (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-562))))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-303)))) (-4179 (($ $) NIL (|has| |#1| (-1190)))) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) NIL (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) NIL (|has| |#1| (-527 (-1170) |#1|)))) (-4029 (((-769) $) NIL (|has| |#1| (-303)))) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-3277 (($ $ |#1|) NIL (|has| |#1| (-283 |#1| |#1|)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-303)))) (-2119 ((|#1| (-1259 $)) NIL) ((|#1|) NIL)) (-3158 (((-769) $) NIL (|has| |#1| (-353))) (((-3 (-769) "failed") $ $) NIL (|has| |#1| (-353)))) (-3139 (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $) NIL (|has| |#1| (-227)))) (-3482 (((-685 |#1|) (-1259 $) (-1 |#1| |#1|)) NIL (|has| |#1| (-368)))) (-2830 (((-1166 |#1|)) NIL)) (-4302 (($ $) NIL (|has| |#1| (-1190)))) (-4237 (($ $) NIL (|has| |#1| (-1190)))) (-2278 (($) NIL (|has| |#1| (-353)))) (-4289 (($ $) NIL (|has| |#1| (-1190)))) (-4228 (($ $) NIL (|has| |#1| (-1190)))) (-4278 (($ $) NIL (|has| |#1| (-1190)))) (-4220 (($ $) NIL (|has| |#1| (-1190)))) (-3160 (((-1259 |#1|) $ (-1259 $)) NIL) (((-685 |#1|) (-1259 $) (-1259 $)) NIL) (((-1259 |#1|) $) NIL) (((-685 |#1|) (-1259 $)) NIL)) (-4081 (((-1259 |#1|) $) NIL) (($ (-1259 |#1|)) NIL) (((-1166 |#1|) $) NIL) (($ (-1166 |#1|)) NIL) (((-893 (-572)) $) NIL (|has| |#1| (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| |#1| (-613 (-893 (-385))))) (((-171 (-385)) $) NIL (|has| |#1| (-1028))) (((-171 (-217)) $) NIL (|has| |#1| (-1028))) (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3018 (($ $) 45)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-353))))) (-3363 (($ |#1| |#1|) 37)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) 36) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-368)) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-562))))) (-2779 (($ $) NIL (|has| |#1| (-353))) (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2707 (((-1166 |#1|) $) NIL)) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL)) (-4321 (($ $) NIL (|has| |#1| (-1190)))) (-4251 (($ $) NIL (|has| |#1| (-1190)))) (-3774 (((-121) $ $) NIL (-1841 (-12 (|has| |#1| (-303)) (|has| |#1| (-910))) (|has| |#1| (-562))))) (-4308 (($ $) NIL (|has| |#1| (-1190)))) (-4241 (($ $) NIL (|has| |#1| (-1190)))) (-4333 (($ $) NIL (|has| |#1| (-1190)))) (-4263 (($ $) NIL (|has| |#1| (-1190)))) (-2917 ((|#1| $) NIL (|has| |#1| (-1190)))) (-2104 (($ $) NIL (|has| |#1| (-1190)))) (-4268 (($ $) NIL (|has| |#1| (-1190)))) (-4327 (($ $) NIL (|has| |#1| (-1190)))) (-4257 (($ $) NIL (|has| |#1| (-1190)))) (-4314 (($ $) NIL (|has| |#1| (-1190)))) (-4246 (($ $) NIL (|has| |#1| (-1190)))) (-2264 (($ $) NIL (|has| |#1| (-1063)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 28 T CONST)) (-3255 (($) 30 T CONST)) (-3594 (((-1152) $) 23 (|has| |#1| (-829))) (((-1152) $ (-121)) 25 (|has| |#1| (-829))) (((-1264) (-823) $) 26 (|has| |#1| (-829))) (((-1264) (-823) $ (-121)) 27 (|has| |#1| (-829)))) (-1557 (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $) NIL (|has| |#1| (-227)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ $) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 39)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-413 (-572))) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1190)))) (($ $ $) NIL (|has| |#1| (-1190))) (($ $ (-572)) NIL (|has| |#1| (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 42) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-413 (-572)) $) NIL (|has| |#1| (-368))) (($ $ (-413 (-572))) NIL (|has| |#1| (-368))))) 
-(((-171 |#1|) (-13 (-168 |#1|) (-10 -7 (IF (|has| |#1| (-829)) (-6 (-829)) |noBranch|))) (-174)) (T -171)) 
-NIL 
-(-13 (-168 |#1|) (-10 -7 (IF (|has| |#1| (-829)) (-6 (-829)) |noBranch|))) 
-((-4081 (((-893 |#1|) |#3|) 22))) 
-(((-172 |#1| |#2| |#3|) (-10 -7 (-15 -4081 ((-893 |#1|) |#3|))) (-1098) (-13 (-613 (-893 |#1|)) (-174)) (-168 |#2|)) (T -172)) 
-((-4081 (*1 *2 *3) (-12 (-4 *5 (-13 (-613 *2) (-174))) (-5 *2 (-893 *4)) (-5 *1 (-172 *4 *5 *3)) (-4 *4 (-1098)) (-4 *3 (-168 *5))))) 
-(-10 -7 (-15 -4081 ((-893 |#1|) |#3|))) 
-((-2262 (((-121) $ $) NIL)) (-4382 (((-121) $) 9)) (-1302 (((-121) $ (-121)) 11)) (-1364 (($) 12)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1607 (($ $) 13)) (-3972 (((-856) $) 17)) (-2245 (((-121) $) 8)) (-2371 (((-121) $ (-121)) 10)) (-1324 (((-121) $ $) NIL))) 
-(((-173) (-13 (-1098) (-10 -8 (-15 -1364 ($)) (-15 -2245 ((-121) $)) (-15 -4382 ((-121) $)) (-15 -2371 ((-121) $ (-121))) (-15 -1302 ((-121) $ (-121))) (-15 -1607 ($ $))))) (T -173)) 
-((-1364 (*1 *1) (-5 *1 (-173))) (-2245 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-173)))) (-4382 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-173)))) (-2371 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-173)))) (-1302 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-173)))) (-1607 (*1 *1 *1) (-5 *1 (-173)))) 
-(-13 (-1098) (-10 -8 (-15 -1364 ($)) (-15 -2245 ((-121) $)) (-15 -4382 ((-121) $)) (-15 -2371 ((-121) $ (-121))) (-15 -1302 ((-121) $ (-121))) (-15 -1607 ($ $)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-174) (-1290)) (T -174)) 
-NIL 
-(-13 (-1054) (-120 $ $) (-10 -7 (-6 (-4604 "*")))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 ((|#1| $) 74)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-2190 (($ $ $) NIL)) (-1414 (($ $) 19)) (-2151 (($ |#1| (-1150 |#1|)) 47)) (-1799 (((-3 $ "failed") $) 116)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-4294 (((-1150 |#1|) $) 81)) (-3080 (((-1150 |#1|) $) 78)) (-4039 (((-1150 |#1|) $) 79)) (-3893 (((-121) $) NIL)) (-2142 (((-1150 |#1|) $) 87)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1629 (($ (-638 $)) NIL) (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ (-638 $)) NIL) (($ $ $) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL)) (-1977 (($ $ (-572)) 90)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-2134 (((-1150 |#1|) $) 88)) (-4515 (((-1150 (-413 |#1|)) $) 13)) (-3915 (($ (-413 |#1|)) 17) (($ |#1| (-1150 |#1|) (-1150 |#1|)) 37)) (-2424 (($ $) 92)) (-3972 (((-856) $) 126) (($ (-572)) 50) (($ |#1|) 51) (($ (-413 |#1|)) 35) (($ (-413 (-572))) NIL) (($ $) NIL)) (-2140 (((-769)) 63)) (-3774 (((-121) $ $) NIL)) (-2637 (((-1150 (-413 |#1|)) $) 18)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 25 T CONST)) (-3255 (($) 28 T CONST)) (-1324 (((-121) $ $) 34)) (-1379 (($ $ $) 114)) (-1373 (($ $) 105) (($ $ $) 102)) (-1367 (($ $ $) 100)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 112) (($ $ $) 107) (($ $ |#1|) NIL) (($ |#1| $) 109) (($ (-413 |#1|) $) 110) (($ $ (-413 |#1|)) NIL) (($ (-413 (-572)) $) NIL) (($ $ (-413 (-572))) NIL))) 
-(((-175 |#1|) (-13 (-43 |#1|) (-43 (-413 |#1|)) (-368) (-10 -8 (-15 -3915 ($ (-413 |#1|))) (-15 -3915 ($ |#1| (-1150 |#1|) (-1150 |#1|))) (-15 -2151 ($ |#1| (-1150 |#1|))) (-15 -3080 ((-1150 |#1|) $)) (-15 -4039 ((-1150 |#1|) $)) (-15 -4294 ((-1150 |#1|) $)) (-15 -2551 (|#1| $)) (-15 -1414 ($ $)) (-15 -2637 ((-1150 (-413 |#1|)) $)) (-15 -4515 ((-1150 (-413 |#1|)) $)) (-15 -2142 ((-1150 |#1|) $)) (-15 -2134 ((-1150 |#1|) $)) (-15 -1977 ($ $ (-572))) (-15 -2424 ($ $)))) (-303)) (T -175)) 
-((-3915 (*1 *1 *2) (-12 (-5 *2 (-413 *3)) (-4 *3 (-303)) (-5 *1 (-175 *3)))) (-3915 (*1 *1 *2 *3 *3) (-12 (-5 *3 (-1150 *2)) (-4 *2 (-303)) (-5 *1 (-175 *2)))) (-2151 (*1 *1 *2 *3) (-12 (-5 *3 (-1150 *2)) (-4 *2 (-303)) (-5 *1 (-175 *2)))) (-3080 (*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303)))) (-4039 (*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303)))) (-4294 (*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303)))) (-2551 (*1 *2 *1) (-12 (-5 *1 (-175 *2)) (-4 *2 (-303)))) (-1414 (*1 *1 *1) (-12 (-5 *1 (-175 *2)) (-4 *2 (-303)))) (-2637 (*1 *2 *1) (-12 (-5 *2 (-1150 (-413 *3))) (-5 *1 (-175 *3)) (-4 *3 (-303)))) (-4515 (*1 *2 *1) (-12 (-5 *2 (-1150 (-413 *3))) (-5 *1 (-175 *3)) (-4 *3 (-303)))) (-2142 (*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303)))) (-2134 (*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303)))) (-1977 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-175 *3)) (-4 *3 (-303)))) (-2424 (*1 *1 *1) (-12 (-5 *1 (-175 *2)) (-4 *2 (-303))))) 
-(-13 (-43 |#1|) (-43 (-413 |#1|)) (-368) (-10 -8 (-15 -3915 ($ (-413 |#1|))) (-15 -3915 ($ |#1| (-1150 |#1|) (-1150 |#1|))) (-15 -2151 ($ |#1| (-1150 |#1|))) (-15 -3080 ((-1150 |#1|) $)) (-15 -4039 ((-1150 |#1|) $)) (-15 -4294 ((-1150 |#1|) $)) (-15 -2551 (|#1| $)) (-15 -1414 ($ $)) (-15 -2637 ((-1150 (-413 |#1|)) $)) (-15 -4515 ((-1150 (-413 |#1|)) $)) (-15 -2142 ((-1150 |#1|) $)) (-15 -2134 ((-1150 |#1|) $)) (-15 -1977 ($ $ (-572))) (-15 -2424 ($ $)))) 
-((-3129 (((-1 (-950 |#1|) (-950 |#1|)) |#1|) 40)) (-2152 (((-950 |#1|) (-950 |#1|)) 19)) (-4407 (((-1 (-950 |#1|) (-950 |#1|)) |#1|) 36)) (-3962 (((-950 |#1|) (-950 |#1|)) 17)) (-3178 (((-950 |#1|) (-950 |#1|)) 25)) (-3976 (((-950 |#1|) (-950 |#1|)) 24)) (-3762 (((-950 |#1|) (-950 |#1|)) 23)) (-2740 (((-1 (-950 |#1|) (-950 |#1|)) |#1|) 37)) (-1840 (((-1 (-950 |#1|) (-950 |#1|)) |#1|) 35)) (-2447 (((-1 (-950 |#1|) (-950 |#1|)) |#1|) 34)) (-2014 (((-950 |#1|) (-950 |#1|)) 18)) (-3906 (((-1 (-950 |#1|) (-950 |#1|)) |#1| |#1|) 43)) (-3998 (((-950 |#1|) (-950 |#1|)) 8)) (-1510 (((-1 (-950 |#1|) (-950 |#1|)) |#1|) 39)) (-3565 (((-1 (-950 |#1|) (-950 |#1|)) |#1|) 38))) 
-(((-176 |#1|) (-10 -7 (-15 -3998 ((-950 |#1|) (-950 |#1|))) (-15 -3962 ((-950 |#1|) (-950 |#1|))) (-15 -2014 ((-950 |#1|) (-950 |#1|))) (-15 -2152 ((-950 |#1|) (-950 |#1|))) (-15 -3762 ((-950 |#1|) (-950 |#1|))) (-15 -3976 ((-950 |#1|) (-950 |#1|))) (-15 -3178 ((-950 |#1|) (-950 |#1|))) (-15 -2447 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -1840 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -4407 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -2740 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -3565 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -1510 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -3129 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -3906 ((-1 (-950 |#1|) (-950 |#1|)) |#1| |#1|))) (-13 (-368) (-1190) (-1009))) (T -176)) 
-((-3906 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) (-3129 (*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) (-1510 (*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) (-3565 (*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) (-2740 (*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) (-4407 (*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) (-1840 (*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) (-2447 (*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) (-3178 (*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3)))) (-3976 (*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3)))) (-3762 (*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3)))) (-2152 (*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3)))) (-2014 (*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3)))) (-3962 (*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3)))) (-3998 (*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3))))) 
-(-10 -7 (-15 -3998 ((-950 |#1|) (-950 |#1|))) (-15 -3962 ((-950 |#1|) (-950 |#1|))) (-15 -2014 ((-950 |#1|) (-950 |#1|))) (-15 -2152 ((-950 |#1|) (-950 |#1|))) (-15 -3762 ((-950 |#1|) (-950 |#1|))) (-15 -3976 ((-950 |#1|) (-950 |#1|))) (-15 -3178 ((-950 |#1|) (-950 |#1|))) (-15 -2447 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -1840 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -4407 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -2740 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -3565 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -1510 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -3129 ((-1 (-950 |#1|) (-950 |#1|)) |#1|)) (-15 -3906 ((-1 (-950 |#1|) (-950 |#1|)) |#1| |#1|))) 
-((-2707 ((|#2| |#3|) 27))) 
-(((-177 |#1| |#2| |#3|) (-10 -7 (-15 -2707 (|#2| |#3|))) (-174) (-1234 |#1|) (-720 |#1| |#2|)) (T -177)) 
-((-2707 (*1 *2 *3) (-12 (-4 *4 (-174)) (-4 *2 (-1234 *4)) (-5 *1 (-177 *4 *2 *3)) (-4 *3 (-720 *4 *2))))) 
-(-10 -7 (-15 -2707 (|#2| |#3|))) 
-((-3103 (((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)) 47 (|has| (-959 |#2|) (-887 |#1|))))) 
-(((-178 |#1| |#2| |#3|) (-10 -7 (IF (|has| (-959 |#2|) (-887 |#1|)) (-15 -3103 ((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|))) |noBranch|)) (-1098) (-13 (-887 |#1|) (-174)) (-168 |#2|)) (T -178)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *3)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *3 (-168 *6)) (-4 (-959 *6) (-887 *5)) (-4 *6 (-13 (-887 *5) (-174))) (-5 *1 (-178 *5 *6 *3))))) 
-(-10 -7 (IF (|has| (-959 |#2|) (-887 |#1|)) (-15 -3103 ((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|))) |noBranch|)) 
-((-2160 (((-638 |#1|) (-638 |#1|) |#1|) 36)) (-3479 (((-638 |#1|) |#1| (-638 |#1|)) 19)) (-4399 (((-638 |#1|) (-638 (-638 |#1|)) (-638 |#1|)) 31) ((|#1| (-638 |#1|) (-638 |#1|)) 29))) 
-(((-179 |#1|) (-10 -7 (-15 -3479 ((-638 |#1|) |#1| (-638 |#1|))) (-15 -4399 (|#1| (-638 |#1|) (-638 |#1|))) (-15 -4399 ((-638 |#1|) (-638 (-638 |#1|)) (-638 |#1|))) (-15 -2160 ((-638 |#1|) (-638 |#1|) |#1|))) (-303)) (T -179)) 
-((-2160 (*1 *2 *2 *3) (-12 (-5 *2 (-638 *3)) (-4 *3 (-303)) (-5 *1 (-179 *3)))) (-4399 (*1 *2 *3 *2) (-12 (-5 *3 (-638 (-638 *4))) (-5 *2 (-638 *4)) (-4 *4 (-303)) (-5 *1 (-179 *4)))) (-4399 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *2)) (-5 *1 (-179 *2)) (-4 *2 (-303)))) (-3479 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-303)) (-5 *1 (-179 *3))))) 
-(-10 -7 (-15 -3479 ((-638 |#1|) |#1| (-638 |#1|))) (-15 -4399 (|#1| (-638 |#1|) (-638 |#1|))) (-15 -4399 ((-638 |#1|) (-638 (-638 |#1|)) (-638 |#1|))) (-15 -2160 ((-638 |#1|) (-638 |#1|) |#1|))) 
-((-2870 (((-2 (|:| |start| |#2|) (|:| -4547 (-424 |#2|))) |#2|) 61)) (-1298 ((|#1| |#1|) 54)) (-1712 (((-171 |#1|) |#2|) 82)) (-2901 ((|#1| |#2|) 122) ((|#1| |#2| |#1|) 80)) (-3870 ((|#2| |#2|) 81)) (-3875 (((-424 |#2|) |#2| |#1|) 112) (((-424 |#2|) |#2| |#1| (-121)) 79)) (-4429 ((|#1| |#2|) 111)) (-2862 ((|#2| |#2|) 118)) (-4304 (((-424 |#2|) |#2|) 133) (((-424 |#2|) |#2| |#1|) 32) (((-424 |#2|) |#2| |#1| (-121)) 132)) (-3941 (((-638 (-2 (|:| -4547 (-638 |#2|)) (|:| -3900 |#1|))) |#2| |#2|) 131) (((-638 (-2 (|:| -4547 (-638 |#2|)) (|:| -3900 |#1|))) |#2| |#2| (-121)) 75)) (-3767 (((-638 (-171 |#1|)) |#2| |#1|) 40) (((-638 (-171 |#1|)) |#2|) 41))) 
-(((-180 |#1| |#2|) (-10 -7 (-15 -3767 ((-638 (-171 |#1|)) |#2|)) (-15 -3767 ((-638 (-171 |#1|)) |#2| |#1|)) (-15 -3941 ((-638 (-2 (|:| -4547 (-638 |#2|)) (|:| -3900 |#1|))) |#2| |#2| (-121))) (-15 -3941 ((-638 (-2 (|:| -4547 (-638 |#2|)) (|:| -3900 |#1|))) |#2| |#2|)) (-15 -4304 ((-424 |#2|) |#2| |#1| (-121))) (-15 -4304 ((-424 |#2|) |#2| |#1|)) (-15 -4304 ((-424 |#2|) |#2|)) (-15 -2862 (|#2| |#2|)) (-15 -4429 (|#1| |#2|)) (-15 -3875 ((-424 |#2|) |#2| |#1| (-121))) (-15 -3875 ((-424 |#2|) |#2| |#1|)) (-15 -3870 (|#2| |#2|)) (-15 -2901 (|#1| |#2| |#1|)) (-15 -2901 (|#1| |#2|)) (-15 -1712 ((-171 |#1|) |#2|)) (-15 -1298 (|#1| |#1|)) (-15 -2870 ((-2 (|:| |start| |#2|) (|:| -4547 (-424 |#2|))) |#2|))) (-13 (-368) (-846)) (-1234 (-171 |#1|))) (T -180)) 
-((-2870 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-2 (|:| |start| *3) (|:| -4547 (-424 *3)))) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) (-1298 (*1 *2 *2) (-12 (-4 *2 (-13 (-368) (-846))) (-5 *1 (-180 *2 *3)) (-4 *3 (-1234 (-171 *2))))) (-1712 (*1 *2 *3) (-12 (-5 *2 (-171 *4)) (-5 *1 (-180 *4 *3)) (-4 *4 (-13 (-368) (-846))) (-4 *3 (-1234 *2)))) (-2901 (*1 *2 *3) (-12 (-4 *2 (-13 (-368) (-846))) (-5 *1 (-180 *2 *3)) (-4 *3 (-1234 (-171 *2))))) (-2901 (*1 *2 *3 *2) (-12 (-4 *2 (-13 (-368) (-846))) (-5 *1 (-180 *2 *3)) (-4 *3 (-1234 (-171 *2))))) (-3870 (*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-846))) (-5 *1 (-180 *3 *2)) (-4 *2 (-1234 (-171 *3))))) (-3875 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) (-3875 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) (-4429 (*1 *2 *3) (-12 (-4 *2 (-13 (-368) (-846))) (-5 *1 (-180 *2 *3)) (-4 *3 (-1234 (-171 *2))))) (-2862 (*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-846))) (-5 *1 (-180 *3 *2)) (-4 *2 (-1234 (-171 *3))))) (-4304 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) (-4304 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) (-4304 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) (-3941 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-638 (-2 (|:| -4547 (-638 *3)) (|:| -3900 *4)))) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) (-3941 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-368) (-846))) (-5 *2 (-638 (-2 (|:| -4547 (-638 *3)) (|:| -3900 *5)))) (-5 *1 (-180 *5 *3)) (-4 *3 (-1234 (-171 *5))))) (-3767 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-638 (-171 *4))) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) (-3767 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-638 (-171 *4))) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4)))))) 
-(-10 -7 (-15 -3767 ((-638 (-171 |#1|)) |#2|)) (-15 -3767 ((-638 (-171 |#1|)) |#2| |#1|)) (-15 -3941 ((-638 (-2 (|:| -4547 (-638 |#2|)) (|:| -3900 |#1|))) |#2| |#2| (-121))) (-15 -3941 ((-638 (-2 (|:| -4547 (-638 |#2|)) (|:| -3900 |#1|))) |#2| |#2|)) (-15 -4304 ((-424 |#2|) |#2| |#1| (-121))) (-15 -4304 ((-424 |#2|) |#2| |#1|)) (-15 -4304 ((-424 |#2|) |#2|)) (-15 -2862 (|#2| |#2|)) (-15 -4429 (|#1| |#2|)) (-15 -3875 ((-424 |#2|) |#2| |#1| (-121))) (-15 -3875 ((-424 |#2|) |#2| |#1|)) (-15 -3870 (|#2| |#2|)) (-15 -2901 (|#1| |#2| |#1|)) (-15 -2901 (|#1| |#2|)) (-15 -1712 ((-171 |#1|) |#2|)) (-15 -1298 (|#1| |#1|)) (-15 -2870 ((-2 (|:| |start| |#2|) (|:| -4547 (-424 |#2|))) |#2|))) 
-((-4388 (((-3 |#2| "failed") |#2|) 14)) (-3576 (((-769) |#2|) 16)) (-1781 ((|#2| |#2| |#2|) 18))) 
-(((-181 |#1| |#2|) (-10 -7 (-15 -4388 ((-3 |#2| "failed") |#2|)) (-15 -3576 ((-769) |#2|)) (-15 -1781 (|#2| |#2| |#2|))) (-1204) (-669 |#1|)) (T -181)) 
-((-1781 (*1 *2 *2 *2) (-12 (-4 *3 (-1204)) (-5 *1 (-181 *3 *2)) (-4 *2 (-669 *3)))) (-3576 (*1 *2 *3) (-12 (-4 *4 (-1204)) (-5 *2 (-769)) (-5 *1 (-181 *4 *3)) (-4 *3 (-669 *4)))) (-4388 (*1 *2 *2) (|partial| -12 (-4 *3 (-1204)) (-5 *1 (-181 *3 *2)) (-4 *2 (-669 *3))))) 
-(-10 -7 (-15 -4388 ((-3 |#2| "failed") |#2|)) (-15 -3576 ((-769) |#2|)) (-15 -1781 (|#2| |#2| |#2|))) 
-((-3838 ((|#2| |#2|) 28)) (-4523 (((-121) |#2|) 19)) (-3359 (((-312 |#1|) |#2|) 12)) (-4310 (((-312 |#1|) |#2|) 14)) (-2126 ((|#2| |#2| (-1170)) 68) ((|#2| |#2|) 69)) (-1485 (((-171 (-312 |#1|)) |#2|) 9)) (-2635 ((|#2| |#2| (-1170)) 65) ((|#2| |#2|) 58))) 
-(((-182 |#1| |#2|) (-10 -7 (-15 -2126 (|#2| |#2|)) (-15 -2126 (|#2| |#2| (-1170))) (-15 -2635 (|#2| |#2|)) (-15 -2635 (|#2| |#2| (-1170))) (-15 -3359 ((-312 |#1|) |#2|)) (-15 -4310 ((-312 |#1|) |#2|)) (-15 -4523 ((-121) |#2|)) (-15 -3838 (|#2| |#2|)) (-15 -1485 ((-171 (-312 |#1|)) |#2|))) (-13 (-562) (-848) (-1044 (-572))) (-13 (-27) (-1190) (-436 (-171 |#1|)))) (T -182)) 
-((-1485 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-171 (-312 *4))) (-5 *1 (-182 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 (-171 *4)))))) (-3838 (*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *3)))))) (-4523 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-121)) (-5 *1 (-182 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 (-171 *4)))))) (-4310 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-312 *4)) (-5 *1 (-182 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 (-171 *4)))))) (-3359 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-312 *4)) (-5 *1 (-182 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 (-171 *4)))))) (-2635 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *4)))))) (-2635 (*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *3)))))) (-2126 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *4)))))) (-2126 (*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *3))))))) 
-(-10 -7 (-15 -2126 (|#2| |#2|)) (-15 -2126 (|#2| |#2| (-1170))) (-15 -2635 (|#2| |#2|)) (-15 -2635 (|#2| |#2| (-1170))) (-15 -3359 ((-312 |#1|) |#2|)) (-15 -4310 ((-312 |#1|) |#2|)) (-15 -4523 ((-121) |#2|)) (-15 -3838 (|#2| |#2|)) (-15 -1485 ((-171 (-312 |#1|)) |#2|))) 
-((-1294 (((-1259 (-685 (-959 |#1|))) (-1259 (-685 |#1|))) 22)) (-3972 (((-1259 (-685 (-413 (-959 |#1|)))) (-1259 (-685 |#1|))) 30))) 
-(((-183 |#1|) (-10 -7 (-15 -1294 ((-1259 (-685 (-959 |#1|))) (-1259 (-685 |#1|)))) (-15 -3972 ((-1259 (-685 (-413 (-959 |#1|)))) (-1259 (-685 |#1|))))) (-174)) (T -183)) 
-((-3972 (*1 *2 *3) (-12 (-5 *3 (-1259 (-685 *4))) (-4 *4 (-174)) (-5 *2 (-1259 (-685 (-413 (-959 *4))))) (-5 *1 (-183 *4)))) (-1294 (*1 *2 *3) (-12 (-5 *3 (-1259 (-685 *4))) (-4 *4 (-174)) (-5 *2 (-1259 (-685 (-959 *4)))) (-5 *1 (-183 *4))))) 
-(-10 -7 (-15 -1294 ((-1259 (-685 (-959 |#1|))) (-1259 (-685 |#1|)))) (-15 -3972 ((-1259 (-685 (-413 (-959 |#1|)))) (-1259 (-685 |#1|))))) 
-((-2161 (((-1172 (-413 (-572))) (-1172 (-413 (-572))) (-1172 (-413 (-572)))) 66)) (-4031 (((-1172 (-413 (-572))) (-638 (-572)) (-638 (-572))) 74)) (-3500 (((-1172 (-413 (-572))) (-572)) 40)) (-3213 (((-1172 (-413 (-572))) (-572)) 52)) (-4485 (((-413 (-572)) (-1172 (-413 (-572)))) 62)) (-3681 (((-1172 (-413 (-572))) (-572)) 32)) (-1693 (((-1172 (-413 (-572))) (-572)) 48)) (-4398 (((-1172 (-413 (-572))) (-572)) 46)) (-4281 (((-1172 (-413 (-572))) (-1172 (-413 (-572))) (-1172 (-413 (-572)))) 60)) (-2424 (((-1172 (-413 (-572))) (-572)) 25)) (-3779 (((-413 (-572)) (-1172 (-413 (-572))) (-1172 (-413 (-572)))) 64)) (-3374 (((-1172 (-413 (-572))) (-572)) 30)) (-3685 (((-1172 (-413 (-572))) (-638 (-572))) 71))) 
-(((-184) (-10 -7 (-15 -2424 ((-1172 (-413 (-572))) (-572))) (-15 -3500 ((-1172 (-413 (-572))) (-572))) (-15 -3681 ((-1172 (-413 (-572))) (-572))) (-15 -3374 ((-1172 (-413 (-572))) (-572))) (-15 -4398 ((-1172 (-413 (-572))) (-572))) (-15 -1693 ((-1172 (-413 (-572))) (-572))) (-15 -3213 ((-1172 (-413 (-572))) (-572))) (-15 -3779 ((-413 (-572)) (-1172 (-413 (-572))) (-1172 (-413 (-572))))) (-15 -4281 ((-1172 (-413 (-572))) (-1172 (-413 (-572))) (-1172 (-413 (-572))))) (-15 -4485 ((-413 (-572)) (-1172 (-413 (-572))))) (-15 -2161 ((-1172 (-413 (-572))) (-1172 (-413 (-572))) (-1172 (-413 (-572))))) (-15 -3685 ((-1172 (-413 (-572))) (-638 (-572)))) (-15 -4031 ((-1172 (-413 (-572))) (-638 (-572)) (-638 (-572)))))) (T -184)) 
-((-4031 (*1 *2 *3 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)))) (-3685 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)))) (-2161 (*1 *2 *2 *2) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)))) (-4485 (*1 *2 *3) (-12 (-5 *3 (-1172 (-413 (-572)))) (-5 *2 (-413 (-572))) (-5 *1 (-184)))) (-4281 (*1 *2 *2 *2) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)))) (-3779 (*1 *2 *3 *3) (-12 (-5 *3 (-1172 (-413 (-572)))) (-5 *2 (-413 (-572))) (-5 *1 (-184)))) (-3213 (*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572)))) (-1693 (*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572)))) (-4398 (*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572)))) (-3374 (*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572)))) (-3681 (*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572)))) (-3500 (*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572)))) (-2424 (*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572))))) 
-(-10 -7 (-15 -2424 ((-1172 (-413 (-572))) (-572))) (-15 -3500 ((-1172 (-413 (-572))) (-572))) (-15 -3681 ((-1172 (-413 (-572))) (-572))) (-15 -3374 ((-1172 (-413 (-572))) (-572))) (-15 -4398 ((-1172 (-413 (-572))) (-572))) (-15 -1693 ((-1172 (-413 (-572))) (-572))) (-15 -3213 ((-1172 (-413 (-572))) (-572))) (-15 -3779 ((-413 (-572)) (-1172 (-413 (-572))) (-1172 (-413 (-572))))) (-15 -4281 ((-1172 (-413 (-572))) (-1172 (-413 (-572))) (-1172 (-413 (-572))))) (-15 -4485 ((-413 (-572)) (-1172 (-413 (-572))))) (-15 -2161 ((-1172 (-413 (-572))) (-1172 (-413 (-572))) (-1172 (-413 (-572))))) (-15 -3685 ((-1172 (-413 (-572))) (-638 (-572)))) (-15 -4031 ((-1172 (-413 (-572))) (-638 (-572)) (-638 (-572))))) 
-((-2162 (((-424 (-1166 (-572))) (-572)) 28)) (-1345 (((-638 (-1166 (-572))) (-572)) 23)) (-2654 (((-1166 (-572)) (-572)) 21))) 
-(((-185) (-10 -7 (-15 -1345 ((-638 (-1166 (-572))) (-572))) (-15 -2654 ((-1166 (-572)) (-572))) (-15 -2162 ((-424 (-1166 (-572))) (-572))))) (T -185)) 
-((-2162 (*1 *2 *3) (-12 (-5 *2 (-424 (-1166 (-572)))) (-5 *1 (-185)) (-5 *3 (-572)))) (-2654 (*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-185)) (-5 *3 (-572)))) (-1345 (*1 *2 *3) (-12 (-5 *2 (-638 (-1166 (-572)))) (-5 *1 (-185)) (-5 *3 (-572))))) 
-(-10 -7 (-15 -1345 ((-638 (-1166 (-572))) (-572))) (-15 -2654 ((-1166 (-572)) (-572))) (-15 -2162 ((-424 (-1166 (-572))) (-572)))) 
-((-3145 (((-1150 (-217)) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 101)) (-4050 (((-638 (-1152)) (-1150 (-217))) NIL)) (-3600 (((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 77)) (-2491 (((-638 (-217)) (-312 (-217)) (-1170) (-1092 (-841 (-217)))) NIL)) (-1417 (((-638 (-1152)) (-638 (-217))) NIL)) (-3839 (((-217) (-1092 (-841 (-217)))) 22)) (-2567 (((-217) (-1092 (-841 (-217)))) 23)) (-4205 (((-385) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 93)) (-2682 (((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 40)) (-1937 (((-1152) (-217)) NIL)) (-1507 (((-1152) (-638 (-1152))) 19)) (-4214 (((-1042) (-1170) (-1170) (-1042)) 12))) 
-(((-186) (-10 -7 (-15 -3600 ((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2682 ((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3839 ((-217) (-1092 (-841 (-217))))) (-15 -2567 ((-217) (-1092 (-841 (-217))))) (-15 -4205 ((-385) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2491 ((-638 (-217)) (-312 (-217)) (-1170) (-1092 (-841 (-217))))) (-15 -3145 ((-1150 (-217)) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -1937 ((-1152) (-217))) (-15 -1417 ((-638 (-1152)) (-638 (-217)))) (-15 -4050 ((-638 (-1152)) (-1150 (-217)))) (-15 -1507 ((-1152) (-638 (-1152)))) (-15 -4214 ((-1042) (-1170) (-1170) (-1042))))) (T -186)) 
-((-4214 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1042)) (-5 *3 (-1170)) (-5 *1 (-186)))) (-1507 (*1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-1152)) (-5 *1 (-186)))) (-4050 (*1 *2 *3) (-12 (-5 *3 (-1150 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-186)))) (-1417 (*1 *2 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-186)))) (-1937 (*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-1152)) (-5 *1 (-186)))) (-3145 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-1150 (-217))) (-5 *1 (-186)))) (-2491 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-1170)) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-638 (-217))) (-5 *1 (-186)))) (-4205 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-186)))) (-2567 (*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-186)))) (-3839 (*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-186)))) (-2682 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (-5 *1 (-186)))) (-3600 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (-5 *1 (-186))))) 
-(-10 -7 (-15 -3600 ((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2682 ((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3839 ((-217) (-1092 (-841 (-217))))) (-15 -2567 ((-217) (-1092 (-841 (-217))))) (-15 -4205 ((-385) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2491 ((-638 (-217)) (-312 (-217)) (-1170) (-1092 (-841 (-217))))) (-15 -3145 ((-1150 (-217)) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -1937 ((-1152) (-217))) (-15 -1417 ((-638 (-1152)) (-638 (-217)))) (-15 -4050 ((-638 (-1152)) (-1150 (-217)))) (-15 -1507 ((-1152) (-638 (-1152)))) (-15 -4214 ((-1042) (-1170) (-1170) (-1042)))) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 53) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 28) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-187) (-788)) (T -187)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 58) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 37) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-188) (-788)) (T -188)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 67) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 36) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-189) (-788)) (T -189)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 54) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 30) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-190) (-788)) (T -190)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 65) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 35) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-191) (-788)) (T -191)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 71) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 33) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-192) (-788)) (T -192)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 78) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 43) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-193) (-788)) (T -193)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 68) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 37) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-194) (-788)) (T -194)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 62)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 29)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-195) (-788)) (T -195)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 60)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 32)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-196) (-788)) (T -196)) 
-NIL 
-(-788) 
-((-2262 (((-121) $ $) NIL)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 89) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 77) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-197) (-788)) (T -197)) 
-NIL 
-(-788) 
-((-1983 (((-3 (-2 (|:| -1824 (-123)) (|:| |w| (-217))) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 80)) (-1682 (((-572) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 39)) (-2646 (((-3 (-638 (-217)) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 69))) 
-(((-198) (-10 -7 (-15 -1983 ((-3 (-2 (|:| -1824 (-123)) (|:| |w| (-217))) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2646 ((-3 (-638 (-217)) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -1682 ((-572) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) (T -198)) 
-((-1682 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-572)) (-5 *1 (-198)))) (-2646 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-638 (-217))) (-5 *1 (-198)))) (-1983 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| -1824 (-123)) (|:| |w| (-217)))) (-5 *1 (-198))))) 
-(-10 -7 (-15 -1983 ((-3 (-2 (|:| -1824 (-123)) (|:| |w| (-217))) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2646 ((-3 (-638 (-217)) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -1682 ((-572) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) 
-((-1516 (((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 37)) (-2708 (((-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385))) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 127)) (-1478 (((-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385))) (-685 (-312 (-217)))) 87)) (-2143 (((-385) (-685 (-312 (-217)))) 110)) (-3441 (((-685 (-312 (-217))) (-1259 (-312 (-217))) (-638 (-1170))) 107)) (-3054 (((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 26)) (-4042 (((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 42)) (-4485 (((-685 (-312 (-217))) (-685 (-312 (-217))) (-638 (-1170)) (-1259 (-312 (-217)))) 99)) (-2054 (((-385) (-385) (-638 (-385))) 104) (((-385) (-385) (-385)) 102)) (-4057 (((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 33))) 
-(((-199) (-10 -7 (-15 -2054 ((-385) (-385) (-385))) (-15 -2054 ((-385) (-385) (-638 (-385)))) (-15 -2143 ((-385) (-685 (-312 (-217))))) (-15 -3441 ((-685 (-312 (-217))) (-1259 (-312 (-217))) (-638 (-1170)))) (-15 -4485 ((-685 (-312 (-217))) (-685 (-312 (-217))) (-638 (-1170)) (-1259 (-312 (-217))))) (-15 -1478 ((-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385))) (-685 (-312 (-217))))) (-15 -2708 ((-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385))) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -1516 ((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -4042 ((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -4057 ((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3054 ((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) (T -199)) 
-((-3054 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-199)))) (-4057 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-199)))) (-4042 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-199)))) (-1516 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-199)))) (-2708 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385)))) (-5 *1 (-199)))) (-1478 (*1 *2 *3) (-12 (-5 *3 (-685 (-312 (-217)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385)))) (-5 *1 (-199)))) (-4485 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-685 (-312 (-217)))) (-5 *3 (-638 (-1170))) (-5 *4 (-1259 (-312 (-217)))) (-5 *1 (-199)))) (-3441 (*1 *2 *3 *4) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *4 (-638 (-1170))) (-5 *2 (-685 (-312 (-217)))) (-5 *1 (-199)))) (-2143 (*1 *2 *3) (-12 (-5 *3 (-685 (-312 (-217)))) (-5 *2 (-385)) (-5 *1 (-199)))) (-2054 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-385))) (-5 *2 (-385)) (-5 *1 (-199)))) (-2054 (*1 *2 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-199))))) 
-(-10 -7 (-15 -2054 ((-385) (-385) (-385))) (-15 -2054 ((-385) (-385) (-638 (-385)))) (-15 -2143 ((-385) (-685 (-312 (-217))))) (-15 -3441 ((-685 (-312 (-217))) (-1259 (-312 (-217))) (-638 (-1170)))) (-15 -4485 ((-685 (-312 (-217))) (-685 (-312 (-217))) (-638 (-1170)) (-1259 (-312 (-217))))) (-15 -1478 ((-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385))) (-685 (-312 (-217))))) (-15 -2708 ((-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385))) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -1516 ((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -4042 ((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -4057 ((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3054 ((-385) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) 
-((-2262 (((-121) $ $) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 37)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1512 (((-1042) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 60)) (-1324 (((-121) $ $) NIL))) 
-(((-200) (-801)) (T -200)) 
-NIL 
-(-801) 
-((-2262 (((-121) $ $) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 37)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1512 (((-1042) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 60)) (-1324 (((-121) $ $) NIL))) 
-(((-201) (-801)) (T -201)) 
-NIL 
-(-801) 
-((-2262 (((-121) $ $) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 36)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1512 (((-1042) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 64)) (-1324 (((-121) $ $) NIL))) 
-(((-202) (-801)) (T -202)) 
-NIL 
-(-801) 
-((-2262 (((-121) $ $) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 42)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1512 (((-1042) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 73)) (-1324 (((-121) $ $) NIL))) 
-(((-203) (-801)) (T -203)) 
-NIL 
-(-801) 
-((-2199 (((-638 (-1170)) (-1170) (-769)) 22)) (-1942 (((-312 (-217)) (-312 (-217))) 29)) (-2657 (((-121) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) 67)) (-1653 (((-121) (-217) (-217) (-638 (-312 (-217)))) 43))) 
-(((-204) (-10 -7 (-15 -2199 ((-638 (-1170)) (-1170) (-769))) (-15 -1942 ((-312 (-217)) (-312 (-217)))) (-15 -1653 ((-121) (-217) (-217) (-638 (-312 (-217))))) (-15 -2657 ((-121) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217))))))) (T -204)) 
-((-2657 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *2 (-121)) (-5 *1 (-204)))) (-1653 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-638 (-312 (-217)))) (-5 *3 (-217)) (-5 *2 (-121)) (-5 *1 (-204)))) (-1942 (*1 *2 *2) (-12 (-5 *2 (-312 (-217))) (-5 *1 (-204)))) (-2199 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-5 *2 (-638 (-1170))) (-5 *1 (-204)) (-5 *3 (-1170))))) 
-(-10 -7 (-15 -2199 ((-638 (-1170)) (-1170) (-769))) (-15 -1942 ((-312 (-217)) (-312 (-217)))) (-15 -1653 ((-121) (-217) (-217) (-638 (-312 (-217))))) (-15 -2657 ((-121) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))))) 
-((-2262 (((-121) $ $) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) 17)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-2047 (((-1042) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) 55)) (-1324 (((-121) $ $) NIL))) 
-(((-205) (-896)) (T -205)) 
-NIL 
-(-896) 
-((-2262 (((-121) $ $) NIL)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) 12)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-2047 (((-1042) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-206) (-896)) (T -206)) 
-NIL 
-(-896) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3735 (((-1264) $) 36) (((-1264) $ (-923) (-923)) 38)) (-3277 (($ $ (-997)) 19) (((-242 (-1152)) $ (-1170)) 15)) (-2415 (((-1264) $) 34)) (-3972 (((-856) $) 31) (($ (-638 |#1|)) 8)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $ $) 27)) (-1367 (($ $ $) 22))) 
-(((-207 |#1|) (-13 (-1098) (-10 -8 (-15 -3277 ($ $ (-997))) (-15 -3277 ((-242 (-1152)) $ (-1170))) (-15 -1367 ($ $ $)) (-15 -1373 ($ $ $)) (-15 -3972 ($ (-638 |#1|))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $)) (-15 -3735 ((-1264) $ (-923) (-923))))) (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))) (T -207)) 
-((-3277 (*1 *1 *1 *2) (-12 (-5 *2 (-997)) (-5 *1 (-207 *3)) (-4 *3 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-242 (-1152))) (-5 *1 (-207 *4)) (-4 *4 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ *3)) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))))) (-1367 (*1 *1 *1 *1) (-12 (-5 *1 (-207 *2)) (-4 *2 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))))) (-1373 (*1 *1 *1 *1) (-12 (-5 *1 (-207 *2)) (-4 *2 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))) (-5 *1 (-207 *3)))) (-2415 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-207 *3)) (-4 *3 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 (*2 $)) (-15 -3735 (*2 $))))))) (-3735 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-207 *3)) (-4 *3 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 (*2 $)) (-15 -3735 (*2 $))))))) (-3735 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1264)) (-5 *1 (-207 *4)) (-4 *4 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 (*2 $)) (-15 -3735 (*2 $)))))))) 
-(-13 (-1098) (-10 -8 (-15 -3277 ($ $ (-997))) (-15 -3277 ((-242 (-1152)) $ (-1170))) (-15 -1367 ($ $ $)) (-15 -1373 ($ $ $)) (-15 -3972 ($ (-638 |#1|))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $)) (-15 -3735 ((-1264) $ (-923) (-923))))) 
-((-3613 ((|#2| |#4| (-1 |#2| |#2|)) 46))) 
-(((-208 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3613 (|#2| |#4| (-1 |#2| |#2|)))) (-368) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|)) (T -208)) 
-((-3613 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *2 *2)) (-4 *5 (-368)) (-4 *6 (-1234 (-413 *2))) (-4 *2 (-1234 *5)) (-5 *1 (-208 *5 *2 *6 *3)) (-4 *3 (-342 *5 *2 *6))))) 
-(-10 -7 (-15 -3613 (|#2| |#4| (-1 |#2| |#2|)))) 
-((-1884 ((|#2| |#2| (-769) |#2|) 41)) (-1322 ((|#2| |#2| (-769) |#2|) 37)) (-4227 (((-638 |#2|) (-638 (-2 (|:| |deg| (-769)) (|:| -2225 |#2|)))) 55)) (-2710 (((-638 (-2 (|:| |deg| (-769)) (|:| -2225 |#2|))) |#2|) 51)) (-4452 (((-121) |#2|) 48)) (-2602 (((-424 |#2|) |#2|) 74)) (-4304 (((-424 |#2|) |#2|) 73)) (-1319 ((|#2| |#2| (-769) |#2|) 35)) (-3634 (((-2 (|:| |cont| |#1|) (|:| -4547 (-638 (-2 (|:| |irr| |#2|) (|:| -3341 (-572)))))) |#2| (-121)) 66))) 
-(((-209 |#1| |#2|) (-10 -7 (-15 -4304 ((-424 |#2|) |#2|)) (-15 -2602 ((-424 |#2|) |#2|)) (-15 -3634 ((-2 (|:| |cont| |#1|) (|:| -4547 (-638 (-2 (|:| |irr| |#2|) (|:| -3341 (-572)))))) |#2| (-121))) (-15 -2710 ((-638 (-2 (|:| |deg| (-769)) (|:| -2225 |#2|))) |#2|)) (-15 -4227 ((-638 |#2|) (-638 (-2 (|:| |deg| (-769)) (|:| -2225 |#2|))))) (-15 -1319 (|#2| |#2| (-769) |#2|)) (-15 -1322 (|#2| |#2| (-769) |#2|)) (-15 -1884 (|#2| |#2| (-769) |#2|)) (-15 -4452 ((-121) |#2|))) (-353) (-1234 |#1|)) (T -209)) 
-((-4452 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-209 *4 *3)) (-4 *3 (-1234 *4)))) (-1884 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-769)) (-4 *4 (-353)) (-5 *1 (-209 *4 *2)) (-4 *2 (-1234 *4)))) (-1322 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-769)) (-4 *4 (-353)) (-5 *1 (-209 *4 *2)) (-4 *2 (-1234 *4)))) (-1319 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-769)) (-4 *4 (-353)) (-5 *1 (-209 *4 *2)) (-4 *2 (-1234 *4)))) (-4227 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| |deg| (-769)) (|:| -2225 *5)))) (-4 *5 (-1234 *4)) (-4 *4 (-353)) (-5 *2 (-638 *5)) (-5 *1 (-209 *4 *5)))) (-2710 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-638 (-2 (|:| |deg| (-769)) (|:| -2225 *3)))) (-5 *1 (-209 *4 *3)) (-4 *3 (-1234 *4)))) (-3634 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-353)) (-5 *2 (-2 (|:| |cont| *5) (|:| -4547 (-638 (-2 (|:| |irr| *3) (|:| -3341 (-572))))))) (-5 *1 (-209 *5 *3)) (-4 *3 (-1234 *5)))) (-2602 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-209 *4 *3)) (-4 *3 (-1234 *4)))) (-4304 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-209 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -4304 ((-424 |#2|) |#2|)) (-15 -2602 ((-424 |#2|) |#2|)) (-15 -3634 ((-2 (|:| |cont| |#1|) (|:| -4547 (-638 (-2 (|:| |irr| |#2|) (|:| -3341 (-572)))))) |#2| (-121))) (-15 -2710 ((-638 (-2 (|:| |deg| (-769)) (|:| -2225 |#2|))) |#2|)) (-15 -4227 ((-638 |#2|) (-638 (-2 (|:| |deg| (-769)) (|:| -2225 |#2|))))) (-15 -1319 (|#2| |#2| (-769) |#2|)) (-15 -1322 (|#2| |#2| (-769) |#2|)) (-15 -1884 (|#2| |#2| (-769) |#2|)) (-15 -4452 ((-121) |#2|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 (((-572) $) NIL (|has| (-572) (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| (-572) (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL (|has| (-572) (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-572) (-1044 (-572)))) (((-3 (-572) "failed") $) NIL (|has| (-572) (-1044 (-572))))) (-1318 (((-572) $) NIL) (((-1170) $) NIL (|has| (-572) (-1044 (-1170)))) (((-413 (-572)) $) NIL (|has| (-572) (-1044 (-572)))) (((-572) $) NIL (|has| (-572) (-1044 (-572))))) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-572) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-572) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-685 (-572)) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-572) (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) NIL (|has| (-572) (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| (-572) (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| (-572) (-887 (-385))))) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL)) (-4487 (((-572) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| (-572) (-1144)))) (-4472 (((-121) $) NIL (|has| (-572) (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-572) (-848)))) (-3828 (($ (-1 (-572) (-572)) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-572) (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| (-572) (-303))) (((-413 (-572)) $) NIL)) (-1716 (((-572) $) NIL (|has| (-572) (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 (-572)) (-638 (-572))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-572) (-572)) NIL (|has| (-572) (-305 (-572)))) (($ $ (-290 (-572))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-638 (-290 (-572)))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-638 (-1170)) (-638 (-572))) NIL (|has| (-572) (-527 (-1170) (-572)))) (($ $ (-1170) (-572)) NIL (|has| (-572) (-527 (-1170) (-572))))) (-4029 (((-769) $) NIL)) (-3277 (($ $ (-572)) NIL (|has| (-572) (-283 (-572) (-572))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL (|has| (-572) (-227))) (($ $ (-769)) NIL (|has| (-572) (-227))) (($ $ (-1170)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1 (-572) (-572)) (-769)) NIL) (($ $ (-1 (-572) (-572))) NIL)) (-3425 (($ $) NIL)) (-4492 (((-572) $) NIL)) (-2949 (($ (-413 (-572))) 8)) (-4081 (((-893 (-572)) $) NIL (|has| (-572) (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| (-572) (-613 (-893 (-385))))) (((-545) $) NIL (|has| (-572) (-613 (-545)))) (((-385) $) NIL (|has| (-572) (-1028))) (((-217) $) NIL (|has| (-572) (-1028)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-572) (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) 7) (($ (-572)) NIL) (($ (-1170)) NIL (|has| (-572) (-1044 (-1170)))) (((-413 (-572)) $) NIL) (((-1011 10) $) 9)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-572) (-910))) (|has| (-572) (-149))))) (-2140 (((-769)) NIL)) (-2634 (((-572) $) NIL (|has| (-572) (-554)))) (-3774 (((-121) $ $) NIL)) (-2264 (($ $) NIL (|has| (-572) (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $) NIL (|has| (-572) (-227))) (($ $ (-769)) NIL (|has| (-572) (-227))) (($ $ (-1170)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1 (-572) (-572)) (-769)) NIL) (($ $ (-1 (-572) (-572))) NIL)) (-1349 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1379 (($ $ $) NIL) (($ (-572) (-572)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ (-572) $) NIL) (($ $ (-572)) NIL))) 
-(((-210) (-13 (-1000 (-572)) (-10 -8 (-15 -3972 ((-413 (-572)) $)) (-15 -3972 ((-1011 10) $)) (-15 -3346 ((-413 (-572)) $)) (-15 -2949 ($ (-413 (-572))))))) (T -210)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-210)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1011 10)) (-5 *1 (-210)))) (-3346 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-210)))) (-2949 (*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-210))))) 
-(-13 (-1000 (-572)) (-10 -8 (-15 -3972 ((-413 (-572)) $)) (-15 -3972 ((-1011 10) $)) (-15 -3346 ((-413 (-572)) $)) (-15 -2949 ($ (-413 (-572)))))) 
-((-2774 (((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1090 (-841 |#2|)) (-1152)) 27) (((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1090 (-841 |#2|))) 23)) (-2734 (((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1170) (-841 |#2|) (-841 |#2|) (-121)) 16))) 
-(((-211 |#1| |#2|) (-10 -7 (-15 -2774 ((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1090 (-841 |#2|)))) (-15 -2774 ((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1090 (-841 |#2|)) (-1152))) (-15 -2734 ((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1170) (-841 |#2|) (-841 |#2|) (-121)))) (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572))) (-13 (-1190) (-966) (-29 |#1|))) (T -211)) 
-((-2734 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-1170)) (-5 *6 (-121)) (-4 *7 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-4 *3 (-13 (-1190) (-966) (-29 *7))) (-5 *2 (-3 (|:| |f1| (-841 *3)) (|:| |f2| (-638 (-841 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-211 *7 *3)) (-5 *5 (-841 *3)))) (-2774 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1090 (-841 *3))) (-5 *5 (-1152)) (-4 *3 (-13 (-1190) (-966) (-29 *6))) (-4 *6 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 *3)) (|:| |f2| (-638 (-841 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-211 *6 *3)))) (-2774 (*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-841 *3))) (-4 *3 (-13 (-1190) (-966) (-29 *5))) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 *3)) (|:| |f2| (-638 (-841 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-211 *5 *3))))) 
-(-10 -7 (-15 -2774 ((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1090 (-841 |#2|)))) (-15 -2774 ((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1090 (-841 |#2|)) (-1152))) (-15 -2734 ((-3 (|:| |f1| (-841 |#2|)) (|:| |f2| (-638 (-841 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1170) (-841 |#2|) (-841 |#2|) (-121)))) 
-((-2774 (((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-413 (-959 |#1|)))) (-1152)) 44) (((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-413 (-959 |#1|))))) 41) (((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-312 |#1|))) (-1152)) 45) (((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-312 |#1|)))) 17))) 
-(((-212 |#1|) (-10 -7 (-15 -2774 ((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-312 |#1|))))) (-15 -2774 ((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-312 |#1|))) (-1152))) (-15 -2774 ((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-413 (-959 |#1|)))))) (-15 -2774 ((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-413 (-959 |#1|)))) (-1152)))) (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (T -212)) 
-((-2774 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1090 (-841 (-413 (-959 *6))))) (-5 *5 (-1152)) (-5 *3 (-413 (-959 *6))) (-4 *6 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 (-312 *6))) (|:| |f2| (-638 (-841 (-312 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-212 *6)))) (-2774 (*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-841 (-413 (-959 *5))))) (-5 *3 (-413 (-959 *5))) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 (-312 *5))) (|:| |f2| (-638 (-841 (-312 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-212 *5)))) (-2774 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-413 (-959 *6))) (-5 *4 (-1090 (-841 (-312 *6)))) (-5 *5 (-1152)) (-4 *6 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 (-312 *6))) (|:| |f2| (-638 (-841 (-312 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-212 *6)))) (-2774 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1090 (-841 (-312 *5)))) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 (-312 *5))) (|:| |f2| (-638 (-841 (-312 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-212 *5))))) 
-(-10 -7 (-15 -2774 ((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-312 |#1|))))) (-15 -2774 ((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-312 |#1|))) (-1152))) (-15 -2774 ((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-413 (-959 |#1|)))))) (-15 -2774 ((-3 (|:| |f1| (-841 (-312 |#1|))) (|:| |f2| (-638 (-841 (-312 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-413 (-959 |#1|)) (-1090 (-841 (-413 (-959 |#1|)))) (-1152)))) 
-((-3116 (((-2 (|:| -1805 (-1166 |#1|)) (|:| |deg| (-923))) (-1166 |#1|)) 20)) (-2534 (((-638 (-312 |#2|)) (-312 |#2|) (-923)) 42))) 
-(((-213 |#1| |#2|) (-10 -7 (-15 -3116 ((-2 (|:| -1805 (-1166 |#1|)) (|:| |deg| (-923))) (-1166 |#1|))) (-15 -2534 ((-638 (-312 |#2|)) (-312 |#2|) (-923)))) (-1054) (-13 (-562) (-848))) (T -213)) 
-((-2534 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *6 (-13 (-562) (-848))) (-5 *2 (-638 (-312 *6))) (-5 *1 (-213 *5 *6)) (-5 *3 (-312 *6)) (-4 *5 (-1054)))) (-3116 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-2 (|:| -1805 (-1166 *4)) (|:| |deg| (-923)))) (-5 *1 (-213 *4 *5)) (-5 *3 (-1166 *4)) (-4 *5 (-13 (-562) (-848)))))) 
-(-10 -7 (-15 -3116 ((-2 (|:| -1805 (-1166 |#1|)) (|:| |deg| (-923))) (-1166 |#1|))) (-15 -2534 ((-638 (-312 |#2|)) (-312 |#2|) (-923)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1312 ((|#1| $) 25)) (-1615 ((|#1| $) 26)) (-1946 (((-121) $ (-769)) NIL)) (-2211 (($) NIL T CONST)) (-4080 (($ $) NIL)) (-2985 (($ $) 32)) (-4107 ((|#1| |#1| $) NIL)) (-3772 ((|#1| $) NIL)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-3200 (((-769) $) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-4221 ((|#1| $) NIL)) (-2243 ((|#1| |#1| $) 29)) (-1488 ((|#1| |#1| $) 31)) (-1335 (($ |#1| $) NIL)) (-1455 (((-769) $) 27)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2011 ((|#1| $) NIL)) (-2983 ((|#1| $) 24)) (-3205 ((|#1| $) 8)) (-2232 ((|#1| $) NIL)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-2933 ((|#1| |#1| $) NIL)) (-4037 (((-121) $) 15)) (-1665 (($) NIL)) (-4494 ((|#1| $) NIL)) (-2446 (($) NIL) (($ (-638 |#1|)) 13)) (-1564 (((-769) $) 28)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-4579 ((|#1| $) 9)) (-3058 (($ (-638 |#1|)) NIL)) (-3782 ((|#1| $) NIL)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-214 |#1|) (-13 (-249 |#1|) (-10 -8 (-15 -2446 ($ (-638 |#1|))) (-15 -4494 (|#1| $)) (-15 -2232 (|#1| $)) (-15 -2933 (|#1| |#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -2011 (|#1| $)) (-15 -3782 (|#1| $)) (-15 -4080 ($ $)) (-15 -3200 ((-769) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -3058 ($ (-638 |#1|))) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -2211 ($)) (-15 -1607 ($ $)) (-15 -3598 ((-121) $ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (-15 -1564 ((-769) $)) (-15 -2446 ($)) (-15 -1455 ((-769) $)) (-15 -1615 (|#1| $)) (-15 -4579 (|#1| $)) (-15 -3205 (|#1| $)) (-15 -2983 (|#1| $)) (-15 -1488 (|#1| |#1| $)) (-15 -2243 (|#1| |#1| $)) (-15 -3772 (|#1| $)) (-15 -4107 (|#1| |#1| $)) (-15 -2985 ($ $)) (-15 -1312 (|#1| $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) (-1098)) (T -214)) 
-((-3598 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) (-1607 (*1 *1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-1665 (*1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-4037 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) (-3524 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-214 *4)) (-4 *4 (-1098)))) (-2157 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-214 *4)) (-4 *4 (-1098)))) (-1946 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-214 *4)) (-4 *4 (-1098)))) (-2211 (*1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-4032 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-214 *3)))) (-2435 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-1098)) (-5 *1 (-214 *3)))) (-3501 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-214 *4)))) (-2109 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-214 *4)))) (-1571 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-214 *4)))) (-2010 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) (-1571 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3002 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-1658 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-2607 (*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-1324 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-2262 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3058 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-214 *3)))) (-2232 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-1335 (*1 *1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-4221 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-4107 (*1 *2 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-3772 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-1615 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-1564 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) (-3782 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-2011 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-3200 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) (-4080 (*1 *1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-4494 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-2933 (*1 *2 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-2446 (*1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-2446 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-214 *3)))) (-1455 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) (-1312 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-4579 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-2243 (*1 *2 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-1488 (*1 *2 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-2983 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-3205 (*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) (-2985 (*1 *1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098))))) 
-(-13 (-249 |#1|) (-10 -8 (-15 -2446 ($ (-638 |#1|))) (-15 -4494 (|#1| $)) (-15 -2232 (|#1| $)) (-15 -2933 (|#1| |#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -2011 (|#1| $)) (-15 -3782 (|#1| $)) (-15 -4080 ($ $)) (-15 -3200 ((-769) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -3058 ($ (-638 |#1|))) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -2211 ($)) (-15 -1607 ($ $)) (-15 -3598 ((-121) $ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (-15 -1564 ((-769) $)) (-15 -2446 ($)) (-15 -1455 ((-769) $)) (-15 -1615 (|#1| $)) (-15 -4579 (|#1| $)) (-15 -3205 (|#1| $)) (-15 -2983 (|#1| $)) (-15 -1488 (|#1| |#1| $)) (-15 -2243 (|#1| |#1| $)) (-15 -3772 (|#1| $)) (-15 -4107 (|#1| |#1| $)) (-15 -2985 ($ $)) (-15 -1312 (|#1| $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3630 (($ (-312 |#1|)) 23)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1804 (((-121) $) NIL)) (-3376 (((-3 (-312 |#1|) "failed") $) NIL)) (-1318 (((-312 |#1|) $) NIL)) (-4383 (($ $) 31)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-3828 (($ (-1 (-312 |#1|) (-312 |#1|)) $) NIL)) (-4373 (((-312 |#1|) $) NIL)) (-2021 (($ $) 30)) (-1658 (((-1152) $) NIL)) (-3792 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-2307 (($ (-769)) NIL)) (-2165 (($ $) 32)) (-4316 (((-572) $) NIL)) (-3972 (((-856) $) 57) (($ (-572)) NIL) (($ (-312 |#1|)) NIL)) (-1958 (((-312 |#1|) $ $) NIL)) (-2140 (((-769)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 25 T CONST)) (-3255 (($) 50 T CONST)) (-1324 (((-121) $ $) 28)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 19)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 24) (($ (-312 |#1|) $) 18))) 
-(((-215 |#1| |#2|) (-13 (-616 (-312 |#1|)) (-1044 (-312 |#1|)) (-10 -8 (-15 -4373 ((-312 |#1|) $)) (-15 -2021 ($ $)) (-15 -4383 ($ $)) (-15 -1958 ((-312 |#1|) $ $)) (-15 -2307 ($ (-769))) (-15 -3792 ((-121) $)) (-15 -1804 ((-121) $)) (-15 -4316 ((-572) $)) (-15 -3828 ($ (-1 (-312 |#1|) (-312 |#1|)) $)) (-15 -3630 ($ (-312 |#1|))) (-15 -2165 ($ $)))) (-13 (-1054) (-848)) (-638 (-1170))) (T -215)) 
-((-4373 (*1 *2 *1) (-12 (-5 *2 (-312 *3)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) (-2021 (*1 *1 *1) (-12 (-5 *1 (-215 *2 *3)) (-4 *2 (-13 (-1054) (-848))) (-14 *3 (-638 (-1170))))) (-4383 (*1 *1 *1) (-12 (-5 *1 (-215 *2 *3)) (-4 *2 (-13 (-1054) (-848))) (-14 *3 (-638 (-1170))))) (-1958 (*1 *2 *1 *1) (-12 (-5 *2 (-312 *3)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) (-2307 (*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) (-3792 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) (-1804 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) (-4316 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-312 *3) (-312 *3))) (-4 *3 (-13 (-1054) (-848))) (-5 *1 (-215 *3 *4)) (-14 *4 (-638 (-1170))))) (-3630 (*1 *1 *2) (-12 (-5 *2 (-312 *3)) (-4 *3 (-13 (-1054) (-848))) (-5 *1 (-215 *3 *4)) (-14 *4 (-638 (-1170))))) (-2165 (*1 *1 *1) (-12 (-5 *1 (-215 *2 *3)) (-4 *2 (-13 (-1054) (-848))) (-14 *3 (-638 (-1170)))))) 
-(-13 (-616 (-312 |#1|)) (-1044 (-312 |#1|)) (-10 -8 (-15 -4373 ((-312 |#1|) $)) (-15 -2021 ($ $)) (-15 -4383 ($ $)) (-15 -1958 ((-312 |#1|) $ $)) (-15 -2307 ($ (-769))) (-15 -3792 ((-121) $)) (-15 -1804 ((-121) $)) (-15 -4316 ((-572) $)) (-15 -3828 ($ (-1 (-312 |#1|) (-312 |#1|)) $)) (-15 -3630 ($ (-312 |#1|))) (-15 -2165 ($ $)))) 
-((-2967 (((-121) (-1152)) 22)) (-2083 (((-3 (-841 |#2|) "failed") (-611 |#2|) |#2| (-841 |#2|) (-841 |#2|) (-121)) 32)) (-3525 (((-3 (-121) "failed") (-1166 |#2|) (-841 |#2|) (-841 |#2|) (-121)) 73) (((-3 (-121) "failed") (-959 |#1|) (-1170) (-841 |#2|) (-841 |#2|) (-121)) 74))) 
-(((-216 |#1| |#2|) (-10 -7 (-15 -2967 ((-121) (-1152))) (-15 -2083 ((-3 (-841 |#2|) "failed") (-611 |#2|) |#2| (-841 |#2|) (-841 |#2|) (-121))) (-15 -3525 ((-3 (-121) "failed") (-959 |#1|) (-1170) (-841 |#2|) (-841 |#2|) (-121))) (-15 -3525 ((-3 (-121) "failed") (-1166 |#2|) (-841 |#2|) (-841 |#2|) (-121)))) (-13 (-457) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-1190) (-29 |#1|))) (T -216)) 
-((-3525 (*1 *2 *3 *4 *4 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-1166 *6)) (-5 *4 (-841 *6)) (-4 *6 (-13 (-1190) (-29 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-216 *5 *6)))) (-3525 (*1 *2 *3 *4 *5 *5 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-959 *6)) (-5 *4 (-1170)) (-5 *5 (-841 *7)) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-4 *7 (-13 (-1190) (-29 *6))) (-5 *1 (-216 *6 *7)))) (-2083 (*1 *2 *3 *4 *2 *2 *5) (|partial| -12 (-5 *2 (-841 *4)) (-5 *3 (-611 *4)) (-5 *5 (-121)) (-4 *4 (-13 (-1190) (-29 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-216 *6 *4)))) (-2967 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-121)) (-5 *1 (-216 *4 *5)) (-4 *5 (-13 (-1190) (-29 *4)))))) 
-(-10 -7 (-15 -2967 ((-121) (-1152))) (-15 -2083 ((-3 (-841 |#2|) "failed") (-611 |#2|) |#2| (-841 |#2|) (-841 |#2|) (-121))) (-15 -3525 ((-3 (-121) "failed") (-959 |#1|) (-1170) (-841 |#2|) (-841 |#2|) (-121))) (-15 -3525 ((-3 (-121) "failed") (-1166 |#2|) (-841 |#2|) (-841 |#2|) (-121)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 95)) (-2551 (((-572) $) 124)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2525 (($ $) NIL)) (-4284 (($ $) 83)) (-4224 (($ $) 71)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4190 (($ $) 62)) (-3112 (((-121) $ $) NIL)) (-4273 (($ $) 81)) (-4217 (($ $) 69)) (-2433 (((-572) $) 137)) (-4295 (($ $) 86)) (-4233 (($ $) 73)) (-2211 (($) NIL T CONST)) (-3599 (($ $) NIL)) (-3376 (((-3 (-572) "failed") $) 120) (((-3 (-413 (-572)) "failed") $) 135)) (-1318 (((-572) $) 136) (((-413 (-572)) $) 133)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) 98)) (-4428 (((-413 (-572)) $ (-769)) 131) (((-413 (-572)) $ (-769) (-769)) 130)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1539 (((-923)) 34) (((-923) (-923)) NIL (|has| $ (-6 -4593)))) (-1908 (((-121) $) NIL)) (-1459 (($ $ $) 123)) (-4184 (($) 44)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL)) (-3377 (((-572) $) 40)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL)) (-4429 (($ $) NIL)) (-4472 (((-121) $) 94)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) 59) (($) 39 (-12 (-2959 (|has| $ (-6 -4585))) (-2959 (|has| $ (-6 -4593)))))) (-4238 (($ $ $) 58) (($) 38 (-12 (-2959 (|has| $ (-6 -4585))) (-2959 (|has| $ (-6 -4593)))))) (-3917 (((-572) $) 32)) (-2179 (((-413 (-572)) $) 27)) (-2504 (($ $) 35)) (-4082 (($ $) 63)) (-3539 (($ $) 68)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-3502 (((-638 (-572)) $) 29)) (-3794 (((-923) (-572)) NIL (|has| $ (-6 -4593)))) (-2607 (((-1116) $) NIL) (((-572) $) 96)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL)) (-1716 (($ $) NIL)) (-3997 (($ (-572) (-572)) NIL) (($ (-572) (-572) (-923)) 125)) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3751 (((-572) $) 33)) (-2557 (($) 43)) (-4179 (($ $) 67)) (-4029 (((-769) $) NIL)) (-3564 (((-1152) (-1152)) 8)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-4465 (((-923)) NIL) (((-923) (-923)) NIL (|has| $ (-6 -4593)))) (-2350 (($ $) 116)) (-3139 (($ $ (-769)) NIL) (($ $) 99)) (-1506 (((-923) (-572)) NIL (|has| $ (-6 -4593)))) (-4302 (($ $) 84)) (-4237 (($ $) 74)) (-4289 (($ $) 85)) (-4228 (($ $) 72)) (-4278 (($ $) 82)) (-4220 (($ $) 70)) (-4081 (((-385) $) 129) (((-217) $) 126) (((-893 (-385)) $) NIL) (((-545) $) 51)) (-3972 (((-856) $) 48) (($ (-572)) 66) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-572)) 66) (($ (-413 (-572))) NIL)) (-2140 (((-769)) NIL)) (-2634 (($ $) NIL)) (-1813 (((-923)) 37) (((-923) (-923)) NIL (|has| $ (-6 -4593)))) (-3045 (($ $ $) 112)) (-2625 (($ $ $) 110)) (-2312 (($ $ $) 108)) (-2638 (($ $ $) 106)) (-4393 (((-923)) 31)) (-4321 (($ $) 89)) (-4251 (($ $) 77) (($ $ $) 132)) (-3774 (((-121) $ $) NIL)) (-4308 (($ $) 87)) (-4241 (($ $) 75)) (-4333 (($ $) 92)) (-4263 (($ $) 80)) (-3804 (($ $) 104)) (-1465 (($ $) 102)) (-2104 (($ $) 90)) (-4268 (($ $) 78)) (-4327 (($ $) 91)) (-4257 (($ $) 79)) (-4314 (($ $) 88)) (-4246 (($ $) 76)) (-2264 (($ $) 138)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 41 T CONST)) (-3255 (($) 42 T CONST)) (-3594 (((-1152) $) 19) (((-1152) $ (-121)) 21) (((-1264) (-823) $) 22) (((-1264) (-823) $ (-121)) 23)) (-1877 (($ $) 118) (($ $ $) NIL)) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1869 (($ $ $) 114)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 60)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 52)) (-1379 (($ $ $) 93) (($ $ (-572)) 61)) (-1373 (($ $) 53) (($ $ $) 55)) (-1367 (($ $ $) 54)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 64) (($ $ (-413 (-572))) 148) (($ $ $) 65)) (* (($ (-923) $) 36) (($ (-769) $) NIL) (($ (-572) $) 57) (($ $ $) 56) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL))) 
-(((-217) (-13 (-410) (-227) (-829) (-1190) (-1132) (-613 (-545)) (-10 -8 (-15 -1379 ($ $ (-572))) (-15 ** ($ $ $)) (-15 -2557 ($)) (-15 -2607 ((-572) $)) (-15 -2504 ($ $)) (-15 -4082 ($ $)) (-15 -4251 ($ $ $)) (-15 -1877 ($ $)) (-15 -1869 ($ $ $)) (-15 -3564 ((-1152) (-1152))) (-15 -4428 ((-413 (-572)) $ (-769))) (-15 -4428 ((-413 (-572)) $ (-769) (-769))) (-15 -2179 ((-413 (-572)) $)) (-15 -3502 ((-638 (-572)) $))))) (T -217)) 
-((** (*1 *1 *1 *1) (-5 *1 (-217))) (-1877 (*1 *1 *1) (-5 *1 (-217))) (-1869 (*1 *1 *1 *1) (-5 *1 (-217))) (-1379 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-217)))) (-2557 (*1 *1) (-5 *1 (-217))) (-2607 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-217)))) (-2504 (*1 *1 *1) (-5 *1 (-217))) (-4082 (*1 *1 *1) (-5 *1 (-217))) (-4251 (*1 *1 *1 *1) (-5 *1 (-217))) (-3564 (*1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-217)))) (-4428 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-413 (-572))) (-5 *1 (-217)))) (-4428 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-413 (-572))) (-5 *1 (-217)))) (-2179 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-217)))) (-3502 (*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-217))))) 
-(-13 (-410) (-227) (-829) (-1190) (-1132) (-613 (-545)) (-10 -8 (-15 -1379 ($ $ (-572))) (-15 ** ($ $ $)) (-15 -2557 ($)) (-15 -2607 ((-572) $)) (-15 -2504 ($ $)) (-15 -4082 ($ $)) (-15 -4251 ($ $ $)) (-15 -1877 ($ $)) (-15 -1869 ($ $ $)) (-15 -3564 ((-1152) (-1152))) (-15 -4428 ((-413 (-572)) $ (-769))) (-15 -4428 ((-413 (-572)) $ (-769) (-769))) (-15 -2179 ((-413 (-572)) $)) (-15 -3502 ((-638 (-572)) $)))) 
-((-2262 (((-121) $ $) NIL (|has| (-217) (-1098)))) (-4169 (($ (-769) (-769)) NIL)) (-2113 (($ $ $) NIL)) (-1444 (($ (-220)) NIL) (($ $) NIL)) (-3083 (((-121) $) NIL)) (-3861 (($ $ (-572) (-572)) NIL)) (-3595 (($ $ (-572) (-572)) NIL)) (-4152 (($ $ (-572) (-572) (-572) (-572)) NIL)) (-4369 (($ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2569 (($ $ (-572) (-572) $) NIL)) (-3283 (((-217) $ (-572) (-572) (-217)) NIL) (($ $ (-638 (-572)) (-638 (-572)) $) NIL)) (-1823 (($ $ (-572) (-220)) NIL)) (-1695 (($ $ (-572) (-220)) NIL)) (-1468 (($ (-769) (-217)) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) NIL (|has| (-217) (-303)))) (-4267 (((-220) $ (-572)) NIL)) (-2667 (((-769) $) NIL (|has| (-217) (-562)))) (-3037 (((-217) $ (-572) (-572) (-217)) 16)) (-3596 (($ (-572) (-572)) 18)) (-4212 (((-217) $ (-572) (-572)) 15)) (-4439 (((-217) $) NIL (|has| (-217) (-174)))) (-2010 (((-638 (-217)) $) NIL)) (-3095 (((-769) $) NIL (|has| (-217) (-562)))) (-1301 (((-638 (-220)) $) NIL (|has| (-217) (-562)))) (-3704 (((-769) $) 10)) (-1364 (($ (-769) (-769) (-217)) 19)) (-3712 (((-769) $) 11)) (-2157 (((-121) $ (-769)) NIL)) (-1522 (((-217) $) NIL (|has| (-217) (-6 (-4604 "*"))))) (-2660 (((-572) $) 7)) (-3092 (((-572) $) 8)) (-4467 (((-638 (-217)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-217) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-217) (-1098))))) (-3927 (((-572) $) 12)) (-3227 (((-572) $) 13)) (-3597 (($ (-638 (-638 (-217)))) NIL) (($ (-769) (-769) (-1 (-217) (-572) (-572))) NIL)) (-2435 (($ (-1 (-217) (-217)) $) NIL)) (-3828 (($ (-1 (-217) (-217)) $) NIL) (($ (-1 (-217) (-217) (-217)) $ $) NIL) (($ (-1 (-217) (-217) (-217)) $ $ (-217)) NIL)) (-2259 (((-638 (-638 (-217))) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| (-217) (-1098)))) (-3750 (((-3 $ "failed") $) NIL (|has| (-217) (-368)))) (-1865 (($ $ $) NIL)) (-2607 (((-1116) $) NIL (|has| (-217) (-1098)))) (-3299 (($ $ (-217)) NIL)) (-1803 (((-3 $ "failed") $ (-217)) NIL (|has| (-217) (-562)))) (-2109 (((-121) (-1 (-121) (-217)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-217)))) NIL (-12 (|has| (-217) (-305 (-217))) (|has| (-217) (-1098)))) (($ $ (-290 (-217))) NIL (-12 (|has| (-217) (-305 (-217))) (|has| (-217) (-1098)))) (($ $ (-217) (-217)) NIL (-12 (|has| (-217) (-305 (-217))) (|has| (-217) (-1098)))) (($ $ (-638 (-217)) (-638 (-217))) NIL (-12 (|has| (-217) (-305 (-217))) (|has| (-217) (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 17)) (-3277 (((-217) $ (-572) (-572)) NIL) (((-217) $ (-572) (-572) (-217)) NIL) (($ $ (-638 (-572)) (-638 (-572))) NIL)) (-3132 (($ (-638 (-217))) NIL) (($ (-638 $)) NIL)) (-3785 (((-121) $) NIL)) (-2271 (((-217) $) NIL (|has| (-217) (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) (-217)) $) NIL (|has| $ (-6 -4602))) (((-769) (-217) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-217) (-1098))))) (-1607 (($ $) NIL)) (-1802 (((-638 (-220)) $) NIL (|has| (-217) (-303)))) (-4580 (((-220) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| (-217) (-1098))) (($ (-220)) NIL)) (-3501 (((-121) (-1 (-121) (-217)) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL (|has| (-217) (-1098)))) (-1379 (($ $ (-217)) NIL (|has| (-217) (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-217) (-368)))) (* (($ $ $) NIL) (($ (-217) $) NIL) (($ $ (-217)) NIL) (($ (-572) $) NIL) (((-220) $ (-220)) NIL) (((-220) (-220) $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-218) (-13 (-683 (-217) (-220) (-220)) (-10 -8 (-15 -3596 ($ (-572) (-572)))))) (T -218)) 
-((-3596 (*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-218))))) 
-(-13 (-683 (-217) (-220) (-220)) (-10 -8 (-15 -3596 ($ (-572) (-572))))) 
-((-1459 (((-171 (-217)) (-769) (-171 (-217))) 61) (((-217) (-769) (-217)) 62)) (-2187 (((-171 (-217)) (-171 (-217))) 63) (((-217) (-217)) 64)) (-4516 (((-171 (-217)) (-171 (-217)) (-171 (-217))) 69) (((-217) (-217) (-217)) 72)) (-2650 (((-385) (-385)) 60)) (-1327 (((-385) (-385)) 59)) (-2350 (((-171 (-217)) (-171 (-217))) 74) (((-217) (-217)) 73)) (-3045 (((-171 (-217)) (-171 (-217)) (-171 (-217))) 91) (((-217) (-217) (-217)) 83)) (-2625 (((-171 (-217)) (-171 (-217)) (-171 (-217))) 94) (((-217) (-217) (-217)) 92)) (-2312 (((-171 (-217)) (-171 (-217)) (-171 (-217))) 65) (((-217) (-217) (-217)) 66)) (-2638 (((-171 (-217)) (-171 (-217)) (-171 (-217))) 67) (((-217) (-217) (-217)) 68)) (-3804 (((-171 (-217)) (-171 (-217))) 105) (((-217) (-217)) 104)) (-1465 (((-217) (-217)) 99) (((-171 (-217)) (-171 (-217))) 103)) (-1877 (((-171 (-217)) (-171 (-217))) 7) (((-217) (-217)) 9)) (-3515 (((-834 (-217)) (-572) (-217)) 23)) (-1477 (((-834 (-217)) (-834 (-217))) 36)) (-3010 (((-834 (-217)) (-834 (-217))) 35)) (-2180 (((-834 (-217)) (-834 (-217))) 34)) (-2099 (((-834 (-217)) (-834 (-217))) 33)) (-2074 (((-834 (-217)) (-834 (-217))) 32)) (-4085 (((-834 (-217)) (-834 (-217))) 31)) (-1622 (((-834 (-217)) (-834 (-217))) 37)) (-3670 (((-834 (-217)) (-217)) 22)) (-1869 (((-171 (-217)) (-171 (-217)) (-171 (-217))) 79) (((-217) (-217) (-217)) 75))) 
-(((-219) (-10 -7 (-15 -1877 ((-217) (-217))) (-15 -1877 ((-171 (-217)) (-171 (-217)))) (-15 -3670 ((-834 (-217)) (-217))) (-15 -3515 ((-834 (-217)) (-572) (-217))) (-15 -1622 ((-834 (-217)) (-834 (-217)))) (-15 -4085 ((-834 (-217)) (-834 (-217)))) (-15 -2074 ((-834 (-217)) (-834 (-217)))) (-15 -2099 ((-834 (-217)) (-834 (-217)))) (-15 -2180 ((-834 (-217)) (-834 (-217)))) (-15 -3010 ((-834 (-217)) (-834 (-217)))) (-15 -1477 ((-834 (-217)) (-834 (-217)))) (-15 -1869 ((-217) (-217) (-217))) (-15 -1869 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -2187 ((-217) (-217))) (-15 -2187 ((-171 (-217)) (-171 (-217)))) (-15 -2350 ((-217) (-217))) (-15 -2350 ((-171 (-217)) (-171 (-217)))) (-15 -1459 ((-217) (-769) (-217))) (-15 -1459 ((-171 (-217)) (-769) (-171 (-217)))) (-15 -2312 ((-217) (-217) (-217))) (-15 -2312 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -3045 ((-217) (-217) (-217))) (-15 -3045 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -2638 ((-217) (-217) (-217))) (-15 -2638 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -2625 ((-217) (-217) (-217))) (-15 -2625 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -1465 ((-171 (-217)) (-171 (-217)))) (-15 -1465 ((-217) (-217))) (-15 -3804 ((-217) (-217))) (-15 -3804 ((-171 (-217)) (-171 (-217)))) (-15 -4516 ((-217) (-217) (-217))) (-15 -4516 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -2650 ((-385) (-385))) (-15 -1327 ((-385) (-385))))) (T -219)) 
-((-1327 (*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-219)))) (-2650 (*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-219)))) (-4516 (*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-4516 (*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-3804 (*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-3804 (*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-1465 (*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-1465 (*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-2625 (*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-2625 (*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-2638 (*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-2638 (*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-3045 (*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-3045 (*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-2312 (*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-2312 (*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-1459 (*1 *2 *3 *2) (-12 (-5 *2 (-171 (-217))) (-5 *3 (-769)) (-5 *1 (-219)))) (-1459 (*1 *2 *3 *2) (-12 (-5 *2 (-217)) (-5 *3 (-769)) (-5 *1 (-219)))) (-2350 (*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-2350 (*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-2187 (*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-2187 (*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-1869 (*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-1869 (*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) (-1477 (*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)))) (-3010 (*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)))) (-2180 (*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)))) (-2099 (*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)))) (-2074 (*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)))) (-4085 (*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)))) (-1622 (*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)))) (-3515 (*1 *2 *3 *4) (-12 (-5 *3 (-572)) (-5 *2 (-834 (-217))) (-5 *1 (-219)) (-5 *4 (-217)))) (-3670 (*1 *2 *3) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)) (-5 *3 (-217)))) (-1877 (*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) (-1877 (*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219))))) 
-(-10 -7 (-15 -1877 ((-217) (-217))) (-15 -1877 ((-171 (-217)) (-171 (-217)))) (-15 -3670 ((-834 (-217)) (-217))) (-15 -3515 ((-834 (-217)) (-572) (-217))) (-15 -1622 ((-834 (-217)) (-834 (-217)))) (-15 -4085 ((-834 (-217)) (-834 (-217)))) (-15 -2074 ((-834 (-217)) (-834 (-217)))) (-15 -2099 ((-834 (-217)) (-834 (-217)))) (-15 -2180 ((-834 (-217)) (-834 (-217)))) (-15 -3010 ((-834 (-217)) (-834 (-217)))) (-15 -1477 ((-834 (-217)) (-834 (-217)))) (-15 -1869 ((-217) (-217) (-217))) (-15 -1869 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -2187 ((-217) (-217))) (-15 -2187 ((-171 (-217)) (-171 (-217)))) (-15 -2350 ((-217) (-217))) (-15 -2350 ((-171 (-217)) (-171 (-217)))) (-15 -1459 ((-217) (-769) (-217))) (-15 -1459 ((-171 (-217)) (-769) (-171 (-217)))) (-15 -2312 ((-217) (-217) (-217))) (-15 -2312 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -3045 ((-217) (-217) (-217))) (-15 -3045 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -2638 ((-217) (-217) (-217))) (-15 -2638 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -2625 ((-217) (-217) (-217))) (-15 -2625 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -1465 ((-171 (-217)) (-171 (-217)))) (-15 -1465 ((-217) (-217))) (-15 -3804 ((-217) (-217))) (-15 -3804 ((-171 (-217)) (-171 (-217)))) (-15 -4516 ((-217) (-217) (-217))) (-15 -4516 ((-171 (-217)) (-171 (-217)) (-171 (-217)))) (-15 -2650 ((-385) (-385))) (-15 -1327 ((-385) (-385)))) 
-((-2262 (((-121) $ $) NIL (|has| (-217) (-1098)))) (-4169 (($ (-769)) NIL (|has| (-217) (-23)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) (-217) (-217)) $) NIL) (((-121) $) NIL (|has| (-217) (-848)))) (-4131 (($ (-1 (-121) (-217) (-217)) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-217) (-848))))) (-3008 (($ (-1 (-121) (-217) (-217)) $) NIL) (($ $) NIL (|has| (-217) (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-217) $ (-572) (-217)) 17 (|has| $ (-6 -4603))) (((-217) $ (-1225 (-572)) (-217)) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-217)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-217) (-1098))))) (-3445 (($ (-217) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-217) (-1098)))) (($ (-1 (-121) (-217)) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-217) (-1 (-217) (-217) (-217)) $ (-217) (-217)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-217) (-1098)))) (((-217) (-1 (-217) (-217) (-217)) $ (-217)) NIL (|has| $ (-6 -4602))) (((-217) (-1 (-217) (-217) (-217)) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-217) $ (-572) (-217)) 9 (|has| $ (-6 -4603)))) (-3596 (($ (-572)) 14)) (-4212 (((-217) $ (-572)) 8)) (-4014 (((-572) (-1 (-121) (-217)) $) NIL) (((-572) (-217) $) NIL (|has| (-217) (-1098))) (((-572) (-217) $ (-572)) NIL (|has| (-217) (-1098)))) (-2010 (((-638 (-217)) $) NIL (|has| $ (-6 -4602)))) (-3349 (((-685 (-217)) $ $) NIL (|has| (-217) (-1054)))) (-1364 (($ (-769) (-217)) 15)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 12 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| (-217) (-848)))) (-4475 (($ (-1 (-121) (-217) (-217)) $ $) NIL) (($ $ $) NIL (|has| (-217) (-848)))) (-4467 (((-638 (-217)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-217) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-217) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-217) (-848)))) (-2435 (($ (-1 (-217) (-217)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-217) (-217)) $) NIL) (($ (-1 (-217) (-217) (-217)) $ $) NIL)) (-3169 (((-217) $) NIL (-12 (|has| (-217) (-1009)) (|has| (-217) (-1054))))) (-3524 (((-121) $ (-769)) NIL)) (-3200 (((-217) $) NIL (-12 (|has| (-217) (-1009)) (|has| (-217) (-1054))))) (-1658 (((-1152) $) NIL (|has| (-217) (-1098)))) (-2603 (($ (-217) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| (-217) (-1098)))) (-1837 (((-217) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-217) "failed") (-1 (-121) (-217)) $) NIL)) (-3299 (($ $ (-217)) 18 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-217)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-217)))) NIL (-12 (|has| (-217) (-305 (-217))) (|has| (-217) (-1098)))) (($ $ (-290 (-217))) NIL (-12 (|has| (-217) (-305 (-217))) (|has| (-217) (-1098)))) (($ $ (-217) (-217)) NIL (-12 (|has| (-217) (-305 (-217))) (|has| (-217) (-1098)))) (($ $ (-638 (-217)) (-638 (-217))) NIL (-12 (|has| (-217) (-305 (-217))) (|has| (-217) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-217) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-217) (-1098))))) (-2957 (((-638 (-217)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 13)) (-3277 (((-217) $ (-572) (-217)) NIL) (((-217) $ (-572)) 16) (($ $ (-1225 (-572))) NIL)) (-1436 (((-217) $ $) NIL (|has| (-217) (-1054)))) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-3780 (($ $ $) NIL (|has| (-217) (-1054)))) (-1571 (((-769) (-1 (-121) (-217)) $) NIL (|has| $ (-6 -4602))) (((-769) (-217) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-217) (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-217) (-613 (-545))))) (-3921 (($ (-638 (-217))) NIL)) (-4500 (($ $ (-217)) NIL) (($ (-217) $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| (-217) (-1098)))) (-3501 (((-121) (-1 (-121) (-217)) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| (-217) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-217) (-848)))) (-1324 (((-121) $ $) NIL (|has| (-217) (-1098)))) (-1343 (((-121) $ $) NIL (|has| (-217) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-217) (-848)))) (-1373 (($ $) NIL (|has| (-217) (-21))) (($ $ $) NIL (|has| (-217) (-21)))) (-1367 (($ $ $) NIL (|has| (-217) (-25)))) (* (($ (-572) $) NIL (|has| (-217) (-21))) (($ (-217) $) NIL (|has| (-217) (-722))) (($ $ (-217)) NIL (|has| (-217) (-722)))) (-4032 (((-769) $) 11 (|has| $ (-6 -4602))))) 
-(((-220) (-13 (-1257 (-217)) (-10 -8 (-15 -3596 ($ (-572)))))) (T -220)) 
-((-3596 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-220))))) 
-(-13 (-1257 (-217)) (-10 -8 (-15 -3596 ($ (-572))))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4169 (($ (-769) (-769)) NIL)) (-2113 (($ $ $) NIL)) (-1444 (($ (-1259 |#1|)) NIL) (($ $) NIL)) (-2953 (($ |#1| |#1| |#1|) 32)) (-3083 (((-121) $) NIL)) (-3861 (($ $ (-572) (-572)) NIL)) (-3595 (($ $ (-572) (-572)) NIL)) (-4152 (($ $ (-572) (-572) (-572) (-572)) NIL)) (-4369 (($ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2569 (($ $ (-572) (-572) $) NIL)) (-3283 ((|#1| $ (-572) (-572) |#1|) NIL) (($ $ (-638 (-572)) (-638 (-572)) $) NIL)) (-1823 (($ $ (-572) (-1259 |#1|)) NIL)) (-1695 (($ $ (-572) (-1259 |#1|)) NIL)) (-1355 (($ |#1| |#1| |#1|) 31)) (-1468 (($ (-769) |#1|) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) NIL (|has| |#1| (-303)))) (-4267 (((-1259 |#1|) $ (-572)) NIL)) (-2197 (($ |#1|) 30)) (-1782 (($ |#1|) 29)) (-1351 (($ |#1|) 28)) (-2667 (((-769) $) NIL (|has| |#1| (-562)))) (-3037 ((|#1| $ (-572) (-572) |#1|) NIL)) (-4212 ((|#1| $ (-572) (-572)) NIL)) (-4439 ((|#1| $) NIL (|has| |#1| (-174)))) (-2010 (((-638 |#1|) $) NIL)) (-3095 (((-769) $) NIL (|has| |#1| (-562)))) (-1301 (((-638 (-1259 |#1|)) $) NIL (|has| |#1| (-562)))) (-3704 (((-769) $) NIL)) (-1364 (($ (-769) (-769) |#1|) NIL)) (-3712 (((-769) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-1522 ((|#1| $) NIL (|has| |#1| (-6 (-4604 "*"))))) (-2660 (((-572) $) NIL)) (-3092 (((-572) $) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3927 (((-572) $) NIL)) (-3227 (((-572) $) NIL)) (-3597 (($ (-638 (-638 |#1|))) 10) (($ (-769) (-769) (-1 |#1| (-572) (-572))) NIL)) (-2435 (($ (-1 |#1| |#1|) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2259 (((-638 (-638 |#1|)) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-3750 (((-3 $ "failed") $) NIL (|has| |#1| (-368)))) (-3745 (($) 11)) (-1865 (($ $ $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3299 (($ $ |#1|) NIL)) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) (-572)) NIL) ((|#1| $ (-572) (-572) |#1|) NIL) (($ $ (-638 (-572)) (-638 (-572))) NIL)) (-3132 (($ (-638 |#1|)) NIL) (($ (-638 $)) NIL)) (-3785 (((-121) $) NIL)) (-2271 ((|#1| $) NIL (|has| |#1| (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-1802 (((-638 (-1259 |#1|)) $) NIL (|has| |#1| (-303)))) (-4580 (((-1259 |#1|) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098))) (($ (-1259 |#1|)) NIL)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-572) $) NIL) (((-1259 |#1|) $ (-1259 |#1|)) 14) (((-1259 |#1|) (-1259 |#1|) $) NIL) (((-950 |#1|) $ (-950 |#1|)) 20)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-221 |#1|) (-13 (-683 |#1| (-1259 |#1|) (-1259 |#1|)) (-10 -8 (-15 * ((-950 |#1|) $ (-950 |#1|))) (-15 -3745 ($)) (-15 -1351 ($ |#1|)) (-15 -1782 ($ |#1|)) (-15 -2197 ($ |#1|)) (-15 -1355 ($ |#1| |#1| |#1|)) (-15 -2953 ($ |#1| |#1| |#1|)))) (-13 (-368) (-1190))) (T -221)) 
-((* (*1 *2 *1 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190))) (-5 *1 (-221 *3)))) (-3745 (*1 *1) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190))))) (-1351 (*1 *1 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190))))) (-1782 (*1 *1 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190))))) (-2197 (*1 *1 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190))))) (-1355 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190))))) (-2953 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190)))))) 
-(-13 (-683 |#1| (-1259 |#1|) (-1259 |#1|)) (-10 -8 (-15 * ((-950 |#1|) $ (-950 |#1|))) (-15 -3745 ($)) (-15 -1351 ($ |#1|)) (-15 -1782 ($ |#1|)) (-15 -2197 ($ |#1|)) (-15 -1355 ($ |#1| |#1| |#1|)) (-15 -2953 ($ |#1| |#1| |#1|)))) 
-((-1550 (($ (-1 (-121) |#2|) $) 17)) (-1544 (($ |#2| $) NIL) (($ (-1 (-121) |#2|) $) 25)) (-1535 (($) NIL) (($ (-638 |#2|)) 11)) (-1324 (((-121) $ $) 23))) 
-(((-222 |#1| |#2|) (-10 -8 (-15 -1550 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1544 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1544 (|#1| |#2| |#1|)) (-15 -1535 (|#1| (-638 |#2|))) (-15 -1535 (|#1|)) (-15 -1324 ((-121) |#1| |#1|))) (-223 |#2|) (-1098)) (T -222)) 
-NIL 
-(-10 -8 (-15 -1550 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1544 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1544 (|#1| |#2| |#1|)) (-15 -1535 (|#1| (-638 |#2|))) (-15 -1535 (|#1|)) (-15 -1324 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-1550 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-1643 (($ $) 55 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ |#1| $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4602)))) (-3445 (($ |#1| $) 54 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4602)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1535 (($) 46) (($ (-638 |#1|)) 45)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 47)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-223 |#1|) (-1290) (-1098)) (T -223)) 
-NIL 
-(-13 (-229 |t#1|)) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-229 |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-3139 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-769)) 11) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) 19) (($ $ (-769)) NIL) (($ $) 16)) (-1557 (($ $ (-1 |#2| |#2|)) 12) (($ $ (-1 |#2| |#2|) (-769)) 14) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL) (($ $ (-769)) NIL) (($ $) NIL))) 
-(((-224 |#1| |#2|) (-10 -8 (-15 -3139 (|#1| |#1|)) (-15 -1557 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -1557 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -1557 (|#1| |#1| (-1170))) (-15 -1557 (|#1| |#1| (-638 (-1170)))) (-15 -1557 (|#1| |#1| (-1170) (-769))) (-15 -1557 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -1557 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -1557 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|)))) (-225 |#2|) (-1054)) (T -224)) 
-NIL 
-(-10 -8 (-15 -3139 (|#1| |#1|)) (-15 -1557 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -1557 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -1557 (|#1| |#1| (-1170))) (-15 -1557 (|#1| |#1| (-638 (-1170)))) (-15 -1557 (|#1| |#1| (-1170) (-769))) (-15 -1557 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -1557 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -1557 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3139 (($ $ (-1 |#1| |#1|)) 51) (($ $ (-1 |#1| |#1|) (-769)) 50) (($ $ (-638 (-1170)) (-638 (-769))) 43 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 42 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 41 (|has| |#1| (-901 (-1170)))) (($ $ (-1170)) 40 (|has| |#1| (-901 (-1170)))) (($ $ (-769)) 38 (|has| |#1| (-227))) (($ $) 36 (|has| |#1| (-227)))) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-1 |#1| |#1|)) 49) (($ $ (-1 |#1| |#1|) (-769)) 48) (($ $ (-638 (-1170)) (-638 (-769))) 47 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 46 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 45 (|has| |#1| (-901 (-1170)))) (($ $ (-1170)) 44 (|has| |#1| (-901 (-1170)))) (($ $ (-769)) 39 (|has| |#1| (-227))) (($ $) 37 (|has| |#1| (-227)))) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-225 |#1|) (-1290) (-1054)) (T -225)) 
-((-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-225 *3)) (-4 *3 (-1054)))) (-3139 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-769)) (-4 *1 (-225 *4)) (-4 *4 (-1054)))) (-1557 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-225 *3)) (-4 *3 (-1054)))) (-1557 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-769)) (-4 *1 (-225 *4)) (-4 *4 (-1054))))) 
-(-13 (-1054) (-10 -8 (-15 -3139 ($ $ (-1 |t#1| |t#1|))) (-15 -3139 ($ $ (-1 |t#1| |t#1|) (-769))) (-15 -1557 ($ $ (-1 |t#1| |t#1|))) (-15 -1557 ($ $ (-1 |t#1| |t#1|) (-769))) (IF (|has| |t#1| (-227)) (-6 (-227)) |noBranch|) (IF (|has| |t#1| (-901 (-1170))) (-6 (-901 (-1170))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-227) |has| |#1| (-227)) ((-641 $) . T) ((-722) . T) ((-901 (-1170)) |has| |#1| (-901 (-1170))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3139 (($ $) NIL) (($ $ (-769)) 10)) (-1557 (($ $) 8) (($ $ (-769)) 12))) 
-(((-226 |#1|) (-10 -8 (-15 -1557 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-769))) (-15 -1557 (|#1| |#1|)) (-15 -3139 (|#1| |#1|))) (-227)) (T -226)) 
-NIL 
-(-10 -8 (-15 -1557 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-769))) (-15 -1557 (|#1| |#1|)) (-15 -3139 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3139 (($ $) 37) (($ $ (-769)) 35)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $) 36) (($ $ (-769)) 34)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-227) (-1290)) (T -227)) 
-((-3139 (*1 *1 *1) (-4 *1 (-227))) (-1557 (*1 *1 *1) (-4 *1 (-227))) (-3139 (*1 *1 *1 *2) (-12 (-4 *1 (-227)) (-5 *2 (-769)))) (-1557 (*1 *1 *1 *2) (-12 (-4 *1 (-227)) (-5 *2 (-769))))) 
-(-13 (-1054) (-10 -8 (-15 -3139 ($ $)) (-15 -1557 ($ $)) (-15 -3139 ($ $ (-769))) (-15 -1557 ($ $ (-769))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-1535 (($) 12) (($ (-638 |#2|)) NIL)) (-1607 (($ $) 14)) (-3921 (($ (-638 |#2|)) 10)) (-3972 (((-856) $) 21))) 
-(((-228 |#1| |#2|) (-10 -8 (-15 -1535 (|#1| (-638 |#2|))) (-15 -1535 (|#1|)) (-15 -3921 (|#1| (-638 |#2|))) (-15 -3972 ((-856) |#1|)) (-15 -1607 (|#1| |#1|))) (-229 |#2|) (-1098)) (T -228)) 
-NIL 
-(-10 -8 (-15 -1535 (|#1| (-638 |#2|))) (-15 -1535 (|#1|)) (-15 -3921 (|#1| (-638 |#2|))) (-15 -3972 ((-856) |#1|)) (-15 -1607 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-1550 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-1643 (($ $) 55 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ |#1| $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4602)))) (-3445 (($ |#1| $) 54 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4602)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1535 (($) 46) (($ (-638 |#1|)) 45)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 47)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-229 |#1|) (-1290) (-1098)) (T -229)) 
-((-1535 (*1 *1) (-12 (-4 *1 (-229 *2)) (-4 *2 (-1098)))) (-1535 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-229 *3)))) (-1544 (*1 *1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-229 *2)) (-4 *2 (-1098)))) (-1544 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4602)) (-4 *1 (-229 *3)) (-4 *3 (-1098)))) (-1550 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4602)) (-4 *1 (-229 *3)) (-4 *3 (-1098))))) 
-(-13 (-111 |t#1|) (-155 |t#1|) (-10 -8 (-15 -1535 ($)) (-15 -1535 ($ (-638 |t#1|))) (IF (|has| $ (-6 -4602)) (PROGN (-15 -1544 ($ |t#1| $)) (-15 -1544 ($ (-1 (-121) |t#1|) $)) (-15 -1550 ($ (-1 (-121) |t#1|) $))) |noBranch|))) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-3452 (((-2 (|:| |varOrder| (-638 (-1170))) (|:| |inhom| (-3 (-638 (-1259 (-769))) "failed")) (|:| |hom| (-638 (-1259 (-769))))) (-290 (-959 (-572)))) 25))) 
-(((-230) (-10 -7 (-15 -3452 ((-2 (|:| |varOrder| (-638 (-1170))) (|:| |inhom| (-3 (-638 (-1259 (-769))) "failed")) (|:| |hom| (-638 (-1259 (-769))))) (-290 (-959 (-572))))))) (T -230)) 
-((-3452 (*1 *2 *3) (-12 (-5 *3 (-290 (-959 (-572)))) (-5 *2 (-2 (|:| |varOrder| (-638 (-1170))) (|:| |inhom| (-3 (-638 (-1259 (-769))) "failed")) (|:| |hom| (-638 (-1259 (-769)))))) (-5 *1 (-230))))) 
-(-10 -7 (-15 -3452 ((-2 (|:| |varOrder| (-638 (-1170))) (|:| |inhom| (-3 (-638 (-1259 (-769))) "failed")) (|:| |hom| (-638 (-1259 (-769))))) (-290 (-959 (-572)))))) 
-((-1685 (((-769)) 51)) (-2284 (((-2 (|:| -1369 (-685 |#3|)) (|:| |vec| (-1259 |#3|))) (-685 $) (-1259 $)) 49) (((-685 |#3|) (-685 $)) 41) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-685 (-572)) (-685 $)) NIL)) (-2502 (((-140)) 57)) (-3139 (($ $ (-1 |#3| |#3|) (-769)) NIL) (($ $ (-1 |#3| |#3|)) 18) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL) (($ $ (-769)) NIL) (($ $) NIL)) (-3972 (((-1259 |#3|) $) NIL) (($ |#3|) NIL) (((-856) $) NIL) (($ (-572)) 12) (($ (-413 (-572))) NIL)) (-2140 (((-769)) 15)) (-1379 (($ $ |#3|) 54))) 
-(((-231 |#1| |#2| |#3|) (-10 -8 (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|)) (-15 -2140 ((-769))) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -3972 (|#1| |#3|)) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|))) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|) (-769))) (-15 -2284 ((-685 |#3|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#3|)) (|:| |vec| (-1259 |#3|))) (-685 |#1|) (-1259 |#1|))) (-15 -1685 ((-769))) (-15 -1379 (|#1| |#1| |#3|)) (-15 -2502 ((-140))) (-15 -3972 ((-1259 |#3|) |#1|))) (-232 |#2| |#3|) (-769) (-1204)) (T -231)) 
-((-2502 (*1 *2) (-12 (-14 *4 (-769)) (-4 *5 (-1204)) (-5 *2 (-140)) (-5 *1 (-231 *3 *4 *5)) (-4 *3 (-232 *4 *5)))) (-1685 (*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1204)) (-5 *2 (-769)) (-5 *1 (-231 *3 *4 *5)) (-4 *3 (-232 *4 *5)))) (-2140 (*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1204)) (-5 *2 (-769)) (-5 *1 (-231 *3 *4 *5)) (-4 *3 (-232 *4 *5))))) 
-(-10 -8 (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|)) (-15 -2140 ((-769))) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -3972 (|#1| |#3|)) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|))) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|) (-769))) (-15 -2284 ((-685 |#3|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#3|)) (|:| |vec| (-1259 |#3|))) (-685 |#1|) (-1259 |#1|))) (-15 -1685 ((-769))) (-15 -1379 (|#1| |#1| |#3|)) (-15 -2502 ((-140))) (-15 -3972 ((-1259 |#3|) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#2| (-1098)))) (-1342 (((-121) $) 67 (|has| |#2| (-138)))) (-3421 (($ (-923)) 123 (|has| |#2| (-1054)))) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-1614 (($ $ $) 119 (|has| |#2| (-794)))) (-1572 (((-3 $ "failed") $ $) 69 (|has| |#2| (-138)))) (-1946 (((-121) $ (-769)) 8)) (-1685 (((-769)) 104 (|has| |#2| (-374)))) (-2433 (((-572) $) 117 (|has| |#2| (-846)))) (-3283 ((|#2| $ (-572) |#2|) 49 (|has| $ (-6 -4603)))) (-2211 (($) 7 T CONST)) (-3376 (((-3 (-572) "failed") $) 62 (-4028 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098)))) (((-3 (-413 (-572)) "failed") $) 59 (-4028 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) (((-3 |#2| "failed") $) 56 (|has| |#2| (-1098)))) (-1318 (((-572) $) 63 (-4028 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098)))) (((-413 (-572)) $) 60 (-4028 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) ((|#2| $) 55 (|has| |#2| (-1098)))) (-2284 (((-685 (-572)) (-685 $)) 103 (-4028 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 102 (-4028 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) 101 (|has| |#2| (-1054))) (((-685 |#2|) (-685 $)) 100 (|has| |#2| (-1054)))) (-1799 (((-3 $ "failed") $) 75 (|has| |#2| (-722)))) (-3286 (($) 107 (|has| |#2| (-374)))) (-3037 ((|#2| $ (-572) |#2|) 50 (|has| $ (-6 -4603)))) (-4212 ((|#2| $ (-572)) 48)) (-1908 (((-121) $) 115 (|has| |#2| (-846)))) (-2010 (((-638 |#2|) $) 30 (|has| $ (-6 -4602)))) (-3893 (((-121) $) 78 (|has| |#2| (-722)))) (-4472 (((-121) $) 116 (|has| |#2| (-846)))) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-1771 (($ $ $) 114 (-1841 (|has| |#2| (-846)) (|has| |#2| (-794))))) (-4467 (((-638 |#2|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#2| $) 27 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-4238 (($ $ $) 113 (-1841 (|has| |#2| (-846)) (|has| |#2| (-794))))) (-2435 (($ (-1 |#2| |#2|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#2| |#2|) $) 35)) (-3633 (((-923) $) 106 (|has| |#2| (-374)))) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#2| (-1098)))) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-1763 (($ (-923)) 105 (|has| |#2| (-374)))) (-2607 (((-1116) $) 21 (|has| |#2| (-1098)))) (-1837 ((|#2| $) 39 (|has| (-572) (-848)))) (-3299 (($ $ |#2|) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#2|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#2|))) 26 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) 25 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) 24 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) 23 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) 14)) (-3587 (((-638 $)) 108 (|has| |#2| (-374)))) (-3167 (((-121) |#2| $) 42 (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#2| $ (-572) |#2|) 47) ((|#2| $ (-572)) 46)) (-1436 ((|#2| $ $) 122 (|has| |#2| (-1054)))) (-4315 (($ (-1259 |#2|)) 124)) (-2502 (((-140)) 121 (|has| |#2| (-368)))) (-3139 (($ $) 95 (-4028 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-769)) 93 (-4028 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-1170)) 91 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170))) 90 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1170) (-769)) 89 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) 88 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1 |#2| |#2|) (-769)) 81 (|has| |#2| (-1054))) (($ $ (-1 |#2| |#2|)) 80 (|has| |#2| (-1054)))) (-1571 (((-769) (-1 (-121) |#2|) $) 31 (|has| $ (-6 -4602))) (((-769) |#2| $) 28 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-1259 |#2|) $) 125) (((-856) $) 20 (|has| |#2| (-1098))) (($ (-572)) 61 (-1841 (-4028 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098))) (|has| |#2| (-1054)))) (($ (-413 (-572))) 58 (-4028 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) (($ |#2|) 57 (|has| |#2| (-1098)))) (-2140 (((-769)) 99 (|has| |#2| (-1054)))) (-3501 (((-121) (-1 (-121) |#2|) $) 33 (|has| $ (-6 -4602)))) (-2264 (($ $) 118 (|has| |#2| (-846)))) (-4174 (($ $ (-769)) 76 (|has| |#2| (-722))) (($ $ (-923)) 72 (|has| |#2| (-722)))) (-2378 (($) 66 (|has| |#2| (-138)) CONST)) (-3255 (($) 79 (|has| |#2| (-722)) CONST)) (-1557 (($ $) 94 (-4028 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-769)) 92 (-4028 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-1170)) 87 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170))) 86 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1170) (-769)) 85 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) 84 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1 |#2| |#2|) (-769)) 83 (|has| |#2| (-1054))) (($ $ (-1 |#2| |#2|)) 82 (|has| |#2| (-1054)))) (-1349 (((-121) $ $) 111 (-1841 (|has| |#2| (-846)) (|has| |#2| (-794))))) (-1338 (((-121) $ $) 110 (-1841 (|has| |#2| (-846)) (|has| |#2| (-794))))) (-1324 (((-121) $ $) 19 (|has| |#2| (-1098)))) (-1343 (((-121) $ $) 112 (-1841 (|has| |#2| (-846)) (|has| |#2| (-794))))) (-1334 (((-121) $ $) 109 (-1841 (|has| |#2| (-846)) (|has| |#2| (-794))))) (-1379 (($ $ |#2|) 120 (|has| |#2| (-368)))) (-1373 (($ $ $) 97 (|has| |#2| (-1054))) (($ $) 96 (|has| |#2| (-1054)))) (-1367 (($ $ $) 64 (|has| |#2| (-25)))) (** (($ $ (-769)) 77 (|has| |#2| (-722))) (($ $ (-923)) 73 (|has| |#2| (-722)))) (* (($ (-572) $) 98 (|has| |#2| (-1054))) (($ $ $) 74 (|has| |#2| (-722))) (($ $ |#2|) 71 (|has| |#2| (-722))) (($ |#2| $) 70 (|has| |#2| (-722))) (($ (-769) $) 68 (|has| |#2| (-138))) (($ (-923) $) 65 (|has| |#2| (-25)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-232 |#1| |#2|) (-1290) (-769) (-1204)) (T -232)) 
-((-4315 (*1 *1 *2) (-12 (-5 *2 (-1259 *4)) (-4 *4 (-1204)) (-4 *1 (-232 *3 *4)))) (-3421 (*1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-232 *3 *4)) (-4 *4 (-1054)) (-4 *4 (-1204)))) (-1436 (*1 *2 *1 *1) (-12 (-4 *1 (-232 *3 *2)) (-4 *2 (-1204)) (-4 *2 (-1054)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-232 *3 *2)) (-4 *2 (-1204)) (-4 *2 (-722)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-232 *3 *2)) (-4 *2 (-1204)) (-4 *2 (-722))))) 
-(-13 (-605 (-572) |t#2|) (-612 (-1259 |t#2|)) (-10 -8 (-6 -4602) (-15 -4315 ($ (-1259 |t#2|))) (IF (|has| |t#2| (-1098)) (-6 (-417 |t#2|)) |noBranch|) (IF (|has| |t#2| (-1054)) (PROGN (-6 (-120 |t#2| |t#2|)) (-6 (-225 |t#2|)) (-6 (-383 |t#2|)) (-15 -3421 ($ (-923))) (-15 -1436 (|t#2| $ $))) |noBranch|) (IF (|has| |t#2| (-25)) (-6 (-25)) |noBranch|) (IF (|has| |t#2| (-138)) (-6 (-138)) |noBranch|) (IF (|has| |t#2| (-722)) (PROGN (-6 (-722)) (-15 * ($ |t#2| $)) (-15 * ($ $ |t#2|))) |noBranch|) (IF (|has| |t#2| (-374)) (-6 (-374)) |noBranch|) (IF (|has| |t#2| (-174)) (PROGN (-6 (-43 |t#2|)) (-6 (-174))) |noBranch|) (IF (|has| |t#2| (-6 -4599)) (-6 -4599) |noBranch|) (IF (|has| |t#2| (-846)) (-6 (-846)) |noBranch|) (IF (|has| |t#2| (-794)) (-6 (-794)) |noBranch|) (IF (|has| |t#2| (-368)) (-6 (-1266 |t#2|)) |noBranch|))) 
-(((-21) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-368)) (|has| |#2| (-174))) ((-23) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-794)) (|has| |#2| (-368)) (|has| |#2| (-174)) (|has| |#2| (-138))) ((-25) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-794)) (|has| |#2| (-368)) (|has| |#2| (-174)) (|has| |#2| (-138)) (|has| |#2| (-25))) ((-39) . T) ((-43 |#2|) |has| |#2| (-174)) ((-105) -1841 (|has| |#2| (-1098)) (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-794)) (|has| |#2| (-722)) (|has| |#2| (-374)) (|has| |#2| (-368)) (|has| |#2| (-174)) (|has| |#2| (-138)) (|has| |#2| (-25))) ((-120 |#2| |#2|) -1841 (|has| |#2| (-1054)) (|has| |#2| (-368)) (|has| |#2| (-174))) ((-120 $ $) |has| |#2| (-174)) ((-138) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-794)) (|has| |#2| (-368)) (|has| |#2| (-174)) (|has| |#2| (-138))) ((-612 (-856)) -1841 (|has| |#2| (-1098)) (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-794)) (|has| |#2| (-722)) (|has| |#2| (-374)) (|has| |#2| (-368)) (|has| |#2| (-174)) (|has| |#2| (-138)) (|has| |#2| (-25))) ((-612 (-1259 |#2|)) . T) ((-174) |has| |#2| (-174)) ((-225 |#2|) |has| |#2| (-1054)) ((-227) -12 (|has| |#2| (-227)) (|has| |#2| (-1054))) ((-283 (-572) |#2|) . T) ((-285 (-572) |#2|) . T) ((-305 |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-374) |has| |#2| (-374)) ((-383 |#2|) |has| |#2| (-1054)) ((-417 |#2|) |has| |#2| (-1098)) ((-503 |#2|) . T) ((-605 (-572) |#2|) . T) ((-527 |#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-641 |#2|) -1841 (|has| |#2| (-1054)) (|has| |#2| (-368)) (|has| |#2| (-174))) ((-641 $) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-174))) ((-634 (-572)) -12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054))) ((-634 |#2|) |has| |#2| (-1054)) ((-713 |#2|) -1841 (|has| |#2| (-368)) (|has| |#2| (-174))) ((-722) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-722)) (|has| |#2| (-174))) ((-792) |has| |#2| (-846)) ((-793) -1841 (|has| |#2| (-846)) (|has| |#2| (-794))) ((-794) |has| |#2| (-794)) ((-795) -1841 (|has| |#2| (-846)) (|has| |#2| (-794))) ((-796) -1841 (|has| |#2| (-846)) (|has| |#2| (-794))) ((-846) |has| |#2| (-846)) ((-848) -1841 (|has| |#2| (-846)) (|has| |#2| (-794))) ((-901 (-1170)) -12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054))) ((-1044 (-413 (-572))) -12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098))) ((-1044 (-572)) -12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098))) ((-1044 |#2|) |has| |#2| (-1098)) ((-1060 |#2|) -1841 (|has| |#2| (-1054)) (|has| |#2| (-368)) (|has| |#2| (-174))) ((-1060 $) |has| |#2| (-174)) ((-1054) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-174))) ((-1061) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-174))) ((-1110) -1841 (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-722)) (|has| |#2| (-174))) ((-1098) -1841 (|has| |#2| (-1098)) (|has| |#2| (-1054)) (|has| |#2| (-846)) (|has| |#2| (-794)) (|has| |#2| (-722)) (|has| |#2| (-374)) (|has| |#2| (-368)) (|has| |#2| (-174)) (|has| |#2| (-138)) (|has| |#2| (-25))) ((-1204) . T) ((-1266 |#2|) |has| |#2| (-368))) 
-((-1911 (((-234 |#1| |#3|) (-1 |#3| |#2| |#3|) (-234 |#1| |#2|) |#3|) 21)) (-3116 ((|#3| (-1 |#3| |#2| |#3|) (-234 |#1| |#2|) |#3|) 23)) (-3828 (((-234 |#1| |#3|) (-1 |#3| |#2|) (-234 |#1| |#2|)) 18))) 
-(((-233 |#1| |#2| |#3|) (-10 -7 (-15 -1911 ((-234 |#1| |#3|) (-1 |#3| |#2| |#3|) (-234 |#1| |#2|) |#3|)) (-15 -3116 (|#3| (-1 |#3| |#2| |#3|) (-234 |#1| |#2|) |#3|)) (-15 -3828 ((-234 |#1| |#3|) (-1 |#3| |#2|) (-234 |#1| |#2|)))) (-769) (-1204) (-1204)) (T -233)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-234 *5 *6)) (-14 *5 (-769)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-5 *2 (-234 *5 *7)) (-5 *1 (-233 *5 *6 *7)))) (-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *6 *2)) (-5 *4 (-234 *5 *6)) (-14 *5 (-769)) (-4 *6 (-1204)) (-4 *2 (-1204)) (-5 *1 (-233 *5 *6 *2)))) (-1911 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *7 *5)) (-5 *4 (-234 *6 *7)) (-14 *6 (-769)) (-4 *7 (-1204)) (-4 *5 (-1204)) (-5 *2 (-234 *6 *5)) (-5 *1 (-233 *6 *7 *5))))) 
-(-10 -7 (-15 -1911 ((-234 |#1| |#3|) (-1 |#3| |#2| |#3|) (-234 |#1| |#2|) |#3|)) (-15 -3116 (|#3| (-1 |#3| |#2| |#3|) (-234 |#1| |#2|) |#3|)) (-15 -3828 ((-234 |#1| |#3|) (-1 |#3| |#2|) (-234 |#1| |#2|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#2| (-1098)))) (-1342 (((-121) $) NIL (|has| |#2| (-138)))) (-3421 (($ (-923)) 56 (|has| |#2| (-1054)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-1614 (($ $ $) 60 (|has| |#2| (-794)))) (-1572 (((-3 $ "failed") $ $) 49 (|has| |#2| (-138)))) (-1946 (((-121) $ (-769)) 17)) (-1685 (((-769)) NIL (|has| |#2| (-374)))) (-2433 (((-572) $) NIL (|has| |#2| (-846)))) (-3283 ((|#2| $ (-572) |#2|) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) (((-3 |#2| "failed") $) 29 (|has| |#2| (-1098)))) (-1318 (((-572) $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098)))) (((-413 (-572)) $) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) ((|#2| $) 27 (|has| |#2| (-1098)))) (-2284 (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL (|has| |#2| (-1054))) (((-685 |#2|) (-685 $)) NIL (|has| |#2| (-1054)))) (-1799 (((-3 $ "failed") $) 53 (|has| |#2| (-722)))) (-3286 (($) NIL (|has| |#2| (-374)))) (-3037 ((|#2| $ (-572) |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ (-572)) 51)) (-1908 (((-121) $) NIL (|has| |#2| (-846)))) (-2010 (((-638 |#2|) $) 15 (|has| $ (-6 -4602)))) (-3893 (((-121) $) NIL (|has| |#2| (-722)))) (-4472 (((-121) $) NIL (|has| |#2| (-846)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 20 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-4467 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 (((-572) $) 50 (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-2435 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#2| |#2|) $) 41)) (-3633 (((-923) $) NIL (|has| |#2| (-374)))) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#2| (-1098)))) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-1763 (($ (-923)) NIL (|has| |#2| (-374)))) (-2607 (((-1116) $) NIL (|has| |#2| (-1098)))) (-1837 ((|#2| $) NIL (|has| (-572) (-848)))) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#2|) $) 24 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3587 (((-638 $)) NIL (|has| |#2| (-374)))) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ (-572) |#2|) NIL) ((|#2| $ (-572)) 21)) (-1436 ((|#2| $ $) NIL (|has| |#2| (-1054)))) (-4315 (($ (-1259 |#2|)) 18)) (-2502 (((-140)) NIL (|has| |#2| (-368)))) (-3139 (($ $) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1 |#2| |#2|) (-769)) NIL (|has| |#2| (-1054))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1054)))) (-1571 (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-1259 |#2|) $) 10) (((-856) $) NIL (|has| |#2| (-1098))) (($ (-572)) NIL (-1841 (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098))) (|has| |#2| (-1054)))) (($ (-413 (-572))) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) (($ |#2|) 13 (|has| |#2| (-1098)))) (-2140 (((-769)) NIL (|has| |#2| (-1054)))) (-3501 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-2264 (($ $) NIL (|has| |#2| (-846)))) (-4174 (($ $ (-769)) NIL (|has| |#2| (-722))) (($ $ (-923)) NIL (|has| |#2| (-722)))) (-2378 (($) 35 (|has| |#2| (-138)) CONST)) (-3255 (($) 38 (|has| |#2| (-722)) CONST)) (-1557 (($ $) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1 |#2| |#2|) (-769)) NIL (|has| |#2| (-1054))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1054)))) (-1349 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1338 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1324 (((-121) $ $) 26 (|has| |#2| (-1098)))) (-1343 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1334 (((-121) $ $) 58 (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $ $) NIL (|has| |#2| (-1054))) (($ $) NIL (|has| |#2| (-1054)))) (-1367 (($ $ $) 33 (|has| |#2| (-25)))) (** (($ $ (-769)) NIL (|has| |#2| (-722))) (($ $ (-923)) NIL (|has| |#2| (-722)))) (* (($ (-572) $) NIL (|has| |#2| (-1054))) (($ $ $) 44 (|has| |#2| (-722))) (($ $ |#2|) 42 (|has| |#2| (-722))) (($ |#2| $) 43 (|has| |#2| (-722))) (($ (-769) $) NIL (|has| |#2| (-138))) (($ (-923) $) NIL (|has| |#2| (-25)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-234 |#1| |#2|) (-232 |#1| |#2|) (-769) (-1204)) (T -234)) 
-NIL 
-(-232 |#1| |#2|) 
-((-2262 (((-121) $ $) NIL)) (-3013 (($) 34 T CONST)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-174)))) (-3946 (($ $) NIL (|has| |#1| (-174)))) (-3686 (((-121) $) 54 (|has| |#1| (-174)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) 55)) (-3893 (((-121) $) NIL)) (-3719 (((-121) $ (-923)) 71)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-174)))) (-3277 ((|#1| $ (-923)) 9)) (-3972 (((-856) $) 29) (($ (-572)) NIL) (($ (-1 |#1| (-923))) 12) (((-1 |#1| (-923)) $) 11) (($ (-1150 |#1|)) 26) (((-1150 |#1|) $) 24) (($ |#1|) NIL (|has| |#1| (-174))) (($ $) NIL (|has| |#1| (-174)))) (-2140 (((-769)) NIL)) (-3774 (((-121) $ $) NIL (|has| |#1| (-174)))) (-2215 (((-121) $ (-923)) 72)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 33 T CONST)) (-3255 (($) 13 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) 38) (($ $ $) NIL)) (-1367 (($ $ $) 36)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 40) (($ $ $) 51) (($ |#1| $) 42 (|has| |#1| (-174))) (($ $ |#1|) NIL (|has| |#1| (-174))))) 
-(((-235 |#1|) (-13 (-1054) (-283 (-923) |#1|) (-10 -8 (IF (|has| |#1| (-174)) (-6 (-562)) |noBranch|) (IF (|has| |#1| (-174)) (-6 (-43 |#1|)) |noBranch|) (-15 -3972 ($ (-1 |#1| (-923)))) (-15 -3972 ((-1 |#1| (-923)) $)) (-15 -3972 ($ (-1150 |#1|))) (-15 -3972 ((-1150 |#1|) $)) (-15 -3013 ($) -3211) (-15 -3719 ((-121) $ (-923))) (-15 -2215 ((-121) $ (-923))))) (-1054)) (T -235)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1 *3 (-923))) (-4 *3 (-1054)) (-5 *1 (-235 *3)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1 *3 (-923))) (-5 *1 (-235 *3)) (-4 *3 (-1054)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-235 *3)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-235 *3)) (-4 *3 (-1054)))) (-3013 (*1 *1) (-12 (-5 *1 (-235 *2)) (-4 *2 (-1054)))) (-3719 (*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-5 *2 (-121)) (-5 *1 (-235 *4)) (-4 *4 (-1054)))) (-2215 (*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-5 *2 (-121)) (-5 *1 (-235 *4)) (-4 *4 (-1054))))) 
-(-13 (-1054) (-283 (-923) |#1|) (-10 -8 (IF (|has| |#1| (-174)) (-6 (-562)) |noBranch|) (IF (|has| |#1| (-174)) (-6 (-43 |#1|)) |noBranch|) (-15 -3972 ($ (-1 |#1| (-923)))) (-15 -3972 ((-1 |#1| (-923)) $)) (-15 -3972 ($ (-1150 |#1|))) (-15 -3972 ((-1150 |#1|) $)) (-15 -3013 ($) -3211) (-15 -3719 ((-121) $ (-923))) (-15 -2215 ((-121) $ (-923))))) 
-((-2216 (((-572) (-638 (-1152))) 24) (((-572) (-1152)) 19)) (-3881 (((-1264) (-638 (-1152))) 29) (((-1264) (-1152)) 28)) (-3442 (((-1152)) 14)) (-2972 (((-1152) (-572) (-1152)) 16)) (-1694 (((-638 (-1152)) (-638 (-1152)) (-572) (-1152)) 25) (((-1152) (-1152) (-572) (-1152)) 23)) (-1850 (((-638 (-1152)) (-638 (-1152))) 13) (((-638 (-1152)) (-1152)) 11))) 
-(((-236) (-10 -7 (-15 -1850 ((-638 (-1152)) (-1152))) (-15 -1850 ((-638 (-1152)) (-638 (-1152)))) (-15 -3442 ((-1152))) (-15 -2972 ((-1152) (-572) (-1152))) (-15 -1694 ((-1152) (-1152) (-572) (-1152))) (-15 -1694 ((-638 (-1152)) (-638 (-1152)) (-572) (-1152))) (-15 -3881 ((-1264) (-1152))) (-15 -3881 ((-1264) (-638 (-1152)))) (-15 -2216 ((-572) (-1152))) (-15 -2216 ((-572) (-638 (-1152)))))) (T -236)) 
-((-2216 (*1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-572)) (-5 *1 (-236)))) (-2216 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-572)) (-5 *1 (-236)))) (-3881 (*1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-1264)) (-5 *1 (-236)))) (-3881 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-236)))) (-1694 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-638 (-1152))) (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *1 (-236)))) (-1694 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-1152)) (-5 *3 (-572)) (-5 *1 (-236)))) (-2972 (*1 *2 *3 *2) (-12 (-5 *2 (-1152)) (-5 *3 (-572)) (-5 *1 (-236)))) (-3442 (*1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-236)))) (-1850 (*1 *2 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-236)))) (-1850 (*1 *2 *3) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-236)) (-5 *3 (-1152))))) 
-(-10 -7 (-15 -1850 ((-638 (-1152)) (-1152))) (-15 -1850 ((-638 (-1152)) (-638 (-1152)))) (-15 -3442 ((-1152))) (-15 -2972 ((-1152) (-572) (-1152))) (-15 -1694 ((-1152) (-1152) (-572) (-1152))) (-15 -1694 ((-638 (-1152)) (-638 (-1152)) (-572) (-1152))) (-15 -3881 ((-1264) (-1152))) (-15 -3881 ((-1264) (-638 (-1152)))) (-15 -2216 ((-572) (-1152))) (-15 -2216 ((-572) (-638 (-1152))))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2640 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-572)))) $) 44)) (-1567 (((-638 |#1|) $) 30)) (-3270 (((-638 |#1|) $) 29)) (-4575 (((-638 |#1|) $) 31)) (-1572 (((-3 $ "failed") $ $) 18)) (-1585 (((-638 $) $) 36)) (-1685 (((-769) $) 43)) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 39)) (-1318 ((|#1| $) 40)) (-4351 ((|#1| $ (-572)) 46)) (-1333 (((-572) $ (-572)) 45)) (-3629 (($ (-1 |#1| |#1|) $) 49)) (-2966 (($ (-1 (-572) (-572)) $) 48)) (-1658 (((-1152) $) 9)) (-2408 (($ $) 26)) (-3696 (($ $ $) 50 (|has| (-572) (-793)))) (-2607 (((-1116) $) 10)) (-4134 (((-121) $) 32)) (-2428 (($ $) 28)) (-2206 (($ $) 27)) (-4316 (((-572) $) 37)) (-4500 (($ $ $) 33)) (-1650 (($ $) 34)) (-3972 (((-856) $) 11) (($ |#1|) 38)) (-1958 (((-572) |#1| $) 47)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 35)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13) (($ |#1| $) 41)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ (-572)) 52) (($ (-572) $) 51) (($ (-572) |#1|) 42))) 
-(((-237 |#1|) (-1290) (-1098)) (T -237)) 
-((-4316 (*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-572)))) (-1585 (*1 *2 *1) (-12 (-4 *3 (-1098)) (-5 *2 (-638 *1)) (-4 *1 (-237 *3)))) (-1343 (*1 *2 *1 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-121)))) (-1650 (*1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098)))) (-4500 (*1 *1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098)))) (-4134 (*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-121)))) (-4575 (*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-638 *3)))) (-1567 (*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-638 *3)))) (-3270 (*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-638 *3)))) (-2428 (*1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098)))) (-2206 (*1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098)))) (-2408 (*1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098))))) 
-(-13 (-21) (-713 (-572)) (-322 |t#1| (-572)) (-10 -8 (-15 -4316 ((-572) $)) (-15 -1585 ((-638 $) $)) (-15 -1343 ((-121) $ $)) (-15 -1650 ($ $)) (-15 -4500 ($ $ $)) (-15 -4134 ((-121) $)) (-15 -4575 ((-638 |t#1|) $)) (-15 -1567 ((-638 |t#1|) $)) (-15 -3270 ((-638 |t#1|) $)) (-15 -2428 ($ $)) (-15 -2206 ($ $)) (-15 -2408 ($ $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 (-572) (-572)) . T) ((-138) . T) ((-612 (-856)) . T) ((-322 |#1| (-572)) . T) ((-641 (-572)) . T) ((-713 (-572)) . T) ((-1044 |#1|) . T) ((-1060 (-572)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 17)) (-2640 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-572)))) $) 30)) (-1567 (((-638 |#1|) $) 36)) (-3270 (((-638 |#1|) $) 37)) (-4575 (((-638 |#1|) $) 35)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1585 (((-638 $) $) 29)) (-1685 (((-769) $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-4383 (($ $) 24)) (-4351 ((|#1| $ (-572)) NIL)) (-1333 (((-572) $ (-572)) NIL)) (-3629 (($ (-1 |#1| |#1|) $) NIL)) (-2966 (($ (-1 (-572) (-572)) $) NIL)) (-1658 (((-1152) $) NIL)) (-2408 (($ $) 8)) (-3696 (($ $ $) NIL (|has| (-572) (-793)))) (-2826 (((-2 (|:| |gen| |#1|) (|:| -4179 (-572))) $) 26)) (-2607 (((-1116) $) NIL)) (-4134 (((-121) $) 50)) (-2428 (($ $) 38)) (-2206 (($ $) 39)) (-4316 (((-572) $) 58)) (-4500 (($ $ $) 44)) (-1650 (($ $) 33)) (-3972 (((-856) $) 22) (($ |#1|) 27)) (-1958 (((-572) |#1| $) 32)) (-2378 (($) 23 T CONST)) (-1324 (((-121) $ $) 40)) (-1343 (((-121) $ $) 51)) (-1373 (($ $) 48) (($ $ $) 47)) (-1367 (($ $ $) 45) (($ |#1| $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 49) (($ $ (-572)) NIL) (($ (-572) $) 49) (($ (-572) |#1|) NIL))) 
-(((-238 |#1|) (-13 (-237 |#1|) (-10 -8 (-15 -2826 ((-2 (|:| |gen| |#1|) (|:| -4179 (-572))) $)) (-15 -4383 ($ $)))) (-1096)) (T -238)) 
-((-2826 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |gen| *3) (|:| -4179 (-572)))) (-5 *1 (-238 *3)) (-4 *3 (-1096)))) (-4383 (*1 *1 *1) (-12 (-5 *1 (-238 *2)) (-4 *2 (-1096))))) 
-(-13 (-237 |#1|) (-10 -8 (-15 -2826 ((-2 (|:| |gen| |#1|) (|:| -4179 (-572))) $)) (-15 -4383 ($ $)))) 
-((-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 9)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 18)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ (-413 (-572)) $) 25) (($ $ (-413 (-572))) NIL))) 
-(((-239 |#1|) (-10 -8 (-15 -4174 (|#1| |#1| (-572))) (-15 ** (|#1| |#1| (-572))) (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 ** (|#1| |#1| (-769))) (-15 -4174 (|#1| |#1| (-769))) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-923))) (-15 -4174 (|#1| |#1| (-923))) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) (-240)) (T -239)) 
-NIL 
-(-10 -8 (-15 -4174 (|#1| |#1| (-572))) (-15 ** (|#1| |#1| (-572))) (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 ** (|#1| |#1| (-769))) (-15 -4174 (|#1| |#1| (-769))) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-923))) (-15 -4174 (|#1| |#1| (-923))) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 38)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 43)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 39)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 40)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ (-413 (-572)) $) 42) (($ $ (-413 (-572))) 41))) 
-(((-240) (-1290)) (T -240)) 
-((** (*1 *1 *1 *2) (-12 (-4 *1 (-240)) (-5 *2 (-572)))) (-4174 (*1 *1 *1 *2) (-12 (-4 *1 (-240)) (-5 *2 (-572)))) (-4350 (*1 *1 *1) (-4 *1 (-240)))) 
-(-13 (-287) (-43 (-413 (-572))) (-10 -8 (-15 ** ($ $ (-572))) (-15 -4174 ($ $ (-572))) (-15 -4350 ($ $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-287) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-722) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-4232 (($ $) 54)) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-3803 (($ $ $) 50 (|has| $ (-6 -4603)))) (-3460 (($ $ $) 49 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-2211 (($) 7 T CONST)) (-2181 (($ $) 53)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-2043 (($ $) 52)) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-3253 ((|#1| $) 56)) (-2826 (($ $) 55)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44)) (-3537 (((-572) $ $) 41)) (-1791 (((-121) $) 43)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-2977 (($ $ $) 51 (|has| $ (-6 -4603)))) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-241 |#1|) (-1290) (-1204)) (T -241)) 
-((-3253 (*1 *2 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204)))) (-2826 (*1 *1 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204)))) (-4232 (*1 *1 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204)))) (-2181 (*1 *1 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204)))) (-2043 (*1 *1 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204)))) (-2977 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-241 *2)) (-4 *2 (-1204)))) (-3803 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-241 *2)) (-4 *2 (-1204)))) (-3460 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-241 *2)) (-4 *2 (-1204))))) 
-(-13 (-1017 |t#1|) (-10 -8 (-15 -3253 (|t#1| $)) (-15 -2826 ($ $)) (-15 -4232 ($ $)) (-15 -2181 ($ $)) (-15 -2043 ($ $)) (IF (|has| $ (-6 -4603)) (PROGN (-15 -2977 ($ $ $)) (-15 -3803 ($ $ $)) (-15 -3460 ($ $ $))) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1017 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) NIL)) (-4230 ((|#1| $) NIL)) (-4232 (($ $) NIL)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) $) NIL (|has| |#1| (-848))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-4131 (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848)))) (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3008 (($ $) 10 (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-3749 (($ $ $) NIL (|has| $ (-6 -4603)))) (-2656 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-4055 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ "first" |#1|) NIL (|has| $ (-6 -4603))) (($ $ "rest" $) NIL (|has| $ (-6 -4603))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-1550 (($ (-1 (-121) |#1|) $) NIL)) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4066 ((|#1| $) NIL)) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1651 (($ $) NIL) (($ $ (-769)) NIL)) (-3259 (($ $) NIL (|has| |#1| (-1098)))) (-1643 (($ $) 7 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1544 (($ |#1| $) NIL (|has| |#1| (-1098))) (($ (-1 (-121) |#1|) $) NIL)) (-3445 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-2429 (((-121) $) NIL)) (-4014 (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098))) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) (-1 (-121) |#1|) $) NIL)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1364 (($ (-769) |#1|) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-3279 (($ $ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4475 (($ $ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1624 (($ |#1|) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-3253 ((|#1| $) NIL) (($ $ (-769)) NIL)) (-1335 (($ $ $ (-572)) NIL) (($ |#1| $ (-572)) NIL)) (-2603 (($ $ $ (-572)) NIL) (($ |#1| $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) NIL) (($ $ (-769)) NIL)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-3540 (((-121) $) NIL)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1225 (-572))) NIL) ((|#1| $ (-572)) NIL) ((|#1| $ (-572) |#1|) NIL) (($ $ "unique") 9) (($ $ "sort") 12) (((-769) $ "count") 16)) (-3537 (((-572) $ $) NIL)) (-2145 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-1940 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-2222 (($ (-638 |#1|)) 22)) (-1791 (((-121) $) NIL)) (-2619 (($ $) NIL)) (-3316 (($ $) NIL (|has| $ (-6 -4603)))) (-1471 (((-769) $) NIL)) (-3622 (($ $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-2977 (($ $ $) NIL) (($ $ |#1|) NIL)) (-4500 (($ $ $) NIL) (($ |#1| $) NIL) (($ (-638 $)) NIL) (($ $ |#1|) NIL)) (-3972 (($ (-638 |#1|)) 17) (((-638 |#1|) $) 18) (((-856) $) 21 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-4032 (((-769) $) 14 (|has| $ (-6 -4602))))) 
-(((-242 |#1|) (-13 (-662 |#1|) (-10 -8 (-15 -3972 ($ (-638 |#1|))) (-15 -3972 ((-638 |#1|) $)) (-15 -2222 ($ (-638 |#1|))) (-15 -3277 ($ $ "unique")) (-15 -3277 ($ $ "sort")) (-15 -3277 ((-769) $ "count")))) (-848)) (T -242)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-242 *3)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-242 *3)) (-4 *3 (-848)))) (-2222 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-242 *3)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 "unique") (-5 *1 (-242 *3)) (-4 *3 (-848)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 "sort") (-5 *1 (-242 *3)) (-4 *3 (-848)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 "count") (-5 *2 (-769)) (-5 *1 (-242 *4)) (-4 *4 (-848))))) 
-(-13 (-662 |#1|) (-10 -8 (-15 -3972 ($ (-638 |#1|))) (-15 -3972 ((-638 |#1|) $)) (-15 -2222 ($ (-638 |#1|))) (-15 -3277 ($ $ "unique")) (-15 -3277 ($ $ "sort")) (-15 -3277 ((-769) $ "count")))) 
-((-3287 (((-3 (-769) "failed") |#1| |#1| (-769)) 26))) 
-(((-243 |#1|) (-10 -7 (-15 -3287 ((-3 (-769) "failed") |#1| |#1| (-769)))) (-13 (-722) (-374) (-10 -7 (-15 ** (|#1| |#1| (-572)))))) (T -243)) 
-((-3287 (*1 *2 *3 *3 *2) (|partial| -12 (-5 *2 (-769)) (-4 *3 (-13 (-722) (-374) (-10 -7 (-15 ** (*3 *3 (-572)))))) (-5 *1 (-243 *3))))) 
-(-10 -7 (-15 -3287 ((-3 (-769) "failed") |#1| |#1| (-769)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-858 |#1|)) $) NIL)) (-4297 (((-1166 $) $ (-858 |#1|)) NIL) (((-1166 |#2|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#2| (-562)))) (-3946 (($ $) NIL (|has| |#2| (-562)))) (-3686 (((-121) $) NIL (|has| |#2| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-858 |#1|))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2844 (($ $) NIL (|has| |#2| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#2| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-858 |#1|) "failed") $) NIL)) (-1318 ((|#2| $) NIL) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-858 |#1|) $) NIL)) (-3190 (($ $ $ (-858 |#1|)) NIL (|has| |#2| (-174)))) (-3814 (($ $ (-638 (-572))) NIL)) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#2| (-457))) (($ $ (-858 |#1|)) NIL (|has| |#2| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#2| (-910)))) (-3977 (($ $ |#2| (-234 (-4032 |#1|) (-769)) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-858 |#1|) (-887 (-385))) (|has| |#2| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-858 |#1|) (-887 (-572))) (|has| |#2| (-887 (-572)))))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-4335 (($ (-1166 |#2|) (-858 |#1|)) NIL) (($ (-1166 $) (-858 |#1|)) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#2| (-234 (-4032 |#1|) (-769))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-858 |#1|)) NIL)) (-1784 (((-234 (-4032 |#1|) (-769)) $) NIL) (((-769) $ (-858 |#1|)) NIL) (((-638 (-769)) $ (-638 (-858 |#1|))) NIL)) (-1771 (($ $ $) NIL (|has| |#2| (-848)))) (-4238 (($ $ $) NIL (|has| |#2| (-848)))) (-3918 (($ (-1 (-234 (-4032 |#1|) (-769)) (-234 (-4032 |#1|) (-769))) $) NIL)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-1470 (((-3 (-858 |#1|) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#2| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-1658 (((-1152) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-858 |#1|)) (|:| -3751 (-769))) "failed") $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#2| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#2| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#2| (-910)))) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-858 |#1|) |#2|) NIL) (($ $ (-638 (-858 |#1|)) (-638 |#2|)) NIL) (($ $ (-858 |#1|) $) NIL) (($ $ (-638 (-858 |#1|)) (-638 $)) NIL)) (-2119 (($ $ (-858 |#1|)) NIL (|has| |#2| (-174)))) (-3139 (($ $ (-858 |#1|)) NIL) (($ $ (-638 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-4316 (((-234 (-4032 |#1|) (-769)) $) NIL) (((-769) $ (-858 |#1|)) NIL) (((-638 (-769)) $ (-638 (-858 |#1|))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-858 |#1|) (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-858 |#1|) (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-858 |#1|) (-613 (-545))) (|has| |#2| (-613 (-545)))))) (-3694 ((|#2| $) NIL (|has| |#2| (-457))) (($ $ (-858 |#1|)) NIL (|has| |#2| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#2| (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) NIL) (($ (-858 |#1|)) NIL) (($ (-413 (-572))) NIL (-1841 (|has| |#2| (-43 (-413 (-572)))) (|has| |#2| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#2| (-562)))) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-234 (-4032 |#1|) (-769))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#2| (-910))) (|has| |#2| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#2| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#2| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-858 |#1|)) NIL) (($ $ (-638 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-1349 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#2| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#2| (-43 (-413 (-572))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-244 |#1| |#2|) (-13 (-956 |#2| (-234 (-4032 |#1|) (-769)) (-858 |#1|)) (-10 -8 (-15 -3814 ($ $ (-638 (-572)))))) (-638 (-1170)) (-1054)) (T -244)) 
-((-3814 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-244 *3 *4)) (-14 *3 (-638 (-1170))) (-4 *4 (-1054))))) 
-(-13 (-956 |#2| (-234 (-4032 |#1|) (-769)) (-858 |#1|)) (-10 -8 (-15 -3814 ($ $ (-638 (-572)))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3421 (($ (-923)) NIL (|has| |#4| (-1054)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-1614 (($ $ $) NIL (|has| |#4| (-794)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-1685 (((-769)) NIL (|has| |#4| (-374)))) (-2433 (((-572) $) NIL (|has| |#4| (-846)))) (-3283 ((|#4| $ (-572) |#4|) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#4| "failed") $) NIL (|has| |#4| (-1098))) (((-3 (-572) "failed") $) NIL (-12 (|has| |#4| (-1044 (-572))) (|has| |#4| (-1098)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| |#4| (-1044 (-413 (-572)))) (|has| |#4| (-1098))))) (-1318 ((|#4| $) NIL (|has| |#4| (-1098))) (((-572) $) NIL (-12 (|has| |#4| (-1044 (-572))) (|has| |#4| (-1098)))) (((-413 (-572)) $) NIL (-12 (|has| |#4| (-1044 (-413 (-572)))) (|has| |#4| (-1098))))) (-2284 (((-2 (|:| -1369 (-685 |#4|)) (|:| |vec| (-1259 |#4|))) (-685 $) (-1259 $)) NIL (|has| |#4| (-1054))) (((-685 |#4|) (-685 $)) NIL (|has| |#4| (-1054))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054)))) (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))))) (-1799 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))) (|has| |#4| (-722)) (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))))) (-3286 (($) NIL (|has| |#4| (-374)))) (-3037 ((|#4| $ (-572) |#4|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#4| $ (-572)) NIL)) (-1908 (((-121) $) NIL (|has| |#4| (-846)))) (-2010 (((-638 |#4|) $) NIL (|has| $ (-6 -4602)))) (-3893 (((-121) $) NIL (-1841 (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))) (|has| |#4| (-722)) (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))))) (-4472 (((-121) $) NIL (|has| |#4| (-846)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (-1841 (|has| |#4| (-794)) (|has| |#4| (-846))))) (-4467 (((-638 |#4|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (-1841 (|has| |#4| (-794)) (|has| |#4| (-846))))) (-2435 (($ (-1 |#4| |#4|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) NIL)) (-3633 (((-923) $) NIL (|has| |#4| (-374)))) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-1763 (($ (-923)) NIL (|has| |#4| (-374)))) (-2607 (((-1116) $) NIL)) (-1837 ((|#4| $) NIL (|has| (-572) (-848)))) (-3299 (($ $ |#4|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#4|))) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 |#4|) (-638 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3587 (((-638 $)) NIL (|has| |#4| (-374)))) (-3167 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-2957 (((-638 |#4|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#4| $ (-572) |#4|) NIL) ((|#4| $ (-572)) 12)) (-1436 ((|#4| $ $) NIL (|has| |#4| (-1054)))) (-4315 (($ (-1259 |#4|)) NIL)) (-2502 (((-140)) NIL (|has| |#4| (-368)))) (-3139 (($ $ (-1 |#4| |#4|) (-769)) NIL (|has| |#4| (-1054))) (($ $ (-1 |#4| |#4|)) NIL (|has| |#4| (-1054))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#4| (-227)) (|has| |#4| (-1054)))) (($ $) NIL (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))))) (-1571 (((-769) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602))) (((-769) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-1259 |#4|) $) NIL) (((-856) $) NIL) (($ |#4|) NIL (|has| |#4| (-1098))) (($ (-572)) NIL (-1841 (-12 (|has| |#4| (-1044 (-572))) (|has| |#4| (-1098))) (|has| |#4| (-1054)))) (($ (-413 (-572))) NIL (-12 (|has| |#4| (-1044 (-413 (-572)))) (|has| |#4| (-1098))))) (-2140 (((-769)) NIL (|has| |#4| (-1054)))) (-3501 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-2264 (($ $) NIL (|has| |#4| (-846)))) (-4174 (($ $ (-769)) NIL (-1841 (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))) (|has| |#4| (-722)) (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054))))) (($ $ (-923)) NIL (-1841 (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))) (|has| |#4| (-722)) (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))))) (-2378 (($) NIL T CONST)) (-3255 (($) NIL (-1841 (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))) (|has| |#4| (-722)) (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) CONST)) (-1557 (($ $ (-1 |#4| |#4|) (-769)) NIL (|has| |#4| (-1054))) (($ $ (-1 |#4| |#4|)) NIL (|has| |#4| (-1054))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#4| (-227)) (|has| |#4| (-1054)))) (($ $) NIL (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))))) (-1349 (((-121) $ $) NIL (-1841 (|has| |#4| (-794)) (|has| |#4| (-846))))) (-1338 (((-121) $ $) NIL (-1841 (|has| |#4| (-794)) (|has| |#4| (-846))))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (-1841 (|has| |#4| (-794)) (|has| |#4| (-846))))) (-1334 (((-121) $ $) NIL (-1841 (|has| |#4| (-794)) (|has| |#4| (-846))))) (-1379 (($ $ |#4|) NIL (|has| |#4| (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL (-1841 (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))) (|has| |#4| (-722)) (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054))))) (($ $ (-923)) NIL (-1841 (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))) (|has| |#4| (-722)) (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))))) (* (($ |#2| $) 14) (($ (-572) $) NIL) (($ (-769) $) NIL) (($ (-923) $) NIL) (($ |#3| $) 18) (($ $ |#4|) NIL (|has| |#4| (-722))) (($ |#4| $) NIL (|has| |#4| (-722))) (($ $ $) NIL (-1841 (-12 (|has| |#4| (-227)) (|has| |#4| (-1054))) (-12 (|has| |#4| (-634 (-572))) (|has| |#4| (-1054))) (|has| |#4| (-722)) (-12 (|has| |#4| (-901 (-1170))) (|has| |#4| (-1054)))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-245 |#1| |#2| |#3| |#4|) (-13 (-232 |#1| |#4|) (-641 |#2|) (-641 |#3|)) (-923) (-1054) (-1119 |#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) (-641 |#2|)) (T -245)) 
-NIL 
-(-13 (-232 |#1| |#4|) (-641 |#2|) (-641 |#3|)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3421 (($ (-923)) NIL (|has| |#3| (-1054)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-1614 (($ $ $) NIL (|has| |#3| (-794)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-1685 (((-769)) NIL (|has| |#3| (-374)))) (-2433 (((-572) $) NIL (|has| |#3| (-846)))) (-3283 ((|#3| $ (-572) |#3|) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#3| "failed") $) NIL (|has| |#3| (-1098))) (((-3 (-572) "failed") $) NIL (-12 (|has| |#3| (-1044 (-572))) (|has| |#3| (-1098)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| |#3| (-1044 (-413 (-572)))) (|has| |#3| (-1098))))) (-1318 ((|#3| $) NIL (|has| |#3| (-1098))) (((-572) $) NIL (-12 (|has| |#3| (-1044 (-572))) (|has| |#3| (-1098)))) (((-413 (-572)) $) NIL (-12 (|has| |#3| (-1044 (-413 (-572)))) (|has| |#3| (-1098))))) (-2284 (((-2 (|:| -1369 (-685 |#3|)) (|:| |vec| (-1259 |#3|))) (-685 $) (-1259 $)) NIL (|has| |#3| (-1054))) (((-685 |#3|) (-685 $)) NIL (|has| |#3| (-1054))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054)))) (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))))) (-1799 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))) (|has| |#3| (-722)) (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))))) (-3286 (($) NIL (|has| |#3| (-374)))) (-3037 ((|#3| $ (-572) |#3|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#3| $ (-572)) NIL)) (-1908 (((-121) $) NIL (|has| |#3| (-846)))) (-2010 (((-638 |#3|) $) NIL (|has| $ (-6 -4602)))) (-3893 (((-121) $) NIL (-1841 (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))) (|has| |#3| (-722)) (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))))) (-4472 (((-121) $) NIL (|has| |#3| (-846)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-4467 (((-638 |#3|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#3| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-2435 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#3| |#3|) $) NIL)) (-3633 (((-923) $) NIL (|has| |#3| (-374)))) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-1763 (($ (-923)) NIL (|has| |#3| (-374)))) (-2607 (((-1116) $) NIL)) (-1837 ((|#3| $) NIL (|has| (-572) (-848)))) (-3299 (($ $ |#3|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#3|))) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ (-290 |#3|)) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ (-638 |#3|) (-638 |#3|)) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3587 (((-638 $)) NIL (|has| |#3| (-374)))) (-3167 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#3| (-1098))))) (-2957 (((-638 |#3|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#3| $ (-572) |#3|) NIL) ((|#3| $ (-572)) 11)) (-1436 ((|#3| $ $) NIL (|has| |#3| (-1054)))) (-4315 (($ (-1259 |#3|)) NIL)) (-2502 (((-140)) NIL (|has| |#3| (-368)))) (-3139 (($ $ (-1 |#3| |#3|) (-769)) NIL (|has| |#3| (-1054))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1054))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#3| (-227)) (|has| |#3| (-1054)))) (($ $) NIL (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))))) (-1571 (((-769) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602))) (((-769) |#3| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#3| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-1259 |#3|) $) NIL) (((-856) $) NIL) (($ |#3|) NIL (|has| |#3| (-1098))) (($ (-572)) NIL (-1841 (-12 (|has| |#3| (-1044 (-572))) (|has| |#3| (-1098))) (|has| |#3| (-1054)))) (($ (-413 (-572))) NIL (-12 (|has| |#3| (-1044 (-413 (-572)))) (|has| |#3| (-1098))))) (-2140 (((-769)) NIL (|has| |#3| (-1054)))) (-3501 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602)))) (-2264 (($ $) NIL (|has| |#3| (-846)))) (-4174 (($ $ (-769)) NIL (-1841 (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))) (|has| |#3| (-722)) (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054))))) (($ $ (-923)) NIL (-1841 (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))) (|has| |#3| (-722)) (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))))) (-2378 (($) NIL T CONST)) (-3255 (($) NIL (-1841 (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))) (|has| |#3| (-722)) (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) CONST)) (-1557 (($ $ (-1 |#3| |#3|) (-769)) NIL (|has| |#3| (-1054))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1054))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#3| (-227)) (|has| |#3| (-1054)))) (($ $) NIL (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))))) (-1349 (((-121) $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-1338 (((-121) $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-1334 (((-121) $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-1379 (($ $ |#3|) NIL (|has| |#3| (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL (-1841 (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))) (|has| |#3| (-722)) (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054))))) (($ $ (-923)) NIL (-1841 (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))) (|has| |#3| (-722)) (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))))) (* (($ |#2| $) 13) (($ (-572) $) NIL) (($ (-769) $) NIL) (($ (-923) $) NIL) (($ $ |#3|) NIL (|has| |#3| (-722))) (($ |#3| $) NIL (|has| |#3| (-722))) (($ $ $) NIL (-1841 (-12 (|has| |#3| (-227)) (|has| |#3| (-1054))) (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054))) (|has| |#3| (-722)) (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-246 |#1| |#2| |#3|) (-13 (-232 |#1| |#3|) (-641 |#2|)) (-769) (-1054) (-641 |#2|)) (T -246)) 
-NIL 
-(-13 (-232 |#1| |#3|) (-641 |#2|)) 
-((-2923 (((-638 (-769)) $) 47) (((-638 (-769)) $ |#3|) 50)) (-3073 (((-769) $) 49) (((-769) $ |#3|) 52)) (-4048 (($ $) 65)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 (-572) "failed") $) NIL) (((-3 |#4| "failed") $) NIL) (((-3 |#3| "failed") $) 72)) (-3377 (((-769) $ |#3|) 39) (((-769) $) 36)) (-3101 (((-1 $ (-769)) |#3|) 15) (((-1 $ (-769)) $) 77)) (-4021 ((|#4| $) 58)) (-3815 (((-121) $) 56)) (-2106 (($ $) 64)) (-4485 (($ $ (-638 (-290 $))) 96) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ |#4| |#2|) NIL) (($ $ (-638 |#4|) (-638 |#2|)) NIL) (($ $ |#4| $) NIL) (($ $ (-638 |#4|) (-638 $)) NIL) (($ $ |#3| $) NIL) (($ $ (-638 |#3|) (-638 $)) 89) (($ $ |#3| |#2|) NIL) (($ $ (-638 |#3|) (-638 |#2|)) 84)) (-3139 (($ $ |#4|) NIL) (($ $ (-638 |#4|)) NIL) (($ $ |#4| (-769)) NIL) (($ $ (-638 |#4|) (-638 (-769))) NIL) (($ $) NIL) (($ $ (-769)) NIL) (($ $ (-1170)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) 32)) (-2866 (((-638 |#3|) $) 75)) (-4316 ((|#5| $) NIL) (((-769) $ |#4|) NIL) (((-638 (-769)) $ (-638 |#4|)) NIL) (((-769) $ |#3|) 44)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) NIL) (($ |#4|) NIL) (($ |#3|) 67) (($ (-413 (-572))) NIL) (($ $) NIL))) 
-(((-247 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -3972 (|#1| |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -4485 (|#1| |#1| (-638 |#3|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#3| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#3|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#3| |#1|)) (-15 -3101 ((-1 |#1| (-769)) |#1|)) (-15 -4048 (|#1| |#1|)) (-15 -2106 (|#1| |#1|)) (-15 -4021 (|#4| |#1|)) (-15 -3815 ((-121) |#1|)) (-15 -3073 ((-769) |#1| |#3|)) (-15 -2923 ((-638 (-769)) |#1| |#3|)) (-15 -3073 ((-769) |#1|)) (-15 -2923 ((-638 (-769)) |#1|)) (-15 -4316 ((-769) |#1| |#3|)) (-15 -3377 ((-769) |#1|)) (-15 -3377 ((-769) |#1| |#3|)) (-15 -2866 ((-638 |#3|) |#1|)) (-15 -3101 ((-1 |#1| (-769)) |#3|)) (-15 -3376 ((-3 |#3| "failed") |#1|)) (-15 -3972 (|#1| |#3|)) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1|)) (-15 -4316 ((-638 (-769)) |#1| (-638 |#4|))) (-15 -4316 ((-769) |#1| |#4|)) (-15 -3376 ((-3 |#4| "failed") |#1|)) (-15 -3972 (|#1| |#4|)) (-15 -4485 (|#1| |#1| (-638 |#4|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#4| |#1|)) (-15 -4485 (|#1| |#1| (-638 |#4|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#4| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4316 (|#5| |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3139 (|#1| |#1| (-638 |#4|) (-638 (-769)))) (-15 -3139 (|#1| |#1| |#4| (-769))) (-15 -3139 (|#1| |#1| (-638 |#4|))) (-15 -3139 (|#1| |#1| |#4|)) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) (-248 |#2| |#3| |#4| |#5|) (-1054) (-848) (-264 |#3|) (-794)) (T -247)) 
-NIL 
-(-10 -8 (-15 -3972 (|#1| |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -4485 (|#1| |#1| (-638 |#3|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#3| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#3|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#3| |#1|)) (-15 -3101 ((-1 |#1| (-769)) |#1|)) (-15 -4048 (|#1| |#1|)) (-15 -2106 (|#1| |#1|)) (-15 -4021 (|#4| |#1|)) (-15 -3815 ((-121) |#1|)) (-15 -3073 ((-769) |#1| |#3|)) (-15 -2923 ((-638 (-769)) |#1| |#3|)) (-15 -3073 ((-769) |#1|)) (-15 -2923 ((-638 (-769)) |#1|)) (-15 -4316 ((-769) |#1| |#3|)) (-15 -3377 ((-769) |#1|)) (-15 -3377 ((-769) |#1| |#3|)) (-15 -2866 ((-638 |#3|) |#1|)) (-15 -3101 ((-1 |#1| (-769)) |#3|)) (-15 -3376 ((-3 |#3| "failed") |#1|)) (-15 -3972 (|#1| |#3|)) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1|)) (-15 -4316 ((-638 (-769)) |#1| (-638 |#4|))) (-15 -4316 ((-769) |#1| |#4|)) (-15 -3376 ((-3 |#4| "failed") |#1|)) (-15 -3972 (|#1| |#4|)) (-15 -4485 (|#1| |#1| (-638 |#4|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#4| |#1|)) (-15 -4485 (|#1| |#1| (-638 |#4|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#4| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4316 (|#5| |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3139 (|#1| |#1| (-638 |#4|) (-638 (-769)))) (-15 -3139 (|#1| |#1| |#4| (-769))) (-15 -3139 (|#1| |#1| (-638 |#4|))) (-15 -3139 (|#1| |#1| |#4|)) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2923 (((-638 (-769)) $) 193) (((-638 (-769)) $ |#2|) 191)) (-3073 (((-769) $) 192) (((-769) $ |#2|) 190)) (-3456 (((-638 |#3|) $) 108)) (-4297 (((-1166 $) $ |#3|) 123) (((-1166 |#1|) $) 122)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 85 (|has| |#1| (-562)))) (-3946 (($ $) 86 (|has| |#1| (-562)))) (-3686 (((-121) $) 88 (|has| |#1| (-562)))) (-2357 (((-769) $) 110) (((-769) $ (-638 |#3|)) 109)) (-1572 (((-3 $ "failed") $ $) 18)) (-4073 (((-424 (-1166 $)) (-1166 $)) 98 (|has| |#1| (-910)))) (-2844 (($ $) 96 (|has| |#1| (-457)))) (-1466 (((-424 $) $) 95 (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 101 (|has| |#1| (-910)))) (-4048 (($ $) 186)) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 162) (((-3 (-413 (-572)) "failed") $) 160 (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) 158 (|has| |#1| (-1044 (-572)))) (((-3 |#3| "failed") $) 134) (((-3 |#2| "failed") $) 200)) (-1318 ((|#1| $) 163) (((-413 (-572)) $) 159 (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) 157 (|has| |#1| (-1044 (-572)))) ((|#3| $) 133) ((|#2| $) 199)) (-3190 (($ $ $ |#3|) 106 (|has| |#1| (-174)))) (-4383 (($ $) 152)) (-2284 (((-685 (-572)) (-685 $)) 132 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 131 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 130) (((-685 |#1|) (-685 $)) 129)) (-1799 (((-3 $ "failed") $) 33)) (-3988 (($ $) 174 (|has| |#1| (-457))) (($ $ |#3|) 103 (|has| |#1| (-457)))) (-4378 (((-638 $) $) 107)) (-1526 (((-121) $) 94 (|has| |#1| (-910)))) (-3977 (($ $ |#1| |#4| $) 170)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 82 (-12 (|has| |#3| (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 81 (-12 (|has| |#3| (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3377 (((-769) $ |#2|) 196) (((-769) $) 195)) (-3893 (((-121) $) 30)) (-3475 (((-769) $) 167)) (-4335 (($ (-1166 |#1|) |#3|) 115) (($ (-1166 $) |#3|) 114)) (-3658 (((-638 $) $) 124)) (-4581 (((-121) $) 150)) (-4328 (($ |#1| |#4|) 151) (($ $ |#3| (-769)) 117) (($ $ (-638 |#3|) (-638 (-769))) 116)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ |#3|) 118)) (-1784 ((|#4| $) 168) (((-769) $ |#3|) 120) (((-638 (-769)) $ (-638 |#3|)) 119)) (-1771 (($ $ $) 77 (|has| |#1| (-848)))) (-4238 (($ $ $) 76 (|has| |#1| (-848)))) (-3918 (($ (-1 |#4| |#4|) $) 169)) (-3828 (($ (-1 |#1| |#1|) $) 149)) (-3101 (((-1 $ (-769)) |#2|) 198) (((-1 $ (-769)) $) 185 (|has| |#1| (-227)))) (-1470 (((-3 |#3| "failed") $) 121)) (-4368 (($ $) 147)) (-4373 ((|#1| $) 146)) (-4021 ((|#3| $) 188)) (-1629 (($ (-638 $)) 92 (|has| |#1| (-457))) (($ $ $) 91 (|has| |#1| (-457)))) (-1658 (((-1152) $) 9)) (-3815 (((-121) $) 189)) (-1921 (((-3 (-638 $) "failed") $) 112)) (-2336 (((-3 (-638 $) "failed") $) 113)) (-3019 (((-3 (-2 (|:| |var| |#3|) (|:| -3751 (-769))) "failed") $) 111)) (-2106 (($ $) 187)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 164)) (-4362 ((|#1| $) 165)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 93 (|has| |#1| (-457)))) (-3069 (($ (-638 $)) 90 (|has| |#1| (-457))) (($ $ $) 89 (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) 100 (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) 99 (|has| |#1| (-910)))) (-4304 (((-424 $) $) 97 (|has| |#1| (-910)))) (-1803 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-562))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) 143) (($ $ (-290 $)) 142) (($ $ $ $) 141) (($ $ (-638 $) (-638 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-638 |#3|) (-638 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-638 |#3|) (-638 $)) 136) (($ $ |#2| $) 184 (|has| |#1| (-227))) (($ $ (-638 |#2|) (-638 $)) 183 (|has| |#1| (-227))) (($ $ |#2| |#1|) 182 (|has| |#1| (-227))) (($ $ (-638 |#2|) (-638 |#1|)) 181 (|has| |#1| (-227)))) (-2119 (($ $ |#3|) 105 (|has| |#1| (-174)))) (-3139 (($ $ |#3|) 41) (($ $ (-638 |#3|)) 40) (($ $ |#3| (-769)) 39) (($ $ (-638 |#3|) (-638 (-769))) 38) (($ $) 217 (|has| |#1| (-227))) (($ $ (-769)) 215 (|has| |#1| (-227))) (($ $ (-1170)) 213 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 212 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 211 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) 210 (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) 203) (($ $ (-1 |#1| |#1|)) 202)) (-2866 (((-638 |#2|) $) 197)) (-4316 ((|#4| $) 148) (((-769) $ |#3|) 128) (((-638 (-769)) $ (-638 |#3|)) 127) (((-769) $ |#2|) 194)) (-4081 (((-893 (-385)) $) 80 (-12 (|has| |#3| (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) 79 (-12 (|has| |#3| (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) 78 (-12 (|has| |#3| (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) 173 (|has| |#1| (-457))) (($ $ |#3|) 104 (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 102 (-4028 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 161) (($ |#3|) 135) (($ |#2|) 201) (($ (-413 (-572))) 70 (-1841 (|has| |#1| (-1044 (-413 (-572)))) (|has| |#1| (-43 (-413 (-572)))))) (($ $) 83 (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) 166)) (-1958 ((|#1| $ |#4|) 153) (($ $ |#3| (-769)) 126) (($ $ (-638 |#3|) (-638 (-769))) 125)) (-2779 (((-3 $ "failed") $) 71 (-1841 (-4028 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) 28)) (-2565 (($ $ $ (-769)) 171 (|has| |#1| (-174)))) (-3774 (((-121) $ $) 87 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ |#3|) 37) (($ $ (-638 |#3|)) 36) (($ $ |#3| (-769)) 35) (($ $ (-638 |#3|) (-638 (-769))) 34) (($ $) 216 (|has| |#1| (-227))) (($ $ (-769)) 214 (|has| |#1| (-227))) (($ $ (-1170)) 209 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 208 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 207 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) 206 (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) 205) (($ $ (-1 |#1| |#1|)) 204)) (-1349 (((-121) $ $) 74 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 73 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 75 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 72 (|has| |#1| (-848)))) (-1379 (($ $ |#1|) 154 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 156 (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) 155 (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
-(((-248 |#1| |#2| |#3| |#4|) (-1290) (-1054) (-848) (-264 |t#2|) (-794)) (T -248)) 
-((-3101 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-1 *1 (-769))) (-4 *1 (-248 *4 *3 *5 *6)))) (-2866 (*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-638 *4)))) (-3377 (*1 *2 *1 *3) (-12 (-4 *1 (-248 *4 *3 *5 *6)) (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-769)))) (-3377 (*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-769)))) (-4316 (*1 *2 *1 *3) (-12 (-4 *1 (-248 *4 *3 *5 *6)) (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-769)))) (-2923 (*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-638 (-769))))) (-3073 (*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-769)))) (-2923 (*1 *2 *1 *3) (-12 (-4 *1 (-248 *4 *3 *5 *6)) (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-638 (-769))))) (-3073 (*1 *2 *1 *3) (-12 (-4 *1 (-248 *4 *3 *5 *6)) (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-769)))) (-3815 (*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-121)))) (-4021 (*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-794)) (-4 *2 (-264 *4)))) (-2106 (*1 *1 *1) (-12 (-4 *1 (-248 *2 *3 *4 *5)) (-4 *2 (-1054)) (-4 *3 (-848)) (-4 *4 (-264 *3)) (-4 *5 (-794)))) (-4048 (*1 *1 *1) (-12 (-4 *1 (-248 *2 *3 *4 *5)) (-4 *2 (-1054)) (-4 *3 (-848)) (-4 *4 (-264 *3)) (-4 *5 (-794)))) (-3101 (*1 *2 *1) (-12 (-4 *3 (-227)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-1 *1 (-769))) (-4 *1 (-248 *3 *4 *5 *6))))) 
-(-13 (-956 |t#1| |t#4| |t#3|) (-225 |t#1|) (-1044 |t#2|) (-10 -8 (-15 -3101 ((-1 $ (-769)) |t#2|)) (-15 -2866 ((-638 |t#2|) $)) (-15 -3377 ((-769) $ |t#2|)) (-15 -3377 ((-769) $)) (-15 -4316 ((-769) $ |t#2|)) (-15 -2923 ((-638 (-769)) $)) (-15 -3073 ((-769) $)) (-15 -2923 ((-638 (-769)) $ |t#2|)) (-15 -3073 ((-769) $ |t#2|)) (-15 -3815 ((-121) $)) (-15 -4021 (|t#3| $)) (-15 -2106 ($ $)) (-15 -4048 ($ $)) (IF (|has| |t#1| (-227)) (PROGN (-6 (-527 |t#2| |t#1|)) (-6 (-527 |t#2| $)) (-6 (-305 $)) (-15 -3101 ((-1 $ (-769)) $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#4|) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-613 (-545)) -12 (|has| |#1| (-613 (-545))) (|has| |#3| (-613 (-545)))) ((-613 (-893 (-385))) -12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#3| (-613 (-893 (-385))))) ((-613 (-893 (-572))) -12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#3| (-613 (-893 (-572))))) ((-225 |#1|) . T) ((-227) |has| |#1| (-227)) ((-287) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-305 $) . T) ((-326 |#1| |#4|) . T) ((-383 |#1|) . T) ((-417 |#1|) . T) ((-457) -1841 (|has| |#1| (-910)) (|has| |#1| (-457))) ((-527 |#2| |#1|) |has| |#1| (-227)) ((-527 |#2| $) |has| |#1| (-227)) ((-527 |#3| |#1|) . T) ((-527 |#3| $) . T) ((-527 $ $) . T) ((-562) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-722) . T) ((-848) |has| |#1| (-848)) ((-901 (-1170)) |has| |#1| (-901 (-1170))) ((-901 |#3|) . T) ((-887 (-385)) -12 (|has| |#1| (-887 (-385))) (|has| |#3| (-887 (-385)))) ((-887 (-572)) -12 (|has| |#1| (-887 (-572))) (|has| |#3| (-887 (-572)))) ((-956 |#1| |#4| |#3|) . T) ((-910) |has| |#1| (-910)) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1044 |#2|) . T) ((-1044 |#3|) . T) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) |has| |#1| (-910))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1312 ((|#1| $) 51)) (-1615 ((|#1| $) 41)) (-1946 (((-121) $ (-769)) 8)) (-2211 (($) 7 T CONST)) (-4080 (($ $) 57)) (-2985 (($ $) 45)) (-4107 ((|#1| |#1| $) 43)) (-3772 ((|#1| $) 42)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-3200 (((-769) $) 58)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-4221 ((|#1| $) 36)) (-2243 ((|#1| |#1| $) 49)) (-1488 ((|#1| |#1| $) 48)) (-1335 (($ |#1| $) 37)) (-1455 (((-769) $) 52)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2011 ((|#1| $) 59)) (-2983 ((|#1| $) 47)) (-3205 ((|#1| $) 46)) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-2933 ((|#1| |#1| $) 55)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-4494 ((|#1| $) 56)) (-2446 (($) 54) (($ (-638 |#1|)) 53)) (-1564 (((-769) $) 40)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4579 ((|#1| $) 50)) (-3058 (($ (-638 |#1|)) 39)) (-3782 ((|#1| $) 60)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-249 |#1|) (-1290) (-1204)) (T -249)) 
-((-2446 (*1 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204)))) (-2446 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-4 *1 (-249 *3)))) (-1455 (*1 *2 *1) (-12 (-4 *1 (-249 *3)) (-4 *3 (-1204)) (-5 *2 (-769)))) (-1312 (*1 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204)))) (-4579 (*1 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204)))) (-2243 (*1 *2 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204)))) (-1488 (*1 *2 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204)))) (-2983 (*1 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204)))) (-3205 (*1 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204)))) (-2985 (*1 *1 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204))))) 
-(-13 (-1117 |t#1|) (-1002 |t#1|) (-10 -8 (-15 -2446 ($)) (-15 -2446 ($ (-638 |t#1|))) (-15 -1455 ((-769) $)) (-15 -1312 (|t#1| $)) (-15 -4579 (|t#1| $)) (-15 -2243 (|t#1| |t#1| $)) (-15 -1488 (|t#1| |t#1| $)) (-15 -2983 (|t#1| $)) (-15 -3205 (|t#1| $)) (-15 -2985 ($ $)))) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1002 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1117 |#1|) . T) ((-1204) . T)) 
-((-4034 (((-1 (-950 (-217)) (-217) (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1 (-217) (-217) (-217) (-217))) 139)) (-4507 (((-1129 (-217)) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385))) 160) (((-1129 (-217)) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)) (-638 (-258))) 158) (((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385))) 163) (((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258))) 159) (((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385))) 150) (((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258))) 149) (((-1129 (-217)) (-1 (-950 (-217)) (-217)) (-1092 (-385))) 129) (((-1129 (-217)) (-1 (-950 (-217)) (-217)) (-1092 (-385)) (-638 (-258))) 127) (((-1129 (-217)) (-881 (-1 (-217) (-217))) (-1092 (-385))) 128) (((-1129 (-217)) (-881 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258))) 125)) (-4502 (((-1261) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385))) 162) (((-1261) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)) (-638 (-258))) 161) (((-1261) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385))) 165) (((-1261) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258))) 164) (((-1261) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385))) 152) (((-1261) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258))) 151) (((-1261) (-1 (-950 (-217)) (-217)) (-1092 (-385))) 135) (((-1261) (-1 (-950 (-217)) (-217)) (-1092 (-385)) (-638 (-258))) 134) (((-1261) (-881 (-1 (-217) (-217))) (-1092 (-385))) 133) (((-1261) (-881 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258))) 132) (((-1260) (-879 (-1 (-217) (-217))) (-1092 (-385))) 99) (((-1260) (-879 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258))) 98) (((-1260) (-1 (-217) (-217)) (-1092 (-385))) 95) (((-1260) (-1 (-217) (-217)) (-1092 (-385)) (-638 (-258))) 94))) 
-(((-250) (-10 -7 (-15 -4502 ((-1260) (-1 (-217) (-217)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1260) (-1 (-217) (-217)) (-1092 (-385)))) (-15 -4502 ((-1260) (-879 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1260) (-879 (-1 (-217) (-217))) (-1092 (-385)))) (-15 -4502 ((-1261) (-881 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-881 (-1 (-217) (-217))) (-1092 (-385)))) (-15 -4502 ((-1261) (-1 (-950 (-217)) (-217)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-1 (-950 (-217)) (-217)) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-881 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-881 (-1 (-217) (-217))) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-1 (-950 (-217)) (-217)) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-1 (-950 (-217)) (-217)) (-1092 (-385)))) (-15 -4502 ((-1261) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)))) (-15 -4502 ((-1261) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)))) (-15 -4502 ((-1261) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)))) (-15 -4034 ((-1 (-950 (-217)) (-217) (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1 (-217) (-217) (-217) (-217)))))) (T -250)) 
-((-4034 (*1 *2 *2 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217) (-217))) (-5 *3 (-1 (-217) (-217) (-217) (-217))) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-883 (-1 (-217) (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-883 (-1 (-217) (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-883 (-1 (-217) (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-883 (-1 (-217) (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-950 (-217)) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4) (-12 (-5 *3 (-881 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4507 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-881 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-950 (-217)) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4) (-12 (-5 *3 (-881 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-881 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4) (-12 (-5 *3 (-879 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1260)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-879 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1260)) (-5 *1 (-250)))) (-4502 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-250))))) 
-(-10 -7 (-15 -4502 ((-1260) (-1 (-217) (-217)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1260) (-1 (-217) (-217)) (-1092 (-385)))) (-15 -4502 ((-1260) (-879 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1260) (-879 (-1 (-217) (-217))) (-1092 (-385)))) (-15 -4502 ((-1261) (-881 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-881 (-1 (-217) (-217))) (-1092 (-385)))) (-15 -4502 ((-1261) (-1 (-950 (-217)) (-217)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-1 (-950 (-217)) (-217)) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-881 (-1 (-217) (-217))) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-881 (-1 (-217) (-217))) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-1 (-950 (-217)) (-217)) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-1 (-950 (-217)) (-217)) (-1092 (-385)))) (-15 -4502 ((-1261) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1092 (-385)) (-1092 (-385)))) (-15 -4502 ((-1261) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-385)) (-1092 (-385)))) (-15 -4502 ((-1261) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)))) (-15 -4507 ((-1129 (-217)) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-883 (-1 (-217) (-217) (-217))) (-1092 (-385)) (-1092 (-385)))) (-15 -4034 ((-1 (-950 (-217)) (-217) (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1 (-217) (-217) (-217) (-217))))) 
-((-4502 (((-1260) (-290 |#2|) (-1170) (-1170) (-638 (-258))) 93))) 
-(((-251 |#1| |#2|) (-10 -7 (-15 -4502 ((-1260) (-290 |#2|) (-1170) (-1170) (-638 (-258))))) (-13 (-562) (-848) (-1044 (-572))) (-436 |#1|)) (T -251)) 
-((-4502 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-290 *7)) (-5 *4 (-1170)) (-5 *5 (-638 (-258))) (-4 *7 (-436 *6)) (-4 *6 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-1260)) (-5 *1 (-251 *6 *7))))) 
-(-10 -7 (-15 -4502 ((-1260) (-290 |#2|) (-1170) (-1170) (-638 (-258))))) 
-((-1548 (((-572) (-572)) 50)) (-2231 (((-572) (-572)) 51)) (-1982 (((-217) (-217)) 52)) (-4313 (((-1261) (-1 (-171 (-217)) (-171 (-217))) (-1092 (-217)) (-1092 (-217))) 49)) (-2836 (((-1261) (-1 (-171 (-217)) (-171 (-217))) (-1092 (-217)) (-1092 (-217)) (-121)) 47))) 
-(((-252) (-10 -7 (-15 -2836 ((-1261) (-1 (-171 (-217)) (-171 (-217))) (-1092 (-217)) (-1092 (-217)) (-121))) (-15 -4313 ((-1261) (-1 (-171 (-217)) (-171 (-217))) (-1092 (-217)) (-1092 (-217)))) (-15 -1548 ((-572) (-572))) (-15 -2231 ((-572) (-572))) (-15 -1982 ((-217) (-217))))) (T -252)) 
-((-1982 (*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-252)))) (-2231 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-252)))) (-1548 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-252)))) (-4313 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-171 (-217)) (-171 (-217)))) (-5 *4 (-1092 (-217))) (-5 *2 (-1261)) (-5 *1 (-252)))) (-2836 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-171 (-217)) (-171 (-217)))) (-5 *4 (-1092 (-217))) (-5 *5 (-121)) (-5 *2 (-1261)) (-5 *1 (-252))))) 
-(-10 -7 (-15 -2836 ((-1261) (-1 (-171 (-217)) (-171 (-217))) (-1092 (-217)) (-1092 (-217)) (-121))) (-15 -4313 ((-1261) (-1 (-171 (-217)) (-171 (-217))) (-1092 (-217)) (-1092 (-217)))) (-15 -1548 ((-572) (-572))) (-15 -2231 ((-572) (-572))) (-15 -1982 ((-217) (-217)))) 
-((-3972 (((-1090 (-385)) (-1090 (-312 |#1|))) 16))) 
-(((-253 |#1|) (-10 -7 (-15 -3972 ((-1090 (-385)) (-1090 (-312 |#1|))))) (-13 (-848) (-562) (-613 (-385)))) (T -253)) 
-((-3972 (*1 *2 *3) (-12 (-5 *3 (-1090 (-312 *4))) (-4 *4 (-13 (-848) (-562) (-613 (-385)))) (-5 *2 (-1090 (-385))) (-5 *1 (-253 *4))))) 
-(-10 -7 (-15 -3972 ((-1090 (-385)) (-1090 (-312 |#1|))))) 
-((-4507 (((-1129 (-217)) (-883 |#1|) (-1090 (-385)) (-1090 (-385))) 69) (((-1129 (-217)) (-883 |#1|) (-1090 (-385)) (-1090 (-385)) (-638 (-258))) 68) (((-1129 (-217)) |#1| (-1090 (-385)) (-1090 (-385))) 59) (((-1129 (-217)) |#1| (-1090 (-385)) (-1090 (-385)) (-638 (-258))) 58) (((-1129 (-217)) (-881 |#1|) (-1090 (-385))) 50) (((-1129 (-217)) (-881 |#1|) (-1090 (-385)) (-638 (-258))) 49)) (-4502 (((-1261) (-883 |#1|) (-1090 (-385)) (-1090 (-385))) 72) (((-1261) (-883 |#1|) (-1090 (-385)) (-1090 (-385)) (-638 (-258))) 71) (((-1261) |#1| (-1090 (-385)) (-1090 (-385))) 62) (((-1261) |#1| (-1090 (-385)) (-1090 (-385)) (-638 (-258))) 61) (((-1261) (-881 |#1|) (-1090 (-385))) 54) (((-1261) (-881 |#1|) (-1090 (-385)) (-638 (-258))) 53) (((-1260) (-879 |#1|) (-1090 (-385))) 41) (((-1260) (-879 |#1|) (-1090 (-385)) (-638 (-258))) 40) (((-1260) |#1| (-1090 (-385))) 33) (((-1260) |#1| (-1090 (-385)) (-638 (-258))) 32))) 
-(((-254 |#1|) (-10 -7 (-15 -4502 ((-1260) |#1| (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1260) |#1| (-1090 (-385)))) (-15 -4502 ((-1260) (-879 |#1|) (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1260) (-879 |#1|) (-1090 (-385)))) (-15 -4502 ((-1261) (-881 |#1|) (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-881 |#1|) (-1090 (-385)))) (-15 -4507 ((-1129 (-217)) (-881 |#1|) (-1090 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-881 |#1|) (-1090 (-385)))) (-15 -4502 ((-1261) |#1| (-1090 (-385)) (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) |#1| (-1090 (-385)) (-1090 (-385)))) (-15 -4507 ((-1129 (-217)) |#1| (-1090 (-385)) (-1090 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) |#1| (-1090 (-385)) (-1090 (-385)))) (-15 -4502 ((-1261) (-883 |#1|) (-1090 (-385)) (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-883 |#1|) (-1090 (-385)) (-1090 (-385)))) (-15 -4507 ((-1129 (-217)) (-883 |#1|) (-1090 (-385)) (-1090 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-883 |#1|) (-1090 (-385)) (-1090 (-385))))) (-13 (-613 (-545)) (-1098))) (T -254)) 
-((-4507 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-883 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *5)))) (-4507 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-883 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *6)))) (-4502 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-883 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1261)) (-5 *1 (-254 *5)))) (-4502 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-883 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1261)) (-5 *1 (-254 *6)))) (-4507 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1090 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) (-4507 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) (-4502 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1090 (-385))) (-5 *2 (-1261)) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) (-4502 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) (-4507 (*1 *2 *3 *4) (-12 (-5 *3 (-881 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *5)))) (-4507 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-881 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *6)))) (-4502 (*1 *2 *3 *4) (-12 (-5 *3 (-881 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1261)) (-5 *1 (-254 *5)))) (-4502 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-881 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1261)) (-5 *1 (-254 *6)))) (-4502 (*1 *2 *3 *4) (-12 (-5 *3 (-879 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1260)) (-5 *1 (-254 *5)))) (-4502 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-879 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1260)) (-5 *1 (-254 *6)))) (-4502 (*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-385))) (-5 *2 (-1260)) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) (-4502 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098)))))) 
-(-10 -7 (-15 -4502 ((-1260) |#1| (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1260) |#1| (-1090 (-385)))) (-15 -4502 ((-1260) (-879 |#1|) (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1260) (-879 |#1|) (-1090 (-385)))) (-15 -4502 ((-1261) (-881 |#1|) (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-881 |#1|) (-1090 (-385)))) (-15 -4507 ((-1129 (-217)) (-881 |#1|) (-1090 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-881 |#1|) (-1090 (-385)))) (-15 -4502 ((-1261) |#1| (-1090 (-385)) (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) |#1| (-1090 (-385)) (-1090 (-385)))) (-15 -4507 ((-1129 (-217)) |#1| (-1090 (-385)) (-1090 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) |#1| (-1090 (-385)) (-1090 (-385)))) (-15 -4502 ((-1261) (-883 |#1|) (-1090 (-385)) (-1090 (-385)) (-638 (-258)))) (-15 -4502 ((-1261) (-883 |#1|) (-1090 (-385)) (-1090 (-385)))) (-15 -4507 ((-1129 (-217)) (-883 |#1|) (-1090 (-385)) (-1090 (-385)) (-638 (-258)))) (-15 -4507 ((-1129 (-217)) (-883 |#1|) (-1090 (-385)) (-1090 (-385))))) 
-((-4502 (((-1261) (-638 (-217)) (-638 (-217)) (-638 (-217)) (-638 (-258))) 21) (((-1261) (-638 (-217)) (-638 (-217)) (-638 (-217))) 22) (((-1260) (-638 (-950 (-217))) (-638 (-258))) 13) (((-1260) (-638 (-950 (-217)))) 14) (((-1260) (-638 (-217)) (-638 (-217)) (-638 (-258))) 18) (((-1260) (-638 (-217)) (-638 (-217))) 19))) 
-(((-255) (-10 -7 (-15 -4502 ((-1260) (-638 (-217)) (-638 (-217)))) (-15 -4502 ((-1260) (-638 (-217)) (-638 (-217)) (-638 (-258)))) (-15 -4502 ((-1260) (-638 (-950 (-217))))) (-15 -4502 ((-1260) (-638 (-950 (-217))) (-638 (-258)))) (-15 -4502 ((-1261) (-638 (-217)) (-638 (-217)) (-638 (-217)))) (-15 -4502 ((-1261) (-638 (-217)) (-638 (-217)) (-638 (-217)) (-638 (-258)))))) (T -255)) 
-((-4502 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-638 (-217))) (-5 *4 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-255)))) (-4502 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-1261)) (-5 *1 (-255)))) (-4502 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-950 (-217)))) (-5 *4 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-255)))) (-4502 (*1 *2 *3) (-12 (-5 *3 (-638 (-950 (-217)))) (-5 *2 (-1260)) (-5 *1 (-255)))) (-4502 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 (-217))) (-5 *4 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-255)))) (-4502 (*1 *2 *3 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-1260)) (-5 *1 (-255))))) 
-(-10 -7 (-15 -4502 ((-1260) (-638 (-217)) (-638 (-217)))) (-15 -4502 ((-1260) (-638 (-217)) (-638 (-217)) (-638 (-258)))) (-15 -4502 ((-1260) (-638 (-950 (-217))))) (-15 -4502 ((-1260) (-638 (-950 (-217))) (-638 (-258)))) (-15 -4502 ((-1261) (-638 (-217)) (-638 (-217)) (-638 (-217)))) (-15 -4502 ((-1261) (-638 (-217)) (-638 (-217)) (-638 (-217)) (-638 (-258))))) 
-((-2469 (((-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))) (-638 (-258)) (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) 24)) (-2817 (((-923) (-638 (-258)) (-923)) 49)) (-2249 (((-923) (-638 (-258)) (-923)) 48)) (-1810 (((-638 (-385)) (-638 (-258)) (-638 (-385))) 65)) (-3691 (((-385) (-638 (-258)) (-385)) 55)) (-2163 (((-923) (-638 (-258)) (-923)) 50)) (-4260 (((-121) (-638 (-258)) (-121)) 26)) (-3493 (((-1152) (-638 (-258)) (-1152)) 19)) (-3912 (((-1152) (-638 (-258)) (-1152)) 25)) (-3022 (((-1129 (-217)) (-638 (-258))) 43)) (-1588 (((-638 (-1092 (-385))) (-638 (-258)) (-638 (-1092 (-385)))) 37)) (-1291 (((-875) (-638 (-258)) (-875)) 31)) (-2815 (((-875) (-638 (-258)) (-875)) 32)) (-2720 (((-1 (-950 (-217)) (-950 (-217))) (-638 (-258)) (-1 (-950 (-217)) (-950 (-217)))) 60)) (-2450 (((-121) (-638 (-258)) (-121)) 15)) (-2496 (((-121) (-638 (-258)) (-121)) 14))) 
-(((-256) (-10 -7 (-15 -2496 ((-121) (-638 (-258)) (-121))) (-15 -2450 ((-121) (-638 (-258)) (-121))) (-15 -2469 ((-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))) (-638 (-258)) (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))))) (-15 -3493 ((-1152) (-638 (-258)) (-1152))) (-15 -3912 ((-1152) (-638 (-258)) (-1152))) (-15 -4260 ((-121) (-638 (-258)) (-121))) (-15 -1291 ((-875) (-638 (-258)) (-875))) (-15 -2815 ((-875) (-638 (-258)) (-875))) (-15 -1588 ((-638 (-1092 (-385))) (-638 (-258)) (-638 (-1092 (-385))))) (-15 -2249 ((-923) (-638 (-258)) (-923))) (-15 -2817 ((-923) (-638 (-258)) (-923))) (-15 -3022 ((-1129 (-217)) (-638 (-258)))) (-15 -2163 ((-923) (-638 (-258)) (-923))) (-15 -3691 ((-385) (-638 (-258)) (-385))) (-15 -2720 ((-1 (-950 (-217)) (-950 (-217))) (-638 (-258)) (-1 (-950 (-217)) (-950 (-217))))) (-15 -1810 ((-638 (-385)) (-638 (-258)) (-638 (-385)))))) (T -256)) 
-((-1810 (*1 *2 *3 *2) (-12 (-5 *2 (-638 (-385))) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-2720 (*1 *2 *3 *2) (-12 (-5 *2 (-1 (-950 (-217)) (-950 (-217)))) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-3691 (*1 *2 *3 *2) (-12 (-5 *2 (-385)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-2163 (*1 *2 *3 *2) (-12 (-5 *2 (-923)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-3022 (*1 *2 *3) (-12 (-5 *3 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-256)))) (-2817 (*1 *2 *3 *2) (-12 (-5 *2 (-923)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-2249 (*1 *2 *3 *2) (-12 (-5 *2 (-923)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-1588 (*1 *2 *3 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-2815 (*1 *2 *3 *2) (-12 (-5 *2 (-875)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-1291 (*1 *2 *3 *2) (-12 (-5 *2 (-875)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-4260 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-3912 (*1 *2 *3 *2) (-12 (-5 *2 (-1152)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-3493 (*1 *2 *3 *2) (-12 (-5 *2 (-1152)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-2469 (*1 *2 *3 *2) (-12 (-5 *2 (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-2450 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) (-2496 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-638 (-258))) (-5 *1 (-256))))) 
-(-10 -7 (-15 -2496 ((-121) (-638 (-258)) (-121))) (-15 -2450 ((-121) (-638 (-258)) (-121))) (-15 -2469 ((-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))) (-638 (-258)) (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))))) (-15 -3493 ((-1152) (-638 (-258)) (-1152))) (-15 -3912 ((-1152) (-638 (-258)) (-1152))) (-15 -4260 ((-121) (-638 (-258)) (-121))) (-15 -1291 ((-875) (-638 (-258)) (-875))) (-15 -2815 ((-875) (-638 (-258)) (-875))) (-15 -1588 ((-638 (-1092 (-385))) (-638 (-258)) (-638 (-1092 (-385))))) (-15 -2249 ((-923) (-638 (-258)) (-923))) (-15 -2817 ((-923) (-638 (-258)) (-923))) (-15 -3022 ((-1129 (-217)) (-638 (-258)))) (-15 -2163 ((-923) (-638 (-258)) (-923))) (-15 -3691 ((-385) (-638 (-258)) (-385))) (-15 -2720 ((-1 (-950 (-217)) (-950 (-217))) (-638 (-258)) (-1 (-950 (-217)) (-950 (-217))))) (-15 -1810 ((-638 (-385)) (-638 (-258)) (-638 (-385))))) 
-((-2890 (((-3 |#1| "failed") (-638 (-258)) (-1170)) 17))) 
-(((-257 |#1|) (-10 -7 (-15 -2890 ((-3 |#1| "failed") (-638 (-258)) (-1170)))) (-1204)) (T -257)) 
-((-2890 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-638 (-258))) (-5 *4 (-1170)) (-5 *1 (-257 *2)) (-4 *2 (-1204))))) 
-(-10 -7 (-15 -2890 ((-3 |#1| "failed") (-638 (-258)) (-1170)))) 
-((-2262 (((-121) $ $) NIL)) (-2469 (($ (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) 14)) (-2817 (($ (-923)) 70)) (-2249 (($ (-923)) 69)) (-3029 (($ (-638 (-385))) 76)) (-3691 (($ (-385)) 55)) (-2163 (($ (-923)) 71)) (-4260 (($ (-121)) 22)) (-3493 (($ (-1152)) 17)) (-3912 (($ (-1152)) 18)) (-3022 (($ (-1129 (-217))) 65)) (-1588 (($ (-638 (-1092 (-385)))) 61)) (-1441 (($ (-638 (-1092 (-385)))) 56) (($ (-638 (-1092 (-413 (-572))))) 60)) (-1870 (($ (-385)) 28) (($ (-875)) 32)) (-3070 (((-121) (-638 $) (-1170)) 85)) (-2890 (((-3 (-57) "failed") (-638 $) (-1170)) 87)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4003 (($ (-385)) 33) (($ (-875)) 34)) (-3160 (($ (-1 (-950 (-217)) (-950 (-217)))) 54)) (-2720 (($ (-1 (-950 (-217)) (-950 (-217)))) 72)) (-3671 (($ (-1 (-217) (-217))) 38) (($ (-1 (-217) (-217) (-217))) 42) (($ (-1 (-217) (-217) (-217) (-217))) 46)) (-3972 (((-856) $) 81)) (-3439 (($ (-121)) 23) (($ (-638 (-1092 (-385)))) 50)) (-2496 (($ (-121)) 24)) (-1324 (((-121) $ $) 83))) 
-(((-258) (-13 (-1098) (-10 -8 (-15 -2496 ($ (-121))) (-15 -3439 ($ (-121))) (-15 -2469 ($ (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))))) (-15 -3493 ($ (-1152))) (-15 -3912 ($ (-1152))) (-15 -4260 ($ (-121))) (-15 -3439 ($ (-638 (-1092 (-385))))) (-15 -3160 ($ (-1 (-950 (-217)) (-950 (-217))))) (-15 -1870 ($ (-385))) (-15 -1870 ($ (-875))) (-15 -4003 ($ (-385))) (-15 -4003 ($ (-875))) (-15 -3671 ($ (-1 (-217) (-217)))) (-15 -3671 ($ (-1 (-217) (-217) (-217)))) (-15 -3671 ($ (-1 (-217) (-217) (-217) (-217)))) (-15 -3691 ($ (-385))) (-15 -1441 ($ (-638 (-1092 (-385))))) (-15 -1441 ($ (-638 (-1092 (-413 (-572)))))) (-15 -1588 ($ (-638 (-1092 (-385))))) (-15 -3022 ($ (-1129 (-217)))) (-15 -2249 ($ (-923))) (-15 -2817 ($ (-923))) (-15 -2163 ($ (-923))) (-15 -2720 ($ (-1 (-950 (-217)) (-950 (-217))))) (-15 -3029 ($ (-638 (-385)))) (-15 -2890 ((-3 (-57) "failed") (-638 $) (-1170))) (-15 -3070 ((-121) (-638 $) (-1170)))))) (T -258)) 
-((-2496 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-258)))) (-3439 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-258)))) (-2469 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) (-5 *1 (-258)))) (-3493 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-258)))) (-3912 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-258)))) (-4260 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-258)))) (-3439 (*1 *1 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-258)))) (-3160 (*1 *1 *2) (-12 (-5 *2 (-1 (-950 (-217)) (-950 (-217)))) (-5 *1 (-258)))) (-1870 (*1 *1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-258)))) (-1870 (*1 *1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-258)))) (-4003 (*1 *1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-258)))) (-4003 (*1 *1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-258)))) (-3671 (*1 *1 *2) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *1 (-258)))) (-3671 (*1 *1 *2) (-12 (-5 *2 (-1 (-217) (-217) (-217))) (-5 *1 (-258)))) (-3671 (*1 *1 *2) (-12 (-5 *2 (-1 (-217) (-217) (-217) (-217))) (-5 *1 (-258)))) (-3691 (*1 *1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-258)))) (-1441 (*1 *1 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-258)))) (-1441 (*1 *1 *2) (-12 (-5 *2 (-638 (-1092 (-413 (-572))))) (-5 *1 (-258)))) (-1588 (*1 *1 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-258)))) (-3022 (*1 *1 *2) (-12 (-5 *2 (-1129 (-217))) (-5 *1 (-258)))) (-2249 (*1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-258)))) (-2817 (*1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-258)))) (-2163 (*1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-258)))) (-2720 (*1 *1 *2) (-12 (-5 *2 (-1 (-950 (-217)) (-950 (-217)))) (-5 *1 (-258)))) (-3029 (*1 *1 *2) (-12 (-5 *2 (-638 (-385))) (-5 *1 (-258)))) (-2890 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-638 (-258))) (-5 *4 (-1170)) (-5 *2 (-57)) (-5 *1 (-258)))) (-3070 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-258))) (-5 *4 (-1170)) (-5 *2 (-121)) (-5 *1 (-258))))) 
-(-13 (-1098) (-10 -8 (-15 -2496 ($ (-121))) (-15 -3439 ($ (-121))) (-15 -2469 ($ (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))))) (-15 -3493 ($ (-1152))) (-15 -3912 ($ (-1152))) (-15 -4260 ($ (-121))) (-15 -3439 ($ (-638 (-1092 (-385))))) (-15 -3160 ($ (-1 (-950 (-217)) (-950 (-217))))) (-15 -1870 ($ (-385))) (-15 -1870 ($ (-875))) (-15 -4003 ($ (-385))) (-15 -4003 ($ (-875))) (-15 -3671 ($ (-1 (-217) (-217)))) (-15 -3671 ($ (-1 (-217) (-217) (-217)))) (-15 -3671 ($ (-1 (-217) (-217) (-217) (-217)))) (-15 -3691 ($ (-385))) (-15 -1441 ($ (-638 (-1092 (-385))))) (-15 -1441 ($ (-638 (-1092 (-413 (-572)))))) (-15 -1588 ($ (-638 (-1092 (-385))))) (-15 -3022 ($ (-1129 (-217)))) (-15 -2249 ($ (-923))) (-15 -2817 ($ (-923))) (-15 -2163 ($ (-923))) (-15 -2720 ($ (-1 (-950 (-217)) (-950 (-217))))) (-15 -3029 ($ (-638 (-385)))) (-15 -2890 ((-3 (-57) "failed") (-638 $) (-1170))) (-15 -3070 ((-121) (-638 $) (-1170))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2923 (((-638 (-769)) $) NIL) (((-638 (-769)) $ |#2|) NIL)) (-3073 (((-769) $) NIL) (((-769) $ |#2|) NIL)) (-3456 (((-638 |#3|) $) NIL)) (-4297 (((-1166 $) $ |#3|) NIL) (((-1166 |#1|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 |#3|)) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4048 (($ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 |#3| "failed") $) NIL) (((-3 |#2| "failed") $) NIL) (((-3 (-1121 |#1| |#2|) "failed") $) 20)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) ((|#3| $) NIL) ((|#2| $) NIL) (((-1121 |#1| |#2|) $) NIL)) (-3190 (($ $ $ |#3|) NIL (|has| |#1| (-174)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ |#3|) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-538 |#3|) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| |#1| (-887 (-385))) (|has| |#3| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| |#1| (-887 (-572))) (|has| |#3| (-887 (-572)))))) (-3377 (((-769) $ |#2|) NIL) (((-769) $) 10)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-4335 (($ (-1166 |#1|) |#3|) NIL) (($ (-1166 $) |#3|) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-538 |#3|)) NIL) (($ $ |#3| (-769)) NIL) (($ $ (-638 |#3|) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ |#3|) NIL)) (-1784 (((-538 |#3|) $) NIL) (((-769) $ |#3|) NIL) (((-638 (-769)) $ (-638 |#3|)) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-538 |#3|) (-538 |#3|)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3101 (((-1 $ (-769)) |#2|) NIL) (((-1 $ (-769)) $) NIL (|has| |#1| (-227)))) (-1470 (((-3 |#3| "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-4021 ((|#3| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-3815 (((-121) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| |#3|) (|:| -3751 (-769))) "failed") $) NIL)) (-2106 (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ |#3| |#1|) NIL) (($ $ (-638 |#3|) (-638 |#1|)) NIL) (($ $ |#3| $) NIL) (($ $ (-638 |#3|) (-638 $)) NIL) (($ $ |#2| $) NIL (|has| |#1| (-227))) (($ $ (-638 |#2|) (-638 $)) NIL (|has| |#1| (-227))) (($ $ |#2| |#1|) NIL (|has| |#1| (-227))) (($ $ (-638 |#2|) (-638 |#1|)) NIL (|has| |#1| (-227)))) (-2119 (($ $ |#3|) NIL (|has| |#1| (-174)))) (-3139 (($ $ |#3|) NIL) (($ $ (-638 |#3|)) NIL) (($ $ |#3| (-769)) NIL) (($ $ (-638 |#3|) (-638 (-769))) NIL) (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2866 (((-638 |#2|) $) NIL)) (-4316 (((-538 |#3|) $) NIL) (((-769) $ |#3|) NIL) (((-638 (-769)) $ (-638 |#3|)) NIL) (((-769) $ |#2|) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#3| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#3| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| |#1| (-613 (-545))) (|has| |#3| (-613 (-545)))))) (-3694 ((|#1| $) NIL (|has| |#1| (-457))) (($ $ |#3|) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) 23) (($ |#3|) 22) (($ |#2|) NIL) (($ (-1121 |#1| |#2|)) 28) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-538 |#3|)) NIL) (($ $ |#3| (-769)) NIL) (($ $ (-638 |#3|) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ |#3|) NIL) (($ $ (-638 |#3|)) NIL) (($ $ |#3| (-769)) NIL) (($ $ (-638 |#3|) (-638 (-769))) NIL) (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-259 |#1| |#2| |#3|) (-13 (-248 |#1| |#2| |#3| (-538 |#3|)) (-1044 (-1121 |#1| |#2|))) (-1054) (-848) (-264 |#2|)) (T -259)) 
-NIL 
-(-13 (-248 |#1| |#2| |#3| (-538 |#3|)) (-1044 (-1121 |#1| |#2|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-4565 (($ |#1| (-638 $)) 51) (($ |#1|) 50) (($ (-638 |#1|)) 49)) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-2211 (($) 7 T CONST)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44)) (-3537 (((-572) $ $) 41)) (-1791 (((-121) $) 43)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-260 |#1|) (-1290) (-1098)) (T -260)) 
-((-4565 (*1 *1 *2 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-260 *2)) (-4 *2 (-1098)))) (-4565 (*1 *1 *2) (-12 (-4 *1 (-260 *2)) (-4 *2 (-1098)))) (-4565 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-260 *3))))) 
-(-13 (-1017 |t#1|) (-10 -8 (-6 -4603) (-6 -4602) (-15 -4565 ($ |t#1| (-638 $))) (-15 -4565 ($ |t#1|)) (-15 -4565 ($ (-638 |t#1|))))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1017 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) 12)) (-4565 (($ |#1| (-638 $)) 31) (($ |#1|) 32) (($ (-638 |#1|)) 33)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) 35 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 34 (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-2699 (((-638 |#1|) $) 22)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1647 (((-121) (-121)) 18) (((-121)) 19)) (-1702 (((-856) $) 15)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-2270 (((-1152) $) 28)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ "value") NIL)) (-3537 (((-572) $ $) NIL)) (-1791 (((-121) $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-856) $) 30 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 8)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 26 (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-261 |#1|) (-13 (-260 |#1|) (-10 -8 (-15 -2270 ((-1152) $)) (-15 -1702 ((-856) $)) (-15 -1647 ((-121) (-121))) (-15 -1647 ((-121))))) (-1098)) (T -261)) 
-((-2270 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-261 *3)) (-4 *3 (-1098)))) (-1702 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-261 *3)) (-4 *3 (-1098)))) (-1647 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-261 *3)) (-4 *3 (-1098)))) (-1647 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-261 *3)) (-4 *3 (-1098))))) 
-(-13 (-260 |#1|) (-10 -8 (-15 -2270 ((-1152) $)) (-15 -1702 ((-856) $)) (-15 -1647 ((-121) (-121))) (-15 -1647 ((-121))))) 
-((-2456 (((-1264) |#10| (-638 |#3|)) 133) (((-1264) |#10|) 135)) (-3140 (((-1264) |#10|) NIL)) (-3652 ((|#8| |#10|) 28)) (-4495 (((-572) (-769) (-638 |#10|)) 147)) (-2658 (((-769) (-769) (-638 |#10|)) 145)) (-1639 (((-572) |#3|) 148)) (-1774 (((-769) |#3|) 146)) (-3837 (((-1264) |#10|) 136)) (-2288 ((|#8| |#3| |#10|) 111)) (-4493 ((|#10| |#5| |#3|) 138)) (-3548 (((-638 |#10|) |#3|) 144)) (-2790 (((-1264) |#10|) 134)) (-2086 (((-638 |#9|) |#9|) 87)) (-4457 ((|#8| |#10|) 110))) 
-(((-262 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -2086 ((-638 |#9|) |#9|)) (-15 -2288 (|#8| |#3| |#10|)) (-15 -4457 (|#8| |#10|)) (-15 -2790 ((-1264) |#10|)) (-15 -4493 (|#10| |#5| |#3|)) (-15 -3548 ((-638 |#10|) |#3|)) (-15 -3837 ((-1264) |#10|)) (-15 -3140 ((-1264) |#10|)) (-15 -2456 ((-1264) |#10|)) (-15 -2456 ((-1264) |#10| (-638 |#3|))) (-15 -1774 ((-769) |#3|)) (-15 -1639 ((-572) |#3|)) (-15 -2658 ((-769) (-769) (-638 |#10|))) (-15 -3652 (|#8| |#10|)) (-15 -4495 ((-572) (-769) (-638 |#10|)))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|) (-645 |#1|) (-926 |#1| |#6|) (-237 |#7|) (-540 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-260 |#9|) (-117)) (T -262)) 
-((-4495 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *14)) (-4 *14 (-260 *13)) (-4 *13 (-540 *5 *6 *7 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) *3)) (-4 *9 (-978 *5)) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-4 *12 (-237 *11)) (-5 *3 (-769)) (-5 *2 (-572)) (-5 *1 (-262 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15)))) (-3652 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-540 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *10)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-260 *11)))) (-2658 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *13)) (-4 *13 (-260 *12)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) *2)) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-5 *2 (-769)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)))) (-1639 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-572)) (-5 *1 (-262 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-1774 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) *2)) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-769)) (-5 *1 (-262 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-2456 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *7)) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) (-769))) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *9 (-978 *5)) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-4 *12 (-237 *11)) (-4 *13 (-540 *5 *6 *7 *8 *9 *10 *11 *12 *14)) (-4 *14 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (-4 *3 (-260 *13)))) (-2456 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-260 *12)))) (-3140 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-260 *12)))) (-3837 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-260 *12)))) (-3548 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *12)) (-5 *1 (-262 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-4493 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *4 (-956 *5 *7 (-858 *6))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *3 (-978 *5)) (-4 *8 (-645 *5)) (-4 *9 (-926 *5 *8)) (-4 *10 (-237 *9)) (-4 *12 (-117)) (-4 *2 (-260 *11)) (-5 *1 (-262 *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (-4 *11 (-540 *5 *6 *4 *7 *3 *8 *9 *10 *12)))) (-2790 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-260 *12)))) (-4457 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-540 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *10)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-260 *11)))) (-2288 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *8 (-978 *5)) (-4 *9 (-645 *5)) (-4 *10 (-926 *5 *9)) (-4 *11 (-540 *5 *6 *3 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *10)) (-5 *1 (-262 *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (-4 *4 (-260 *11)))) (-2086 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *3 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-638 *3)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (-4 *12 (-260 *3))))) 
-(-10 -7 (-15 -2086 ((-638 |#9|) |#9|)) (-15 -2288 (|#8| |#3| |#10|)) (-15 -4457 (|#8| |#10|)) (-15 -2790 ((-1264) |#10|)) (-15 -4493 (|#10| |#5| |#3|)) (-15 -3548 ((-638 |#10|) |#3|)) (-15 -3837 ((-1264) |#10|)) (-15 -3140 ((-1264) |#10|)) (-15 -2456 ((-1264) |#10|)) (-15 -2456 ((-1264) |#10| (-638 |#3|))) (-15 -1774 ((-769) |#3|)) (-15 -1639 ((-572) |#3|)) (-15 -2658 ((-769) (-769) (-638 |#10|))) (-15 -3652 (|#8| |#10|)) (-15 -4495 ((-572) (-769) (-638 |#10|)))) 
-((-3073 (((-769) $) 30)) (-3376 (((-3 |#2| "failed") $) 17)) (-1318 ((|#2| $) 27)) (-3139 (($ $) 12) (($ $ (-769)) 15)) (-3972 (((-856) $) 26) (($ |#2|) 10)) (-1324 (((-121) $ $) 20)) (-1334 (((-121) $ $) 29))) 
-(((-263 |#1| |#2|) (-10 -8 (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1|)) (-15 -3073 ((-769) |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) (-264 |#2|) (-848)) (T -263)) 
-NIL 
-(-10 -8 (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1|)) (-15 -3073 ((-769) |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-3073 (((-769) $) 21)) (-3342 ((|#1| $) 22)) (-3376 (((-3 |#1| "failed") $) 26)) (-1318 ((|#1| $) 25)) (-3377 (((-769) $) 23)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-3101 (($ |#1| (-769)) 24)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3139 (($ $) 20) (($ $ (-769)) 19)) (-3972 (((-856) $) 11) (($ |#1|) 27)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17))) 
-(((-264 |#1|) (-1290) (-848)) (T -264)) 
-((-3972 (*1 *1 *2) (-12 (-4 *1 (-264 *2)) (-4 *2 (-848)))) (-3101 (*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-264 *2)) (-4 *2 (-848)))) (-3377 (*1 *2 *1) (-12 (-4 *1 (-264 *3)) (-4 *3 (-848)) (-5 *2 (-769)))) (-3342 (*1 *2 *1) (-12 (-4 *1 (-264 *2)) (-4 *2 (-848)))) (-3073 (*1 *2 *1) (-12 (-4 *1 (-264 *3)) (-4 *3 (-848)) (-5 *2 (-769)))) (-3139 (*1 *1 *1) (-12 (-4 *1 (-264 *2)) (-4 *2 (-848)))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-264 *3)) (-4 *3 (-848))))) 
-(-13 (-848) (-1044 |t#1|) (-10 -8 (-15 -3101 ($ |t#1| (-769))) (-15 -3377 ((-769) $)) (-15 -3342 (|t#1| $)) (-15 -3073 ((-769) $)) (-15 -3139 ($ $)) (-15 -3139 ($ $ (-769))) (-15 -3972 ($ |t#1|)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-848) . T) ((-1044 |#1|) . T) ((-1098) . T)) 
-((-3456 (((-638 (-1170)) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 40)) (-2199 (((-638 (-1170)) (-312 (-217)) (-769)) 79)) (-3435 (((-3 (-312 (-217)) "failed") (-312 (-217))) 50)) (-3761 (((-312 (-217)) (-312 (-217))) 65)) (-4418 (((-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 26)) (-2717 (((-121) (-638 (-312 (-217)))) 83)) (-3545 (((-121) (-312 (-217))) 24)) (-2244 (((-638 (-1152)) (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))) 104)) (-1421 (((-638 (-312 (-217))) (-638 (-312 (-217)))) 86)) (-1328 (((-638 (-312 (-217))) (-638 (-312 (-217)))) 85)) (-3945 (((-685 (-217)) (-638 (-312 (-217))) (-769)) 93)) (-3812 (((-121) (-312 (-217))) 20) (((-121) (-638 (-312 (-217)))) 84)) (-4106 (((-638 (-217)) (-638 (-841 (-217))) (-217)) 14)) (-2477 (((-385) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 99)) (-2902 (((-1042) (-1170) (-1042)) 33))) 
-(((-265) (-10 -7 (-15 -4106 ((-638 (-217)) (-638 (-841 (-217))) (-217))) (-15 -4418 ((-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))))) (-15 -3435 ((-3 (-312 (-217)) "failed") (-312 (-217)))) (-15 -3761 ((-312 (-217)) (-312 (-217)))) (-15 -2717 ((-121) (-638 (-312 (-217))))) (-15 -3812 ((-121) (-638 (-312 (-217))))) (-15 -3812 ((-121) (-312 (-217)))) (-15 -3945 ((-685 (-217)) (-638 (-312 (-217))) (-769))) (-15 -1328 ((-638 (-312 (-217))) (-638 (-312 (-217))))) (-15 -1421 ((-638 (-312 (-217))) (-638 (-312 (-217))))) (-15 -3545 ((-121) (-312 (-217)))) (-15 -3456 ((-638 (-1170)) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) (-15 -2199 ((-638 (-1170)) (-312 (-217)) (-769))) (-15 -2902 ((-1042) (-1170) (-1042))) (-15 -2477 ((-385) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) (-15 -2244 ((-638 (-1152)) (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))))))) (T -265)) 
-((-2244 (*1 *2 *3) (-12 (-5 *3 (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))) (-5 *2 (-638 (-1152))) (-5 *1 (-265)))) (-2477 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *2 (-385)) (-5 *1 (-265)))) (-2902 (*1 *2 *3 *2) (-12 (-5 *2 (-1042)) (-5 *3 (-1170)) (-5 *1 (-265)))) (-2199 (*1 *2 *3 *4) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-769)) (-5 *2 (-638 (-1170))) (-5 *1 (-265)))) (-3456 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *2 (-638 (-1170))) (-5 *1 (-265)))) (-3545 (*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-121)) (-5 *1 (-265)))) (-1421 (*1 *2 *2) (-12 (-5 *2 (-638 (-312 (-217)))) (-5 *1 (-265)))) (-1328 (*1 *2 *2) (-12 (-5 *2 (-638 (-312 (-217)))) (-5 *1 (-265)))) (-3945 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-312 (-217)))) (-5 *4 (-769)) (-5 *2 (-685 (-217))) (-5 *1 (-265)))) (-3812 (*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-121)) (-5 *1 (-265)))) (-3812 (*1 *2 *3) (-12 (-5 *3 (-638 (-312 (-217)))) (-5 *2 (-121)) (-5 *1 (-265)))) (-2717 (*1 *2 *3) (-12 (-5 *3 (-638 (-312 (-217)))) (-5 *2 (-121)) (-5 *1 (-265)))) (-3761 (*1 *2 *2) (-12 (-5 *2 (-312 (-217))) (-5 *1 (-265)))) (-3435 (*1 *2 *2) (|partial| -12 (-5 *2 (-312 (-217))) (-5 *1 (-265)))) (-4418 (*1 *2 *2) (-12 (-5 *2 (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (-5 *1 (-265)))) (-4106 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-841 (-217)))) (-5 *4 (-217)) (-5 *2 (-638 *4)) (-5 *1 (-265))))) 
-(-10 -7 (-15 -4106 ((-638 (-217)) (-638 (-841 (-217))) (-217))) (-15 -4418 ((-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))))) (-15 -3435 ((-3 (-312 (-217)) "failed") (-312 (-217)))) (-15 -3761 ((-312 (-217)) (-312 (-217)))) (-15 -2717 ((-121) (-638 (-312 (-217))))) (-15 -3812 ((-121) (-638 (-312 (-217))))) (-15 -3812 ((-121) (-312 (-217)))) (-15 -3945 ((-685 (-217)) (-638 (-312 (-217))) (-769))) (-15 -1328 ((-638 (-312 (-217))) (-638 (-312 (-217))))) (-15 -1421 ((-638 (-312 (-217))) (-638 (-312 (-217))))) (-15 -3545 ((-121) (-312 (-217)))) (-15 -3456 ((-638 (-1170)) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) (-15 -2199 ((-638 (-1170)) (-312 (-217)) (-769))) (-15 -2902 ((-1042) (-1170) (-1042))) (-15 -2477 ((-385) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) (-15 -2244 ((-638 (-1152)) (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))))) 
-((-2262 (((-121) $ $) NIL)) (-3690 (((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 39)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 20) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-266) (-837)) (T -266)) 
-NIL 
-(-837) 
-((-2262 (((-121) $ $) NIL)) (-3690 (((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 54) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 49)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 29) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 31)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-267) (-837)) (T -267)) 
-NIL 
-(-837) 
-((-2262 (((-121) $ $) NIL)) (-3690 (((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 73) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 69)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 40) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 51)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-268) (-837)) (T -268)) 
-NIL 
-(-837) 
-((-2262 (((-121) $ $) NIL)) (-3690 (((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 48)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 27) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-269) (-837)) (T -269)) 
-NIL 
-(-837) 
-((-2262 (((-121) $ $) NIL)) (-3690 (((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 48)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 23) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-270) (-837)) (T -270)) 
-NIL 
-(-837) 
-((-2262 (((-121) $ $) NIL)) (-3690 (((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 69)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 23) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-271) (-837)) (T -271)) 
-NIL 
-(-837) 
-((-2262 (((-121) $ $) NIL)) (-3690 (((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 73)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 19) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-272) (-837)) (T -272)) 
-NIL 
-(-837) 
-((-2262 (((-121) $ $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3414 (((-638 (-572)) $) 16)) (-4316 (((-769) $) 14)) (-3972 (((-856) $) 20) (($ (-638 (-572))) 12)) (-1899 (($ (-769)) 17)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 9)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 10))) 
-(((-273) (-13 (-848) (-10 -8 (-15 -3972 ($ (-638 (-572)))) (-15 -4316 ((-769) $)) (-15 -3414 ((-638 (-572)) $)) (-15 -1899 ($ (-769)))))) (T -273)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-273)))) (-4316 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-273)))) (-3414 (*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-273)))) (-1899 (*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-273))))) 
-(-13 (-848) (-10 -8 (-15 -3972 ($ (-638 (-572)))) (-15 -4316 ((-769) $)) (-15 -3414 ((-638 (-572)) $)) (-15 -1899 ($ (-769))))) 
-((-4284 ((|#2| |#2|) 77)) (-4224 ((|#2| |#2|) 65)) (-2251 (((-3 |#2| "failed") |#2| (-638 (-2 (|:| |func| |#2|) (|:| |pole| (-121))))) 116)) (-4273 ((|#2| |#2|) 75)) (-4217 ((|#2| |#2|) 63)) (-4295 ((|#2| |#2|) 79)) (-4233 ((|#2| |#2|) 67)) (-4184 ((|#2|) 46)) (-4564 (((-123) (-123)) 95)) (-3539 ((|#2| |#2|) 61)) (-4454 (((-121) |#2|) 134)) (-4182 ((|#2| |#2|) 180)) (-2732 ((|#2| |#2|) 156)) (-4097 ((|#2|) 59)) (-3543 ((|#2|) 58)) (-2294 ((|#2| |#2|) 176)) (-4290 ((|#2| |#2|) 152)) (-3929 ((|#2| |#2|) 184)) (-4292 ((|#2| |#2|) 160)) (-2441 ((|#2| |#2|) 148)) (-2666 ((|#2| |#2|) 150)) (-3004 ((|#2| |#2|) 186)) (-4158 ((|#2| |#2|) 162)) (-4376 ((|#2| |#2|) 182)) (-4576 ((|#2| |#2|) 158)) (-1385 ((|#2| |#2|) 178)) (-1733 ((|#2| |#2|) 154)) (-3844 ((|#2| |#2|) 192)) (-3619 ((|#2| |#2|) 168)) (-2486 ((|#2| |#2|) 188)) (-2289 ((|#2| |#2|) 164)) (-1390 ((|#2| |#2|) 196)) (-4361 ((|#2| |#2|) 172)) (-1962 ((|#2| |#2|) 198)) (-3055 ((|#2| |#2|) 174)) (-4189 ((|#2| |#2|) 194)) (-2778 ((|#2| |#2|) 170)) (-4553 ((|#2| |#2|) 190)) (-3340 ((|#2| |#2|) 166)) (-4179 ((|#2| |#2|) 62)) (-4302 ((|#2| |#2|) 80)) (-4237 ((|#2| |#2|) 68)) (-4289 ((|#2| |#2|) 78)) (-4228 ((|#2| |#2|) 66)) (-4278 ((|#2| |#2|) 76)) (-4220 ((|#2| |#2|) 64)) (-3228 (((-121) (-123)) 93)) (-4321 ((|#2| |#2|) 83)) (-4251 ((|#2| |#2|) 71)) (-4308 ((|#2| |#2|) 81)) (-4241 ((|#2| |#2|) 69)) (-4333 ((|#2| |#2|) 85)) (-4263 ((|#2| |#2|) 73)) (-2104 ((|#2| |#2|) 86)) (-4268 ((|#2| |#2|) 74)) (-4327 ((|#2| |#2|) 84)) (-4257 ((|#2| |#2|) 72)) (-4314 ((|#2| |#2|) 82)) (-4246 ((|#2| |#2|) 70))) 
-(((-274 |#1| |#2|) (-10 -7 (-15 -4179 (|#2| |#2|)) (-15 -3539 (|#2| |#2|)) (-15 -4217 (|#2| |#2|)) (-15 -4220 (|#2| |#2|)) (-15 -4224 (|#2| |#2|)) (-15 -4228 (|#2| |#2|)) (-15 -4233 (|#2| |#2|)) (-15 -4237 (|#2| |#2|)) (-15 -4241 (|#2| |#2|)) (-15 -4246 (|#2| |#2|)) (-15 -4251 (|#2| |#2|)) (-15 -4257 (|#2| |#2|)) (-15 -4263 (|#2| |#2|)) (-15 -4268 (|#2| |#2|)) (-15 -4273 (|#2| |#2|)) (-15 -4278 (|#2| |#2|)) (-15 -4284 (|#2| |#2|)) (-15 -4289 (|#2| |#2|)) (-15 -4295 (|#2| |#2|)) (-15 -4302 (|#2| |#2|)) (-15 -4308 (|#2| |#2|)) (-15 -4314 (|#2| |#2|)) (-15 -4321 (|#2| |#2|)) (-15 -4327 (|#2| |#2|)) (-15 -4333 (|#2| |#2|)) (-15 -2104 (|#2| |#2|)) (-15 -4184 (|#2|)) (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -3543 (|#2|)) (-15 -4097 (|#2|)) (-15 -2666 (|#2| |#2|)) (-15 -2441 (|#2| |#2|)) (-15 -4290 (|#2| |#2|)) (-15 -1733 (|#2| |#2|)) (-15 -2732 (|#2| |#2|)) (-15 -4576 (|#2| |#2|)) (-15 -4292 (|#2| |#2|)) (-15 -4158 (|#2| |#2|)) (-15 -2289 (|#2| |#2|)) (-15 -3340 (|#2| |#2|)) (-15 -3619 (|#2| |#2|)) (-15 -2778 (|#2| |#2|)) (-15 -4361 (|#2| |#2|)) (-15 -3055 (|#2| |#2|)) (-15 -2294 (|#2| |#2|)) (-15 -1385 (|#2| |#2|)) (-15 -4182 (|#2| |#2|)) (-15 -4376 (|#2| |#2|)) (-15 -3929 (|#2| |#2|)) (-15 -3004 (|#2| |#2|)) (-15 -2486 (|#2| |#2|)) (-15 -4553 (|#2| |#2|)) (-15 -3844 (|#2| |#2|)) (-15 -4189 (|#2| |#2|)) (-15 -1390 (|#2| |#2|)) (-15 -1962 (|#2| |#2|)) (-15 -2251 ((-3 |#2| "failed") |#2| (-638 (-2 (|:| |func| |#2|) (|:| |pole| (-121)))))) (-15 -4454 ((-121) |#2|))) (-13 (-848) (-562)) (-13 (-436 |#1|) (-1009))) (T -274)) 
-((-4454 (*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-274 *4 *3)) (-4 *3 (-13 (-436 *4) (-1009))))) (-2251 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-638 (-2 (|:| |func| *2) (|:| |pole| (-121))))) (-4 *2 (-13 (-436 *4) (-1009))) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-274 *4 *2)))) (-1962 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-1390 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4189 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-3844 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4553 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-2486 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-3004 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-3929 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4376 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4182 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-1385 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-2294 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-3055 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4361 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-2778 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-3619 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-3340 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-2289 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4158 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4292 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4576 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-2732 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-1733 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4290 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-2441 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-2666 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4097 (*1 *2) (-12 (-4 *2 (-13 (-436 *3) (-1009))) (-5 *1 (-274 *3 *2)) (-4 *3 (-13 (-848) (-562))))) (-3543 (*1 *2) (-12 (-4 *2 (-13 (-436 *3) (-1009))) (-5 *1 (-274 *3 *2)) (-4 *3 (-13 (-848) (-562))))) (-4564 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *4)) (-4 *4 (-13 (-436 *3) (-1009))))) (-3228 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-274 *4 *5)) (-4 *5 (-13 (-436 *4) (-1009))))) (-4184 (*1 *2) (-12 (-4 *2 (-13 (-436 *3) (-1009))) (-5 *1 (-274 *3 *2)) (-4 *3 (-13 (-848) (-562))))) (-2104 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4333 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4327 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4321 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4314 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4308 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4302 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4295 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4289 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4284 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4278 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4273 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4268 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4263 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4257 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4251 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4246 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4241 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4237 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4233 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4228 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4224 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4220 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4217 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-3539 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) (-4179 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(-10 -7 (-15 -4179 (|#2| |#2|)) (-15 -3539 (|#2| |#2|)) (-15 -4217 (|#2| |#2|)) (-15 -4220 (|#2| |#2|)) (-15 -4224 (|#2| |#2|)) (-15 -4228 (|#2| |#2|)) (-15 -4233 (|#2| |#2|)) (-15 -4237 (|#2| |#2|)) (-15 -4241 (|#2| |#2|)) (-15 -4246 (|#2| |#2|)) (-15 -4251 (|#2| |#2|)) (-15 -4257 (|#2| |#2|)) (-15 -4263 (|#2| |#2|)) (-15 -4268 (|#2| |#2|)) (-15 -4273 (|#2| |#2|)) (-15 -4278 (|#2| |#2|)) (-15 -4284 (|#2| |#2|)) (-15 -4289 (|#2| |#2|)) (-15 -4295 (|#2| |#2|)) (-15 -4302 (|#2| |#2|)) (-15 -4308 (|#2| |#2|)) (-15 -4314 (|#2| |#2|)) (-15 -4321 (|#2| |#2|)) (-15 -4327 (|#2| |#2|)) (-15 -4333 (|#2| |#2|)) (-15 -2104 (|#2| |#2|)) (-15 -4184 (|#2|)) (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -3543 (|#2|)) (-15 -4097 (|#2|)) (-15 -2666 (|#2| |#2|)) (-15 -2441 (|#2| |#2|)) (-15 -4290 (|#2| |#2|)) (-15 -1733 (|#2| |#2|)) (-15 -2732 (|#2| |#2|)) (-15 -4576 (|#2| |#2|)) (-15 -4292 (|#2| |#2|)) (-15 -4158 (|#2| |#2|)) (-15 -2289 (|#2| |#2|)) (-15 -3340 (|#2| |#2|)) (-15 -3619 (|#2| |#2|)) (-15 -2778 (|#2| |#2|)) (-15 -4361 (|#2| |#2|)) (-15 -3055 (|#2| |#2|)) (-15 -2294 (|#2| |#2|)) (-15 -1385 (|#2| |#2|)) (-15 -4182 (|#2| |#2|)) (-15 -4376 (|#2| |#2|)) (-15 -3929 (|#2| |#2|)) (-15 -3004 (|#2| |#2|)) (-15 -2486 (|#2| |#2|)) (-15 -4553 (|#2| |#2|)) (-15 -3844 (|#2| |#2|)) (-15 -4189 (|#2| |#2|)) (-15 -1390 (|#2| |#2|)) (-15 -1962 (|#2| |#2|)) (-15 -2251 ((-3 |#2| "failed") |#2| (-638 (-2 (|:| |func| |#2|) (|:| |pole| (-121)))))) (-15 -4454 ((-121) |#2|))) 
-((-2487 (((-3 |#2| "failed") (-638 (-611 |#2|)) |#2| (-1170)) 133)) (-4450 ((|#2| (-413 (-572)) |#2|) 50)) (-2311 ((|#2| |#2| (-611 |#2|)) 126)) (-1829 (((-2 (|:| |func| |#2|) (|:| |kers| (-638 (-611 |#2|))) (|:| |vals| (-638 |#2|))) |#2| (-1170)) 125)) (-2250 ((|#2| |#2| (-1170)) 19) ((|#2| |#2|) 22)) (-3985 ((|#2| |#2| (-1170)) 139) ((|#2| |#2|) 137))) 
-(((-275 |#1| |#2|) (-10 -7 (-15 -3985 (|#2| |#2|)) (-15 -3985 (|#2| |#2| (-1170))) (-15 -1829 ((-2 (|:| |func| |#2|) (|:| |kers| (-638 (-611 |#2|))) (|:| |vals| (-638 |#2|))) |#2| (-1170))) (-15 -2250 (|#2| |#2|)) (-15 -2250 (|#2| |#2| (-1170))) (-15 -2487 ((-3 |#2| "failed") (-638 (-611 |#2|)) |#2| (-1170))) (-15 -2311 (|#2| |#2| (-611 |#2|))) (-15 -4450 (|#2| (-413 (-572)) |#2|))) (-13 (-562) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|))) (T -275)) 
-((-4450 (*1 *2 *3 *2) (-12 (-5 *3 (-413 (-572))) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))))) (-2311 (*1 *2 *2 *3) (-12 (-5 *3 (-611 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *4 *2)))) (-2487 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-638 (-611 *2))) (-5 *4 (-1170)) (-4 *2 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *5 *2)))) (-2250 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))))) (-2250 (*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) (-1829 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-2 (|:| |func| *3) (|:| |kers| (-638 (-611 *3))) (|:| |vals| (-638 *3)))) (-5 *1 (-275 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-3985 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))))) (-3985 (*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3)))))) 
-(-10 -7 (-15 -3985 (|#2| |#2|)) (-15 -3985 (|#2| |#2| (-1170))) (-15 -1829 ((-2 (|:| |func| |#2|) (|:| |kers| (-638 (-611 |#2|))) (|:| |vals| (-638 |#2|))) |#2| (-1170))) (-15 -2250 (|#2| |#2|)) (-15 -2250 (|#2| |#2| (-1170))) (-15 -2487 ((-3 |#2| "failed") (-638 (-611 |#2|)) |#2| (-1170))) (-15 -2311 (|#2| |#2| (-611 |#2|))) (-15 -4450 (|#2| (-413 (-572)) |#2|))) 
-((-2857 (((-3 |#3| "failed") |#3|) 110)) (-4284 ((|#3| |#3|) 131)) (-2748 (((-3 |#3| "failed") |#3|) 82)) (-4224 ((|#3| |#3|) 121)) (-1580 (((-3 |#3| "failed") |#3|) 58)) (-4273 ((|#3| |#3|) 129)) (-3302 (((-3 |#3| "failed") |#3|) 46)) (-4217 ((|#3| |#3|) 119)) (-1326 (((-3 |#3| "failed") |#3|) 112)) (-4295 ((|#3| |#3|) 133)) (-2887 (((-3 |#3| "failed") |#3|) 84)) (-4233 ((|#3| |#3|) 123)) (-4345 (((-3 |#3| "failed") |#3| (-769)) 36)) (-2986 (((-3 |#3| "failed") |#3|) 74)) (-3539 ((|#3| |#3|) 118)) (-2290 (((-3 |#3| "failed") |#3|) 44)) (-4179 ((|#3| |#3|) 117)) (-3834 (((-3 |#3| "failed") |#3|) 113)) (-4302 ((|#3| |#3|) 134)) (-2323 (((-3 |#3| "failed") |#3|) 85)) (-4237 ((|#3| |#3|) 124)) (-2811 (((-3 |#3| "failed") |#3|) 111)) (-4289 ((|#3| |#3|) 132)) (-4460 (((-3 |#3| "failed") |#3|) 83)) (-4228 ((|#3| |#3|) 122)) (-1400 (((-3 |#3| "failed") |#3|) 60)) (-4278 ((|#3| |#3|) 130)) (-1935 (((-3 |#3| "failed") |#3|) 48)) (-4220 ((|#3| |#3|) 120)) (-4338 (((-3 |#3| "failed") |#3|) 66)) (-4321 ((|#3| |#3|) 137)) (-3096 (((-3 |#3| "failed") |#3|) 104)) (-4251 ((|#3| |#3|) 142)) (-4551 (((-3 |#3| "failed") |#3|) 62)) (-4308 ((|#3| |#3|) 135)) (-3983 (((-3 |#3| "failed") |#3|) 50)) (-4241 ((|#3| |#3|) 125)) (-3739 (((-3 |#3| "failed") |#3|) 70)) (-4333 ((|#3| |#3|) 139)) (-3402 (((-3 |#3| "failed") |#3|) 54)) (-4263 ((|#3| |#3|) 127)) (-3418 (((-3 |#3| "failed") |#3|) 72)) (-2104 ((|#3| |#3|) 140)) (-4359 (((-3 |#3| "failed") |#3|) 56)) (-4268 ((|#3| |#3|) 128)) (-4167 (((-3 |#3| "failed") |#3|) 68)) (-4327 ((|#3| |#3|) 138)) (-4163 (((-3 |#3| "failed") |#3|) 107)) (-4257 ((|#3| |#3|) 143)) (-1292 (((-3 |#3| "failed") |#3|) 64)) (-4314 ((|#3| |#3|) 136)) (-2234 (((-3 |#3| "failed") |#3|) 52)) (-4246 ((|#3| |#3|) 126)) (** ((|#3| |#3| (-413 (-572))) 40 (|has| |#1| (-368))))) 
-(((-276 |#1| |#2| |#3|) (-13 (-991 |#3|) (-10 -7 (IF (|has| |#1| (-368)) (-15 ** (|#3| |#3| (-413 (-572)))) |noBranch|) (-15 -4179 (|#3| |#3|)) (-15 -3539 (|#3| |#3|)) (-15 -4217 (|#3| |#3|)) (-15 -4220 (|#3| |#3|)) (-15 -4224 (|#3| |#3|)) (-15 -4228 (|#3| |#3|)) (-15 -4233 (|#3| |#3|)) (-15 -4237 (|#3| |#3|)) (-15 -4241 (|#3| |#3|)) (-15 -4246 (|#3| |#3|)) (-15 -4251 (|#3| |#3|)) (-15 -4257 (|#3| |#3|)) (-15 -4263 (|#3| |#3|)) (-15 -4268 (|#3| |#3|)) (-15 -4273 (|#3| |#3|)) (-15 -4278 (|#3| |#3|)) (-15 -4284 (|#3| |#3|)) (-15 -4289 (|#3| |#3|)) (-15 -4295 (|#3| |#3|)) (-15 -4302 (|#3| |#3|)) (-15 -4308 (|#3| |#3|)) (-15 -4314 (|#3| |#3|)) (-15 -4321 (|#3| |#3|)) (-15 -4327 (|#3| |#3|)) (-15 -4333 (|#3| |#3|)) (-15 -2104 (|#3| |#3|)))) (-43 (-413 (-572))) (-1249 |#1|) (-1220 |#1| |#2|)) (T -276)) 
-((** (*1 *2 *2 *3) (-12 (-5 *3 (-413 (-572))) (-4 *4 (-368)) (-4 *4 (-43 *3)) (-4 *5 (-1249 *4)) (-5 *1 (-276 *4 *5 *2)) (-4 *2 (-1220 *4 *5)))) (-4179 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-3539 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4217 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4220 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4224 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4228 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4233 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4237 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4241 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4246 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4251 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4257 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4263 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4268 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4273 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4278 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4284 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4289 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4295 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4302 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4308 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4314 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4321 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4327 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-4333 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) (-2104 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4))))) 
-(-13 (-991 |#3|) (-10 -7 (IF (|has| |#1| (-368)) (-15 ** (|#3| |#3| (-413 (-572)))) |noBranch|) (-15 -4179 (|#3| |#3|)) (-15 -3539 (|#3| |#3|)) (-15 -4217 (|#3| |#3|)) (-15 -4220 (|#3| |#3|)) (-15 -4224 (|#3| |#3|)) (-15 -4228 (|#3| |#3|)) (-15 -4233 (|#3| |#3|)) (-15 -4237 (|#3| |#3|)) (-15 -4241 (|#3| |#3|)) (-15 -4246 (|#3| |#3|)) (-15 -4251 (|#3| |#3|)) (-15 -4257 (|#3| |#3|)) (-15 -4263 (|#3| |#3|)) (-15 -4268 (|#3| |#3|)) (-15 -4273 (|#3| |#3|)) (-15 -4278 (|#3| |#3|)) (-15 -4284 (|#3| |#3|)) (-15 -4289 (|#3| |#3|)) (-15 -4295 (|#3| |#3|)) (-15 -4302 (|#3| |#3|)) (-15 -4308 (|#3| |#3|)) (-15 -4314 (|#3| |#3|)) (-15 -4321 (|#3| |#3|)) (-15 -4327 (|#3| |#3|)) (-15 -4333 (|#3| |#3|)) (-15 -2104 (|#3| |#3|)))) 
-((-2857 (((-3 |#3| "failed") |#3|) 66)) (-4284 ((|#3| |#3|) 133)) (-2748 (((-3 |#3| "failed") |#3|) 50)) (-4224 ((|#3| |#3|) 121)) (-1580 (((-3 |#3| "failed") |#3|) 62)) (-4273 ((|#3| |#3|) 131)) (-3302 (((-3 |#3| "failed") |#3|) 46)) (-4217 ((|#3| |#3|) 119)) (-1326 (((-3 |#3| "failed") |#3|) 70)) (-4295 ((|#3| |#3|) 135)) (-2887 (((-3 |#3| "failed") |#3|) 54)) (-4233 ((|#3| |#3|) 123)) (-4345 (((-3 |#3| "failed") |#3| (-769)) 35)) (-2986 (((-3 |#3| "failed") |#3|) 44)) (-3539 ((|#3| |#3|) 112)) (-2290 (((-3 |#3| "failed") |#3|) 42)) (-4179 ((|#3| |#3|) 118)) (-3834 (((-3 |#3| "failed") |#3|) 72)) (-4302 ((|#3| |#3|) 136)) (-2323 (((-3 |#3| "failed") |#3|) 56)) (-4237 ((|#3| |#3|) 124)) (-2811 (((-3 |#3| "failed") |#3|) 68)) (-4289 ((|#3| |#3|) 134)) (-4460 (((-3 |#3| "failed") |#3|) 52)) (-4228 ((|#3| |#3|) 122)) (-1400 (((-3 |#3| "failed") |#3|) 64)) (-4278 ((|#3| |#3|) 132)) (-1935 (((-3 |#3| "failed") |#3|) 48)) (-4220 ((|#3| |#3|) 120)) (-4338 (((-3 |#3| "failed") |#3|) 78)) (-4321 ((|#3| |#3|) 139)) (-3096 (((-3 |#3| "failed") |#3|) 58)) (-4251 ((|#3| |#3|) 127)) (-4551 (((-3 |#3| "failed") |#3|) 74)) (-4308 ((|#3| |#3|) 137)) (-3983 (((-3 |#3| "failed") |#3|) 102)) (-4241 ((|#3| |#3|) 125)) (-3739 (((-3 |#3| "failed") |#3|) 82)) (-4333 ((|#3| |#3|) 141)) (-3402 (((-3 |#3| "failed") |#3|) 109)) (-4263 ((|#3| |#3|) 129)) (-3418 (((-3 |#3| "failed") |#3|) 84)) (-2104 ((|#3| |#3|) 142)) (-4359 (((-3 |#3| "failed") |#3|) 111)) (-4268 ((|#3| |#3|) 130)) (-4167 (((-3 |#3| "failed") |#3|) 80)) (-4327 ((|#3| |#3|) 140)) (-4163 (((-3 |#3| "failed") |#3|) 60)) (-4257 ((|#3| |#3|) 128)) (-1292 (((-3 |#3| "failed") |#3|) 76)) (-4314 ((|#3| |#3|) 138)) (-2234 (((-3 |#3| "failed") |#3|) 105)) (-4246 ((|#3| |#3|) 126)) (** ((|#3| |#3| (-413 (-572))) 40 (|has| |#1| (-368))))) 
-(((-277 |#1| |#2| |#3| |#4|) (-13 (-991 |#3|) (-10 -7 (IF (|has| |#1| (-368)) (-15 ** (|#3| |#3| (-413 (-572)))) |noBranch|) (-15 -4179 (|#3| |#3|)) (-15 -3539 (|#3| |#3|)) (-15 -4217 (|#3| |#3|)) (-15 -4220 (|#3| |#3|)) (-15 -4224 (|#3| |#3|)) (-15 -4228 (|#3| |#3|)) (-15 -4233 (|#3| |#3|)) (-15 -4237 (|#3| |#3|)) (-15 -4241 (|#3| |#3|)) (-15 -4246 (|#3| |#3|)) (-15 -4251 (|#3| |#3|)) (-15 -4257 (|#3| |#3|)) (-15 -4263 (|#3| |#3|)) (-15 -4268 (|#3| |#3|)) (-15 -4273 (|#3| |#3|)) (-15 -4278 (|#3| |#3|)) (-15 -4284 (|#3| |#3|)) (-15 -4289 (|#3| |#3|)) (-15 -4295 (|#3| |#3|)) (-15 -4302 (|#3| |#3|)) (-15 -4308 (|#3| |#3|)) (-15 -4314 (|#3| |#3|)) (-15 -4321 (|#3| |#3|)) (-15 -4327 (|#3| |#3|)) (-15 -4333 (|#3| |#3|)) (-15 -2104 (|#3| |#3|)))) (-43 (-413 (-572))) (-1218 |#1|) (-1241 |#1| |#2|) (-991 |#2|)) (T -277)) 
-((** (*1 *2 *2 *3) (-12 (-5 *3 (-413 (-572))) (-4 *4 (-368)) (-4 *4 (-43 *3)) (-4 *5 (-1218 *4)) (-5 *1 (-277 *4 *5 *2 *6)) (-4 *2 (-1241 *4 *5)) (-4 *6 (-991 *5)))) (-4179 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-3539 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4217 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4220 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4224 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4228 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4233 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4237 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4241 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4246 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4251 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4257 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4263 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4268 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4273 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4278 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4284 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4289 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4295 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4302 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4308 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4314 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4321 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4327 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-4333 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) (-2104 (*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4))))) 
-(-13 (-991 |#3|) (-10 -7 (IF (|has| |#1| (-368)) (-15 ** (|#3| |#3| (-413 (-572)))) |noBranch|) (-15 -4179 (|#3| |#3|)) (-15 -3539 (|#3| |#3|)) (-15 -4217 (|#3| |#3|)) (-15 -4220 (|#3| |#3|)) (-15 -4224 (|#3| |#3|)) (-15 -4228 (|#3| |#3|)) (-15 -4233 (|#3| |#3|)) (-15 -4237 (|#3| |#3|)) (-15 -4241 (|#3| |#3|)) (-15 -4246 (|#3| |#3|)) (-15 -4251 (|#3| |#3|)) (-15 -4257 (|#3| |#3|)) (-15 -4263 (|#3| |#3|)) (-15 -4268 (|#3| |#3|)) (-15 -4273 (|#3| |#3|)) (-15 -4278 (|#3| |#3|)) (-15 -4284 (|#3| |#3|)) (-15 -4289 (|#3| |#3|)) (-15 -4295 (|#3| |#3|)) (-15 -4302 (|#3| |#3|)) (-15 -4308 (|#3| |#3|)) (-15 -4314 (|#3| |#3|)) (-15 -4321 (|#3| |#3|)) (-15 -4327 (|#3| |#3|)) (-15 -4333 (|#3| |#3|)) (-15 -2104 (|#3| |#3|)))) 
-((-2561 (($ (-1 (-121) |#2|) $) 23)) (-1643 (($ $) 36)) (-1544 (($ (-1 (-121) |#2|) $) NIL) (($ |#2| $) 34)) (-3445 (($ |#2| $) 31) (($ (-1 (-121) |#2|) $) 17)) (-3279 (($ (-1 (-121) |#2| |#2|) $ $) NIL) (($ $ $) 40)) (-2603 (($ |#2| $ (-572)) 19) (($ $ $ (-572)) 21)) (-1940 (($ $ (-572)) 11) (($ $ (-1225 (-572))) 14)) (-2977 (($ $ |#2|) 29) (($ $ $) NIL)) (-4500 (($ $ |#2|) 28) (($ |#2| $) NIL) (($ $ $) 25) (($ (-638 $)) NIL))) 
-(((-278 |#1| |#2|) (-10 -8 (-15 -3279 (|#1| |#1| |#1|)) (-15 -1544 (|#1| |#2| |#1|)) (-15 -3279 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -1544 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -2977 (|#1| |#1| |#1|)) (-15 -2977 (|#1| |#1| |#2|)) (-15 -2603 (|#1| |#1| |#1| (-572))) (-15 -2603 (|#1| |#2| |#1| (-572))) (-15 -1940 (|#1| |#1| (-1225 (-572)))) (-15 -1940 (|#1| |#1| (-572))) (-15 -4500 (|#1| (-638 |#1|))) (-15 -4500 (|#1| |#1| |#1|)) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#2|)) (-15 -3445 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -2561 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3445 (|#1| |#2| |#1|)) (-15 -1643 (|#1| |#1|))) (-279 |#2|) (-1204)) (T -278)) 
-NIL 
-(-10 -8 (-15 -3279 (|#1| |#1| |#1|)) (-15 -1544 (|#1| |#2| |#1|)) (-15 -3279 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -1544 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -2977 (|#1| |#1| |#1|)) (-15 -2977 (|#1| |#1| |#2|)) (-15 -2603 (|#1| |#1| |#1| (-572))) (-15 -2603 (|#1| |#2| |#1| (-572))) (-15 -1940 (|#1| |#1| (-1225 (-572)))) (-15 -1940 (|#1| |#1| (-572))) (-15 -4500 (|#1| (-638 |#1|))) (-15 -4500 (|#1| |#1| |#1|)) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#2|)) (-15 -3445 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -2561 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3445 (|#1| |#2| |#1|)) (-15 -1643 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#1| $ (-572) |#1|) 49 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 53 (|has| $ (-6 -4603)))) (-1550 (($ (-1 (-121) |#1|) $) 78)) (-2561 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-3259 (($ $) 76 (|has| |#1| (-1098)))) (-1643 (($ $) 73 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ (-1 (-121) |#1|) $) 82) (($ |#1| $) 77 (|has| |#1| (-1098)))) (-3445 (($ |#1| $) 72 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) 50 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 48)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-1364 (($ (-769) |#1|) 64)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-3279 (($ (-1 (-121) |#1| |#1|) $ $) 79) (($ $ $) 75 (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-1335 (($ |#1| $ (-572)) 81) (($ $ $ (-572)) 80)) (-2603 (($ |#1| $ (-572)) 55) (($ $ $ (-572)) 54)) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 39 (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3299 (($ $ |#1|) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ (-572) |#1|) 47) ((|#1| $ (-572)) 46) (($ $ (-1225 (-572))) 58)) (-2145 (($ $ (-572)) 84) (($ $ (-1225 (-572))) 83)) (-1940 (($ $ (-572)) 57) (($ $ (-1225 (-572))) 56)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 74 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 65)) (-2977 (($ $ |#1|) 86) (($ $ $) 85)) (-4500 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-638 $)) 60)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-279 |#1|) (-1290) (-1204)) (T -279)) 
-((-2977 (*1 *1 *1 *2) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)))) (-2977 (*1 *1 *1 *1) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)))) (-2145 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) (-2145 (*1 *1 *1 *2) (-12 (-5 *2 (-1225 (-572))) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) (-1544 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) (-1335 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-279 *2)) (-4 *2 (-1204)))) (-1335 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) (-3279 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) (-1550 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) (-1544 (*1 *1 *2 *1) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)) (-4 *2 (-1098)))) (-3259 (*1 *1 *1) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)) (-4 *2 (-1098)))) (-3279 (*1 *1 *1 *1) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)) (-4 *2 (-848))))) 
-(-13 (-644 |t#1|) (-10 -8 (-6 -4603) (-15 -2977 ($ $ |t#1|)) (-15 -2977 ($ $ $)) (-15 -2145 ($ $ (-572))) (-15 -2145 ($ $ (-1225 (-572)))) (-15 -1544 ($ (-1 (-121) |t#1|) $)) (-15 -1335 ($ |t#1| $ (-572))) (-15 -1335 ($ $ $ (-572))) (-15 -3279 ($ (-1 (-121) |t#1| |t#1|) $ $)) (-15 -1550 ($ (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1098)) (PROGN (-15 -1544 ($ |t#1| $)) (-15 -3259 ($ $))) |noBranch|) (IF (|has| |t#1| (-848)) (-15 -3279 ($ $ $)) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-644 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
+((-2027 (((-141) $) 12)) (-2731 (($ (-1 |#2| |#2|) $) 21)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ (-433 (-592)) $) 24) (($ $ (-433 (-592))) NIL))) 
+(((-51 |#1| |#2| |#3|) (-10 -8 (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 -2027 ((-141) |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) (-52 |#2| |#3|) (-1075) (-814)) (T -51)) 
+NIL 
+(-10 -8 (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 -2027 ((-141) |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-4593 (($ $) 59)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2027 (((-141) $) 61)) (-4526 (($ |#1| |#2|) 60)) (-2731 (($ (-1 |#1| |#1|) $) 62)) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582)))) (-4525 ((|#2| $) 63)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 56 (|has| |#1| (-43 (-433 (-592))))) (($ $) 48 (|has| |#1| (-582))) (($ |#1|) 46 (|has| |#1| (-194)))) (-1937 ((|#1| $ |#2|) 58)) (-1517 (((-3 $ "failed") $) 47 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-52 |#1| |#2|) (-1311) (-1075) (-814)) (T -52)) 
+((-4579 (*1 *2 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) (-4573 (*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)))) (-4525 (*1 *2 *1) (-12 (-4 *1 (-52 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-52 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)))) (-2027 (*1 *2 *1) (-12 (-4 *1 (-52 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-141)))) (-4526 (*1 *1 *2 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)))) (-4593 (*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)))) (-1937 (*1 *2 *1 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) (-3313 (*1 *1 *1 *2) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *2 (-388))))) 
+(-13 (-1075) (-140 |t#1| |t#1|) (-10 -8 (-15 -4579 (|t#1| $)) (-15 -4573 ($ $)) (-15 -4525 (|t#2| $)) (-15 -2731 ($ (-1 |t#1| |t#1|) $)) (-15 -2027 ((-141) $)) (-15 -4526 ($ |t#1| |t#2|)) (-15 -4593 ($ $)) (-15 -1937 (|t#1| $ |t#2|)) (IF (|has| |t#1| (-388)) (-15 -3313 ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-194)) (PROGN (-6 (-194)) (-6 (-43 |t#1|))) |noBranch|) (IF (|has| |t#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |t#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |t#1| (-582)) (-6 (-582)) |noBranch|) (IF (|has| |t#1| (-43 (-433 (-592)))) (-6 (-43 (-433 (-592)))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) |has| |#1| (-582)) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-307) |has| |#1| (-582)) ((-582) |has| |#1| (-582)) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) |has| |#1| (-582)) ((-743) . T) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-3863 (((-658 $) (-1187 $) (-1191)) NIL) (((-658 $) (-1187 $)) NIL) (((-658 $) (-980 $)) NIL)) (-3224 (($ (-1187 $) (-1191)) NIL) (($ (-1187 $)) NIL) (($ (-980 $)) NIL)) (-2272 (((-141) $) 11)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2165 (((-658 (-631 $)) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3147 (($ $ (-310 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1442 (($ $) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-1316 (((-658 $) (-1187 $) (-1191)) NIL) (((-658 $) (-1187 $)) NIL) (((-658 $) (-980 $)) NIL)) (-3906 (($ (-1187 $) (-1191)) NIL) (($ (-1187 $)) NIL) (($ (-980 $)) NIL)) (-4368 (((-3 (-631 $) "failed") $) NIL) (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL)) (-2400 (((-631 $) $) NIL) (((-592) $) NIL) (((-433 (-592)) $) NIL)) (-1586 (($ $ $) NIL)) (-3945 (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-706 (-592)) (-706 $)) NIL) (((-2 (|:| -3253 (-706 (-433 (-592)))) (|:| |vec| (-1280 (-433 (-592))))) (-706 $) (-1280 $)) NIL) (((-706 (-433 (-592))) (-706 $)) NIL)) (-3657 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-2243 (($ $) NIL) (($ (-658 $)) NIL)) (-4388 (((-658 (-143)) $) NIL)) (-2791 (((-143) (-143)) NIL)) (-3558 (((-141) $) 14)) (-3372 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-1448 (((-1142 (-592) (-631 $)) $) NIL)) (-4422 (($ $ (-592)) NIL)) (-2793 (((-1187 $) (-1187 $) (-631 $)) NIL) (((-1187 $) (-1187 $) (-658 (-631 $))) NIL) (($ $ (-631 $)) NIL) (($ $ (-658 (-631 $))) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2710 (((-1187 $) (-631 $)) NIL (|has| $ (-1075)))) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 $ $) (-631 $)) NIL)) (-4160 (((-3 (-631 $) "failed") $) NIL)) (-2750 (($ (-658 $)) NIL) (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-4486 (((-658 (-631 $)) $) NIL)) (-1462 (($ (-143) $) NIL) (($ (-143) (-658 $)) NIL)) (-3013 (((-141) $ (-143)) NIL) (((-141) $ (-1191)) NIL)) (-4552 (($ $) NIL)) (-2535 (((-790) $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ (-658 $)) NIL) (($ $ $) NIL)) (-1319 (((-141) $ $) NIL) (((-141) $ (-1191)) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3554 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-2806 (($ $ (-631 $) $) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-1191) (-1 $ (-658 $))) NIL) (($ $ (-1191) (-1 $ $)) NIL) (($ $ (-658 (-143)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-143) (-1 $ (-658 $))) NIL) (($ $ (-143) (-1 $ $)) NIL)) (-2769 (((-790) $) NIL)) (-3927 (($ (-143) $) NIL) (($ (-143) $ $) NIL) (($ (-143) $ $ $) NIL) (($ (-143) $ $ $ $) NIL) (($ (-143) (-658 $)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2818 (($ $) NIL) (($ $ $) NIL)) (-3644 (($ $ (-790)) NIL) (($ $) NIL)) (-1456 (((-1142 (-592) (-631 $)) $) NIL)) (-3390 (($ $) NIL (|has| $ (-1075)))) (-1778 (((-405) $) NIL) (((-237) $) NIL) (((-191 (-405)) $) NIL)) (-1683 (((-877) $) NIL) (($ (-631 $)) NIL) (($ (-433 (-592))) NIL) (($ $) NIL) (($ (-592)) NIL) (($ (-1142 (-592) (-631 $))) NIL)) (-4010 (((-790)) NIL)) (-3280 (($ $) NIL) (($ (-658 $)) NIL)) (-3038 (((-141) (-143)) NIL)) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-592)) NIL) (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (-3514 (($) 7 T CONST)) (-4257 (($) 12 T CONST)) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 16)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL)) (-3306 (($ $ $) 15) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-433 (-592))) NIL) (($ $ (-592)) NIL) (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (* (($ (-433 (-592)) $) NIL) (($ $ (-433 (-592))) NIL) (($ $ $) NIL) (($ (-592) $) NIL) (($ (-790) $) NIL) (($ (-944) $) NIL))) 
+(((-53) (-13 (-318) (-27) (-1065 (-592)) (-1065 (-433 (-592))) (-654 (-592)) (-1049) (-654 (-433 (-592))) (-171) (-633 (-191 (-405))) (-247) (-10 -8 (-15 -1683 ($ (-1142 (-592) (-631 $)))) (-15 -1448 ((-1142 (-592) (-631 $)) $)) (-15 -1456 ((-1142 (-592) (-631 $)) $)) (-15 -3657 ($ $)) (-15 -2793 ((-1187 $) (-1187 $) (-631 $))) (-15 -2793 ((-1187 $) (-1187 $) (-658 (-631 $)))) (-15 -2793 ($ $ (-631 $))) (-15 -2793 ($ $ (-658 (-631 $))))))) (T -53)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1142 (-592) (-631 (-53)))) (-5 *1 (-53)))) (-1448 (*1 *2 *1) (-12 (-5 *2 (-1142 (-592) (-631 (-53)))) (-5 *1 (-53)))) (-1456 (*1 *2 *1) (-12 (-5 *2 (-1142 (-592) (-631 (-53)))) (-5 *1 (-53)))) (-3657 (*1 *1 *1) (-5 *1 (-53))) (-2793 (*1 *2 *2 *3) (-12 (-5 *2 (-1187 (-53))) (-5 *3 (-631 (-53))) (-5 *1 (-53)))) (-2793 (*1 *2 *2 *3) (-12 (-5 *2 (-1187 (-53))) (-5 *3 (-658 (-631 (-53)))) (-5 *1 (-53)))) (-2793 (*1 *1 *1 *2) (-12 (-5 *2 (-631 (-53))) (-5 *1 (-53)))) (-2793 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-631 (-53)))) (-5 *1 (-53))))) 
+(-13 (-318) (-27) (-1065 (-592)) (-1065 (-433 (-592))) (-654 (-592)) (-1049) (-654 (-433 (-592))) (-171) (-633 (-191 (-405))) (-247) (-10 -8 (-15 -1683 ($ (-1142 (-592) (-631 $)))) (-15 -1448 ((-1142 (-592) (-631 $)) $)) (-15 -1456 ((-1142 (-592) (-631 $)) $)) (-15 -3657 ($ $)) (-15 -2793 ((-1187 $) (-1187 $) (-631 $))) (-15 -2793 ((-1187 $) (-1187 $) (-658 (-631 $)))) (-15 -2793 ($ $ (-631 $))) (-15 -2793 ($ $ (-658 (-631 $)))))) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 7)) (-3255 (((-141) $ $) NIL))) 
+(((-54) (-1119)) (T -54)) 
+NIL 
+(-1119) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 60)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3461 (((-141) $) 20)) (-4368 (((-3 |#1| "failed") $) 23)) (-2400 ((|#1| $) 24)) (-4593 (($ $) 27)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4579 ((|#1| $) 21)) (-1693 (($ $) 49)) (-2685 (((-1173) $) NIL)) (-1815 (((-141) $) 28)) (-2951 (((-1137) $) NIL)) (-2934 (($ (-790)) 47)) (-1430 (($ (-658 (-592))) 48)) (-4525 (((-790) $) 29)) (-1683 (((-877) $) 63) (($ (-592)) 44) (($ |#1|) 42)) (-1937 ((|#1| $ $) 19)) (-4010 (((-790)) 46)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 30 T CONST)) (-4257 (($) 14 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 40)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 41) (($ |#1| $) 35))) 
+(((-55 |#1| |#2|) (-13 (-636 |#1|) (-1065 |#1|) (-10 -8 (-15 -4579 (|#1| $)) (-15 -1693 ($ $)) (-15 -4593 ($ $)) (-15 -1937 (|#1| $ $)) (-15 -2934 ($ (-790))) (-15 -1430 ($ (-658 (-592)))) (-15 -1815 ((-141) $)) (-15 -3461 ((-141) $)) (-15 -4525 ((-790) $)) (-15 -2731 ($ (-1 |#1| |#1|) $)))) (-1075) (-658 (-1191))) (T -55)) 
+((-4579 (*1 *2 *1) (-12 (-4 *2 (-1075)) (-5 *1 (-55 *2 *3)) (-14 *3 (-658 (-1191))))) (-1693 (*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-658 (-1191))))) (-4593 (*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-658 (-1191))))) (-1937 (*1 *2 *1 *1) (-12 (-4 *2 (-1075)) (-5 *1 (-55 *2 *3)) (-14 *3 (-658 (-1191))))) (-2934 (*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) (-1430 (*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) (-1815 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) (-3461 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) (-4525 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-55 *3 *4)) (-14 *4 (-658 (-1191)))))) 
+(-13 (-636 |#1|) (-1065 |#1|) (-10 -8 (-15 -4579 (|#1| $)) (-15 -1693 ($ $)) (-15 -4593 ($ $)) (-15 -1937 (|#1| $ $)) (-15 -2934 ($ (-790))) (-15 -1430 ($ (-658 (-592)))) (-15 -1815 ((-141) $)) (-15 -3461 ((-141) $)) (-15 -4525 ((-790) $)) (-15 -2731 ($ (-1 |#1| |#1|) $)))) 
+((-3461 (((-141) (-57)) 13)) (-4368 (((-3 |#1| "failed") (-57)) 21)) (-2400 ((|#1| (-57)) 22)) (-1683 (((-57) |#1|) 18))) 
+(((-56 |#1|) (-10 -7 (-15 -1683 ((-57) |#1|)) (-15 -4368 ((-3 |#1| "failed") (-57))) (-15 -3461 ((-141) (-57))) (-15 -2400 (|#1| (-57)))) (-1225)) (T -56)) 
+((-2400 (*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1225)))) (-3461 (*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *2 (-141)) (-5 *1 (-56 *4)) (-4 *4 (-1225)))) (-4368 (*1 *2 *3) (|partial| -12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1225)))) (-1683 (*1 *2 *3) (-12 (-5 *2 (-57)) (-5 *1 (-56 *3)) (-4 *3 (-1225))))) 
+(-10 -7 (-15 -1683 ((-57) |#1|)) (-15 -4368 ((-3 |#1| "failed") (-57))) (-15 -3461 ((-141) (-57))) (-15 -2400 (|#1| (-57)))) 
+((-1641 (((-141) $ $) NIL)) (-3727 (((-1173) (-141)) 25)) (-3364 (((-877) $) 24)) (-4456 (((-793) $) 12)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4350 (((-877) $) 16)) (-3447 (((-1123) $) 14)) (-1683 (((-877) $) 32)) (-4110 (($ (-1123) (-793)) 33)) (-3255 (((-141) $ $) 18))) 
+(((-57) (-13 (-1119) (-10 -8 (-15 -4110 ($ (-1123) (-793))) (-15 -4350 ((-877) $)) (-15 -3364 ((-877) $)) (-15 -3447 ((-1123) $)) (-15 -4456 ((-793) $)) (-15 -3727 ((-1173) (-141)))))) (T -57)) 
+((-4110 (*1 *1 *2 *3) (-12 (-5 *2 (-1123)) (-5 *3 (-793)) (-5 *1 (-57)))) (-4350 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-57)))) (-3364 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-57)))) (-3447 (*1 *2 *1) (-12 (-5 *2 (-1123)) (-5 *1 (-57)))) (-4456 (*1 *2 *1) (-12 (-5 *2 (-793)) (-5 *1 (-57)))) (-3727 (*1 *2 *3) (-12 (-5 *3 (-141)) (-5 *2 (-1173)) (-5 *1 (-57))))) 
+(-13 (-1119) (-10 -8 (-15 -4110 ($ (-1123) (-793))) (-15 -4350 ((-877) $)) (-15 -3364 ((-877) $)) (-15 -3447 ((-1123) $)) (-15 -4456 ((-793) $)) (-15 -3727 ((-1173) (-141))))) 
+((-4199 (((-1285)) 20)) (-1573 (((-1285) (-141)) 22)) (-2098 (((-1121 (-1191)) (-1191)) 15)) (-4259 (((-1121 (-1191)) (-1191)) 16)) (-4256 (((-1285)) 19))) 
+(((-58) (-10 -7 (-15 -2098 ((-1121 (-1191)) (-1191))) (-15 -4259 ((-1121 (-1191)) (-1191))) (-15 -4256 ((-1285))) (-15 -4199 ((-1285))) (-15 -1573 ((-1285) (-141))))) (T -58)) 
+((-1573 (*1 *2 *3) (-12 (-5 *3 (-141)) (-5 *2 (-1285)) (-5 *1 (-58)))) (-4199 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-58)))) (-4256 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-58)))) (-4259 (*1 *2 *3) (-12 (-5 *2 (-1121 (-1191))) (-5 *1 (-58)) (-5 *3 (-1191)))) (-2098 (*1 *2 *3) (-12 (-5 *2 (-1121 (-1191))) (-5 *1 (-58)) (-5 *3 (-1191))))) 
+(-10 -7 (-15 -2098 ((-1121 (-1191)) (-1191))) (-15 -4259 ((-1121 (-1191)) (-1191))) (-15 -4256 ((-1285))) (-15 -4199 ((-1285))) (-15 -1573 ((-1285) (-141)))) 
+((-4572 ((|#2| |#3| (-1 |#2| |#2|) |#2|) 16))) 
+(((-59 |#1| |#2| |#3|) (-10 -7 (-15 -4572 (|#2| |#3| (-1 |#2| |#2|) |#2|))) (-1075) (-661 |#1|) (-871 |#1|)) (T -59)) 
+((-4572 (*1 *2 *3 *4 *2) (-12 (-5 *4 (-1 *2 *2)) (-4 *2 (-661 *5)) (-4 *5 (-1075)) (-5 *1 (-59 *5 *2 *3)) (-4 *3 (-871 *5))))) 
+(-10 -7 (-15 -4572 (|#2| |#3| (-1 |#2| |#2|) |#2|))) 
+((-2756 ((|#3| |#3| (-658 (-1191))) 35)) (-2688 ((|#3| (-658 (-1097 |#1| |#2| |#3|)) |#3| (-944)) 22) ((|#3| (-658 (-1097 |#1| |#2| |#3|)) |#3|) 20))) 
+(((-60 |#1| |#2| |#3|) (-10 -7 (-15 -2688 (|#3| (-658 (-1097 |#1| |#2| |#3|)) |#3|)) (-15 -2688 (|#3| (-658 (-1097 |#1| |#2| |#3|)) |#3| (-944))) (-15 -2756 (|#3| |#3| (-658 (-1191))))) (-1119) (-13 (-1075) (-908 |#1|) (-869) (-633 (-914 |#1|))) (-13 (-456 |#2|) (-908 |#1|) (-633 (-914 |#1|)))) (T -60)) 
+((-2756 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-60 *4 *5 *2)) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))))) (-2688 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-658 (-1097 *5 *6 *2))) (-5 *4 (-944)) (-4 *5 (-1119)) (-4 *6 (-13 (-1075) (-908 *5) (-869) (-633 (-914 *5)))) (-4 *2 (-13 (-456 *6) (-908 *5) (-633 (-914 *5)))) (-5 *1 (-60 *5 *6 *2)))) (-2688 (*1 *2 *3 *2) (-12 (-5 *3 (-658 (-1097 *4 *5 *2))) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))) (-5 *1 (-60 *4 *5 *2))))) 
+(-10 -7 (-15 -2688 (|#3| (-658 (-1097 |#1| |#2| |#3|)) |#3|)) (-15 -2688 (|#3| (-658 (-1097 |#1| |#2| |#3|)) |#3| (-944))) (-15 -2756 (|#3| |#3| (-658 (-1191))))) 
+((-2126 (((-141) $ (-790)) 23)) (-2547 (($ $ (-592) |#3|) 45)) (-2242 (($ $ (-592) |#4|) 49)) (-2747 ((|#3| $ (-592)) 58)) (-4004 (((-658 |#2|) $) 30)) (-4345 (((-141) $ (-790)) 25)) (-3133 (((-141) |#2| $) 53)) (-3987 (($ (-1 |#2| |#2|) $) 37)) (-2731 (($ (-1 |#2| |#2|) $) 36) (($ (-1 |#2| |#2| |#2|) $ $) 39) (($ (-1 |#2| |#2| |#2|) $ $ |#2|) 41)) (-2554 (((-141) $ (-790)) 24)) (-1892 (($ $ |#2|) 34)) (-3002 (((-141) (-1 (-141) |#2|) $) 19)) (-3927 ((|#2| $ (-592) (-592)) NIL) ((|#2| $ (-592) (-592) |#2|) 27)) (-3452 (((-790) (-1 (-141) |#2|) $) 28) (((-790) |#2| $) 55)) (-4599 (($ $) 33)) (-2000 ((|#4| $ (-592)) 61)) (-1683 (((-877) $) 66)) (-3369 (((-141) (-1 (-141) |#2|) $) 18)) (-3255 (((-141) $ $) 52)) (-1699 (((-790) $) 26))) 
+(((-61 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2731 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1| |#2|)) (-15 -2731 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -3987 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2242 (|#1| |#1| (-592) |#4|)) (-15 -2547 (|#1| |#1| (-592) |#3|)) (-15 -4004 ((-658 |#2|) |#1|)) (-15 -2000 (|#4| |#1| (-592))) (-15 -2747 (|#3| |#1| (-592))) (-15 -3927 (|#2| |#1| (-592) (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592) (-592))) (-15 -1892 (|#1| |#1| |#2|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3133 ((-141) |#2| |#1|)) (-15 -3452 ((-790) |#2| |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1699 ((-790) |#1|)) (-15 -2126 ((-141) |#1| (-790))) (-15 -4345 ((-141) |#1| (-790))) (-15 -2554 ((-141) |#1| (-790))) (-15 -4599 (|#1| |#1|))) (-62 |#2| |#3| |#4|) (-1225) (-399 |#2|) (-399 |#2|)) (T -61)) 
+NIL 
+(-10 -8 (-15 -2731 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1| |#2|)) (-15 -2731 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -3987 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2242 (|#1| |#1| (-592) |#4|)) (-15 -2547 (|#1| |#1| (-592) |#3|)) (-15 -4004 ((-658 |#2|) |#1|)) (-15 -2000 (|#4| |#1| (-592))) (-15 -2747 (|#3| |#1| (-592))) (-15 -3927 (|#2| |#1| (-592) (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592) (-592))) (-15 -1892 (|#1| |#1| |#2|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3133 ((-141) |#2| |#1|)) (-15 -3452 ((-790) |#2| |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1699 ((-790) |#1|)) (-15 -2126 ((-141) |#1| (-790))) (-15 -4345 ((-141) |#1| (-790))) (-15 -2554 ((-141) |#1| (-790))) (-15 -4599 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#1| $ (-592) (-592) |#1|) 41)) (-2547 (($ $ (-592) |#2|) 39)) (-2242 (($ $ (-592) |#3|) 38)) (-3001 (($) 7 T CONST)) (-2747 ((|#2| $ (-592)) 43)) (-1426 ((|#1| $ (-592) (-592) |#1|) 40)) (-3959 ((|#1| $ (-592) (-592)) 45)) (-4004 (((-658 |#1|) $) 30)) (-4292 (((-790) $) 48)) (-3242 (($ (-790) (-790) |#1|) 54)) (-4298 (((-790) $) 47)) (-4345 (((-141) $ (-790)) 9)) (-4577 (((-592) $) 52)) (-4280 (((-592) $) 50)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1898 (((-592) $) 51)) (-3005 (((-592) $) 49)) (-3987 (($ (-1 |#1| |#1|) $) 34)) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 37) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) 36)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1892 (($ $ |#1|) 53)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ (-592) (-592)) 46) ((|#1| $ (-592) (-592) |#1|) 44)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-2000 ((|#3| $ (-592)) 42)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-62 |#1| |#2| |#3|) (-1311) (-1225) (-399 |t#1|) (-399 |t#1|)) (T -62)) 
+((-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-3242 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-790)) (-4 *3 (-1225)) (-4 *1 (-62 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-1892 (*1 *1 *1 *2) (-12 (-4 *1 (-62 *2 *3 *4)) (-4 *2 (-1225)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (-4577 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-592)))) (-1898 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-592)))) (-4280 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-592)))) (-3005 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-592)))) (-4292 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-790)))) (-4298 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-790)))) (-3927 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-1225)))) (-3959 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-1225)))) (-3927 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1225)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)))) (-2747 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-62 *4 *2 *5)) (-4 *4 (-1225)) (-4 *5 (-399 *4)) (-4 *2 (-399 *4)))) (-2000 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-62 *4 *5 *2)) (-4 *4 (-1225)) (-4 *5 (-399 *4)) (-4 *2 (-399 *4)))) (-4004 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-658 *3)))) (-3932 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1225)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)))) (-1426 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1225)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)))) (-2547 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-592)) (-4 *1 (-62 *4 *3 *5)) (-4 *4 (-1225)) (-4 *3 (-399 *4)) (-4 *5 (-399 *4)))) (-2242 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-592)) (-4 *1 (-62 *4 *5 *3)) (-4 *4 (-1225)) (-4 *5 (-399 *4)) (-4 *3 (-399 *4)))) (-3987 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-2731 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-2731 (*1 *1 *2 *1 *1 *3) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3))))) 
+(-13 (-523 |t#1|) (-10 -8 (-6 -4626) (-6 -4625) (-15 -3242 ($ (-790) (-790) |t#1|)) (-15 -1892 ($ $ |t#1|)) (-15 -4577 ((-592) $)) (-15 -1898 ((-592) $)) (-15 -4280 ((-592) $)) (-15 -3005 ((-592) $)) (-15 -4292 ((-790) $)) (-15 -4298 ((-790) $)) (-15 -3927 (|t#1| $ (-592) (-592))) (-15 -3959 (|t#1| $ (-592) (-592))) (-15 -3927 (|t#1| $ (-592) (-592) |t#1|)) (-15 -2747 (|t#2| $ (-592))) (-15 -2000 (|t#3| $ (-592))) (-15 -4004 ((-658 |t#1|) $)) (-15 -3932 (|t#1| $ (-592) (-592) |t#1|)) (-15 -1426 (|t#1| $ (-592) (-592) |t#1|)) (-15 -2547 ($ $ (-592) |t#2|)) (-15 -2242 ($ $ (-592) |t#3|)) (-15 -2731 ($ (-1 |t#1| |t#1|) $)) (-15 -3987 ($ (-1 |t#1| |t#1|) $)) (-15 -2731 ($ (-1 |t#1| |t#1| |t#1|) $ $)) (-15 -2731 ($ (-1 |t#1| |t#1| |t#1|) $ $ |t#1|)))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1779 (((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|) 16)) (-3657 ((|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|) 18)) (-2731 (((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)) 13))) 
+(((-63 |#1| |#2|) (-10 -7 (-15 -1779 ((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3657 (|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -2731 ((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)))) (-1225) (-1225)) (T -63)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-64 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-64 *6)) (-5 *1 (-63 *5 *6)))) (-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-64 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-63 *5 *2)))) (-1779 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-64 *6)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-5 *2 (-64 *5)) (-5 *1 (-63 *6 *5))))) 
+(-10 -7 (-15 -1779 ((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3657 (|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -2731 ((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) NIL) (((-141) $) NIL (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) |#1|) 11 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-1721 (((-592) (-1 (-141) |#1|) $) NIL) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119)))) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3297 (($ (-658 |#1|)) 13) (($ (-790) |#1|) 14)) (-3242 (($ (-790) |#1|) 9)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) NIL (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 7)) (-3927 ((|#1| $ (-592) |#1|) NIL) ((|#1| $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-2266 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-64 |#1|) (-13 (-19 |#1|) (-10 -8 (-15 -3297 ($ (-658 |#1|))) (-15 -3297 ($ (-790) |#1|)))) (-1225)) (T -64)) 
+((-3297 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-64 *3)))) (-3297 (*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *1 (-64 *3)) (-4 *3 (-1225))))) 
+(-13 (-19 |#1|) (-10 -8 (-15 -3297 ($ (-658 |#1|))) (-15 -3297 ($ (-790) |#1|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) (-592) |#1|) NIL)) (-2547 (($ $ (-592) (-64 |#1|)) NIL)) (-2242 (($ $ (-592) (-64 |#1|)) NIL)) (-3001 (($) NIL T CONST)) (-2747 (((-64 |#1|) $ (-592)) NIL)) (-1426 ((|#1| $ (-592) (-592) |#1|) NIL)) (-3959 ((|#1| $ (-592) (-592)) NIL)) (-4004 (((-658 |#1|) $) NIL)) (-4292 (((-790) $) NIL)) (-3242 (($ (-790) (-790) |#1|) NIL)) (-4298 (((-790) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-4577 (((-592) $) NIL)) (-4280 (((-592) $) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1898 (((-592) $) NIL)) (-3005 (((-592) $) NIL)) (-3987 (($ (-1 |#1| |#1|) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1892 (($ $ |#1|) NIL)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) (-592)) NIL) ((|#1| $ (-592) (-592) |#1|) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-2000 (((-64 |#1|) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-65 |#1|) (-13 (-62 |#1| (-64 |#1|) (-64 |#1|)) (-10 -7 (-6 -4626))) (-1225)) (T -65)) 
+NIL 
+(-13 (-62 |#1| (-64 |#1|) (-64 |#1|)) (-10 -7 (-6 -4626))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 69) (((-3 $ "failed") (-1280 (-332 (-592)))) 58) (((-3 $ "failed") (-1280 (-980 (-405)))) 91) (((-3 $ "failed") (-1280 (-980 (-592)))) 80) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 47) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 36)) (-2400 (($ (-1280 (-332 (-405)))) 65) (($ (-1280 (-332 (-592)))) 54) (($ (-1280 (-980 (-405)))) 87) (($ (-1280 (-980 (-592)))) 76) (($ (-1280 (-433 (-980 (-405))))) 43) (($ (-1280 (-433 (-980 (-592))))) 29)) (-3592 (((-1285) $) 118)) (-1683 (((-877) $) 111) (($ (-658 (-350))) 100) (($ (-350)) 94) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 97) (($ (-1280 (-359 (-4466 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4466) (-715)))) 28))) 
+(((-66 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4466) (-715))))))) (-1191)) (T -66)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4466) (-715)))) (-5 *1 (-66 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4466) (-715))))))) 
+((-3592 (((-1285) $) 48) (((-1285)) 49)) (-1683 (((-877) $) 45))) 
+(((-67 |#1|) (-13 (-421) (-10 -7 (-15 -3592 ((-1285))))) (-1191)) (T -67)) 
+((-3592 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-67 *3)) (-14 *3 (-1191))))) 
+(-13 (-421) (-10 -7 (-15 -3592 ((-1285))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 142) (((-3 $ "failed") (-1280 (-332 (-592)))) 132) (((-3 $ "failed") (-1280 (-980 (-405)))) 163) (((-3 $ "failed") (-1280 (-980 (-592)))) 152) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 121) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 110)) (-2400 (($ (-1280 (-332 (-405)))) 138) (($ (-1280 (-332 (-592)))) 128) (($ (-1280 (-980 (-405)))) 159) (($ (-1280 (-980 (-592)))) 148) (($ (-1280 (-433 (-980 (-405))))) 117) (($ (-1280 (-433 (-980 (-592))))) 103)) (-3592 (((-1285) $) 96)) (-1683 (((-877) $) 90) (($ (-658 (-350))) 28) (($ (-350)) 34) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 31) (($ (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715)))) 88))) 
+(((-68 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715))))))) (-1191)) (T -68)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715)))) (-5 *1 (-68 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-332 (-405))) 36) (((-3 $ "failed") (-332 (-592))) 41) (((-3 $ "failed") (-980 (-405))) 46) (((-3 $ "failed") (-980 (-592))) 51) (((-3 $ "failed") (-433 (-980 (-405)))) 31) (((-3 $ "failed") (-433 (-980 (-592)))) 26)) (-2400 (($ (-332 (-405))) 34) (($ (-332 (-592))) 39) (($ (-980 (-405))) 44) (($ (-980 (-592))) 49) (($ (-433 (-980 (-405)))) 29) (($ (-433 (-980 (-592)))) 23)) (-3592 (((-1285) $) 73)) (-1683 (((-877) $) 66) (($ (-658 (-350))) 57) (($ (-350)) 63) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 60) (($ (-359 (-4466 (QUOTE X)) (-4466) (-715))) 22))) 
+(((-69 |#1|) (-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466 (QUOTE X)) (-4466) (-715)))))) (-1191)) (T -69)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-359 (-4466 (QUOTE X)) (-4466) (-715))) (-5 *1 (-69 *3)) (-14 *3 (-1191))))) 
+(-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466 (QUOTE X)) (-4466) (-715)))))) 
+((-4368 (((-3 $ "failed") (-706 (-332 (-405)))) 100) (((-3 $ "failed") (-706 (-332 (-592)))) 89) (((-3 $ "failed") (-706 (-980 (-405)))) 122) (((-3 $ "failed") (-706 (-980 (-592)))) 111) (((-3 $ "failed") (-706 (-433 (-980 (-405))))) 78) (((-3 $ "failed") (-706 (-433 (-980 (-592))))) 67)) (-2400 (($ (-706 (-332 (-405)))) 96) (($ (-706 (-332 (-592)))) 85) (($ (-706 (-980 (-405)))) 118) (($ (-706 (-980 (-592)))) 107) (($ (-706 (-433 (-980 (-405))))) 74) (($ (-706 (-433 (-980 (-592))))) 60)) (-3592 (((-1285) $) 130)) (-1683 (((-877) $) 124) (($ (-658 (-350))) 27) (($ (-350)) 33) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 30) (($ (-706 (-359 (-4466) (-4466 (QUOTE X) (QUOTE HESS)) (-715)))) 53))) 
+(((-70 |#1|) (-13 (-410) (-10 -8 (-15 -1683 ($ (-706 (-359 (-4466) (-4466 (QUOTE X) (QUOTE HESS)) (-715))))))) (-1191)) (T -70)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-706 (-359 (-4466) (-4466 (QUOTE X) (QUOTE HESS)) (-715)))) (-5 *1 (-70 *3)) (-14 *3 (-1191))))) 
+(-13 (-410) (-10 -8 (-15 -1683 ($ (-706 (-359 (-4466) (-4466 (QUOTE X) (QUOTE HESS)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-332 (-405))) 54) (((-3 $ "failed") (-332 (-592))) 59) (((-3 $ "failed") (-980 (-405))) 64) (((-3 $ "failed") (-980 (-592))) 69) (((-3 $ "failed") (-433 (-980 (-405)))) 49) (((-3 $ "failed") (-433 (-980 (-592)))) 44)) (-2400 (($ (-332 (-405))) 52) (($ (-332 (-592))) 57) (($ (-980 (-405))) 62) (($ (-980 (-592))) 67) (($ (-433 (-980 (-405)))) 47) (($ (-433 (-980 (-592)))) 41)) (-3592 (((-1285) $) 78)) (-1683 (((-877) $) 72) (($ (-658 (-350))) 27) (($ (-350)) 33) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 30) (($ (-359 (-4466) (-4466 (QUOTE XC)) (-715))) 38))) 
+(((-71 |#1|) (-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466) (-4466 (QUOTE XC)) (-715)))))) (-1191)) (T -71)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-359 (-4466) (-4466 (QUOTE XC)) (-715))) (-5 *1 (-71 *3)) (-14 *3 (-1191))))) 
+(-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466) (-4466 (QUOTE XC)) (-715)))))) 
+((-3592 (((-1285) $) 63)) (-1683 (((-877) $) 57) (($ (-706 (-715))) 49) (($ (-658 (-350))) 48) (($ (-350)) 55) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 53))) 
+(((-72 |#1|) (-409) (-1191)) (T -72)) 
+NIL 
+(-409) 
+((-3592 (((-1285) $) 64)) (-1683 (((-877) $) 58) (($ (-706 (-715))) 50) (($ (-658 (-350))) 49) (($ (-350)) 52) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 55))) 
+(((-73 |#1|) (-409) (-1191)) (T -73)) 
+NIL 
+(-409) 
+((-3592 (((-1285) $) NIL) (((-1285)) 32)) (-1683 (((-877) $) NIL))) 
+(((-74 |#1|) (-13 (-421) (-10 -7 (-15 -3592 ((-1285))))) (-1191)) (T -74)) 
+((-3592 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-74 *3)) (-14 *3 (-1191))))) 
+(-13 (-421) (-10 -7 (-15 -3592 ((-1285))))) 
+((-3592 (((-1285) $) 68)) (-1683 (((-877) $) 62) (($ (-706 (-715))) 53) (($ (-658 (-350))) 56) (($ (-350)) 59) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 52))) 
+(((-75 |#1|) (-409) (-1191)) (T -75)) 
+NIL 
+(-409) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 98) (((-3 $ "failed") (-1280 (-332 (-592)))) 87) (((-3 $ "failed") (-1280 (-980 (-405)))) 119) (((-3 $ "failed") (-1280 (-980 (-592)))) 108) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 76) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 65)) (-2400 (($ (-1280 (-332 (-405)))) 94) (($ (-1280 (-332 (-592)))) 83) (($ (-1280 (-980 (-405)))) 115) (($ (-1280 (-980 (-592)))) 104) (($ (-1280 (-433 (-980 (-405))))) 72) (($ (-1280 (-433 (-980 (-592))))) 58)) (-3592 (((-1285) $) 133)) (-1683 (((-877) $) 127) (($ (-658 (-350))) 122) (($ (-350)) 125) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 50) (($ (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715)))) 51))) 
+(((-76 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715))))))) (-1191)) (T -76)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715)))) (-5 *1 (-76 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715))))))) 
+((-3592 (((-1285) $) 32) (((-1285)) 31)) (-1683 (((-877) $) 35))) 
+(((-77 |#1|) (-13 (-421) (-10 -7 (-15 -3592 ((-1285))))) (-1191)) (T -77)) 
+((-3592 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-77 *3)) (-14 *3 (-1191))))) 
+(-13 (-421) (-10 -7 (-15 -3592 ((-1285))))) 
+((-3592 (((-1285) $) 62)) (-1683 (((-877) $) 56) (($ (-706 (-715))) 47) (($ (-658 (-350))) 50) (($ (-350)) 53) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 46))) 
+(((-78 |#1|) (-409) (-1191)) (T -78)) 
+NIL 
+(-409) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 119) (((-3 $ "failed") (-1280 (-332 (-592)))) 108) (((-3 $ "failed") (-1280 (-980 (-405)))) 141) (((-3 $ "failed") (-1280 (-980 (-592)))) 130) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 98) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 87)) (-2400 (($ (-1280 (-332 (-405)))) 115) (($ (-1280 (-332 (-592)))) 104) (($ (-1280 (-980 (-405)))) 137) (($ (-1280 (-980 (-592)))) 126) (($ (-1280 (-433 (-980 (-405))))) 94) (($ (-1280 (-433 (-980 (-592))))) 80)) (-3592 (((-1285) $) 73)) (-1683 (((-877) $) 27) (($ (-658 (-350))) 63) (($ (-350)) 59) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 66) (($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) 60))) 
+(((-79 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715))))))) (-1191)) (T -79)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) (-5 *1 (-79 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 125) (((-3 $ "failed") (-1280 (-332 (-592)))) 114) (((-3 $ "failed") (-1280 (-980 (-405)))) 147) (((-3 $ "failed") (-1280 (-980 (-592)))) 136) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 103) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 92)) (-2400 (($ (-1280 (-332 (-405)))) 121) (($ (-1280 (-332 (-592)))) 110) (($ (-1280 (-980 (-405)))) 143) (($ (-1280 (-980 (-592)))) 132) (($ (-1280 (-433 (-980 (-405))))) 99) (($ (-1280 (-433 (-980 (-592))))) 85)) (-3592 (((-1285) $) 78)) (-1683 (((-877) $) 70) (($ (-658 (-350))) NIL) (($ (-350)) NIL) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) NIL) (($ (-1280 (-359 (-4466 (QUOTE X) (QUOTE EPS)) (-4466 (QUOTE -3820)) (-715)))) 65))) 
+(((-80 |#1| |#2| |#3|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X) (QUOTE EPS)) (-4466 (QUOTE -3820)) (-715))))))) (-1191) (-1191) (-1191)) (T -80)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X) (QUOTE EPS)) (-4466 (QUOTE -3820)) (-715)))) (-5 *1 (-80 *3 *4 *5)) (-14 *3 (-1191)) (-14 *4 (-1191)) (-14 *5 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X) (QUOTE EPS)) (-4466 (QUOTE -3820)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 129) (((-3 $ "failed") (-1280 (-332 (-592)))) 118) (((-3 $ "failed") (-1280 (-980 (-405)))) 151) (((-3 $ "failed") (-1280 (-980 (-592)))) 140) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 107) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 96)) (-2400 (($ (-1280 (-332 (-405)))) 125) (($ (-1280 (-332 (-592)))) 114) (($ (-1280 (-980 (-405)))) 147) (($ (-1280 (-980 (-592)))) 136) (($ (-1280 (-433 (-980 (-405))))) 103) (($ (-1280 (-433 (-980 (-592))))) 89)) (-3592 (((-1285) $) 82)) (-1683 (((-877) $) 74) (($ (-658 (-350))) NIL) (($ (-350)) NIL) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) NIL) (($ (-1280 (-359 (-4466 (QUOTE EPS)) (-4466 (QUOTE YA) (QUOTE YB)) (-715)))) 69))) 
+(((-81 |#1| |#2| |#3|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE EPS)) (-4466 (QUOTE YA) (QUOTE YB)) (-715))))))) (-1191) (-1191) (-1191)) (T -81)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE EPS)) (-4466 (QUOTE YA) (QUOTE YB)) (-715)))) (-5 *1 (-81 *3 *4 *5)) (-14 *3 (-1191)) (-14 *4 (-1191)) (-14 *5 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE EPS)) (-4466 (QUOTE YA) (QUOTE YB)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-332 (-405))) 77) (((-3 $ "failed") (-332 (-592))) 82) (((-3 $ "failed") (-980 (-405))) 87) (((-3 $ "failed") (-980 (-592))) 92) (((-3 $ "failed") (-433 (-980 (-405)))) 72) (((-3 $ "failed") (-433 (-980 (-592)))) 67)) (-2400 (($ (-332 (-405))) 75) (($ (-332 (-592))) 80) (($ (-980 (-405))) 85) (($ (-980 (-592))) 90) (($ (-433 (-980 (-405)))) 70) (($ (-433 (-980 (-592)))) 64)) (-3592 (((-1285) $) 61)) (-1683 (((-877) $) 49) (($ (-658 (-350))) 45) (($ (-350)) 55) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 53) (($ (-359 (-4466) (-4466 (QUOTE X)) (-715))) 46))) 
+(((-82 |#1|) (-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466) (-4466 (QUOTE X)) (-715)))))) (-1191)) (T -82)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-359 (-4466) (-4466 (QUOTE X)) (-715))) (-5 *1 (-82 *3)) (-14 *3 (-1191))))) 
+(-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466) (-4466 (QUOTE X)) (-715)))))) 
+((-4368 (((-3 $ "failed") (-332 (-405))) 41) (((-3 $ "failed") (-332 (-592))) 46) (((-3 $ "failed") (-980 (-405))) 51) (((-3 $ "failed") (-980 (-592))) 56) (((-3 $ "failed") (-433 (-980 (-405)))) 36) (((-3 $ "failed") (-433 (-980 (-592)))) 31)) (-2400 (($ (-332 (-405))) 39) (($ (-332 (-592))) 44) (($ (-980 (-405))) 49) (($ (-980 (-592))) 54) (($ (-433 (-980 (-405)))) 34) (($ (-433 (-980 (-592)))) 28)) (-3592 (((-1285) $) 77)) (-1683 (((-877) $) 71) (($ (-658 (-350))) 62) (($ (-350)) 68) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 65) (($ (-359 (-4466) (-4466 (QUOTE X)) (-715))) 27))) 
+(((-83 |#1|) (-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466) (-4466 (QUOTE X)) (-715)))))) (-1191)) (T -83)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-359 (-4466) (-4466 (QUOTE X)) (-715))) (-5 *1 (-83 *3)) (-14 *3 (-1191))))) 
+(-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466) (-4466 (QUOTE X)) (-715)))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 84) (((-3 $ "failed") (-1280 (-332 (-592)))) 73) (((-3 $ "failed") (-1280 (-980 (-405)))) 106) (((-3 $ "failed") (-1280 (-980 (-592)))) 95) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 62) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 51)) (-2400 (($ (-1280 (-332 (-405)))) 80) (($ (-1280 (-332 (-592)))) 69) (($ (-1280 (-980 (-405)))) 102) (($ (-1280 (-980 (-592)))) 91) (($ (-1280 (-433 (-980 (-405))))) 58) (($ (-1280 (-433 (-980 (-592))))) 44)) (-3592 (((-1285) $) 122)) (-1683 (((-877) $) 116) (($ (-658 (-350))) 109) (($ (-350)) 36) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 112) (($ (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715)))) 37))) 
+(((-84 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715))))))) (-1191)) (T -84)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715)))) (-5 *1 (-84 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 137) (((-3 $ "failed") (-1280 (-332 (-592)))) 126) (((-3 $ "failed") (-1280 (-980 (-405)))) 158) (((-3 $ "failed") (-1280 (-980 (-592)))) 147) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 116) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 105)) (-2400 (($ (-1280 (-332 (-405)))) 133) (($ (-1280 (-332 (-592)))) 122) (($ (-1280 (-980 (-405)))) 154) (($ (-1280 (-980 (-592)))) 143) (($ (-1280 (-433 (-980 (-405))))) 112) (($ (-1280 (-433 (-980 (-592))))) 98)) (-3592 (((-1285) $) 91)) (-1683 (((-877) $) 85) (($ (-658 (-350))) 76) (($ (-350)) 83) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 81) (($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) 77))) 
+(((-85 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715))))))) (-1191)) (T -85)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) (-5 *1 (-85 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 73) (((-3 $ "failed") (-1280 (-332 (-592)))) 62) (((-3 $ "failed") (-1280 (-980 (-405)))) 95) (((-3 $ "failed") (-1280 (-980 (-592)))) 84) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 51) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 40)) (-2400 (($ (-1280 (-332 (-405)))) 69) (($ (-1280 (-332 (-592)))) 58) (($ (-1280 (-980 (-405)))) 91) (($ (-1280 (-980 (-592)))) 80) (($ (-1280 (-433 (-980 (-405))))) 47) (($ (-1280 (-433 (-980 (-592))))) 33)) (-3592 (((-1285) $) 121)) (-1683 (((-877) $) 115) (($ (-658 (-350))) 106) (($ (-350)) 112) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 110) (($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) 32))) 
+(((-86 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715))))))) (-1191)) (T -86)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) (-5 *1 (-86 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 90) (((-3 $ "failed") (-1280 (-332 (-592)))) 79) (((-3 $ "failed") (-1280 (-980 (-405)))) 112) (((-3 $ "failed") (-1280 (-980 (-592)))) 101) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 68) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 57)) (-2400 (($ (-1280 (-332 (-405)))) 86) (($ (-1280 (-332 (-592)))) 75) (($ (-1280 (-980 (-405)))) 108) (($ (-1280 (-980 (-592)))) 97) (($ (-1280 (-433 (-980 (-405))))) 64) (($ (-1280 (-433 (-980 (-592))))) 50)) (-3592 (((-1285) $) 43)) (-1683 (((-877) $) 36) (($ (-658 (-350))) 26) (($ (-350)) 29) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 32) (($ (-1280 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715)))) 27))) 
+(((-87 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715))))))) (-1191)) (T -87)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715)))) (-5 *1 (-87 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715))))))) 
+((-4368 (((-3 $ "failed") (-706 (-332 (-405)))) 103) (((-3 $ "failed") (-706 (-332 (-592)))) 92) (((-3 $ "failed") (-706 (-980 (-405)))) 125) (((-3 $ "failed") (-706 (-980 (-592)))) 114) (((-3 $ "failed") (-706 (-433 (-980 (-405))))) 82) (((-3 $ "failed") (-706 (-433 (-980 (-592))))) 71)) (-2400 (($ (-706 (-332 (-405)))) 99) (($ (-706 (-332 (-592)))) 88) (($ (-706 (-980 (-405)))) 121) (($ (-706 (-980 (-592)))) 110) (($ (-706 (-433 (-980 (-405))))) 78) (($ (-706 (-433 (-980 (-592))))) 64)) (-3592 (((-1285) $) 57)) (-1683 (((-877) $) 43) (($ (-658 (-350))) 50) (($ (-350)) 39) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 47) (($ (-706 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715)))) 40))) 
+(((-88 |#1|) (-13 (-410) (-10 -8 (-15 -1683 ($ (-706 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715))))))) (-1191)) (T -88)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-706 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715)))) (-5 *1 (-88 *3)) (-14 *3 (-1191))))) 
+(-13 (-410) (-10 -8 (-15 -1683 ($ (-706 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715))))))) 
+((-4368 (((-3 $ "failed") (-706 (-332 (-405)))) 103) (((-3 $ "failed") (-706 (-332 (-592)))) 92) (((-3 $ "failed") (-706 (-980 (-405)))) 124) (((-3 $ "failed") (-706 (-980 (-592)))) 113) (((-3 $ "failed") (-706 (-433 (-980 (-405))))) 81) (((-3 $ "failed") (-706 (-433 (-980 (-592))))) 70)) (-2400 (($ (-706 (-332 (-405)))) 99) (($ (-706 (-332 (-592)))) 88) (($ (-706 (-980 (-405)))) 120) (($ (-706 (-980 (-592)))) 109) (($ (-706 (-433 (-980 (-405))))) 77) (($ (-706 (-433 (-980 (-592))))) 63)) (-3592 (((-1285) $) 56)) (-1683 (((-877) $) 50) (($ (-658 (-350))) 44) (($ (-350)) 47) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 40) (($ (-706 (-359 (-4466 (QUOTE X)) (-4466) (-715)))) 41))) 
+(((-89 |#1|) (-13 (-410) (-10 -8 (-15 -1683 ($ (-706 (-359 (-4466 (QUOTE X)) (-4466) (-715))))))) (-1191)) (T -89)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-706 (-359 (-4466 (QUOTE X)) (-4466) (-715)))) (-5 *1 (-89 *3)) (-14 *3 (-1191))))) 
+(-13 (-410) (-10 -8 (-15 -1683 ($ (-706 (-359 (-4466 (QUOTE X)) (-4466) (-715))))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 99) (((-3 $ "failed") (-1280 (-332 (-592)))) 88) (((-3 $ "failed") (-1280 (-980 (-405)))) 121) (((-3 $ "failed") (-1280 (-980 (-592)))) 110) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 77) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 66)) (-2400 (($ (-1280 (-332 (-405)))) 95) (($ (-1280 (-332 (-592)))) 84) (($ (-1280 (-980 (-405)))) 117) (($ (-1280 (-980 (-592)))) 106) (($ (-1280 (-433 (-980 (-405))))) 73) (($ (-1280 (-433 (-980 (-592))))) 59)) (-3592 (((-1285) $) 45)) (-1683 (((-877) $) 39) (($ (-658 (-350))) 48) (($ (-350)) 35) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 51) (($ (-1280 (-359 (-4466 (QUOTE X)) (-4466) (-715)))) 36))) 
+(((-90 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X)) (-4466) (-715))))))) (-1191)) (T -90)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X)) (-4466) (-715)))) (-5 *1 (-90 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X)) (-4466) (-715))))))) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 74) (((-3 $ "failed") (-1280 (-332 (-592)))) 63) (((-3 $ "failed") (-1280 (-980 (-405)))) 96) (((-3 $ "failed") (-1280 (-980 (-592)))) 85) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 52) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 41)) (-2400 (($ (-1280 (-332 (-405)))) 70) (($ (-1280 (-332 (-592)))) 59) (($ (-1280 (-980 (-405)))) 92) (($ (-1280 (-980 (-592)))) 81) (($ (-1280 (-433 (-980 (-405))))) 48) (($ (-1280 (-433 (-980 (-592))))) 34)) (-3592 (((-1285) $) 122)) (-1683 (((-877) $) 116) (($ (-658 (-350))) 107) (($ (-350)) 113) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 111) (($ (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715)))) 33))) 
+(((-91 |#1|) (-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715))))))) (-1191)) (T -91)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715)))) (-5 *1 (-91 *3)) (-14 *3 (-1191))))) 
+(-13 (-466) (-10 -8 (-15 -1683 ($ (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715))))))) 
+((-4368 (((-3 $ "failed") (-706 (-332 (-405)))) 105) (((-3 $ "failed") (-706 (-332 (-592)))) 94) (((-3 $ "failed") (-706 (-980 (-405)))) 127) (((-3 $ "failed") (-706 (-980 (-592)))) 116) (((-3 $ "failed") (-706 (-433 (-980 (-405))))) 83) (((-3 $ "failed") (-706 (-433 (-980 (-592))))) 72)) (-2400 (($ (-706 (-332 (-405)))) 101) (($ (-706 (-332 (-592)))) 90) (($ (-706 (-980 (-405)))) 123) (($ (-706 (-980 (-592)))) 112) (($ (-706 (-433 (-980 (-405))))) 79) (($ (-706 (-433 (-980 (-592))))) 65)) (-3592 (((-1285) $) 58)) (-1683 (((-877) $) 52) (($ (-658 (-350))) 42) (($ (-350)) 49) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 47) (($ (-706 (-359 (-4466 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4466) (-715)))) 43))) 
+(((-92 |#1|) (-13 (-410) (-10 -8 (-15 -1683 ($ (-706 (-359 (-4466 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4466) (-715))))))) (-1191)) (T -92)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-706 (-359 (-4466 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4466) (-715)))) (-5 *1 (-92 *3)) (-14 *3 (-1191))))) 
+(-13 (-410) (-10 -8 (-15 -1683 ($ (-706 (-359 (-4466 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4466) (-715))))))) 
+((-3592 (((-1285) $) 44)) (-1683 (((-877) $) 38) (($ (-1280 (-715))) 88) (($ (-658 (-350))) 29) (($ (-350)) 35) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 32))) 
+(((-93 |#1|) (-465) (-1191)) (T -93)) 
+NIL 
+(-465) 
+((-4368 (((-3 $ "failed") (-332 (-405))) 42) (((-3 $ "failed") (-332 (-592))) 47) (((-3 $ "failed") (-980 (-405))) 52) (((-3 $ "failed") (-980 (-592))) 57) (((-3 $ "failed") (-433 (-980 (-405)))) 37) (((-3 $ "failed") (-433 (-980 (-592)))) 32)) (-2400 (($ (-332 (-405))) 40) (($ (-332 (-592))) 45) (($ (-980 (-405))) 50) (($ (-980 (-592))) 55) (($ (-433 (-980 (-405)))) 35) (($ (-433 (-980 (-592)))) 29)) (-3592 (((-1285) $) 88)) (-1683 (((-877) $) 82) (($ (-658 (-350))) 76) (($ (-350)) 79) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 73) (($ (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715))) 28))) 
+(((-94 |#1|) (-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715)))))) (-1191)) (T -94)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715))) (-5 *1 (-94 *3)) (-14 *3 (-1191))))) 
+(-13 (-422) (-10 -8 (-15 -1683 ($ (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715)))))) 
+((-2066 (((-1280 (-706 |#1|)) (-706 |#1|)) 54)) (-3176 (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 (-658 (-944))))) |#2| (-944)) 44)) (-1680 (((-2 (|:| |minor| (-658 (-944))) (|:| -2042 |#2|) (|:| |minors| (-658 (-658 (-944)))) (|:| |ops| (-658 |#2|))) |#2| (-944)) 62 (|has| |#1| (-388))))) 
+(((-95 |#1| |#2|) (-10 -7 (-15 -3176 ((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 (-658 (-944))))) |#2| (-944))) (-15 -2066 ((-1280 (-706 |#1|)) (-706 |#1|))) (IF (|has| |#1| (-388)) (-15 -1680 ((-2 (|:| |minor| (-658 (-944))) (|:| -2042 |#2|) (|:| |minors| (-658 (-658 (-944)))) (|:| |ops| (-658 |#2|))) |#2| (-944))) |noBranch|)) (-582) (-670 |#1|)) (T -95)) 
+((-1680 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |minor| (-658 (-944))) (|:| -2042 *3) (|:| |minors| (-658 (-658 (-944)))) (|:| |ops| (-658 *3)))) (-5 *1 (-95 *5 *3)) (-5 *4 (-944)) (-4 *3 (-670 *5)))) (-2066 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-1280 (-706 *4))) (-5 *1 (-95 *4 *5)) (-5 *3 (-706 *4)) (-4 *5 (-670 *4)))) (-3176 (*1 *2 *3 *4) (-12 (-4 *5 (-582)) (-5 *2 (-2 (|:| -3253 (-706 *5)) (|:| |vec| (-1280 (-658 (-944)))))) (-5 *1 (-95 *5 *3)) (-5 *4 (-944)) (-4 *3 (-670 *5))))) 
+(-10 -7 (-15 -3176 ((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 (-658 (-944))))) |#2| (-944))) (-15 -2066 ((-1280 (-706 |#1|)) (-706 |#1|))) (IF (|has| |#1| (-388)) (-15 -1680 ((-2 (|:| |minor| (-658 (-944))) (|:| -2042 |#2|) (|:| |minors| (-658 (-658 (-944)))) (|:| |ops| (-658 |#2|))) |#2| (-944))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3349 ((|#1| $) 34)) (-2126 (((-141) $ (-790)) NIL)) (-3001 (($) NIL T CONST)) (-3568 ((|#1| |#1| $) 30)) (-2486 ((|#1| $) 28)) (-4004 (((-658 |#1|) $) 39 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) 43 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 41)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4137 ((|#1| $) 45)) (-2113 (($ |#1| $) 31)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-2106 ((|#1| $) 29)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 16)) (-2890 (($) 38)) (-3439 (((-790) $) 26)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) 15)) (-1683 (((-877) $) 25 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) NIL)) (-3335 (($ (-658 |#1|)) 36)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 13 (|has| |#1| (-1119)))) (-1699 (((-790) $) 10 (|has| $ (-6 -4625))))) 
+(((-96 |#1|) (-13 (-1138 |#1|) (-10 -8 (-15 -3335 ($ (-658 |#1|))) (-15 -2486 (|#1| $)) (-15 -2106 (|#1| $)) (-15 -3568 (|#1| |#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -3349 (|#1| $)) (-15 -3439 ((-790) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -4560 ($ (-658 |#1|))) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -3001 ($)) (-15 -4599 ($ $)) (-15 -1724 ((-141) $ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) (-1119)) (T -96)) 
+((-1724 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) (-4599 (*1 *1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-2890 (*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-2943 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) (-2554 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-96 *4)) (-4 *4 (-1119)))) (-4345 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-96 *4)) (-4 *4 (-1119)))) (-2126 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-96 *4)) (-4 *4 (-1119)))) (-3001 (*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-96 *3)))) (-3987 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-1119)) (-5 *1 (-96 *3)))) (-3369 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-96 *4)))) (-3002 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-96 *4)))) (-3452 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-96 *4)))) (-4004 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) (-3452 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-3133 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-2685 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-2951 (*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-3255 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-1641 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-4560 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-96 *3)))) (-2106 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-2113 (*1 *1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-4137 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-3568 (*1 *2 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-2486 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-3349 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) (-3439 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) (-3335 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-96 *3))))) 
+(-13 (-1138 |#1|) (-10 -8 (-15 -3335 ($ (-658 |#1|))) (-15 -2486 (|#1| $)) (-15 -2106 (|#1| $)) (-15 -3568 (|#1| |#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -3349 (|#1| $)) (-15 -3439 ((-790) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -4560 ($ (-658 |#1|))) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -3001 ($)) (-15 -4599 ($ $)) (-15 -1724 ((-141) $ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) 
+NIL 
+(((-97) (-1311)) (T -97)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-98) (-1311)) (T -98)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-99) (-1311)) (T -99)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-100) (-1311)) (T -100)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-101) (-1311)) (T -101)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-102) (-1311)) (T -102)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-103) (-1311)) (T -103)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-104) (-1311)) (T -104)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-105) (-1311)) (T -105)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-106) (-1311)) (T -106)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-107) (-1311)) (T -107)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-108) (-1311)) (T -108)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-109) (-1311)) (T -109)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-110) (-1311)) (T -110)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-111) (-1311)) (T -111)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-112) (-1311)) (T -112)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-113) (-1311)) (T -113)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+NIL 
+(((-114) (-1311)) (T -114)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+((-1559 (($ $) 10)) (-1567 (($ $) 12))) 
+(((-115 |#1|) (-10 -8 (-15 -1567 (|#1| |#1|)) (-15 -1559 (|#1| |#1|))) (-116)) (T -115)) 
+NIL 
+(-10 -8 (-15 -1567 (|#1| |#1|)) (-15 -1559 (|#1| |#1|))) 
+((-1546 (($ $) 11)) (-1533 (($ $) 10)) (-1559 (($ $) 9)) (-1567 (($ $) 8)) (-1552 (($ $) 7)) (-1540 (($ $) 6))) 
+(((-116) (-1311)) (T -116)) 
+((-1546 (*1 *1 *1) (-4 *1 (-116))) (-1533 (*1 *1 *1) (-4 *1 (-116))) (-1559 (*1 *1 *1) (-4 *1 (-116))) (-1567 (*1 *1 *1) (-4 *1 (-116))) (-1552 (*1 *1 *1) (-4 *1 (-116))) (-1540 (*1 *1 *1) (-4 *1 (-116)))) 
+(-13 (-10 -8 (-15 -1540 ($ $)) (-15 -1552 ($ $)) (-15 -1567 ($ $)) (-15 -1559 ($ $)) (-15 -1533 ($ $)) (-15 -1546 ($ $)))) 
+NIL 
+(((-117) (-1311)) (T -117)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+((-1641 (((-141) $ $) NIL)) (-2546 (((-405) (-1173) (-405)) 42) (((-405) (-1173) (-1173) (-405)) 41)) (-3487 (((-405) (-405)) 33)) (-3790 (((-1285)) 36)) (-2685 (((-1173) $) NIL)) (-1471 (((-405) (-1173) (-1173)) 46) (((-405) (-1173)) 48)) (-2951 (((-1137) $) NIL)) (-2602 (((-405) (-1173) (-1173)) 47)) (-1921 (((-405) (-1173) (-1173)) 49) (((-405) (-1173)) 50)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-118) (-13 (-1119) (-10 -7 (-15 -1471 ((-405) (-1173) (-1173))) (-15 -1471 ((-405) (-1173))) (-15 -1921 ((-405) (-1173) (-1173))) (-15 -1921 ((-405) (-1173))) (-15 -2602 ((-405) (-1173) (-1173))) (-15 -3790 ((-1285))) (-15 -3487 ((-405) (-405))) (-15 -2546 ((-405) (-1173) (-405))) (-15 -2546 ((-405) (-1173) (-1173) (-405))) (-6 -4625)))) (T -118)) 
+((-1471 (*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118)))) (-1471 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118)))) (-1921 (*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118)))) (-1921 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118)))) (-2602 (*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118)))) (-3790 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-118)))) (-3487 (*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-118)))) (-2546 (*1 *2 *3 *2) (-12 (-5 *2 (-405)) (-5 *3 (-1173)) (-5 *1 (-118)))) (-2546 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-405)) (-5 *3 (-1173)) (-5 *1 (-118))))) 
+(-13 (-1119) (-10 -7 (-15 -1471 ((-405) (-1173) (-1173))) (-15 -1471 ((-405) (-1173))) (-15 -1921 ((-405) (-1173) (-1173))) (-15 -1921 ((-405) (-1173))) (-15 -2602 ((-405) (-1173) (-1173))) (-15 -3790 ((-1285))) (-15 -3487 ((-405) (-405))) (-15 -2546 ((-405) (-1173) (-405))) (-15 -2546 ((-405) (-1173) (-1173) (-405))) (-6 -4625))) 
+NIL 
+(((-119) (-1311)) (T -119)) 
+NIL 
+(-13 (-10 -7 (-6 -4625) (-6 (-4627 "*")) (-6 -4626) (-6 -4622) (-6 -4620) (-6 -4619) (-6 -4618) (-6 -4623) (-6 -4617) (-6 -4616) (-6 -4615) (-6 -4614) (-6 -4613) (-6 -4621) (-6 -4624) (-6 |NullSquare|) (-6 |JacobiIdentity|) (-6 -4612) (-6 -2642))) 
+NIL 
+(((-120) (-1311)) (T -120)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+((-1641 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-2333 (($ (-1 |#1| |#1|)) 25) (($ (-1 |#1| |#1|) (-1 |#1| |#1|)) 24) (($ (-1 |#1| |#1| (-592))) 22)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 14)) (-2951 (((-1137) $) NIL)) (-3927 ((|#1| $ |#1|) 11)) (-2227 (($ $ $) NIL)) (-2131 (($ $ $) NIL)) (-1683 (((-877) $) 20)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-4257 (($) 8 T CONST)) (-3255 (((-141) $ $) 10)) (-3313 (($ $ $) NIL)) (** (($ $ (-944)) 28) (($ $ (-790)) NIL) (($ $ (-592)) 16)) (* (($ $ $) 29))) 
+(((-121 |#1|) (-13 (-502) (-303 |#1| |#1|) (-10 -8 (-15 -2333 ($ (-1 |#1| |#1|))) (-15 -2333 ($ (-1 |#1| |#1|) (-1 |#1| |#1|))) (-15 -2333 ($ (-1 |#1| |#1| (-592)))))) (-1075)) (T -121)) 
+((-2333 (*1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-121 *3)))) (-2333 (*1 *1 *2 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-121 *3)))) (-2333 (*1 *1 *2) (-12 (-5 *2 (-1 *3 *3 (-592))) (-4 *3 (-1075)) (-5 *1 (-121 *3))))) 
+(-13 (-502) (-303 |#1| |#1|) (-10 -8 (-15 -2333 ($ (-1 |#1| |#1|))) (-15 -2333 ($ (-1 |#1| |#1|) (-1 |#1| |#1|))) (-15 -2333 ($ (-1 |#1| |#1| (-592)))))) 
+((-4497 (((-1285) (-1123)) 20)) (-2293 (((-1173) (-1173) (-1173)) 7)) (-2464 (((-1285) (-592) (-1 (-1285) (-1123))) 14))) 
+(((-122) (-10 -7 (-15 -2464 ((-1285) (-592) (-1 (-1285) (-1123)))) (-15 -4497 ((-1285) (-1123))) (-15 -2293 ((-1173) (-1173) (-1173))))) (T -122)) 
+((-2293 (*1 *2 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-122)))) (-4497 (*1 *2 *3) (-12 (-5 *3 (-1123)) (-5 *2 (-1285)) (-5 *1 (-122)))) (-2464 (*1 *2 *3 *4) (-12 (-5 *3 (-592)) (-5 *4 (-1 (-1285) (-1123))) (-5 *2 (-1285)) (-5 *1 (-122))))) 
+(-10 -7 (-15 -2464 ((-1285) (-592) (-1 (-1285) (-1123)))) (-15 -4497 ((-1285) (-1123))) (-15 -2293 ((-1173) (-1173) (-1173)))) 
+((-2622 (((-444 |#2|) |#2| (-658 |#2|)) 10) (((-444 |#2|) |#2| |#2|) 11))) 
+(((-123 |#1| |#2|) (-10 -7 (-15 -2622 ((-444 |#2|) |#2| |#2|)) (-15 -2622 ((-444 |#2|) |#2| (-658 |#2|)))) (-13 (-477) (-171)) (-1255 |#1|)) (T -123)) 
+((-2622 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-13 (-477) (-171))) (-5 *2 (-444 *3)) (-5 *1 (-123 *5 *3)))) (-2622 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-477) (-171))) (-5 *2 (-444 *3)) (-5 *1 (-123 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -2622 ((-444 |#2|) |#2| |#2|)) (-15 -2622 ((-444 |#2|) |#2| (-658 |#2|)))) 
+((-1641 (((-141) $ $) 9))) 
+(((-124 |#1|) (-10 -8 (-15 -1641 ((-141) |#1| |#1|))) (-125)) (T -124)) 
+NIL 
+(-10 -8 (-15 -1641 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-3255 (((-141) $ $) 6))) 
+(((-125) (-1311)) (T -125)) 
+((-1641 (*1 *2 *1 *1) (-12 (-4 *1 (-125)) (-5 *2 (-141)))) (-3255 (*1 *2 *1 *1) (-12 (-4 *1 (-125)) (-5 *2 (-141))))) 
+(-13 (-10 -8 (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) 13 (|has| $ (-6 -4626)))) (-2949 (($ $ $) NIL (|has| $ (-6 -4626)))) (-1348 (($ $ $) NIL (|has| $ (-6 -4626)))) (-3492 (($ $ (-658 |#1|)) 15)) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) (($ $ "left" $) NIL (|has| $ (-6 -4626))) (($ $ "right" $) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-1954 (($ $) 11)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-4245 (($ $ |#1| $) 17)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3464 ((|#1| $ (-1 |#1| |#1| |#1|)) 25) (($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|)) 30)) (-2611 (($ $ |#1| (-1 |#1| |#1| |#1|)) 31) (($ $ |#1| (-1 (-658 |#1|) |#1| |#1| |#1|)) 35)) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-1961 (($ $) 10)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) 12)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 9)) (-2890 (($) 16)) (-3927 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-2920 (((-592) $ $) NIL)) (-3228 (((-141) $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1702 (($ (-790) |#1|) 19)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-126 |#1|) (-13 (-155 |#1|) (-10 -8 (-6 -4625) (-6 -4626) (-15 -1702 ($ (-790) |#1|)) (-15 -3492 ($ $ (-658 |#1|))) (-15 -3464 (|#1| $ (-1 |#1| |#1| |#1|))) (-15 -3464 ($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|))) (-15 -2611 ($ $ |#1| (-1 |#1| |#1| |#1|))) (-15 -2611 ($ $ |#1| (-1 (-658 |#1|) |#1| |#1| |#1|))))) (-1119)) (T -126)) 
+((-1702 (*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *1 (-126 *3)) (-4 *3 (-1119)))) (-3492 (*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-126 *3)))) (-3464 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *1 (-126 *2)) (-4 *2 (-1119)))) (-3464 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3 *3 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-126 *3)))) (-2611 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1119)) (-5 *1 (-126 *2)))) (-2611 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 (-658 *2) *2 *2 *2)) (-4 *2 (-1119)) (-5 *1 (-126 *2))))) 
+(-13 (-155 |#1|) (-10 -8 (-6 -4625) (-6 -4626) (-15 -1702 ($ (-790) |#1|)) (-15 -3492 ($ $ (-658 |#1|))) (-15 -3464 (|#1| $ (-1 |#1| |#1| |#1|))) (-15 -3464 ($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|))) (-15 -2611 ($ $ |#1| (-1 |#1| |#1| |#1|))) (-15 -2611 ($ $ |#1| (-1 (-658 |#1|) |#1| |#1| |#1|))))) 
+((-3018 (((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|)) 20)) (-3317 (((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|)) 17)) (-3946 (((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|)) 21))) 
+(((-127 |#1|) (-10 -7 (-15 -3317 ((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|))) (-15 -3018 ((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|))) (-15 -3946 ((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|)))) (-1075)) (T -127)) 
+((-3946 (*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-1 (-658 *4) *4)) (-5 *1 (-127 *4)) (-5 *3 (-658 *4)))) (-3018 (*1 *2 *3 *3 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-1 (-658 *4) *4)) (-5 *1 (-127 *4)) (-5 *3 (-658 *4)))) (-3317 (*1 *2 *3 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-1 (-658 *4) *4)) (-5 *1 (-127 *4)) (-5 *3 (-658 *4))))) 
+(-10 -7 (-15 -3317 ((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|))) (-15 -3018 ((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|))) (-15 -3946 ((-1 (-658 |#1|) |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|) (-658 |#1|)))) 
+((-3211 ((|#3| |#2| |#2|) 28)) (-4604 ((|#1| |#2| |#2|) 36 (|has| |#1| (-6 (-4627 "*"))))) (-1791 ((|#3| |#2| |#2|) 29)) (-2957 ((|#1| |#2|) 40 (|has| |#1| (-6 (-4627 "*")))))) 
+(((-128 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3211 (|#3| |#2| |#2|)) (-15 -1791 (|#3| |#2| |#2|)) (IF (|has| |#1| (-6 (-4627 "*"))) (PROGN (-15 -4604 (|#1| |#2| |#2|)) (-15 -2957 (|#1| |#2|))) |noBranch|)) (-1075) (-1255 |#1|) (-704 |#1| |#4| |#5|) (-399 |#1|) (-399 |#1|)) (T -128)) 
+((-2957 (*1 *2 *3) (-12 (|has| *2 (-6 (-4627 "*"))) (-4 *5 (-399 *2)) (-4 *6 (-399 *2)) (-4 *2 (-1075)) (-5 *1 (-128 *2 *3 *4 *5 *6)) (-4 *3 (-1255 *2)) (-4 *4 (-704 *2 *5 *6)))) (-4604 (*1 *2 *3 *3) (-12 (|has| *2 (-6 (-4627 "*"))) (-4 *5 (-399 *2)) (-4 *6 (-399 *2)) (-4 *2 (-1075)) (-5 *1 (-128 *2 *3 *4 *5 *6)) (-4 *3 (-1255 *2)) (-4 *4 (-704 *2 *5 *6)))) (-1791 (*1 *2 *3 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-128 *4 *3 *2 *5 *6)) (-4 *3 (-1255 *4)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)))) (-3211 (*1 *2 *3 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-128 *4 *3 *2 *5 *6)) (-4 *3 (-1255 *4)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4))))) 
+(-10 -7 (-15 -3211 (|#3| |#2| |#2|)) (-15 -1791 (|#3| |#2| |#2|)) (IF (|has| |#1| (-6 (-4627 "*"))) (PROGN (-15 -4604 (|#1| |#2| |#2|)) (-15 -2957 (|#1| |#2|))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-2757 (((-658 (-1191))) 32)) (-3448 (((-2 (|:| |zeros| (-1171 (-237))) (|:| |ones| (-1171 (-237))) (|:| |singularities| (-1171 (-237)))) (-1191)) 35)) (-3255 (((-141) $ $) NIL))) 
+(((-129) (-13 (-1119) (-10 -7 (-15 -2757 ((-658 (-1191)))) (-15 -3448 ((-2 (|:| |zeros| (-1171 (-237))) (|:| |ones| (-1171 (-237))) (|:| |singularities| (-1171 (-237)))) (-1191))) (-6 -4625)))) (T -129)) 
+((-2757 (*1 *2) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-129)))) (-3448 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-2 (|:| |zeros| (-1171 (-237))) (|:| |ones| (-1171 (-237))) (|:| |singularities| (-1171 (-237))))) (-5 *1 (-129))))) 
+(-13 (-1119) (-10 -7 (-15 -2757 ((-658 (-1191)))) (-15 -3448 ((-2 (|:| |zeros| (-1171 (-237))) (|:| |ones| (-1171 (-237))) (|:| |singularities| (-1171 (-237)))) (-1191))) (-6 -4625))) 
+((-4560 (($ (-658 |#2|)) 11))) 
+(((-130 |#1| |#2|) (-10 -8 (-15 -4560 (|#1| (-658 |#2|)))) (-131 |#2|) (-1225)) (T -130)) 
+NIL 
+(-10 -8 (-15 -4560 (|#1| (-658 |#2|)))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-3001 (($) 7 T CONST)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-131 |#1|) (-1311) (-1225)) (T -131)) 
+((-4560 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-4 *1 (-131 *3)))) (-2106 (*1 *2 *1) (-12 (-4 *1 (-131 *2)) (-4 *2 (-1225)))) (-2113 (*1 *1 *2 *1) (-12 (-4 *1 (-131 *2)) (-4 *2 (-1225)))) (-4137 (*1 *2 *1) (-12 (-4 *1 (-131 *2)) (-4 *2 (-1225))))) 
+(-13 (-523 |t#1|) (-10 -8 (-6 -4626) (-15 -4560 ($ (-658 |t#1|))) (-15 -2106 (|t#1| $)) (-15 -2113 ($ |t#1| $)) (-15 -4137 (|t#1| $)))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 (((-592) $) NIL (|has| (-592) (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| (-592) (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL (|has| (-592) (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-592) (-1065 (-592)))) (((-3 (-592) "failed") $) NIL (|has| (-592) (-1065 (-592))))) (-2400 (((-592) $) NIL) (((-1191) $) NIL (|has| (-592) (-1065 (-1191)))) (((-433 (-592)) $) NIL (|has| (-592) (-1065 (-592)))) (((-592) $) NIL (|has| (-592) (-1065 (-592))))) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-592) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-592) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-706 (-592)) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-592) (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) NIL (|has| (-592) (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| (-592) (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| (-592) (-908 (-405))))) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL)) (-1448 (((-592) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| (-592) (-1165)))) (-1324 (((-141) $) NIL (|has| (-592) (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-592) (-869)))) (-2731 (($ (-1 (-592) (-592)) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-592) (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| (-592) (-323))) (((-433 (-592)) $) NIL)) (-2039 (((-592) $) NIL (|has| (-592) (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 (-592)) (-658 (-592))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-592) (-592)) NIL (|has| (-592) (-325 (-592)))) (($ $ (-310 (-592))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-658 (-310 (-592)))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-658 (-1191)) (-658 (-592))) NIL (|has| (-592) (-547 (-1191) (-592)))) (($ $ (-1191) (-592)) NIL (|has| (-592) (-547 (-1191) (-592))))) (-2769 (((-790) $) NIL)) (-3927 (($ $ (-592)) NIL (|has| (-592) (-303 (-592) (-592))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL (|has| (-592) (-247))) (($ $ (-790)) NIL (|has| (-592) (-247))) (($ $ (-1191)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1 (-592) (-592)) (-790)) NIL) (($ $ (-1 (-592) (-592))) NIL)) (-2782 (($ $) NIL)) (-1456 (((-592) $) NIL)) (-1778 (((-914 (-592)) $) NIL (|has| (-592) (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| (-592) (-633 (-914 (-405))))) (((-565) $) NIL (|has| (-592) (-633 (-565)))) (((-405) $) NIL (|has| (-592) (-1049))) (((-237) $) NIL (|has| (-592) (-1049)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-592) (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) 7) (($ (-592)) NIL) (($ (-1191)) NIL (|has| (-592) (-1065 (-1191)))) (((-433 (-592)) $) NIL) (((-1032 2) $) 9)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-592) (-931))) (|has| (-592) (-169))))) (-4010 (((-790)) NIL)) (-2744 (((-592) $) NIL (|has| (-592) (-574)))) (-2514 (($ (-433 (-592))) 8)) (-2537 (((-141) $ $) NIL)) (-1392 (($ $) NIL (|has| (-592) (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $) NIL (|has| (-592) (-247))) (($ $ (-790)) NIL (|has| (-592) (-247))) (($ $ (-1191)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1 (-592) (-592)) (-790)) NIL) (($ $ (-1 (-592) (-592))) NIL)) (-3286 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3313 (($ $ $) NIL) (($ (-592) (-592)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ (-592) $) NIL) (($ $ (-592)) NIL))) 
+(((-132) (-13 (-1021 (-592)) (-10 -8 (-15 -1683 ((-433 (-592)) $)) (-15 -1683 ((-1032 2) $)) (-15 -3856 ((-433 (-592)) $)) (-15 -2514 ($ (-433 (-592))))))) (T -132)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-132)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1032 2)) (-5 *1 (-132)))) (-3856 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-132)))) (-2514 (*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-132))))) 
+(-13 (-1021 (-592)) (-10 -8 (-15 -1683 ((-433 (-592)) $)) (-15 -1683 ((-1032 2) $)) (-15 -3856 ((-433 (-592)) $)) (-15 -2514 ($ (-433 (-592)))))) 
+((-1641 (((-141) $ $) NIL)) (-3388 (((-1137) $ (-1137)) 23)) (-2820 (($ $ (-1173)) 17)) (-3463 (((-3 (-1137) "failed") $) 22)) (-4393 (((-1137) $) 20)) (-2208 (((-1137) $ (-1137)) 25)) (-1721 (((-1137) $) 24)) (-1774 (($ (-414)) NIL) (($ (-414) (-1173)) 16)) (-4095 (((-414) $) NIL)) (-2685 (((-1173) $) NIL)) (-2690 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4342 (((-1285) $) NIL)) (-1683 (((-877) $) NIL)) (-2607 (($ $) 18)) (-3255 (((-141) $ $) NIL))) 
+(((-133) (-13 (-389 (-414) (-1137)) (-10 -8 (-15 -3463 ((-3 (-1137) "failed") $)) (-15 -1721 ((-1137) $)) (-15 -2208 ((-1137) $ (-1137)))))) (T -133)) 
+((-3463 (*1 *2 *1) (|partial| -12 (-5 *2 (-1137)) (-5 *1 (-133)))) (-1721 (*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-133)))) (-2208 (*1 *2 *1 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-133))))) 
+(-13 (-389 (-414) (-1137)) (-10 -8 (-15 -3463 ((-3 (-1137) "failed") $)) (-15 -1721 ((-1137) $)) (-15 -2208 ((-1137) $ (-1137))))) 
+((-1641 (((-141) $ $) NIL)) (-3163 (($ $) NIL)) (-2773 (($ $ $) NIL)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) $) NIL (|has| (-141) (-869))) (((-141) (-1 (-141) (-141) (-141)) $) NIL)) (-2831 (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-141) (-869)))) (($ (-1 (-141) (-141) (-141)) $) NIL (|has| $ (-6 -4626)))) (-3960 (($ $) NIL (|has| (-141) (-869))) (($ (-1 (-141) (-141) (-141)) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-141) $ (-1246 (-592)) (-141)) NIL (|has| $ (-6 -4626))) (((-141) $ (-592) (-141)) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-4459 (($ (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625))) (($ (-141) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-3657 (((-141) (-1 (-141) (-141) (-141)) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-141) (-141)) $ (-141)) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-141) (-141)) $ (-141) (-141)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-1426 (((-141) $ (-592) (-141)) NIL (|has| $ (-6 -4626)))) (-3959 (((-141) $ (-592)) NIL)) (-1721 (((-592) (-141) $ (-592)) NIL (|has| (-141) (-1119))) (((-592) (-141) $) NIL (|has| (-141) (-1119))) (((-592) (-1 (-141) (-141)) $) NIL)) (-4004 (((-658 (-141)) $) NIL (|has| $ (-6 -4625)))) (-3573 (($ $ $) NIL)) (-3252 (($ $) NIL)) (-1419 (($ $ $) NIL)) (-3242 (($ (-790) (-141)) 8)) (-3782 (($ $ $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL)) (-4491 (($ $ $) NIL (|has| (-141) (-869))) (($ (-1 (-141) (-141) (-141)) $ $) NIL)) (-4467 (((-658 (-141)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-141) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL)) (-3987 (($ (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-141) (-141) (-141)) $ $) NIL) (($ (-1 (-141) (-141)) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-3666 (($ $ $ (-592)) NIL) (($ (-141) $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-141) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-141) "failed") (-1 (-141) (-141)) $) NIL)) (-1892 (($ $ (-141)) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-141)) (-658 (-141))) NIL (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-141) (-141)) NIL (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-310 (-141))) NIL (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-658 (-310 (-141)))) NIL (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-141) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-4210 (((-658 (-141)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 (($ $ (-1246 (-592))) NIL) (((-141) $ (-592)) NIL) (((-141) $ (-592) (-141)) NIL)) (-3208 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-3452 (((-790) (-141) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119)))) (((-790) (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625)))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-141) (-633 (-565))))) (-4466 (($ (-658 (-141))) NIL)) (-2266 (($ (-658 $)) NIL) (($ $ $) NIL) (($ (-141) $) NIL) (($ $ (-141)) NIL)) (-1683 (((-877) $) NIL)) (-3671 (($ (-790) (-141)) 9)) (-3369 (((-141) (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625)))) (-1732 (($ $ $) NIL)) (-1424 (($ $) NIL)) (-1623 (($ $ $) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-1616 (($ $ $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-134) (-13 (-153) (-10 -8 (-15 -3671 ($ (-790) (-141)))))) (T -134)) 
+((-3671 (*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-141)) (-5 *1 (-134))))) 
+(-13 (-153) (-10 -8 (-15 -3671 ($ (-790) (-141))))) 
+((-2154 (((-986 (-191 (-237))) (-1137) (-191 (-237)) (-986 (-191 (-237))) (-1137) (-986 (-191 (-237))) (-1137)) 33)) (-2144 (((-592) (-1137) (-986 (-191 (-237))) (-1137)) 32)) (-1980 (((-592) (-592) (-986 (-405)) (-592)) 31)) (-2488 (((-592) (-592) (-986 (-237)) (-592)) 29)) (-3182 (((-592) (-592) (-986 (-191 (-405))) (-592)) 28)) (-2566 (((-237) (-1137) (-986 (-191 (-237))) (-1137)) 25)) (-2440 (((-237) (-1137) (-986 (-191 (-237))) (-1137)) 24)) (-1433 (((-658 (-986 (-237))) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137)) 22)) (-3947 (((-986 (-237)) (-1137) (-237) (-986 (-237)) (-1137)) 21)) (-3716 (((-986 (-237)) (-237) (-237) (-237) (-237)) 18)) (-1523 (((-658 (-986 (-237))) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137) (-237) (-237)) 20)) (-3340 (((-237) (-1137) (-986 (-237)) (-1137)) 17)) (-1391 (((-237) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137)) 16)) (-1997 (((-986 (-237)) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137)) 15)) (-4395 (((-237) (-191 (-237))) 10)) (-1536 (((-986 (-237)) (-1137) (-237) (-986 (-237)) (-1137) (-986 (-237)) (-1137)) 14)) (-3003 (((-237) (-1137) (-986 (-237)) (-1137)) 13))) 
+(((-135) (-10 -7 (-15 -4395 ((-237) (-191 (-237)))) (-15 -3003 ((-237) (-1137) (-986 (-237)) (-1137))) (-15 -1536 ((-986 (-237)) (-1137) (-237) (-986 (-237)) (-1137) (-986 (-237)) (-1137))) (-15 -1997 ((-986 (-237)) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137))) (-15 -1391 ((-237) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137))) (-15 -3340 ((-237) (-1137) (-986 (-237)) (-1137))) (-15 -3716 ((-986 (-237)) (-237) (-237) (-237) (-237))) (-15 -1523 ((-658 (-986 (-237))) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137) (-237) (-237))) (-15 -3947 ((-986 (-237)) (-1137) (-237) (-986 (-237)) (-1137))) (-15 -1433 ((-658 (-986 (-237))) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137))) (-15 -2440 ((-237) (-1137) (-986 (-191 (-237))) (-1137))) (-15 -2566 ((-237) (-1137) (-986 (-191 (-237))) (-1137))) (-15 -3182 ((-592) (-592) (-986 (-191 (-405))) (-592))) (-15 -2488 ((-592) (-592) (-986 (-237)) (-592))) (-15 -1980 ((-592) (-592) (-986 (-405)) (-592))) (-15 -2144 ((-592) (-1137) (-986 (-191 (-237))) (-1137))) (-15 -2154 ((-986 (-191 (-237))) (-1137) (-191 (-237)) (-986 (-191 (-237))) (-1137) (-986 (-191 (-237))) (-1137))))) (T -135)) 
+((-2154 (*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-986 (-191 (-237)))) (-5 *3 (-1137)) (-5 *4 (-191 (-237))) (-5 *1 (-135)))) (-2144 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-191 (-237)))) (-5 *2 (-592)) (-5 *1 (-135)))) (-1980 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-592)) (-5 *3 (-986 (-405))) (-5 *1 (-135)))) (-2488 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-592)) (-5 *3 (-986 (-237))) (-5 *1 (-135)))) (-3182 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-592)) (-5 *3 (-986 (-191 (-405)))) (-5 *1 (-135)))) (-2566 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-191 (-237)))) (-5 *2 (-237)) (-5 *1 (-135)))) (-2440 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-191 (-237)))) (-5 *2 (-237)) (-5 *1 (-135)))) (-1433 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *2 (-658 (-986 (-237)))) (-5 *1 (-135)) (-5 *4 (-986 (-237))))) (-3947 (*1 *2 *3 *4 *2 *3) (-12 (-5 *2 (-986 (-237))) (-5 *3 (-1137)) (-5 *4 (-237)) (-5 *1 (-135)))) (-1523 (*1 *2 *3 *4 *3 *4 *3 *5 *5) (-12 (-5 *3 (-1137)) (-5 *5 (-237)) (-5 *2 (-658 (-986 *5))) (-5 *1 (-135)) (-5 *4 (-986 *5)))) (-3716 (*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-986 (-237))) (-5 *1 (-135)) (-5 *3 (-237)))) (-3340 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-237))) (-5 *2 (-237)) (-5 *1 (-135)))) (-1391 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-237))) (-5 *2 (-237)) (-5 *1 (-135)))) (-1997 (*1 *2 *3 *2 *3 *2 *3) (-12 (-5 *2 (-986 (-237))) (-5 *3 (-1137)) (-5 *1 (-135)))) (-1536 (*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-986 (-237))) (-5 *3 (-1137)) (-5 *4 (-237)) (-5 *1 (-135)))) (-3003 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-237))) (-5 *2 (-237)) (-5 *1 (-135)))) (-4395 (*1 *2 *3) (-12 (-5 *3 (-191 (-237))) (-5 *2 (-237)) (-5 *1 (-135))))) 
+(-10 -7 (-15 -4395 ((-237) (-191 (-237)))) (-15 -3003 ((-237) (-1137) (-986 (-237)) (-1137))) (-15 -1536 ((-986 (-237)) (-1137) (-237) (-986 (-237)) (-1137) (-986 (-237)) (-1137))) (-15 -1997 ((-986 (-237)) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137))) (-15 -1391 ((-237) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137))) (-15 -3340 ((-237) (-1137) (-986 (-237)) (-1137))) (-15 -3716 ((-986 (-237)) (-237) (-237) (-237) (-237))) (-15 -1523 ((-658 (-986 (-237))) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137) (-237) (-237))) (-15 -3947 ((-986 (-237)) (-1137) (-237) (-986 (-237)) (-1137))) (-15 -1433 ((-658 (-986 (-237))) (-1137) (-986 (-237)) (-1137) (-986 (-237)) (-1137))) (-15 -2440 ((-237) (-1137) (-986 (-191 (-237))) (-1137))) (-15 -2566 ((-237) (-1137) (-986 (-191 (-237))) (-1137))) (-15 -3182 ((-592) (-592) (-986 (-191 (-405))) (-592))) (-15 -2488 ((-592) (-592) (-986 (-237)) (-592))) (-15 -1980 ((-592) (-592) (-986 (-405)) (-592))) (-15 -2144 ((-592) (-1137) (-986 (-191 (-237))) (-1137))) (-15 -2154 ((-986 (-191 (-237))) (-1137) (-191 (-237)) (-986 (-191 (-237))) (-1137) (-986 (-191 (-237))) (-1137)))) 
+((-1641 (((-141) $ $) NIL)) (-4039 (((-3 "left" "center" "right" "vertical" "horizontal") $) 17)) (-3531 (((-592) $) 14)) (-3676 (((-592) $) 15)) (-3852 (((-592) $) 16)) (-2685 (((-1173) $) NIL)) (-3899 (((-141) $) 8)) (-2951 (((-1137) $) NIL)) (-1873 (((-592) $) 12)) (-3441 (($ (-592) (-592) (-592) (-592) (-592) (-141) (-3 "left" "center" "right" "vertical" "horizontal")) 11)) (-1683 (((-877) $) 19) (($ (-658 (-592))) NIL)) (-2392 (((-592) $) 13)) (-3255 (((-141) $ $) NIL))) 
+(((-136) (-13 (-137) (-10 -7 (-6 |HamburgerNoether|)))) (T -136)) 
+NIL 
+(-13 (-137) (-10 -7 (-6 |HamburgerNoether|))) 
+((-1641 (((-141) $ $) 7)) (-4039 (((-3 "left" "center" "right" "vertical" "horizontal") $) 12)) (-3531 (((-592) $) 17)) (-3676 (((-592) $) 15)) (-3852 (((-592) $) 13)) (-2685 (((-1173) $) 9)) (-3899 (((-141) $) 14)) (-2951 (((-1137) $) 10)) (-1873 (((-592) $) 19)) (-3441 (($ (-592) (-592) (-592) (-592) (-592) (-141) (-3 "left" "center" "right" "vertical" "horizontal")) 16)) (-1683 (((-877) $) 11) (($ (-658 (-592))) 20)) (-2392 (((-592) $) 18)) (-3255 (((-141) $ $) 6))) 
+(((-137) (-1311)) (T -137)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-4 *1 (-137)))) (-1873 (*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592)))) (-2392 (*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592)))) (-3531 (*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592)))) (-3441 (*1 *1 *2 *2 *2 *2 *2 *3 *4) (-12 (-5 *2 (-592)) (-5 *3 (-141)) (-5 *4 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *1 (-137)))) (-3676 (*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592)))) (-3899 (*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-141)))) (-3852 (*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592)))) (-4039 (*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-3 "left" "center" "right" "vertical" "horizontal"))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-658 (-592)))) (-15 -1873 ((-592) $)) (-15 -2392 ((-592) $)) (-15 -3531 ((-592) $)) (-15 -3441 ($ (-592) (-592) (-592) (-592) (-592) (-141) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -3676 ((-592) $)) (-15 -3899 ((-141) $)) (-15 -3852 ((-592) $)) (-15 -4039 ((-3 "left" "center" "right" "vertical" "horizontal") $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-4039 (((-3 "left" "center" "right" "vertical" "horizontal") $) NIL)) (-3531 (((-592) $) 14)) (-3676 (((-592) $) 11)) (-3852 (((-592) $) 15)) (-2685 (((-1173) $) NIL)) (-3899 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-1873 (((-592) $) 12)) (-3441 (($ (-592) (-592) (-592) (-592) (-592) (-141) (-3 "left" "center" "right" "vertical" "horizontal")) NIL)) (-1683 (((-877) $) 17) (($ (-658 (-592))) 10)) (-2392 (((-592) $) 13)) (-3255 (((-141) $ $) NIL))) 
+(((-138) (-13 (-137) (-10 -7 (-6 |QuadraticTransform|)))) (T -138)) 
+NIL 
+(-13 (-137) (-10 -7 (-6 |QuadraticTransform|))) 
+((-2145 (((-2 (|:| |mult| (-790)) (|:| |subMult| (-790)) (|:| |blUpRec| (-658 (-2 (|:| |recTransStr| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-33 |#1|) |#5| |#1|) 70)) (-4165 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-790) |#5|) 54)) (-2842 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) |#3| |#5|) 99)) (-2268 (((-658 (-658 (-790))) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|)) NIL)) (-1888 ((|#3| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) |#5|) 105)) (-3699 ((|#3| |#3| |#5|) 107))) 
+(((-139 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3699 (|#3| |#3| |#5|)) (-15 -4165 ((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-790) |#5|)) (-15 -2145 ((-2 (|:| |mult| (-790)) (|:| |subMult| (-790)) (|:| |blUpRec| (-658 (-2 (|:| |recTransStr| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-33 |#1|) |#5| |#1|)) (-15 -2268 ((-658 (-658 (-790))) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|))) (-15 -2842 ((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) |#3| |#5|)) (-15 -1888 (|#3| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) |#5|))) (-388) (-658 (-1191)) (-346 |#1| |#4|) (-252 (-1699 |#2|) (-790)) (-137)) (T -139)) 
+((-1888 (*1 *2 *3 *4) (-12 (-5 *3 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *5)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *2 (-346 *5 *7)) (-5 *1 (-139 *5 *6 *2 *7 *4)) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *4 (-137)))) (-2842 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-5 *2 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *5)) (-5 *1 (-139 *5 *6 *3 *7 *4)) (-4 *3 (-346 *5 *7)) (-4 *4 (-137)))) (-2268 (*1 *2 *3) (-12 (-5 *3 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *4)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-5 *2 (-658 (-658 (-790)))) (-5 *1 (-139 *4 *5 *6 *7 *8)) (-4 *6 (-346 *4 *7)) (-4 *8 (-137)))) (-2145 (*1 *2 *3 *4 *5 *6) (-12 (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *9 (-252 (-1699 *7) (-790))) (-5 *2 (-2 (|:| |mult| (-790)) (|:| |subMult| (-790)) (|:| |blUpRec| (-658 (-2 (|:| |recTransStr| (-264 (-4466 (QUOTE X) (QUOTE -3820)) *6)) (|:| |recPoint| (-33 *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (-5 *1 (-139 *6 *7 *8 *9 *5)) (-5 *3 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *6)) (-5 *4 (-33 *6)) (-4 *8 (-346 *6 *9)) (-4 *5 (-137)))) (-4165 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *5)) (-4 *5 (-388)) (-5 *3 (-790)) (-14 *6 (-658 (-1191))) (-4 *8 (-252 (-1699 *6) *3)) (-5 *1 (-139 *5 *6 *7 *8 *4)) (-4 *7 (-346 *5 *8)) (-4 *4 (-137)))) (-3699 (*1 *2 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *1 (-139 *4 *5 *2 *6 *3)) (-4 *2 (-346 *4 *6)) (-4 *3 (-137))))) 
+(-10 -7 (-15 -3699 (|#3| |#3| |#5|)) (-15 -4165 ((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-790) |#5|)) (-15 -2145 ((-2 (|:| |mult| (-790)) (|:| |subMult| (-790)) (|:| |blUpRec| (-658 (-2 (|:| |recTransStr| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-33 |#1|) |#5| |#1|)) (-15 -2268 ((-658 (-658 (-790))) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|))) (-15 -2842 ((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) |#3| |#5|)) (-15 -1888 (|#3| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) |#5|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ |#1| $) 22) (($ $ |#2|) 24))) 
+(((-140 |#1| |#2|) (-1311) (-1075) (-1075)) (T -140)) 
+NIL 
+(-13 (-661 |t#1|) (-1081 |t#2|) (-10 -7 (-6 -4620) (-6 -4619))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-1081 |#2|) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-3163 (($ $) 12)) (-2773 (($ $ $) 17)) (-2680 (($) 8 T CONST)) (-4012 (((-141) $) 7)) (-1403 (((-790)) 24)) (-4290 (($) 30)) (-3573 (($ $ $) 15)) (-3252 (($ $) 10)) (-1419 (($ $ $) 18)) (-3782 (($ $ $) 19)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-3546 (((-944) $) 29)) (-2685 (((-1173) $) NIL)) (-1825 (($ (-944)) 28)) (-4171 (($ $ $) 21)) (-2951 (((-1137) $) NIL)) (-3327 (($) 9 T CONST)) (-1405 (((-658 $)) NIL)) (-1778 (((-565) $) 36)) (-1683 (((-877) $) 39)) (-1732 (($ $ $) 13)) (-1424 (($ $) 11)) (-1623 (($ $ $) 16)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 20)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 22)) (-1616 (($ $ $) 14))) 
+(((-141) (-13 (-869) (-394) (-675) (-633 (-565)) (-10 -8 (-15 -2680 ($) -4249) (-15 -3327 ($) -4249) (-15 -1424 ($ $)) (-15 -3252 ($ $)) (-15 -1732 ($ $ $)) (-15 -3573 ($ $ $)) (-15 -2773 ($ $ $)) (-15 -3782 ($ $ $)) (-15 -1419 ($ $ $)) (-15 -4171 ($ $ $)) (-15 -4012 ((-141) $))))) (T -141)) 
+((-2680 (*1 *1) (-5 *1 (-141))) (-3327 (*1 *1) (-5 *1 (-141))) (-1424 (*1 *1 *1) (-5 *1 (-141))) (-3252 (*1 *1 *1) (-5 *1 (-141))) (-1732 (*1 *1 *1 *1) (-5 *1 (-141))) (-3573 (*1 *1 *1 *1) (-5 *1 (-141))) (-2773 (*1 *1 *1 *1) (-5 *1 (-141))) (-3782 (*1 *1 *1 *1) (-5 *1 (-141))) (-1419 (*1 *1 *1 *1) (-5 *1 (-141))) (-4171 (*1 *1 *1 *1) (-5 *1 (-141))) (-4012 (*1 *1 *1) (-5 *1 (-141)))) 
+(-13 (-869) (-394) (-675) (-633 (-565)) (-10 -8 (-15 -2680 ($) -4249) (-15 -3327 ($) -4249) (-15 -1424 ($ $)) (-15 -3252 ($ $)) (-15 -1732 ($ $ $)) (-15 -3573 ($ $ $)) (-15 -2773 ($ $ $)) (-15 -3782 ($ $ $)) (-15 -1419 ($ $ $)) (-15 -4171 ($ $ $)) (-15 -4012 ((-141) $)))) 
+((-1646 (((-3 (-1 |#1| (-658 |#1|)) "failed") (-143)) 18) (((-143) (-143) (-1 |#1| |#1|)) 13) (((-143) (-143) (-1 |#1| (-658 |#1|))) 11) (((-3 |#1| "failed") (-143) (-658 |#1|)) 20)) (-2550 (((-3 (-658 (-1 |#1| (-658 |#1|))) "failed") (-143)) 24) (((-143) (-143) (-1 |#1| |#1|)) 30) (((-143) (-143) (-658 (-1 |#1| (-658 |#1|)))) 26)) (-2321 (((-143) |#1|) 53 (|has| |#1| (-869)))) (-2891 (((-3 |#1| "failed") (-143)) 48 (|has| |#1| (-869))))) 
+(((-142 |#1|) (-10 -7 (-15 -1646 ((-3 |#1| "failed") (-143) (-658 |#1|))) (-15 -1646 ((-143) (-143) (-1 |#1| (-658 |#1|)))) (-15 -1646 ((-143) (-143) (-1 |#1| |#1|))) (-15 -1646 ((-3 (-1 |#1| (-658 |#1|)) "failed") (-143))) (-15 -2550 ((-143) (-143) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2550 ((-143) (-143) (-1 |#1| |#1|))) (-15 -2550 ((-3 (-658 (-1 |#1| (-658 |#1|))) "failed") (-143))) (IF (|has| |#1| (-869)) (PROGN (-15 -2321 ((-143) |#1|)) (-15 -2891 ((-3 |#1| "failed") (-143)))) |noBranch|)) (-1119)) (T -142)) 
+((-2891 (*1 *2 *3) (|partial| -12 (-5 *3 (-143)) (-4 *2 (-1119)) (-4 *2 (-869)) (-5 *1 (-142 *2)))) (-2321 (*1 *2 *3) (-12 (-5 *2 (-143)) (-5 *1 (-142 *3)) (-4 *3 (-869)) (-4 *3 (-1119)))) (-2550 (*1 *2 *3) (|partial| -12 (-5 *3 (-143)) (-5 *2 (-658 (-1 *4 (-658 *4)))) (-5 *1 (-142 *4)) (-4 *4 (-1119)))) (-2550 (*1 *2 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1119)) (-5 *1 (-142 *4)))) (-2550 (*1 *2 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-658 (-1 *4 (-658 *4)))) (-4 *4 (-1119)) (-5 *1 (-142 *4)))) (-1646 (*1 *2 *3) (|partial| -12 (-5 *3 (-143)) (-5 *2 (-1 *4 (-658 *4))) (-5 *1 (-142 *4)) (-4 *4 (-1119)))) (-1646 (*1 *2 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1119)) (-5 *1 (-142 *4)))) (-1646 (*1 *2 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *4 (-658 *4))) (-4 *4 (-1119)) (-5 *1 (-142 *4)))) (-1646 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-143)) (-5 *4 (-658 *2)) (-5 *1 (-142 *2)) (-4 *2 (-1119))))) 
+(-10 -7 (-15 -1646 ((-3 |#1| "failed") (-143) (-658 |#1|))) (-15 -1646 ((-143) (-143) (-1 |#1| (-658 |#1|)))) (-15 -1646 ((-143) (-143) (-1 |#1| |#1|))) (-15 -1646 ((-3 (-1 |#1| (-658 |#1|)) "failed") (-143))) (-15 -2550 ((-143) (-143) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2550 ((-143) (-143) (-1 |#1| |#1|))) (-15 -2550 ((-3 (-658 (-1 |#1| (-658 |#1|))) "failed") (-143))) (IF (|has| |#1| (-869)) (PROGN (-15 -2321 ((-143) |#1|)) (-15 -2891 ((-3 |#1| "failed") (-143)))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-3775 (((-790) $) 68) (($ $ (-790)) 30)) (-4536 (((-141) $) 32)) (-4452 (($ $ (-1173) (-793)) 26)) (-2182 (($ $ (-50 (-1173) (-793))) 13)) (-3663 (((-3 (-793) "failed") $ (-1173)) 24)) (-2334 (((-50 (-1173) (-793)) $) 12)) (-2791 (($ (-1191)) 15) (($ (-1191) (-790)) 20)) (-3496 (((-141) $) 31)) (-2717 (((-141) $) 33)) (-4095 (((-1191) $) 8)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-3013 (((-141) $ (-1191)) 10)) (-4007 (($ $ (-1 (-565) (-658 (-565)))) 50) (((-3 (-1 (-565) (-658 (-565))) "failed") $) 54)) (-2951 (((-1137) $) NIL)) (-1345 (((-141) $ (-1173)) 29)) (-3235 (($ $ (-1 (-141) $ $)) 35)) (-3536 (((-3 (-1 (-877) (-658 (-877))) "failed") $) 52) (($ $ (-1 (-877) (-658 (-877)))) 41) (($ $ (-1 (-877) (-877))) 43)) (-3151 (($ $ (-1173)) 45)) (-4599 (($ $) 61)) (-2681 (($ $ (-1 (-141) $ $)) 36)) (-1683 (((-877) $) 48)) (-3366 (($ $ (-1173)) 27)) (-2573 (((-3 (-790) "failed") $) 56)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 67)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 72))) 
+(((-143) (-13 (-869) (-10 -8 (-15 -4095 ((-1191) $)) (-15 -2334 ((-50 (-1173) (-793)) $)) (-15 -4599 ($ $)) (-15 -2791 ($ (-1191))) (-15 -2791 ($ (-1191) (-790))) (-15 -2573 ((-3 (-790) "failed") $)) (-15 -3496 ((-141) $)) (-15 -4536 ((-141) $)) (-15 -2717 ((-141) $)) (-15 -3775 ((-790) $)) (-15 -3775 ($ $ (-790))) (-15 -3235 ($ $ (-1 (-141) $ $))) (-15 -2681 ($ $ (-1 (-141) $ $))) (-15 -3536 ((-3 (-1 (-877) (-658 (-877))) "failed") $)) (-15 -3536 ($ $ (-1 (-877) (-658 (-877))))) (-15 -3536 ($ $ (-1 (-877) (-877)))) (-15 -4007 ($ $ (-1 (-565) (-658 (-565))))) (-15 -4007 ((-3 (-1 (-565) (-658 (-565))) "failed") $)) (-15 -3013 ((-141) $ (-1191))) (-15 -1345 ((-141) $ (-1173))) (-15 -3366 ($ $ (-1173))) (-15 -3151 ($ $ (-1173))) (-15 -3663 ((-3 (-793) "failed") $ (-1173))) (-15 -4452 ($ $ (-1173) (-793))) (-15 -2182 ($ $ (-50 (-1173) (-793))))))) (T -143)) 
+((-4095 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-143)))) (-2334 (*1 *2 *1) (-12 (-5 *2 (-50 (-1173) (-793))) (-5 *1 (-143)))) (-4599 (*1 *1 *1) (-5 *1 (-143))) (-2791 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-143)))) (-2791 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-790)) (-5 *1 (-143)))) (-2573 (*1 *2 *1) (|partial| -12 (-5 *2 (-790)) (-5 *1 (-143)))) (-3496 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-143)))) (-4536 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-143)))) (-2717 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-143)))) (-3775 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-143)))) (-3775 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-143)))) (-3235 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-141) (-143) (-143))) (-5 *1 (-143)))) (-2681 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-141) (-143) (-143))) (-5 *1 (-143)))) (-3536 (*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-877) (-658 (-877)))) (-5 *1 (-143)))) (-3536 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-877) (-658 (-877)))) (-5 *1 (-143)))) (-3536 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-877) (-877))) (-5 *1 (-143)))) (-4007 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-565) (-658 (-565)))) (-5 *1 (-143)))) (-4007 (*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-565) (-658 (-565)))) (-5 *1 (-143)))) (-3013 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-141)) (-5 *1 (-143)))) (-1345 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-141)) (-5 *1 (-143)))) (-3366 (*1 *1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-143)))) (-3151 (*1 *1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-143)))) (-3663 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1173)) (-5 *2 (-793)) (-5 *1 (-143)))) (-4452 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1173)) (-5 *3 (-793)) (-5 *1 (-143)))) (-2182 (*1 *1 *1 *2) (-12 (-5 *2 (-50 (-1173) (-793))) (-5 *1 (-143))))) 
+(-13 (-869) (-10 -8 (-15 -4095 ((-1191) $)) (-15 -2334 ((-50 (-1173) (-793)) $)) (-15 -4599 ($ $)) (-15 -2791 ($ (-1191))) (-15 -2791 ($ (-1191) (-790))) (-15 -2573 ((-3 (-790) "failed") $)) (-15 -3496 ((-141) $)) (-15 -4536 ((-141) $)) (-15 -2717 ((-141) $)) (-15 -3775 ((-790) $)) (-15 -3775 ($ $ (-790))) (-15 -3235 ($ $ (-1 (-141) $ $))) (-15 -2681 ($ $ (-1 (-141) $ $))) (-15 -3536 ((-3 (-1 (-877) (-658 (-877))) "failed") $)) (-15 -3536 ($ $ (-1 (-877) (-658 (-877))))) (-15 -3536 ($ $ (-1 (-877) (-877)))) (-15 -4007 ($ $ (-1 (-565) (-658 (-565))))) (-15 -4007 ((-3 (-1 (-565) (-658 (-565))) "failed") $)) (-15 -3013 ((-141) $ (-1191))) (-15 -1345 ((-141) $ (-1173))) (-15 -3366 ($ $ (-1173))) (-15 -3151 ($ $ (-1173))) (-15 -3663 ((-3 (-793) "failed") $ (-1173))) (-15 -4452 ($ $ (-1173) (-793))) (-15 -2182 ($ $ (-50 (-1173) (-793)))))) 
+((-2263 (((-592) |#2|) 36))) 
+(((-144 |#1| |#2|) (-10 -7 (-15 -2263 ((-592) |#2|))) (-13 (-388) (-1065 (-433 (-592)))) (-1255 |#1|)) (T -144)) 
+((-2263 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-1065 (-433 *2)))) (-5 *2 (-592)) (-5 *1 (-144 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -2263 ((-592) |#2|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $ (-592)) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-2749 (($ (-1187 (-592)) (-592)) NIL)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3980 (($ $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-4346 (((-790) $) NIL)) (-3558 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1704 (((-592)) NIL)) (-1518 (((-592) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2807 (($ $ (-592)) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4406 (((-1171 (-592)) $) NIL)) (-1700 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL)) (-4010 (((-790)) NIL)) (-2537 (((-141) $ $) NIL)) (-2642 (((-592) $ (-592)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL))) 
+(((-145 |#1|) (-890 |#1|) (-592)) (T -145)) 
+NIL 
+(-890 |#1|) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 (((-145 |#1|) $) NIL (|has| (-145 |#1|) (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-145 |#1|) (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| (-145 |#1|) (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| (-145 |#1|) (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-145 |#1|) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL (|has| (-145 |#1|) (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-145 |#1|) (-1065 (-592)))) (((-3 (-592) "failed") $) NIL (|has| (-145 |#1|) (-1065 (-592))))) (-2400 (((-145 |#1|) $) NIL) (((-1191) $) NIL (|has| (-145 |#1|) (-1065 (-1191)))) (((-433 (-592)) $) NIL (|has| (-145 |#1|) (-1065 (-592)))) (((-592) $) NIL (|has| (-145 |#1|) (-1065 (-592))))) (-3792 (($ $) NIL) (($ (-592) $) NIL)) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-145 |#1|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-145 |#1|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-145 |#1|))) (|:| |vec| (-1280 (-145 |#1|)))) (-706 $) (-1280 $)) NIL) (((-706 (-145 |#1|)) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-145 |#1|) (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) NIL (|has| (-145 |#1|) (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| (-145 |#1|) (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| (-145 |#1|) (-908 (-405))))) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL)) (-1448 (((-145 |#1|) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| (-145 |#1|) (-1165)))) (-1324 (((-141) $) NIL (|has| (-145 |#1|) (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| (-145 |#1|) (-869)))) (-3319 (($ $ $) NIL (|has| (-145 |#1|) (-869)))) (-2731 (($ (-1 (-145 |#1|) (-145 |#1|)) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-145 |#1|) (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| (-145 |#1|) (-323)))) (-2039 (((-145 |#1|) $) NIL (|has| (-145 |#1|) (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-145 |#1|) (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-145 |#1|) (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 (-145 |#1|)) (-658 (-145 |#1|))) NIL (|has| (-145 |#1|) (-325 (-145 |#1|)))) (($ $ (-145 |#1|) (-145 |#1|)) NIL (|has| (-145 |#1|) (-325 (-145 |#1|)))) (($ $ (-310 (-145 |#1|))) NIL (|has| (-145 |#1|) (-325 (-145 |#1|)))) (($ $ (-658 (-310 (-145 |#1|)))) NIL (|has| (-145 |#1|) (-325 (-145 |#1|)))) (($ $ (-658 (-1191)) (-658 (-145 |#1|))) NIL (|has| (-145 |#1|) (-547 (-1191) (-145 |#1|)))) (($ $ (-1191) (-145 |#1|)) NIL (|has| (-145 |#1|) (-547 (-1191) (-145 |#1|))))) (-2769 (((-790) $) NIL)) (-3927 (($ $ (-145 |#1|)) NIL (|has| (-145 |#1|) (-303 (-145 |#1|) (-145 |#1|))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL (|has| (-145 |#1|) (-247))) (($ $ (-790)) NIL (|has| (-145 |#1|) (-247))) (($ $ (-1191)) NIL (|has| (-145 |#1|) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-145 |#1|) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-145 |#1|) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-145 |#1|) (-922 (-1191)))) (($ $ (-1 (-145 |#1|) (-145 |#1|)) (-790)) NIL) (($ $ (-1 (-145 |#1|) (-145 |#1|))) NIL)) (-2782 (($ $) NIL)) (-1456 (((-145 |#1|) $) NIL)) (-1778 (((-914 (-592)) $) NIL (|has| (-145 |#1|) (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| (-145 |#1|) (-633 (-914 (-405))))) (((-565) $) NIL (|has| (-145 |#1|) (-633 (-565)))) (((-405) $) NIL (|has| (-145 |#1|) (-1049))) (((-237) $) NIL (|has| (-145 |#1|) (-1049)))) (-2867 (((-195 (-433 (-592))) $) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-145 |#1|) (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-145 |#1|)) NIL) (($ (-1191)) NIL (|has| (-145 |#1|) (-1065 (-1191))))) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-145 |#1|) (-931))) (|has| (-145 |#1|) (-169))))) (-4010 (((-790)) NIL)) (-2744 (((-145 |#1|) $) NIL (|has| (-145 |#1|) (-574)))) (-2537 (((-141) $ $) NIL)) (-2642 (((-433 (-592)) $ (-592)) NIL)) (-1392 (($ $) NIL (|has| (-145 |#1|) (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $) NIL (|has| (-145 |#1|) (-247))) (($ $ (-790)) NIL (|has| (-145 |#1|) (-247))) (($ $ (-1191)) NIL (|has| (-145 |#1|) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-145 |#1|) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-145 |#1|) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-145 |#1|) (-922 (-1191)))) (($ $ (-1 (-145 |#1|) (-145 |#1|)) (-790)) NIL) (($ $ (-1 (-145 |#1|) (-145 |#1|))) NIL)) (-3286 (((-141) $ $) NIL (|has| (-145 |#1|) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-145 |#1|) (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| (-145 |#1|) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-145 |#1|) (-869)))) (-3313 (($ $ $) NIL) (($ (-145 |#1|) (-145 |#1|)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ (-145 |#1|) $) NIL) (($ $ (-145 |#1|)) NIL))) 
+(((-146 |#1|) (-13 (-1021 (-145 |#1|)) (-10 -8 (-15 -2642 ((-433 (-592)) $ (-592))) (-15 -2867 ((-195 (-433 (-592))) $)) (-15 -3792 ($ $)) (-15 -3792 ($ (-592) $)))) (-592)) (T -146)) 
+((-2642 (*1 *2 *1 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-146 *4)) (-14 *4 *3) (-5 *3 (-592)))) (-2867 (*1 *2 *1) (-12 (-5 *2 (-195 (-433 (-592)))) (-5 *1 (-146 *3)) (-14 *3 (-592)))) (-3792 (*1 *1 *1) (-12 (-5 *1 (-146 *2)) (-14 *2 (-592)))) (-3792 (*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-146 *3)) (-14 *3 *2)))) 
+(-13 (-1021 (-145 |#1|)) (-10 -8 (-15 -2642 ((-433 (-592)) $ (-592))) (-15 -2867 ((-195 (-433 (-592))) $)) (-15 -3792 ($ $)) (-15 -3792 ($ (-592) $)))) 
+((-3932 ((|#2| $ "value" |#2|) NIL) (($ $ "left" $) 48) (($ $ "right" $) 50)) (-2774 (((-658 $) $) 27)) (-3055 (((-141) $ $) 32)) (-3133 (((-141) |#2| $) 36)) (-4063 (((-658 |#2|) $) 22)) (-3683 (((-141) $) 16)) (-3927 ((|#2| $ "value") NIL) (($ $ "left") 10) (($ $ "right") 13)) (-3228 (((-141) $) 45)) (-1683 (((-877) $) 41)) (-2493 (((-658 $) $) 28)) (-3255 (((-141) $ $) 34)) (-1699 (((-790) $) 43))) 
+(((-147 |#1| |#2|) (-10 -8 (-15 -3932 (|#1| |#1| "right" |#1|)) (-15 -3932 (|#1| |#1| "left" |#1|)) (-15 -3927 (|#1| |#1| "right")) (-15 -3927 (|#1| |#1| "left")) (-15 -3932 (|#2| |#1| "value" |#2|)) (-15 -3055 ((-141) |#1| |#1|)) (-15 -4063 ((-658 |#2|) |#1|)) (-15 -3228 ((-141) |#1|)) (-15 -3927 (|#2| |#1| "value")) (-15 -3683 ((-141) |#1|)) (-15 -2774 ((-658 |#1|) |#1|)) (-15 -2493 ((-658 |#1|) |#1|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3133 ((-141) |#2| |#1|)) (-15 -1699 ((-790) |#1|))) (-148 |#2|) (-1225)) (T -147)) 
+NIL 
+(-10 -8 (-15 -3932 (|#1| |#1| "right" |#1|)) (-15 -3932 (|#1| |#1| "left" |#1|)) (-15 -3927 (|#1| |#1| "right")) (-15 -3927 (|#1| |#1| "left")) (-15 -3932 (|#2| |#1| "value" |#2|)) (-15 -3055 ((-141) |#1| |#1|)) (-15 -4063 ((-658 |#2|) |#1|)) (-15 -3228 ((-141) |#1|)) (-15 -3927 (|#2| |#1| "value")) (-15 -3683 ((-141) |#1|)) (-15 -2774 ((-658 |#1|) |#1|)) (-15 -2493 ((-658 |#1|) |#1|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3133 ((-141) |#2| |#1|)) (-15 -1699 ((-790) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-2949 (($ $ $) 49 (|has| $ (-6 -4626)))) (-1348 (($ $ $) 51 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626))) (($ $ "left" $) 52 (|has| $ (-6 -4626))) (($ $ "right" $) 50 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-3001 (($) 7 T CONST)) (-1954 (($ $) 54)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-1961 (($ $) 56)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44) (($ $ "left") 55) (($ $ "right") 53)) (-2920 (((-592) $ $) 41)) (-3228 (((-141) $) 43)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-148 |#1|) (-1311) (-1225)) (T -148)) 
+((-1961 (*1 *1 *1) (-12 (-4 *1 (-148 *2)) (-4 *2 (-1225)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 "left") (-4 *1 (-148 *3)) (-4 *3 (-1225)))) (-1954 (*1 *1 *1) (-12 (-4 *1 (-148 *2)) (-4 *2 (-1225)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 "right") (-4 *1 (-148 *3)) (-4 *3 (-1225)))) (-3932 (*1 *1 *1 *2 *1) (-12 (-5 *2 "left") (|has| *1 (-6 -4626)) (-4 *1 (-148 *3)) (-4 *3 (-1225)))) (-1348 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-148 *2)) (-4 *2 (-1225)))) (-3932 (*1 *1 *1 *2 *1) (-12 (-5 *2 "right") (|has| *1 (-6 -4626)) (-4 *1 (-148 *3)) (-4 *3 (-1225)))) (-2949 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-148 *2)) (-4 *2 (-1225))))) 
+(-13 (-1038 |t#1|) (-10 -8 (-15 -1961 ($ $)) (-15 -3927 ($ $ "left")) (-15 -1954 ($ $)) (-15 -3927 ($ $ "right")) (IF (|has| $ (-6 -4626)) (PROGN (-15 -3932 ($ $ "left" $)) (-15 -1348 ($ $ $)) (-15 -3932 ($ $ "right" $)) (-15 -2949 ($ $ $))) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1038 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1388 (((-141) |#1|) 24)) (-2823 (((-790) (-790)) 23) (((-790)) 22)) (-1357 (((-141) |#1| (-141)) 25) (((-141) |#1|) 26))) 
+(((-149 |#1|) (-10 -7 (-15 -1357 ((-141) |#1|)) (-15 -1357 ((-141) |#1| (-141))) (-15 -2823 ((-790))) (-15 -2823 ((-790) (-790))) (-15 -1388 ((-141) |#1|))) (-1255 (-592))) (T -149)) 
+((-1388 (*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592))))) (-2823 (*1 *2 *2) (-12 (-5 *2 (-790)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592))))) (-2823 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592))))) (-1357 (*1 *2 *3 *2) (-12 (-5 *2 (-141)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592))))) (-1357 (*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592)))))) 
+(-10 -7 (-15 -1357 ((-141) |#1|)) (-15 -1357 ((-141) |#1| (-141))) (-15 -2823 ((-790))) (-15 -2823 ((-790) (-790))) (-15 -1388 ((-141) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2843 (((-3 $ "failed") (-1191) (-1191)) 31)) (-2951 (((-1137) $) NIL)) (-4412 (((-3 (-1191) "failed") $) 45)) (-3834 (((-3 $ (-592)) (-1191)) 36)) (-1902 (((-1199 (-1191) $)) 42)) (-2559 (((-658 $)) 40)) (-2322 (((-3 $ "failed") (-1191)) 19)) (-1778 (($ (-1191)) 27) (((-1191) $) NIL)) (-1683 (((-877) $) 21)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL))) 
+(((-150) (-13 (-869) (-10 -8 (-6 (-633 (-1191))) (-15 -2322 ((-3 $ "failed") (-1191))) (-15 -1778 ($ (-1191))) (-15 -2843 ((-3 $ "failed") (-1191) (-1191))) (-15 -3834 ((-3 $ (-592)) (-1191))) (-15 -2559 ((-658 $))) (-15 -1902 ((-1199 (-1191) $))) (-15 -4412 ((-3 (-1191) "failed") $))))) (T -150)) 
+((-2322 (*1 *1 *2) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-150)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-150)))) (-2843 (*1 *1 *2 *2) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-150)))) (-3834 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-3 (-150) (-592))) (-5 *1 (-150)))) (-2559 (*1 *2) (-12 (-5 *2 (-658 (-150))) (-5 *1 (-150)))) (-1902 (*1 *2) (-12 (-5 *2 (-1199 (-1191) (-150))) (-5 *1 (-150)))) (-4412 (*1 *2 *1) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-150))))) 
+(-13 (-869) (-10 -8 (-6 (-633 (-1191))) (-15 -2322 ((-3 $ "failed") (-1191))) (-15 -1778 ($ (-1191))) (-15 -2843 ((-3 $ "failed") (-1191) (-1191))) (-15 -3834 ((-3 $ (-592)) (-1191))) (-15 -2559 ((-658 $))) (-15 -1902 ((-1199 (-1191) $))) (-15 -4412 ((-3 (-1191) "failed") $)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) 15)) (-1356 (((-2 (|:| |less| $) (|:| |greater| $)) |#1| $) 22)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-2949 (($ $ $) 18 (|has| $ (-6 -4626)))) (-1348 (($ $ $) 20 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) (($ $ "left" $) NIL (|has| $ (-6 -4626))) (($ $ "right" $) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-1954 (($ $) 17)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-4245 (($ $ |#1| $) 23)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-1961 (($ $) 19)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3429 (($ |#1| $) 24)) (-2113 (($ |#1| $) 10)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 14)) (-2890 (($) 8)) (-3927 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-2920 (((-592) $ $) NIL)) (-3228 (((-141) $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3502 (($ (-658 |#1|)) 12)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-151 |#1|) (-13 (-155 |#1|) (-10 -8 (-6 -4626) (-6 -4625) (-15 -3502 ($ (-658 |#1|))) (-15 -2113 ($ |#1| $)) (-15 -3429 ($ |#1| $)) (-15 -1356 ((-2 (|:| |less| $) (|:| |greater| $)) |#1| $)))) (-869)) (T -151)) 
+((-3502 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-151 *3)))) (-2113 (*1 *1 *2 *1) (-12 (-5 *1 (-151 *2)) (-4 *2 (-869)))) (-3429 (*1 *1 *2 *1) (-12 (-5 *1 (-151 *2)) (-4 *2 (-869)))) (-1356 (*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |less| (-151 *3)) (|:| |greater| (-151 *3)))) (-5 *1 (-151 *3)) (-4 *3 (-869))))) 
+(-13 (-155 |#1|) (-10 -8 (-6 -4626) (-6 -4625) (-15 -3502 ($ (-658 |#1|))) (-15 -2113 ($ |#1| $)) (-15 -3429 ($ |#1| $)) (-15 -1356 ((-2 (|:| |less| $) (|:| |greater| $)) |#1| $)))) 
+((-3163 (($ $) 14)) (-3252 (($ $) 11)) (-1419 (($ $ $) 24)) (-3782 (($ $ $) 22)) (-1424 (($ $) 12)) (-1623 (($ $ $) 20)) (-1616 (($ $ $) 18))) 
+(((-152 |#1|) (-10 -8 (-15 -1419 (|#1| |#1| |#1|)) (-15 -3782 (|#1| |#1| |#1|)) (-15 -1424 (|#1| |#1|)) (-15 -3252 (|#1| |#1|)) (-15 -3163 (|#1| |#1|)) (-15 -1616 (|#1| |#1| |#1|)) (-15 -1623 (|#1| |#1| |#1|))) (-153)) (T -152)) 
+NIL 
+(-10 -8 (-15 -1419 (|#1| |#1| |#1|)) (-15 -3782 (|#1| |#1| |#1|)) (-15 -1424 (|#1| |#1|)) (-15 -3252 (|#1| |#1|)) (-15 -3163 (|#1| |#1|)) (-15 -1616 (|#1| |#1| |#1|)) (-15 -1623 (|#1| |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-3163 (($ $) 103)) (-2773 (($ $ $) 24)) (-3898 (((-1285) $ (-592) (-592)) 66 (|has| $ (-6 -4626)))) (-4076 (((-141) $) 98 (|has| (-141) (-869))) (((-141) (-1 (-141) (-141) (-141)) $) 92)) (-2831 (($ $) 102 (-12 (|has| (-141) (-869)) (|has| $ (-6 -4626)))) (($ (-1 (-141) (-141) (-141)) $) 101 (|has| $ (-6 -4626)))) (-3960 (($ $) 97 (|has| (-141) (-869))) (($ (-1 (-141) (-141) (-141)) $) 91)) (-2126 (((-141) $ (-790)) 37)) (-3932 (((-141) $ (-1246 (-592)) (-141)) 88 (|has| $ (-6 -4626))) (((-141) $ (-592) (-141)) 54 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-141)) $) 71 (|has| $ (-6 -4625)))) (-3001 (($) 38 T CONST)) (-2512 (($ $) 100 (|has| $ (-6 -4626)))) (-1373 (($ $) 90)) (-1360 (($ $) 68 (-12 (|has| (-141) (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ (-1 (-141) (-141)) $) 72 (|has| $ (-6 -4625))) (($ (-141) $) 69 (-12 (|has| (-141) (-1119)) (|has| $ (-6 -4625))))) (-3657 (((-141) (-1 (-141) (-141) (-141)) $) 74 (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-141) (-141)) $ (-141)) 73 (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-141) (-141)) $ (-141) (-141)) 70 (-12 (|has| (-141) (-1119)) (|has| $ (-6 -4625))))) (-1426 (((-141) $ (-592) (-141)) 53 (|has| $ (-6 -4626)))) (-3959 (((-141) $ (-592)) 55)) (-1721 (((-592) (-141) $ (-592)) 95 (|has| (-141) (-1119))) (((-592) (-141) $) 94 (|has| (-141) (-1119))) (((-592) (-1 (-141) (-141)) $) 93)) (-4004 (((-658 (-141)) $) 45 (|has| $ (-6 -4625)))) (-3573 (($ $ $) 25)) (-3252 (($ $) 30)) (-1419 (($ $ $) 27)) (-3242 (($ (-790) (-141)) 77)) (-3782 (($ $ $) 28)) (-4345 (((-141) $ (-790)) 36)) (-2261 (((-592) $) 63 (|has| (-592) (-869)))) (-1837 (($ $ $) 12)) (-4491 (($ $ $) 96 (|has| (-141) (-869))) (($ (-1 (-141) (-141) (-141)) $ $) 89)) (-4467 (((-658 (-141)) $) 46 (|has| $ (-6 -4625)))) (-3133 (((-141) (-141) $) 48 (-12 (|has| (-141) (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 62 (|has| (-592) (-869)))) (-3319 (($ $ $) 13)) (-3987 (($ (-1 (-141) (-141)) $) 41 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-141) (-141) (-141)) $ $) 82) (($ (-1 (-141) (-141)) $) 40)) (-2554 (((-141) $ (-790)) 35)) (-2685 (((-1173) $) 9)) (-3666 (($ $ $ (-592)) 87) (($ (-141) $ (-592)) 86)) (-3708 (((-658 (-592)) $) 60)) (-3780 (((-141) (-592) $) 59)) (-2951 (((-1137) $) 10)) (-1918 (((-141) $) 64 (|has| (-592) (-869)))) (-4050 (((-3 (-141) "failed") (-1 (-141) (-141)) $) 75)) (-1892 (($ $ (-141)) 65 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-141)) $) 43 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-141)) (-658 (-141))) 52 (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-141) (-141)) 51 (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-310 (-141))) 50 (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-658 (-310 (-141)))) 49 (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119))))) (-1724 (((-141) $ $) 31)) (-2254 (((-141) (-141) $) 61 (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-4210 (((-658 (-141)) $) 58)) (-2943 (((-141) $) 34)) (-2890 (($) 33)) (-3927 (($ $ (-1246 (-592))) 83) (((-141) $ (-592)) 57) (((-141) $ (-592) (-141)) 56)) (-3208 (($ $ (-1246 (-592))) 85) (($ $ (-592)) 84)) (-3452 (((-790) (-141) $) 47 (-12 (|has| (-141) (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) (-141)) $) 44 (|has| $ (-6 -4625)))) (-2385 (($ $ $ (-592)) 99 (|has| $ (-6 -4626)))) (-4599 (($ $) 32)) (-1778 (((-565) $) 67 (|has| (-141) (-633 (-565))))) (-4466 (($ (-658 (-141))) 76)) (-2266 (($ (-658 $)) 81) (($ $ $) 80) (($ (-141) $) 79) (($ $ (-141)) 78)) (-1683 (((-877) $) 11)) (-3369 (((-141) (-1 (-141) (-141)) $) 42 (|has| $ (-6 -4625)))) (-1732 (($ $ $) 26)) (-1424 (($ $) 29)) (-1623 (($ $ $) 105)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (-1616 (($ $ $) 104)) (-1699 (((-790) $) 39 (|has| $ (-6 -4625))))) 
+(((-153) (-1311)) (T -153)) 
+((-3252 (*1 *1 *1) (-4 *1 (-153))) (-1424 (*1 *1 *1) (-4 *1 (-153))) (-3782 (*1 *1 *1 *1) (-4 *1 (-153))) (-1419 (*1 *1 *1 *1) (-4 *1 (-153))) (-1732 (*1 *1 *1 *1) (-4 *1 (-153))) (-3573 (*1 *1 *1 *1) (-4 *1 (-153))) (-2773 (*1 *1 *1 *1) (-4 *1 (-153)))) 
+(-13 (-869) (-675) (-19 (-141)) (-10 -8 (-15 -3252 ($ $)) (-15 -1424 ($ $)) (-15 -3782 ($ $ $)) (-15 -1419 ($ $ $)) (-15 -1732 ($ $ $)) (-15 -3573 ($ $ $)) (-15 -2773 ($ $ $)))) 
+(((-39) . T) ((-125) . T) ((-632 (-877)) . T) ((-175 (-141)) . T) ((-633 (-565)) |has| (-141) (-633 (-565))) ((-303 (-592) (-141)) . T) ((-305 (-592) (-141)) . T) ((-325 (-141)) -12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119))) ((-399 (-141)) . T) ((-523 (-141)) . T) ((-625 (-592) (-141)) . T) ((-547 (-141) (-141)) -12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119))) ((-664 (-141)) . T) ((-675) . T) ((-19 (-141)) . T) ((-869) . T) ((-1119) . T) ((-1225) . T)) 
+((-3987 (($ (-1 |#2| |#2|) $) 22)) (-4599 (($ $) 16)) (-1699 (((-790) $) 24))) 
+(((-154 |#1| |#2|) (-10 -8 (-15 -3987 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1699 ((-790) |#1|)) (-15 -4599 (|#1| |#1|))) (-155 |#2|) (-1119)) (T -154)) 
+NIL 
+(-10 -8 (-15 -3987 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1699 ((-790) |#1|)) (-15 -4599 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-2949 (($ $ $) 49 (|has| $ (-6 -4626)))) (-1348 (($ $ $) 51 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626))) (($ $ "left" $) 52 (|has| $ (-6 -4626))) (($ $ "right" $) 50 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-3001 (($) 7 T CONST)) (-1954 (($ $) 54)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-4245 (($ $ |#1| $) 57)) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-1961 (($ $) 56)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44) (($ $ "left") 55) (($ $ "right") 53)) (-2920 (((-592) $ $) 41)) (-3228 (((-141) $) 43)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-155 |#1|) (-1311) (-1119)) (T -155)) 
+((-4245 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-155 *2)) (-4 *2 (-1119))))) 
+(-13 (-148 |t#1|) (-10 -8 (-6 -4626) (-6 -4625) (-15 -4245 ($ $ |t#1| $)))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-148 |#1|) . T) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1038 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) 15)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) 19 (|has| $ (-6 -4626)))) (-2949 (($ $ $) 20 (|has| $ (-6 -4626)))) (-1348 (($ $ $) 18 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) (($ $ "left" $) NIL (|has| $ (-6 -4626))) (($ $ "right" $) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-1954 (($ $) 21)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-4245 (($ $ |#1| $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-1961 (($ $) NIL)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2113 (($ |#1| $) 10)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 14)) (-2890 (($) 8)) (-3927 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-2920 (((-592) $ $) NIL)) (-3228 (((-141) $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) 17)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2128 (($ (-658 |#1|)) 12)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-156 |#1|) (-13 (-155 |#1|) (-10 -8 (-6 -4626) (-15 -2128 ($ (-658 |#1|))) (-15 -2113 ($ |#1| $)))) (-869)) (T -156)) 
+((-2128 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-156 *3)))) (-2113 (*1 *1 *2 *1) (-12 (-5 *1 (-156 *2)) (-4 *2 (-869))))) 
+(-13 (-155 |#1|) (-10 -8 (-6 -4626) (-15 -2128 ($ (-658 |#1|))) (-15 -2113 ($ |#1| $)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) 24)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) 26 (|has| $ (-6 -4626)))) (-2949 (($ $ $) 30 (|has| $ (-6 -4626)))) (-1348 (($ $ $) 28 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) (($ $ "left" $) NIL (|has| $ (-6 -4626))) (($ $ "right" $) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-1954 (($ $) 20)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-4245 (($ $ |#1| $) 15)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-1961 (($ $) 19)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) 21)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 18)) (-2890 (($) 11)) (-3927 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-2920 (((-592) $ $) NIL)) (-3228 (((-141) $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1730 (($ |#1|) 17) (($ $ |#1| $) 16)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 10 (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-157 |#1|) (-13 (-155 |#1|) (-10 -8 (-15 -1730 ($ |#1|)) (-15 -1730 ($ $ |#1| $)))) (-1119)) (T -157)) 
+((-1730 (*1 *1 *2) (-12 (-5 *1 (-157 *2)) (-4 *2 (-1119)))) (-1730 (*1 *1 *1 *2 *1) (-12 (-5 *1 (-157 *2)) (-4 *2 (-1119))))) 
+(-13 (-155 |#1|) (-10 -8 (-15 -1730 ($ |#1|)) (-15 -1730 ($ $ |#1| $)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14))) 
+(((-158) (-1311)) (T -158)) 
+((-2350 (*1 *1 *1 *1) (|partial| -4 *1 (-158)))) 
+(-13 (-23) (-10 -8 (-15 -2350 ((-3 $ "failed") $ $)))) 
+(((-23) . T) ((-25) . T) ((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) 7)) (-1632 (((-1285) $ (-790)) 18)) (-1721 (((-790) $) 19)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17))) 
+(((-159) (-1311)) (T -159)) 
+((-1721 (*1 *2 *1) (-12 (-4 *1 (-159)) (-5 *2 (-790)))) (-1632 (*1 *2 *1 *3) (-12 (-4 *1 (-159)) (-5 *3 (-790)) (-5 *2 (-1285))))) 
+(-13 (-869) (-10 -8 (-15 -1721 ((-790) $)) (-15 -1632 ((-1285) $ (-790))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-869) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-790) "failed") $) 38)) (-2400 (((-790) $) 36)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) 26)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2898 (((-141)) 39)) (-2656 (((-141) (-141)) 41)) (-3561 (((-141) $) 23)) (-4330 (((-141) $) 35)) (-1683 (((-877) $) 22) (($ (-790)) 14)) (-1424 (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (-3514 (($) 12 T CONST)) (-4257 (($) 11 T CONST)) (-4128 (($ (-790)) 15)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 24)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 25)) (-3306 (((-3 $ "failed") $ $) 29)) (-3300 (($ $ $) 27)) (** (($ $ (-790)) NIL) (($ $ (-944)) NIL) (($ $ $) 34)) (* (($ (-790) $) 32) (($ (-944) $) NIL) (($ $ $) 30))) 
+(((-160) (-13 (-869) (-23) (-743) (-1065 (-790)) (-10 -8 (-6 (-4627 "*")) (-15 -3306 ((-3 $ "failed") $ $)) (-15 ** ($ $ $)) (-15 -4128 ($ (-790))) (-15 -3561 ((-141) $)) (-15 -4330 ((-141) $)) (-15 -2898 ((-141))) (-15 -2656 ((-141) (-141)))))) (T -160)) 
+((-3306 (*1 *1 *1 *1) (|partial| -5 *1 (-160))) (** (*1 *1 *1 *1) (-5 *1 (-160))) (-4128 (*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-160)))) (-3561 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-160)))) (-4330 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-160)))) (-2898 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-160)))) (-2656 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-160))))) 
+(-13 (-869) (-23) (-743) (-1065 (-790)) (-10 -8 (-6 (-4627 "*")) (-15 -3306 ((-3 $ "failed") $ $)) (-15 ** ($ $ $)) (-15 -4128 ($ (-790))) (-15 -3561 ((-141) $)) (-15 -4330 ((-141) $)) (-15 -2898 ((-141))) (-15 -2656 ((-141) (-141))))) 
+((-3711 (((-162 |#1| |#2| |#4|) (-658 |#4|) (-162 |#1| |#2| |#3|)) 14)) (-2731 (((-162 |#1| |#2| |#4|) (-1 |#4| |#3|) (-162 |#1| |#2| |#3|)) 18))) 
+(((-161 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3711 ((-162 |#1| |#2| |#4|) (-658 |#4|) (-162 |#1| |#2| |#3|))) (-15 -2731 ((-162 |#1| |#2| |#4|) (-1 |#4| |#3|) (-162 |#1| |#2| |#3|)))) (-592) (-790) (-194) (-194)) (T -161)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *7)) (-5 *4 (-162 *5 *6 *7)) (-14 *5 (-592)) (-14 *6 (-790)) (-4 *7 (-194)) (-4 *8 (-194)) (-5 *2 (-162 *5 *6 *8)) (-5 *1 (-161 *5 *6 *7 *8)))) (-3711 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-162 *5 *6 *7)) (-14 *5 (-592)) (-14 *6 (-790)) (-4 *7 (-194)) (-4 *8 (-194)) (-5 *2 (-162 *5 *6 *8)) (-5 *1 (-161 *5 *6 *7 *8))))) 
+(-10 -7 (-15 -3711 ((-162 |#1| |#2| |#4|) (-658 |#4|) (-162 |#1| |#2| |#3|))) (-15 -2731 ((-162 |#1| |#2| |#4|) (-1 |#4| |#3|) (-162 |#1| |#2| |#3|)))) 
+((-1641 (((-141) $ $) NIL)) (-2926 (($ (-658 |#3|)) 38)) (-2245 (($ $) 97) (($ $ (-592) (-592)) 96)) (-3001 (($) 17)) (-4368 (((-3 |#3| "failed") $) 58)) (-2400 ((|#3| $) NIL)) (-2030 (($ $ (-658 (-592))) 98)) (-2209 (((-658 |#3|) $) 34)) (-4175 (((-790) $) 42)) (-3679 (($ $ $) 91)) (-1887 (($) 41)) (-2685 (((-1173) $) NIL)) (-1953 (($) 16)) (-2951 (((-1137) $) NIL)) (-3927 ((|#3| $) 44) ((|#3| $ (-592)) 45) ((|#3| $ (-592) (-592)) 46) ((|#3| $ (-592) (-592) (-592)) 47) ((|#3| $ (-592) (-592) (-592) (-592)) 48) ((|#3| $ (-658 (-592))) 50)) (-4525 (((-790) $) 43)) (-1764 (($ $ (-592) $ (-592)) 92) (($ $ (-592) (-592)) 94)) (-1683 (((-877) $) 65) (($ |#3|) 66) (($ (-254 |#2| |#3|)) 73) (($ (-1156 |#2| |#3|)) 76) (($ (-658 |#3|)) 51) (($ (-658 $)) 56)) (-3514 (($) 67 T CONST)) (-4257 (($) 68 T CONST)) (-3255 (((-141) $ $) 78)) (-3306 (($ $) 84) (($ $ $) 82)) (-3300 (($ $ $) 80)) (* (($ |#3| $) 89) (($ $ |#3|) 90) (($ $ (-592)) 87) (($ (-592) $) 86) (($ $ $) 93))) 
+(((-162 |#1| |#2| |#3|) (-13 (-494 |#3| (-790)) (-499 (-592) (-790)) (-10 -8 (-15 -1683 ($ (-254 |#2| |#3|))) (-15 -1683 ($ (-1156 |#2| |#3|))) (-15 -1683 ($ (-658 |#3|))) (-15 -1683 ($ (-658 $))) (-15 -4175 ((-790) $)) (-15 -3927 (|#3| $)) (-15 -3927 (|#3| $ (-592))) (-15 -3927 (|#3| $ (-592) (-592))) (-15 -3927 (|#3| $ (-592) (-592) (-592))) (-15 -3927 (|#3| $ (-592) (-592) (-592) (-592))) (-15 -3927 (|#3| $ (-658 (-592)))) (-15 -3679 ($ $ $)) (-15 * ($ $ $)) (-15 -1764 ($ $ (-592) $ (-592))) (-15 -1764 ($ $ (-592) (-592))) (-15 -2245 ($ $)) (-15 -2245 ($ $ (-592) (-592))) (-15 -2030 ($ $ (-658 (-592)))) (-15 -1953 ($)) (-15 -1887 ($)) (-15 -2209 ((-658 |#3|) $)) (-15 -2926 ($ (-658 |#3|))) (-15 -3001 ($)))) (-592) (-790) (-194)) (T -162)) 
+((-3679 (*1 *1 *1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-254 *4 *5)) (-14 *4 (-790)) (-4 *5 (-194)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1156 *4 *5)) (-14 *4 (-790)) (-4 *5 (-194)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 *5)) (-4 *5 (-194)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-162 *3 *4 *5))) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)) (-4 *5 (-194)))) (-4175 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 *2) (-4 *5 (-194)))) (-3927 (*1 *2 *1) (-12 (-4 *2 (-194)) (-5 *1 (-162 *3 *4 *2)) (-14 *3 (-592)) (-14 *4 (-790)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-790)))) (-3927 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-790)))) (-3927 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-592)) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-790)))) (-3927 (*1 *2 *1 *3 *3 *3 *3) (-12 (-5 *3 (-592)) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-790)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-658 (-592))) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 (-592)) (-14 *5 (-790)))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) (-1764 (*1 *1 *1 *2 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-790)) (-4 *5 (-194)))) (-1764 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-790)) (-4 *5 (-194)))) (-2245 (*1 *1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) (-2245 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-790)) (-4 *5 (-194)))) (-2030 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)) (-4 *5 (-194)))) (-1953 (*1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) (-1887 (*1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) (-2209 (*1 *2 *1) (-12 (-5 *2 (-658 *5)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)) (-4 *5 (-194)))) (-2926 (*1 *1 *2) (-12 (-5 *2 (-658 *5)) (-4 *5 (-194)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)))) (-3001 (*1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194))))) 
+(-13 (-494 |#3| (-790)) (-499 (-592) (-790)) (-10 -8 (-15 -1683 ($ (-254 |#2| |#3|))) (-15 -1683 ($ (-1156 |#2| |#3|))) (-15 -1683 ($ (-658 |#3|))) (-15 -1683 ($ (-658 $))) (-15 -4175 ((-790) $)) (-15 -3927 (|#3| $)) (-15 -3927 (|#3| $ (-592))) (-15 -3927 (|#3| $ (-592) (-592))) (-15 -3927 (|#3| $ (-592) (-592) (-592))) (-15 -3927 (|#3| $ (-592) (-592) (-592) (-592))) (-15 -3927 (|#3| $ (-658 (-592)))) (-15 -3679 ($ $ $)) (-15 * ($ $ $)) (-15 -1764 ($ $ (-592) $ (-592))) (-15 -1764 ($ $ (-592) (-592))) (-15 -2245 ($ $)) (-15 -2245 ($ $ (-592) (-592))) (-15 -2030 ($ $ (-658 (-592)))) (-15 -1953 ($)) (-15 -1887 ($)) (-15 -2209 ((-658 |#3|) $)) (-15 -2926 ($ (-658 |#3|))) (-15 -3001 ($)))) 
+((-1641 (((-141) $ $) NIL)) (-3777 (($) 15 T CONST)) (-1875 (($) NIL (|has| (-168) (-394)))) (-4528 (($ $ $) 17) (($ $ (-168)) NIL) (($ (-168) $) NIL)) (-4471 (($ $ $) NIL)) (-2461 (((-141) $ $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-1403 (((-790)) NIL (|has| (-168) (-394)))) (-2224 (($) NIL) (($ (-658 (-168))) NIL)) (-4125 (($ (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-4065 (($ (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625))) (($ (-168) $) 51 (|has| $ (-6 -4625)))) (-4459 (($ (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625))) (($ (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-3657 (((-168) (-1 (-168) (-168) (-168)) $) NIL (|has| $ (-6 -4625))) (((-168) (-1 (-168) (-168) (-168)) $ (-168)) NIL (|has| $ (-6 -4625))) (((-168) (-1 (-168) (-168) (-168)) $ (-168) (-168)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-4290 (($) NIL (|has| (-168) (-394)))) (-4004 (((-658 (-168)) $) 60 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-1837 (((-168) $) NIL (|has| (-168) (-869)))) (-4467 (((-658 (-168)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-168) $) 26 (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-3319 (((-168) $) NIL (|has| (-168) (-869)))) (-3987 (($ (-1 (-168) (-168)) $) 59 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-168) (-168)) $) 55)) (-1633 (($) 16 T CONST)) (-3546 (((-944) $) NIL (|has| (-168) (-394)))) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-2852 (($ $ $) 29)) (-4137 (((-168) $) 52)) (-2113 (($ (-168) $) 50)) (-1825 (($ (-944)) NIL (|has| (-168) (-394)))) (-3880 (($) 14 T CONST)) (-2951 (((-1137) $) NIL)) (-4050 (((-3 (-168) "failed") (-1 (-141) (-168)) $) NIL)) (-2106 (((-168) $) 53)) (-3002 (((-141) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-168)) (-658 (-168))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-168) (-168)) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-310 (-168))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-658 (-310 (-168)))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))))) (-1724 (((-141) $ $) NIL)) (-1405 (((-658 $)) NIL (|has| (-168) (-394)))) (-2943 (((-141) $) NIL)) (-2890 (($) 48)) (-4040 (($) 13 T CONST)) (-4328 (($ $ $) 31) (($ $ (-168)) NIL)) (-1653 (($ (-658 (-168))) NIL) (($) NIL)) (-3452 (((-790) (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119)))) (((-790) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-1173) $) 36) (((-565) $) NIL (|has| (-168) (-633 (-565)))) (((-658 (-168)) $) 34)) (-4466 (($ (-658 (-168))) NIL)) (-2184 (($ $) 32 (|has| (-168) (-394)))) (-1683 (((-877) $) 46)) (-1743 (($ (-1173)) 12) (($ (-658 (-168))) 43)) (-1484 (((-790) $) NIL)) (-4586 (($) 49) (($ (-658 (-168))) NIL)) (-4560 (($ (-658 (-168))) NIL)) (-3369 (((-141) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-4360 (($) 19 T CONST)) (-1660 (($) 18 T CONST)) (-3255 (((-141) $ $) 22)) (-3266 (((-141) $ $) NIL)) (-1699 (((-790) $) 47 (|has| $ (-6 -4625))))) 
+(((-163) (-13 (-1119) (-633 (-1173)) (-451 (-168)) (-633 (-658 (-168))) (-10 -8 (-15 -1743 ($ (-1173))) (-15 -1743 ($ (-658 (-168)))) (-15 -4040 ($) -4249) (-15 -3880 ($) -4249) (-15 -3777 ($) -4249) (-15 -1633 ($) -4249) (-15 -1660 ($) -4249) (-15 -4360 ($) -4249)))) (T -163)) 
+((-1743 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-163)))) (-1743 (*1 *1 *2) (-12 (-5 *2 (-658 (-168))) (-5 *1 (-163)))) (-4040 (*1 *1) (-5 *1 (-163))) (-3880 (*1 *1) (-5 *1 (-163))) (-3777 (*1 *1) (-5 *1 (-163))) (-1633 (*1 *1) (-5 *1 (-163))) (-1660 (*1 *1) (-5 *1 (-163))) (-4360 (*1 *1) (-5 *1 (-163)))) 
+(-13 (-1119) (-633 (-1173)) (-451 (-168)) (-633 (-658 (-168))) (-10 -8 (-15 -1743 ($ (-1173))) (-15 -1743 ($ (-658 (-168)))) (-15 -4040 ($) -4249) (-15 -3880 ($) -4249) (-15 -3777 ($) -4249) (-15 -1633 ($) -4249) (-15 -1660 ($) -4249) (-15 -4360 ($) -4249))) 
+((-3626 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) 17)) (-2088 ((|#1| |#3|) 9)) (-2219 ((|#3| |#3|) 15))) 
+(((-164 |#1| |#2| |#3|) (-10 -7 (-15 -2088 (|#1| |#3|)) (-15 -2219 (|#3| |#3|)) (-15 -3626 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) (-582) (-1021 |#1|) (-399 |#2|)) (T -164)) 
+((-3626 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-1021 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-164 *4 *5 *3)) (-4 *3 (-399 *5)))) (-2219 (*1 *2 *2) (-12 (-4 *3 (-582)) (-4 *4 (-1021 *3)) (-5 *1 (-164 *3 *4 *2)) (-4 *2 (-399 *4)))) (-2088 (*1 *2 *3) (-12 (-4 *4 (-1021 *2)) (-4 *2 (-582)) (-5 *1 (-164 *2 *4 *3)) (-4 *3 (-399 *4))))) 
+(-10 -7 (-15 -2088 (|#1| |#3|)) (-15 -2219 (|#3| |#3|)) (-15 -3626 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) 
+((-1641 (((-141) $ $) NIL (|has| (-191 (-237)) (-1119)))) (-1417 (($ (-790) (-790)) NIL)) (-4596 (($ $ $) NIL)) (-2245 (($ (-166)) NIL) (($ $) NIL)) (-4034 (((-141) $) NIL)) (-2668 (($ $ (-592) (-592)) NIL)) (-1664 (($ $ (-592) (-592)) NIL)) (-2019 (($ $ (-592) (-592) (-592) (-592)) NIL)) (-1574 (($ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-2854 (($ $ (-592) (-592) $) NIL)) (-3932 (((-191 (-237)) $ (-592) (-592) (-191 (-237))) NIL) (($ $ (-658 (-592)) (-658 (-592)) $) NIL)) (-2547 (($ $ (-592) (-166)) NIL)) (-2242 (($ $ (-592) (-166)) NIL)) (-3223 (($ (-790) (-191 (-237))) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) NIL (|has| (-191 (-237)) (-323)))) (-2747 (((-166) $ (-592)) NIL)) (-4175 (((-790) $) NIL (|has| (-191 (-237)) (-582)))) (-1426 (((-191 (-237)) $ (-592) (-592) (-191 (-237))) 16)) (-1695 (($ (-592) (-592)) 18)) (-3959 (((-191 (-237)) $ (-592) (-592)) 15)) (-1794 (((-191 (-237)) $) NIL (|has| (-191 (-237)) (-194)))) (-4004 (((-658 (-191 (-237))) $) NIL)) (-3178 (((-790) $) NIL (|has| (-191 (-237)) (-582)))) (-3555 (((-658 (-166)) $) NIL (|has| (-191 (-237)) (-582)))) (-4292 (((-790) $) 10)) (-3242 (($ (-790) (-790) (-191 (-237))) 19)) (-4298 (((-790) $) 11)) (-4345 (((-141) $ (-790)) NIL)) (-3781 (((-191 (-237)) $) NIL (|has| (-191 (-237)) (-6 (-4627 "*"))))) (-4577 (((-592) $) 7)) (-4280 (((-592) $) 8)) (-4467 (((-658 (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-191 (-237)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-191 (-237)) (-1119))))) (-1898 (((-592) $) 12)) (-3005 (((-592) $) 13)) (-4186 (($ (-658 (-658 (-191 (-237))))) NIL) (($ (-790) (-790) (-1 (-191 (-237)) (-592) (-592))) NIL)) (-3987 (($ (-1 (-191 (-237)) (-191 (-237))) $) NIL)) (-2731 (($ (-1 (-191 (-237)) (-191 (-237))) $) NIL) (($ (-1 (-191 (-237)) (-191 (-237)) (-191 (-237))) $ $) NIL) (($ (-1 (-191 (-237)) (-191 (-237)) (-191 (-237))) $ $ (-191 (-237))) NIL)) (-4601 (((-658 (-658 (-191 (-237)))) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| (-191 (-237)) (-1119)))) (-3183 (((-3 $ "failed") $) NIL (|has| (-191 (-237)) (-388)))) (-2083 (($ $ $) NIL)) (-2951 (((-1137) $) NIL (|has| (-191 (-237)) (-1119)))) (-1892 (($ $ (-191 (-237))) NIL)) (-3616 (((-3 $ "failed") $ (-191 (-237))) NIL (|has| (-191 (-237)) (-582)))) (-3002 (((-141) (-1 (-141) (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-191 (-237))))) NIL (-12 (|has| (-191 (-237)) (-325 (-191 (-237)))) (|has| (-191 (-237)) (-1119)))) (($ $ (-310 (-191 (-237)))) NIL (-12 (|has| (-191 (-237)) (-325 (-191 (-237)))) (|has| (-191 (-237)) (-1119)))) (($ $ (-191 (-237)) (-191 (-237))) NIL (-12 (|has| (-191 (-237)) (-325 (-191 (-237)))) (|has| (-191 (-237)) (-1119)))) (($ $ (-658 (-191 (-237))) (-658 (-191 (-237)))) NIL (-12 (|has| (-191 (-237)) (-325 (-191 (-237)))) (|has| (-191 (-237)) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 17)) (-3927 (((-191 (-237)) $ (-592) (-592)) NIL) (((-191 (-237)) $ (-592) (-592) (-191 (-237))) NIL) (($ $ (-658 (-592)) (-658 (-592))) NIL)) (-2933 (($ (-658 (-191 (-237)))) NIL) (($ (-658 $)) NIL)) (-2940 (((-141) $) NIL)) (-1625 (((-191 (-237)) $) NIL (|has| (-191 (-237)) (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) (-191 (-237))) $) NIL (|has| $ (-6 -4625))) (((-790) (-191 (-237)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-191 (-237)) (-1119))))) (-4599 (($ $) NIL)) (-3430 (((-658 (-166)) $) NIL (|has| (-191 (-237)) (-323)))) (-2000 (((-166) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| (-191 (-237)) (-1119))) (($ (-166)) NIL)) (-3369 (((-141) (-1 (-141) (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL (|has| (-191 (-237)) (-1119)))) (-3313 (($ $ (-191 (-237))) NIL (|has| (-191 (-237)) (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-191 (-237)) (-388)))) (* (($ $ $) NIL) (($ (-191 (-237)) $) NIL) (($ $ (-191 (-237))) NIL) (($ (-592) $) NIL) (((-166) $ (-166)) NIL) (((-166) (-166) $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-165) (-13 (-704 (-191 (-237)) (-166) (-166)) (-10 -8 (-15 -1695 ($ (-592) (-592)))))) (T -165)) 
+((-1695 (*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-165))))) 
+(-13 (-704 (-191 (-237)) (-166) (-166)) (-10 -8 (-15 -1695 ($ (-592) (-592))))) 
+((-1641 (((-141) $ $) NIL (|has| (-191 (-237)) (-1119)))) (-1417 (($ (-790)) NIL (|has| (-191 (-237)) (-23)))) (-3665 (($ (-658 (-191 (-237)))) NIL)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) (-191 (-237)) (-191 (-237))) $) NIL) (((-141) $) NIL (|has| (-191 (-237)) (-869)))) (-2831 (($ (-1 (-141) (-191 (-237)) (-191 (-237))) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-191 (-237)) (-869))))) (-3960 (($ (-1 (-141) (-191 (-237)) (-191 (-237))) $) NIL) (($ $) NIL (|has| (-191 (-237)) (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-191 (-237)) $ (-592) (-191 (-237))) 18 (|has| $ (-6 -4626))) (((-191 (-237)) $ (-1246 (-592)) (-191 (-237))) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-191 (-237)) (-1119))))) (-4459 (($ (-191 (-237)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-191 (-237)) (-1119)))) (($ (-1 (-141) (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-191 (-237)) (-1 (-191 (-237)) (-191 (-237)) (-191 (-237))) $ (-191 (-237)) (-191 (-237))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-191 (-237)) (-1119)))) (((-191 (-237)) (-1 (-191 (-237)) (-191 (-237)) (-191 (-237))) $ (-191 (-237))) NIL (|has| $ (-6 -4625))) (((-191 (-237)) (-1 (-191 (-237)) (-191 (-237)) (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-191 (-237)) $ (-592) (-191 (-237))) 9 (|has| $ (-6 -4626)))) (-1695 (($ (-592)) 14)) (-3959 (((-191 (-237)) $ (-592)) 8)) (-1721 (((-592) (-1 (-141) (-191 (-237))) $) NIL) (((-592) (-191 (-237)) $) NIL (|has| (-191 (-237)) (-1119))) (((-592) (-191 (-237)) $ (-592)) NIL (|has| (-191 (-237)) (-1119)))) (-4004 (((-658 (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-4363 (((-706 (-191 (-237))) $ $) NIL (|has| (-191 (-237)) (-1075)))) (-3242 (($ (-790) (-191 (-237))) 16)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 12 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| (-191 (-237)) (-869)))) (-4491 (($ (-1 (-141) (-191 (-237)) (-191 (-237))) $ $) NIL) (($ $ $) NIL (|has| (-191 (-237)) (-869)))) (-4467 (((-658 (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-191 (-237)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-191 (-237)) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-191 (-237)) (-869)))) (-3987 (($ (-1 (-191 (-237)) (-191 (-237))) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-191 (-237)) (-191 (-237))) $) NIL) (($ (-1 (-191 (-237)) (-191 (-237)) (-191 (-237))) $ $) NIL)) (-2311 (((-191 (-237)) $) NIL (-12 (|has| (-191 (-237)) (-1030)) (|has| (-191 (-237)) (-1075))))) (-2554 (((-141) $ (-790)) NIL)) (-4233 (((-191 (-237)) $) NIL (-12 (|has| (-191 (-237)) (-1030)) (|has| (-191 (-237)) (-1075))))) (-2685 (((-1173) $) NIL (|has| (-191 (-237)) (-1119)))) (-3666 (($ (-191 (-237)) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| (-191 (-237)) (-1119)))) (-1918 (((-191 (-237)) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-191 (-237)) "failed") (-1 (-141) (-191 (-237))) $) NIL)) (-1892 (($ $ (-191 (-237))) 15 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-191 (-237))))) NIL (-12 (|has| (-191 (-237)) (-325 (-191 (-237)))) (|has| (-191 (-237)) (-1119)))) (($ $ (-310 (-191 (-237)))) NIL (-12 (|has| (-191 (-237)) (-325 (-191 (-237)))) (|has| (-191 (-237)) (-1119)))) (($ $ (-191 (-237)) (-191 (-237))) NIL (-12 (|has| (-191 (-237)) (-325 (-191 (-237)))) (|has| (-191 (-237)) (-1119)))) (($ $ (-658 (-191 (-237))) (-658 (-191 (-237)))) NIL (-12 (|has| (-191 (-237)) (-325 (-191 (-237)))) (|has| (-191 (-237)) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-191 (-237)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-191 (-237)) (-1119))))) (-4210 (((-658 (-191 (-237))) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 13)) (-3927 (((-191 (-237)) $ (-592) (-191 (-237))) NIL) (((-191 (-237)) $ (-592)) 17) (($ $ (-1246 (-592))) NIL)) (-1729 (((-191 (-237)) $ $) NIL (|has| (-191 (-237)) (-1075)))) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-2746 (($ $ $) NIL (|has| (-191 (-237)) (-1075)))) (-3452 (((-790) (-1 (-141) (-191 (-237))) $) NIL (|has| $ (-6 -4625))) (((-790) (-191 (-237)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-191 (-237)) (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-191 (-237)) (-633 (-565))))) (-4466 (($ (-658 (-191 (-237)))) NIL)) (-2266 (($ $ (-191 (-237))) NIL) (($ (-191 (-237)) $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| (-191 (-237)) (-1119)))) (-3369 (((-141) (-1 (-141) (-191 (-237))) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| (-191 (-237)) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-191 (-237)) (-869)))) (-3255 (((-141) $ $) NIL (|has| (-191 (-237)) (-1119)))) (-3279 (((-141) $ $) NIL (|has| (-191 (-237)) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-191 (-237)) (-869)))) (-3306 (($ $) NIL (|has| (-191 (-237)) (-21))) (($ $ $) NIL (|has| (-191 (-237)) (-21)))) (-3300 (($ $ $) NIL (|has| (-191 (-237)) (-25)))) (* (($ (-592) $) NIL (|has| (-191 (-237)) (-21))) (($ (-191 (-237)) $) NIL (|has| (-191 (-237)) (-743))) (($ $ (-191 (-237))) NIL (|has| (-191 (-237)) (-743)))) (-1699 (((-790) $) 11 (|has| $ (-6 -4625))))) 
+(((-166) (-13 (-1278 (-191 (-237))) (-10 -8 (-15 -1695 ($ (-592))) (-15 -3665 ($ (-658 (-191 (-237)))))))) (T -166)) 
+((-1695 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-166)))) (-3665 (*1 *1 *2) (-12 (-5 *2 (-658 (-191 (-237)))) (-5 *1 (-166))))) 
+(-13 (-1278 (-191 (-237))) (-10 -8 (-15 -1695 ($ (-592))) (-15 -3665 ($ (-658 (-191 (-237))))))) 
+((-3870 (($ $ $) 8)) (-2283 (($ $) 7)) (-4042 (($ $ $) 6))) 
+(((-167) (-1311)) (T -167)) 
+((-3870 (*1 *1 *1 *1) (-4 *1 (-167))) (-2283 (*1 *1 *1) (-4 *1 (-167))) (-4042 (*1 *1 *1 *1) (-4 *1 (-167)))) 
+(-13 (-10 -8 (-15 -4042 ($ $ $)) (-15 -2283 ($ $)) (-15 -3870 ($ $ $)))) 
+((-1641 (((-141) $ $) NIL)) (-1766 (((-141) $) 38)) (-3777 (($ $) 50)) (-2366 (($) 25)) (-1403 (((-790)) 16)) (-4290 (($) 24)) (-3645 (($) 26)) (-2016 (((-592) $) 21)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2454 (((-141) $) 40)) (-1633 (($ $) 51)) (-3546 (((-944) $) 22)) (-2685 (((-1173) $) 46)) (-1825 (($ (-944)) 20)) (-3648 (((-141) $) 36)) (-2951 (((-1137) $) NIL)) (-1354 (($) 27)) (-1405 (((-658 $)) NIL)) (-3791 (((-141) $) 34)) (-1683 (((-877) $) 29)) (-3289 (($ (-592)) 18) (($ (-1173)) 49)) (-2143 (((-141) $) 44)) (-4468 (((-141) $) 42)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 13)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 14))) 
+(((-168) (-13 (-863) (-10 -8 (-15 -2016 ((-592) $)) (-15 -3289 ($ (-592))) (-15 -3289 ($ (-1173))) (-15 -2366 ($)) (-15 -3645 ($)) (-15 -1354 ($)) (-15 -3777 ($ $)) (-15 -1633 ($ $)) (-15 -3791 ((-141) $)) (-15 -3648 ((-141) $)) (-15 -4468 ((-141) $)) (-15 -1766 ((-141) $)) (-15 -2454 ((-141) $)) (-15 -2143 ((-141) $))))) (T -168)) 
+((-2016 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-168)))) (-3289 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-168)))) (-3289 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-168)))) (-2366 (*1 *1) (-5 *1 (-168))) (-3645 (*1 *1) (-5 *1 (-168))) (-1354 (*1 *1) (-5 *1 (-168))) (-3777 (*1 *1 *1) (-5 *1 (-168))) (-1633 (*1 *1 *1) (-5 *1 (-168))) (-3791 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168)))) (-3648 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168)))) (-4468 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168)))) (-1766 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168)))) (-2454 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168)))) (-2143 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168))))) 
+(-13 (-863) (-10 -8 (-15 -2016 ((-592) $)) (-15 -3289 ($ (-592))) (-15 -3289 ($ (-1173))) (-15 -2366 ($)) (-15 -3645 ($)) (-15 -1354 ($)) (-15 -3777 ($ $)) (-15 -1633 ($ $)) (-15 -3791 ((-141) $)) (-15 -3648 ((-141) $)) (-15 -4468 ((-141) $)) (-15 -1766 ((-141) $)) (-15 -2454 ((-141) $)) (-15 -2143 ((-141) $)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-1517 (((-3 $ "failed") $) 34)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-169) (-1311)) (T -169)) 
+((-1517 (*1 *1 *1) (|partial| -4 *1 (-169)))) 
+(-13 (-1075) (-10 -8 (-15 -1517 ((-3 $ "failed") $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-4198 ((|#1| (-706 |#1|) |#1|) 17))) 
+(((-170 |#1|) (-10 -7 (-15 -4198 (|#1| (-706 |#1|) |#1|))) (-194)) (T -170)) 
+((-4198 (*1 *2 *3 *2) (-12 (-5 *3 (-706 *2)) (-4 *2 (-194)) (-5 *1 (-170 *2))))) 
+(-10 -7 (-15 -4198 (|#1| (-706 |#1|) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-171) (-1311)) (T -171)) 
+NIL 
+(-13 (-1075)) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-4119 (((-2 (|:| -3215 (-790)) (|:| -1487 (-433 |#2|)) (|:| |radicand| |#2|)) (-433 |#2|) (-790)) 69)) (-2987 (((-3 (-2 (|:| |radicand| (-433 |#2|)) (|:| |deg| (-790))) "failed") |#3|) 51)) (-1983 (((-2 (|:| -1487 (-433 |#2|)) (|:| |poly| |#3|)) |#3|) 36)) (-1661 ((|#1| |#3| |#3|) 39)) (-2806 ((|#3| |#3| (-433 |#2|) (-433 |#2|)) 19)) (-2529 (((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-433 |#2|)) (|:| |c2| (-433 |#2|)) (|:| |deg| (-790))) |#3| |#3|) 48))) 
+(((-172 |#1| |#2| |#3|) (-10 -7 (-15 -1983 ((-2 (|:| -1487 (-433 |#2|)) (|:| |poly| |#3|)) |#3|)) (-15 -2987 ((-3 (-2 (|:| |radicand| (-433 |#2|)) (|:| |deg| (-790))) "failed") |#3|)) (-15 -4119 ((-2 (|:| -3215 (-790)) (|:| -1487 (-433 |#2|)) (|:| |radicand| |#2|)) (-433 |#2|) (-790))) (-15 -1661 (|#1| |#3| |#3|)) (-15 -2806 (|#3| |#3| (-433 |#2|) (-433 |#2|))) (-15 -2529 ((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-433 |#2|)) (|:| |c2| (-433 |#2|)) (|:| |deg| (-790))) |#3| |#3|))) (-1235) (-1255 |#1|) (-1255 (-433 |#2|))) (T -172)) 
+((-2529 (*1 *2 *3 *3) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (-433 *5)) (|:| |c2| (-433 *5)) (|:| |deg| (-790)))) (-5 *1 (-172 *4 *5 *3)) (-4 *3 (-1255 (-433 *5))))) (-2806 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-433 *5)) (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-5 *1 (-172 *4 *5 *2)) (-4 *2 (-1255 *3)))) (-1661 (*1 *2 *3 *3) (-12 (-4 *4 (-1255 *2)) (-4 *2 (-1235)) (-5 *1 (-172 *2 *4 *3)) (-4 *3 (-1255 (-433 *4))))) (-4119 (*1 *2 *3 *4) (-12 (-5 *3 (-433 *6)) (-4 *5 (-1235)) (-4 *6 (-1255 *5)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *3) (|:| |radicand| *6))) (-5 *1 (-172 *5 *6 *7)) (-5 *4 (-790)) (-4 *7 (-1255 *3)))) (-2987 (*1 *2 *3) (|partial| -12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| |radicand| (-433 *5)) (|:| |deg| (-790)))) (-5 *1 (-172 *4 *5 *3)) (-4 *3 (-1255 (-433 *5))))) (-1983 (*1 *2 *3) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -1487 (-433 *5)) (|:| |poly| *3))) (-5 *1 (-172 *4 *5 *3)) (-4 *3 (-1255 (-433 *5)))))) 
+(-10 -7 (-15 -1983 ((-2 (|:| -1487 (-433 |#2|)) (|:| |poly| |#3|)) |#3|)) (-15 -2987 ((-3 (-2 (|:| |radicand| (-433 |#2|)) (|:| |deg| (-790))) "failed") |#3|)) (-15 -4119 ((-2 (|:| -3215 (-790)) (|:| -1487 (-433 |#2|)) (|:| |radicand| |#2|)) (-433 |#2|) (-790))) (-15 -1661 (|#1| |#3| |#3|)) (-15 -2806 (|#3| |#3| (-433 |#2|) (-433 |#2|))) (-15 -2529 ((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-433 |#2|)) (|:| |c2| (-433 |#2|)) (|:| |deg| (-790))) |#3| |#3|))) 
+((-3524 (((-3 (-658 (-1187 |#2|)) "failed") (-658 (-1187 |#2|)) (-1187 |#2|)) 31))) 
+(((-173 |#1| |#2|) (-10 -7 (-15 -3524 ((-3 (-658 (-1187 |#2|)) "failed") (-658 (-1187 |#2|)) (-1187 |#2|)))) (-574) (-188 |#1|)) (T -173)) 
+((-3524 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *5))) (-5 *3 (-1187 *5)) (-4 *5 (-188 *4)) (-4 *4 (-574)) (-5 *1 (-173 *4 *5))))) 
+(-10 -7 (-15 -3524 ((-3 (-658 (-1187 |#2|)) "failed") (-658 (-1187 |#2|)) (-1187 |#2|)))) 
+((-3113 (($ (-1 (-141) |#2|) $) 29)) (-1360 (($ $) 36)) (-4459 (($ (-1 (-141) |#2|) $) 27) (($ |#2| $) 32)) (-3657 ((|#2| (-1 |#2| |#2| |#2|) $) 22) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 24) ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 34)) (-4050 (((-3 |#2| "failed") (-1 (-141) |#2|) $) 19)) (-3002 (((-141) (-1 (-141) |#2|) $) 16)) (-3452 (((-790) (-1 (-141) |#2|) $) 13) (((-790) |#2| $) NIL)) (-3369 (((-141) (-1 (-141) |#2|) $) 15)) (-1699 (((-790) $) 11))) 
+(((-174 |#1| |#2|) (-10 -8 (-15 -1360 (|#1| |#1|)) (-15 -4459 (|#1| |#2| |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3113 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4459 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -4050 ((-3 |#2| "failed") (-1 (-141) |#2|) |#1|)) (-15 -3452 ((-790) |#2| |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -1699 ((-790) |#1|))) (-175 |#2|) (-1225)) (T -174)) 
+NIL 
+(-10 -8 (-15 -1360 (|#1| |#1|)) (-15 -4459 (|#1| |#2| |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3113 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4459 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -4050 ((-3 |#2| "failed") (-1 (-141) |#2|) |#1|)) (-15 -3452 ((-790) |#2| |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -1699 ((-790) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-3113 (($ (-1 (-141) |#1|) $) 41 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1360 (($ $) 38 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ (-1 (-141) |#1|) $) 42 (|has| $ (-6 -4625))) (($ |#1| $) 39 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $) 44 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 43 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 40 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 45)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 37 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 46)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-175 |#1|) (-1311) (-1225)) (T -175)) 
+((-4466 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-4 *1 (-175 *3)))) (-4050 (*1 *2 *3 *1) (|partial| -12 (-5 *3 (-1 (-141) *2)) (-4 *1 (-175 *2)) (-4 *2 (-1225)))) (-3657 (*1 *2 *3 *1) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)))) (-3657 (*1 *2 *3 *1 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)))) (-4459 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *3)) (-4 *3 (-1225)))) (-3113 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *3)) (-4 *3 (-1225)))) (-3657 (*1 *2 *3 *1 *2 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1119)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)))) (-4459 (*1 *1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)) (-4 *2 (-1119)))) (-1360 (*1 *1 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)) (-4 *2 (-1119))))) 
+(-13 (-523 |t#1|) (-10 -8 (-15 -4466 ($ (-658 |t#1|))) (-15 -4050 ((-3 |t#1| "failed") (-1 (-141) |t#1|) $)) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3657 (|t#1| (-1 |t#1| |t#1| |t#1|) $)) (-15 -3657 (|t#1| (-1 |t#1| |t#1| |t#1|) $ |t#1|)) (-15 -4459 ($ (-1 (-141) |t#1|) $)) (-15 -3113 ($ (-1 (-141) |t#1|) $)) (IF (|has| |t#1| (-1119)) (PROGN (-15 -3657 (|t#1| (-1 |t#1| |t#1| |t#1|) $ |t#1| |t#1|)) (-15 -4459 ($ |t#1| $)) (-15 -1360 ($ $))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) 85)) (-3558 (((-141) $) NIL)) (-4526 (($ |#2| (-658 (-944))) 56)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3881 (($ (-944)) 48)) (-1936 (((-160)) 23)) (-1683 (((-877) $) 68) (($ (-592)) 46) (($ |#2|) 47)) (-1937 ((|#2| $ (-658 (-944))) 58)) (-4010 (((-790)) 20)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 40 T CONST)) (-4257 (($) 44 T CONST)) (-3255 (((-141) $ $) 26)) (-3313 (($ $ |#2|) NIL)) (-3306 (($ $) 34) (($ $ $) 32)) (-3300 (($ $ $) 30)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 37) (($ $ $) 52) (($ |#2| $) 39) (($ $ |#2|) NIL))) 
+(((-176 |#1| |#2| |#3|) (-13 (-1075) (-43 |#2|) (-1287 |#2|) (-10 -8 (-15 -3881 ($ (-944))) (-15 -4526 ($ |#2| (-658 (-944)))) (-15 -1937 (|#2| $ (-658 (-944)))) (-15 -3371 ((-3 $ "failed") $)))) (-944) (-388) (-1022 |#1| |#2|)) (T -176)) 
+((-3371 (*1 *1 *1) (|partial| -12 (-5 *1 (-176 *2 *3 *4)) (-14 *2 (-944)) (-4 *3 (-388)) (-14 *4 (-1022 *2 *3)))) (-3881 (*1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-176 *3 *4 *5)) (-14 *3 *2) (-4 *4 (-388)) (-14 *5 (-1022 *3 *4)))) (-4526 (*1 *1 *2 *3) (-12 (-5 *3 (-658 (-944))) (-5 *1 (-176 *4 *2 *5)) (-14 *4 (-944)) (-4 *2 (-388)) (-14 *5 (-1022 *4 *2)))) (-1937 (*1 *2 *1 *3) (-12 (-5 *3 (-658 (-944))) (-4 *2 (-388)) (-5 *1 (-176 *4 *2 *5)) (-14 *4 (-944)) (-14 *5 (-1022 *4 *2))))) 
+(-13 (-1075) (-43 |#2|) (-1287 |#2|) (-10 -8 (-15 -3881 ($ (-944))) (-15 -4526 ($ |#2| (-658 (-944)))) (-15 -1937 (|#2| $ (-658 (-944)))) (-15 -3371 ((-3 $ "failed") $)))) 
+((-2956 (((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-658 (-971 (-237)))) (-237) (-237) (-237) (-237)) 38)) (-4250 (((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954) (-433 (-592)) (-433 (-592))) 62) (((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954)) 63)) (-3100 (((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-658 (-971 (-237))))) 66) (((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-971 (-237)))) 65) (((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954) (-433 (-592)) (-433 (-592))) 57) (((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954)) 58))) 
+(((-177) (-10 -7 (-15 -3100 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954))) (-15 -3100 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954) (-433 (-592)) (-433 (-592)))) (-15 -4250 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954))) (-15 -4250 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954) (-433 (-592)) (-433 (-592)))) (-15 -2956 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-658 (-971 (-237)))) (-237) (-237) (-237) (-237))) (-15 -3100 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-971 (-237))))) (-15 -3100 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-658 (-971 (-237)))))))) (T -177)) 
+((-3100 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)) (-5 *3 (-658 (-658 (-971 (-237))))))) (-3100 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)) (-5 *3 (-658 (-971 (-237)))))) (-2956 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *4 (-237)) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 *4)))) (|:| |xValues| (-1113 *4)) (|:| |yValues| (-1113 *4)))) (-5 *1 (-177)) (-5 *3 (-658 (-658 (-971 *4)))))) (-4250 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-954)) (-5 *4 (-433 (-592))) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)))) (-4250 (*1 *2 *3) (-12 (-5 *3 (-954)) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)))) (-3100 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-954)) (-5 *4 (-433 (-592))) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)))) (-3100 (*1 *2 *3) (-12 (-5 *3 (-954)) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177))))) 
+(-10 -7 (-15 -3100 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954))) (-15 -3100 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954) (-433 (-592)) (-433 (-592)))) (-15 -4250 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954))) (-15 -4250 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-954) (-433 (-592)) (-433 (-592)))) (-15 -2956 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-658 (-971 (-237)))) (-237) (-237) (-237) (-237))) (-15 -3100 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-971 (-237))))) (-15 -3100 ((-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237)))) (-658 (-658 (-971 (-237))))))) 
+((-3688 (((-658 (-191 |#2|)) |#1| |#2|) 45))) 
+(((-178 |#1| |#2|) (-10 -7 (-15 -3688 ((-658 (-191 |#2|)) |#1| |#2|))) (-1255 (-191 (-592))) (-13 (-388) (-867))) (T -178)) 
+((-3688 (*1 *2 *3 *4) (-12 (-5 *2 (-658 (-191 *4))) (-5 *1 (-178 *3 *4)) (-4 *3 (-1255 (-191 (-592)))) (-4 *4 (-13 (-388) (-867)))))) 
+(-10 -7 (-15 -3688 ((-658 (-191 |#2|)) |#1| |#2|))) 
+((-1641 (((-141) $ $) NIL)) (-2082 (($) 15)) (-4080 (($) 14)) (-3877 (((-944)) 22)) (-2685 (((-1173) $) NIL)) (-3850 (((-592) $) 19)) (-2951 (((-1137) $) NIL)) (-1420 (($) 16)) (-2932 (($ (-592)) 23)) (-1683 (((-877) $) 29)) (-2796 (($) 17)) (-3255 (((-141) $ $) 13)) (-3300 (($ $ $) 11)) (* (($ (-944) $) 21) (($ (-237) $) 8))) 
+(((-179) (-13 (-25) (-10 -8 (-15 * ($ (-944) $)) (-15 * ($ (-237) $)) (-15 -3300 ($ $ $)) (-15 -4080 ($)) (-15 -2082 ($)) (-15 -1420 ($)) (-15 -2796 ($)) (-15 -3850 ((-592) $)) (-15 -3877 ((-944))) (-15 -2932 ($ (-592)))))) (T -179)) 
+((-3300 (*1 *1 *1 *1) (-5 *1 (-179))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-944)) (-5 *1 (-179)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-237)) (-5 *1 (-179)))) (-4080 (*1 *1) (-5 *1 (-179))) (-2082 (*1 *1) (-5 *1 (-179))) (-1420 (*1 *1) (-5 *1 (-179))) (-2796 (*1 *1) (-5 *1 (-179))) (-3850 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-179)))) (-3877 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-179)))) (-2932 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-179))))) 
+(-13 (-25) (-10 -8 (-15 * ($ (-944) $)) (-15 * ($ (-237) $)) (-15 -3300 ($ $ $)) (-15 -4080 ($)) (-15 -2082 ($)) (-15 -1420 ($)) (-15 -2796 ($)) (-15 -3850 ((-592) $)) (-15 -3877 ((-944))) (-15 -2932 ($ (-592))))) 
+((-2178 ((|#2| |#2| (-1111 |#2|)) 87) ((|#2| |#2| (-1191)) 67)) (-3679 ((|#2| |#2| (-1111 |#2|)) 86) ((|#2| |#2| (-1191)) 66)) (-3870 ((|#2| |#2| |#2|) 27)) (-2791 (((-143) (-143)) 97)) (-4019 ((|#2| (-658 |#2|)) 116)) (-2762 ((|#2| (-658 |#2|)) 134)) (-2080 ((|#2| (-658 |#2|)) 124)) (-3221 ((|#2| |#2|) 122)) (-2994 ((|#2| (-658 |#2|)) 109)) (-3212 ((|#2| (-658 |#2|)) 110)) (-3426 ((|#2| (-658 |#2|)) 132)) (-2944 ((|#2| |#2| (-1191)) 54) ((|#2| |#2|) 53)) (-2283 ((|#2| |#2|) 23)) (-4042 ((|#2| |#2| |#2|) 26)) (-3038 (((-141) (-143)) 47)) (** ((|#2| |#2| |#2|) 38))) 
+(((-180 |#1| |#2|) (-10 -7 (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 ** (|#2| |#2| |#2|)) (-15 -4042 (|#2| |#2| |#2|)) (-15 -3870 (|#2| |#2| |#2|)) (-15 -2283 (|#2| |#2|)) (-15 -2944 (|#2| |#2|)) (-15 -2944 (|#2| |#2| (-1191))) (-15 -2178 (|#2| |#2| (-1191))) (-15 -2178 (|#2| |#2| (-1111 |#2|))) (-15 -3679 (|#2| |#2| (-1191))) (-15 -3679 (|#2| |#2| (-1111 |#2|))) (-15 -3221 (|#2| |#2|)) (-15 -3426 (|#2| (-658 |#2|))) (-15 -2080 (|#2| (-658 |#2|))) (-15 -2762 (|#2| (-658 |#2|))) (-15 -2994 (|#2| (-658 |#2|))) (-15 -3212 (|#2| (-658 |#2|))) (-15 -4019 (|#2| (-658 |#2|)))) (-13 (-869) (-582)) (-456 |#1|)) (T -180)) 
+((-4019 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-3212 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-2994 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-2762 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-2080 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-3426 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-3221 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) (-3679 (*1 *2 *2 *3) (-12 (-5 *3 (-1111 *2)) (-4 *2 (-456 *4)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)))) (-3679 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)) (-4 *2 (-456 *4)))) (-2178 (*1 *2 *2 *3) (-12 (-5 *3 (-1111 *2)) (-4 *2 (-456 *4)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)))) (-2178 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)) (-4 *2 (-456 *4)))) (-2944 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)) (-4 *2 (-456 *4)))) (-2944 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) (-2283 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) (-3870 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) (-4042 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) (** (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) (-2791 (*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *4)) (-4 *4 (-456 *3)))) (-3038 (*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-180 *4 *5)) (-4 *5 (-456 *4))))) 
+(-10 -7 (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 ** (|#2| |#2| |#2|)) (-15 -4042 (|#2| |#2| |#2|)) (-15 -3870 (|#2| |#2| |#2|)) (-15 -2283 (|#2| |#2|)) (-15 -2944 (|#2| |#2|)) (-15 -2944 (|#2| |#2| (-1191))) (-15 -2178 (|#2| |#2| (-1191))) (-15 -2178 (|#2| |#2| (-1111 |#2|))) (-15 -3679 (|#2| |#2| (-1191))) (-15 -3679 (|#2| |#2| (-1111 |#2|))) (-15 -3221 (|#2| |#2|)) (-15 -3426 (|#2| (-658 |#2|))) (-15 -2080 (|#2| (-658 |#2|))) (-15 -2762 (|#2| (-658 |#2|))) (-15 -2994 (|#2| (-658 |#2|))) (-15 -3212 (|#2| (-658 |#2|))) (-15 -4019 (|#2| (-658 |#2|)))) 
+((-4396 ((|#1| |#1| |#1|) 52)) (-2995 ((|#1| |#1| |#1|) 49)) (-3870 ((|#1| |#1| |#1|) 43)) (-1744 ((|#1| |#1|) 34)) (-2525 ((|#1| |#1| (-658 |#1|)) 42)) (-2283 ((|#1| |#1|) 36)) (-4042 ((|#1| |#1| |#1|) 39))) 
+(((-181 |#1|) (-10 -7 (-15 -4042 (|#1| |#1| |#1|)) (-15 -2283 (|#1| |#1|)) (-15 -2525 (|#1| |#1| (-658 |#1|))) (-15 -1744 (|#1| |#1|)) (-15 -3870 (|#1| |#1| |#1|)) (-15 -2995 (|#1| |#1| |#1|)) (-15 -4396 (|#1| |#1| |#1|))) (-574)) (T -181)) 
+((-4396 (*1 *2 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574)))) (-2995 (*1 *2 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574)))) (-3870 (*1 *2 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574)))) (-1744 (*1 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574)))) (-2525 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-574)) (-5 *1 (-181 *2)))) (-2283 (*1 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574)))) (-4042 (*1 *2 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574))))) 
+(-10 -7 (-15 -4042 (|#1| |#1| |#1|)) (-15 -2283 (|#1| |#1|)) (-15 -2525 (|#1| |#1| (-658 |#1|))) (-15 -1744 (|#1| |#1|)) (-15 -3870 (|#1| |#1| |#1|)) (-15 -2995 (|#1| |#1| |#1|)) (-15 -4396 (|#1| |#1| |#1|))) 
+((-2178 (($ $ (-1191)) 12) (($ $ (-1111 $)) 11)) (-3679 (($ $ (-1191)) 10) (($ $ (-1111 $)) 9)) (-3870 (($ $ $) 8)) (-2944 (($ $) 14) (($ $ (-1191)) 13)) (-2283 (($ $) 7)) (-4042 (($ $ $) 6))) 
+(((-182) (-1311)) (T -182)) 
+((-2944 (*1 *1 *1) (-4 *1 (-182))) (-2944 (*1 *1 *1 *2) (-12 (-4 *1 (-182)) (-5 *2 (-1191)))) (-2178 (*1 *1 *1 *2) (-12 (-4 *1 (-182)) (-5 *2 (-1191)))) (-2178 (*1 *1 *1 *2) (-12 (-5 *2 (-1111 *1)) (-4 *1 (-182)))) (-3679 (*1 *1 *1 *2) (-12 (-4 *1 (-182)) (-5 *2 (-1191)))) (-3679 (*1 *1 *1 *2) (-12 (-5 *2 (-1111 *1)) (-4 *1 (-182))))) 
+(-13 (-167) (-10 -8 (-15 -2944 ($ $)) (-15 -2944 ($ $ (-1191))) (-15 -2178 ($ $ (-1191))) (-15 -2178 ($ $ (-1111 $))) (-15 -3679 ($ $ (-1191))) (-15 -3679 ($ $ (-1111 $))))) 
+(((-167) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2009 (($ (-592)) 13) (($ $ $) 14)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 17)) (-3255 (((-141) $ $) 9))) 
+(((-183) (-13 (-1119) (-10 -8 (-15 -2009 ($ (-592))) (-15 -2009 ($ $ $))))) (T -183)) 
+((-2009 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-183)))) (-2009 (*1 *1 *1 *1) (-5 *1 (-183)))) 
+(-13 (-1119) (-10 -8 (-15 -2009 ($ (-592))) (-15 -2009 ($ $ $)))) 
+((-2791 (((-143) (-1191)) 99))) 
+(((-184) (-10 -7 (-15 -2791 ((-143) (-1191))))) (T -184)) 
+((-2791 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-143)) (-5 *1 (-184))))) 
+(-10 -7 (-15 -2791 ((-143) (-1191)))) 
+((-1905 ((|#3| |#3|) 19))) 
+(((-185 |#1| |#2| |#3|) (-10 -7 (-15 -1905 (|#3| |#3|))) (-1075) (-1255 |#1|) (-1255 |#2|)) (T -185)) 
+((-1905 (*1 *2 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-1255 *3)) (-5 *1 (-185 *3 *4 *2)) (-4 *2 (-1255 *4))))) 
+(-10 -7 (-15 -1905 (|#3| |#3|))) 
+((-1641 (((-141) $ $) 7)) (-1828 (((-141) $ $) 12)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-186) (-1311)) (T -186)) 
+((-1828 (*1 *2 *1 *1) (-12 (-4 *1 (-186)) (-5 *2 (-141))))) 
+(-13 (-1119) (-10 -8 (-15 -1828 ((-141) $ $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 215)) (-4529 ((|#2| $) 95)) (-1588 (($ $) 242)) (-1507 (($ $) 236)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 39)) (-1575 (($ $) 240)) (-1495 (($ $) 234)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 |#2| "failed") $) 139)) (-2400 (((-592) $) NIL) (((-433 (-592)) $) NIL) ((|#2| $) 137)) (-1586 (($ $ $) 220)) (-3945 (((-706 (-592)) (-706 $)) NIL) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) 153) (((-706 |#2|) (-706 $)) 147)) (-3657 (($ (-1187 |#2|)) 118) (((-3 $ "failed") (-433 (-1187 |#2|))) NIL)) (-3371 (((-3 $ "failed") $) 207)) (-4182 (((-3 (-433 (-592)) "failed") $) 197)) (-2435 (((-141) $) 192)) (-2270 (((-433 (-592)) $) 195)) (-4175 (((-944)) 88)) (-1599 (($ $ $) 222)) (-4120 (((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) $) 258)) (-1435 (($) 231)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 184) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 189)) (-2793 ((|#2| $) 93)) (-3504 (((-1187 |#2|) $) 120)) (-2731 (($ (-1 |#2| |#2|) $) 101)) (-4546 (($ $) 233)) (-3650 (((-1187 |#2|) $) 119)) (-4552 (($ $) 200)) (-2795 (($) 96)) (-1416 (((-444 (-1187 $)) (-1187 $)) 87)) (-3339 (((-444 (-1187 $)) (-1187 $)) 56)) (-3616 (((-3 $ "failed") $ |#2|) 202) (((-3 $ "failed") $ $) 205)) (-1430 (($ $) 232)) (-2769 (((-790) $) 217)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 226)) (-1482 ((|#2| (-1280 $)) NIL) ((|#2|) 90)) (-3644 (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) 112) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL) (($ $ (-790)) NIL) (($ $) NIL)) (-3390 (((-1187 |#2|)) 113)) (-1581 (($ $) 241)) (-1501 (($ $) 235)) (-2231 (((-1280 |#2|) $ (-1280 $)) 126) (((-706 |#2|) (-1280 $) (-1280 $)) NIL) (((-1280 |#2|) $) 109) (((-706 |#2|) (-1280 $)) NIL)) (-1778 (((-1280 |#2|) $) NIL) (($ (-1280 |#2|)) NIL) (((-1187 |#2|) $) NIL) (($ (-1187 |#2|)) NIL) (((-914 (-592)) $) 175) (((-914 (-405)) $) 179) (((-191 (-405)) $) 165) (((-191 (-237)) $) 160) (((-565) $) 171)) (-2227 (($ $) 97)) (-1683 (((-877) $) 136) (($ (-592)) NIL) (($ |#2|) NIL) (($ (-433 (-592))) NIL) (($ $) NIL)) (-4198 (((-1187 |#2|) $) 23)) (-4010 (((-790)) 99)) (-1630 (($ $) 245)) (-1546 (($ $) 239)) (-1617 (($ $) 243)) (-1533 (($ $) 237)) (-4575 ((|#2| $) 230)) (-1624 (($ $) 244)) (-1540 (($ $) 238)) (-1392 (($ $) 155)) (-3255 (((-141) $ $) 103)) (-3266 (((-141) $ $) 191)) (-3306 (($ $) 105) (($ $ $) NIL)) (-3300 (($ $ $) 104)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-433 (-592))) 264) (($ $ $) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 111) (($ $ $) 140) (($ $ |#2|) NIL) (($ |#2| $) 107) (($ (-433 (-592)) $) NIL) (($ $ (-433 (-592))) NIL))) 
+(((-187 |#1| |#2|) (-10 -8 (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -1683 (|#1| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3620 ((-2 (|:| -4509 |#1|) (|:| -4612 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -2769 ((-790) |#1|)) (-15 -4570 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -1599 (|#1| |#1| |#1|)) (-15 -1586 (|#1| |#1| |#1|)) (-15 -4552 (|#1| |#1|)) (-15 ** (|#1| |#1| (-592))) (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -3266 ((-141) |#1| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -1778 ((-191 (-237)) |#1|)) (-15 -1778 ((-191 (-405)) |#1|)) (-15 -1507 (|#1| |#1|)) (-15 -1495 (|#1| |#1|)) (-15 -1501 (|#1| |#1|)) (-15 -1540 (|#1| |#1|)) (-15 -1533 (|#1| |#1|)) (-15 -1546 (|#1| |#1|)) (-15 -1581 (|#1| |#1|)) (-15 -1575 (|#1| |#1|)) (-15 -1588 (|#1| |#1|)) (-15 -1624 (|#1| |#1|)) (-15 -1617 (|#1| |#1|)) (-15 -1630 (|#1| |#1|)) (-15 -4546 (|#1| |#1|)) (-15 -1430 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 -1435 (|#1|)) (-15 ** (|#1| |#1| (-433 (-592)))) (-15 -3339 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -1416 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -3524 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|))) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -4120 ((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) |#1|)) (-15 -4575 (|#2| |#1|)) (-15 -1392 (|#1| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#2|)) (-15 -2227 (|#1| |#1|)) (-15 -2795 (|#1|)) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -3412 ((-911 (-405) |#1|) |#1| (-914 (-405)) (-911 (-405) |#1|))) (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|))) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3657 ((-3 |#1| "failed") (-433 (-1187 |#2|)))) (-15 -3650 ((-1187 |#2|) |#1|)) (-15 -1778 (|#1| (-1187 |#2|))) (-15 -3657 (|#1| (-1187 |#2|))) (-15 -3390 ((-1187 |#2|))) (-15 -3945 ((-706 |#2|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1778 ((-1187 |#2|) |#1|)) (-15 -1482 (|#2|)) (-15 -1778 (|#1| (-1280 |#2|))) (-15 -1778 ((-1280 |#2|) |#1|)) (-15 -2231 ((-706 |#2|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1|)) (-15 -3504 ((-1187 |#2|) |#1|)) (-15 -4198 ((-1187 |#2|) |#1|)) (-15 -1482 (|#2| (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -2793 (|#2| |#1|)) (-15 -4529 (|#2| |#1|)) (-15 -4175 ((-944))) (-15 -1683 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 ** (|#1| |#1| (-790))) (-15 -3371 ((-3 |#1| "failed") |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-944))) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|)) (-15 -3300 (|#1| |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) (-188 |#2|) (-194)) (T -187)) 
+((-4010 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-790)) (-5 *1 (-187 *3 *4)) (-4 *3 (-188 *4)))) (-4175 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-944)) (-5 *1 (-187 *3 *4)) (-4 *3 (-188 *4)))) (-1482 (*1 *2) (-12 (-4 *2 (-194)) (-5 *1 (-187 *3 *2)) (-4 *3 (-188 *2)))) (-3390 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-1187 *4)) (-5 *1 (-187 *3 *4)) (-4 *3 (-188 *4))))) 
+(-10 -8 (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -1683 (|#1| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3620 ((-2 (|:| -4509 |#1|) (|:| -4612 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -2769 ((-790) |#1|)) (-15 -4570 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -1599 (|#1| |#1| |#1|)) (-15 -1586 (|#1| |#1| |#1|)) (-15 -4552 (|#1| |#1|)) (-15 ** (|#1| |#1| (-592))) (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -3266 ((-141) |#1| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -1778 ((-191 (-237)) |#1|)) (-15 -1778 ((-191 (-405)) |#1|)) (-15 -1507 (|#1| |#1|)) (-15 -1495 (|#1| |#1|)) (-15 -1501 (|#1| |#1|)) (-15 -1540 (|#1| |#1|)) (-15 -1533 (|#1| |#1|)) (-15 -1546 (|#1| |#1|)) (-15 -1581 (|#1| |#1|)) (-15 -1575 (|#1| |#1|)) (-15 -1588 (|#1| |#1|)) (-15 -1624 (|#1| |#1|)) (-15 -1617 (|#1| |#1|)) (-15 -1630 (|#1| |#1|)) (-15 -4546 (|#1| |#1|)) (-15 -1430 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 -1435 (|#1|)) (-15 ** (|#1| |#1| (-433 (-592)))) (-15 -3339 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -1416 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -3524 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|))) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -4120 ((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) |#1|)) (-15 -4575 (|#2| |#1|)) (-15 -1392 (|#1| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#2|)) (-15 -2227 (|#1| |#1|)) (-15 -2795 (|#1|)) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -3412 ((-911 (-405) |#1|) |#1| (-914 (-405)) (-911 (-405) |#1|))) (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|))) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3657 ((-3 |#1| "failed") (-433 (-1187 |#2|)))) (-15 -3650 ((-1187 |#2|) |#1|)) (-15 -1778 (|#1| (-1187 |#2|))) (-15 -3657 (|#1| (-1187 |#2|))) (-15 -3390 ((-1187 |#2|))) (-15 -3945 ((-706 |#2|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1778 ((-1187 |#2|) |#1|)) (-15 -1482 (|#2|)) (-15 -1778 (|#1| (-1280 |#2|))) (-15 -1778 ((-1280 |#2|) |#1|)) (-15 -2231 ((-706 |#2|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1|)) (-15 -3504 ((-1187 |#2|) |#1|)) (-15 -4198 ((-1187 |#2|) |#1|)) (-15 -1482 (|#2| (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -2793 (|#2| |#1|)) (-15 -4529 (|#2| |#1|)) (-15 -4175 ((-944))) (-15 -1683 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 ** (|#1| |#1| (-790))) (-15 -3371 ((-3 |#1| "failed") |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-944))) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|)) (-15 -3300 (|#1| |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 88 (-3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-1555 (($ $) 89 (-3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-1313 (((-141) $) 91 (-3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-1800 (((-706 |#1|) (-1280 $)) 44) (((-706 |#1|)) 55)) (-4529 ((|#1| $) 50)) (-1588 (($ $) 213 (|has| |#1| (-1211)))) (-1507 (($ $) 196 (|has| |#1| (-1211)))) (-4217 (((-1199 (-944) (-790)) (-592)) 142 (|has| |#1| (-373)))) (-2350 (((-3 $ "failed") $ $) 18)) (-4043 (((-444 (-1187 $)) (-1187 $)) 227 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (-3743 (($ $) 108 (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388))))) (-3164 (((-444 $) $) 109 (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388))))) (-1442 (($ $) 226 (-12 (|has| |#1| (-1030)) (|has| |#1| (-1211))))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 230 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (-3652 (((-141) $ $) 99 (|has| |#1| (-323)))) (-1403 (((-790)) 81 (|has| |#1| (-394)))) (-1575 (($ $) 212 (|has| |#1| (-1211)))) (-1495 (($ $) 197 (|has| |#1| (-1211)))) (-1601 (($ $) 211 (|has| |#1| (-1211)))) (-1521 (($ $) 198 (|has| |#1| (-1211)))) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 164 (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 162 (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 161)) (-2400 (((-592) $) 165 (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) 163 (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 160)) (-1626 (($ (-1280 |#1|) (-1280 $)) 46) (($ (-1280 |#1|)) 58)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 148 (|has| |#1| (-373)))) (-1586 (($ $ $) 103 (|has| |#1| (-323)))) (-4493 (((-706 |#1|) $ (-1280 $)) 51) (((-706 |#1|) $) 53)) (-3945 (((-706 (-592)) (-706 $)) 159 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 158 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 157) (((-706 |#1|) (-706 $)) 156)) (-3657 (($ (-1187 |#1|)) 153) (((-3 $ "failed") (-433 (-1187 |#1|))) 150 (|has| |#1| (-388)))) (-3371 (((-3 $ "failed") $) 33)) (-3996 ((|#1| $) 238)) (-4182 (((-3 (-433 (-592)) "failed") $) 231 (|has| |#1| (-574)))) (-2435 (((-141) $) 233 (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) 232 (|has| |#1| (-574)))) (-4175 (((-944)) 52)) (-4290 (($) 84 (|has| |#1| (-394)))) (-1599 (($ $ $) 102 (|has| |#1| (-323)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 97 (|has| |#1| (-323)))) (-2667 (($) 144 (|has| |#1| (-373)))) (-3293 (((-141) $) 145 (|has| |#1| (-373)))) (-1525 (($ $ (-790)) 136 (|has| |#1| (-373))) (($ $) 135 (|has| |#1| (-373)))) (-2802 (((-141) $) 110 (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388))))) (-4120 (((-2 (|:| |r| |#1|) (|:| |phi| |#1|)) $) 234 (-12 (|has| |#1| (-1084)) (|has| |#1| (-1211))))) (-1435 (($) 223 (|has| |#1| (-1211)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 246 (|has| |#1| (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 245 (|has| |#1| (-908 (-405))))) (-4346 (((-944) $) 147 (|has| |#1| (-373))) (((-855 (-944)) $) 133 (|has| |#1| (-373)))) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 225 (-12 (|has| |#1| (-1030)) (|has| |#1| (-1211))))) (-2793 ((|#1| $) 49)) (-3921 (((-3 $ "failed") $) 137 (|has| |#1| (-373)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 106 (|has| |#1| (-323)))) (-3504 (((-1187 |#1|) $) 42 (|has| |#1| (-388)))) (-1837 (($ $ $) 192 (|has| |#1| (-869)))) (-3319 (($ $ $) 191 (|has| |#1| (-869)))) (-2731 (($ (-1 |#1| |#1|) $) 247)) (-3546 (((-944) $) 83 (|has| |#1| (-394)))) (-4546 (($ $) 220 (|has| |#1| (-1211)))) (-3650 (((-1187 |#1|) $) 151)) (-2750 (($ (-658 $)) 95 (-3836 (|has| |#1| (-323)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (($ $ $) 94 (-3836 (|has| |#1| (-323)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-2685 (((-1173) $) 9)) (-4552 (($ $) 111 (|has| |#1| (-388)))) (-3703 (($) 138 (|has| |#1| (-373)) CONST)) (-1825 (($ (-944)) 82 (|has| |#1| (-394)))) (-2795 (($) 242)) (-4506 ((|#1| $) 239)) (-2951 (((-1137) $) 10)) (-2934 (($) 155)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 96 (-3836 (|has| |#1| (-323)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-3548 (($ (-658 $)) 93 (-3836 (|has| |#1| (-323)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (($ $ $) 92 (-3836 (|has| |#1| (-323)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 141 (|has| |#1| (-373)))) (-1416 (((-444 (-1187 $)) (-1187 $)) 229 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (-3339 (((-444 (-1187 $)) (-1187 $)) 228 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (-4500 (((-444 $) $) 107 (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388))))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105 (|has| |#1| (-323))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 104 (|has| |#1| (-323)))) (-3616 (((-3 $ "failed") $ |#1|) 237 (|has| |#1| (-582))) (((-3 $ "failed") $ $) 87 (-3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 98 (|has| |#1| (-323)))) (-1430 (($ $) 221 (|has| |#1| (-1211)))) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) 253 (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) 252 (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) 251 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) 250 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) 249 (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) 248 (|has| |#1| (-547 (-1191) |#1|)))) (-2769 (((-790) $) 100 (|has| |#1| (-323)))) (-1405 (((-658 $)) 85 (|has| |#1| (-394)))) (-3927 (($ $ |#1|) 254 (|has| |#1| (-303 |#1| |#1|)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 101 (|has| |#1| (-323)))) (-1482 ((|#1| (-1280 $)) 45) ((|#1|) 54)) (-2177 (((-790) $) 146 (|has| |#1| (-373))) (((-3 (-790) "failed") $ $) 134 (|has| |#1| (-373)))) (-3644 (($ $ (-1 |#1| |#1|) (-790)) 118) (($ $ (-1 |#1| |#1|)) 117) (($ $ (-658 (-1191)) (-658 (-790))) 125 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 126 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 127 (|has| |#1| (-922 (-1191)))) (($ $ (-1191)) 128 (|has| |#1| (-922 (-1191)))) (($ $ (-790)) 130 (-3836 (-1732 (|has| |#1| (-388)) (|has| |#1| (-247))) (|has| |#1| (-247)) (-1732 (|has| |#1| (-247)) (|has| |#1| (-388))))) (($ $) 132 (-3836 (-1732 (|has| |#1| (-388)) (|has| |#1| (-247))) (|has| |#1| (-247)) (-1732 (|has| |#1| (-247)) (|has| |#1| (-388)))))) (-4174 (((-706 |#1|) (-1280 $) (-1 |#1| |#1|)) 149 (|has| |#1| (-388)))) (-3390 (((-1187 |#1|)) 154)) (-1609 (($ $) 210 (|has| |#1| (-1211)))) (-1527 (($ $) 199 (|has| |#1| (-1211)))) (-3809 (($) 143 (|has| |#1| (-373)))) (-1594 (($ $) 209 (|has| |#1| (-1211)))) (-1515 (($ $) 200 (|has| |#1| (-1211)))) (-1581 (($ $) 208 (|has| |#1| (-1211)))) (-1501 (($ $) 201 (|has| |#1| (-1211)))) (-2231 (((-1280 |#1|) $ (-1280 $)) 48) (((-706 |#1|) (-1280 $) (-1280 $)) 47) (((-1280 |#1|) $) 60) (((-706 |#1|) (-1280 $)) 59)) (-1778 (((-1280 |#1|) $) 57) (($ (-1280 |#1|)) 56) (((-1187 |#1|) $) 166) (($ (-1187 |#1|)) 152) (((-914 (-592)) $) 244 (|has| |#1| (-633 (-914 (-592))))) (((-914 (-405)) $) 243 (|has| |#1| (-633 (-914 (-405))))) (((-191 (-405)) $) 195 (|has| |#1| (-1049))) (((-191 (-237)) $) 194 (|has| |#1| (-1049))) (((-565) $) 193 (|has| |#1| (-633 (-565))))) (-2227 (($ $) 241)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 140 (-3836 (-1732 (|has| $ (-169)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))) (|has| |#1| (-373))))) (-4001 (($ |#1| |#1|) 240)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 36) (($ (-433 (-592))) 80 (-3836 (|has| |#1| (-388)) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) 86 (-3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-1517 (($ $) 139 (|has| |#1| (-373))) (((-3 $ "failed") $) 41 (-3836 (-1732 (|has| $ (-169)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))) (|has| |#1| (-169))))) (-4198 (((-1187 |#1|) $) 43)) (-4010 (((-790)) 28)) (-2195 (((-1280 $)) 61)) (-1630 (($ $) 219 (|has| |#1| (-1211)))) (-1546 (($ $) 207 (|has| |#1| (-1211)))) (-2537 (((-141) $ $) 90 (-3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931)))))) (-1617 (($ $) 218 (|has| |#1| (-1211)))) (-1533 (($ $) 206 (|has| |#1| (-1211)))) (-1642 (($ $) 217 (|has| |#1| (-1211)))) (-1559 (($ $) 205 (|has| |#1| (-1211)))) (-4575 ((|#1| $) 235 (|has| |#1| (-1211)))) (-2892 (($ $) 216 (|has| |#1| (-1211)))) (-1567 (($ $) 204 (|has| |#1| (-1211)))) (-1636 (($ $) 215 (|has| |#1| (-1211)))) (-1552 (($ $) 203 (|has| |#1| (-1211)))) (-1624 (($ $) 214 (|has| |#1| (-1211)))) (-1540 (($ $) 202 (|has| |#1| (-1211)))) (-1392 (($ $) 236 (|has| |#1| (-1084)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 112 (|has| |#1| (-388)))) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-1 |#1| |#1|) (-790)) 120) (($ $ (-1 |#1| |#1|)) 119) (($ $ (-658 (-1191)) (-658 (-790))) 121 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 122 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 123 (|has| |#1| (-922 (-1191)))) (($ $ (-1191)) 124 (|has| |#1| (-922 (-1191)))) (($ $ (-790)) 129 (-3836 (-1732 (|has| |#1| (-388)) (|has| |#1| (-247))) (|has| |#1| (-247)) (-1732 (|has| |#1| (-247)) (|has| |#1| (-388))))) (($ $) 131 (-3836 (-1732 (|has| |#1| (-388)) (|has| |#1| (-247))) (|has| |#1| (-247)) (-1732 (|has| |#1| (-247)) (|has| |#1| (-388)))))) (-3286 (((-141) $ $) 189 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 188 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 190 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 187 (|has| |#1| (-869)))) (-3313 (($ $ $) 116 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-433 (-592))) 224 (-12 (|has| |#1| (-1030)) (|has| |#1| (-1211)))) (($ $ $) 222 (|has| |#1| (-1211))) (($ $ (-592)) 113 (|has| |#1| (-388)))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ (-433 (-592)) $) 115 (|has| |#1| (-388))) (($ $ (-433 (-592))) 114 (|has| |#1| (-388))))) 
+(((-188 |#1|) (-1311) (-194)) (T -188)) 
+((-2793 (*1 *2 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) (-2795 (*1 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) (-2227 (*1 *1 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) (-4001 (*1 *1 *2 *2) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) (-4506 (*1 *2 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) (-3996 (*1 *2 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) (-3616 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-188 *2)) (-4 *2 (-194)) (-4 *2 (-582)))) (-1392 (*1 *1 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)) (-4 *2 (-1084)))) (-4575 (*1 *2 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)) (-4 *2 (-1211)))) (-4120 (*1 *2 *1) (-12 (-4 *1 (-188 *3)) (-4 *3 (-194)) (-4 *3 (-1084)) (-4 *3 (-1211)) (-5 *2 (-2 (|:| |r| *3) (|:| |phi| *3))))) (-2435 (*1 *2 *1) (-12 (-4 *1 (-188 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-141)))) (-2270 (*1 *2 *1) (-12 (-4 *1 (-188 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) (-4182 (*1 *2 *1) (|partial| -12 (-4 *1 (-188 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592)))))) 
+(-13 (-741 |t#1| (-1187 |t#1|)) (-437 |t#1|) (-245 |t#1|) (-358 |t#1|) (-426 |t#1|) (-906 |t#1|) (-403 |t#1|) (-194) (-10 -8 (-6 -4001) (-15 -2795 ($)) (-15 -2227 ($ $)) (-15 -4001 ($ |t#1| |t#1|)) (-15 -4506 (|t#1| $)) (-15 -3996 (|t#1| $)) (-15 -2793 (|t#1| $)) (IF (|has| |t#1| (-869)) (-6 (-869)) |noBranch|) (IF (|has| |t#1| (-582)) (PROGN (-6 (-582)) (-15 -3616 ((-3 $ "failed") $ |t#1|))) |noBranch|) (IF (|has| |t#1| (-323)) (-6 (-323)) |noBranch|) (IF (|has| |t#1| (-6 -4624)) (-6 -4624) |noBranch|) (IF (|has| |t#1| (-6 -4621)) (-6 -4621) |noBranch|) (IF (|has| |t#1| (-388)) (-6 (-388)) |noBranch|) (IF (|has| |t#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (IF (|has| |t#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |t#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |t#1| (-1049)) (PROGN (-6 (-633 (-191 (-237)))) (-6 (-633 (-191 (-405))))) |noBranch|) (IF (|has| |t#1| (-1084)) (-15 -1392 ($ $)) |noBranch|) (IF (|has| |t#1| (-1211)) (PROGN (-6 (-1211)) (-15 -4575 (|t#1| $)) (IF (|has| |t#1| (-1030)) (-6 (-1030)) |noBranch|) (IF (|has| |t#1| (-1084)) (-15 -4120 ((-2 (|:| |r| |t#1|) (|:| |phi| |t#1|)) $)) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|) (IF (|has| |t#1| (-931)) (IF (|has| |t#1| (-323)) (-6 (-931)) |noBranch|) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-43 |#1|) . T) ((-43 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-373)) (|has| |#1| (-388)) (|has| |#1| (-323))) ((-40) |has| |#1| (-1211)) ((-116) |has| |#1| (-1211)) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-140 |#1| |#1|) . T) ((-140 $ $) . T) ((-158) . T) ((-169) -3836 (|has| |#1| (-373)) (|has| |#1| (-169))) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) . T) ((-633 (-191 (-237))) |has| |#1| (-1049)) ((-633 (-191 (-405))) |has| |#1| (-1049)) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-633 (-914 (-405))) |has| |#1| (-633 (-914 (-405)))) ((-633 (-914 (-592))) |has| |#1| (-633 (-914 (-592)))) ((-633 (-1187 |#1|)) . T) ((-245 |#1|) . T) ((-247) -3836 (|has| |#1| (-373)) (|has| |#1| (-247))) ((-260) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-301) |has| |#1| (-1211)) ((-303 |#1| $) |has| |#1| (-303 |#1| |#1|)) ((-307) -3836 (|has| |#1| (-582)) (|has| |#1| (-373)) (|has| |#1| (-388)) (|has| |#1| (-323))) ((-323) -3836 (|has| |#1| (-373)) (|has| |#1| (-388)) (|has| |#1| (-323))) ((-325 |#1|) |has| |#1| (-325 |#1|)) ((-388) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-428) |has| |#1| (-373)) ((-394) -3836 (|has| |#1| (-394)) (|has| |#1| (-373))) ((-373) |has| |#1| (-373)) ((-396 |#1| (-1187 |#1|)) . T) ((-435 |#1| (-1187 |#1|)) . T) ((-358 |#1|) . T) ((-403 |#1|) . T) ((-426 |#1|) . T) ((-437 |#1|) . T) ((-477) -3836 (|has| |#1| (-373)) (|has| |#1| (-388)) (|has| |#1| (-323))) ((-526) |has| |#1| (-1211)) ((-547 (-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((-547 |#1| |#1|) |has| |#1| (-325 |#1|)) ((-582) -3836 (|has| |#1| (-582)) (|has| |#1| (-373)) (|has| |#1| (-388)) (|has| |#1| (-323))) ((-661 (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) -3836 (|has| |#1| (-373)) (|has| |#1| (-388)) (|has| |#1| (-323))) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-734 (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-734 |#1|) . T) ((-734 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-373)) (|has| |#1| (-388)) (|has| |#1| (-323))) ((-741 |#1| (-1187 |#1|)) . T) ((-743) . T) ((-869) |has| |#1| (-869)) ((-922 (-1191)) |has| |#1| (-922 (-1191))) ((-908 (-405)) |has| |#1| (-908 (-405))) ((-908 (-592)) |has| |#1| (-908 (-592))) ((-906 |#1|) . T) ((-931) -12 (|has| |#1| (-323)) (|has| |#1| (-931))) ((-943) -3836 (|has| |#1| (-373)) (|has| |#1| (-388)) (|has| |#1| (-323))) ((-1030) -12 (|has| |#1| (-1030)) (|has| |#1| (-1211))) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-1081 |#1|) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) |has| |#1| (-373)) ((-1211) |has| |#1| (-1211)) ((-1214) |has| |#1| (-1211)) ((-1225) . T) ((-1235) -3836 (|has| |#1| (-373)) (|has| |#1| (-388)) (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) 
+((-4500 (((-444 |#2|) |#2|) 63))) 
+(((-189 |#1| |#2|) (-10 -7 (-15 -4500 ((-444 |#2|) |#2|))) (-323) (-1255 (-191 |#1|))) (T -189)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-189 *4 *3)) (-4 *3 (-1255 (-191 *4)))))) 
+(-10 -7 (-15 -4500 ((-444 |#2|) |#2|))) 
+((-2731 (((-191 |#2|) (-1 |#2| |#1|) (-191 |#1|)) 14))) 
+(((-190 |#1| |#2|) (-10 -7 (-15 -2731 ((-191 |#2|) (-1 |#2| |#1|) (-191 |#1|)))) (-194) (-194)) (T -190)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-191 *5)) (-4 *5 (-194)) (-4 *6 (-194)) (-5 *2 (-191 *6)) (-5 *1 (-190 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-191 |#2|) (-1 |#2| |#1|) (-191 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 33)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-582))))) (-1555 (($ $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-582))))) (-1313 (((-141) $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-582))))) (-1800 (((-706 |#1|) (-1280 $)) NIL) (((-706 |#1|)) NIL)) (-4529 ((|#1| $) NIL)) (-1588 (($ $) NIL (|has| |#1| (-1211)))) (-1507 (($ $) NIL (|has| |#1| (-1211)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| |#1| (-373)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (-3743 (($ $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388))))) (-3164 (((-444 $) $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388))))) (-1442 (($ $) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1211))))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-323)))) (-1403 (((-790)) NIL (|has| |#1| (-394)))) (-1575 (($ $) NIL (|has| |#1| (-1211)))) (-1495 (($ $) NIL (|has| |#1| (-1211)))) (-1601 (($ $) NIL (|has| |#1| (-1211)))) (-1521 (($ $) NIL (|has| |#1| (-1211)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-1626 (($ (-1280 |#1|) (-1280 $)) NIL) (($ (-1280 |#1|)) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-373)))) (-1586 (($ $ $) NIL (|has| |#1| (-323)))) (-4493 (((-706 |#1|) $ (-1280 $)) NIL) (((-706 |#1|) $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3657 (($ (-1187 |#1|)) NIL) (((-3 $ "failed") (-433 (-1187 |#1|))) NIL (|has| |#1| (-388)))) (-3371 (((-3 $ "failed") $) NIL)) (-3996 ((|#1| $) 13)) (-4182 (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-574)))) (-2435 (((-141) $) NIL (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) NIL (|has| |#1| (-574)))) (-4175 (((-944)) NIL)) (-4290 (($) NIL (|has| |#1| (-394)))) (-1599 (($ $ $) NIL (|has| |#1| (-323)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-323)))) (-2667 (($) NIL (|has| |#1| (-373)))) (-3293 (((-141) $) NIL (|has| |#1| (-373)))) (-1525 (($ $ (-790)) NIL (|has| |#1| (-373))) (($ $) NIL (|has| |#1| (-373)))) (-2802 (((-141) $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388))))) (-4120 (((-2 (|:| |r| |#1|) (|:| |phi| |#1|)) $) NIL (-12 (|has| |#1| (-1084)) (|has| |#1| (-1211))))) (-1435 (($) NIL (|has| |#1| (-1211)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| |#1| (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| |#1| (-908 (-405))))) (-4346 (((-944) $) NIL (|has| |#1| (-373))) (((-855 (-944)) $) NIL (|has| |#1| (-373)))) (-3558 (((-141) $) 35)) (-4422 (($ $ (-592)) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1211))))) (-2793 ((|#1| $) 46)) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-373)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-323)))) (-3504 (((-1187 |#1|) $) NIL (|has| |#1| (-388)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3546 (((-944) $) NIL (|has| |#1| (-394)))) (-4546 (($ $) NIL (|has| |#1| (-1211)))) (-3650 (((-1187 |#1|) $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-323))) (($ $ $) NIL (|has| |#1| (-323)))) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-3703 (($) NIL (|has| |#1| (-373)) CONST)) (-1825 (($ (-944)) NIL (|has| |#1| (-394)))) (-2795 (($) NIL)) (-4506 ((|#1| $) 15)) (-2951 (((-1137) $) NIL)) (-2934 (($) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-323)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-323))) (($ $ $) NIL (|has| |#1| (-323)))) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| |#1| (-373)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| |#1| (-323)) (|has| |#1| (-931))))) (-4500 (((-444 $) $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-388))))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-323))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-323)))) (-3616 (((-3 $ "failed") $ |#1|) 44 (|has| |#1| (-582))) (((-3 $ "failed") $ $) 47 (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-582))))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-323)))) (-1430 (($ $) NIL (|has| |#1| (-1211)))) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) NIL (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) NIL (|has| |#1| (-547 (-1191) |#1|)))) (-2769 (((-790) $) NIL (|has| |#1| (-323)))) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-3927 (($ $ |#1|) NIL (|has| |#1| (-303 |#1| |#1|)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-323)))) (-1482 ((|#1| (-1280 $)) NIL) ((|#1|) NIL)) (-2177 (((-790) $) NIL (|has| |#1| (-373))) (((-3 (-790) "failed") $ $) NIL (|has| |#1| (-373)))) (-3644 (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $) NIL (|has| |#1| (-247)))) (-4174 (((-706 |#1|) (-1280 $) (-1 |#1| |#1|)) NIL (|has| |#1| (-388)))) (-3390 (((-1187 |#1|)) NIL)) (-1609 (($ $) NIL (|has| |#1| (-1211)))) (-1527 (($ $) NIL (|has| |#1| (-1211)))) (-3809 (($) NIL (|has| |#1| (-373)))) (-1594 (($ $) NIL (|has| |#1| (-1211)))) (-1515 (($ $) NIL (|has| |#1| (-1211)))) (-1581 (($ $) NIL (|has| |#1| (-1211)))) (-1501 (($ $) NIL (|has| |#1| (-1211)))) (-2231 (((-1280 |#1|) $ (-1280 $)) NIL) (((-706 |#1|) (-1280 $) (-1280 $)) NIL) (((-1280 |#1|) $) NIL) (((-706 |#1|) (-1280 $)) NIL)) (-1778 (((-1280 |#1|) $) NIL) (($ (-1280 |#1|)) NIL) (((-1187 |#1|) $) NIL) (($ (-1187 |#1|)) NIL) (((-914 (-592)) $) NIL (|has| |#1| (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| |#1| (-633 (-914 (-405))))) (((-191 (-405)) $) NIL (|has| |#1| (-1049))) (((-191 (-237)) $) NIL (|has| |#1| (-1049))) (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-2227 (($ $) 45)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-373))))) (-4001 (($ |#1| |#1|) 37)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) 36) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-388)) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-582))))) (-1517 (($ $) NIL (|has| |#1| (-373))) (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4198 (((-1187 |#1|) $) NIL)) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL)) (-1630 (($ $) NIL (|has| |#1| (-1211)))) (-1546 (($ $) NIL (|has| |#1| (-1211)))) (-2537 (((-141) $ $) NIL (-3836 (-12 (|has| |#1| (-323)) (|has| |#1| (-931))) (|has| |#1| (-582))))) (-1617 (($ $) NIL (|has| |#1| (-1211)))) (-1533 (($ $) NIL (|has| |#1| (-1211)))) (-1642 (($ $) NIL (|has| |#1| (-1211)))) (-1559 (($ $) NIL (|has| |#1| (-1211)))) (-4575 ((|#1| $) NIL (|has| |#1| (-1211)))) (-2892 (($ $) NIL (|has| |#1| (-1211)))) (-1567 (($ $) NIL (|has| |#1| (-1211)))) (-1636 (($ $) NIL (|has| |#1| (-1211)))) (-1552 (($ $) NIL (|has| |#1| (-1211)))) (-1624 (($ $) NIL (|has| |#1| (-1211)))) (-1540 (($ $) NIL (|has| |#1| (-1211)))) (-1392 (($ $) NIL (|has| |#1| (-1084)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 28 T CONST)) (-4257 (($) 30 T CONST)) (-1637 (((-1173) $) 23 (|has| |#1| (-850))) (((-1173) $ (-141)) 25 (|has| |#1| (-850))) (((-1285) (-844) $) 26 (|has| |#1| (-850))) (((-1285) (-844) $ (-141)) 27 (|has| |#1| (-850)))) (-1940 (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $) NIL (|has| |#1| (-247)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ $) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 39)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-433 (-592))) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1211)))) (($ $ $) NIL (|has| |#1| (-1211))) (($ $ (-592)) NIL (|has| |#1| (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 42) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-433 (-592)) $) NIL (|has| |#1| (-388))) (($ $ (-433 (-592))) NIL (|has| |#1| (-388))))) 
+(((-191 |#1|) (-13 (-188 |#1|) (-10 -7 (IF (|has| |#1| (-850)) (-6 (-850)) |noBranch|))) (-194)) (T -191)) 
+NIL 
+(-13 (-188 |#1|) (-10 -7 (IF (|has| |#1| (-850)) (-6 (-850)) |noBranch|))) 
+((-1778 (((-914 |#1|) |#3|) 22))) 
+(((-192 |#1| |#2| |#3|) (-10 -7 (-15 -1778 ((-914 |#1|) |#3|))) (-1119) (-13 (-633 (-914 |#1|)) (-194)) (-188 |#2|)) (T -192)) 
+((-1778 (*1 *2 *3) (-12 (-4 *5 (-13 (-633 *2) (-194))) (-5 *2 (-914 *4)) (-5 *1 (-192 *4 *5 *3)) (-4 *4 (-1119)) (-4 *3 (-188 *5))))) 
+(-10 -7 (-15 -1778 ((-914 |#1|) |#3|))) 
+((-1641 (((-141) $ $) NIL)) (-3914 (((-141) $) 9)) (-3758 (((-141) $ (-141)) 11)) (-3242 (($) 12)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4599 (($ $) 13)) (-1683 (((-877) $) 17)) (-2308 (((-141) $) 8)) (-3511 (((-141) $ (-141)) 10)) (-3255 (((-141) $ $) NIL))) 
+(((-193) (-13 (-1119) (-10 -8 (-15 -3242 ($)) (-15 -2308 ((-141) $)) (-15 -3914 ((-141) $)) (-15 -3511 ((-141) $ (-141))) (-15 -3758 ((-141) $ (-141))) (-15 -4599 ($ $))))) (T -193)) 
+((-3242 (*1 *1) (-5 *1 (-193))) (-2308 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-193)))) (-3914 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-193)))) (-3511 (*1 *2 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-193)))) (-3758 (*1 *2 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-193)))) (-4599 (*1 *1 *1) (-5 *1 (-193)))) 
+(-13 (-1119) (-10 -8 (-15 -3242 ($)) (-15 -2308 ((-141) $)) (-15 -3914 ((-141) $)) (-15 -3511 ((-141) $ (-141))) (-15 -3758 ((-141) $ (-141))) (-15 -4599 ($ $)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-194) (-1311)) (T -194)) 
+NIL 
+(-13 (-1075) (-140 $ $) (-10 -7 (-6 (-4627 "*")))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 ((|#1| $) 74)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-1586 (($ $ $) NIL)) (-2140 (($ $) 19)) (-4201 (($ |#1| (-1171 |#1|)) 47)) (-3371 (((-3 $ "failed") $) 116)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-2168 (((-1171 |#1|) $) 81)) (-3944 (((-1171 |#1|) $) 78)) (-2993 (((-1171 |#1|) $) 79)) (-3558 (((-141) $) NIL)) (-4045 (((-1171 |#1|) $) 87)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2750 (($ (-658 $)) NIL) (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ (-658 $)) NIL) (($ $ $) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL)) (-2807 (($ $ (-592)) 90)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3892 (((-1171 |#1|) $) 88)) (-2706 (((-1171 (-433 |#1|)) $) 13)) (-2867 (($ (-433 |#1|)) 17) (($ |#1| (-1171 |#1|) (-1171 |#1|)) 37)) (-1700 (($ $) 92)) (-1683 (((-877) $) 126) (($ (-592)) 50) (($ |#1|) 51) (($ (-433 |#1|)) 35) (($ (-433 (-592))) NIL) (($ $) NIL)) (-4010 (((-790)) 63)) (-2537 (((-141) $ $) NIL)) (-2850 (((-1171 (-433 |#1|)) $) 18)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 25 T CONST)) (-4257 (($) 28 T CONST)) (-3255 (((-141) $ $) 34)) (-3313 (($ $ $) 114)) (-3306 (($ $) 105) (($ $ $) 102)) (-3300 (($ $ $) 100)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 112) (($ $ $) 107) (($ $ |#1|) NIL) (($ |#1| $) 109) (($ (-433 |#1|) $) 110) (($ $ (-433 |#1|)) NIL) (($ (-433 (-592)) $) NIL) (($ $ (-433 (-592))) NIL))) 
+(((-195 |#1|) (-13 (-43 |#1|) (-43 (-433 |#1|)) (-388) (-10 -8 (-15 -2867 ($ (-433 |#1|))) (-15 -2867 ($ |#1| (-1171 |#1|) (-1171 |#1|))) (-15 -4201 ($ |#1| (-1171 |#1|))) (-15 -3944 ((-1171 |#1|) $)) (-15 -2993 ((-1171 |#1|) $)) (-15 -2168 ((-1171 |#1|) $)) (-15 -1505 (|#1| $)) (-15 -2140 ($ $)) (-15 -2850 ((-1171 (-433 |#1|)) $)) (-15 -2706 ((-1171 (-433 |#1|)) $)) (-15 -4045 ((-1171 |#1|) $)) (-15 -3892 ((-1171 |#1|) $)) (-15 -2807 ($ $ (-592))) (-15 -1700 ($ $)))) (-323)) (T -195)) 
+((-2867 (*1 *1 *2) (-12 (-5 *2 (-433 *3)) (-4 *3 (-323)) (-5 *1 (-195 *3)))) (-2867 (*1 *1 *2 *3 *3) (-12 (-5 *3 (-1171 *2)) (-4 *2 (-323)) (-5 *1 (-195 *2)))) (-4201 (*1 *1 *2 *3) (-12 (-5 *3 (-1171 *2)) (-4 *2 (-323)) (-5 *1 (-195 *2)))) (-3944 (*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323)))) (-2993 (*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323)))) (-2168 (*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323)))) (-1505 (*1 *2 *1) (-12 (-5 *1 (-195 *2)) (-4 *2 (-323)))) (-2140 (*1 *1 *1) (-12 (-5 *1 (-195 *2)) (-4 *2 (-323)))) (-2850 (*1 *2 *1) (-12 (-5 *2 (-1171 (-433 *3))) (-5 *1 (-195 *3)) (-4 *3 (-323)))) (-2706 (*1 *2 *1) (-12 (-5 *2 (-1171 (-433 *3))) (-5 *1 (-195 *3)) (-4 *3 (-323)))) (-4045 (*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323)))) (-3892 (*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323)))) (-2807 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-195 *3)) (-4 *3 (-323)))) (-1700 (*1 *1 *1) (-12 (-5 *1 (-195 *2)) (-4 *2 (-323))))) 
+(-13 (-43 |#1|) (-43 (-433 |#1|)) (-388) (-10 -8 (-15 -2867 ($ (-433 |#1|))) (-15 -2867 ($ |#1| (-1171 |#1|) (-1171 |#1|))) (-15 -4201 ($ |#1| (-1171 |#1|))) (-15 -3944 ((-1171 |#1|) $)) (-15 -2993 ((-1171 |#1|) $)) (-15 -2168 ((-1171 |#1|) $)) (-15 -1505 (|#1| $)) (-15 -2140 ($ $)) (-15 -2850 ((-1171 (-433 |#1|)) $)) (-15 -2706 ((-1171 (-433 |#1|)) $)) (-15 -4045 ((-1171 |#1|) $)) (-15 -3892 ((-1171 |#1|) $)) (-15 -2807 ($ $ (-592))) (-15 -1700 ($ $)))) 
+((-2822 (((-1 (-971 |#1|) (-971 |#1|)) |#1|) 40)) (-4222 (((-971 |#1|) (-971 |#1|)) 19)) (-3455 (((-1 (-971 |#1|) (-971 |#1|)) |#1|) 36)) (-3939 (((-971 |#1|) (-971 |#1|)) 17)) (-2494 (((-971 |#1|) (-971 |#1|)) 25)) (-4189 (((-971 |#1|) (-971 |#1|)) 24)) (-3534 (((-971 |#1|) (-971 |#1|)) 23)) (-3730 (((-1 (-971 |#1|) (-971 |#1|)) |#1|) 37)) (-3020 (((-1 (-971 |#1|) (-971 |#1|)) |#1|) 35)) (-3143 (((-1 (-971 |#1|) (-971 |#1|)) |#1|) 34)) (-1537 (((-971 |#1|) (-971 |#1|)) 18)) (-2563 (((-1 (-971 |#1|) (-971 |#1|)) |#1| |#1|) 43)) (-3458 (((-971 |#1|) (-971 |#1|)) 8)) (-3334 (((-1 (-971 |#1|) (-971 |#1|)) |#1|) 39)) (-2228 (((-1 (-971 |#1|) (-971 |#1|)) |#1|) 38))) 
+(((-196 |#1|) (-10 -7 (-15 -3458 ((-971 |#1|) (-971 |#1|))) (-15 -3939 ((-971 |#1|) (-971 |#1|))) (-15 -1537 ((-971 |#1|) (-971 |#1|))) (-15 -4222 ((-971 |#1|) (-971 |#1|))) (-15 -3534 ((-971 |#1|) (-971 |#1|))) (-15 -4189 ((-971 |#1|) (-971 |#1|))) (-15 -2494 ((-971 |#1|) (-971 |#1|))) (-15 -3143 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -3020 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -3455 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -3730 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -2228 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -3334 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -2822 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -2563 ((-1 (-971 |#1|) (-971 |#1|)) |#1| |#1|))) (-13 (-388) (-1211) (-1030))) (T -196)) 
+((-2563 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) (-2822 (*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) (-3334 (*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) (-2228 (*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) (-3730 (*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) (-3455 (*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) (-3020 (*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) (-3143 (*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) (-2494 (*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3)))) (-4189 (*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3)))) (-3534 (*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3)))) (-4222 (*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3)))) (-1537 (*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3)))) (-3939 (*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3)))) (-3458 (*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3))))) 
+(-10 -7 (-15 -3458 ((-971 |#1|) (-971 |#1|))) (-15 -3939 ((-971 |#1|) (-971 |#1|))) (-15 -1537 ((-971 |#1|) (-971 |#1|))) (-15 -4222 ((-971 |#1|) (-971 |#1|))) (-15 -3534 ((-971 |#1|) (-971 |#1|))) (-15 -4189 ((-971 |#1|) (-971 |#1|))) (-15 -2494 ((-971 |#1|) (-971 |#1|))) (-15 -3143 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -3020 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -3455 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -3730 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -2228 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -3334 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -2822 ((-1 (-971 |#1|) (-971 |#1|)) |#1|)) (-15 -2563 ((-1 (-971 |#1|) (-971 |#1|)) |#1| |#1|))) 
+((-4198 ((|#2| |#3|) 27))) 
+(((-197 |#1| |#2| |#3|) (-10 -7 (-15 -4198 (|#2| |#3|))) (-194) (-1255 |#1|) (-741 |#1| |#2|)) (T -197)) 
+((-4198 (*1 *2 *3) (-12 (-4 *4 (-194)) (-4 *2 (-1255 *4)) (-5 *1 (-197 *4 *2 *3)) (-4 *3 (-741 *4 *2))))) 
+(-10 -7 (-15 -4198 (|#2| |#3|))) 
+((-3412 (((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)) 47 (|has| (-980 |#2|) (-908 |#1|))))) 
+(((-198 |#1| |#2| |#3|) (-10 -7 (IF (|has| (-980 |#2|) (-908 |#1|)) (-15 -3412 ((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|))) |noBranch|)) (-1119) (-13 (-908 |#1|) (-194)) (-188 |#2|)) (T -198)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *3)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *3 (-188 *6)) (-4 (-980 *6) (-908 *5)) (-4 *6 (-13 (-908 *5) (-194))) (-5 *1 (-198 *5 *6 *3))))) 
+(-10 -7 (IF (|has| (-980 |#2|) (-908 |#1|)) (-15 -3412 ((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|))) |noBranch|)) 
+((-3206 (((-658 |#1|) (-658 |#1|) |#1|) 36)) (-4107 (((-658 |#1|) |#1| (-658 |#1|)) 19)) (-3219 (((-658 |#1|) (-658 (-658 |#1|)) (-658 |#1|)) 31) ((|#1| (-658 |#1|) (-658 |#1|)) 29))) 
+(((-199 |#1|) (-10 -7 (-15 -4107 ((-658 |#1|) |#1| (-658 |#1|))) (-15 -3219 (|#1| (-658 |#1|) (-658 |#1|))) (-15 -3219 ((-658 |#1|) (-658 (-658 |#1|)) (-658 |#1|))) (-15 -3206 ((-658 |#1|) (-658 |#1|) |#1|))) (-323)) (T -199)) 
+((-3206 (*1 *2 *2 *3) (-12 (-5 *2 (-658 *3)) (-4 *3 (-323)) (-5 *1 (-199 *3)))) (-3219 (*1 *2 *3 *2) (-12 (-5 *3 (-658 (-658 *4))) (-5 *2 (-658 *4)) (-4 *4 (-323)) (-5 *1 (-199 *4)))) (-3219 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *2)) (-5 *1 (-199 *2)) (-4 *2 (-323)))) (-4107 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-323)) (-5 *1 (-199 *3))))) 
+(-10 -7 (-15 -4107 ((-658 |#1|) |#1| (-658 |#1|))) (-15 -3219 (|#1| (-658 |#1|) (-658 |#1|))) (-15 -3219 ((-658 |#1|) (-658 (-658 |#1|)) (-658 |#1|))) (-15 -3206 ((-658 |#1|) (-658 |#1|) |#1|))) 
+((-3024 (((-2 (|:| |start| |#2|) (|:| -2033 (-444 |#2|))) |#2|) 61)) (-3543 ((|#1| |#1|) 54)) (-1971 (((-191 |#1|) |#2|) 82)) (-2305 ((|#1| |#2|) 122) ((|#1| |#2| |#1|) 80)) (-2975 ((|#2| |#2|) 81)) (-4238 (((-444 |#2|) |#2| |#1|) 112) (((-444 |#2|) |#2| |#1| (-141)) 79)) (-2793 ((|#1| |#2|) 111)) (-2817 ((|#2| |#2|) 118)) (-4500 (((-444 |#2|) |#2|) 133) (((-444 |#2|) |#2| |#1|) 32) (((-444 |#2|) |#2| |#1| (-141)) 132)) (-1414 (((-658 (-2 (|:| -2033 (-658 |#2|)) (|:| -1615 |#1|))) |#2| |#2|) 131) (((-658 (-2 (|:| -2033 (-658 |#2|)) (|:| -1615 |#1|))) |#2| |#2| (-141)) 75)) (-3688 (((-658 (-191 |#1|)) |#2| |#1|) 40) (((-658 (-191 |#1|)) |#2|) 41))) 
+(((-200 |#1| |#2|) (-10 -7 (-15 -3688 ((-658 (-191 |#1|)) |#2|)) (-15 -3688 ((-658 (-191 |#1|)) |#2| |#1|)) (-15 -1414 ((-658 (-2 (|:| -2033 (-658 |#2|)) (|:| -1615 |#1|))) |#2| |#2| (-141))) (-15 -1414 ((-658 (-2 (|:| -2033 (-658 |#2|)) (|:| -1615 |#1|))) |#2| |#2|)) (-15 -4500 ((-444 |#2|) |#2| |#1| (-141))) (-15 -4500 ((-444 |#2|) |#2| |#1|)) (-15 -4500 ((-444 |#2|) |#2|)) (-15 -2817 (|#2| |#2|)) (-15 -2793 (|#1| |#2|)) (-15 -4238 ((-444 |#2|) |#2| |#1| (-141))) (-15 -4238 ((-444 |#2|) |#2| |#1|)) (-15 -2975 (|#2| |#2|)) (-15 -2305 (|#1| |#2| |#1|)) (-15 -2305 (|#1| |#2|)) (-15 -1971 ((-191 |#1|) |#2|)) (-15 -3543 (|#1| |#1|)) (-15 -3024 ((-2 (|:| |start| |#2|) (|:| -2033 (-444 |#2|))) |#2|))) (-13 (-388) (-867)) (-1255 (-191 |#1|))) (T -200)) 
+((-3024 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-2 (|:| |start| *3) (|:| -2033 (-444 *3)))) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) (-3543 (*1 *2 *2) (-12 (-4 *2 (-13 (-388) (-867))) (-5 *1 (-200 *2 *3)) (-4 *3 (-1255 (-191 *2))))) (-1971 (*1 *2 *3) (-12 (-5 *2 (-191 *4)) (-5 *1 (-200 *4 *3)) (-4 *4 (-13 (-388) (-867))) (-4 *3 (-1255 *2)))) (-2305 (*1 *2 *3) (-12 (-4 *2 (-13 (-388) (-867))) (-5 *1 (-200 *2 *3)) (-4 *3 (-1255 (-191 *2))))) (-2305 (*1 *2 *3 *2) (-12 (-4 *2 (-13 (-388) (-867))) (-5 *1 (-200 *2 *3)) (-4 *3 (-1255 (-191 *2))))) (-2975 (*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-867))) (-5 *1 (-200 *3 *2)) (-4 *2 (-1255 (-191 *3))))) (-4238 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) (-4238 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-141)) (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) (-2793 (*1 *2 *3) (-12 (-4 *2 (-13 (-388) (-867))) (-5 *1 (-200 *2 *3)) (-4 *3 (-1255 (-191 *2))))) (-2817 (*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-867))) (-5 *1 (-200 *3 *2)) (-4 *2 (-1255 (-191 *3))))) (-4500 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) (-4500 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) (-4500 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-141)) (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) (-1414 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-658 (-2 (|:| -2033 (-658 *3)) (|:| -1615 *4)))) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) (-1414 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-388) (-867))) (-5 *2 (-658 (-2 (|:| -2033 (-658 *3)) (|:| -1615 *5)))) (-5 *1 (-200 *5 *3)) (-4 *3 (-1255 (-191 *5))))) (-3688 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-658 (-191 *4))) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) (-3688 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-658 (-191 *4))) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4)))))) 
+(-10 -7 (-15 -3688 ((-658 (-191 |#1|)) |#2|)) (-15 -3688 ((-658 (-191 |#1|)) |#2| |#1|)) (-15 -1414 ((-658 (-2 (|:| -2033 (-658 |#2|)) (|:| -1615 |#1|))) |#2| |#2| (-141))) (-15 -1414 ((-658 (-2 (|:| -2033 (-658 |#2|)) (|:| -1615 |#1|))) |#2| |#2|)) (-15 -4500 ((-444 |#2|) |#2| |#1| (-141))) (-15 -4500 ((-444 |#2|) |#2| |#1|)) (-15 -4500 ((-444 |#2|) |#2|)) (-15 -2817 (|#2| |#2|)) (-15 -2793 (|#1| |#2|)) (-15 -4238 ((-444 |#2|) |#2| |#1| (-141))) (-15 -4238 ((-444 |#2|) |#2| |#1|)) (-15 -2975 (|#2| |#2|)) (-15 -2305 (|#1| |#2| |#1|)) (-15 -2305 (|#1| |#2|)) (-15 -1971 ((-191 |#1|) |#2|)) (-15 -3543 (|#1| |#1|)) (-15 -3024 ((-2 (|:| |start| |#2|) (|:| -2033 (-444 |#2|))) |#2|))) 
+((-4073 (((-3 |#2| "failed") |#2|) 14)) (-2429 (((-790) |#2|) 16)) (-4115 ((|#2| |#2| |#2|) 18))) 
+(((-201 |#1| |#2|) (-10 -7 (-15 -4073 ((-3 |#2| "failed") |#2|)) (-15 -2429 ((-790) |#2|)) (-15 -4115 (|#2| |#2| |#2|))) (-1225) (-690 |#1|)) (T -201)) 
+((-4115 (*1 *2 *2 *2) (-12 (-4 *3 (-1225)) (-5 *1 (-201 *3 *2)) (-4 *2 (-690 *3)))) (-2429 (*1 *2 *3) (-12 (-4 *4 (-1225)) (-5 *2 (-790)) (-5 *1 (-201 *4 *3)) (-4 *3 (-690 *4)))) (-4073 (*1 *2 *2) (|partial| -12 (-4 *3 (-1225)) (-5 *1 (-201 *3 *2)) (-4 *2 (-690 *3))))) 
+(-10 -7 (-15 -4073 ((-3 |#2| "failed") |#2|)) (-15 -2429 ((-790) |#2|)) (-15 -4115 (|#2| |#2| |#2|))) 
+((-1519 ((|#2| |#2|) 28)) (-2952 (((-141) |#2|) 19)) (-3996 (((-332 |#1|) |#2|) 12)) (-4506 (((-332 |#1|) |#2|) 14)) (-1689 ((|#2| |#2| (-1191)) 68) ((|#2| |#2|) 69)) (-2438 (((-191 (-332 |#1|)) |#2|) 9)) (-2771 ((|#2| |#2| (-1191)) 65) ((|#2| |#2|) 58))) 
+(((-202 |#1| |#2|) (-10 -7 (-15 -1689 (|#2| |#2|)) (-15 -1689 (|#2| |#2| (-1191))) (-15 -2771 (|#2| |#2|)) (-15 -2771 (|#2| |#2| (-1191))) (-15 -3996 ((-332 |#1|) |#2|)) (-15 -4506 ((-332 |#1|) |#2|)) (-15 -2952 ((-141) |#2|)) (-15 -1519 (|#2| |#2|)) (-15 -2438 ((-191 (-332 |#1|)) |#2|))) (-13 (-582) (-869) (-1065 (-592))) (-13 (-27) (-1211) (-456 (-191 |#1|)))) (T -202)) 
+((-2438 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-191 (-332 *4))) (-5 *1 (-202 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 (-191 *4)))))) (-1519 (*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *3)))))) (-2952 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-141)) (-5 *1 (-202 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 (-191 *4)))))) (-4506 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-332 *4)) (-5 *1 (-202 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 (-191 *4)))))) (-3996 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-332 *4)) (-5 *1 (-202 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 (-191 *4)))))) (-2771 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *4)))))) (-2771 (*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *3)))))) (-1689 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *4)))))) (-1689 (*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *3))))))) 
+(-10 -7 (-15 -1689 (|#2| |#2|)) (-15 -1689 (|#2| |#2| (-1191))) (-15 -2771 (|#2| |#2|)) (-15 -2771 (|#2| |#2| (-1191))) (-15 -3996 ((-332 |#1|) |#2|)) (-15 -4506 ((-332 |#1|) |#2|)) (-15 -2952 ((-141) |#2|)) (-15 -1519 (|#2| |#2|)) (-15 -2438 ((-191 (-332 |#1|)) |#2|))) 
+((-4266 (((-1280 (-706 (-980 |#1|))) (-1280 (-706 |#1|))) 22)) (-1683 (((-1280 (-706 (-433 (-980 |#1|)))) (-1280 (-706 |#1|))) 30))) 
+(((-203 |#1|) (-10 -7 (-15 -4266 ((-1280 (-706 (-980 |#1|))) (-1280 (-706 |#1|)))) (-15 -1683 ((-1280 (-706 (-433 (-980 |#1|)))) (-1280 (-706 |#1|))))) (-194)) (T -203)) 
+((-1683 (*1 *2 *3) (-12 (-5 *3 (-1280 (-706 *4))) (-4 *4 (-194)) (-5 *2 (-1280 (-706 (-433 (-980 *4))))) (-5 *1 (-203 *4)))) (-4266 (*1 *2 *3) (-12 (-5 *3 (-1280 (-706 *4))) (-4 *4 (-194)) (-5 *2 (-1280 (-706 (-980 *4)))) (-5 *1 (-203 *4))))) 
+(-10 -7 (-15 -4266 ((-1280 (-706 (-980 |#1|))) (-1280 (-706 |#1|)))) (-15 -1683 ((-1280 (-706 (-433 (-980 |#1|)))) (-1280 (-706 |#1|))))) 
+((-3225 (((-1193 (-433 (-592))) (-1193 (-433 (-592))) (-1193 (-433 (-592)))) 66)) (-2803 (((-1193 (-433 (-592))) (-658 (-592)) (-658 (-592))) 74)) (-3347 (((-1193 (-433 (-592))) (-592)) 40)) (-4405 (((-1193 (-433 (-592))) (-592)) 52)) (-2806 (((-433 (-592)) (-1193 (-433 (-592)))) 62)) (-4495 (((-1193 (-433 (-592))) (-592)) 32)) (-2211 (((-1193 (-433 (-592))) (-592)) 48)) (-3187 (((-1193 (-433 (-592))) (-592)) 46)) (-1838 (((-1193 (-433 (-592))) (-1193 (-433 (-592))) (-1193 (-433 (-592)))) 60)) (-1700 (((-1193 (-433 (-592))) (-592)) 25)) (-2708 (((-433 (-592)) (-1193 (-433 (-592))) (-1193 (-433 (-592)))) 64)) (-4273 (((-1193 (-433 (-592))) (-592)) 30)) (-4576 (((-1193 (-433 (-592))) (-658 (-592))) 71))) 
+(((-204) (-10 -7 (-15 -1700 ((-1193 (-433 (-592))) (-592))) (-15 -3347 ((-1193 (-433 (-592))) (-592))) (-15 -4495 ((-1193 (-433 (-592))) (-592))) (-15 -4273 ((-1193 (-433 (-592))) (-592))) (-15 -3187 ((-1193 (-433 (-592))) (-592))) (-15 -2211 ((-1193 (-433 (-592))) (-592))) (-15 -4405 ((-1193 (-433 (-592))) (-592))) (-15 -2708 ((-433 (-592)) (-1193 (-433 (-592))) (-1193 (-433 (-592))))) (-15 -1838 ((-1193 (-433 (-592))) (-1193 (-433 (-592))) (-1193 (-433 (-592))))) (-15 -2806 ((-433 (-592)) (-1193 (-433 (-592))))) (-15 -3225 ((-1193 (-433 (-592))) (-1193 (-433 (-592))) (-1193 (-433 (-592))))) (-15 -4576 ((-1193 (-433 (-592))) (-658 (-592)))) (-15 -2803 ((-1193 (-433 (-592))) (-658 (-592)) (-658 (-592)))))) (T -204)) 
+((-2803 (*1 *2 *3 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)))) (-4576 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)))) (-3225 (*1 *2 *2 *2) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)))) (-2806 (*1 *2 *3) (-12 (-5 *3 (-1193 (-433 (-592)))) (-5 *2 (-433 (-592))) (-5 *1 (-204)))) (-1838 (*1 *2 *2 *2) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)))) (-2708 (*1 *2 *3 *3) (-12 (-5 *3 (-1193 (-433 (-592)))) (-5 *2 (-433 (-592))) (-5 *1 (-204)))) (-4405 (*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592)))) (-2211 (*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592)))) (-3187 (*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592)))) (-4273 (*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592)))) (-4495 (*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592)))) (-3347 (*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592)))) (-1700 (*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592))))) 
+(-10 -7 (-15 -1700 ((-1193 (-433 (-592))) (-592))) (-15 -3347 ((-1193 (-433 (-592))) (-592))) (-15 -4495 ((-1193 (-433 (-592))) (-592))) (-15 -4273 ((-1193 (-433 (-592))) (-592))) (-15 -3187 ((-1193 (-433 (-592))) (-592))) (-15 -2211 ((-1193 (-433 (-592))) (-592))) (-15 -4405 ((-1193 (-433 (-592))) (-592))) (-15 -2708 ((-433 (-592)) (-1193 (-433 (-592))) (-1193 (-433 (-592))))) (-15 -1838 ((-1193 (-433 (-592))) (-1193 (-433 (-592))) (-1193 (-433 (-592))))) (-15 -2806 ((-433 (-592)) (-1193 (-433 (-592))))) (-15 -3225 ((-1193 (-433 (-592))) (-1193 (-433 (-592))) (-1193 (-433 (-592))))) (-15 -4576 ((-1193 (-433 (-592))) (-658 (-592)))) (-15 -2803 ((-1193 (-433 (-592))) (-658 (-592)) (-658 (-592))))) 
+((-3246 (((-444 (-1187 (-592))) (-592)) 28)) (-2327 (((-658 (-1187 (-592))) (-592)) 23)) (-4446 (((-1187 (-592)) (-592)) 21))) 
+(((-205) (-10 -7 (-15 -2327 ((-658 (-1187 (-592))) (-592))) (-15 -4446 ((-1187 (-592)) (-592))) (-15 -3246 ((-444 (-1187 (-592))) (-592))))) (T -205)) 
+((-3246 (*1 *2 *3) (-12 (-5 *2 (-444 (-1187 (-592)))) (-5 *1 (-205)) (-5 *3 (-592)))) (-4446 (*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-205)) (-5 *3 (-592)))) (-2327 (*1 *2 *3) (-12 (-5 *2 (-658 (-1187 (-592)))) (-5 *1 (-205)) (-5 *3 (-592))))) 
+(-10 -7 (-15 -2327 ((-658 (-1187 (-592))) (-592))) (-15 -4446 ((-1187 (-592)) (-592))) (-15 -3246 ((-444 (-1187 (-592))) (-592)))) 
+((-1914 (((-1171 (-237)) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 101)) (-1945 (((-658 (-1173)) (-1171 (-237))) NIL)) (-3793 (((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 77)) (-2990 (((-658 (-237)) (-332 (-237)) (-1191) (-1113 (-862 (-237)))) NIL)) (-2247 (((-658 (-1173)) (-658 (-237))) NIL)) (-1550 (((-237) (-1113 (-862 (-237)))) 22)) (-3896 (((-237) (-1113 (-862 (-237)))) 23)) (-1760 (((-405) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 93)) (-1752 (((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 40)) (-3058 (((-1173) (-237)) NIL)) (-3844 (((-1173) (-658 (-1173))) 19)) (-3984 (((-1063) (-1191) (-1191) (-1063)) 12))) 
+(((-206) (-10 -7 (-15 -3793 ((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1752 ((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1550 ((-237) (-1113 (-862 (-237))))) (-15 -3896 ((-237) (-1113 (-862 (-237))))) (-15 -1760 ((-405) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -2990 ((-658 (-237)) (-332 (-237)) (-1191) (-1113 (-862 (-237))))) (-15 -1914 ((-1171 (-237)) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -3058 ((-1173) (-237))) (-15 -2247 ((-658 (-1173)) (-658 (-237)))) (-15 -1945 ((-658 (-1173)) (-1171 (-237)))) (-15 -3844 ((-1173) (-658 (-1173)))) (-15 -3984 ((-1063) (-1191) (-1191) (-1063))))) (T -206)) 
+((-3984 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1063)) (-5 *3 (-1191)) (-5 *1 (-206)))) (-3844 (*1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-1173)) (-5 *1 (-206)))) (-1945 (*1 *2 *3) (-12 (-5 *3 (-1171 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-206)))) (-2247 (*1 *2 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-206)))) (-3058 (*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-1173)) (-5 *1 (-206)))) (-1914 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-1171 (-237))) (-5 *1 (-206)))) (-2990 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-1191)) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-658 (-237))) (-5 *1 (-206)))) (-1760 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-206)))) (-3896 (*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-206)))) (-1550 (*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-206)))) (-1752 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (-5 *1 (-206)))) (-3793 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (-5 *1 (-206))))) 
+(-10 -7 (-15 -3793 ((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1752 ((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1550 ((-237) (-1113 (-862 (-237))))) (-15 -3896 ((-237) (-1113 (-862 (-237))))) (-15 -1760 ((-405) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -2990 ((-658 (-237)) (-332 (-237)) (-1191) (-1113 (-862 (-237))))) (-15 -1914 ((-1171 (-237)) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -3058 ((-1173) (-237))) (-15 -2247 ((-658 (-1173)) (-658 (-237)))) (-15 -1945 ((-658 (-1173)) (-1171 (-237)))) (-15 -3844 ((-1173) (-658 (-1173)))) (-15 -3984 ((-1063) (-1191) (-1191) (-1063)))) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 53) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 28) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-207) (-809)) (T -207)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 58) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 37) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-208) (-809)) (T -208)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 67) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 36) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-209) (-809)) (T -209)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 54) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 30) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-210) (-809)) (T -210)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 65) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 35) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-211) (-809)) (T -211)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 71) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 33) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-212) (-809)) (T -212)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 78) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 43) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-213) (-809)) (T -213)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 68) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 37) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-214) (-809)) (T -214)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 62)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 29)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-215) (-809)) (T -215)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 60)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 32)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-216) (-809)) (T -216)) 
+NIL 
+(-809) 
+((-1641 (((-141) $ $) NIL)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 89) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 77) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-217) (-809)) (T -217)) 
+NIL 
+(-809) 
+((-2277 (((-3 (-2 (|:| -1608 (-143)) (|:| |w| (-237))) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 80)) (-1943 (((-592) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 39)) (-1814 (((-3 (-658 (-237)) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 69))) 
+(((-218) (-10 -7 (-15 -2277 ((-3 (-2 (|:| -1608 (-143)) (|:| |w| (-237))) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1814 ((-3 (-658 (-237)) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1943 ((-592) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) (T -218)) 
+((-1943 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-592)) (-5 *1 (-218)))) (-1814 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-658 (-237))) (-5 *1 (-218)))) (-2277 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| -1608 (-143)) (|:| |w| (-237)))) (-5 *1 (-218))))) 
+(-10 -7 (-15 -2277 ((-3 (-2 (|:| -1608 (-143)) (|:| |w| (-237))) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1814 ((-3 (-658 (-237)) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1943 ((-592) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) 
+((-3491 (((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 37)) (-4223 (((-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405))) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 127)) (-2800 (((-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405))) (-706 (-332 (-237)))) 87)) (-4067 (((-405) (-706 (-332 (-237)))) 110)) (-3142 (((-706 (-332 (-237))) (-1280 (-332 (-237))) (-658 (-1191))) 107)) (-4438 (((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 26)) (-3076 (((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 42)) (-2806 (((-706 (-332 (-237))) (-706 (-332 (-237))) (-658 (-1191)) (-1280 (-332 (-237)))) 99)) (-4334 (((-405) (-405) (-658 (-405))) 104) (((-405) (-405) (-405)) 102)) (-2159 (((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 33))) 
+(((-219) (-10 -7 (-15 -4334 ((-405) (-405) (-405))) (-15 -4334 ((-405) (-405) (-658 (-405)))) (-15 -4067 ((-405) (-706 (-332 (-237))))) (-15 -3142 ((-706 (-332 (-237))) (-1280 (-332 (-237))) (-658 (-1191)))) (-15 -2806 ((-706 (-332 (-237))) (-706 (-332 (-237))) (-658 (-1191)) (-1280 (-332 (-237))))) (-15 -2800 ((-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405))) (-706 (-332 (-237))))) (-15 -4223 ((-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405))) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -3491 ((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -3076 ((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -2159 ((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -4438 ((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) (T -219)) 
+((-4438 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-219)))) (-2159 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-219)))) (-3076 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-219)))) (-3491 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-219)))) (-4223 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405)))) (-5 *1 (-219)))) (-2800 (*1 *2 *3) (-12 (-5 *3 (-706 (-332 (-237)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405)))) (-5 *1 (-219)))) (-2806 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-706 (-332 (-237)))) (-5 *3 (-658 (-1191))) (-5 *4 (-1280 (-332 (-237)))) (-5 *1 (-219)))) (-3142 (*1 *2 *3 *4) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *4 (-658 (-1191))) (-5 *2 (-706 (-332 (-237)))) (-5 *1 (-219)))) (-4067 (*1 *2 *3) (-12 (-5 *3 (-706 (-332 (-237)))) (-5 *2 (-405)) (-5 *1 (-219)))) (-4334 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-405))) (-5 *2 (-405)) (-5 *1 (-219)))) (-4334 (*1 *2 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-219))))) 
+(-10 -7 (-15 -4334 ((-405) (-405) (-405))) (-15 -4334 ((-405) (-405) (-658 (-405)))) (-15 -4067 ((-405) (-706 (-332 (-237))))) (-15 -3142 ((-706 (-332 (-237))) (-1280 (-332 (-237))) (-658 (-1191)))) (-15 -2806 ((-706 (-332 (-237))) (-706 (-332 (-237))) (-658 (-1191)) (-1280 (-332 (-237))))) (-15 -2800 ((-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405))) (-706 (-332 (-237))))) (-15 -4223 ((-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405))) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -3491 ((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -3076 ((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -2159 ((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -4438 ((-405) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) 
+((-1641 (((-141) $ $) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 37)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3356 (((-1063) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 60)) (-3255 (((-141) $ $) NIL))) 
+(((-220) (-822)) (T -220)) 
+NIL 
+(-822) 
+((-1641 (((-141) $ $) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 37)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3356 (((-1063) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 60)) (-3255 (((-141) $ $) NIL))) 
+(((-221) (-822)) (T -221)) 
+NIL 
+(-822) 
+((-1641 (((-141) $ $) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 36)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3356 (((-1063) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 64)) (-3255 (((-141) $ $) NIL))) 
+(((-222) (-822)) (T -222)) 
+NIL 
+(-822) 
+((-1641 (((-141) $ $) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 42)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3356 (((-1063) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 73)) (-3255 (((-141) $ $) NIL))) 
+(((-223) (-822)) (T -223)) 
+NIL 
+(-822) 
+((-2692 (((-658 (-1191)) (-1191) (-790)) 22)) (-1834 (((-332 (-237)) (-332 (-237))) 29)) (-4516 (((-141) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) 67)) (-2565 (((-141) (-237) (-237) (-658 (-332 (-237)))) 43))) 
+(((-224) (-10 -7 (-15 -2692 ((-658 (-1191)) (-1191) (-790))) (-15 -1834 ((-332 (-237)) (-332 (-237)))) (-15 -2565 ((-141) (-237) (-237) (-658 (-332 (-237))))) (-15 -4516 ((-141) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237))))))) (T -224)) 
+((-4516 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *2 (-141)) (-5 *1 (-224)))) (-2565 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-658 (-332 (-237)))) (-5 *3 (-237)) (-5 *2 (-141)) (-5 *1 (-224)))) (-1834 (*1 *2 *2) (-12 (-5 *2 (-332 (-237))) (-5 *1 (-224)))) (-2692 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-5 *2 (-658 (-1191))) (-5 *1 (-224)) (-5 *3 (-1191))))) 
+(-10 -7 (-15 -2692 ((-658 (-1191)) (-1191) (-790))) (-15 -1834 ((-332 (-237)) (-332 (-237)))) (-15 -2565 ((-141) (-237) (-237) (-658 (-332 (-237))))) (-15 -4516 ((-141) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))))) 
+((-1641 (((-141) $ $) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) 17)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-4180 (((-1063) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) 55)) (-3255 (((-141) $ $) NIL))) 
+(((-225) (-917)) (T -225)) 
+NIL 
+(-917) 
+((-1641 (((-141) $ $) NIL)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) 12)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-4180 (((-1063) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-226) (-917)) (T -226)) 
+NIL 
+(-917) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3948 (((-1285) $) 36) (((-1285) $ (-944) (-944)) 38)) (-3927 (($ $ (-1018)) 19) (((-262 (-1173)) $ (-1191)) 15)) (-3536 (((-1285) $) 34)) (-1683 (((-877) $) 31) (($ (-658 |#1|)) 8)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $ $) 27)) (-3300 (($ $ $) 22))) 
+(((-227 |#1|) (-13 (-1119) (-10 -8 (-15 -3927 ($ $ (-1018))) (-15 -3927 ((-262 (-1173)) $ (-1191))) (-15 -3300 ($ $ $)) (-15 -3306 ($ $ $)) (-15 -1683 ($ (-658 |#1|))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $)) (-15 -3948 ((-1285) $ (-944) (-944))))) (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))) (T -227)) 
+((-3927 (*1 *1 *1 *2) (-12 (-5 *2 (-1018)) (-5 *1 (-227 *3)) (-4 *3 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-262 (-1173))) (-5 *1 (-227 *4)) (-4 *4 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ *3)) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))))) (-3300 (*1 *1 *1 *1) (-12 (-5 *1 (-227 *2)) (-4 *2 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))))) (-3306 (*1 *1 *1 *1) (-12 (-5 *1 (-227 *2)) (-4 *2 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))) (-5 *1 (-227 *3)))) (-3536 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-227 *3)) (-4 *3 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 (*2 $)) (-15 -3948 (*2 $))))))) (-3948 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-227 *3)) (-4 *3 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 (*2 $)) (-15 -3948 (*2 $))))))) (-3948 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1285)) (-5 *1 (-227 *4)) (-4 *4 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 (*2 $)) (-15 -3948 (*2 $)))))))) 
+(-13 (-1119) (-10 -8 (-15 -3927 ($ $ (-1018))) (-15 -3927 ((-262 (-1173)) $ (-1191))) (-15 -3300 ($ $ $)) (-15 -3306 ($ $ $)) (-15 -1683 ($ (-658 |#1|))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $)) (-15 -3948 ((-1285) $ (-944) (-944))))) 
+((-4133 ((|#2| |#4| (-1 |#2| |#2|)) 46))) 
+(((-228 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4133 (|#2| |#4| (-1 |#2| |#2|)))) (-388) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|)) (T -228)) 
+((-4133 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *2 *2)) (-4 *5 (-388)) (-4 *6 (-1255 (-433 *2))) (-4 *2 (-1255 *5)) (-5 *1 (-228 *5 *2 *6 *3)) (-4 *3 (-362 *5 *2 *6))))) 
+(-10 -7 (-15 -4133 (|#2| |#4| (-1 |#2| |#2|)))) 
+((-2444 ((|#2| |#2| (-790) |#2|) 41)) (-3157 ((|#2| |#2| (-790) |#2|) 37)) (-4293 (((-658 |#2|) (-658 (-2 (|:| |deg| (-790)) (|:| -1975 |#2|)))) 55)) (-4283 (((-658 (-2 (|:| |deg| (-790)) (|:| -1975 |#2|))) |#2|) 51)) (-2139 (((-141) |#2|) 48)) (-3082 (((-444 |#2|) |#2|) 74)) (-4500 (((-444 |#2|) |#2|) 73)) (-3473 ((|#2| |#2| (-790) |#2|) 35)) (-3587 (((-2 (|:| |cont| |#1|) (|:| -2033 (-658 (-2 (|:| |irr| |#2|) (|:| -1777 (-592)))))) |#2| (-141)) 66))) 
+(((-229 |#1| |#2|) (-10 -7 (-15 -4500 ((-444 |#2|) |#2|)) (-15 -3082 ((-444 |#2|) |#2|)) (-15 -3587 ((-2 (|:| |cont| |#1|) (|:| -2033 (-658 (-2 (|:| |irr| |#2|) (|:| -1777 (-592)))))) |#2| (-141))) (-15 -4283 ((-658 (-2 (|:| |deg| (-790)) (|:| -1975 |#2|))) |#2|)) (-15 -4293 ((-658 |#2|) (-658 (-2 (|:| |deg| (-790)) (|:| -1975 |#2|))))) (-15 -3473 (|#2| |#2| (-790) |#2|)) (-15 -3157 (|#2| |#2| (-790) |#2|)) (-15 -2444 (|#2| |#2| (-790) |#2|)) (-15 -2139 ((-141) |#2|))) (-373) (-1255 |#1|)) (T -229)) 
+((-2139 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-229 *4 *3)) (-4 *3 (-1255 *4)))) (-2444 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-790)) (-4 *4 (-373)) (-5 *1 (-229 *4 *2)) (-4 *2 (-1255 *4)))) (-3157 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-790)) (-4 *4 (-373)) (-5 *1 (-229 *4 *2)) (-4 *2 (-1255 *4)))) (-3473 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-790)) (-4 *4 (-373)) (-5 *1 (-229 *4 *2)) (-4 *2 (-1255 *4)))) (-4293 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| |deg| (-790)) (|:| -1975 *5)))) (-4 *5 (-1255 *4)) (-4 *4 (-373)) (-5 *2 (-658 *5)) (-5 *1 (-229 *4 *5)))) (-4283 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-658 (-2 (|:| |deg| (-790)) (|:| -1975 *3)))) (-5 *1 (-229 *4 *3)) (-4 *3 (-1255 *4)))) (-3587 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-373)) (-5 *2 (-2 (|:| |cont| *5) (|:| -2033 (-658 (-2 (|:| |irr| *3) (|:| -1777 (-592))))))) (-5 *1 (-229 *5 *3)) (-4 *3 (-1255 *5)))) (-3082 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-229 *4 *3)) (-4 *3 (-1255 *4)))) (-4500 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-229 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -4500 ((-444 |#2|) |#2|)) (-15 -3082 ((-444 |#2|) |#2|)) (-15 -3587 ((-2 (|:| |cont| |#1|) (|:| -2033 (-658 (-2 (|:| |irr| |#2|) (|:| -1777 (-592)))))) |#2| (-141))) (-15 -4283 ((-658 (-2 (|:| |deg| (-790)) (|:| -1975 |#2|))) |#2|)) (-15 -4293 ((-658 |#2|) (-658 (-2 (|:| |deg| (-790)) (|:| -1975 |#2|))))) (-15 -3473 (|#2| |#2| (-790) |#2|)) (-15 -3157 (|#2| |#2| (-790) |#2|)) (-15 -2444 (|#2| |#2| (-790) |#2|)) (-15 -2139 ((-141) |#2|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 (((-592) $) NIL (|has| (-592) (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| (-592) (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL (|has| (-592) (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-592) (-1065 (-592)))) (((-3 (-592) "failed") $) NIL (|has| (-592) (-1065 (-592))))) (-2400 (((-592) $) NIL) (((-1191) $) NIL (|has| (-592) (-1065 (-1191)))) (((-433 (-592)) $) NIL (|has| (-592) (-1065 (-592)))) (((-592) $) NIL (|has| (-592) (-1065 (-592))))) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-592) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-592) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-706 (-592)) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-592) (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) NIL (|has| (-592) (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| (-592) (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| (-592) (-908 (-405))))) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL)) (-1448 (((-592) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| (-592) (-1165)))) (-1324 (((-141) $) NIL (|has| (-592) (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-592) (-869)))) (-2731 (($ (-1 (-592) (-592)) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-592) (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| (-592) (-323))) (((-433 (-592)) $) NIL)) (-2039 (((-592) $) NIL (|has| (-592) (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 (-592)) (-658 (-592))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-592) (-592)) NIL (|has| (-592) (-325 (-592)))) (($ $ (-310 (-592))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-658 (-310 (-592)))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-658 (-1191)) (-658 (-592))) NIL (|has| (-592) (-547 (-1191) (-592)))) (($ $ (-1191) (-592)) NIL (|has| (-592) (-547 (-1191) (-592))))) (-2769 (((-790) $) NIL)) (-3927 (($ $ (-592)) NIL (|has| (-592) (-303 (-592) (-592))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL (|has| (-592) (-247))) (($ $ (-790)) NIL (|has| (-592) (-247))) (($ $ (-1191)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1 (-592) (-592)) (-790)) NIL) (($ $ (-1 (-592) (-592))) NIL)) (-2782 (($ $) NIL)) (-1456 (((-592) $) NIL)) (-4035 (($ (-433 (-592))) 8)) (-1778 (((-914 (-592)) $) NIL (|has| (-592) (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| (-592) (-633 (-914 (-405))))) (((-565) $) NIL (|has| (-592) (-633 (-565)))) (((-405) $) NIL (|has| (-592) (-1049))) (((-237) $) NIL (|has| (-592) (-1049)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-592) (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) 7) (($ (-592)) NIL) (($ (-1191)) NIL (|has| (-592) (-1065 (-1191)))) (((-433 (-592)) $) NIL) (((-1032 10) $) 9)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-592) (-931))) (|has| (-592) (-169))))) (-4010 (((-790)) NIL)) (-2744 (((-592) $) NIL (|has| (-592) (-574)))) (-2537 (((-141) $ $) NIL)) (-1392 (($ $) NIL (|has| (-592) (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $) NIL (|has| (-592) (-247))) (($ $ (-790)) NIL (|has| (-592) (-247))) (($ $ (-1191)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1 (-592) (-592)) (-790)) NIL) (($ $ (-1 (-592) (-592))) NIL)) (-3286 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3313 (($ $ $) NIL) (($ (-592) (-592)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ (-592) $) NIL) (($ $ (-592)) NIL))) 
+(((-230) (-13 (-1021 (-592)) (-10 -8 (-15 -1683 ((-433 (-592)) $)) (-15 -1683 ((-1032 10) $)) (-15 -3856 ((-433 (-592)) $)) (-15 -4035 ($ (-433 (-592))))))) (T -230)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-230)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1032 10)) (-5 *1 (-230)))) (-3856 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-230)))) (-4035 (*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-230))))) 
+(-13 (-1021 (-592)) (-10 -8 (-15 -1683 ((-433 (-592)) $)) (-15 -1683 ((-1032 10) $)) (-15 -3856 ((-433 (-592)) $)) (-15 -4035 ($ (-433 (-592)))))) 
+((-3162 (((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1111 (-862 |#2|)) (-1173)) 27) (((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1111 (-862 |#2|))) 23)) (-3609 (((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1191) (-862 |#2|) (-862 |#2|) (-141)) 16))) 
+(((-231 |#1| |#2|) (-10 -7 (-15 -3162 ((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1111 (-862 |#2|)))) (-15 -3162 ((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1111 (-862 |#2|)) (-1173))) (-15 -3609 ((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1191) (-862 |#2|) (-862 |#2|) (-141)))) (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592))) (-13 (-1211) (-987) (-29 |#1|))) (T -231)) 
+((-3609 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-1191)) (-5 *6 (-141)) (-4 *7 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-4 *3 (-13 (-1211) (-987) (-29 *7))) (-5 *2 (-3 (|:| |f1| (-862 *3)) (|:| |f2| (-658 (-862 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-231 *7 *3)) (-5 *5 (-862 *3)))) (-3162 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1111 (-862 *3))) (-5 *5 (-1173)) (-4 *3 (-13 (-1211) (-987) (-29 *6))) (-4 *6 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 *3)) (|:| |f2| (-658 (-862 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-231 *6 *3)))) (-3162 (*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-862 *3))) (-4 *3 (-13 (-1211) (-987) (-29 *5))) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 *3)) (|:| |f2| (-658 (-862 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-231 *5 *3))))) 
+(-10 -7 (-15 -3162 ((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1111 (-862 |#2|)))) (-15 -3162 ((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1111 (-862 |#2|)) (-1173))) (-15 -3609 ((-3 (|:| |f1| (-862 |#2|)) (|:| |f2| (-658 (-862 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1191) (-862 |#2|) (-862 |#2|) (-141)))) 
+((-3162 (((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-433 (-980 |#1|)))) (-1173)) 44) (((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-433 (-980 |#1|))))) 41) (((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-332 |#1|))) (-1173)) 45) (((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-332 |#1|)))) 17))) 
+(((-232 |#1|) (-10 -7 (-15 -3162 ((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-332 |#1|))))) (-15 -3162 ((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-332 |#1|))) (-1173))) (-15 -3162 ((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-433 (-980 |#1|)))))) (-15 -3162 ((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-433 (-980 |#1|)))) (-1173)))) (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (T -232)) 
+((-3162 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1111 (-862 (-433 (-980 *6))))) (-5 *5 (-1173)) (-5 *3 (-433 (-980 *6))) (-4 *6 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 (-332 *6))) (|:| |f2| (-658 (-862 (-332 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-232 *6)))) (-3162 (*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-862 (-433 (-980 *5))))) (-5 *3 (-433 (-980 *5))) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 (-332 *5))) (|:| |f2| (-658 (-862 (-332 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-232 *5)))) (-3162 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-433 (-980 *6))) (-5 *4 (-1111 (-862 (-332 *6)))) (-5 *5 (-1173)) (-4 *6 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 (-332 *6))) (|:| |f2| (-658 (-862 (-332 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-232 *6)))) (-3162 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1111 (-862 (-332 *5)))) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 (-332 *5))) (|:| |f2| (-658 (-862 (-332 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-232 *5))))) 
+(-10 -7 (-15 -3162 ((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-332 |#1|))))) (-15 -3162 ((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-332 |#1|))) (-1173))) (-15 -3162 ((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-433 (-980 |#1|)))))) (-15 -3162 ((-3 (|:| |f1| (-862 (-332 |#1|))) (|:| |f2| (-658 (-862 (-332 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-433 (-980 |#1|)) (-1111 (-862 (-433 (-980 |#1|)))) (-1173)))) 
+((-3657 (((-2 (|:| -3489 (-1187 |#1|)) (|:| |deg| (-944))) (-1187 |#1|)) 20)) (-3098 (((-658 (-332 |#2|)) (-332 |#2|) (-944)) 42))) 
+(((-233 |#1| |#2|) (-10 -7 (-15 -3657 ((-2 (|:| -3489 (-1187 |#1|)) (|:| |deg| (-944))) (-1187 |#1|))) (-15 -3098 ((-658 (-332 |#2|)) (-332 |#2|) (-944)))) (-1075) (-13 (-582) (-869))) (T -233)) 
+((-3098 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *6 (-13 (-582) (-869))) (-5 *2 (-658 (-332 *6))) (-5 *1 (-233 *5 *6)) (-5 *3 (-332 *6)) (-4 *5 (-1075)))) (-3657 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-2 (|:| -3489 (-1187 *4)) (|:| |deg| (-944)))) (-5 *1 (-233 *4 *5)) (-5 *3 (-1187 *4)) (-4 *5 (-13 (-582) (-869)))))) 
+(-10 -7 (-15 -3657 ((-2 (|:| -3489 (-1187 |#1|)) (|:| |deg| (-944))) (-1187 |#1|))) (-15 -3098 ((-658 (-332 |#2|)) (-332 |#2|) (-944)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2616 ((|#1| $) 25)) (-3349 ((|#1| $) 26)) (-2126 (((-141) $ (-790)) NIL)) (-3001 (($) NIL T CONST)) (-4179 (($ $) NIL)) (-2512 (($ $) 32)) (-3568 ((|#1| |#1| $) NIL)) (-2486 ((|#1| $) NIL)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-4233 (((-790) $) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4137 ((|#1| $) NIL)) (-2251 ((|#1| |#1| $) 29)) (-4451 ((|#1| |#1| $) 31)) (-2113 (($ |#1| $) NIL)) (-2535 (((-790) $) 27)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1476 ((|#1| $) NIL)) (-2452 ((|#1| $) 24)) (-4225 ((|#1| $) 8)) (-2106 ((|#1| $) NIL)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1659 ((|#1| |#1| $) NIL)) (-2943 (((-141) $) 15)) (-2890 (($) NIL)) (-1716 ((|#1| $) NIL)) (-4309 (($) NIL) (($ (-658 |#1|)) 13)) (-3439 (((-790) $) 28)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-1966 ((|#1| $) 9)) (-4560 (($ (-658 |#1|)) NIL)) (-2829 ((|#1| $) NIL)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-234 |#1|) (-13 (-269 |#1|) (-10 -8 (-15 -4309 ($ (-658 |#1|))) (-15 -1716 (|#1| $)) (-15 -2106 (|#1| $)) (-15 -1659 (|#1| |#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -1476 (|#1| $)) (-15 -2829 (|#1| $)) (-15 -4179 ($ $)) (-15 -4233 ((-790) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -4560 ($ (-658 |#1|))) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -3001 ($)) (-15 -4599 ($ $)) (-15 -1724 ((-141) $ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (-15 -3439 ((-790) $)) (-15 -4309 ($)) (-15 -2535 ((-790) $)) (-15 -3349 (|#1| $)) (-15 -1966 (|#1| $)) (-15 -4225 (|#1| $)) (-15 -2452 (|#1| $)) (-15 -4451 (|#1| |#1| $)) (-15 -2251 (|#1| |#1| $)) (-15 -2486 (|#1| $)) (-15 -3568 (|#1| |#1| $)) (-15 -2512 ($ $)) (-15 -2616 (|#1| $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) (-1119)) (T -234)) 
+((-1724 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) (-4599 (*1 *1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-2890 (*1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-2943 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) (-2554 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-234 *4)) (-4 *4 (-1119)))) (-4345 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-234 *4)) (-4 *4 (-1119)))) (-2126 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-234 *4)) (-4 *4 (-1119)))) (-3001 (*1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-234 *3)))) (-3987 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-1119)) (-5 *1 (-234 *3)))) (-3369 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-234 *4)))) (-3002 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-234 *4)))) (-3452 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-234 *4)))) (-4004 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) (-3452 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-3133 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-2685 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-2951 (*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-3255 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-1641 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-4560 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-234 *3)))) (-2106 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-2113 (*1 *1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-4137 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-3568 (*1 *2 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-2486 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-3349 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-3439 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) (-2829 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-1476 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-4233 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) (-4179 (*1 *1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-1716 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-1659 (*1 *2 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-4309 (*1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-4309 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-234 *3)))) (-2535 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) (-2616 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-1966 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-2251 (*1 *2 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-4451 (*1 *2 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-2452 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-4225 (*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) (-2512 (*1 *1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119))))) 
+(-13 (-269 |#1|) (-10 -8 (-15 -4309 ($ (-658 |#1|))) (-15 -1716 (|#1| $)) (-15 -2106 (|#1| $)) (-15 -1659 (|#1| |#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -1476 (|#1| $)) (-15 -2829 (|#1| $)) (-15 -4179 ($ $)) (-15 -4233 ((-790) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -4560 ($ (-658 |#1|))) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -3001 ($)) (-15 -4599 ($ $)) (-15 -1724 ((-141) $ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (-15 -3439 ((-790) $)) (-15 -4309 ($)) (-15 -2535 ((-790) $)) (-15 -3349 (|#1| $)) (-15 -1966 (|#1| $)) (-15 -4225 (|#1| $)) (-15 -2452 (|#1| $)) (-15 -4451 (|#1| |#1| $)) (-15 -2251 (|#1| |#1| $)) (-15 -2486 (|#1| $)) (-15 -3568 (|#1| |#1| $)) (-15 -2512 ($ $)) (-15 -2616 (|#1| $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3435 (($ (-332 |#1|)) 23)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3461 (((-141) $) NIL)) (-4368 (((-3 (-332 |#1|) "failed") $) NIL)) (-2400 (((-332 |#1|) $) NIL)) (-4593 (($ $) 31)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-2731 (($ (-1 (-332 |#1|) (-332 |#1|)) $) NIL)) (-4579 (((-332 |#1|) $) NIL)) (-1693 (($ $) 30)) (-2685 (((-1173) $) NIL)) (-1815 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-2934 (($ (-790)) NIL)) (-3310 (($ $) 32)) (-4525 (((-592) $) NIL)) (-1683 (((-877) $) 57) (($ (-592)) NIL) (($ (-332 |#1|)) NIL)) (-1937 (((-332 |#1|) $ $) NIL)) (-4010 (((-790)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 25 T CONST)) (-4257 (($) 50 T CONST)) (-3255 (((-141) $ $) 28)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 19)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 24) (($ (-332 |#1|) $) 18))) 
+(((-235 |#1| |#2|) (-13 (-636 (-332 |#1|)) (-1065 (-332 |#1|)) (-10 -8 (-15 -4579 ((-332 |#1|) $)) (-15 -1693 ($ $)) (-15 -4593 ($ $)) (-15 -1937 ((-332 |#1|) $ $)) (-15 -2934 ($ (-790))) (-15 -1815 ((-141) $)) (-15 -3461 ((-141) $)) (-15 -4525 ((-592) $)) (-15 -2731 ($ (-1 (-332 |#1|) (-332 |#1|)) $)) (-15 -3435 ($ (-332 |#1|))) (-15 -3310 ($ $)))) (-13 (-1075) (-869)) (-658 (-1191))) (T -235)) 
+((-4579 (*1 *2 *1) (-12 (-5 *2 (-332 *3)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) (-1693 (*1 *1 *1) (-12 (-5 *1 (-235 *2 *3)) (-4 *2 (-13 (-1075) (-869))) (-14 *3 (-658 (-1191))))) (-4593 (*1 *1 *1) (-12 (-5 *1 (-235 *2 *3)) (-4 *2 (-13 (-1075) (-869))) (-14 *3 (-658 (-1191))))) (-1937 (*1 *2 *1 *1) (-12 (-5 *2 (-332 *3)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) (-2934 (*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) (-1815 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) (-3461 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) (-4525 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-332 *3) (-332 *3))) (-4 *3 (-13 (-1075) (-869))) (-5 *1 (-235 *3 *4)) (-14 *4 (-658 (-1191))))) (-3435 (*1 *1 *2) (-12 (-5 *2 (-332 *3)) (-4 *3 (-13 (-1075) (-869))) (-5 *1 (-235 *3 *4)) (-14 *4 (-658 (-1191))))) (-3310 (*1 *1 *1) (-12 (-5 *1 (-235 *2 *3)) (-4 *2 (-13 (-1075) (-869))) (-14 *3 (-658 (-1191)))))) 
+(-13 (-636 (-332 |#1|)) (-1065 (-332 |#1|)) (-10 -8 (-15 -4579 ((-332 |#1|) $)) (-15 -1693 ($ $)) (-15 -4593 ($ $)) (-15 -1937 ((-332 |#1|) $ $)) (-15 -2934 ($ (-790))) (-15 -1815 ((-141) $)) (-15 -3461 ((-141) $)) (-15 -4525 ((-592) $)) (-15 -2731 ($ (-1 (-332 |#1|) (-332 |#1|)) $)) (-15 -3435 ($ (-332 |#1|))) (-15 -3310 ($ $)))) 
+((-3304 (((-141) (-1173)) 22)) (-3764 (((-3 (-862 |#2|) "failed") (-631 |#2|) |#2| (-862 |#2|) (-862 |#2|) (-141)) 32)) (-2578 (((-3 (-141) "failed") (-1187 |#2|) (-862 |#2|) (-862 |#2|) (-141)) 73) (((-3 (-141) "failed") (-980 |#1|) (-1191) (-862 |#2|) (-862 |#2|) (-141)) 74))) 
+(((-236 |#1| |#2|) (-10 -7 (-15 -3304 ((-141) (-1173))) (-15 -3764 ((-3 (-862 |#2|) "failed") (-631 |#2|) |#2| (-862 |#2|) (-862 |#2|) (-141))) (-15 -2578 ((-3 (-141) "failed") (-980 |#1|) (-1191) (-862 |#2|) (-862 |#2|) (-141))) (-15 -2578 ((-3 (-141) "failed") (-1187 |#2|) (-862 |#2|) (-862 |#2|) (-141)))) (-13 (-477) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-1211) (-29 |#1|))) (T -236)) 
+((-2578 (*1 *2 *3 *4 *4 *2) (|partial| -12 (-5 *2 (-141)) (-5 *3 (-1187 *6)) (-5 *4 (-862 *6)) (-4 *6 (-13 (-1211) (-29 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-236 *5 *6)))) (-2578 (*1 *2 *3 *4 *5 *5 *2) (|partial| -12 (-5 *2 (-141)) (-5 *3 (-980 *6)) (-5 *4 (-1191)) (-5 *5 (-862 *7)) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-4 *7 (-13 (-1211) (-29 *6))) (-5 *1 (-236 *6 *7)))) (-3764 (*1 *2 *3 *4 *2 *2 *5) (|partial| -12 (-5 *2 (-862 *4)) (-5 *3 (-631 *4)) (-5 *5 (-141)) (-4 *4 (-13 (-1211) (-29 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-236 *6 *4)))) (-3304 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-141)) (-5 *1 (-236 *4 *5)) (-4 *5 (-13 (-1211) (-29 *4)))))) 
+(-10 -7 (-15 -3304 ((-141) (-1173))) (-15 -3764 ((-3 (-862 |#2|) "failed") (-631 |#2|) |#2| (-862 |#2|) (-862 |#2|) (-141))) (-15 -2578 ((-3 (-141) "failed") (-980 |#1|) (-1191) (-862 |#2|) (-862 |#2|) (-141))) (-15 -2578 ((-3 (-141) "failed") (-1187 |#2|) (-862 |#2|) (-862 |#2|) (-141)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 95)) (-1505 (((-592) $) 124)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2306 (($ $) NIL)) (-1588 (($ $) 83)) (-1507 (($ $) 71)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1442 (($ $) 62)) (-3652 (((-141) $ $) NIL)) (-1575 (($ $) 81)) (-1495 (($ $) 69)) (-3940 (((-592) $) 137)) (-1601 (($ $) 86)) (-1521 (($ $) 73)) (-3001 (($) NIL T CONST)) (-1755 (($ $) NIL)) (-4368 (((-3 (-592) "failed") $) 120) (((-3 (-433 (-592)) "failed") $) 135)) (-2400 (((-592) $) 136) (((-433 (-592)) $) 133)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) 98)) (-2753 (((-433 (-592)) $ (-790)) 131) (((-433 (-592)) $ (-790) (-790)) 130)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-4047 (((-944)) 34) (((-944) (-944)) NIL (|has| $ (-6 -4616)))) (-1691 (((-141) $) NIL)) (-4018 (($ $ $) 123)) (-1435 (($) 44)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL)) (-4346 (((-592) $) 40)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL)) (-2793 (($ $) NIL)) (-1324 (((-141) $) 94)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) 59) (($) 39 (-12 (-3252 (|has| $ (-6 -4608))) (-3252 (|has| $ (-6 -4616)))))) (-3319 (($ $ $) 58) (($) 38 (-12 (-3252 (|has| $ (-6 -4608))) (-3252 (|has| $ (-6 -4616)))))) (-2950 (((-592) $) 32)) (-3631 (((-433 (-592)) $) 27)) (-1998 (($ $) 35)) (-4197 (($ $) 63)) (-4546 (($ $) 68)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3396 (((-658 (-592)) $) 29)) (-1867 (((-944) (-592)) NIL (|has| $ (-6 -4616)))) (-2951 (((-1137) $) NIL) (((-592) $) 96)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL)) (-2039 (($ $) NIL)) (-4540 (($ (-592) (-592)) NIL) (($ (-592) (-592) (-944)) 125)) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3215 (((-592) $) 33)) (-1667 (($) 43)) (-1430 (($ $) 67)) (-2769 (((-790) $) NIL)) (-2205 (((-1173) (-1173)) 8)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4406 (((-944)) NIL) (((-944) (-944)) NIL (|has| $ (-6 -4616)))) (-2002 (($ $) 116)) (-3644 (($ $ (-790)) NIL) (($ $) 99)) (-1738 (((-944) (-592)) NIL (|has| $ (-6 -4616)))) (-1609 (($ $) 84)) (-1527 (($ $) 74)) (-1594 (($ $) 85)) (-1515 (($ $) 72)) (-1581 (($ $) 82)) (-1501 (($ $) 70)) (-1778 (((-405) $) 129) (((-237) $) 126) (((-914 (-405)) $) NIL) (((-565) $) 51)) (-1683 (((-877) $) 48) (($ (-592)) 66) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-592)) 66) (($ (-433 (-592))) NIL)) (-4010 (((-790)) NIL)) (-2744 (($ $) NIL)) (-3671 (((-944)) 37) (((-944) (-944)) NIL (|has| $ (-6 -4616)))) (-2280 (($ $ $) 112)) (-2500 (($ $ $) 110)) (-3468 (($ $ $) 108)) (-2894 (($ $ $) 106)) (-4226 (((-944)) 31)) (-1630 (($ $) 89)) (-1546 (($ $) 77) (($ $ $) 132)) (-2537 (((-141) $ $) NIL)) (-1617 (($ $) 87)) (-1533 (($ $) 75)) (-1642 (($ $) 92)) (-1559 (($ $) 80)) (-2156 (($ $) 104)) (-3132 (($ $) 102)) (-2892 (($ $) 90)) (-1567 (($ $) 78)) (-1636 (($ $) 91)) (-1552 (($ $) 79)) (-1624 (($ $) 88)) (-1540 (($ $) 76)) (-1392 (($ $) 138)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 41 T CONST)) (-4257 (($) 42 T CONST)) (-1637 (((-1173) $) 19) (((-1173) $ (-141)) 21) (((-1285) (-844) $) 22) (((-1285) (-844) $ (-141)) 23)) (-2348 (($ $) 118) (($ $ $) NIL)) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-2170 (($ $ $) 114)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 60)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 52)) (-3313 (($ $ $) 93) (($ $ (-592)) 61)) (-3306 (($ $) 53) (($ $ $) 55)) (-3300 (($ $ $) 54)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 64) (($ $ (-433 (-592))) 148) (($ $ $) 65)) (* (($ (-944) $) 36) (($ (-790) $) NIL) (($ (-592) $) 57) (($ $ $) 56) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL))) 
+(((-237) (-13 (-430) (-247) (-850) (-1211) (-1153) (-633 (-565)) (-10 -8 (-15 -3313 ($ $ (-592))) (-15 ** ($ $ $)) (-15 -1667 ($)) (-15 -2951 ((-592) $)) (-15 -1998 ($ $)) (-15 -4197 ($ $)) (-15 -1546 ($ $ $)) (-15 -2348 ($ $)) (-15 -2170 ($ $ $)) (-15 -2205 ((-1173) (-1173))) (-15 -2753 ((-433 (-592)) $ (-790))) (-15 -2753 ((-433 (-592)) $ (-790) (-790))) (-15 -3631 ((-433 (-592)) $)) (-15 -3396 ((-658 (-592)) $))))) (T -237)) 
+((** (*1 *1 *1 *1) (-5 *1 (-237))) (-2348 (*1 *1 *1) (-5 *1 (-237))) (-2170 (*1 *1 *1 *1) (-5 *1 (-237))) (-3313 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-237)))) (-1667 (*1 *1) (-5 *1 (-237))) (-2951 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-237)))) (-1998 (*1 *1 *1) (-5 *1 (-237))) (-4197 (*1 *1 *1) (-5 *1 (-237))) (-1546 (*1 *1 *1 *1) (-5 *1 (-237))) (-2205 (*1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-237)))) (-2753 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-433 (-592))) (-5 *1 (-237)))) (-2753 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-433 (-592))) (-5 *1 (-237)))) (-3631 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-237)))) (-3396 (*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-237))))) 
+(-13 (-430) (-247) (-850) (-1211) (-1153) (-633 (-565)) (-10 -8 (-15 -3313 ($ $ (-592))) (-15 ** ($ $ $)) (-15 -1667 ($)) (-15 -2951 ((-592) $)) (-15 -1998 ($ $)) (-15 -4197 ($ $)) (-15 -1546 ($ $ $)) (-15 -2348 ($ $)) (-15 -2170 ($ $ $)) (-15 -2205 ((-1173) (-1173))) (-15 -2753 ((-433 (-592)) $ (-790))) (-15 -2753 ((-433 (-592)) $ (-790) (-790))) (-15 -3631 ((-433 (-592)) $)) (-15 -3396 ((-658 (-592)) $)))) 
+((-1641 (((-141) $ $) NIL (|has| (-237) (-1119)))) (-1417 (($ (-790) (-790)) NIL)) (-4596 (($ $ $) NIL)) (-2245 (($ (-240)) NIL) (($ $) NIL)) (-4034 (((-141) $) NIL)) (-2668 (($ $ (-592) (-592)) NIL)) (-1664 (($ $ (-592) (-592)) NIL)) (-2019 (($ $ (-592) (-592) (-592) (-592)) NIL)) (-1574 (($ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-2854 (($ $ (-592) (-592) $) NIL)) (-3932 (((-237) $ (-592) (-592) (-237)) NIL) (($ $ (-658 (-592)) (-658 (-592)) $) NIL)) (-2547 (($ $ (-592) (-240)) NIL)) (-2242 (($ $ (-592) (-240)) NIL)) (-3223 (($ (-790) (-237)) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) NIL (|has| (-237) (-323)))) (-2747 (((-240) $ (-592)) NIL)) (-4175 (((-790) $) NIL (|has| (-237) (-582)))) (-1426 (((-237) $ (-592) (-592) (-237)) 16)) (-1695 (($ (-592) (-592)) 18)) (-3959 (((-237) $ (-592) (-592)) 15)) (-1794 (((-237) $) NIL (|has| (-237) (-194)))) (-4004 (((-658 (-237)) $) NIL)) (-3178 (((-790) $) NIL (|has| (-237) (-582)))) (-3555 (((-658 (-240)) $) NIL (|has| (-237) (-582)))) (-4292 (((-790) $) 10)) (-3242 (($ (-790) (-790) (-237)) 19)) (-4298 (((-790) $) 11)) (-4345 (((-141) $ (-790)) NIL)) (-3781 (((-237) $) NIL (|has| (-237) (-6 (-4627 "*"))))) (-4577 (((-592) $) 7)) (-4280 (((-592) $) 8)) (-4467 (((-658 (-237)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-237) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-237) (-1119))))) (-1898 (((-592) $) 12)) (-3005 (((-592) $) 13)) (-4186 (($ (-658 (-658 (-237)))) NIL) (($ (-790) (-790) (-1 (-237) (-592) (-592))) NIL)) (-3987 (($ (-1 (-237) (-237)) $) NIL)) (-2731 (($ (-1 (-237) (-237)) $) NIL) (($ (-1 (-237) (-237) (-237)) $ $) NIL) (($ (-1 (-237) (-237) (-237)) $ $ (-237)) NIL)) (-4601 (((-658 (-658 (-237))) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| (-237) (-1119)))) (-3183 (((-3 $ "failed") $) NIL (|has| (-237) (-388)))) (-2083 (($ $ $) NIL)) (-2951 (((-1137) $) NIL (|has| (-237) (-1119)))) (-1892 (($ $ (-237)) NIL)) (-3616 (((-3 $ "failed") $ (-237)) NIL (|has| (-237) (-582)))) (-3002 (((-141) (-1 (-141) (-237)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-237)))) NIL (-12 (|has| (-237) (-325 (-237))) (|has| (-237) (-1119)))) (($ $ (-310 (-237))) NIL (-12 (|has| (-237) (-325 (-237))) (|has| (-237) (-1119)))) (($ $ (-237) (-237)) NIL (-12 (|has| (-237) (-325 (-237))) (|has| (-237) (-1119)))) (($ $ (-658 (-237)) (-658 (-237))) NIL (-12 (|has| (-237) (-325 (-237))) (|has| (-237) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 17)) (-3927 (((-237) $ (-592) (-592)) NIL) (((-237) $ (-592) (-592) (-237)) NIL) (($ $ (-658 (-592)) (-658 (-592))) NIL)) (-2933 (($ (-658 (-237))) NIL) (($ (-658 $)) NIL)) (-2940 (((-141) $) NIL)) (-1625 (((-237) $) NIL (|has| (-237) (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) (-237)) $) NIL (|has| $ (-6 -4625))) (((-790) (-237) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-237) (-1119))))) (-4599 (($ $) NIL)) (-3430 (((-658 (-240)) $) NIL (|has| (-237) (-323)))) (-2000 (((-240) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| (-237) (-1119))) (($ (-240)) NIL)) (-3369 (((-141) (-1 (-141) (-237)) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL (|has| (-237) (-1119)))) (-3313 (($ $ (-237)) NIL (|has| (-237) (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-237) (-388)))) (* (($ $ $) NIL) (($ (-237) $) NIL) (($ $ (-237)) NIL) (($ (-592) $) NIL) (((-240) $ (-240)) NIL) (((-240) (-240) $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-238) (-13 (-704 (-237) (-240) (-240)) (-10 -8 (-15 -1695 ($ (-592) (-592)))))) (T -238)) 
+((-1695 (*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-238))))) 
+(-13 (-704 (-237) (-240) (-240)) (-10 -8 (-15 -1695 ($ (-592) (-592))))) 
+((-4018 (((-191 (-237)) (-790) (-191 (-237))) 61) (((-237) (-790) (-237)) 62)) (-3805 (((-191 (-237)) (-191 (-237))) 63) (((-237) (-237)) 64)) (-2738 (((-191 (-237)) (-191 (-237)) (-191 (-237))) 69) (((-237) (-237) (-237)) 72)) (-2424 (((-405) (-405)) 60)) (-1927 (((-405) (-405)) 59)) (-2002 (((-191 (-237)) (-191 (-237))) 74) (((-237) (-237)) 73)) (-2280 (((-191 (-237)) (-191 (-237)) (-191 (-237))) 91) (((-237) (-237) (-237)) 83)) (-2500 (((-191 (-237)) (-191 (-237)) (-191 (-237))) 94) (((-237) (-237) (-237)) 92)) (-3468 (((-191 (-237)) (-191 (-237)) (-191 (-237))) 65) (((-237) (-237) (-237)) 66)) (-2894 (((-191 (-237)) (-191 (-237)) (-191 (-237))) 67) (((-237) (-237) (-237)) 68)) (-2156 (((-191 (-237)) (-191 (-237))) 105) (((-237) (-237)) 104)) (-3132 (((-237) (-237)) 99) (((-191 (-237)) (-191 (-237))) 103)) (-2348 (((-191 (-237)) (-191 (-237))) 7) (((-237) (-237)) 9)) (-3729 (((-855 (-237)) (-592) (-237)) 23)) (-2760 (((-855 (-237)) (-855 (-237))) 36)) (-2007 (((-855 (-237)) (-855 (-237))) 35)) (-3660 (((-855 (-237)) (-855 (-237))) 34)) (-2743 (((-855 (-237)) (-855 (-237))) 33)) (-3577 (((-855 (-237)) (-855 (-237))) 32)) (-4265 (((-855 (-237)) (-855 (-237))) 31)) (-4299 (((-855 (-237)) (-855 (-237))) 37)) (-2194 (((-855 (-237)) (-237)) 22)) (-2170 (((-191 (-237)) (-191 (-237)) (-191 (-237))) 79) (((-237) (-237) (-237)) 75))) 
+(((-239) (-10 -7 (-15 -2348 ((-237) (-237))) (-15 -2348 ((-191 (-237)) (-191 (-237)))) (-15 -2194 ((-855 (-237)) (-237))) (-15 -3729 ((-855 (-237)) (-592) (-237))) (-15 -4299 ((-855 (-237)) (-855 (-237)))) (-15 -4265 ((-855 (-237)) (-855 (-237)))) (-15 -3577 ((-855 (-237)) (-855 (-237)))) (-15 -2743 ((-855 (-237)) (-855 (-237)))) (-15 -3660 ((-855 (-237)) (-855 (-237)))) (-15 -2007 ((-855 (-237)) (-855 (-237)))) (-15 -2760 ((-855 (-237)) (-855 (-237)))) (-15 -2170 ((-237) (-237) (-237))) (-15 -2170 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -3805 ((-237) (-237))) (-15 -3805 ((-191 (-237)) (-191 (-237)))) (-15 -2002 ((-237) (-237))) (-15 -2002 ((-191 (-237)) (-191 (-237)))) (-15 -4018 ((-237) (-790) (-237))) (-15 -4018 ((-191 (-237)) (-790) (-191 (-237)))) (-15 -3468 ((-237) (-237) (-237))) (-15 -3468 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -2280 ((-237) (-237) (-237))) (-15 -2280 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -2894 ((-237) (-237) (-237))) (-15 -2894 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -2500 ((-237) (-237) (-237))) (-15 -2500 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -3132 ((-191 (-237)) (-191 (-237)))) (-15 -3132 ((-237) (-237))) (-15 -2156 ((-237) (-237))) (-15 -2156 ((-191 (-237)) (-191 (-237)))) (-15 -2738 ((-237) (-237) (-237))) (-15 -2738 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -2424 ((-405) (-405))) (-15 -1927 ((-405) (-405))))) (T -239)) 
+((-1927 (*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-239)))) (-2424 (*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-239)))) (-2738 (*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2738 (*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-2156 (*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2156 (*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-3132 (*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-3132 (*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2500 (*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2500 (*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-2894 (*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2894 (*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-2280 (*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2280 (*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-3468 (*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-3468 (*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-4018 (*1 *2 *3 *2) (-12 (-5 *2 (-191 (-237))) (-5 *3 (-790)) (-5 *1 (-239)))) (-4018 (*1 *2 *3 *2) (-12 (-5 *2 (-237)) (-5 *3 (-790)) (-5 *1 (-239)))) (-2002 (*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2002 (*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-3805 (*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-3805 (*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-2170 (*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2170 (*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) (-2760 (*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)))) (-2007 (*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)))) (-3660 (*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)))) (-2743 (*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)))) (-3577 (*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)))) (-4265 (*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)))) (-4299 (*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)))) (-3729 (*1 *2 *3 *4) (-12 (-5 *3 (-592)) (-5 *2 (-855 (-237))) (-5 *1 (-239)) (-5 *4 (-237)))) (-2194 (*1 *2 *3) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)) (-5 *3 (-237)))) (-2348 (*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) (-2348 (*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239))))) 
+(-10 -7 (-15 -2348 ((-237) (-237))) (-15 -2348 ((-191 (-237)) (-191 (-237)))) (-15 -2194 ((-855 (-237)) (-237))) (-15 -3729 ((-855 (-237)) (-592) (-237))) (-15 -4299 ((-855 (-237)) (-855 (-237)))) (-15 -4265 ((-855 (-237)) (-855 (-237)))) (-15 -3577 ((-855 (-237)) (-855 (-237)))) (-15 -2743 ((-855 (-237)) (-855 (-237)))) (-15 -3660 ((-855 (-237)) (-855 (-237)))) (-15 -2007 ((-855 (-237)) (-855 (-237)))) (-15 -2760 ((-855 (-237)) (-855 (-237)))) (-15 -2170 ((-237) (-237) (-237))) (-15 -2170 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -3805 ((-237) (-237))) (-15 -3805 ((-191 (-237)) (-191 (-237)))) (-15 -2002 ((-237) (-237))) (-15 -2002 ((-191 (-237)) (-191 (-237)))) (-15 -4018 ((-237) (-790) (-237))) (-15 -4018 ((-191 (-237)) (-790) (-191 (-237)))) (-15 -3468 ((-237) (-237) (-237))) (-15 -3468 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -2280 ((-237) (-237) (-237))) (-15 -2280 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -2894 ((-237) (-237) (-237))) (-15 -2894 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -2500 ((-237) (-237) (-237))) (-15 -2500 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -3132 ((-191 (-237)) (-191 (-237)))) (-15 -3132 ((-237) (-237))) (-15 -2156 ((-237) (-237))) (-15 -2156 ((-191 (-237)) (-191 (-237)))) (-15 -2738 ((-237) (-237) (-237))) (-15 -2738 ((-191 (-237)) (-191 (-237)) (-191 (-237)))) (-15 -2424 ((-405) (-405))) (-15 -1927 ((-405) (-405)))) 
+((-1641 (((-141) $ $) NIL (|has| (-237) (-1119)))) (-1417 (($ (-790)) NIL (|has| (-237) (-23)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) (-237) (-237)) $) NIL) (((-141) $) NIL (|has| (-237) (-869)))) (-2831 (($ (-1 (-141) (-237) (-237)) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-237) (-869))))) (-3960 (($ (-1 (-141) (-237) (-237)) $) NIL) (($ $) NIL (|has| (-237) (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-237) $ (-592) (-237)) 17 (|has| $ (-6 -4626))) (((-237) $ (-1246 (-592)) (-237)) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-237)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-237) (-1119))))) (-4459 (($ (-237) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-237) (-1119)))) (($ (-1 (-141) (-237)) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-237) (-1 (-237) (-237) (-237)) $ (-237) (-237)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-237) (-1119)))) (((-237) (-1 (-237) (-237) (-237)) $ (-237)) NIL (|has| $ (-6 -4625))) (((-237) (-1 (-237) (-237) (-237)) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-237) $ (-592) (-237)) 9 (|has| $ (-6 -4626)))) (-1695 (($ (-592)) 14)) (-3959 (((-237) $ (-592)) 8)) (-1721 (((-592) (-1 (-141) (-237)) $) NIL) (((-592) (-237) $) NIL (|has| (-237) (-1119))) (((-592) (-237) $ (-592)) NIL (|has| (-237) (-1119)))) (-4004 (((-658 (-237)) $) NIL (|has| $ (-6 -4625)))) (-4363 (((-706 (-237)) $ $) NIL (|has| (-237) (-1075)))) (-3242 (($ (-790) (-237)) 15)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 12 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| (-237) (-869)))) (-4491 (($ (-1 (-141) (-237) (-237)) $ $) NIL) (($ $ $) NIL (|has| (-237) (-869)))) (-4467 (((-658 (-237)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-237) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-237) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-237) (-869)))) (-3987 (($ (-1 (-237) (-237)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-237) (-237)) $) NIL) (($ (-1 (-237) (-237) (-237)) $ $) NIL)) (-2311 (((-237) $) NIL (-12 (|has| (-237) (-1030)) (|has| (-237) (-1075))))) (-2554 (((-141) $ (-790)) NIL)) (-4233 (((-237) $) NIL (-12 (|has| (-237) (-1030)) (|has| (-237) (-1075))))) (-2685 (((-1173) $) NIL (|has| (-237) (-1119)))) (-3666 (($ (-237) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| (-237) (-1119)))) (-1918 (((-237) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-237) "failed") (-1 (-141) (-237)) $) NIL)) (-1892 (($ $ (-237)) 18 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-237)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-237)))) NIL (-12 (|has| (-237) (-325 (-237))) (|has| (-237) (-1119)))) (($ $ (-310 (-237))) NIL (-12 (|has| (-237) (-325 (-237))) (|has| (-237) (-1119)))) (($ $ (-237) (-237)) NIL (-12 (|has| (-237) (-325 (-237))) (|has| (-237) (-1119)))) (($ $ (-658 (-237)) (-658 (-237))) NIL (-12 (|has| (-237) (-325 (-237))) (|has| (-237) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-237) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-237) (-1119))))) (-4210 (((-658 (-237)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 13)) (-3927 (((-237) $ (-592) (-237)) NIL) (((-237) $ (-592)) 16) (($ $ (-1246 (-592))) NIL)) (-1729 (((-237) $ $) NIL (|has| (-237) (-1075)))) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-2746 (($ $ $) NIL (|has| (-237) (-1075)))) (-3452 (((-790) (-1 (-141) (-237)) $) NIL (|has| $ (-6 -4625))) (((-790) (-237) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-237) (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-237) (-633 (-565))))) (-4466 (($ (-658 (-237))) NIL)) (-2266 (($ $ (-237)) NIL) (($ (-237) $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| (-237) (-1119)))) (-3369 (((-141) (-1 (-141) (-237)) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| (-237) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-237) (-869)))) (-3255 (((-141) $ $) NIL (|has| (-237) (-1119)))) (-3279 (((-141) $ $) NIL (|has| (-237) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-237) (-869)))) (-3306 (($ $) NIL (|has| (-237) (-21))) (($ $ $) NIL (|has| (-237) (-21)))) (-3300 (($ $ $) NIL (|has| (-237) (-25)))) (* (($ (-592) $) NIL (|has| (-237) (-21))) (($ (-237) $) NIL (|has| (-237) (-743))) (($ $ (-237)) NIL (|has| (-237) (-743)))) (-1699 (((-790) $) 11 (|has| $ (-6 -4625))))) 
+(((-240) (-13 (-1278 (-237)) (-10 -8 (-15 -1695 ($ (-592)))))) (T -240)) 
+((-1695 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-240))))) 
+(-13 (-1278 (-237)) (-10 -8 (-15 -1695 ($ (-592))))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1417 (($ (-790) (-790)) NIL)) (-4596 (($ $ $) NIL)) (-2245 (($ (-1280 |#1|)) NIL) (($ $) NIL)) (-3399 (($ |#1| |#1| |#1|) 32)) (-4034 (((-141) $) NIL)) (-2668 (($ $ (-592) (-592)) NIL)) (-1664 (($ $ (-592) (-592)) NIL)) (-2019 (($ $ (-592) (-592) (-592) (-592)) NIL)) (-1574 (($ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-2854 (($ $ (-592) (-592) $) NIL)) (-3932 ((|#1| $ (-592) (-592) |#1|) NIL) (($ $ (-658 (-592)) (-658 (-592)) $) NIL)) (-2547 (($ $ (-592) (-1280 |#1|)) NIL)) (-2242 (($ $ (-592) (-1280 |#1|)) NIL)) (-4086 (($ |#1| |#1| |#1|) 31)) (-3223 (($ (-790) |#1|) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) NIL (|has| |#1| (-323)))) (-2747 (((-1280 |#1|) $ (-592)) NIL)) (-2666 (($ |#1|) 30)) (-4147 (($ |#1|) 29)) (-3963 (($ |#1|) 28)) (-4175 (((-790) $) NIL (|has| |#1| (-582)))) (-1426 ((|#1| $ (-592) (-592) |#1|) NIL)) (-3959 ((|#1| $ (-592) (-592)) NIL)) (-1794 ((|#1| $) NIL (|has| |#1| (-194)))) (-4004 (((-658 |#1|) $) NIL)) (-3178 (((-790) $) NIL (|has| |#1| (-582)))) (-3555 (((-658 (-1280 |#1|)) $) NIL (|has| |#1| (-582)))) (-4292 (((-790) $) NIL)) (-3242 (($ (-790) (-790) |#1|) NIL)) (-4298 (((-790) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-3781 ((|#1| $) NIL (|has| |#1| (-6 (-4627 "*"))))) (-4577 (((-592) $) NIL)) (-4280 (((-592) $) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1898 (((-592) $) NIL)) (-3005 (((-592) $) NIL)) (-4186 (($ (-658 (-658 |#1|))) 10) (($ (-790) (-790) (-1 |#1| (-592) (-592))) NIL)) (-3987 (($ (-1 |#1| |#1|) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-4601 (((-658 (-658 |#1|)) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3183 (((-3 $ "failed") $) NIL (|has| |#1| (-388)))) (-4220 (($) 11)) (-2083 (($ $ $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1892 (($ $ |#1|) NIL)) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) (-592)) NIL) ((|#1| $ (-592) (-592) |#1|) NIL) (($ $ (-658 (-592)) (-658 (-592))) NIL)) (-2933 (($ (-658 |#1|)) NIL) (($ (-658 $)) NIL)) (-2940 (((-141) $) NIL)) (-1625 ((|#1| $) NIL (|has| |#1| (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-3430 (((-658 (-1280 |#1|)) $) NIL (|has| |#1| (-323)))) (-2000 (((-1280 |#1|) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119))) (($ (-1280 |#1|)) NIL)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-592) $) NIL) (((-1280 |#1|) $ (-1280 |#1|)) 14) (((-1280 |#1|) (-1280 |#1|) $) NIL) (((-971 |#1|) $ (-971 |#1|)) 20)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-241 |#1|) (-13 (-704 |#1| (-1280 |#1|) (-1280 |#1|)) (-10 -8 (-15 * ((-971 |#1|) $ (-971 |#1|))) (-15 -4220 ($)) (-15 -3963 ($ |#1|)) (-15 -4147 ($ |#1|)) (-15 -2666 ($ |#1|)) (-15 -4086 ($ |#1| |#1| |#1|)) (-15 -3399 ($ |#1| |#1| |#1|)))) (-13 (-388) (-1211))) (T -241)) 
+((* (*1 *2 *1 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211))) (-5 *1 (-241 *3)))) (-4220 (*1 *1) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211))))) (-3963 (*1 *1 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211))))) (-4147 (*1 *1 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211))))) (-2666 (*1 *1 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211))))) (-4086 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211))))) (-3399 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211)))))) 
+(-13 (-704 |#1| (-1280 |#1|) (-1280 |#1|)) (-10 -8 (-15 * ((-971 |#1|) $ (-971 |#1|))) (-15 -4220 ($)) (-15 -3963 ($ |#1|)) (-15 -4147 ($ |#1|)) (-15 -2666 ($ |#1|)) (-15 -4086 ($ |#1| |#1| |#1|)) (-15 -3399 ($ |#1| |#1| |#1|)))) 
+((-4125 (($ (-1 (-141) |#2|) $) 17)) (-4065 (($ |#2| $) NIL) (($ (-1 (-141) |#2|) $) 25)) (-1653 (($) NIL) (($ (-658 |#2|)) 11)) (-3255 (((-141) $ $) 23))) 
+(((-242 |#1| |#2|) (-10 -8 (-15 -4125 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4065 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4065 (|#1| |#2| |#1|)) (-15 -1653 (|#1| (-658 |#2|))) (-15 -1653 (|#1|)) (-15 -3255 ((-141) |#1| |#1|))) (-243 |#2|) (-1119)) (T -242)) 
+NIL 
+(-10 -8 (-15 -4125 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4065 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4065 (|#1| |#2| |#1|)) (-15 -1653 (|#1| (-658 |#2|))) (-15 -1653 (|#1|)) (-15 -3255 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-4125 (($ (-1 (-141) |#1|) $) 42 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) 52 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1360 (($ $) 55 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ |#1| $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) 43 (|has| $ (-6 -4625)))) (-4459 (($ |#1| $) 54 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 51 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4625)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 48)) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-1653 (($) 46) (($ (-658 |#1|)) 45)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 47)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-243 |#1|) (-1311) (-1119)) (T -243)) 
+NIL 
+(-13 (-249 |t#1|)) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-249 |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-3644 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-790)) 11) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) 19) (($ $ (-790)) NIL) (($ $) 16)) (-1940 (($ $ (-1 |#2| |#2|)) 12) (($ $ (-1 |#2| |#2|) (-790)) 14) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL) (($ $ (-790)) NIL) (($ $) NIL))) 
+(((-244 |#1| |#2|) (-10 -8 (-15 -3644 (|#1| |#1|)) (-15 -1940 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -1940 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -1940 (|#1| |#1| (-1191))) (-15 -1940 (|#1| |#1| (-658 (-1191)))) (-15 -1940 (|#1| |#1| (-1191) (-790))) (-15 -1940 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -1940 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -1940 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|)))) (-245 |#2|) (-1075)) (T -244)) 
+NIL 
+(-10 -8 (-15 -3644 (|#1| |#1|)) (-15 -1940 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -1940 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -1940 (|#1| |#1| (-1191))) (-15 -1940 (|#1| |#1| (-658 (-1191)))) (-15 -1940 (|#1| |#1| (-1191) (-790))) (-15 -1940 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -1940 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -1940 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3644 (($ $ (-1 |#1| |#1|)) 51) (($ $ (-1 |#1| |#1|) (-790)) 50) (($ $ (-658 (-1191)) (-658 (-790))) 43 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 42 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 41 (|has| |#1| (-922 (-1191)))) (($ $ (-1191)) 40 (|has| |#1| (-922 (-1191)))) (($ $ (-790)) 38 (|has| |#1| (-247))) (($ $) 36 (|has| |#1| (-247)))) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-1 |#1| |#1|)) 49) (($ $ (-1 |#1| |#1|) (-790)) 48) (($ $ (-658 (-1191)) (-658 (-790))) 47 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 46 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 45 (|has| |#1| (-922 (-1191)))) (($ $ (-1191)) 44 (|has| |#1| (-922 (-1191)))) (($ $ (-790)) 39 (|has| |#1| (-247))) (($ $) 37 (|has| |#1| (-247)))) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-245 |#1|) (-1311) (-1075)) (T -245)) 
+((-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-245 *3)) (-4 *3 (-1075)))) (-3644 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-790)) (-4 *1 (-245 *4)) (-4 *4 (-1075)))) (-1940 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-245 *3)) (-4 *3 (-1075)))) (-1940 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-790)) (-4 *1 (-245 *4)) (-4 *4 (-1075))))) 
+(-13 (-1075) (-10 -8 (-15 -3644 ($ $ (-1 |t#1| |t#1|))) (-15 -3644 ($ $ (-1 |t#1| |t#1|) (-790))) (-15 -1940 ($ $ (-1 |t#1| |t#1|))) (-15 -1940 ($ $ (-1 |t#1| |t#1|) (-790))) (IF (|has| |t#1| (-247)) (-6 (-247)) |noBranch|) (IF (|has| |t#1| (-922 (-1191))) (-6 (-922 (-1191))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-247) |has| |#1| (-247)) ((-661 $) . T) ((-743) . T) ((-922 (-1191)) |has| |#1| (-922 (-1191))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-3644 (($ $) NIL) (($ $ (-790)) 10)) (-1940 (($ $) 8) (($ $ (-790)) 12))) 
+(((-246 |#1|) (-10 -8 (-15 -1940 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-790))) (-15 -1940 (|#1| |#1|)) (-15 -3644 (|#1| |#1|))) (-247)) (T -246)) 
+NIL 
+(-10 -8 (-15 -1940 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-790))) (-15 -1940 (|#1| |#1|)) (-15 -3644 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3644 (($ $) 37) (($ $ (-790)) 35)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $) 36) (($ $ (-790)) 34)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-247) (-1311)) (T -247)) 
+((-3644 (*1 *1 *1) (-4 *1 (-247))) (-1940 (*1 *1 *1) (-4 *1 (-247))) (-3644 (*1 *1 *1 *2) (-12 (-4 *1 (-247)) (-5 *2 (-790)))) (-1940 (*1 *1 *1 *2) (-12 (-4 *1 (-247)) (-5 *2 (-790))))) 
+(-13 (-1075) (-10 -8 (-15 -3644 ($ $)) (-15 -1940 ($ $)) (-15 -3644 ($ $ (-790))) (-15 -1940 ($ $ (-790))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1653 (($) 12) (($ (-658 |#2|)) NIL)) (-4599 (($ $) 14)) (-4466 (($ (-658 |#2|)) 10)) (-1683 (((-877) $) 21))) 
+(((-248 |#1| |#2|) (-10 -8 (-15 -1653 (|#1| (-658 |#2|))) (-15 -1653 (|#1|)) (-15 -4466 (|#1| (-658 |#2|))) (-15 -1683 ((-877) |#1|)) (-15 -4599 (|#1| |#1|))) (-249 |#2|) (-1119)) (T -248)) 
+NIL 
+(-10 -8 (-15 -1653 (|#1| (-658 |#2|))) (-15 -1653 (|#1|)) (-15 -4466 (|#1| (-658 |#2|))) (-15 -1683 ((-877) |#1|)) (-15 -4599 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-4125 (($ (-1 (-141) |#1|) $) 42 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) 52 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1360 (($ $) 55 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ |#1| $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) 43 (|has| $ (-6 -4625)))) (-4459 (($ |#1| $) 54 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 51 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4625)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 48)) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-1653 (($) 46) (($ (-658 |#1|)) 45)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 47)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-249 |#1|) (-1311) (-1119)) (T -249)) 
+((-1653 (*1 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1119)))) (-1653 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-249 *3)))) (-4065 (*1 *1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-249 *2)) (-4 *2 (-1119)))) (-4065 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (|has| *1 (-6 -4625)) (-4 *1 (-249 *3)) (-4 *3 (-1119)))) (-4125 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (|has| *1 (-6 -4625)) (-4 *1 (-249 *3)) (-4 *3 (-1119))))) 
+(-13 (-131 |t#1|) (-175 |t#1|) (-10 -8 (-15 -1653 ($)) (-15 -1653 ($ (-658 |t#1|))) (IF (|has| $ (-6 -4625)) (PROGN (-15 -4065 ($ |t#1| $)) (-15 -4065 ($ (-1 (-141) |t#1|) $)) (-15 -4125 ($ (-1 (-141) |t#1|) $))) |noBranch|))) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-2021 (((-2 (|:| |varOrder| (-658 (-1191))) (|:| |inhom| (-3 (-658 (-1280 (-790))) "failed")) (|:| |hom| (-658 (-1280 (-790))))) (-310 (-980 (-592)))) 25))) 
+(((-250) (-10 -7 (-15 -2021 ((-2 (|:| |varOrder| (-658 (-1191))) (|:| |inhom| (-3 (-658 (-1280 (-790))) "failed")) (|:| |hom| (-658 (-1280 (-790))))) (-310 (-980 (-592))))))) (T -250)) 
+((-2021 (*1 *2 *3) (-12 (-5 *3 (-310 (-980 (-592)))) (-5 *2 (-2 (|:| |varOrder| (-658 (-1191))) (|:| |inhom| (-3 (-658 (-1280 (-790))) "failed")) (|:| |hom| (-658 (-1280 (-790)))))) (-5 *1 (-250))))) 
+(-10 -7 (-15 -2021 ((-2 (|:| |varOrder| (-658 (-1191))) (|:| |inhom| (-3 (-658 (-1280 (-790))) "failed")) (|:| |hom| (-658 (-1280 (-790))))) (-310 (-980 (-592)))))) 
+((-1403 (((-790)) 51)) (-3945 (((-2 (|:| -3253 (-706 |#3|)) (|:| |vec| (-1280 |#3|))) (-706 $) (-1280 $)) 49) (((-706 |#3|) (-706 $)) 41) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-706 (-592)) (-706 $)) NIL)) (-1936 (((-160)) 57)) (-3644 (($ $ (-1 |#3| |#3|) (-790)) NIL) (($ $ (-1 |#3| |#3|)) 18) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL) (($ $ (-790)) NIL) (($ $) NIL)) (-1683 (((-1280 |#3|) $) NIL) (($ |#3|) NIL) (((-877) $) NIL) (($ (-592)) 12) (($ (-433 (-592))) NIL)) (-4010 (((-790)) 15)) (-3313 (($ $ |#3|) 54))) 
+(((-251 |#1| |#2| |#3|) (-10 -8 (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|)) (-15 -4010 ((-790))) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -1683 (|#1| |#3|)) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|))) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|) (-790))) (-15 -3945 ((-706 |#3|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#3|)) (|:| |vec| (-1280 |#3|))) (-706 |#1|) (-1280 |#1|))) (-15 -1403 ((-790))) (-15 -3313 (|#1| |#1| |#3|)) (-15 -1936 ((-160))) (-15 -1683 ((-1280 |#3|) |#1|))) (-252 |#2| |#3|) (-790) (-1225)) (T -251)) 
+((-1936 (*1 *2) (-12 (-14 *4 (-790)) (-4 *5 (-1225)) (-5 *2 (-160)) (-5 *1 (-251 *3 *4 *5)) (-4 *3 (-252 *4 *5)))) (-1403 (*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1225)) (-5 *2 (-790)) (-5 *1 (-251 *3 *4 *5)) (-4 *3 (-252 *4 *5)))) (-4010 (*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1225)) (-5 *2 (-790)) (-5 *1 (-251 *3 *4 *5)) (-4 *3 (-252 *4 *5))))) 
+(-10 -8 (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|)) (-15 -4010 ((-790))) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -1683 (|#1| |#3|)) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|))) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|) (-790))) (-15 -3945 ((-706 |#3|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#3|)) (|:| |vec| (-1280 |#3|))) (-706 |#1|) (-1280 |#1|))) (-15 -1403 ((-790))) (-15 -3313 (|#1| |#1| |#3|)) (-15 -1936 ((-160))) (-15 -1683 ((-1280 |#3|) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#2| (-1119)))) (-2272 (((-141) $) 67 (|has| |#2| (-158)))) (-2673 (($ (-944)) 123 (|has| |#2| (-1075)))) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-4079 (($ $ $) 119 (|has| |#2| (-815)))) (-2350 (((-3 $ "failed") $ $) 69 (|has| |#2| (-158)))) (-2126 (((-141) $ (-790)) 8)) (-1403 (((-790)) 104 (|has| |#2| (-394)))) (-3940 (((-592) $) 117 (|has| |#2| (-867)))) (-3932 ((|#2| $ (-592) |#2|) 49 (|has| $ (-6 -4626)))) (-3001 (($) 7 T CONST)) (-4368 (((-3 (-592) "failed") $) 62 (-1732 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119)))) (((-3 (-433 (-592)) "failed") $) 59 (-1732 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) (((-3 |#2| "failed") $) 56 (|has| |#2| (-1119)))) (-2400 (((-592) $) 63 (-1732 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119)))) (((-433 (-592)) $) 60 (-1732 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) ((|#2| $) 55 (|has| |#2| (-1119)))) (-3945 (((-706 (-592)) (-706 $)) 103 (-1732 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 102 (-1732 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) 101 (|has| |#2| (-1075))) (((-706 |#2|) (-706 $)) 100 (|has| |#2| (-1075)))) (-3371 (((-3 $ "failed") $) 75 (|has| |#2| (-743)))) (-4290 (($) 107 (|has| |#2| (-394)))) (-1426 ((|#2| $ (-592) |#2|) 50 (|has| $ (-6 -4626)))) (-3959 ((|#2| $ (-592)) 48)) (-1691 (((-141) $) 115 (|has| |#2| (-867)))) (-4004 (((-658 |#2|) $) 30 (|has| $ (-6 -4625)))) (-3558 (((-141) $) 78 (|has| |#2| (-743)))) (-1324 (((-141) $) 116 (|has| |#2| (-867)))) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-1837 (($ $ $) 114 (-3836 (|has| |#2| (-867)) (|has| |#2| (-815))))) (-4467 (((-658 |#2|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#2| $) 27 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3319 (($ $ $) 113 (-3836 (|has| |#2| (-867)) (|has| |#2| (-815))))) (-3987 (($ (-1 |#2| |#2|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#2| |#2|) $) 35)) (-3546 (((-944) $) 106 (|has| |#2| (-394)))) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#2| (-1119)))) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-1825 (($ (-944)) 105 (|has| |#2| (-394)))) (-2951 (((-1137) $) 21 (|has| |#2| (-1119)))) (-1918 ((|#2| $) 39 (|has| (-592) (-869)))) (-1892 (($ $ |#2|) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#2|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#2|))) 26 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) 25 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) 24 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) 23 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) 14)) (-1405 (((-658 $)) 108 (|has| |#2| (-394)))) (-2254 (((-141) |#2| $) 42 (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#2| $ (-592) |#2|) 47) ((|#2| $ (-592)) 46)) (-1729 ((|#2| $ $) 122 (|has| |#2| (-1075)))) (-4512 (($ (-1280 |#2|)) 124)) (-1936 (((-160)) 121 (|has| |#2| (-388)))) (-3644 (($ $) 95 (-1732 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-790)) 93 (-1732 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-1191)) 91 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191))) 90 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1191) (-790)) 89 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) 88 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1 |#2| |#2|) (-790)) 81 (|has| |#2| (-1075))) (($ $ (-1 |#2| |#2|)) 80 (|has| |#2| (-1075)))) (-3452 (((-790) (-1 (-141) |#2|) $) 31 (|has| $ (-6 -4625))) (((-790) |#2| $) 28 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-1280 |#2|) $) 125) (((-877) $) 20 (|has| |#2| (-1119))) (($ (-592)) 61 (-3836 (-1732 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119))) (|has| |#2| (-1075)))) (($ (-433 (-592))) 58 (-1732 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) (($ |#2|) 57 (|has| |#2| (-1119)))) (-4010 (((-790)) 99 (|has| |#2| (-1075)))) (-3369 (((-141) (-1 (-141) |#2|) $) 33 (|has| $ (-6 -4625)))) (-1392 (($ $) 118 (|has| |#2| (-867)))) (-1424 (($ $ (-790)) 76 (|has| |#2| (-743))) (($ $ (-944)) 72 (|has| |#2| (-743)))) (-3514 (($) 66 (|has| |#2| (-158)) CONST)) (-4257 (($) 79 (|has| |#2| (-743)) CONST)) (-1940 (($ $) 94 (-1732 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-790)) 92 (-1732 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-1191)) 87 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191))) 86 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1191) (-790)) 85 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) 84 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1 |#2| |#2|) (-790)) 83 (|has| |#2| (-1075))) (($ $ (-1 |#2| |#2|)) 82 (|has| |#2| (-1075)))) (-3286 (((-141) $ $) 111 (-3836 (|has| |#2| (-867)) (|has| |#2| (-815))))) (-3273 (((-141) $ $) 110 (-3836 (|has| |#2| (-867)) (|has| |#2| (-815))))) (-3255 (((-141) $ $) 19 (|has| |#2| (-1119)))) (-3279 (((-141) $ $) 112 (-3836 (|has| |#2| (-867)) (|has| |#2| (-815))))) (-3266 (((-141) $ $) 109 (-3836 (|has| |#2| (-867)) (|has| |#2| (-815))))) (-3313 (($ $ |#2|) 120 (|has| |#2| (-388)))) (-3306 (($ $ $) 97 (|has| |#2| (-1075))) (($ $) 96 (|has| |#2| (-1075)))) (-3300 (($ $ $) 64 (|has| |#2| (-25)))) (** (($ $ (-790)) 77 (|has| |#2| (-743))) (($ $ (-944)) 73 (|has| |#2| (-743)))) (* (($ (-592) $) 98 (|has| |#2| (-1075))) (($ $ $) 74 (|has| |#2| (-743))) (($ $ |#2|) 71 (|has| |#2| (-743))) (($ |#2| $) 70 (|has| |#2| (-743))) (($ (-790) $) 68 (|has| |#2| (-158))) (($ (-944) $) 65 (|has| |#2| (-25)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-252 |#1| |#2|) (-1311) (-790) (-1225)) (T -252)) 
+((-4512 (*1 *1 *2) (-12 (-5 *2 (-1280 *4)) (-4 *4 (-1225)) (-4 *1 (-252 *3 *4)))) (-2673 (*1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-252 *3 *4)) (-4 *4 (-1075)) (-4 *4 (-1225)))) (-1729 (*1 *2 *1 *1) (-12 (-4 *1 (-252 *3 *2)) (-4 *2 (-1225)) (-4 *2 (-1075)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-252 *3 *2)) (-4 *2 (-1225)) (-4 *2 (-743)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-252 *3 *2)) (-4 *2 (-1225)) (-4 *2 (-743))))) 
+(-13 (-625 (-592) |t#2|) (-632 (-1280 |t#2|)) (-10 -8 (-6 -4625) (-15 -4512 ($ (-1280 |t#2|))) (IF (|has| |t#2| (-1119)) (-6 (-437 |t#2|)) |noBranch|) (IF (|has| |t#2| (-1075)) (PROGN (-6 (-140 |t#2| |t#2|)) (-6 (-245 |t#2|)) (-6 (-403 |t#2|)) (-15 -2673 ($ (-944))) (-15 -1729 (|t#2| $ $))) |noBranch|) (IF (|has| |t#2| (-25)) (-6 (-25)) |noBranch|) (IF (|has| |t#2| (-158)) (-6 (-158)) |noBranch|) (IF (|has| |t#2| (-743)) (PROGN (-6 (-743)) (-15 * ($ |t#2| $)) (-15 * ($ $ |t#2|))) |noBranch|) (IF (|has| |t#2| (-394)) (-6 (-394)) |noBranch|) (IF (|has| |t#2| (-194)) (PROGN (-6 (-43 |t#2|)) (-6 (-194))) |noBranch|) (IF (|has| |t#2| (-6 -4622)) (-6 -4622) |noBranch|) (IF (|has| |t#2| (-867)) (-6 (-867)) |noBranch|) (IF (|has| |t#2| (-815)) (-6 (-815)) |noBranch|) (IF (|has| |t#2| (-388)) (-6 (-1287 |t#2|)) |noBranch|))) 
+(((-21) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-388)) (|has| |#2| (-194))) ((-23) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-815)) (|has| |#2| (-388)) (|has| |#2| (-194)) (|has| |#2| (-158))) ((-25) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-815)) (|has| |#2| (-388)) (|has| |#2| (-194)) (|has| |#2| (-158)) (|has| |#2| (-25))) ((-39) . T) ((-43 |#2|) |has| |#2| (-194)) ((-125) -3836 (|has| |#2| (-1119)) (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-815)) (|has| |#2| (-743)) (|has| |#2| (-394)) (|has| |#2| (-388)) (|has| |#2| (-194)) (|has| |#2| (-158)) (|has| |#2| (-25))) ((-140 |#2| |#2|) -3836 (|has| |#2| (-1075)) (|has| |#2| (-388)) (|has| |#2| (-194))) ((-140 $ $) |has| |#2| (-194)) ((-158) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-815)) (|has| |#2| (-388)) (|has| |#2| (-194)) (|has| |#2| (-158))) ((-632 (-877)) -3836 (|has| |#2| (-1119)) (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-815)) (|has| |#2| (-743)) (|has| |#2| (-394)) (|has| |#2| (-388)) (|has| |#2| (-194)) (|has| |#2| (-158)) (|has| |#2| (-25))) ((-632 (-1280 |#2|)) . T) ((-194) |has| |#2| (-194)) ((-245 |#2|) |has| |#2| (-1075)) ((-247) -12 (|has| |#2| (-247)) (|has| |#2| (-1075))) ((-303 (-592) |#2|) . T) ((-305 (-592) |#2|) . T) ((-325 |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-394) |has| |#2| (-394)) ((-403 |#2|) |has| |#2| (-1075)) ((-437 |#2|) |has| |#2| (-1119)) ((-523 |#2|) . T) ((-625 (-592) |#2|) . T) ((-547 |#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-661 |#2|) -3836 (|has| |#2| (-1075)) (|has| |#2| (-388)) (|has| |#2| (-194))) ((-661 $) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-194))) ((-654 (-592)) -12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075))) ((-654 |#2|) |has| |#2| (-1075)) ((-734 |#2|) -3836 (|has| |#2| (-388)) (|has| |#2| (-194))) ((-743) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-743)) (|has| |#2| (-194))) ((-813) |has| |#2| (-867)) ((-814) -3836 (|has| |#2| (-867)) (|has| |#2| (-815))) ((-815) |has| |#2| (-815)) ((-816) -3836 (|has| |#2| (-867)) (|has| |#2| (-815))) ((-817) -3836 (|has| |#2| (-867)) (|has| |#2| (-815))) ((-867) |has| |#2| (-867)) ((-869) -3836 (|has| |#2| (-867)) (|has| |#2| (-815))) ((-922 (-1191)) -12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075))) ((-1065 (-433 (-592))) -12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119))) ((-1065 (-592)) -12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119))) ((-1065 |#2|) |has| |#2| (-1119)) ((-1081 |#2|) -3836 (|has| |#2| (-1075)) (|has| |#2| (-388)) (|has| |#2| (-194))) ((-1081 $) |has| |#2| (-194)) ((-1075) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-194))) ((-1082) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-194))) ((-1131) -3836 (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-743)) (|has| |#2| (-194))) ((-1119) -3836 (|has| |#2| (-1119)) (|has| |#2| (-1075)) (|has| |#2| (-867)) (|has| |#2| (-815)) (|has| |#2| (-743)) (|has| |#2| (-394)) (|has| |#2| (-388)) (|has| |#2| (-194)) (|has| |#2| (-158)) (|has| |#2| (-25))) ((-1225) . T) ((-1287 |#2|) |has| |#2| (-388))) 
+((-1779 (((-254 |#1| |#3|) (-1 |#3| |#2| |#3|) (-254 |#1| |#2|) |#3|) 21)) (-3657 ((|#3| (-1 |#3| |#2| |#3|) (-254 |#1| |#2|) |#3|) 23)) (-2731 (((-254 |#1| |#3|) (-1 |#3| |#2|) (-254 |#1| |#2|)) 18))) 
+(((-253 |#1| |#2| |#3|) (-10 -7 (-15 -1779 ((-254 |#1| |#3|) (-1 |#3| |#2| |#3|) (-254 |#1| |#2|) |#3|)) (-15 -3657 (|#3| (-1 |#3| |#2| |#3|) (-254 |#1| |#2|) |#3|)) (-15 -2731 ((-254 |#1| |#3|) (-1 |#3| |#2|) (-254 |#1| |#2|)))) (-790) (-1225) (-1225)) (T -253)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-254 *5 *6)) (-14 *5 (-790)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-5 *2 (-254 *5 *7)) (-5 *1 (-253 *5 *6 *7)))) (-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *6 *2)) (-5 *4 (-254 *5 *6)) (-14 *5 (-790)) (-4 *6 (-1225)) (-4 *2 (-1225)) (-5 *1 (-253 *5 *6 *2)))) (-1779 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *7 *5)) (-5 *4 (-254 *6 *7)) (-14 *6 (-790)) (-4 *7 (-1225)) (-4 *5 (-1225)) (-5 *2 (-254 *6 *5)) (-5 *1 (-253 *6 *7 *5))))) 
+(-10 -7 (-15 -1779 ((-254 |#1| |#3|) (-1 |#3| |#2| |#3|) (-254 |#1| |#2|) |#3|)) (-15 -3657 (|#3| (-1 |#3| |#2| |#3|) (-254 |#1| |#2|) |#3|)) (-15 -2731 ((-254 |#1| |#3|) (-1 |#3| |#2|) (-254 |#1| |#2|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#2| (-1119)))) (-2272 (((-141) $) NIL (|has| |#2| (-158)))) (-2673 (($ (-944)) 56 (|has| |#2| (-1075)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4079 (($ $ $) 60 (|has| |#2| (-815)))) (-2350 (((-3 $ "failed") $ $) 49 (|has| |#2| (-158)))) (-2126 (((-141) $ (-790)) 17)) (-1403 (((-790)) NIL (|has| |#2| (-394)))) (-3940 (((-592) $) NIL (|has| |#2| (-867)))) (-3932 ((|#2| $ (-592) |#2|) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) (((-3 |#2| "failed") $) 29 (|has| |#2| (-1119)))) (-2400 (((-592) $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119)))) (((-433 (-592)) $) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) ((|#2| $) 27 (|has| |#2| (-1119)))) (-3945 (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL (|has| |#2| (-1075))) (((-706 |#2|) (-706 $)) NIL (|has| |#2| (-1075)))) (-3371 (((-3 $ "failed") $) 53 (|has| |#2| (-743)))) (-4290 (($) NIL (|has| |#2| (-394)))) (-1426 ((|#2| $ (-592) |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ (-592)) 51)) (-1691 (((-141) $) NIL (|has| |#2| (-867)))) (-4004 (((-658 |#2|) $) 15 (|has| $ (-6 -4625)))) (-3558 (((-141) $) NIL (|has| |#2| (-743)))) (-1324 (((-141) $) NIL (|has| |#2| (-867)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 20 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-4467 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 (((-592) $) 50 (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3987 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#2| |#2|) $) 41)) (-3546 (((-944) $) NIL (|has| |#2| (-394)))) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#2| (-1119)))) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-1825 (($ (-944)) NIL (|has| |#2| (-394)))) (-2951 (((-1137) $) NIL (|has| |#2| (-1119)))) (-1918 ((|#2| $) NIL (|has| (-592) (-869)))) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#2|) $) 24 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1405 (((-658 $)) NIL (|has| |#2| (-394)))) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ (-592) |#2|) NIL) ((|#2| $ (-592)) 21)) (-1729 ((|#2| $ $) NIL (|has| |#2| (-1075)))) (-4512 (($ (-1280 |#2|)) 18)) (-1936 (((-160)) NIL (|has| |#2| (-388)))) (-3644 (($ $) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1 |#2| |#2|) (-790)) NIL (|has| |#2| (-1075))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1075)))) (-3452 (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-1280 |#2|) $) 10) (((-877) $) NIL (|has| |#2| (-1119))) (($ (-592)) NIL (-3836 (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119))) (|has| |#2| (-1075)))) (($ (-433 (-592))) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) (($ |#2|) 13 (|has| |#2| (-1119)))) (-4010 (((-790)) NIL (|has| |#2| (-1075)))) (-3369 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-1392 (($ $) NIL (|has| |#2| (-867)))) (-1424 (($ $ (-790)) NIL (|has| |#2| (-743))) (($ $ (-944)) NIL (|has| |#2| (-743)))) (-3514 (($) 35 (|has| |#2| (-158)) CONST)) (-4257 (($) 38 (|has| |#2| (-743)) CONST)) (-1940 (($ $) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1 |#2| |#2|) (-790)) NIL (|has| |#2| (-1075))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1075)))) (-3286 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3273 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3255 (((-141) $ $) 26 (|has| |#2| (-1119)))) (-3279 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3266 (((-141) $ $) 58 (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $ $) NIL (|has| |#2| (-1075))) (($ $) NIL (|has| |#2| (-1075)))) (-3300 (($ $ $) 33 (|has| |#2| (-25)))) (** (($ $ (-790)) NIL (|has| |#2| (-743))) (($ $ (-944)) NIL (|has| |#2| (-743)))) (* (($ (-592) $) NIL (|has| |#2| (-1075))) (($ $ $) 44 (|has| |#2| (-743))) (($ $ |#2|) 42 (|has| |#2| (-743))) (($ |#2| $) 43 (|has| |#2| (-743))) (($ (-790) $) NIL (|has| |#2| (-158))) (($ (-944) $) NIL (|has| |#2| (-25)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-254 |#1| |#2|) (-252 |#1| |#2|) (-790) (-1225)) (T -254)) 
+NIL 
+(-252 |#1| |#2|) 
+((-1641 (((-141) $ $) NIL)) (-2032 (($) 34 T CONST)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-194)))) (-1555 (($ $) NIL (|has| |#1| (-194)))) (-1313 (((-141) $) 54 (|has| |#1| (-194)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) 55)) (-3558 (((-141) $) NIL)) (-1454 (((-141) $ (-944)) 71)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-194)))) (-3927 ((|#1| $ (-944)) 9)) (-1683 (((-877) $) 29) (($ (-592)) NIL) (($ (-1 |#1| (-944))) 12) (((-1 |#1| (-944)) $) 11) (($ (-1171 |#1|)) 26) (((-1171 |#1|) $) 24) (($ |#1|) NIL (|has| |#1| (-194))) (($ $) NIL (|has| |#1| (-194)))) (-4010 (((-790)) NIL)) (-2537 (((-141) $ $) NIL (|has| |#1| (-194)))) (-3114 (((-141) $ (-944)) 72)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 33 T CONST)) (-4257 (($) 13 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) 38) (($ $ $) NIL)) (-3300 (($ $ $) 36)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 40) (($ $ $) 51) (($ |#1| $) 42 (|has| |#1| (-194))) (($ $ |#1|) NIL (|has| |#1| (-194))))) 
+(((-255 |#1|) (-13 (-1075) (-303 (-944) |#1|) (-10 -8 (IF (|has| |#1| (-194)) (-6 (-582)) |noBranch|) (IF (|has| |#1| (-194)) (-6 (-43 |#1|)) |noBranch|) (-15 -1683 ($ (-1 |#1| (-944)))) (-15 -1683 ((-1 |#1| (-944)) $)) (-15 -1683 ($ (-1171 |#1|))) (-15 -1683 ((-1171 |#1|) $)) (-15 -2032 ($) -4249) (-15 -1454 ((-141) $ (-944))) (-15 -3114 ((-141) $ (-944))))) (-1075)) (T -255)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1 *3 (-944))) (-4 *3 (-1075)) (-5 *1 (-255 *3)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1 *3 (-944))) (-5 *1 (-255 *3)) (-4 *3 (-1075)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-255 *3)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-255 *3)) (-4 *3 (-1075)))) (-2032 (*1 *1) (-12 (-5 *1 (-255 *2)) (-4 *2 (-1075)))) (-1454 (*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-5 *2 (-141)) (-5 *1 (-255 *4)) (-4 *4 (-1075)))) (-3114 (*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-5 *2 (-141)) (-5 *1 (-255 *4)) (-4 *4 (-1075))))) 
+(-13 (-1075) (-303 (-944) |#1|) (-10 -8 (IF (|has| |#1| (-194)) (-6 (-582)) |noBranch|) (IF (|has| |#1| (-194)) (-6 (-43 |#1|)) |noBranch|) (-15 -1683 ($ (-1 |#1| (-944)))) (-15 -1683 ((-1 |#1| (-944)) $)) (-15 -1683 ($ (-1171 |#1|))) (-15 -1683 ((-1171 |#1|) $)) (-15 -2032 ($) -4249) (-15 -1454 ((-141) $ (-944))) (-15 -3114 ((-141) $ (-944))))) 
+((-3134 (((-592) (-658 (-1173))) 24) (((-592) (-1173)) 19)) (-4433 (((-1285) (-658 (-1173))) 29) (((-1285) (-1173)) 28)) (-3167 (((-1173)) 14)) (-3450 (((-1173) (-592) (-1173)) 16)) (-2838 (((-658 (-1173)) (-658 (-1173)) (-592) (-1173)) 25) (((-1173) (-1173) (-592) (-1173)) 23)) (-3074 (((-658 (-1173)) (-658 (-1173))) 13) (((-658 (-1173)) (-1173)) 11))) 
+(((-256) (-10 -7 (-15 -3074 ((-658 (-1173)) (-1173))) (-15 -3074 ((-658 (-1173)) (-658 (-1173)))) (-15 -3167 ((-1173))) (-15 -3450 ((-1173) (-592) (-1173))) (-15 -2838 ((-1173) (-1173) (-592) (-1173))) (-15 -2838 ((-658 (-1173)) (-658 (-1173)) (-592) (-1173))) (-15 -4433 ((-1285) (-1173))) (-15 -4433 ((-1285) (-658 (-1173)))) (-15 -3134 ((-592) (-1173))) (-15 -3134 ((-592) (-658 (-1173)))))) (T -256)) 
+((-3134 (*1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-592)) (-5 *1 (-256)))) (-3134 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-592)) (-5 *1 (-256)))) (-4433 (*1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-1285)) (-5 *1 (-256)))) (-4433 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-256)))) (-2838 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-658 (-1173))) (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *1 (-256)))) (-2838 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-1173)) (-5 *3 (-592)) (-5 *1 (-256)))) (-3450 (*1 *2 *3 *2) (-12 (-5 *2 (-1173)) (-5 *3 (-592)) (-5 *1 (-256)))) (-3167 (*1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-256)))) (-3074 (*1 *2 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-256)))) (-3074 (*1 *2 *3) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-256)) (-5 *3 (-1173))))) 
+(-10 -7 (-15 -3074 ((-658 (-1173)) (-1173))) (-15 -3074 ((-658 (-1173)) (-658 (-1173)))) (-15 -3167 ((-1173))) (-15 -3450 ((-1173) (-592) (-1173))) (-15 -2838 ((-1173) (-1173) (-592) (-1173))) (-15 -2838 ((-658 (-1173)) (-658 (-1173)) (-592) (-1173))) (-15 -4433 ((-1285) (-1173))) (-15 -4433 ((-1285) (-658 (-1173)))) (-15 -3134 ((-592) (-1173))) (-15 -3134 ((-592) (-658 (-1173))))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2982 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-592)))) $) 44)) (-2246 (((-658 |#1|) $) 30)) (-2557 (((-658 |#1|) $) 29)) (-1854 (((-658 |#1|) $) 31)) (-2350 (((-3 $ "failed") $ $) 18)) (-1356 (((-658 $) $) 36)) (-1403 (((-790) $) 43)) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 39)) (-2400 ((|#1| $) 40)) (-4449 ((|#1| $ (-592)) 46)) (-2077 (((-592) $ (-592)) 45)) (-3401 (($ (-1 |#1| |#1|) $) 49)) (-3271 (($ (-1 (-592) (-592)) $) 48)) (-2685 (((-1173) $) 9)) (-3008 (($ $) 26)) (-1619 (($ $ $) 50 (|has| (-592) (-814)))) (-2951 (((-1137) $) 10)) (-2927 (((-141) $) 32)) (-3841 (($ $) 28)) (-2905 (($ $) 27)) (-4525 (((-592) $) 37)) (-2266 (($ $ $) 33)) (-2507 (($ $) 34)) (-1683 (((-877) $) 11) (($ |#1|) 38)) (-1937 (((-592) |#1| $) 47)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 35)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13) (($ |#1| $) 41)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ (-592)) 52) (($ (-592) $) 51) (($ (-592) |#1|) 42))) 
+(((-257 |#1|) (-1311) (-1119)) (T -257)) 
+((-4525 (*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-592)))) (-1356 (*1 *2 *1) (-12 (-4 *3 (-1119)) (-5 *2 (-658 *1)) (-4 *1 (-257 *3)))) (-3279 (*1 *2 *1 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-141)))) (-2507 (*1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119)))) (-2266 (*1 *1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119)))) (-2927 (*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-141)))) (-1854 (*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-658 *3)))) (-2246 (*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-658 *3)))) (-2557 (*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-658 *3)))) (-3841 (*1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119)))) (-2905 (*1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119)))) (-3008 (*1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119))))) 
+(-13 (-21) (-734 (-592)) (-342 |t#1| (-592)) (-10 -8 (-15 -4525 ((-592) $)) (-15 -1356 ((-658 $) $)) (-15 -3279 ((-141) $ $)) (-15 -2507 ($ $)) (-15 -2266 ($ $ $)) (-15 -2927 ((-141) $)) (-15 -1854 ((-658 |t#1|) $)) (-15 -2246 ((-658 |t#1|) $)) (-15 -2557 ((-658 |t#1|) $)) (-15 -3841 ($ $)) (-15 -2905 ($ $)) (-15 -3008 ($ $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 (-592) (-592)) . T) ((-158) . T) ((-632 (-877)) . T) ((-342 |#1| (-592)) . T) ((-661 (-592)) . T) ((-734 (-592)) . T) ((-1065 |#1|) . T) ((-1081 (-592)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 17)) (-2982 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-592)))) $) 30)) (-2246 (((-658 |#1|) $) 36)) (-2557 (((-658 |#1|) $) 37)) (-1854 (((-658 |#1|) $) 35)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1356 (((-658 $) $) 29)) (-1403 (((-790) $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-4593 (($ $) 24)) (-4449 ((|#1| $ (-592)) NIL)) (-2077 (((-592) $ (-592)) NIL)) (-3401 (($ (-1 |#1| |#1|) $) NIL)) (-3271 (($ (-1 (-592) (-592)) $) NIL)) (-2685 (((-1173) $) NIL)) (-3008 (($ $) 8)) (-1619 (($ $ $) NIL (|has| (-592) (-814)))) (-3296 (((-2 (|:| |gen| |#1|) (|:| -1430 (-592))) $) 26)) (-2951 (((-1137) $) NIL)) (-2927 (((-141) $) 50)) (-3841 (($ $) 38)) (-2905 (($ $) 39)) (-4525 (((-592) $) 58)) (-2266 (($ $ $) 44)) (-2507 (($ $) 33)) (-1683 (((-877) $) 22) (($ |#1|) 27)) (-1937 (((-592) |#1| $) 32)) (-3514 (($) 23 T CONST)) (-3255 (((-141) $ $) 40)) (-3279 (((-141) $ $) 51)) (-3306 (($ $) 48) (($ $ $) 47)) (-3300 (($ $ $) 45) (($ |#1| $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 49) (($ $ (-592)) NIL) (($ (-592) $) 49) (($ (-592) |#1|) NIL))) 
+(((-258 |#1|) (-13 (-257 |#1|) (-10 -8 (-15 -3296 ((-2 (|:| |gen| |#1|) (|:| -1430 (-592))) $)) (-15 -4593 ($ $)))) (-1117)) (T -258)) 
+((-3296 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |gen| *3) (|:| -1430 (-592)))) (-5 *1 (-258 *3)) (-4 *3 (-1117)))) (-4593 (*1 *1 *1) (-12 (-5 *1 (-258 *2)) (-4 *2 (-1117))))) 
+(-13 (-257 |#1|) (-10 -8 (-15 -3296 ((-2 (|:| |gen| |#1|) (|:| -1430 (-592))) $)) (-15 -4593 ($ $)))) 
+((-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 9)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 18)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ (-433 (-592)) $) 25) (($ $ (-433 (-592))) NIL))) 
+(((-259 |#1|) (-10 -8 (-15 -1424 (|#1| |#1| (-592))) (-15 ** (|#1| |#1| (-592))) (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 ** (|#1| |#1| (-790))) (-15 -1424 (|#1| |#1| (-790))) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-944))) (-15 -1424 (|#1| |#1| (-944))) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) (-260)) (T -259)) 
+NIL 
+(-10 -8 (-15 -1424 (|#1| |#1| (-592))) (-15 ** (|#1| |#1| (-592))) (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 ** (|#1| |#1| (-790))) (-15 -1424 (|#1| |#1| (-790))) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-944))) (-15 -1424 (|#1| |#1| (-944))) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 38)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 43)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 39)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 40)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ (-433 (-592)) $) 42) (($ $ (-433 (-592))) 41))) 
+(((-260) (-1311)) (T -260)) 
+((** (*1 *1 *1 *2) (-12 (-4 *1 (-260)) (-5 *2 (-592)))) (-1424 (*1 *1 *1 *2) (-12 (-4 *1 (-260)) (-5 *2 (-592)))) (-4552 (*1 *1 *1) (-4 *1 (-260)))) 
+(-13 (-307) (-43 (-433 (-592))) (-10 -8 (-15 ** ($ $ (-592))) (-15 -1424 ($ $ (-592))) (-15 -4552 ($ $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-307) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-734 (-433 (-592))) . T) ((-743) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-3188 (($ $) 54)) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-2134 (($ $ $) 50 (|has| $ (-6 -4626)))) (-1756 (($ $ $) 49 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-3001 (($) 7 T CONST)) (-3690 (($ $) 53)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-3314 (($ $) 52)) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4255 ((|#1| $) 56)) (-3296 (($ $) 55)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44)) (-2920 (((-592) $ $) 41)) (-3228 (((-141) $) 43)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-3619 (($ $ $) 51 (|has| $ (-6 -4626)))) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-261 |#1|) (-1311) (-1225)) (T -261)) 
+((-4255 (*1 *2 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225)))) (-3296 (*1 *1 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225)))) (-3188 (*1 *1 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225)))) (-3690 (*1 *1 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225)))) (-3314 (*1 *1 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225)))) (-3619 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-261 *2)) (-4 *2 (-1225)))) (-2134 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-261 *2)) (-4 *2 (-1225)))) (-1756 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-261 *2)) (-4 *2 (-1225))))) 
+(-13 (-1038 |t#1|) (-10 -8 (-15 -4255 (|t#1| $)) (-15 -3296 ($ $)) (-15 -3188 ($ $)) (-15 -3690 ($ $)) (-15 -3314 ($ $)) (IF (|has| $ (-6 -4626)) (PROGN (-15 -3619 ($ $ $)) (-15 -2134 ($ $ $)) (-15 -1756 ($ $ $))) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1038 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) NIL)) (-1915 ((|#1| $) NIL)) (-3188 (($ $) NIL)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) $) NIL (|has| |#1| (-869))) (((-141) (-1 (-141) |#1| |#1|) $) NIL)) (-2831 (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869)))) (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-3960 (($ $) 10 (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-3153 (($ $ $) NIL (|has| $ (-6 -4626)))) (-4496 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-2101 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ "first" |#1|) NIL (|has| $ (-6 -4626))) (($ $ "rest" $) NIL (|has| $ (-6 -4626))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-4125 (($ (-1 (-141) |#1|) $) NIL)) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-1765 ((|#1| $) NIL)) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1366 (($ $) NIL) (($ $ (-790)) NIL)) (-1461 (($ $) NIL (|has| |#1| (-1119)))) (-1360 (($ $) 7 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4065 (($ |#1| $) NIL (|has| |#1| (-1119))) (($ (-1 (-141) |#1|) $) NIL)) (-4459 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-3868 (((-141) $) NIL)) (-1721 (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119))) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) (-1 (-141) |#1|) $) NIL)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3242 (($ (-790) |#1|) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-2713 (($ $ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) NIL)) (-4491 (($ $ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1333 (($ |#1|) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4255 ((|#1| $) NIL) (($ $ (-790)) NIL)) (-2113 (($ $ $ (-592)) NIL) (($ |#1| $ (-592)) NIL)) (-3666 (($ $ $ (-592)) NIL) (($ |#1| $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) NIL) (($ $ (-790)) NIL)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-2955 (((-141) $) NIL)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1246 (-592))) NIL) ((|#1| $ (-592)) NIL) ((|#1| $ (-592) |#1|) NIL) (($ $ "unique") 9) (($ $ "sort") 12) (((-790) $ "count") 16)) (-2920 (((-592) $ $) NIL)) (-4113 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-3208 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-1901 (($ (-658 |#1|)) 22)) (-3228 (((-141) $) NIL)) (-2399 (($ $) NIL)) (-1337 (($ $) NIL (|has| $ (-6 -4626)))) (-3318 (((-790) $) NIL)) (-3184 (($ $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-3619 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2266 (($ $ $) NIL) (($ |#1| $) NIL) (($ (-658 $)) NIL) (($ $ |#1|) NIL)) (-1683 (($ (-658 |#1|)) 17) (((-658 |#1|) $) 18) (((-877) $) 21 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-1699 (((-790) $) 14 (|has| $ (-6 -4625))))) 
+(((-262 |#1|) (-13 (-683 |#1|) (-10 -8 (-15 -1683 ($ (-658 |#1|))) (-15 -1683 ((-658 |#1|) $)) (-15 -1901 ($ (-658 |#1|))) (-15 -3927 ($ $ "unique")) (-15 -3927 ($ $ "sort")) (-15 -3927 ((-790) $ "count")))) (-869)) (T -262)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-262 *3)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-262 *3)) (-4 *3 (-869)))) (-1901 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-262 *3)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 "unique") (-5 *1 (-262 *3)) (-4 *3 (-869)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 "sort") (-5 *1 (-262 *3)) (-4 *3 (-869)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 "count") (-5 *2 (-790)) (-5 *1 (-262 *4)) (-4 *4 (-869))))) 
+(-13 (-683 |#1|) (-10 -8 (-15 -1683 ($ (-658 |#1|))) (-15 -1683 ((-658 |#1|) $)) (-15 -1901 ($ (-658 |#1|))) (-15 -3927 ($ $ "unique")) (-15 -3927 ($ $ "sort")) (-15 -3927 ((-790) $ "count")))) 
+((-2901 (((-3 (-790) "failed") |#1| |#1| (-790)) 26))) 
+(((-263 |#1|) (-10 -7 (-15 -2901 ((-3 (-790) "failed") |#1| |#1| (-790)))) (-13 (-743) (-394) (-10 -7 (-15 ** (|#1| |#1| (-592)))))) (T -263)) 
+((-2901 (*1 *2 *3 *3 *2) (|partial| -12 (-5 *2 (-790)) (-4 *3 (-13 (-743) (-394) (-10 -7 (-15 ** (*3 *3 (-592)))))) (-5 *1 (-263 *3))))) 
+(-10 -7 (-15 -2901 ((-3 (-790) "failed") |#1| |#1| (-790)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-879 |#1|)) $) NIL)) (-4492 (((-1187 $) $ (-879 |#1|)) NIL) (((-1187 |#2|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#2| (-582)))) (-1555 (($ $) NIL (|has| |#2| (-582)))) (-1313 (((-141) $) NIL (|has| |#2| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-879 |#1|))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3743 (($ $) NIL (|has| |#2| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#2| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-879 |#1|) "failed") $) NIL)) (-2400 ((|#2| $) NIL) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-879 |#1|) $) NIL)) (-1544 (($ $ $ (-879 |#1|)) NIL (|has| |#2| (-194)))) (-4377 (($ $ (-658 (-592))) NIL)) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#2| (-477))) (($ $ (-879 |#1|)) NIL (|has| |#2| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#2| (-931)))) (-4209 (($ $ |#2| (-254 (-1699 |#1|) (-790)) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-879 |#1|) (-908 (-405))) (|has| |#2| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-879 |#1|) (-908 (-592))) (|has| |#2| (-908 (-592)))))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-4533 (($ (-1187 |#2|) (-879 |#1|)) NIL) (($ (-1187 $) (-879 |#1|)) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#2| (-254 (-1699 |#1|) (-790))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-879 |#1|)) NIL)) (-4206 (((-254 (-1699 |#1|) (-790)) $) NIL) (((-790) $ (-879 |#1|)) NIL) (((-658 (-790)) $ (-658 (-879 |#1|))) NIL)) (-1837 (($ $ $) NIL (|has| |#2| (-869)))) (-3319 (($ $ $) NIL (|has| |#2| (-869)))) (-2976 (($ (-1 (-254 (-1699 |#1|) (-790)) (-254 (-1699 |#1|) (-790))) $) NIL)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-3254 (((-3 (-879 |#1|) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#2| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-2685 (((-1173) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-879 |#1|)) (|:| -3215 (-790))) "failed") $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#2| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#2| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#2| (-931)))) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-879 |#1|) |#2|) NIL) (($ $ (-658 (-879 |#1|)) (-658 |#2|)) NIL) (($ $ (-879 |#1|) $) NIL) (($ $ (-658 (-879 |#1|)) (-658 $)) NIL)) (-1482 (($ $ (-879 |#1|)) NIL (|has| |#2| (-194)))) (-3644 (($ $ (-879 |#1|)) NIL) (($ $ (-658 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-4525 (((-254 (-1699 |#1|) (-790)) $) NIL) (((-790) $ (-879 |#1|)) NIL) (((-658 (-790)) $ (-658 (-879 |#1|))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-879 |#1|) (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-879 |#1|) (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-879 |#1|) (-633 (-565))) (|has| |#2| (-633 (-565)))))) (-1554 ((|#2| $) NIL (|has| |#2| (-477))) (($ $ (-879 |#1|)) NIL (|has| |#2| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#2| (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) NIL) (($ (-879 |#1|)) NIL) (($ (-433 (-592))) NIL (-3836 (|has| |#2| (-43 (-433 (-592)))) (|has| |#2| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#2| (-582)))) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-254 (-1699 |#1|) (-790))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#2| (-931))) (|has| |#2| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#2| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#2| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-879 |#1|)) NIL) (($ $ (-658 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-3286 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#2| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#2| (-43 (-433 (-592))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-264 |#1| |#2|) (-13 (-977 |#2| (-254 (-1699 |#1|) (-790)) (-879 |#1|)) (-10 -8 (-15 -4377 ($ $ (-658 (-592)))))) (-658 (-1191)) (-1075)) (T -264)) 
+((-4377 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-264 *3 *4)) (-14 *3 (-658 (-1191))) (-4 *4 (-1075))))) 
+(-13 (-977 |#2| (-254 (-1699 |#1|) (-790)) (-879 |#1|)) (-10 -8 (-15 -4377 ($ $ (-658 (-592)))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2673 (($ (-944)) NIL (|has| |#4| (-1075)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4079 (($ $ $) NIL (|has| |#4| (-815)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-1403 (((-790)) NIL (|has| |#4| (-394)))) (-3940 (((-592) $) NIL (|has| |#4| (-867)))) (-3932 ((|#4| $ (-592) |#4|) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#4| "failed") $) NIL (|has| |#4| (-1119))) (((-3 (-592) "failed") $) NIL (-12 (|has| |#4| (-1065 (-592))) (|has| |#4| (-1119)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| |#4| (-1065 (-433 (-592)))) (|has| |#4| (-1119))))) (-2400 ((|#4| $) NIL (|has| |#4| (-1119))) (((-592) $) NIL (-12 (|has| |#4| (-1065 (-592))) (|has| |#4| (-1119)))) (((-433 (-592)) $) NIL (-12 (|has| |#4| (-1065 (-433 (-592)))) (|has| |#4| (-1119))))) (-3945 (((-2 (|:| -3253 (-706 |#4|)) (|:| |vec| (-1280 |#4|))) (-706 $) (-1280 $)) NIL (|has| |#4| (-1075))) (((-706 |#4|) (-706 $)) NIL (|has| |#4| (-1075))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075)))) (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))))) (-3371 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))) (|has| |#4| (-743)) (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))))) (-4290 (($) NIL (|has| |#4| (-394)))) (-1426 ((|#4| $ (-592) |#4|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#4| $ (-592)) NIL)) (-1691 (((-141) $) NIL (|has| |#4| (-867)))) (-4004 (((-658 |#4|) $) NIL (|has| $ (-6 -4625)))) (-3558 (((-141) $) NIL (-3836 (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))) (|has| |#4| (-743)) (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))))) (-1324 (((-141) $) NIL (|has| |#4| (-867)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (-3836 (|has| |#4| (-815)) (|has| |#4| (-867))))) (-4467 (((-658 |#4|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (-3836 (|has| |#4| (-815)) (|has| |#4| (-867))))) (-3987 (($ (-1 |#4| |#4|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) NIL)) (-3546 (((-944) $) NIL (|has| |#4| (-394)))) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-1825 (($ (-944)) NIL (|has| |#4| (-394)))) (-2951 (((-1137) $) NIL)) (-1918 ((|#4| $) NIL (|has| (-592) (-869)))) (-1892 (($ $ |#4|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#4|))) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 |#4|) (-658 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1405 (((-658 $)) NIL (|has| |#4| (-394)))) (-2254 (((-141) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-4210 (((-658 |#4|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#4| $ (-592) |#4|) NIL) ((|#4| $ (-592)) 12)) (-1729 ((|#4| $ $) NIL (|has| |#4| (-1075)))) (-4512 (($ (-1280 |#4|)) NIL)) (-1936 (((-160)) NIL (|has| |#4| (-388)))) (-3644 (($ $ (-1 |#4| |#4|) (-790)) NIL (|has| |#4| (-1075))) (($ $ (-1 |#4| |#4|)) NIL (|has| |#4| (-1075))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#4| (-247)) (|has| |#4| (-1075)))) (($ $) NIL (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))))) (-3452 (((-790) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625))) (((-790) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-1280 |#4|) $) NIL) (((-877) $) NIL) (($ |#4|) NIL (|has| |#4| (-1119))) (($ (-592)) NIL (-3836 (-12 (|has| |#4| (-1065 (-592))) (|has| |#4| (-1119))) (|has| |#4| (-1075)))) (($ (-433 (-592))) NIL (-12 (|has| |#4| (-1065 (-433 (-592)))) (|has| |#4| (-1119))))) (-4010 (((-790)) NIL (|has| |#4| (-1075)))) (-3369 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-1392 (($ $) NIL (|has| |#4| (-867)))) (-1424 (($ $ (-790)) NIL (-3836 (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))) (|has| |#4| (-743)) (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075))))) (($ $ (-944)) NIL (-3836 (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))) (|has| |#4| (-743)) (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))))) (-3514 (($) NIL T CONST)) (-4257 (($) NIL (-3836 (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))) (|has| |#4| (-743)) (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) CONST)) (-1940 (($ $ (-1 |#4| |#4|) (-790)) NIL (|has| |#4| (-1075))) (($ $ (-1 |#4| |#4|)) NIL (|has| |#4| (-1075))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#4| (-247)) (|has| |#4| (-1075)))) (($ $) NIL (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))))) (-3286 (((-141) $ $) NIL (-3836 (|has| |#4| (-815)) (|has| |#4| (-867))))) (-3273 (((-141) $ $) NIL (-3836 (|has| |#4| (-815)) (|has| |#4| (-867))))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (-3836 (|has| |#4| (-815)) (|has| |#4| (-867))))) (-3266 (((-141) $ $) NIL (-3836 (|has| |#4| (-815)) (|has| |#4| (-867))))) (-3313 (($ $ |#4|) NIL (|has| |#4| (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL (-3836 (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))) (|has| |#4| (-743)) (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075))))) (($ $ (-944)) NIL (-3836 (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))) (|has| |#4| (-743)) (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))))) (* (($ |#2| $) 14) (($ (-592) $) NIL) (($ (-790) $) NIL) (($ (-944) $) NIL) (($ |#3| $) 18) (($ $ |#4|) NIL (|has| |#4| (-743))) (($ |#4| $) NIL (|has| |#4| (-743))) (($ $ $) NIL (-3836 (-12 (|has| |#4| (-247)) (|has| |#4| (-1075))) (-12 (|has| |#4| (-654 (-592))) (|has| |#4| (-1075))) (|has| |#4| (-743)) (-12 (|has| |#4| (-922 (-1191))) (|has| |#4| (-1075)))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-265 |#1| |#2| |#3| |#4|) (-13 (-252 |#1| |#4|) (-661 |#2|) (-661 |#3|)) (-944) (-1075) (-1140 |#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) (-661 |#2|)) (T -265)) 
+NIL 
+(-13 (-252 |#1| |#4|) (-661 |#2|) (-661 |#3|)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2673 (($ (-944)) NIL (|has| |#3| (-1075)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4079 (($ $ $) NIL (|has| |#3| (-815)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-1403 (((-790)) NIL (|has| |#3| (-394)))) (-3940 (((-592) $) NIL (|has| |#3| (-867)))) (-3932 ((|#3| $ (-592) |#3|) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#3| "failed") $) NIL (|has| |#3| (-1119))) (((-3 (-592) "failed") $) NIL (-12 (|has| |#3| (-1065 (-592))) (|has| |#3| (-1119)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| |#3| (-1065 (-433 (-592)))) (|has| |#3| (-1119))))) (-2400 ((|#3| $) NIL (|has| |#3| (-1119))) (((-592) $) NIL (-12 (|has| |#3| (-1065 (-592))) (|has| |#3| (-1119)))) (((-433 (-592)) $) NIL (-12 (|has| |#3| (-1065 (-433 (-592)))) (|has| |#3| (-1119))))) (-3945 (((-2 (|:| -3253 (-706 |#3|)) (|:| |vec| (-1280 |#3|))) (-706 $) (-1280 $)) NIL (|has| |#3| (-1075))) (((-706 |#3|) (-706 $)) NIL (|has| |#3| (-1075))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075)))) (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))))) (-3371 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))) (|has| |#3| (-743)) (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))))) (-4290 (($) NIL (|has| |#3| (-394)))) (-1426 ((|#3| $ (-592) |#3|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#3| $ (-592)) NIL)) (-1691 (((-141) $) NIL (|has| |#3| (-867)))) (-4004 (((-658 |#3|) $) NIL (|has| $ (-6 -4625)))) (-3558 (((-141) $) NIL (-3836 (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))) (|has| |#3| (-743)) (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))))) (-1324 (((-141) $) NIL (|has| |#3| (-867)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-4467 (((-658 |#3|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#3| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#3| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3987 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#3| |#3|) $) NIL)) (-3546 (((-944) $) NIL (|has| |#3| (-394)))) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-1825 (($ (-944)) NIL (|has| |#3| (-394)))) (-2951 (((-1137) $) NIL)) (-1918 ((|#3| $) NIL (|has| (-592) (-869)))) (-1892 (($ $ |#3|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#3|))) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ (-310 |#3|)) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ (-658 |#3|) (-658 |#3|)) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1405 (((-658 $)) NIL (|has| |#3| (-394)))) (-2254 (((-141) |#3| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#3| (-1119))))) (-4210 (((-658 |#3|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#3| $ (-592) |#3|) NIL) ((|#3| $ (-592)) 11)) (-1729 ((|#3| $ $) NIL (|has| |#3| (-1075)))) (-4512 (($ (-1280 |#3|)) NIL)) (-1936 (((-160)) NIL (|has| |#3| (-388)))) (-3644 (($ $ (-1 |#3| |#3|) (-790)) NIL (|has| |#3| (-1075))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1075))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#3| (-247)) (|has| |#3| (-1075)))) (($ $) NIL (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))))) (-3452 (((-790) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625))) (((-790) |#3| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#3| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-1280 |#3|) $) NIL) (((-877) $) NIL) (($ |#3|) NIL (|has| |#3| (-1119))) (($ (-592)) NIL (-3836 (-12 (|has| |#3| (-1065 (-592))) (|has| |#3| (-1119))) (|has| |#3| (-1075)))) (($ (-433 (-592))) NIL (-12 (|has| |#3| (-1065 (-433 (-592)))) (|has| |#3| (-1119))))) (-4010 (((-790)) NIL (|has| |#3| (-1075)))) (-3369 (((-141) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625)))) (-1392 (($ $) NIL (|has| |#3| (-867)))) (-1424 (($ $ (-790)) NIL (-3836 (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))) (|has| |#3| (-743)) (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075))))) (($ $ (-944)) NIL (-3836 (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))) (|has| |#3| (-743)) (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))))) (-3514 (($) NIL T CONST)) (-4257 (($) NIL (-3836 (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))) (|has| |#3| (-743)) (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) CONST)) (-1940 (($ $ (-1 |#3| |#3|) (-790)) NIL (|has| |#3| (-1075))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1075))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#3| (-247)) (|has| |#3| (-1075)))) (($ $) NIL (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))))) (-3286 (((-141) $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3273 (((-141) $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3266 (((-141) $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3313 (($ $ |#3|) NIL (|has| |#3| (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL (-3836 (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))) (|has| |#3| (-743)) (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075))))) (($ $ (-944)) NIL (-3836 (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))) (|has| |#3| (-743)) (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))))) (* (($ |#2| $) 13) (($ (-592) $) NIL) (($ (-790) $) NIL) (($ (-944) $) NIL) (($ $ |#3|) NIL (|has| |#3| (-743))) (($ |#3| $) NIL (|has| |#3| (-743))) (($ $ $) NIL (-3836 (-12 (|has| |#3| (-247)) (|has| |#3| (-1075))) (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075))) (|has| |#3| (-743)) (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-266 |#1| |#2| |#3|) (-13 (-252 |#1| |#3|) (-661 |#2|)) (-790) (-1075) (-661 |#2|)) (T -266)) 
+NIL 
+(-13 (-252 |#1| |#3|) (-661 |#2|)) 
+((-1399 (((-658 (-790)) $) 47) (((-658 (-790)) $ |#3|) 50)) (-3775 (((-790) $) 49) (((-790) $ |#3|) 52)) (-1885 (($ $) 65)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 (-592) "failed") $) NIL) (((-3 |#4| "failed") $) NIL) (((-3 |#3| "failed") $) 72)) (-4346 (((-790) $ |#3|) 39) (((-790) $) 36)) (-3358 (((-1 $ (-790)) |#3|) 15) (((-1 $ (-790)) $) 77)) (-1692 ((|#4| $) 58)) (-4401 (((-141) $) 56)) (-3198 (($ $) 64)) (-2806 (($ $ (-658 (-310 $))) 96) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ |#4| |#2|) NIL) (($ $ (-658 |#4|) (-658 |#2|)) NIL) (($ $ |#4| $) NIL) (($ $ (-658 |#4|) (-658 $)) NIL) (($ $ |#3| $) NIL) (($ $ (-658 |#3|) (-658 $)) 89) (($ $ |#3| |#2|) NIL) (($ $ (-658 |#3|) (-658 |#2|)) 84)) (-3644 (($ $ |#4|) NIL) (($ $ (-658 |#4|)) NIL) (($ $ |#4| (-790)) NIL) (($ $ (-658 |#4|) (-658 (-790))) NIL) (($ $) NIL) (($ $ (-790)) NIL) (($ $ (-1191)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) 32)) (-2912 (((-658 |#3|) $) 75)) (-4525 ((|#5| $) NIL) (((-790) $ |#4|) NIL) (((-658 (-790)) $ (-658 |#4|)) NIL) (((-790) $ |#3|) 44)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) NIL) (($ |#4|) NIL) (($ |#3|) 67) (($ (-433 (-592))) NIL) (($ $) NIL))) 
+(((-267 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -1683 (|#1| |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -2806 (|#1| |#1| (-658 |#3|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#3| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#3|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#3| |#1|)) (-15 -3358 ((-1 |#1| (-790)) |#1|)) (-15 -1885 (|#1| |#1|)) (-15 -3198 (|#1| |#1|)) (-15 -1692 (|#4| |#1|)) (-15 -4401 ((-141) |#1|)) (-15 -3775 ((-790) |#1| |#3|)) (-15 -1399 ((-658 (-790)) |#1| |#3|)) (-15 -3775 ((-790) |#1|)) (-15 -1399 ((-658 (-790)) |#1|)) (-15 -4525 ((-790) |#1| |#3|)) (-15 -4346 ((-790) |#1|)) (-15 -4346 ((-790) |#1| |#3|)) (-15 -2912 ((-658 |#3|) |#1|)) (-15 -3358 ((-1 |#1| (-790)) |#3|)) (-15 -4368 ((-3 |#3| "failed") |#1|)) (-15 -1683 (|#1| |#3|)) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1|)) (-15 -4525 ((-658 (-790)) |#1| (-658 |#4|))) (-15 -4525 ((-790) |#1| |#4|)) (-15 -4368 ((-3 |#4| "failed") |#1|)) (-15 -1683 (|#1| |#4|)) (-15 -2806 (|#1| |#1| (-658 |#4|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#4| |#1|)) (-15 -2806 (|#1| |#1| (-658 |#4|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#4| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -4525 (|#5| |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -3644 (|#1| |#1| (-658 |#4|) (-658 (-790)))) (-15 -3644 (|#1| |#1| |#4| (-790))) (-15 -3644 (|#1| |#1| (-658 |#4|))) (-15 -3644 (|#1| |#1| |#4|)) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) (-268 |#2| |#3| |#4| |#5|) (-1075) (-869) (-284 |#3|) (-815)) (T -267)) 
+NIL 
+(-10 -8 (-15 -1683 (|#1| |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -2806 (|#1| |#1| (-658 |#3|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#3| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#3|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#3| |#1|)) (-15 -3358 ((-1 |#1| (-790)) |#1|)) (-15 -1885 (|#1| |#1|)) (-15 -3198 (|#1| |#1|)) (-15 -1692 (|#4| |#1|)) (-15 -4401 ((-141) |#1|)) (-15 -3775 ((-790) |#1| |#3|)) (-15 -1399 ((-658 (-790)) |#1| |#3|)) (-15 -3775 ((-790) |#1|)) (-15 -1399 ((-658 (-790)) |#1|)) (-15 -4525 ((-790) |#1| |#3|)) (-15 -4346 ((-790) |#1|)) (-15 -4346 ((-790) |#1| |#3|)) (-15 -2912 ((-658 |#3|) |#1|)) (-15 -3358 ((-1 |#1| (-790)) |#3|)) (-15 -4368 ((-3 |#3| "failed") |#1|)) (-15 -1683 (|#1| |#3|)) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1|)) (-15 -4525 ((-658 (-790)) |#1| (-658 |#4|))) (-15 -4525 ((-790) |#1| |#4|)) (-15 -4368 ((-3 |#4| "failed") |#1|)) (-15 -1683 (|#1| |#4|)) (-15 -2806 (|#1| |#1| (-658 |#4|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#4| |#1|)) (-15 -2806 (|#1| |#1| (-658 |#4|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#4| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -4525 (|#5| |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -3644 (|#1| |#1| (-658 |#4|) (-658 (-790)))) (-15 -3644 (|#1| |#1| |#4| (-790))) (-15 -3644 (|#1| |#1| (-658 |#4|))) (-15 -3644 (|#1| |#1| |#4|)) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-1399 (((-658 (-790)) $) 193) (((-658 (-790)) $ |#2|) 191)) (-3775 (((-790) $) 192) (((-790) $ |#2|) 190)) (-4085 (((-658 |#3|) $) 108)) (-4492 (((-1187 $) $ |#3|) 123) (((-1187 |#1|) $) 122)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 85 (|has| |#1| (-582)))) (-1555 (($ $) 86 (|has| |#1| (-582)))) (-1313 (((-141) $) 88 (|has| |#1| (-582)))) (-2189 (((-790) $) 110) (((-790) $ (-658 |#3|)) 109)) (-2350 (((-3 $ "failed") $ $) 18)) (-4043 (((-444 (-1187 $)) (-1187 $)) 98 (|has| |#1| (-931)))) (-3743 (($ $) 96 (|has| |#1| (-477)))) (-3164 (((-444 $) $) 95 (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 101 (|has| |#1| (-931)))) (-1885 (($ $) 186)) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 162) (((-3 (-433 (-592)) "failed") $) 160 (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) 158 (|has| |#1| (-1065 (-592)))) (((-3 |#3| "failed") $) 134) (((-3 |#2| "failed") $) 200)) (-2400 ((|#1| $) 163) (((-433 (-592)) $) 159 (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) 157 (|has| |#1| (-1065 (-592)))) ((|#3| $) 133) ((|#2| $) 199)) (-1544 (($ $ $ |#3|) 106 (|has| |#1| (-194)))) (-4593 (($ $) 152)) (-3945 (((-706 (-592)) (-706 $)) 132 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 131 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 130) (((-706 |#1|) (-706 $)) 129)) (-3371 (((-3 $ "failed") $) 33)) (-3262 (($ $) 174 (|has| |#1| (-477))) (($ $ |#3|) 103 (|has| |#1| (-477)))) (-4585 (((-658 $) $) 107)) (-2802 (((-141) $) 94 (|has| |#1| (-931)))) (-4209 (($ $ |#1| |#4| $) 170)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 82 (-12 (|has| |#3| (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 81 (-12 (|has| |#3| (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-4346 (((-790) $ |#2|) 196) (((-790) $) 195)) (-3558 (((-141) $) 30)) (-4036 (((-790) $) 167)) (-4533 (($ (-1187 |#1|) |#3|) 115) (($ (-1187 $) |#3|) 114)) (-3108 (((-658 $) $) 124)) (-2027 (((-141) $) 150)) (-4526 (($ |#1| |#4|) 151) (($ $ |#3| (-790)) 117) (($ $ (-658 |#3|) (-658 (-790))) 116)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ |#3|) 118)) (-4206 ((|#4| $) 168) (((-790) $ |#3|) 120) (((-658 (-790)) $ (-658 |#3|)) 119)) (-1837 (($ $ $) 77 (|has| |#1| (-869)))) (-3319 (($ $ $) 76 (|has| |#1| (-869)))) (-2976 (($ (-1 |#4| |#4|) $) 169)) (-2731 (($ (-1 |#1| |#1|) $) 149)) (-3358 (((-1 $ (-790)) |#2|) 198) (((-1 $ (-790)) $) 185 (|has| |#1| (-247)))) (-3254 (((-3 |#3| "failed") $) 121)) (-4573 (($ $) 147)) (-4579 ((|#1| $) 146)) (-1692 ((|#3| $) 188)) (-2750 (($ (-658 $)) 92 (|has| |#1| (-477))) (($ $ $) 91 (|has| |#1| (-477)))) (-2685 (((-1173) $) 9)) (-4401 (((-141) $) 189)) (-4421 (((-3 (-658 $) "failed") $) 112)) (-2947 (((-3 (-658 $) "failed") $) 113)) (-2257 (((-3 (-2 (|:| |var| |#3|) (|:| -3215 (-790))) "failed") $) 111)) (-3198 (($ $) 187)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 164)) (-4565 ((|#1| $) 165)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 93 (|has| |#1| (-477)))) (-3548 (($ (-658 $)) 90 (|has| |#1| (-477))) (($ $ $) 89 (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) 100 (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) 99 (|has| |#1| (-931)))) (-4500 (((-444 $) $) 97 (|has| |#1| (-931)))) (-3616 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-582))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) 143) (($ $ (-310 $)) 142) (($ $ $ $) 141) (($ $ (-658 $) (-658 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-658 |#3|) (-658 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-658 |#3|) (-658 $)) 136) (($ $ |#2| $) 184 (|has| |#1| (-247))) (($ $ (-658 |#2|) (-658 $)) 183 (|has| |#1| (-247))) (($ $ |#2| |#1|) 182 (|has| |#1| (-247))) (($ $ (-658 |#2|) (-658 |#1|)) 181 (|has| |#1| (-247)))) (-1482 (($ $ |#3|) 105 (|has| |#1| (-194)))) (-3644 (($ $ |#3|) 41) (($ $ (-658 |#3|)) 40) (($ $ |#3| (-790)) 39) (($ $ (-658 |#3|) (-658 (-790))) 38) (($ $) 217 (|has| |#1| (-247))) (($ $ (-790)) 215 (|has| |#1| (-247))) (($ $ (-1191)) 213 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 212 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 211 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) 210 (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) 203) (($ $ (-1 |#1| |#1|)) 202)) (-2912 (((-658 |#2|) $) 197)) (-4525 ((|#4| $) 148) (((-790) $ |#3|) 128) (((-658 (-790)) $ (-658 |#3|)) 127) (((-790) $ |#2|) 194)) (-1778 (((-914 (-405)) $) 80 (-12 (|has| |#3| (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) 79 (-12 (|has| |#3| (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) 78 (-12 (|has| |#3| (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) 173 (|has| |#1| (-477))) (($ $ |#3|) 104 (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 102 (-1732 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 161) (($ |#3|) 135) (($ |#2|) 201) (($ (-433 (-592))) 70 (-3836 (|has| |#1| (-1065 (-433 (-592)))) (|has| |#1| (-43 (-433 (-592)))))) (($ $) 83 (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) 166)) (-1937 ((|#1| $ |#4|) 153) (($ $ |#3| (-790)) 126) (($ $ (-658 |#3|) (-658 (-790))) 125)) (-1517 (((-3 $ "failed") $) 71 (-3836 (-1732 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) 28)) (-4064 (($ $ $ (-790)) 171 (|has| |#1| (-194)))) (-2537 (((-141) $ $) 87 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ |#3|) 37) (($ $ (-658 |#3|)) 36) (($ $ |#3| (-790)) 35) (($ $ (-658 |#3|) (-658 (-790))) 34) (($ $) 216 (|has| |#1| (-247))) (($ $ (-790)) 214 (|has| |#1| (-247))) (($ $ (-1191)) 209 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 208 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 207 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) 206 (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) 205) (($ $ (-1 |#1| |#1|)) 204)) (-3286 (((-141) $ $) 74 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 73 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 75 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 72 (|has| |#1| (-869)))) (-3313 (($ $ |#1|) 154 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 156 (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) 155 (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
+(((-268 |#1| |#2| |#3| |#4|) (-1311) (-1075) (-869) (-284 |t#2|) (-815)) (T -268)) 
+((-3358 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-1 *1 (-790))) (-4 *1 (-268 *4 *3 *5 *6)))) (-2912 (*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-658 *4)))) (-4346 (*1 *2 *1 *3) (-12 (-4 *1 (-268 *4 *3 *5 *6)) (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-790)))) (-4346 (*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-790)))) (-4525 (*1 *2 *1 *3) (-12 (-4 *1 (-268 *4 *3 *5 *6)) (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-790)))) (-1399 (*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-658 (-790))))) (-3775 (*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-790)))) (-1399 (*1 *2 *1 *3) (-12 (-4 *1 (-268 *4 *3 *5 *6)) (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-658 (-790))))) (-3775 (*1 *2 *1 *3) (-12 (-4 *1 (-268 *4 *3 *5 *6)) (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-790)))) (-4401 (*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-141)))) (-1692 (*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-815)) (-4 *2 (-284 *4)))) (-3198 (*1 *1 *1) (-12 (-4 *1 (-268 *2 *3 *4 *5)) (-4 *2 (-1075)) (-4 *3 (-869)) (-4 *4 (-284 *3)) (-4 *5 (-815)))) (-1885 (*1 *1 *1) (-12 (-4 *1 (-268 *2 *3 *4 *5)) (-4 *2 (-1075)) (-4 *3 (-869)) (-4 *4 (-284 *3)) (-4 *5 (-815)))) (-3358 (*1 *2 *1) (-12 (-4 *3 (-247)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-1 *1 (-790))) (-4 *1 (-268 *3 *4 *5 *6))))) 
+(-13 (-977 |t#1| |t#4| |t#3|) (-245 |t#1|) (-1065 |t#2|) (-10 -8 (-15 -3358 ((-1 $ (-790)) |t#2|)) (-15 -2912 ((-658 |t#2|) $)) (-15 -4346 ((-790) $ |t#2|)) (-15 -4346 ((-790) $)) (-15 -4525 ((-790) $ |t#2|)) (-15 -1399 ((-658 (-790)) $)) (-15 -3775 ((-790) $)) (-15 -1399 ((-658 (-790)) $ |t#2|)) (-15 -3775 ((-790) $ |t#2|)) (-15 -4401 ((-141) $)) (-15 -1692 (|t#3| $)) (-15 -3198 ($ $)) (-15 -1885 ($ $)) (IF (|has| |t#1| (-247)) (PROGN (-6 (-547 |t#2| |t#1|)) (-6 (-547 |t#2| $)) (-6 (-325 $)) (-15 -3358 ((-1 $ (-790)) $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#4|) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-633 (-565)) -12 (|has| |#1| (-633 (-565))) (|has| |#3| (-633 (-565)))) ((-633 (-914 (-405))) -12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#3| (-633 (-914 (-405))))) ((-633 (-914 (-592))) -12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#3| (-633 (-914 (-592))))) ((-245 |#1|) . T) ((-247) |has| |#1| (-247)) ((-307) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-325 $) . T) ((-346 |#1| |#4|) . T) ((-403 |#1|) . T) ((-437 |#1|) . T) ((-477) -3836 (|has| |#1| (-931)) (|has| |#1| (-477))) ((-547 |#2| |#1|) |has| |#1| (-247)) ((-547 |#2| $) |has| |#1| (-247)) ((-547 |#3| |#1|) . T) ((-547 |#3| $) . T) ((-547 $ $) . T) ((-582) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) -3836 (|has| |#1| (-931)) (|has| |#1| (-477))) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-743) . T) ((-869) |has| |#1| (-869)) ((-922 (-1191)) |has| |#1| (-922 (-1191))) ((-922 |#3|) . T) ((-908 (-405)) -12 (|has| |#1| (-908 (-405))) (|has| |#3| (-908 (-405)))) ((-908 (-592)) -12 (|has| |#1| (-908 (-592))) (|has| |#3| (-908 (-592)))) ((-977 |#1| |#4| |#3|) . T) ((-931) |has| |#1| (-931)) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1065 |#2|) . T) ((-1065 |#3|) . T) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) |has| |#1| (-931))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2616 ((|#1| $) 51)) (-3349 ((|#1| $) 41)) (-2126 (((-141) $ (-790)) 8)) (-3001 (($) 7 T CONST)) (-4179 (($ $) 57)) (-2512 (($ $) 45)) (-3568 ((|#1| |#1| $) 43)) (-2486 ((|#1| $) 42)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-4233 (((-790) $) 58)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4137 ((|#1| $) 36)) (-2251 ((|#1| |#1| $) 49)) (-4451 ((|#1| |#1| $) 48)) (-2113 (($ |#1| $) 37)) (-2535 (((-790) $) 52)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1476 ((|#1| $) 59)) (-2452 ((|#1| $) 47)) (-4225 ((|#1| $) 46)) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-1659 ((|#1| |#1| $) 55)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-1716 ((|#1| $) 56)) (-4309 (($) 54) (($ (-658 |#1|)) 53)) (-3439 (((-790) $) 40)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-1966 ((|#1| $) 50)) (-4560 (($ (-658 |#1|)) 39)) (-2829 ((|#1| $) 60)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-269 |#1|) (-1311) (-1225)) (T -269)) 
+((-4309 (*1 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225)))) (-4309 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-4 *1 (-269 *3)))) (-2535 (*1 *2 *1) (-12 (-4 *1 (-269 *3)) (-4 *3 (-1225)) (-5 *2 (-790)))) (-2616 (*1 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225)))) (-1966 (*1 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225)))) (-2251 (*1 *2 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225)))) (-4451 (*1 *2 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225)))) (-2452 (*1 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225)))) (-4225 (*1 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225)))) (-2512 (*1 *1 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225))))) 
+(-13 (-1138 |t#1|) (-1023 |t#1|) (-10 -8 (-15 -4309 ($)) (-15 -4309 ($ (-658 |t#1|))) (-15 -2535 ((-790) $)) (-15 -2616 (|t#1| $)) (-15 -1966 (|t#1| $)) (-15 -2251 (|t#1| |t#1| $)) (-15 -4451 (|t#1| |t#1| $)) (-15 -2452 (|t#1| $)) (-15 -4225 (|t#1| $)) (-15 -2512 ($ $)))) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1023 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1138 |#1|) . T) ((-1225) . T)) 
+((-2885 (((-1 (-971 (-237)) (-237) (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1 (-237) (-237) (-237) (-237))) 139)) (-1478 (((-1150 (-237)) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405))) 160) (((-1150 (-237)) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)) (-658 (-278))) 158) (((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405))) 163) (((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278))) 159) (((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405))) 150) (((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278))) 149) (((-1150 (-237)) (-1 (-971 (-237)) (-237)) (-1113 (-405))) 129) (((-1150 (-237)) (-1 (-971 (-237)) (-237)) (-1113 (-405)) (-658 (-278))) 127) (((-1150 (-237)) (-902 (-1 (-237) (-237))) (-1113 (-405))) 128) (((-1150 (-237)) (-902 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278))) 125)) (-1472 (((-1282) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405))) 162) (((-1282) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)) (-658 (-278))) 161) (((-1282) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405))) 165) (((-1282) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278))) 164) (((-1282) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405))) 152) (((-1282) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278))) 151) (((-1282) (-1 (-971 (-237)) (-237)) (-1113 (-405))) 135) (((-1282) (-1 (-971 (-237)) (-237)) (-1113 (-405)) (-658 (-278))) 134) (((-1282) (-902 (-1 (-237) (-237))) (-1113 (-405))) 133) (((-1282) (-902 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278))) 132) (((-1281) (-900 (-1 (-237) (-237))) (-1113 (-405))) 99) (((-1281) (-900 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278))) 98) (((-1281) (-1 (-237) (-237)) (-1113 (-405))) 95) (((-1281) (-1 (-237) (-237)) (-1113 (-405)) (-658 (-278))) 94))) 
+(((-270) (-10 -7 (-15 -1472 ((-1281) (-1 (-237) (-237)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1281) (-1 (-237) (-237)) (-1113 (-405)))) (-15 -1472 ((-1281) (-900 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1281) (-900 (-1 (-237) (-237))) (-1113 (-405)))) (-15 -1472 ((-1282) (-902 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-902 (-1 (-237) (-237))) (-1113 (-405)))) (-15 -1472 ((-1282) (-1 (-971 (-237)) (-237)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-1 (-971 (-237)) (-237)) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-902 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-902 (-1 (-237) (-237))) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-1 (-971 (-237)) (-237)) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-1 (-971 (-237)) (-237)) (-1113 (-405)))) (-15 -1472 ((-1282) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)))) (-15 -1472 ((-1282) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)))) (-15 -1472 ((-1282) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)))) (-15 -2885 ((-1 (-971 (-237)) (-237) (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1 (-237) (-237) (-237) (-237)))))) (T -270)) 
+((-2885 (*1 *2 *2 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237) (-237))) (-5 *3 (-1 (-237) (-237) (-237) (-237))) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-904 (-1 (-237) (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-904 (-1 (-237) (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-904 (-1 (-237) (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-904 (-1 (-237) (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-971 (-237)) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4) (-12 (-5 *3 (-902 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1478 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-902 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-971 (-237)) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4) (-12 (-5 *3 (-902 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-902 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4) (-12 (-5 *3 (-900 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1281)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-900 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1281)) (-5 *1 (-270)))) (-1472 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-270))))) 
+(-10 -7 (-15 -1472 ((-1281) (-1 (-237) (-237)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1281) (-1 (-237) (-237)) (-1113 (-405)))) (-15 -1472 ((-1281) (-900 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1281) (-900 (-1 (-237) (-237))) (-1113 (-405)))) (-15 -1472 ((-1282) (-902 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-902 (-1 (-237) (-237))) (-1113 (-405)))) (-15 -1472 ((-1282) (-1 (-971 (-237)) (-237)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-1 (-971 (-237)) (-237)) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-902 (-1 (-237) (-237))) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-902 (-1 (-237) (-237))) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-1 (-971 (-237)) (-237)) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-1 (-971 (-237)) (-237)) (-1113 (-405)))) (-15 -1472 ((-1282) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1113 (-405)) (-1113 (-405)))) (-15 -1472 ((-1282) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-405)) (-1113 (-405)))) (-15 -1472 ((-1282) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)))) (-15 -1478 ((-1150 (-237)) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-904 (-1 (-237) (-237) (-237))) (-1113 (-405)) (-1113 (-405)))) (-15 -2885 ((-1 (-971 (-237)) (-237) (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1 (-237) (-237) (-237) (-237))))) 
+((-1472 (((-1281) (-310 |#2|) (-1191) (-1191) (-658 (-278))) 93))) 
+(((-271 |#1| |#2|) (-10 -7 (-15 -1472 ((-1281) (-310 |#2|) (-1191) (-1191) (-658 (-278))))) (-13 (-582) (-869) (-1065 (-592))) (-456 |#1|)) (T -271)) 
+((-1472 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-310 *7)) (-5 *4 (-1191)) (-5 *5 (-658 (-278))) (-4 *7 (-456 *6)) (-4 *6 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-1281)) (-5 *1 (-271 *6 *7))))) 
+(-10 -7 (-15 -1472 ((-1281) (-310 |#2|) (-1191) (-1191) (-658 (-278))))) 
+((-4151 (((-592) (-592)) 50)) (-2076 (((-592) (-592)) 51)) (-2253 (((-237) (-237)) 52)) (-4503 (((-1282) (-1 (-191 (-237)) (-191 (-237))) (-1113 (-237)) (-1113 (-237))) 49)) (-3542 (((-1282) (-1 (-191 (-237)) (-191 (-237))) (-1113 (-237)) (-1113 (-237)) (-141)) 47))) 
+(((-272) (-10 -7 (-15 -3542 ((-1282) (-1 (-191 (-237)) (-191 (-237))) (-1113 (-237)) (-1113 (-237)) (-141))) (-15 -4503 ((-1282) (-1 (-191 (-237)) (-191 (-237))) (-1113 (-237)) (-1113 (-237)))) (-15 -4151 ((-592) (-592))) (-15 -2076 ((-592) (-592))) (-15 -2253 ((-237) (-237))))) (T -272)) 
+((-2253 (*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-272)))) (-2076 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-272)))) (-4151 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-272)))) (-4503 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-191 (-237)) (-191 (-237)))) (-5 *4 (-1113 (-237))) (-5 *2 (-1282)) (-5 *1 (-272)))) (-3542 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-191 (-237)) (-191 (-237)))) (-5 *4 (-1113 (-237))) (-5 *5 (-141)) (-5 *2 (-1282)) (-5 *1 (-272))))) 
+(-10 -7 (-15 -3542 ((-1282) (-1 (-191 (-237)) (-191 (-237))) (-1113 (-237)) (-1113 (-237)) (-141))) (-15 -4503 ((-1282) (-1 (-191 (-237)) (-191 (-237))) (-1113 (-237)) (-1113 (-237)))) (-15 -4151 ((-592) (-592))) (-15 -2076 ((-592) (-592))) (-15 -2253 ((-237) (-237)))) 
+((-1683 (((-1111 (-405)) (-1111 (-332 |#1|))) 16))) 
+(((-273 |#1|) (-10 -7 (-15 -1683 ((-1111 (-405)) (-1111 (-332 |#1|))))) (-13 (-869) (-582) (-633 (-405)))) (T -273)) 
+((-1683 (*1 *2 *3) (-12 (-5 *3 (-1111 (-332 *4))) (-4 *4 (-13 (-869) (-582) (-633 (-405)))) (-5 *2 (-1111 (-405))) (-5 *1 (-273 *4))))) 
+(-10 -7 (-15 -1683 ((-1111 (-405)) (-1111 (-332 |#1|))))) 
+((-1478 (((-1150 (-237)) (-904 |#1|) (-1111 (-405)) (-1111 (-405))) 69) (((-1150 (-237)) (-904 |#1|) (-1111 (-405)) (-1111 (-405)) (-658 (-278))) 68) (((-1150 (-237)) |#1| (-1111 (-405)) (-1111 (-405))) 59) (((-1150 (-237)) |#1| (-1111 (-405)) (-1111 (-405)) (-658 (-278))) 58) (((-1150 (-237)) (-902 |#1|) (-1111 (-405))) 50) (((-1150 (-237)) (-902 |#1|) (-1111 (-405)) (-658 (-278))) 49)) (-1472 (((-1282) (-904 |#1|) (-1111 (-405)) (-1111 (-405))) 72) (((-1282) (-904 |#1|) (-1111 (-405)) (-1111 (-405)) (-658 (-278))) 71) (((-1282) |#1| (-1111 (-405)) (-1111 (-405))) 62) (((-1282) |#1| (-1111 (-405)) (-1111 (-405)) (-658 (-278))) 61) (((-1282) (-902 |#1|) (-1111 (-405))) 54) (((-1282) (-902 |#1|) (-1111 (-405)) (-658 (-278))) 53) (((-1281) (-900 |#1|) (-1111 (-405))) 41) (((-1281) (-900 |#1|) (-1111 (-405)) (-658 (-278))) 40) (((-1281) |#1| (-1111 (-405))) 33) (((-1281) |#1| (-1111 (-405)) (-658 (-278))) 32))) 
+(((-274 |#1|) (-10 -7 (-15 -1472 ((-1281) |#1| (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1281) |#1| (-1111 (-405)))) (-15 -1472 ((-1281) (-900 |#1|) (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1281) (-900 |#1|) (-1111 (-405)))) (-15 -1472 ((-1282) (-902 |#1|) (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-902 |#1|) (-1111 (-405)))) (-15 -1478 ((-1150 (-237)) (-902 |#1|) (-1111 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-902 |#1|) (-1111 (-405)))) (-15 -1472 ((-1282) |#1| (-1111 (-405)) (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) |#1| (-1111 (-405)) (-1111 (-405)))) (-15 -1478 ((-1150 (-237)) |#1| (-1111 (-405)) (-1111 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) |#1| (-1111 (-405)) (-1111 (-405)))) (-15 -1472 ((-1282) (-904 |#1|) (-1111 (-405)) (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-904 |#1|) (-1111 (-405)) (-1111 (-405)))) (-15 -1478 ((-1150 (-237)) (-904 |#1|) (-1111 (-405)) (-1111 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-904 |#1|) (-1111 (-405)) (-1111 (-405))))) (-13 (-633 (-565)) (-1119))) (T -274)) 
+((-1478 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-904 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *5)))) (-1478 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-904 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *6)))) (-1472 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-904 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1282)) (-5 *1 (-274 *5)))) (-1472 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-904 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1282)) (-5 *1 (-274 *6)))) (-1478 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1111 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) (-1478 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) (-1472 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1111 (-405))) (-5 *2 (-1282)) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) (-1472 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) (-1478 (*1 *2 *3 *4) (-12 (-5 *3 (-902 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *5)))) (-1478 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-902 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *6)))) (-1472 (*1 *2 *3 *4) (-12 (-5 *3 (-902 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1282)) (-5 *1 (-274 *5)))) (-1472 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-902 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1282)) (-5 *1 (-274 *6)))) (-1472 (*1 *2 *3 *4) (-12 (-5 *3 (-900 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1281)) (-5 *1 (-274 *5)))) (-1472 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-900 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1281)) (-5 *1 (-274 *6)))) (-1472 (*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-405))) (-5 *2 (-1281)) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) (-1472 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119)))))) 
+(-10 -7 (-15 -1472 ((-1281) |#1| (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1281) |#1| (-1111 (-405)))) (-15 -1472 ((-1281) (-900 |#1|) (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1281) (-900 |#1|) (-1111 (-405)))) (-15 -1472 ((-1282) (-902 |#1|) (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-902 |#1|) (-1111 (-405)))) (-15 -1478 ((-1150 (-237)) (-902 |#1|) (-1111 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-902 |#1|) (-1111 (-405)))) (-15 -1472 ((-1282) |#1| (-1111 (-405)) (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) |#1| (-1111 (-405)) (-1111 (-405)))) (-15 -1478 ((-1150 (-237)) |#1| (-1111 (-405)) (-1111 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) |#1| (-1111 (-405)) (-1111 (-405)))) (-15 -1472 ((-1282) (-904 |#1|) (-1111 (-405)) (-1111 (-405)) (-658 (-278)))) (-15 -1472 ((-1282) (-904 |#1|) (-1111 (-405)) (-1111 (-405)))) (-15 -1478 ((-1150 (-237)) (-904 |#1|) (-1111 (-405)) (-1111 (-405)) (-658 (-278)))) (-15 -1478 ((-1150 (-237)) (-904 |#1|) (-1111 (-405)) (-1111 (-405))))) 
+((-1472 (((-1282) (-658 (-237)) (-658 (-237)) (-658 (-237)) (-658 (-278))) 21) (((-1282) (-658 (-237)) (-658 (-237)) (-658 (-237))) 22) (((-1281) (-658 (-971 (-237))) (-658 (-278))) 13) (((-1281) (-658 (-971 (-237)))) 14) (((-1281) (-658 (-237)) (-658 (-237)) (-658 (-278))) 18) (((-1281) (-658 (-237)) (-658 (-237))) 19))) 
+(((-275) (-10 -7 (-15 -1472 ((-1281) (-658 (-237)) (-658 (-237)))) (-15 -1472 ((-1281) (-658 (-237)) (-658 (-237)) (-658 (-278)))) (-15 -1472 ((-1281) (-658 (-971 (-237))))) (-15 -1472 ((-1281) (-658 (-971 (-237))) (-658 (-278)))) (-15 -1472 ((-1282) (-658 (-237)) (-658 (-237)) (-658 (-237)))) (-15 -1472 ((-1282) (-658 (-237)) (-658 (-237)) (-658 (-237)) (-658 (-278)))))) (T -275)) 
+((-1472 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-658 (-237))) (-5 *4 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-275)))) (-1472 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-1282)) (-5 *1 (-275)))) (-1472 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-971 (-237)))) (-5 *4 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-275)))) (-1472 (*1 *2 *3) (-12 (-5 *3 (-658 (-971 (-237)))) (-5 *2 (-1281)) (-5 *1 (-275)))) (-1472 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 (-237))) (-5 *4 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-275)))) (-1472 (*1 *2 *3 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-1281)) (-5 *1 (-275))))) 
+(-10 -7 (-15 -1472 ((-1281) (-658 (-237)) (-658 (-237)))) (-15 -1472 ((-1281) (-658 (-237)) (-658 (-237)) (-658 (-278)))) (-15 -1472 ((-1281) (-658 (-971 (-237))))) (-15 -1472 ((-1281) (-658 (-971 (-237))) (-658 (-278)))) (-15 -1472 ((-1282) (-658 (-237)) (-658 (-237)) (-658 (-237)))) (-15 -1472 ((-1282) (-658 (-237)) (-658 (-237)) (-658 (-237)) (-658 (-278))))) 
+((-3678 (((-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))) (-658 (-278)) (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) 24)) (-4339 (((-944) (-658 (-278)) (-944)) 49)) (-2380 (((-944) (-658 (-278)) (-944)) 48)) (-3682 (((-658 (-405)) (-658 (-278)) (-658 (-405))) 65)) (-1455 (((-405) (-658 (-278)) (-405)) 55)) (-3267 (((-944) (-658 (-278)) (-944)) 50)) (-2553 (((-141) (-658 (-278)) (-141)) 26)) (-4116 (((-1173) (-658 (-278)) (-1173)) 19)) (-2732 (((-1173) (-658 (-278)) (-1173)) 25)) (-2366 (((-1150 (-237)) (-658 (-278))) 43)) (-1443 (((-658 (-1113 (-405))) (-658 (-278)) (-658 (-1113 (-405)))) 37)) (-4463 (((-896) (-658 (-278)) (-896)) 31)) (-4300 (((-896) (-658 (-278)) (-896)) 32)) (-3302 (((-1 (-971 (-237)) (-971 (-237))) (-658 (-278)) (-1 (-971 (-237)) (-971 (-237)))) 60)) (-3232 (((-141) (-658 (-278)) (-141)) 15)) (-1804 (((-141) (-658 (-278)) (-141)) 14))) 
+(((-276) (-10 -7 (-15 -1804 ((-141) (-658 (-278)) (-141))) (-15 -3232 ((-141) (-658 (-278)) (-141))) (-15 -3678 ((-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))) (-658 (-278)) (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))))) (-15 -4116 ((-1173) (-658 (-278)) (-1173))) (-15 -2732 ((-1173) (-658 (-278)) (-1173))) (-15 -2553 ((-141) (-658 (-278)) (-141))) (-15 -4463 ((-896) (-658 (-278)) (-896))) (-15 -4300 ((-896) (-658 (-278)) (-896))) (-15 -1443 ((-658 (-1113 (-405))) (-658 (-278)) (-658 (-1113 (-405))))) (-15 -2380 ((-944) (-658 (-278)) (-944))) (-15 -4339 ((-944) (-658 (-278)) (-944))) (-15 -2366 ((-1150 (-237)) (-658 (-278)))) (-15 -3267 ((-944) (-658 (-278)) (-944))) (-15 -1455 ((-405) (-658 (-278)) (-405))) (-15 -3302 ((-1 (-971 (-237)) (-971 (-237))) (-658 (-278)) (-1 (-971 (-237)) (-971 (-237))))) (-15 -3682 ((-658 (-405)) (-658 (-278)) (-658 (-405)))))) (T -276)) 
+((-3682 (*1 *2 *3 *2) (-12 (-5 *2 (-658 (-405))) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-3302 (*1 *2 *3 *2) (-12 (-5 *2 (-1 (-971 (-237)) (-971 (-237)))) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-1455 (*1 *2 *3 *2) (-12 (-5 *2 (-405)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-3267 (*1 *2 *3 *2) (-12 (-5 *2 (-944)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-2366 (*1 *2 *3) (-12 (-5 *3 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-276)))) (-4339 (*1 *2 *3 *2) (-12 (-5 *2 (-944)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-2380 (*1 *2 *3 *2) (-12 (-5 *2 (-944)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-1443 (*1 *2 *3 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-4300 (*1 *2 *3 *2) (-12 (-5 *2 (-896)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-4463 (*1 *2 *3 *2) (-12 (-5 *2 (-896)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-2553 (*1 *2 *3 *2) (-12 (-5 *2 (-141)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-2732 (*1 *2 *3 *2) (-12 (-5 *2 (-1173)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-4116 (*1 *2 *3 *2) (-12 (-5 *2 (-1173)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-3678 (*1 *2 *3 *2) (-12 (-5 *2 (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-3232 (*1 *2 *3 *2) (-12 (-5 *2 (-141)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) (-1804 (*1 *2 *3 *2) (-12 (-5 *2 (-141)) (-5 *3 (-658 (-278))) (-5 *1 (-276))))) 
+(-10 -7 (-15 -1804 ((-141) (-658 (-278)) (-141))) (-15 -3232 ((-141) (-658 (-278)) (-141))) (-15 -3678 ((-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))) (-658 (-278)) (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))))) (-15 -4116 ((-1173) (-658 (-278)) (-1173))) (-15 -2732 ((-1173) (-658 (-278)) (-1173))) (-15 -2553 ((-141) (-658 (-278)) (-141))) (-15 -4463 ((-896) (-658 (-278)) (-896))) (-15 -4300 ((-896) (-658 (-278)) (-896))) (-15 -1443 ((-658 (-1113 (-405))) (-658 (-278)) (-658 (-1113 (-405))))) (-15 -2380 ((-944) (-658 (-278)) (-944))) (-15 -4339 ((-944) (-658 (-278)) (-944))) (-15 -2366 ((-1150 (-237)) (-658 (-278)))) (-15 -3267 ((-944) (-658 (-278)) (-944))) (-15 -1455 ((-405) (-658 (-278)) (-405))) (-15 -3302 ((-1 (-971 (-237)) (-971 (-237))) (-658 (-278)) (-1 (-971 (-237)) (-971 (-237))))) (-15 -3682 ((-658 (-405)) (-658 (-278)) (-658 (-405))))) 
+((-3199 (((-3 |#1| "failed") (-658 (-278)) (-1191)) 17))) 
+(((-277 |#1|) (-10 -7 (-15 -3199 ((-3 |#1| "failed") (-658 (-278)) (-1191)))) (-1225)) (T -277)) 
+((-3199 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-658 (-278))) (-5 *4 (-1191)) (-5 *1 (-277 *2)) (-4 *2 (-1225))))) 
+(-10 -7 (-15 -3199 ((-3 |#1| "failed") (-658 (-278)) (-1191)))) 
+((-1641 (((-141) $ $) NIL)) (-3678 (($ (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) 14)) (-4339 (($ (-944)) 70)) (-2380 (($ (-944)) 69)) (-4509 (($ (-658 (-405))) 76)) (-1455 (($ (-405)) 55)) (-3267 (($ (-944)) 71)) (-2553 (($ (-141)) 22)) (-4116 (($ (-1173)) 17)) (-2732 (($ (-1173)) 18)) (-2366 (($ (-1150 (-237))) 65)) (-1443 (($ (-658 (-1113 (-405)))) 61)) (-2166 (($ (-658 (-1113 (-405)))) 56) (($ (-658 (-1113 (-433 (-592))))) 60)) (-2185 (($ (-405)) 28) (($ (-896)) 32)) (-1669 (((-141) (-658 $) (-1191)) 85)) (-3199 (((-3 (-57) "failed") (-658 $) (-1191)) 87)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3596 (($ (-405)) 33) (($ (-896)) 34)) (-2231 (($ (-1 (-971 (-237)) (-971 (-237)))) 54)) (-3302 (($ (-1 (-971 (-237)) (-971 (-237)))) 72)) (-2232 (($ (-1 (-237) (-237))) 38) (($ (-1 (-237) (-237) (-237))) 42) (($ (-1 (-237) (-237) (-237) (-237))) 46)) (-1683 (((-877) $) 81)) (-3100 (($ (-141)) 23) (($ (-658 (-1113 (-405)))) 50)) (-1804 (($ (-141)) 24)) (-3255 (((-141) $ $) 83))) 
+(((-278) (-13 (-1119) (-10 -8 (-15 -1804 ($ (-141))) (-15 -3100 ($ (-141))) (-15 -3678 ($ (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))))) (-15 -4116 ($ (-1173))) (-15 -2732 ($ (-1173))) (-15 -2553 ($ (-141))) (-15 -3100 ($ (-658 (-1113 (-405))))) (-15 -2231 ($ (-1 (-971 (-237)) (-971 (-237))))) (-15 -2185 ($ (-405))) (-15 -2185 ($ (-896))) (-15 -3596 ($ (-405))) (-15 -3596 ($ (-896))) (-15 -2232 ($ (-1 (-237) (-237)))) (-15 -2232 ($ (-1 (-237) (-237) (-237)))) (-15 -2232 ($ (-1 (-237) (-237) (-237) (-237)))) (-15 -1455 ($ (-405))) (-15 -2166 ($ (-658 (-1113 (-405))))) (-15 -2166 ($ (-658 (-1113 (-433 (-592)))))) (-15 -1443 ($ (-658 (-1113 (-405))))) (-15 -2366 ($ (-1150 (-237)))) (-15 -2380 ($ (-944))) (-15 -4339 ($ (-944))) (-15 -3267 ($ (-944))) (-15 -3302 ($ (-1 (-971 (-237)) (-971 (-237))))) (-15 -4509 ($ (-658 (-405)))) (-15 -3199 ((-3 (-57) "failed") (-658 $) (-1191))) (-15 -1669 ((-141) (-658 $) (-1191)))))) (T -278)) 
+((-1804 (*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-278)))) (-3100 (*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-278)))) (-3678 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) (-5 *1 (-278)))) (-4116 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-278)))) (-2732 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-278)))) (-2553 (*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-278)))) (-3100 (*1 *1 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-278)))) (-2231 (*1 *1 *2) (-12 (-5 *2 (-1 (-971 (-237)) (-971 (-237)))) (-5 *1 (-278)))) (-2185 (*1 *1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-278)))) (-2185 (*1 *1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-278)))) (-3596 (*1 *1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-278)))) (-3596 (*1 *1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-278)))) (-2232 (*1 *1 *2) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *1 (-278)))) (-2232 (*1 *1 *2) (-12 (-5 *2 (-1 (-237) (-237) (-237))) (-5 *1 (-278)))) (-2232 (*1 *1 *2) (-12 (-5 *2 (-1 (-237) (-237) (-237) (-237))) (-5 *1 (-278)))) (-1455 (*1 *1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-278)))) (-2166 (*1 *1 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-278)))) (-2166 (*1 *1 *2) (-12 (-5 *2 (-658 (-1113 (-433 (-592))))) (-5 *1 (-278)))) (-1443 (*1 *1 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-278)))) (-2366 (*1 *1 *2) (-12 (-5 *2 (-1150 (-237))) (-5 *1 (-278)))) (-2380 (*1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-278)))) (-4339 (*1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-278)))) (-3267 (*1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-278)))) (-3302 (*1 *1 *2) (-12 (-5 *2 (-1 (-971 (-237)) (-971 (-237)))) (-5 *1 (-278)))) (-4509 (*1 *1 *2) (-12 (-5 *2 (-658 (-405))) (-5 *1 (-278)))) (-3199 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-658 (-278))) (-5 *4 (-1191)) (-5 *2 (-57)) (-5 *1 (-278)))) (-1669 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-278))) (-5 *4 (-1191)) (-5 *2 (-141)) (-5 *1 (-278))))) 
+(-13 (-1119) (-10 -8 (-15 -1804 ($ (-141))) (-15 -3100 ($ (-141))) (-15 -3678 ($ (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))))) (-15 -4116 ($ (-1173))) (-15 -2732 ($ (-1173))) (-15 -2553 ($ (-141))) (-15 -3100 ($ (-658 (-1113 (-405))))) (-15 -2231 ($ (-1 (-971 (-237)) (-971 (-237))))) (-15 -2185 ($ (-405))) (-15 -2185 ($ (-896))) (-15 -3596 ($ (-405))) (-15 -3596 ($ (-896))) (-15 -2232 ($ (-1 (-237) (-237)))) (-15 -2232 ($ (-1 (-237) (-237) (-237)))) (-15 -2232 ($ (-1 (-237) (-237) (-237) (-237)))) (-15 -1455 ($ (-405))) (-15 -2166 ($ (-658 (-1113 (-405))))) (-15 -2166 ($ (-658 (-1113 (-433 (-592)))))) (-15 -1443 ($ (-658 (-1113 (-405))))) (-15 -2366 ($ (-1150 (-237)))) (-15 -2380 ($ (-944))) (-15 -4339 ($ (-944))) (-15 -3267 ($ (-944))) (-15 -3302 ($ (-1 (-971 (-237)) (-971 (-237))))) (-15 -4509 ($ (-658 (-405)))) (-15 -3199 ((-3 (-57) "failed") (-658 $) (-1191))) (-15 -1669 ((-141) (-658 $) (-1191))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1399 (((-658 (-790)) $) NIL) (((-658 (-790)) $ |#2|) NIL)) (-3775 (((-790) $) NIL) (((-790) $ |#2|) NIL)) (-4085 (((-658 |#3|) $) NIL)) (-4492 (((-1187 $) $ |#3|) NIL) (((-1187 |#1|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 |#3|)) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-1885 (($ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 |#3| "failed") $) NIL) (((-3 |#2| "failed") $) NIL) (((-3 (-1142 |#1| |#2|) "failed") $) 20)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) ((|#3| $) NIL) ((|#2| $) NIL) (((-1142 |#1| |#2|) $) NIL)) (-1544 (($ $ $ |#3|) NIL (|has| |#1| (-194)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ |#3|) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-558 |#3|) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| |#1| (-908 (-405))) (|has| |#3| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| |#1| (-908 (-592))) (|has| |#3| (-908 (-592)))))) (-4346 (((-790) $ |#2|) NIL) (((-790) $) 10)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-4533 (($ (-1187 |#1|) |#3|) NIL) (($ (-1187 $) |#3|) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-558 |#3|)) NIL) (($ $ |#3| (-790)) NIL) (($ $ (-658 |#3|) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ |#3|) NIL)) (-4206 (((-558 |#3|) $) NIL) (((-790) $ |#3|) NIL) (((-658 (-790)) $ (-658 |#3|)) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-558 |#3|) (-558 |#3|)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3358 (((-1 $ (-790)) |#2|) NIL) (((-1 $ (-790)) $) NIL (|has| |#1| (-247)))) (-3254 (((-3 |#3| "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-1692 ((|#3| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-4401 (((-141) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| |#3|) (|:| -3215 (-790))) "failed") $) NIL)) (-3198 (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ |#3| |#1|) NIL) (($ $ (-658 |#3|) (-658 |#1|)) NIL) (($ $ |#3| $) NIL) (($ $ (-658 |#3|) (-658 $)) NIL) (($ $ |#2| $) NIL (|has| |#1| (-247))) (($ $ (-658 |#2|) (-658 $)) NIL (|has| |#1| (-247))) (($ $ |#2| |#1|) NIL (|has| |#1| (-247))) (($ $ (-658 |#2|) (-658 |#1|)) NIL (|has| |#1| (-247)))) (-1482 (($ $ |#3|) NIL (|has| |#1| (-194)))) (-3644 (($ $ |#3|) NIL) (($ $ (-658 |#3|)) NIL) (($ $ |#3| (-790)) NIL) (($ $ (-658 |#3|) (-658 (-790))) NIL) (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2912 (((-658 |#2|) $) NIL)) (-4525 (((-558 |#3|) $) NIL) (((-790) $ |#3|) NIL) (((-658 (-790)) $ (-658 |#3|)) NIL) (((-790) $ |#2|) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#3| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#3| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| |#1| (-633 (-565))) (|has| |#3| (-633 (-565)))))) (-1554 ((|#1| $) NIL (|has| |#1| (-477))) (($ $ |#3|) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) 23) (($ |#3|) 22) (($ |#2|) NIL) (($ (-1142 |#1| |#2|)) 28) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-558 |#3|)) NIL) (($ $ |#3| (-790)) NIL) (($ $ (-658 |#3|) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ |#3|) NIL) (($ $ (-658 |#3|)) NIL) (($ $ |#3| (-790)) NIL) (($ $ (-658 |#3|) (-658 (-790))) NIL) (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-279 |#1| |#2| |#3|) (-13 (-268 |#1| |#2| |#3| (-558 |#3|)) (-1065 (-1142 |#1| |#2|))) (-1075) (-869) (-284 |#2|)) (T -279)) 
+NIL 
+(-13 (-268 |#1| |#2| |#3| (-558 |#3|)) (-1065 (-1142 |#1| |#2|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-2836 (($ |#1| (-658 $)) 51) (($ |#1|) 50) (($ (-658 |#1|)) 49)) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-3001 (($) 7 T CONST)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44)) (-2920 (((-592) $ $) 41)) (-3228 (((-141) $) 43)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-280 |#1|) (-1311) (-1119)) (T -280)) 
+((-2836 (*1 *1 *2 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-280 *2)) (-4 *2 (-1119)))) (-2836 (*1 *1 *2) (-12 (-4 *1 (-280 *2)) (-4 *2 (-1119)))) (-2836 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-280 *3))))) 
+(-13 (-1038 |t#1|) (-10 -8 (-6 -4626) (-6 -4625) (-15 -2836 ($ |t#1| (-658 $))) (-15 -2836 ($ |t#1|)) (-15 -2836 ($ (-658 |t#1|))))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1038 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) 12)) (-2836 (($ |#1| (-658 $)) 31) (($ |#1|) 32) (($ (-658 |#1|)) 33)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) 35 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 34 (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-4063 (((-658 |#1|) $) 22)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3767 (((-141) (-141)) 18) (((-141)) 19)) (-1736 (((-877) $) 15)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1589 (((-1173) $) 28)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ "value") NIL)) (-2920 (((-592) $ $) NIL)) (-3228 (((-141) $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-877) $) 30 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 8)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 26 (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-281 |#1|) (-13 (-280 |#1|) (-10 -8 (-15 -1589 ((-1173) $)) (-15 -1736 ((-877) $)) (-15 -3767 ((-141) (-141))) (-15 -3767 ((-141))))) (-1119)) (T -281)) 
+((-1589 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-281 *3)) (-4 *3 (-1119)))) (-1736 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-281 *3)) (-4 *3 (-1119)))) (-3767 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-281 *3)) (-4 *3 (-1119)))) (-3767 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-281 *3)) (-4 *3 (-1119))))) 
+(-13 (-280 |#1|) (-10 -8 (-15 -1589 ((-1173) $)) (-15 -1736 ((-877) $)) (-15 -3767 ((-141) (-141))) (-15 -3767 ((-141))))) 
+((-3375 (((-1285) |#10| (-658 |#3|)) 133) (((-1285) |#10|) 135)) (-1780 (((-1285) |#10|) NIL)) (-2869 ((|#8| |#10|) 28)) (-1747 (((-592) (-790) (-658 |#10|)) 147)) (-4537 (((-790) (-790) (-658 |#10|)) 145)) (-3567 (((-592) |#3|) 148)) (-3918 (((-790) |#3|) 146)) (-1479 (((-1285) |#10|) 136)) (-4052 ((|#8| |#3| |#10|) 111)) (-1685 ((|#10| |#5| |#3|) 138)) (-3166 (((-658 |#10|) |#3|) 144)) (-1795 (((-1285) |#10|) 134)) (-3821 (((-658 |#9|) |#9|) 87)) (-2269 ((|#8| |#10|) 110))) 
+(((-282 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -3821 ((-658 |#9|) |#9|)) (-15 -4052 (|#8| |#3| |#10|)) (-15 -2269 (|#8| |#10|)) (-15 -1795 ((-1285) |#10|)) (-15 -1685 (|#10| |#5| |#3|)) (-15 -3166 ((-658 |#10|) |#3|)) (-15 -1479 ((-1285) |#10|)) (-15 -1780 ((-1285) |#10|)) (-15 -3375 ((-1285) |#10|)) (-15 -3375 ((-1285) |#10| (-658 |#3|))) (-15 -3918 ((-790) |#3|)) (-15 -3567 ((-592) |#3|)) (-15 -4537 ((-790) (-790) (-658 |#10|))) (-15 -2869 (|#8| |#10|)) (-15 -1747 ((-592) (-790) (-658 |#10|)))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|) (-665 |#1|) (-947 |#1| |#6|) (-257 |#7|) (-560 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-280 |#9|) (-137)) (T -282)) 
+((-1747 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *14)) (-4 *14 (-280 *13)) (-4 *13 (-560 *5 *6 *7 *8 *9 *10 *11 *12 *15)) (-4 *15 (-137)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) *3)) (-4 *9 (-999 *5)) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-4 *12 (-257 *11)) (-5 *3 (-790)) (-5 *2 (-592)) (-5 *1 (-282 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15)))) (-2869 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-560 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *10)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-280 *11)))) (-4537 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *13)) (-4 *13 (-280 *12)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) *2)) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-5 *2 (-790)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)))) (-3567 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-592)) (-5 *1 (-282 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3918 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) *2)) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-790)) (-5 *1 (-282 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3375 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *7)) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) (-790))) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *9 (-999 *5)) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-4 *12 (-257 *11)) (-4 *13 (-560 *5 *6 *7 *8 *9 *10 *11 *12 *14)) (-4 *14 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (-4 *3 (-280 *13)))) (-3375 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-280 *12)))) (-1780 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-280 *12)))) (-1479 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-280 *12)))) (-3166 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *12)) (-5 *1 (-282 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-1685 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *4 (-977 *5 *7 (-879 *6))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *3 (-999 *5)) (-4 *8 (-665 *5)) (-4 *9 (-947 *5 *8)) (-4 *10 (-257 *9)) (-4 *12 (-137)) (-4 *2 (-280 *11)) (-5 *1 (-282 *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (-4 *11 (-560 *5 *6 *4 *7 *3 *8 *9 *10 *12)))) (-1795 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-280 *12)))) (-2269 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-560 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *10)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-280 *11)))) (-4052 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *8 (-999 *5)) (-4 *9 (-665 *5)) (-4 *10 (-947 *5 *9)) (-4 *11 (-560 *5 *6 *3 *7 *8 *9 *10 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *10)) (-5 *1 (-282 *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (-4 *4 (-280 *11)))) (-3821 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *3 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-658 *3)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (-4 *12 (-280 *3))))) 
+(-10 -7 (-15 -3821 ((-658 |#9|) |#9|)) (-15 -4052 (|#8| |#3| |#10|)) (-15 -2269 (|#8| |#10|)) (-15 -1795 ((-1285) |#10|)) (-15 -1685 (|#10| |#5| |#3|)) (-15 -3166 ((-658 |#10|) |#3|)) (-15 -1479 ((-1285) |#10|)) (-15 -1780 ((-1285) |#10|)) (-15 -3375 ((-1285) |#10|)) (-15 -3375 ((-1285) |#10| (-658 |#3|))) (-15 -3918 ((-790) |#3|)) (-15 -3567 ((-592) |#3|)) (-15 -4537 ((-790) (-790) (-658 |#10|))) (-15 -2869 (|#8| |#10|)) (-15 -1747 ((-592) (-790) (-658 |#10|)))) 
+((-3775 (((-790) $) 30)) (-4368 (((-3 |#2| "failed") $) 17)) (-2400 ((|#2| $) 27)) (-3644 (($ $) 12) (($ $ (-790)) 15)) (-1683 (((-877) $) 26) (($ |#2|) 10)) (-3255 (((-141) $ $) 20)) (-3266 (((-141) $ $) 29))) 
+(((-283 |#1| |#2|) (-10 -8 (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1|)) (-15 -3775 ((-790) |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) (-284 |#2|) (-869)) (T -283)) 
+NIL 
+(-10 -8 (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1|)) (-15 -3775 ((-790) |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-3775 (((-790) $) 21)) (-3983 ((|#1| $) 22)) (-4368 (((-3 |#1| "failed") $) 26)) (-2400 ((|#1| $) 25)) (-4346 (((-790) $) 23)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-3358 (($ |#1| (-790)) 24)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3644 (($ $) 20) (($ $ (-790)) 19)) (-1683 (((-877) $) 11) (($ |#1|) 27)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17))) 
+(((-284 |#1|) (-1311) (-869)) (T -284)) 
+((-1683 (*1 *1 *2) (-12 (-4 *1 (-284 *2)) (-4 *2 (-869)))) (-3358 (*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-284 *2)) (-4 *2 (-869)))) (-4346 (*1 *2 *1) (-12 (-4 *1 (-284 *3)) (-4 *3 (-869)) (-5 *2 (-790)))) (-3983 (*1 *2 *1) (-12 (-4 *1 (-284 *2)) (-4 *2 (-869)))) (-3775 (*1 *2 *1) (-12 (-4 *1 (-284 *3)) (-4 *3 (-869)) (-5 *2 (-790)))) (-3644 (*1 *1 *1) (-12 (-4 *1 (-284 *2)) (-4 *2 (-869)))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-284 *3)) (-4 *3 (-869))))) 
+(-13 (-869) (-1065 |t#1|) (-10 -8 (-15 -3358 ($ |t#1| (-790))) (-15 -4346 ((-790) $)) (-15 -3983 (|t#1| $)) (-15 -3775 ((-790) $)) (-15 -3644 ($ $)) (-15 -3644 ($ $ (-790))) (-15 -1683 ($ |t#1|)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-869) . T) ((-1065 |#1|) . T) ((-1119) . T)) 
+((-4085 (((-658 (-1191)) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 40)) (-2692 (((-658 (-1191)) (-332 (-237)) (-790)) 79)) (-3017 (((-3 (-332 (-237)) "failed") (-332 (-237))) 50)) (-3505 (((-332 (-237)) (-332 (-237))) 65)) (-2442 (((-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 26)) (-3231 (((-141) (-658 (-332 (-237)))) 83)) (-3104 (((-141) (-332 (-237))) 24)) (-2281 (((-658 (-1173)) (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))) 104)) (-2386 (((-658 (-332 (-237))) (-658 (-332 (-237)))) 86)) (-1952 (((-658 (-332 (-237))) (-658 (-332 (-237)))) 85)) (-1530 (((-706 (-237)) (-658 (-332 (-237))) (-790)) 93)) (-2365 (((-141) (-332 (-237))) 20) (((-141) (-658 (-332 (-237)))) 84)) (-3537 (((-658 (-237)) (-658 (-862 (-237))) (-237)) 14)) (-2552 (((-405) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 99)) (-2326 (((-1063) (-1191) (-1063)) 33))) 
+(((-285) (-10 -7 (-15 -3537 ((-658 (-237)) (-658 (-862 (-237))) (-237))) (-15 -2442 ((-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))))) (-15 -3017 ((-3 (-332 (-237)) "failed") (-332 (-237)))) (-15 -3505 ((-332 (-237)) (-332 (-237)))) (-15 -3231 ((-141) (-658 (-332 (-237))))) (-15 -2365 ((-141) (-658 (-332 (-237))))) (-15 -2365 ((-141) (-332 (-237)))) (-15 -1530 ((-706 (-237)) (-658 (-332 (-237))) (-790))) (-15 -1952 ((-658 (-332 (-237))) (-658 (-332 (-237))))) (-15 -2386 ((-658 (-332 (-237))) (-658 (-332 (-237))))) (-15 -3104 ((-141) (-332 (-237)))) (-15 -4085 ((-658 (-1191)) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) (-15 -2692 ((-658 (-1191)) (-332 (-237)) (-790))) (-15 -2326 ((-1063) (-1191) (-1063))) (-15 -2552 ((-405) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) (-15 -2281 ((-658 (-1173)) (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))))))) (T -285)) 
+((-2281 (*1 *2 *3) (-12 (-5 *3 (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))) (-5 *2 (-658 (-1173))) (-5 *1 (-285)))) (-2552 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *2 (-405)) (-5 *1 (-285)))) (-2326 (*1 *2 *3 *2) (-12 (-5 *2 (-1063)) (-5 *3 (-1191)) (-5 *1 (-285)))) (-2692 (*1 *2 *3 *4) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-790)) (-5 *2 (-658 (-1191))) (-5 *1 (-285)))) (-4085 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *2 (-658 (-1191))) (-5 *1 (-285)))) (-3104 (*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-141)) (-5 *1 (-285)))) (-2386 (*1 *2 *2) (-12 (-5 *2 (-658 (-332 (-237)))) (-5 *1 (-285)))) (-1952 (*1 *2 *2) (-12 (-5 *2 (-658 (-332 (-237)))) (-5 *1 (-285)))) (-1530 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-332 (-237)))) (-5 *4 (-790)) (-5 *2 (-706 (-237))) (-5 *1 (-285)))) (-2365 (*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-141)) (-5 *1 (-285)))) (-2365 (*1 *2 *3) (-12 (-5 *3 (-658 (-332 (-237)))) (-5 *2 (-141)) (-5 *1 (-285)))) (-3231 (*1 *2 *3) (-12 (-5 *3 (-658 (-332 (-237)))) (-5 *2 (-141)) (-5 *1 (-285)))) (-3505 (*1 *2 *2) (-12 (-5 *2 (-332 (-237))) (-5 *1 (-285)))) (-3017 (*1 *2 *2) (|partial| -12 (-5 *2 (-332 (-237))) (-5 *1 (-285)))) (-2442 (*1 *2 *2) (-12 (-5 *2 (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (-5 *1 (-285)))) (-3537 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-862 (-237)))) (-5 *4 (-237)) (-5 *2 (-658 *4)) (-5 *1 (-285))))) 
+(-10 -7 (-15 -3537 ((-658 (-237)) (-658 (-862 (-237))) (-237))) (-15 -2442 ((-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))))) (-15 -3017 ((-3 (-332 (-237)) "failed") (-332 (-237)))) (-15 -3505 ((-332 (-237)) (-332 (-237)))) (-15 -3231 ((-141) (-658 (-332 (-237))))) (-15 -2365 ((-141) (-658 (-332 (-237))))) (-15 -2365 ((-141) (-332 (-237)))) (-15 -1530 ((-706 (-237)) (-658 (-332 (-237))) (-790))) (-15 -1952 ((-658 (-332 (-237))) (-658 (-332 (-237))))) (-15 -2386 ((-658 (-332 (-237))) (-658 (-332 (-237))))) (-15 -3104 ((-141) (-332 (-237)))) (-15 -4085 ((-658 (-1191)) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) (-15 -2692 ((-658 (-1191)) (-332 (-237)) (-790))) (-15 -2326 ((-1063) (-1191) (-1063))) (-15 -2552 ((-405) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) (-15 -2281 ((-658 (-1173)) (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))))) 
+((-1641 (((-141) $ $) NIL)) (-1432 (((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 39)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 20) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-286) (-858)) (T -286)) 
+NIL 
+(-858) 
+((-1641 (((-141) $ $) NIL)) (-1432 (((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 54) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 49)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 29) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 31)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-287) (-858)) (T -287)) 
+NIL 
+(-858) 
+((-1641 (((-141) $ $) NIL)) (-1432 (((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 73) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 69)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 40) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 51)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-288) (-858)) (T -288)) 
+NIL 
+(-858) 
+((-1641 (((-141) $ $) NIL)) (-1432 (((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 48)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 27) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-289) (-858)) (T -289)) 
+NIL 
+(-858) 
+((-1641 (((-141) $ $) NIL)) (-1432 (((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 48)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 23) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-290) (-858)) (T -290)) 
+NIL 
+(-858) 
+((-1641 (((-141) $ $) NIL)) (-1432 (((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 69)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 23) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-291) (-858)) (T -291)) 
+NIL 
+(-858) 
+((-1641 (((-141) $ $) NIL)) (-1432 (((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 73)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 19) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-292) (-858)) (T -292)) 
+NIL 
+(-858) 
+((-1641 (((-141) $ $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2524 (((-658 (-592)) $) 16)) (-4525 (((-790) $) 14)) (-1683 (((-877) $) 20) (($ (-658 (-592))) 12)) (-1428 (($ (-790)) 17)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 9)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 10))) 
+(((-293) (-13 (-869) (-10 -8 (-15 -1683 ($ (-658 (-592)))) (-15 -4525 ((-790) $)) (-15 -2524 ((-658 (-592)) $)) (-15 -1428 ($ (-790)))))) (T -293)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-293)))) (-4525 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-293)))) (-2524 (*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-293)))) (-1428 (*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-293))))) 
+(-13 (-869) (-10 -8 (-15 -1683 ($ (-658 (-592)))) (-15 -4525 ((-790) $)) (-15 -2524 ((-658 (-592)) $)) (-15 -1428 ($ (-790))))) 
+((-1588 ((|#2| |#2|) 77)) (-1507 ((|#2| |#2|) 65)) (-4392 (((-3 |#2| "failed") |#2| (-658 (-2 (|:| |func| |#2|) (|:| |pole| (-141))))) 116)) (-1575 ((|#2| |#2|) 75)) (-1495 ((|#2| |#2|) 63)) (-1601 ((|#2| |#2|) 79)) (-1521 ((|#2| |#2|) 67)) (-1435 ((|#2|) 46)) (-2791 (((-143) (-143)) 95)) (-4546 ((|#2| |#2|) 61)) (-2186 (((-141) |#2|) 134)) (-4504 ((|#2| |#2|) 180)) (-3556 ((|#2| |#2|) 156)) (-3307 ((|#2|) 59)) (-3036 ((|#2|) 58)) (-4207 ((|#2| |#2|) 176)) (-2052 ((|#2| |#2|) 152)) (-1959 ((|#2| |#2|) 184)) (-2099 ((|#2| |#2|) 160)) (-4181 ((|#2| |#2|) 148)) (-1427 ((|#2| |#2|) 150)) (-1856 ((|#2| |#2|) 186)) (-2124 ((|#2| |#2|) 162)) (-3798 ((|#2| |#2|) 182)) (-1881 ((|#2| |#2|) 158)) (-3738 ((|#2| |#2|) 178)) (-2364 ((|#2| |#2|) 154)) (-1710 ((|#2| |#2|) 192)) (-4264 ((|#2| |#2|) 168)) (-2851 ((|#2| |#2|) 188)) (-4089 ((|#2| |#2|) 164)) (-2571 ((|#2| |#2|) 196)) (-1386 ((|#2| |#2|) 172)) (-2389 ((|#2| |#2|) 198)) (-4465 ((|#2| |#2|) 174)) (-1364 ((|#2| |#2|) 194)) (-1932 ((|#2| |#2|) 170)) (-2465 ((|#2| |#2|) 190)) (-1757 ((|#2| |#2|) 166)) (-1430 ((|#2| |#2|) 62)) (-1609 ((|#2| |#2|) 80)) (-1527 ((|#2| |#2|) 68)) (-1594 ((|#2| |#2|) 78)) (-1515 ((|#2| |#2|) 66)) (-1581 ((|#2| |#2|) 76)) (-1501 ((|#2| |#2|) 64)) (-3038 (((-141) (-143)) 93)) (-1630 ((|#2| |#2|) 83)) (-1546 ((|#2| |#2|) 71)) (-1617 ((|#2| |#2|) 81)) (-1533 ((|#2| |#2|) 69)) (-1642 ((|#2| |#2|) 85)) (-1559 ((|#2| |#2|) 73)) (-2892 ((|#2| |#2|) 86)) (-1567 ((|#2| |#2|) 74)) (-1636 ((|#2| |#2|) 84)) (-1552 ((|#2| |#2|) 72)) (-1624 ((|#2| |#2|) 82)) (-1540 ((|#2| |#2|) 70))) 
+(((-294 |#1| |#2|) (-10 -7 (-15 -1430 (|#2| |#2|)) (-15 -4546 (|#2| |#2|)) (-15 -1495 (|#2| |#2|)) (-15 -1501 (|#2| |#2|)) (-15 -1507 (|#2| |#2|)) (-15 -1515 (|#2| |#2|)) (-15 -1521 (|#2| |#2|)) (-15 -1527 (|#2| |#2|)) (-15 -1533 (|#2| |#2|)) (-15 -1540 (|#2| |#2|)) (-15 -1546 (|#2| |#2|)) (-15 -1552 (|#2| |#2|)) (-15 -1559 (|#2| |#2|)) (-15 -1567 (|#2| |#2|)) (-15 -1575 (|#2| |#2|)) (-15 -1581 (|#2| |#2|)) (-15 -1588 (|#2| |#2|)) (-15 -1594 (|#2| |#2|)) (-15 -1601 (|#2| |#2|)) (-15 -1609 (|#2| |#2|)) (-15 -1617 (|#2| |#2|)) (-15 -1624 (|#2| |#2|)) (-15 -1630 (|#2| |#2|)) (-15 -1636 (|#2| |#2|)) (-15 -1642 (|#2| |#2|)) (-15 -2892 (|#2| |#2|)) (-15 -1435 (|#2|)) (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -3036 (|#2|)) (-15 -3307 (|#2|)) (-15 -1427 (|#2| |#2|)) (-15 -4181 (|#2| |#2|)) (-15 -2052 (|#2| |#2|)) (-15 -2364 (|#2| |#2|)) (-15 -3556 (|#2| |#2|)) (-15 -1881 (|#2| |#2|)) (-15 -2099 (|#2| |#2|)) (-15 -2124 (|#2| |#2|)) (-15 -4089 (|#2| |#2|)) (-15 -1757 (|#2| |#2|)) (-15 -4264 (|#2| |#2|)) (-15 -1932 (|#2| |#2|)) (-15 -1386 (|#2| |#2|)) (-15 -4465 (|#2| |#2|)) (-15 -4207 (|#2| |#2|)) (-15 -3738 (|#2| |#2|)) (-15 -4504 (|#2| |#2|)) (-15 -3798 (|#2| |#2|)) (-15 -1959 (|#2| |#2|)) (-15 -1856 (|#2| |#2|)) (-15 -2851 (|#2| |#2|)) (-15 -2465 (|#2| |#2|)) (-15 -1710 (|#2| |#2|)) (-15 -1364 (|#2| |#2|)) (-15 -2571 (|#2| |#2|)) (-15 -2389 (|#2| |#2|)) (-15 -4392 ((-3 |#2| "failed") |#2| (-658 (-2 (|:| |func| |#2|) (|:| |pole| (-141)))))) (-15 -2186 ((-141) |#2|))) (-13 (-869) (-582)) (-13 (-456 |#1|) (-1030))) (T -294)) 
+((-2186 (*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-294 *4 *3)) (-4 *3 (-13 (-456 *4) (-1030))))) (-4392 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-658 (-2 (|:| |func| *2) (|:| |pole| (-141))))) (-4 *2 (-13 (-456 *4) (-1030))) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-294 *4 *2)))) (-2389 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-2571 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1364 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1710 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-2465 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-2851 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1856 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1959 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-3798 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-4504 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-3738 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-4207 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-4465 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1386 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1932 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-4264 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1757 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-4089 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-2124 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-2099 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1881 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-3556 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-2364 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-2052 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-4181 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1427 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-3307 (*1 *2) (-12 (-4 *2 (-13 (-456 *3) (-1030))) (-5 *1 (-294 *3 *2)) (-4 *3 (-13 (-869) (-582))))) (-3036 (*1 *2) (-12 (-4 *2 (-13 (-456 *3) (-1030))) (-5 *1 (-294 *3 *2)) (-4 *3 (-13 (-869) (-582))))) (-2791 (*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *4)) (-4 *4 (-13 (-456 *3) (-1030))))) (-3038 (*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-294 *4 *5)) (-4 *5 (-13 (-456 *4) (-1030))))) (-1435 (*1 *2) (-12 (-4 *2 (-13 (-456 *3) (-1030))) (-5 *1 (-294 *3 *2)) (-4 *3 (-13 (-869) (-582))))) (-2892 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1642 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1636 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1630 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1624 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1617 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1609 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1601 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1594 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1588 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1581 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1575 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1567 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1559 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1552 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1546 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1540 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1533 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1527 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1521 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1515 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1507 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1501 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1495 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-4546 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) (-1430 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(-10 -7 (-15 -1430 (|#2| |#2|)) (-15 -4546 (|#2| |#2|)) (-15 -1495 (|#2| |#2|)) (-15 -1501 (|#2| |#2|)) (-15 -1507 (|#2| |#2|)) (-15 -1515 (|#2| |#2|)) (-15 -1521 (|#2| |#2|)) (-15 -1527 (|#2| |#2|)) (-15 -1533 (|#2| |#2|)) (-15 -1540 (|#2| |#2|)) (-15 -1546 (|#2| |#2|)) (-15 -1552 (|#2| |#2|)) (-15 -1559 (|#2| |#2|)) (-15 -1567 (|#2| |#2|)) (-15 -1575 (|#2| |#2|)) (-15 -1581 (|#2| |#2|)) (-15 -1588 (|#2| |#2|)) (-15 -1594 (|#2| |#2|)) (-15 -1601 (|#2| |#2|)) (-15 -1609 (|#2| |#2|)) (-15 -1617 (|#2| |#2|)) (-15 -1624 (|#2| |#2|)) (-15 -1630 (|#2| |#2|)) (-15 -1636 (|#2| |#2|)) (-15 -1642 (|#2| |#2|)) (-15 -2892 (|#2| |#2|)) (-15 -1435 (|#2|)) (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -3036 (|#2|)) (-15 -3307 (|#2|)) (-15 -1427 (|#2| |#2|)) (-15 -4181 (|#2| |#2|)) (-15 -2052 (|#2| |#2|)) (-15 -2364 (|#2| |#2|)) (-15 -3556 (|#2| |#2|)) (-15 -1881 (|#2| |#2|)) (-15 -2099 (|#2| |#2|)) (-15 -2124 (|#2| |#2|)) (-15 -4089 (|#2| |#2|)) (-15 -1757 (|#2| |#2|)) (-15 -4264 (|#2| |#2|)) (-15 -1932 (|#2| |#2|)) (-15 -1386 (|#2| |#2|)) (-15 -4465 (|#2| |#2|)) (-15 -4207 (|#2| |#2|)) (-15 -3738 (|#2| |#2|)) (-15 -4504 (|#2| |#2|)) (-15 -3798 (|#2| |#2|)) (-15 -1959 (|#2| |#2|)) (-15 -1856 (|#2| |#2|)) (-15 -2851 (|#2| |#2|)) (-15 -2465 (|#2| |#2|)) (-15 -1710 (|#2| |#2|)) (-15 -1364 (|#2| |#2|)) (-15 -2571 (|#2| |#2|)) (-15 -2389 (|#2| |#2|)) (-15 -4392 ((-3 |#2| "failed") |#2| (-658 (-2 (|:| |func| |#2|) (|:| |pole| (-141)))))) (-15 -2186 ((-141) |#2|))) 
+((-2889 (((-3 |#2| "failed") (-658 (-631 |#2|)) |#2| (-1191)) 133)) (-2110 ((|#2| (-433 (-592)) |#2|) 50)) (-3425 ((|#2| |#2| (-631 |#2|)) 126)) (-2727 (((-2 (|:| |func| |#2|) (|:| |kers| (-658 (-631 |#2|))) (|:| |vals| (-658 |#2|))) |#2| (-1191)) 125)) (-4362 ((|#2| |#2| (-1191)) 19) ((|#2| |#2|) 22)) (-4398 ((|#2| |#2| (-1191)) 139) ((|#2| |#2|) 137))) 
+(((-295 |#1| |#2|) (-10 -7 (-15 -4398 (|#2| |#2|)) (-15 -4398 (|#2| |#2| (-1191))) (-15 -2727 ((-2 (|:| |func| |#2|) (|:| |kers| (-658 (-631 |#2|))) (|:| |vals| (-658 |#2|))) |#2| (-1191))) (-15 -4362 (|#2| |#2|)) (-15 -4362 (|#2| |#2| (-1191))) (-15 -2889 ((-3 |#2| "failed") (-658 (-631 |#2|)) |#2| (-1191))) (-15 -3425 (|#2| |#2| (-631 |#2|))) (-15 -2110 (|#2| (-433 (-592)) |#2|))) (-13 (-582) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|))) (T -295)) 
+((-2110 (*1 *2 *3 *2) (-12 (-5 *3 (-433 (-592))) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))))) (-3425 (*1 *2 *2 *3) (-12 (-5 *3 (-631 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *4 *2)))) (-2889 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-658 (-631 *2))) (-5 *4 (-1191)) (-4 *2 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *5 *2)))) (-4362 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))))) (-4362 (*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) (-2727 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-2 (|:| |func| *3) (|:| |kers| (-658 (-631 *3))) (|:| |vals| (-658 *3)))) (-5 *1 (-295 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-4398 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))))) (-4398 (*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3)))))) 
+(-10 -7 (-15 -4398 (|#2| |#2|)) (-15 -4398 (|#2| |#2| (-1191))) (-15 -2727 ((-2 (|:| |func| |#2|) (|:| |kers| (-658 (-631 |#2|))) (|:| |vals| (-658 |#2|))) |#2| (-1191))) (-15 -4362 (|#2| |#2|)) (-15 -4362 (|#2| |#2| (-1191))) (-15 -2889 ((-3 |#2| "failed") (-658 (-631 |#2|)) |#2| (-1191))) (-15 -3425 (|#2| |#2| (-631 |#2|))) (-15 -2110 (|#2| (-433 (-592)) |#2|))) 
+((-2698 (((-3 |#3| "failed") |#3|) 110)) (-1588 ((|#3| |#3|) 131)) (-2540 (((-3 |#3| "failed") |#3|) 82)) (-1507 ((|#3| |#3|) 121)) (-4494 (((-3 |#3| "failed") |#3|) 58)) (-1575 ((|#3| |#3|) 129)) (-1923 (((-3 |#3| "failed") |#3|) 46)) (-1495 ((|#3| |#3|) 119)) (-1890 (((-3 |#3| "failed") |#3|) 112)) (-1601 ((|#3| |#3|) 133)) (-2063 (((-3 |#3| "failed") |#3|) 84)) (-1521 ((|#3| |#3|) 123)) (-1784 (((-3 |#3| "failed") |#3| (-790)) 36)) (-2548 (((-3 |#3| "failed") |#3|) 74)) (-4546 ((|#3| |#3|) 118)) (-4122 (((-3 |#3| "failed") |#3|) 44)) (-1430 ((|#3| |#3|) 117)) (-1415 (((-3 |#3| "failed") |#3|) 113)) (-1609 ((|#3| |#3|) 134)) (-2478 (((-3 |#3| "failed") |#3|) 85)) (-1527 ((|#3| |#3|) 124)) (-4208 (((-3 |#3| "failed") |#3|) 111)) (-1594 ((|#3| |#3|) 132)) (-2345 (((-3 |#3| "failed") |#3|) 83)) (-1515 ((|#3| |#3|) 122)) (-2966 (((-3 |#3| "failed") |#3|) 60)) (-1581 ((|#3| |#3|) 130)) (-2989 (((-3 |#3| "failed") |#3|) 48)) (-1501 ((|#3| |#3|) 120)) (-1650 (((-3 |#3| "failed") |#3|) 66)) (-1630 ((|#3| |#3|) 137)) (-3209 (((-3 |#3| "failed") |#3|) 104)) (-1546 ((|#3| |#3|) 142)) (-2416 (((-3 |#3| "failed") |#3|) 62)) (-1617 ((|#3| |#3|) 135)) (-4352 (((-3 |#3| "failed") |#3|) 50)) (-1533 ((|#3| |#3|) 125)) (-4069 (((-3 |#3| "failed") |#3|) 70)) (-1642 ((|#3| |#3|) 139)) (-3691 (((-3 |#3| "failed") |#3|) 54)) (-1559 ((|#3| |#3|) 127)) (-2590 (((-3 |#3| "failed") |#3|) 72)) (-2892 ((|#3| |#3|) 140)) (-1349 (((-3 |#3| "failed") |#3|) 56)) (-1567 ((|#3| |#3|) 128)) (-2295 (((-3 |#3| "failed") |#3|) 68)) (-1636 ((|#3| |#3|) 138)) (-2233 (((-3 |#3| "failed") |#3|) 107)) (-1552 ((|#3| |#3|) 143)) (-1510 (((-3 |#3| "failed") |#3|) 64)) (-1624 ((|#3| |#3|) 136)) (-2153 (((-3 |#3| "failed") |#3|) 52)) (-1540 ((|#3| |#3|) 126)) (** ((|#3| |#3| (-433 (-592))) 40 (|has| |#1| (-388))))) 
+(((-296 |#1| |#2| |#3|) (-13 (-1012 |#3|) (-10 -7 (IF (|has| |#1| (-388)) (-15 ** (|#3| |#3| (-433 (-592)))) |noBranch|) (-15 -1430 (|#3| |#3|)) (-15 -4546 (|#3| |#3|)) (-15 -1495 (|#3| |#3|)) (-15 -1501 (|#3| |#3|)) (-15 -1507 (|#3| |#3|)) (-15 -1515 (|#3| |#3|)) (-15 -1521 (|#3| |#3|)) (-15 -1527 (|#3| |#3|)) (-15 -1533 (|#3| |#3|)) (-15 -1540 (|#3| |#3|)) (-15 -1546 (|#3| |#3|)) (-15 -1552 (|#3| |#3|)) (-15 -1559 (|#3| |#3|)) (-15 -1567 (|#3| |#3|)) (-15 -1575 (|#3| |#3|)) (-15 -1581 (|#3| |#3|)) (-15 -1588 (|#3| |#3|)) (-15 -1594 (|#3| |#3|)) (-15 -1601 (|#3| |#3|)) (-15 -1609 (|#3| |#3|)) (-15 -1617 (|#3| |#3|)) (-15 -1624 (|#3| |#3|)) (-15 -1630 (|#3| |#3|)) (-15 -1636 (|#3| |#3|)) (-15 -1642 (|#3| |#3|)) (-15 -2892 (|#3| |#3|)))) (-43 (-433 (-592))) (-1270 |#1|) (-1241 |#1| |#2|)) (T -296)) 
+((** (*1 *2 *2 *3) (-12 (-5 *3 (-433 (-592))) (-4 *4 (-388)) (-4 *4 (-43 *3)) (-4 *5 (-1270 *4)) (-5 *1 (-296 *4 *5 *2)) (-4 *2 (-1241 *4 *5)))) (-1430 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-4546 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1495 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1501 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1507 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1515 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1521 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1527 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1533 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1540 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1546 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1552 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1559 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1567 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1575 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1581 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1588 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1594 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1601 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1609 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1617 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1624 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1630 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1636 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-1642 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) (-2892 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4))))) 
+(-13 (-1012 |#3|) (-10 -7 (IF (|has| |#1| (-388)) (-15 ** (|#3| |#3| (-433 (-592)))) |noBranch|) (-15 -1430 (|#3| |#3|)) (-15 -4546 (|#3| |#3|)) (-15 -1495 (|#3| |#3|)) (-15 -1501 (|#3| |#3|)) (-15 -1507 (|#3| |#3|)) (-15 -1515 (|#3| |#3|)) (-15 -1521 (|#3| |#3|)) (-15 -1527 (|#3| |#3|)) (-15 -1533 (|#3| |#3|)) (-15 -1540 (|#3| |#3|)) (-15 -1546 (|#3| |#3|)) (-15 -1552 (|#3| |#3|)) (-15 -1559 (|#3| |#3|)) (-15 -1567 (|#3| |#3|)) (-15 -1575 (|#3| |#3|)) (-15 -1581 (|#3| |#3|)) (-15 -1588 (|#3| |#3|)) (-15 -1594 (|#3| |#3|)) (-15 -1601 (|#3| |#3|)) (-15 -1609 (|#3| |#3|)) (-15 -1617 (|#3| |#3|)) (-15 -1624 (|#3| |#3|)) (-15 -1630 (|#3| |#3|)) (-15 -1636 (|#3| |#3|)) (-15 -1642 (|#3| |#3|)) (-15 -2892 (|#3| |#3|)))) 
+((-2698 (((-3 |#3| "failed") |#3|) 66)) (-1588 ((|#3| |#3|) 133)) (-2540 (((-3 |#3| "failed") |#3|) 50)) (-1507 ((|#3| |#3|) 121)) (-4494 (((-3 |#3| "failed") |#3|) 62)) (-1575 ((|#3| |#3|) 131)) (-1923 (((-3 |#3| "failed") |#3|) 46)) (-1495 ((|#3| |#3|) 119)) (-1890 (((-3 |#3| "failed") |#3|) 70)) (-1601 ((|#3| |#3|) 135)) (-2063 (((-3 |#3| "failed") |#3|) 54)) (-1521 ((|#3| |#3|) 123)) (-1784 (((-3 |#3| "failed") |#3| (-790)) 35)) (-2548 (((-3 |#3| "failed") |#3|) 44)) (-4546 ((|#3| |#3|) 112)) (-4122 (((-3 |#3| "failed") |#3|) 42)) (-1430 ((|#3| |#3|) 118)) (-1415 (((-3 |#3| "failed") |#3|) 72)) (-1609 ((|#3| |#3|) 136)) (-2478 (((-3 |#3| "failed") |#3|) 56)) (-1527 ((|#3| |#3|) 124)) (-4208 (((-3 |#3| "failed") |#3|) 68)) (-1594 ((|#3| |#3|) 134)) (-2345 (((-3 |#3| "failed") |#3|) 52)) (-1515 ((|#3| |#3|) 122)) (-2966 (((-3 |#3| "failed") |#3|) 64)) (-1581 ((|#3| |#3|) 132)) (-2989 (((-3 |#3| "failed") |#3|) 48)) (-1501 ((|#3| |#3|) 120)) (-1650 (((-3 |#3| "failed") |#3|) 78)) (-1630 ((|#3| |#3|) 139)) (-3209 (((-3 |#3| "failed") |#3|) 58)) (-1546 ((|#3| |#3|) 127)) (-2416 (((-3 |#3| "failed") |#3|) 74)) (-1617 ((|#3| |#3|) 137)) (-4352 (((-3 |#3| "failed") |#3|) 102)) (-1533 ((|#3| |#3|) 125)) (-4069 (((-3 |#3| "failed") |#3|) 82)) (-1642 ((|#3| |#3|) 141)) (-3691 (((-3 |#3| "failed") |#3|) 109)) (-1559 ((|#3| |#3|) 129)) (-2590 (((-3 |#3| "failed") |#3|) 84)) (-2892 ((|#3| |#3|) 142)) (-1349 (((-3 |#3| "failed") |#3|) 111)) (-1567 ((|#3| |#3|) 130)) (-2295 (((-3 |#3| "failed") |#3|) 80)) (-1636 ((|#3| |#3|) 140)) (-2233 (((-3 |#3| "failed") |#3|) 60)) (-1552 ((|#3| |#3|) 128)) (-1510 (((-3 |#3| "failed") |#3|) 76)) (-1624 ((|#3| |#3|) 138)) (-2153 (((-3 |#3| "failed") |#3|) 105)) (-1540 ((|#3| |#3|) 126)) (** ((|#3| |#3| (-433 (-592))) 40 (|has| |#1| (-388))))) 
+(((-297 |#1| |#2| |#3| |#4|) (-13 (-1012 |#3|) (-10 -7 (IF (|has| |#1| (-388)) (-15 ** (|#3| |#3| (-433 (-592)))) |noBranch|) (-15 -1430 (|#3| |#3|)) (-15 -4546 (|#3| |#3|)) (-15 -1495 (|#3| |#3|)) (-15 -1501 (|#3| |#3|)) (-15 -1507 (|#3| |#3|)) (-15 -1515 (|#3| |#3|)) (-15 -1521 (|#3| |#3|)) (-15 -1527 (|#3| |#3|)) (-15 -1533 (|#3| |#3|)) (-15 -1540 (|#3| |#3|)) (-15 -1546 (|#3| |#3|)) (-15 -1552 (|#3| |#3|)) (-15 -1559 (|#3| |#3|)) (-15 -1567 (|#3| |#3|)) (-15 -1575 (|#3| |#3|)) (-15 -1581 (|#3| |#3|)) (-15 -1588 (|#3| |#3|)) (-15 -1594 (|#3| |#3|)) (-15 -1601 (|#3| |#3|)) (-15 -1609 (|#3| |#3|)) (-15 -1617 (|#3| |#3|)) (-15 -1624 (|#3| |#3|)) (-15 -1630 (|#3| |#3|)) (-15 -1636 (|#3| |#3|)) (-15 -1642 (|#3| |#3|)) (-15 -2892 (|#3| |#3|)))) (-43 (-433 (-592))) (-1239 |#1|) (-1262 |#1| |#2|) (-1012 |#2|)) (T -297)) 
+((** (*1 *2 *2 *3) (-12 (-5 *3 (-433 (-592))) (-4 *4 (-388)) (-4 *4 (-43 *3)) (-4 *5 (-1239 *4)) (-5 *1 (-297 *4 *5 *2 *6)) (-4 *2 (-1262 *4 *5)) (-4 *6 (-1012 *5)))) (-1430 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-4546 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1495 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1501 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1507 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1515 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1521 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1527 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1533 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1540 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1546 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1552 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1559 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1567 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1575 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1581 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1588 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1594 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1601 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1609 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1617 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1624 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1630 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1636 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-1642 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) (-2892 (*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4))))) 
+(-13 (-1012 |#3|) (-10 -7 (IF (|has| |#1| (-388)) (-15 ** (|#3| |#3| (-433 (-592)))) |noBranch|) (-15 -1430 (|#3| |#3|)) (-15 -4546 (|#3| |#3|)) (-15 -1495 (|#3| |#3|)) (-15 -1501 (|#3| |#3|)) (-15 -1507 (|#3| |#3|)) (-15 -1515 (|#3| |#3|)) (-15 -1521 (|#3| |#3|)) (-15 -1527 (|#3| |#3|)) (-15 -1533 (|#3| |#3|)) (-15 -1540 (|#3| |#3|)) (-15 -1546 (|#3| |#3|)) (-15 -1552 (|#3| |#3|)) (-15 -1559 (|#3| |#3|)) (-15 -1567 (|#3| |#3|)) (-15 -1575 (|#3| |#3|)) (-15 -1581 (|#3| |#3|)) (-15 -1588 (|#3| |#3|)) (-15 -1594 (|#3| |#3|)) (-15 -1601 (|#3| |#3|)) (-15 -1609 (|#3| |#3|)) (-15 -1617 (|#3| |#3|)) (-15 -1624 (|#3| |#3|)) (-15 -1630 (|#3| |#3|)) (-15 -1636 (|#3| |#3|)) (-15 -1642 (|#3| |#3|)) (-15 -2892 (|#3| |#3|)))) 
+((-3113 (($ (-1 (-141) |#2|) $) 23)) (-1360 (($ $) 36)) (-4065 (($ (-1 (-141) |#2|) $) NIL) (($ |#2| $) 34)) (-4459 (($ |#2| $) 31) (($ (-1 (-141) |#2|) $) 17)) (-2713 (($ (-1 (-141) |#2| |#2|) $ $) NIL) (($ $ $) 40)) (-3666 (($ |#2| $ (-592)) 19) (($ $ $ (-592)) 21)) (-3208 (($ $ (-592)) 11) (($ $ (-1246 (-592))) 14)) (-3619 (($ $ |#2|) 29) (($ $ $) NIL)) (-2266 (($ $ |#2|) 28) (($ |#2| $) NIL) (($ $ $) 25) (($ (-658 $)) NIL))) 
+(((-298 |#1| |#2|) (-10 -8 (-15 -2713 (|#1| |#1| |#1|)) (-15 -4065 (|#1| |#2| |#1|)) (-15 -2713 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|)) (-15 -4065 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -3619 (|#1| |#1| |#1|)) (-15 -3619 (|#1| |#1| |#2|)) (-15 -3666 (|#1| |#1| |#1| (-592))) (-15 -3666 (|#1| |#2| |#1| (-592))) (-15 -3208 (|#1| |#1| (-1246 (-592)))) (-15 -3208 (|#1| |#1| (-592))) (-15 -2266 (|#1| (-658 |#1|))) (-15 -2266 (|#1| |#1| |#1|)) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#2|)) (-15 -4459 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -3113 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4459 (|#1| |#2| |#1|)) (-15 -1360 (|#1| |#1|))) (-299 |#2|) (-1225)) (T -298)) 
+NIL 
+(-10 -8 (-15 -2713 (|#1| |#1| |#1|)) (-15 -4065 (|#1| |#2| |#1|)) (-15 -2713 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|)) (-15 -4065 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -3619 (|#1| |#1| |#1|)) (-15 -3619 (|#1| |#1| |#2|)) (-15 -3666 (|#1| |#1| |#1| (-592))) (-15 -3666 (|#1| |#2| |#1| (-592))) (-15 -3208 (|#1| |#1| (-1246 (-592)))) (-15 -3208 (|#1| |#1| (-592))) (-15 -2266 (|#1| (-658 |#1|))) (-15 -2266 (|#1| |#1| |#1|)) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#2|)) (-15 -4459 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -3113 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4459 (|#1| |#2| |#1|)) (-15 -1360 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#1| $ (-592) |#1|) 49 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 53 (|has| $ (-6 -4626)))) (-4125 (($ (-1 (-141) |#1|) $) 78)) (-3113 (($ (-1 (-141) |#1|) $) 70 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1461 (($ $) 76 (|has| |#1| (-1119)))) (-1360 (($ $) 73 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ (-1 (-141) |#1|) $) 82) (($ |#1| $) 77 (|has| |#1| (-1119)))) (-4459 (($ |#1| $) 72 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 69 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) 50 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 48)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-3242 (($ (-790) |#1|) 64)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-2713 (($ (-1 (-141) |#1| |#1|) $ $) 79) (($ $ $) 75 (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-2113 (($ |#1| $ (-592)) 81) (($ $ $ (-592)) 80)) (-3666 (($ |#1| $ (-592)) 55) (($ $ $ (-592)) 54)) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 39 (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 66)) (-1892 (($ $ |#1|) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 42 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ (-592) |#1|) 47) ((|#1| $ (-592)) 46) (($ $ (-1246 (-592))) 58)) (-4113 (($ $ (-592)) 84) (($ $ (-1246 (-592))) 83)) (-3208 (($ $ (-592)) 57) (($ $ (-1246 (-592))) 56)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 74 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 65)) (-3619 (($ $ |#1|) 86) (($ $ $) 85)) (-2266 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-658 $)) 60)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-299 |#1|) (-1311) (-1225)) (T -299)) 
+((-3619 (*1 *1 *1 *2) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)))) (-3619 (*1 *1 *1 *1) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)))) (-4113 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) (-4113 (*1 *1 *1 *2) (-12 (-5 *2 (-1246 (-592))) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) (-4065 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) (-2113 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-299 *2)) (-4 *2 (-1225)))) (-2113 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) (-2713 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-141) *3 *3)) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) (-4125 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) (-4065 (*1 *1 *2 *1) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)) (-4 *2 (-1119)))) (-1461 (*1 *1 *1) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)) (-4 *2 (-1119)))) (-2713 (*1 *1 *1 *1) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)) (-4 *2 (-869))))) 
+(-13 (-664 |t#1|) (-10 -8 (-6 -4626) (-15 -3619 ($ $ |t#1|)) (-15 -3619 ($ $ $)) (-15 -4113 ($ $ (-592))) (-15 -4113 ($ $ (-1246 (-592)))) (-15 -4065 ($ (-1 (-141) |t#1|) $)) (-15 -2113 ($ |t#1| $ (-592))) (-15 -2113 ($ $ $ (-592))) (-15 -2713 ($ (-1 (-141) |t#1| |t#1|) $ $)) (-15 -4125 ($ (-1 (-141) |t#1|) $)) (IF (|has| |t#1| (-1119)) (PROGN (-15 -4065 ($ |t#1| $)) (-15 -1461 ($ $))) |noBranch|) (IF (|has| |t#1| (-869)) (-15 -2713 ($ $ $)) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-664 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
 ((** (($ $ $) 10))) 
-(((-280 |#1|) (-10 -8 (-15 ** (|#1| |#1| |#1|))) (-281)) (T -280)) 
+(((-300 |#1|) (-10 -8 (-15 ** (|#1| |#1| |#1|))) (-301)) (T -300)) 
 NIL 
 (-10 -8 (-15 ** (|#1| |#1| |#1|))) 
-((-3539 (($ $) 6)) (-4179 (($ $) 7)) (** (($ $ $) 8))) 
-(((-281) (-1290)) (T -281)) 
-((** (*1 *1 *1 *1) (-4 *1 (-281))) (-4179 (*1 *1 *1) (-4 *1 (-281))) (-3539 (*1 *1 *1) (-4 *1 (-281)))) 
-(-13 (-10 -8 (-15 -3539 ($ $)) (-15 -4179 ($ $)) (-15 ** ($ $ $)))) 
-((-1786 (((-638 (-1150 |#1|)) (-1150 |#1|) |#1|) 35)) (-3488 ((|#2| |#2| |#1|) 38)) (-1879 ((|#2| |#2| |#1|) 40)) (-3428 ((|#2| |#2| |#1|) 39))) 
-(((-282 |#1| |#2|) (-10 -7 (-15 -3488 (|#2| |#2| |#1|)) (-15 -3428 (|#2| |#2| |#1|)) (-15 -1879 (|#2| |#2| |#1|)) (-15 -1786 ((-638 (-1150 |#1|)) (-1150 |#1|) |#1|))) (-368) (-1249 |#1|)) (T -282)) 
-((-1786 (*1 *2 *3 *4) (-12 (-4 *4 (-368)) (-5 *2 (-638 (-1150 *4))) (-5 *1 (-282 *4 *5)) (-5 *3 (-1150 *4)) (-4 *5 (-1249 *4)))) (-1879 (*1 *2 *2 *3) (-12 (-4 *3 (-368)) (-5 *1 (-282 *3 *2)) (-4 *2 (-1249 *3)))) (-3428 (*1 *2 *2 *3) (-12 (-4 *3 (-368)) (-5 *1 (-282 *3 *2)) (-4 *2 (-1249 *3)))) (-3488 (*1 *2 *2 *3) (-12 (-4 *3 (-368)) (-5 *1 (-282 *3 *2)) (-4 *2 (-1249 *3))))) 
-(-10 -7 (-15 -3488 (|#2| |#2| |#1|)) (-15 -3428 (|#2| |#2| |#1|)) (-15 -1879 (|#2| |#2| |#1|)) (-15 -1786 ((-638 (-1150 |#1|)) (-1150 |#1|) |#1|))) 
-((-3277 ((|#2| $ |#1|) 6))) 
-(((-283 |#1| |#2|) (-1290) (-1098) (-1204)) (T -283)) 
-((-3277 (*1 *2 *1 *3) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204))))) 
-(-13 (-10 -8 (-15 -3277 (|t#2| $ |t#1|)))) 
-((-3037 ((|#3| $ |#2| |#3|) 12)) (-4212 ((|#3| $ |#2|) 10))) 
-(((-284 |#1| |#2| |#3|) (-10 -8 (-15 -3037 (|#3| |#1| |#2| |#3|)) (-15 -4212 (|#3| |#1| |#2|))) (-285 |#2| |#3|) (-1098) (-1204)) (T -284)) 
-NIL 
-(-10 -8 (-15 -3037 (|#3| |#1| |#2| |#3|)) (-15 -4212 (|#3| |#1| |#2|))) 
-((-3283 ((|#2| $ |#1| |#2|) 8 (|has| $ (-6 -4603)))) (-3037 ((|#2| $ |#1| |#2|) 7 (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) 9)) (-3277 ((|#2| $ |#1|) 6) ((|#2| $ |#1| |#2|) 10))) 
-(((-285 |#1| |#2|) (-1290) (-1098) (-1204)) (T -285)) 
-((-3277 (*1 *2 *1 *3 *2) (-12 (-4 *1 (-285 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204)))) (-4212 (*1 *2 *1 *3) (-12 (-4 *1 (-285 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204)))) (-3283 (*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-285 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204)))) (-3037 (*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-285 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204))))) 
-(-13 (-283 |t#1| |t#2|) (-10 -8 (-15 -3277 (|t#2| $ |t#1| |t#2|)) (-15 -4212 (|t#2| $ |t#1|)) (IF (|has| $ (-6 -4603)) (PROGN (-15 -3283 (|t#2| $ |t#1| |t#2|)) (-15 -3037 (|t#2| $ |t#1| |t#2|))) |noBranch|))) 
-(((-283 |#1| |#2|) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 34)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 39)) (-3946 (($ $) 37)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-2190 (($ $ $) 32)) (-3116 (($ |#2| |#3|) 19)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-3893 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3195 ((|#3| $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 20)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1698 (((-3 $ "failed") $ $) NIL)) (-4029 (((-769) $) 33)) (-3277 ((|#2| $ |#2|) 41)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 24)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) ((|#2| $) NIL)) (-2140 (((-769)) NIL)) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 27 T CONST)) (-3255 (($) 35 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 36))) 
-(((-286 |#1| |#2| |#3| |#4| |#5| |#6|) (-13 (-303) (-10 -8 (-15 -3195 (|#3| $)) (-15 -3972 (|#2| $)) (-15 -3116 ($ |#2| |#3|)) (-15 -1698 ((-3 $ "failed") $ $)) (-15 -1799 ((-3 $ "failed") $)) (-15 -4350 ($ $)) (-15 -3277 (|#2| $ |#2|)))) (-174) (-1234 |#1|) (-23) (-1 |#2| |#2| |#3|) (-1 (-3 |#3| "failed") |#3| |#3|) (-1 (-3 |#2| "failed") |#2| |#2| |#3|)) (T -286)) 
-((-1799 (*1 *1 *1) (|partial| -12 (-4 *2 (-174)) (-5 *1 (-286 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1234 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-3195 (*1 *2 *1) (-12 (-4 *3 (-174)) (-4 *2 (-23)) (-5 *1 (-286 *3 *4 *2 *5 *6 *7)) (-4 *4 (-1234 *3)) (-14 *5 (-1 *4 *4 *2)) (-14 *6 (-1 (-3 *2 "failed") *2 *2)) (-14 *7 (-1 (-3 *4 "failed") *4 *4 *2)))) (-3972 (*1 *2 *1) (-12 (-4 *2 (-1234 *3)) (-5 *1 (-286 *3 *2 *4 *5 *6 *7)) (-4 *3 (-174)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) (-3116 (*1 *1 *2 *3) (-12 (-4 *4 (-174)) (-5 *1 (-286 *4 *2 *3 *5 *6 *7)) (-4 *2 (-1234 *4)) (-4 *3 (-23)) (-14 *5 (-1 *2 *2 *3)) (-14 *6 (-1 (-3 *3 "failed") *3 *3)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *3)))) (-1698 (*1 *1 *1 *1) (|partial| -12 (-4 *2 (-174)) (-5 *1 (-286 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1234 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-4350 (*1 *1 *1) (-12 (-4 *2 (-174)) (-5 *1 (-286 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1234 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-3277 (*1 *2 *1 *2) (-12 (-4 *3 (-174)) (-5 *1 (-286 *3 *2 *4 *5 *6 *7)) (-4 *2 (-1234 *3)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4))))) 
-(-13 (-303) (-10 -8 (-15 -3195 (|#3| $)) (-15 -3972 (|#2| $)) (-15 -3116 ($ |#2| |#3|)) (-15 -1698 ((-3 $ "failed") $ $)) (-15 -1799 ((-3 $ "failed") $)) (-15 -4350 ($ $)) (-15 -3277 (|#2| $ |#2|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-287) (-1290)) (T -287)) 
-NIL 
-(-13 (-1054) (-120 $ $) (-10 -7 (-6 -4595))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3422 (((-638 (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |geneigvec| (-638 (-685 (-413 (-959 |#1|))))))) (-685 (-413 (-959 |#1|)))) 83)) (-4440 (((-638 (-685 (-413 (-959 |#1|)))) (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 (-685 (-413 (-959 |#1|)))))) (-685 (-413 (-959 |#1|)))) 78) (((-638 (-685 (-413 (-959 |#1|)))) (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|))) (-685 (-413 (-959 |#1|))) (-769) (-769)) 36)) (-2636 (((-638 (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 (-685 (-413 (-959 |#1|))))))) (-685 (-413 (-959 |#1|)))) 80)) (-3162 (((-638 (-685 (-413 (-959 |#1|)))) (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|))) (-685 (-413 (-959 |#1|)))) 60)) (-3556 (((-638 (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (-685 (-413 (-959 |#1|)))) 59)) (-2707 (((-959 |#1|) (-685 (-413 (-959 |#1|)))) 47) (((-959 |#1|) (-685 (-413 (-959 |#1|))) (-1170)) 48))) 
-(((-288 |#1|) (-10 -7 (-15 -2707 ((-959 |#1|) (-685 (-413 (-959 |#1|))) (-1170))) (-15 -2707 ((-959 |#1|) (-685 (-413 (-959 |#1|))))) (-15 -3556 ((-638 (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (-685 (-413 (-959 |#1|))))) (-15 -3162 ((-638 (-685 (-413 (-959 |#1|)))) (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|))) (-685 (-413 (-959 |#1|))))) (-15 -4440 ((-638 (-685 (-413 (-959 |#1|)))) (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|))) (-685 (-413 (-959 |#1|))) (-769) (-769))) (-15 -4440 ((-638 (-685 (-413 (-959 |#1|)))) (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 (-685 (-413 (-959 |#1|)))))) (-685 (-413 (-959 |#1|))))) (-15 -3422 ((-638 (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |geneigvec| (-638 (-685 (-413 (-959 |#1|))))))) (-685 (-413 (-959 |#1|))))) (-15 -2636 ((-638 (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 (-685 (-413 (-959 |#1|))))))) (-685 (-413 (-959 |#1|)))))) (-457)) (T -288)) 
-((-2636 (*1 *2 *3) (-12 (-4 *4 (-457)) (-5 *2 (-638 (-2 (|:| |eigval| (-3 (-413 (-959 *4)) (-1159 (-1170) (-959 *4)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 (-685 (-413 (-959 *4)))))))) (-5 *1 (-288 *4)) (-5 *3 (-685 (-413 (-959 *4)))))) (-3422 (*1 *2 *3) (-12 (-4 *4 (-457)) (-5 *2 (-638 (-2 (|:| |eigval| (-3 (-413 (-959 *4)) (-1159 (-1170) (-959 *4)))) (|:| |geneigvec| (-638 (-685 (-413 (-959 *4)))))))) (-5 *1 (-288 *4)) (-5 *3 (-685 (-413 (-959 *4)))))) (-4440 (*1 *2 *3 *4) (-12 (-5 *3 (-2 (|:| |eigval| (-3 (-413 (-959 *5)) (-1159 (-1170) (-959 *5)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 *4)))) (-4 *5 (-457)) (-5 *2 (-638 (-685 (-413 (-959 *5))))) (-5 *1 (-288 *5)) (-5 *4 (-685 (-413 (-959 *5)))))) (-4440 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-3 (-413 (-959 *6)) (-1159 (-1170) (-959 *6)))) (-5 *5 (-769)) (-4 *6 (-457)) (-5 *2 (-638 (-685 (-413 (-959 *6))))) (-5 *1 (-288 *6)) (-5 *4 (-685 (-413 (-959 *6)))))) (-3162 (*1 *2 *3 *4) (-12 (-5 *3 (-3 (-413 (-959 *5)) (-1159 (-1170) (-959 *5)))) (-4 *5 (-457)) (-5 *2 (-638 (-685 (-413 (-959 *5))))) (-5 *1 (-288 *5)) (-5 *4 (-685 (-413 (-959 *5)))))) (-3556 (*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 *4)))) (-4 *4 (-457)) (-5 *2 (-638 (-3 (-413 (-959 *4)) (-1159 (-1170) (-959 *4))))) (-5 *1 (-288 *4)))) (-2707 (*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 *4)))) (-5 *2 (-959 *4)) (-5 *1 (-288 *4)) (-4 *4 (-457)))) (-2707 (*1 *2 *3 *4) (-12 (-5 *3 (-685 (-413 (-959 *5)))) (-5 *4 (-1170)) (-5 *2 (-959 *5)) (-5 *1 (-288 *5)) (-4 *5 (-457))))) 
-(-10 -7 (-15 -2707 ((-959 |#1|) (-685 (-413 (-959 |#1|))) (-1170))) (-15 -2707 ((-959 |#1|) (-685 (-413 (-959 |#1|))))) (-15 -3556 ((-638 (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (-685 (-413 (-959 |#1|))))) (-15 -3162 ((-638 (-685 (-413 (-959 |#1|)))) (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|))) (-685 (-413 (-959 |#1|))))) (-15 -4440 ((-638 (-685 (-413 (-959 |#1|)))) (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|))) (-685 (-413 (-959 |#1|))) (-769) (-769))) (-15 -4440 ((-638 (-685 (-413 (-959 |#1|)))) (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 (-685 (-413 (-959 |#1|)))))) (-685 (-413 (-959 |#1|))))) (-15 -3422 ((-638 (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |geneigvec| (-638 (-685 (-413 (-959 |#1|))))))) (-685 (-413 (-959 |#1|))))) (-15 -2636 ((-638 (-2 (|:| |eigval| (-3 (-413 (-959 |#1|)) (-1159 (-1170) (-959 |#1|)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 (-685 (-413 (-959 |#1|))))))) (-685 (-413 (-959 |#1|)))))) 
-((-3828 (((-290 |#2|) (-1 |#2| |#1|) (-290 |#1|)) 14))) 
-(((-289 |#1| |#2|) (-10 -7 (-15 -3828 ((-290 |#2|) (-1 |#2| |#1|) (-290 |#1|)))) (-1204) (-1204)) (T -289)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-290 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-290 *6)) (-5 *1 (-289 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-290 |#2|) (-1 |#2| |#1|) (-290 |#1|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1342 (((-121) $) NIL (|has| |#1| (-21)))) (-1681 (($ $) 22)) (-1572 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-1952 (($ $ $) 93 (|has| |#1| (-298)))) (-2211 (($) NIL (-1841 (|has| |#1| (-21)) (|has| |#1| (-722))) CONST)) (-3157 (($ $) 8 (|has| |#1| (-21)))) (-2279 (((-3 $ "failed") $) 68 (|has| |#1| (-722)))) (-3194 ((|#1| $) 21)) (-1799 (((-3 $ "failed") $) 66 (|has| |#1| (-722)))) (-3893 (((-121) $) NIL (|has| |#1| (-722)))) (-3828 (($ (-1 |#1| |#1|) $) 24)) (-4413 ((|#1| $) 9)) (-2325 (($ $) 57 (|has| |#1| (-21)))) (-3496 (((-3 $ "failed") $) 67 (|has| |#1| (-722)))) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-4350 (($ $) 70 (-1841 (|has| |#1| (-368)) (|has| |#1| (-482))))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2324 (((-638 $) $) 19 (|has| |#1| (-562)))) (-4485 (($ $ $) 34 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 $)) 37 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-1170) |#1|) 27 (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) 31 (|has| |#1| (-527 (-1170) |#1|)))) (-3821 (($ |#1| |#1|) 17)) (-2502 (((-140)) 88 (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170)) 85 (|has| |#1| (-901 (-1170))))) (-3018 (($ $ $) NIL (|has| |#1| (-482)))) (-4056 (($ $ $) NIL (|has| |#1| (-482)))) (-3972 (($ (-572)) NIL (|has| |#1| (-1054))) (((-121) $) 45 (|has| |#1| (-1098))) (((-856) $) 44 (|has| |#1| (-1098)))) (-2140 (((-769)) 73 (|has| |#1| (-1054)))) (-4174 (($ $ (-572)) NIL (|has| |#1| (-482))) (($ $ (-769)) NIL (|has| |#1| (-722))) (($ $ (-923)) NIL (|has| |#1| (-1110)))) (-2378 (($) 55 (|has| |#1| (-21)) CONST)) (-3255 (($) 63 (|has| |#1| (-722)) CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170))))) (-1324 (($ |#1| |#1|) 20) (((-121) $ $) 40 (|has| |#1| (-1098)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) 90 (-1841 (|has| |#1| (-368)) (|has| |#1| (-482))))) (-1373 (($ |#1| $) 53 (|has| |#1| (-21))) (($ $ |#1|) 54 (|has| |#1| (-21))) (($ $ $) 52 (|has| |#1| (-21))) (($ $) 51 (|has| |#1| (-21)))) (-1367 (($ |#1| $) 48 (|has| |#1| (-25))) (($ $ |#1|) 49 (|has| |#1| (-25))) (($ $ $) 47 (|has| |#1| (-25)))) (** (($ $ (-572)) NIL (|has| |#1| (-482))) (($ $ (-769)) NIL (|has| |#1| (-722))) (($ $ (-923)) NIL (|has| |#1| (-1110)))) (* (($ $ |#1|) 61 (|has| |#1| (-1110))) (($ |#1| $) 60 (|has| |#1| (-1110))) (($ $ $) 59 (|has| |#1| (-1110))) (($ (-572) $) 76 (|has| |#1| (-21))) (($ (-769) $) NIL (|has| |#1| (-21))) (($ (-923) $) NIL (|has| |#1| (-25))))) 
-(((-290 |#1|) (-13 (-1204) (-10 -8 (-15 -1324 ($ |#1| |#1|)) (-15 -3821 ($ |#1| |#1|)) (-15 -1681 ($ $)) (-15 -4413 (|#1| $)) (-15 -3194 (|#1| $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-527 (-1170) |#1|)) (-6 (-527 (-1170) |#1|)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-6 (-1098)) (-6 (-612 (-121))) (IF (|has| |#1| (-305 |#1|)) (PROGN (-15 -4485 ($ $ $)) (-15 -4485 ($ $ (-638 $)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-25)) (PROGN (-6 (-25)) (-15 -1367 ($ |#1| $)) (-15 -1367 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-21)) (PROGN (-6 (-21)) (-15 -2325 ($ $)) (-15 -3157 ($ $)) (-15 -1373 ($ |#1| $)) (-15 -1373 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-1110)) (PROGN (-6 (-1110)) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-722)) (PROGN (-6 (-722)) (-15 -3496 ((-3 $ "failed") $)) (-15 -2279 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-482)) (PROGN (-6 (-482)) (-15 -3496 ((-3 $ "failed") $)) (-15 -2279 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-1054)) (PROGN (-6 (-1054)) (-6 (-120 |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-174)) (-6 (-713 |#1|)) |noBranch|) (IF (|has| |#1| (-562)) (-15 -2324 ((-638 $) $)) |noBranch|) (IF (|has| |#1| (-901 (-1170))) (-6 (-901 (-1170))) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-6 (-1266 |#1|)) (-15 -1379 ($ $ $)) (-15 -4350 ($ $))) |noBranch|) (IF (|has| |#1| (-298)) (-15 -1952 ($ $ $)) |noBranch|))) (-1204)) (T -290)) 
-((-1324 (*1 *1 *2 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) (-3821 (*1 *1 *2 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) (-1681 (*1 *1 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) (-4413 (*1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) (-3194 (*1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1204)) (-5 *1 (-290 *3)))) (-4485 (*1 *1 *1 *1) (-12 (-4 *2 (-305 *2)) (-4 *2 (-1098)) (-4 *2 (-1204)) (-5 *1 (-290 *2)))) (-4485 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-290 *3))) (-4 *3 (-305 *3)) (-4 *3 (-1098)) (-4 *3 (-1204)) (-5 *1 (-290 *3)))) (-1367 (*1 *1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-25)) (-4 *2 (-1204)))) (-1367 (*1 *1 *1 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-25)) (-4 *2 (-1204)))) (-2325 (*1 *1 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-21)) (-4 *2 (-1204)))) (-3157 (*1 *1 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-21)) (-4 *2 (-1204)))) (-1373 (*1 *1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-21)) (-4 *2 (-1204)))) (-1373 (*1 *1 *1 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-21)) (-4 *2 (-1204)))) (-3496 (*1 *1 *1) (|partial| -12 (-5 *1 (-290 *2)) (-4 *2 (-722)) (-4 *2 (-1204)))) (-2279 (*1 *1 *1) (|partial| -12 (-5 *1 (-290 *2)) (-4 *2 (-722)) (-4 *2 (-1204)))) (-2324 (*1 *2 *1) (-12 (-5 *2 (-638 (-290 *3))) (-5 *1 (-290 *3)) (-4 *3 (-562)) (-4 *3 (-1204)))) (-1952 (*1 *1 *1 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-298)) (-4 *2 (-1204)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1110)) (-4 *2 (-1204)))) (* (*1 *1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1110)) (-4 *2 (-1204)))) (-1379 (*1 *1 *1 *1) (-1841 (-12 (-5 *1 (-290 *2)) (-4 *2 (-368)) (-4 *2 (-1204))) (-12 (-5 *1 (-290 *2)) (-4 *2 (-482)) (-4 *2 (-1204))))) (-4350 (*1 *1 *1) (-1841 (-12 (-5 *1 (-290 *2)) (-4 *2 (-368)) (-4 *2 (-1204))) (-12 (-5 *1 (-290 *2)) (-4 *2 (-482)) (-4 *2 (-1204)))))) 
-(-13 (-1204) (-10 -8 (-15 -1324 ($ |#1| |#1|)) (-15 -3821 ($ |#1| |#1|)) (-15 -1681 ($ $)) (-15 -4413 (|#1| $)) (-15 -3194 (|#1| $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-527 (-1170) |#1|)) (-6 (-527 (-1170) |#1|)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-6 (-1098)) (-6 (-612 (-121))) (IF (|has| |#1| (-305 |#1|)) (PROGN (-15 -4485 ($ $ $)) (-15 -4485 ($ $ (-638 $)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-25)) (PROGN (-6 (-25)) (-15 -1367 ($ |#1| $)) (-15 -1367 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-21)) (PROGN (-6 (-21)) (-15 -2325 ($ $)) (-15 -3157 ($ $)) (-15 -1373 ($ |#1| $)) (-15 -1373 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-1110)) (PROGN (-6 (-1110)) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-722)) (PROGN (-6 (-722)) (-15 -3496 ((-3 $ "failed") $)) (-15 -2279 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-482)) (PROGN (-6 (-482)) (-15 -3496 ((-3 $ "failed") $)) (-15 -2279 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-1054)) (PROGN (-6 (-1054)) (-6 (-120 |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-174)) (-6 (-713 |#1|)) |noBranch|) (IF (|has| |#1| (-562)) (-15 -2324 ((-638 $) $)) |noBranch|) (IF (|has| |#1| (-901 (-1170))) (-6 (-901 (-1170))) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-6 (-1266 |#1|)) (-15 -1379 ($ $ $)) (-15 -4350 ($ $))) |noBranch|) (IF (|has| |#1| (-298)) (-15 -1952 ($ $ $)) |noBranch|))) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2430 (((-1264) $ |#1| |#1|) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#2| $ |#1| |#2|) NIL)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 |#2| "failed") |#1| $) NIL)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) NIL)) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) NIL)) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 ((|#1| $) NIL (|has| |#1| (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 ((|#1| $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2760 (((-638 |#1|) $) NIL)) (-2365 (((-121) |#1| $) NIL)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2739 (((-638 |#1|) $) NIL)) (-1601 (((-121) |#1| $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-1837 ((|#2| $) NIL (|has| |#1| (-848)))) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-291 |#1| |#2|) (-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602))) (-1098) (-1098)) (T -291)) 
-NIL 
-(-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602))) 
-((-3900 (((-307) (-1152) (-638 (-1152))) 16) (((-307) (-1152) (-1152)) 15) (((-307) (-638 (-1152))) 14) (((-307) (-1152)) 12))) 
-(((-292) (-10 -7 (-15 -3900 ((-307) (-1152))) (-15 -3900 ((-307) (-638 (-1152)))) (-15 -3900 ((-307) (-1152) (-1152))) (-15 -3900 ((-307) (-1152) (-638 (-1152)))))) (T -292)) 
-((-3900 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-1152))) (-5 *3 (-1152)) (-5 *2 (-307)) (-5 *1 (-292)))) (-3900 (*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-307)) (-5 *1 (-292)))) (-3900 (*1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-307)) (-5 *1 (-292)))) (-3900 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-307)) (-5 *1 (-292))))) 
-(-10 -7 (-15 -3900 ((-307) (-1152))) (-15 -3900 ((-307) (-638 (-1152)))) (-15 -3900 ((-307) (-1152) (-1152))) (-15 -3900 ((-307) (-1152) (-638 (-1152))))) 
-((-3828 ((|#2| (-1 |#2| |#1|) (-1152) (-611 |#1|)) 17))) 
-(((-293 |#1| |#2|) (-10 -7 (-15 -3828 (|#2| (-1 |#2| |#1|) (-1152) (-611 |#1|)))) (-298) (-1204)) (T -293)) 
-((-3828 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1152)) (-5 *5 (-611 *6)) (-4 *6 (-298)) (-4 *2 (-1204)) (-5 *1 (-293 *6 *2))))) 
-(-10 -7 (-15 -3828 (|#2| (-1 |#2| |#1|) (-1152) (-611 |#1|)))) 
-((-3828 ((|#2| (-1 |#2| |#1|) (-611 |#1|)) 17))) 
-(((-294 |#1| |#2|) (-10 -7 (-15 -3828 (|#2| (-1 |#2| |#1|) (-611 |#1|)))) (-298) (-298)) (T -294)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5)) (-5 *4 (-611 *5)) (-4 *5 (-298)) (-4 *2 (-298)) (-5 *1 (-294 *5 *2))))) 
-(-10 -7 (-15 -3828 (|#2| (-1 |#2| |#1|) (-611 |#1|)))) 
-((-3679 (((-121) (-217)) 10))) 
-(((-295 |#1| |#2|) (-10 -7 (-15 -3679 ((-121) (-217)))) (-217) (-217)) (T -295)) 
-((-3679 (*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-121)) (-5 *1 (-295 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
-(-10 -7 (-15 -3679 ((-121) (-217)))) 
-((-1770 (((-1150 (-217)) (-312 (-217)) (-638 (-1170)) (-1092 (-841 (-217)))) 88)) (-3145 (((-1150 (-217)) (-1259 (-312 (-217))) (-638 (-1170)) (-1092 (-841 (-217)))) 103) (((-1150 (-217)) (-312 (-217)) (-638 (-1170)) (-1092 (-841 (-217)))) 58)) (-4050 (((-638 (-1152)) (-1150 (-217))) NIL)) (-2491 (((-638 (-217)) (-312 (-217)) (-1170) (-1092 (-841 (-217)))) 55)) (-2495 (((-638 (-217)) (-959 (-413 (-572))) (-1170) (-1092 (-841 (-217)))) 47)) (-1417 (((-638 (-1152)) (-638 (-217))) NIL)) (-3839 (((-217) (-1092 (-841 (-217)))) 23)) (-2567 (((-217) (-1092 (-841 (-217)))) 24)) (-2702 (((-121) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 51)) (-1937 (((-1152) (-217)) NIL))) 
-(((-296) (-10 -7 (-15 -3839 ((-217) (-1092 (-841 (-217))))) (-15 -2567 ((-217) (-1092 (-841 (-217))))) (-15 -2702 ((-121) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2491 ((-638 (-217)) (-312 (-217)) (-1170) (-1092 (-841 (-217))))) (-15 -1770 ((-1150 (-217)) (-312 (-217)) (-638 (-1170)) (-1092 (-841 (-217))))) (-15 -3145 ((-1150 (-217)) (-312 (-217)) (-638 (-1170)) (-1092 (-841 (-217))))) (-15 -3145 ((-1150 (-217)) (-1259 (-312 (-217))) (-638 (-1170)) (-1092 (-841 (-217))))) (-15 -2495 ((-638 (-217)) (-959 (-413 (-572))) (-1170) (-1092 (-841 (-217))))) (-15 -1937 ((-1152) (-217))) (-15 -1417 ((-638 (-1152)) (-638 (-217)))) (-15 -4050 ((-638 (-1152)) (-1150 (-217)))))) (T -296)) 
-((-4050 (*1 *2 *3) (-12 (-5 *3 (-1150 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-296)))) (-1417 (*1 *2 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-296)))) (-1937 (*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-1152)) (-5 *1 (-296)))) (-2495 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-959 (-413 (-572)))) (-5 *4 (-1170)) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-638 (-217))) (-5 *1 (-296)))) (-3145 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *4 (-638 (-1170))) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-1150 (-217))) (-5 *1 (-296)))) (-3145 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-638 (-1170))) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-1150 (-217))) (-5 *1 (-296)))) (-1770 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-638 (-1170))) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-1150 (-217))) (-5 *1 (-296)))) (-2491 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-1170)) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-638 (-217))) (-5 *1 (-296)))) (-2702 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-121)) (-5 *1 (-296)))) (-2567 (*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-296)))) (-3839 (*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-296))))) 
-(-10 -7 (-15 -3839 ((-217) (-1092 (-841 (-217))))) (-15 -2567 ((-217) (-1092 (-841 (-217))))) (-15 -2702 ((-121) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2491 ((-638 (-217)) (-312 (-217)) (-1170) (-1092 (-841 (-217))))) (-15 -1770 ((-1150 (-217)) (-312 (-217)) (-638 (-1170)) (-1092 (-841 (-217))))) (-15 -3145 ((-1150 (-217)) (-312 (-217)) (-638 (-1170)) (-1092 (-841 (-217))))) (-15 -3145 ((-1150 (-217)) (-1259 (-312 (-217))) (-638 (-1170)) (-1092 (-841 (-217))))) (-15 -2495 ((-638 (-217)) (-959 (-413 (-572))) (-1170) (-1092 (-841 (-217))))) (-15 -1937 ((-1152) (-217))) (-15 -1417 ((-638 (-1152)) (-638 (-217)))) (-15 -4050 ((-638 (-1152)) (-1150 (-217))))) 
-((-1337 (((-638 (-611 $)) $) 28)) (-1952 (($ $ (-290 $)) 80) (($ $ (-638 (-290 $))) 120) (($ $ (-638 (-611 $)) (-638 $)) NIL)) (-3376 (((-3 (-611 $) "failed") $) 110)) (-1318 (((-611 $) $) 109)) (-3567 (($ $) 19) (($ (-638 $)) 54)) (-4091 (((-638 (-123)) $) 37)) (-4564 (((-123) (-123)) 90)) (-4240 (((-121) $) 128)) (-3828 (($ (-1 $ $) (-611 $)) 88)) (-3614 (((-3 (-611 $) "failed") $) 92)) (-4496 (($ (-123) $) 60) (($ (-123) (-638 $)) 98)) (-3291 (((-121) $ (-123)) 114) (((-121) $ (-1170)) 113)) (-1455 (((-769) $) 45)) (-4319 (((-121) $ $) 58) (((-121) $ (-1170)) 49)) (-4247 (((-121) $) 126)) (-4485 (($ $ (-611 $) $) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL) (($ $ (-638 (-290 $))) 118) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ $))) 83) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-1170) (-1 $ (-638 $))) 68) (($ $ (-1170) (-1 $ $)) 74) (($ $ (-638 (-123)) (-638 (-1 $ $))) 82) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) 84) (($ $ (-123) (-1 $ (-638 $))) 70) (($ $ (-123) (-1 $ $)) 76)) (-3277 (($ (-123) $) 61) (($ (-123) $ $) 62) (($ (-123) $ $ $) 63) (($ (-123) $ $ $ $) 64) (($ (-123) (-638 $)) 106)) (-2759 (($ $) 51) (($ $ $) 116)) (-3497 (($ $) 17) (($ (-638 $)) 53)) (-3228 (((-121) (-123)) 22))) 
-(((-297 |#1|) (-10 -8 (-15 -4240 ((-121) |#1|)) (-15 -4247 ((-121) |#1|)) (-15 -4485 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-123) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 (-1 |#1| |#1|)))) (-15 -4485 (|#1| |#1| (-1170) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-1170) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-1 |#1| |#1|)))) (-15 -4319 ((-121) |#1| (-1170))) (-15 -4319 ((-121) |#1| |#1|)) (-15 -3828 (|#1| (-1 |#1| |#1|) (-611 |#1|))) (-15 -4496 (|#1| (-123) (-638 |#1|))) (-15 -4496 (|#1| (-123) |#1|)) (-15 -3291 ((-121) |#1| (-1170))) (-15 -3291 ((-121) |#1| (-123))) (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -4091 ((-638 (-123)) |#1|)) (-15 -1337 ((-638 (-611 |#1|)) |#1|)) (-15 -3614 ((-3 (-611 |#1|) "failed") |#1|)) (-15 -1455 ((-769) |#1|)) (-15 -2759 (|#1| |#1| |#1|)) (-15 -2759 (|#1| |#1|)) (-15 -3567 (|#1| (-638 |#1|))) (-15 -3567 (|#1| |#1|)) (-15 -3497 (|#1| (-638 |#1|))) (-15 -3497 (|#1| |#1|)) (-15 -1952 (|#1| |#1| (-638 (-611 |#1|)) (-638 |#1|))) (-15 -1952 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -1952 (|#1| |#1| (-290 |#1|))) (-15 -3277 (|#1| (-123) (-638 |#1|))) (-15 -3277 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1| |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-611 |#1|)) (-638 |#1|))) (-15 -4485 (|#1| |#1| (-611 |#1|) |#1|)) (-15 -1318 ((-611 |#1|) |#1|)) (-15 -3376 ((-3 (-611 |#1|) "failed") |#1|))) (-298)) (T -297)) 
-((-4564 (*1 *2 *2) (-12 (-5 *2 (-123)) (-5 *1 (-297 *3)) (-4 *3 (-298)))) (-3228 (*1 *2 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-297 *4)) (-4 *4 (-298))))) 
-(-10 -8 (-15 -4240 ((-121) |#1|)) (-15 -4247 ((-121) |#1|)) (-15 -4485 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-123) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 (-1 |#1| |#1|)))) (-15 -4485 (|#1| |#1| (-1170) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-1170) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-1 |#1| |#1|)))) (-15 -4319 ((-121) |#1| (-1170))) (-15 -4319 ((-121) |#1| |#1|)) (-15 -3828 (|#1| (-1 |#1| |#1|) (-611 |#1|))) (-15 -4496 (|#1| (-123) (-638 |#1|))) (-15 -4496 (|#1| (-123) |#1|)) (-15 -3291 ((-121) |#1| (-1170))) (-15 -3291 ((-121) |#1| (-123))) (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -4091 ((-638 (-123)) |#1|)) (-15 -1337 ((-638 (-611 |#1|)) |#1|)) (-15 -3614 ((-3 (-611 |#1|) "failed") |#1|)) (-15 -1455 ((-769) |#1|)) (-15 -2759 (|#1| |#1| |#1|)) (-15 -2759 (|#1| |#1|)) (-15 -3567 (|#1| (-638 |#1|))) (-15 -3567 (|#1| |#1|)) (-15 -3497 (|#1| (-638 |#1|))) (-15 -3497 (|#1| |#1|)) (-15 -1952 (|#1| |#1| (-638 (-611 |#1|)) (-638 |#1|))) (-15 -1952 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -1952 (|#1| |#1| (-290 |#1|))) (-15 -3277 (|#1| (-123) (-638 |#1|))) (-15 -3277 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1| |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-611 |#1|)) (-638 |#1|))) (-15 -4485 (|#1| |#1| (-611 |#1|) |#1|)) (-15 -1318 ((-611 |#1|) |#1|)) (-15 -3376 ((-3 (-611 |#1|) "failed") |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1337 (((-638 (-611 $)) $) 43)) (-1952 (($ $ (-290 $)) 55) (($ $ (-638 (-290 $))) 54) (($ $ (-638 (-611 $)) (-638 $)) 53)) (-3376 (((-3 (-611 $) "failed") $) 68)) (-1318 (((-611 $) $) 67)) (-3567 (($ $) 50) (($ (-638 $)) 49)) (-4091 (((-638 (-123)) $) 42)) (-4564 (((-123) (-123)) 41)) (-4240 (((-121) $) 21 (|has| $ (-1044 (-572))))) (-4127 (((-1166 $) (-611 $)) 24 (|has| $ (-1054)))) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-3828 (($ (-1 $ $) (-611 $)) 35)) (-3614 (((-3 (-611 $) "failed") $) 45)) (-1658 (((-1152) $) 9)) (-4291 (((-638 (-611 $)) $) 44)) (-4496 (($ (-123) $) 37) (($ (-123) (-638 $)) 36)) (-3291 (((-121) $ (-123)) 39) (((-121) $ (-1170)) 38)) (-1455 (((-769) $) 46)) (-2607 (((-1116) $) 10)) (-4319 (((-121) $ $) 34) (((-121) $ (-1170)) 33)) (-4247 (((-121) $) 22 (|has| $ (-1044 (-572))))) (-4485 (($ $ (-611 $) $) 66) (($ $ (-638 (-611 $)) (-638 $)) 65) (($ $ (-638 (-290 $))) 64) (($ $ (-290 $)) 63) (($ $ $ $) 62) (($ $ (-638 $) (-638 $)) 61) (($ $ (-638 (-1170)) (-638 (-1 $ $))) 32) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) 31) (($ $ (-1170) (-1 $ (-638 $))) 30) (($ $ (-1170) (-1 $ $)) 29) (($ $ (-638 (-123)) (-638 (-1 $ $))) 28) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) 27) (($ $ (-123) (-1 $ (-638 $))) 26) (($ $ (-123) (-1 $ $)) 25)) (-3277 (($ (-123) $) 60) (($ (-123) $ $) 59) (($ (-123) $ $ $) 58) (($ (-123) $ $ $ $) 57) (($ (-123) (-638 $)) 56)) (-2759 (($ $) 48) (($ $ $) 47)) (-2830 (($ $) 23 (|has| $ (-1054)))) (-3972 (((-856) $) 11) (($ (-611 $)) 69)) (-3497 (($ $) 52) (($ (-638 $)) 51)) (-3228 (((-121) (-123)) 40)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17))) 
-(((-298) (-1290)) (T -298)) 
-((-3277 (*1 *1 *2 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) (-3277 (*1 *1 *2 *1 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) (-3277 (*1 *1 *2 *1 *1 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) (-3277 (*1 *1 *2 *1 *1 *1 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) (-3277 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-638 *1)) (-4 *1 (-298)))) (-1952 (*1 *1 *1 *2) (-12 (-5 *2 (-290 *1)) (-4 *1 (-298)))) (-1952 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-290 *1))) (-4 *1 (-298)))) (-1952 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-611 *1))) (-5 *3 (-638 *1)) (-4 *1 (-298)))) (-3497 (*1 *1 *1) (-4 *1 (-298))) (-3497 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-298)))) (-3567 (*1 *1 *1) (-4 *1 (-298))) (-3567 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-298)))) (-2759 (*1 *1 *1) (-4 *1 (-298))) (-2759 (*1 *1 *1 *1) (-4 *1 (-298))) (-1455 (*1 *2 *1) (-12 (-4 *1 (-298)) (-5 *2 (-769)))) (-3614 (*1 *2 *1) (|partial| -12 (-5 *2 (-611 *1)) (-4 *1 (-298)))) (-4291 (*1 *2 *1) (-12 (-5 *2 (-638 (-611 *1))) (-4 *1 (-298)))) (-1337 (*1 *2 *1) (-12 (-5 *2 (-638 (-611 *1))) (-4 *1 (-298)))) (-4091 (*1 *2 *1) (-12 (-4 *1 (-298)) (-5 *2 (-638 (-123))))) (-4564 (*1 *2 *2) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) (-3228 (*1 *2 *3) (-12 (-4 *1 (-298)) (-5 *3 (-123)) (-5 *2 (-121)))) (-3291 (*1 *2 *1 *3) (-12 (-4 *1 (-298)) (-5 *3 (-123)) (-5 *2 (-121)))) (-3291 (*1 *2 *1 *3) (-12 (-4 *1 (-298)) (-5 *3 (-1170)) (-5 *2 (-121)))) (-4496 (*1 *1 *2 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) (-4496 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-638 *1)) (-4 *1 (-298)))) (-3828 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *1 *1)) (-5 *3 (-611 *1)) (-4 *1 (-298)))) (-4319 (*1 *2 *1 *1) (-12 (-4 *1 (-298)) (-5 *2 (-121)))) (-4319 (*1 *2 *1 *3) (-12 (-4 *1 (-298)) (-5 *3 (-1170)) (-5 *2 (-121)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-638 (-1 *1 *1))) (-4 *1 (-298)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-638 (-1 *1 (-638 *1)))) (-4 *1 (-298)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1 *1 (-638 *1))) (-4 *1 (-298)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1 *1 *1)) (-4 *1 (-298)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-123))) (-5 *3 (-638 (-1 *1 *1))) (-4 *1 (-298)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-123))) (-5 *3 (-638 (-1 *1 (-638 *1)))) (-4 *1 (-298)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 (-638 *1))) (-4 *1 (-298)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 *1)) (-4 *1 (-298)))) (-4127 (*1 *2 *3) (-12 (-5 *3 (-611 *1)) (-4 *1 (-1054)) (-4 *1 (-298)) (-5 *2 (-1166 *1)))) (-2830 (*1 *1 *1) (-12 (-4 *1 (-1054)) (-4 *1 (-298)))) (-4247 (*1 *2 *1) (-12 (-4 *1 (-1044 (-572))) (-4 *1 (-298)) (-5 *2 (-121)))) (-4240 (*1 *2 *1) (-12 (-4 *1 (-1044 (-572))) (-4 *1 (-298)) (-5 *2 (-121))))) 
-(-13 (-848) (-1044 (-611 $)) (-527 (-611 $) $) (-305 $) (-10 -8 (-15 -3277 ($ (-123) $)) (-15 -3277 ($ (-123) $ $)) (-15 -3277 ($ (-123) $ $ $)) (-15 -3277 ($ (-123) $ $ $ $)) (-15 -3277 ($ (-123) (-638 $))) (-15 -1952 ($ $ (-290 $))) (-15 -1952 ($ $ (-638 (-290 $)))) (-15 -1952 ($ $ (-638 (-611 $)) (-638 $))) (-15 -3497 ($ $)) (-15 -3497 ($ (-638 $))) (-15 -3567 ($ $)) (-15 -3567 ($ (-638 $))) (-15 -2759 ($ $)) (-15 -2759 ($ $ $)) (-15 -1455 ((-769) $)) (-15 -3614 ((-3 (-611 $) "failed") $)) (-15 -4291 ((-638 (-611 $)) $)) (-15 -1337 ((-638 (-611 $)) $)) (-15 -4091 ((-638 (-123)) $)) (-15 -4564 ((-123) (-123))) (-15 -3228 ((-121) (-123))) (-15 -3291 ((-121) $ (-123))) (-15 -3291 ((-121) $ (-1170))) (-15 -4496 ($ (-123) $)) (-15 -4496 ($ (-123) (-638 $))) (-15 -3828 ($ (-1 $ $) (-611 $))) (-15 -4319 ((-121) $ $)) (-15 -4319 ((-121) $ (-1170))) (-15 -4485 ($ $ (-638 (-1170)) (-638 (-1 $ $)))) (-15 -4485 ($ $ (-638 (-1170)) (-638 (-1 $ (-638 $))))) (-15 -4485 ($ $ (-1170) (-1 $ (-638 $)))) (-15 -4485 ($ $ (-1170) (-1 $ $))) (-15 -4485 ($ $ (-638 (-123)) (-638 (-1 $ $)))) (-15 -4485 ($ $ (-638 (-123)) (-638 (-1 $ (-638 $))))) (-15 -4485 ($ $ (-123) (-1 $ (-638 $)))) (-15 -4485 ($ $ (-123) (-1 $ $))) (IF (|has| $ (-1054)) (PROGN (-15 -4127 ((-1166 $) (-611 $))) (-15 -2830 ($ $))) |noBranch|) (IF (|has| $ (-1044 (-572))) (PROGN (-15 -4247 ((-121) $)) (-15 -4240 ((-121) $))) |noBranch|))) 
-(((-105) . T) ((-612 (-856)) . T) ((-305 $) . T) ((-527 (-611 $) $) . T) ((-527 $ $) . T) ((-848) . T) ((-1044 (-611 $)) . T) ((-1098) . T)) 
-((-2018 (((-638 |#1|) (-638 |#1|)) 10))) 
-(((-299 |#1|) (-10 -7 (-15 -2018 ((-638 |#1|) (-638 |#1|)))) (-846)) (T -299)) 
-((-2018 (*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-846)) (-5 *1 (-299 *3))))) 
-(-10 -7 (-15 -2018 ((-638 |#1|) (-638 |#1|)))) 
-((-3828 (((-685 |#2|) (-1 |#2| |#1|) (-685 |#1|)) 15))) 
-(((-300 |#1| |#2|) (-10 -7 (-15 -3828 ((-685 |#2|) (-1 |#2| |#1|) (-685 |#1|)))) (-1054) (-1054)) (T -300)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-685 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-685 *6)) (-5 *1 (-300 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-685 |#2|) (-1 |#2| |#1|) (-685 |#1|)))) 
-((-1359 (((-1259 (-312 (-385))) (-1259 (-312 (-217)))) 105)) (-2327 (((-1092 (-841 (-217))) (-1092 (-841 (-385)))) 39)) (-4050 (((-638 (-1152)) (-1150 (-217))) 87)) (-2684 (((-312 (-385)) (-959 (-217))) 49)) (-2639 (((-217) (-959 (-217))) 45)) (-3223 (((-1152) (-385)) 167)) (-2618 (((-841 (-217)) (-841 (-385))) 33)) (-1458 (((-2 (|:| |additions| (-572)) (|:| |multiplications| (-572)) (|:| |exponentiations| (-572)) (|:| |functionCalls| (-572))) (-1259 (-312 (-217)))) 142)) (-4566 (((-1042) (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042)))) 180) (((-1042) (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) 178)) (-1369 (((-685 (-217)) (-638 (-217)) (-769)) 13)) (-2501 (((-1259 (-694)) (-638 (-217))) 94)) (-1417 (((-638 (-1152)) (-638 (-217))) 74)) (-3978 (((-3 (-312 (-217)) "failed") (-312 (-217))) 120)) (-3679 (((-121) (-217) (-1092 (-841 (-217)))) 109)) (-2976 (((-1042) (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))) 198)) (-3839 (((-217) (-1092 (-841 (-217)))) 107)) (-2567 (((-217) (-1092 (-841 (-217)))) 108)) (-1864 (((-217) (-413 (-572))) 26)) (-1474 (((-1152) (-385)) 72)) (-3483 (((-217) (-385)) 17)) (-2477 (((-385) (-1259 (-312 (-217)))) 153)) (-3061 (((-312 (-217)) (-312 (-385))) 23)) (-1954 (((-413 (-572)) (-312 (-217))) 52)) (-4447 (((-312 (-413 (-572))) (-312 (-217))) 68)) (-2269 (((-312 (-385)) (-312 (-217))) 98)) (-3021 (((-217) (-312 (-217))) 53)) (-1634 (((-638 (-217)) (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) 63)) (-1957 (((-1092 (-841 (-217))) (-1092 (-841 (-217)))) 60)) (-1937 (((-1152) (-217)) 71)) (-3530 (((-694) (-217)) 90)) (-1616 (((-413 (-572)) (-217)) 54)) (-4202 (((-312 (-385)) (-217)) 48)) (-4081 (((-638 (-1092 (-841 (-217)))) (-638 (-1092 (-841 (-385))))) 42)) (-4500 (((-1042) (-638 (-1042))) 163) (((-1042) (-1042) (-1042)) 160)) (-2333 (((-1042) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) 194))) 
-(((-301) (-10 -7 (-15 -3483 ((-217) (-385))) (-15 -3061 ((-312 (-217)) (-312 (-385)))) (-15 -2618 ((-841 (-217)) (-841 (-385)))) (-15 -2327 ((-1092 (-841 (-217))) (-1092 (-841 (-385))))) (-15 -4081 ((-638 (-1092 (-841 (-217)))) (-638 (-1092 (-841 (-385)))))) (-15 -1616 ((-413 (-572)) (-217))) (-15 -1954 ((-413 (-572)) (-312 (-217)))) (-15 -3021 ((-217) (-312 (-217)))) (-15 -3978 ((-3 (-312 (-217)) "failed") (-312 (-217)))) (-15 -2477 ((-385) (-1259 (-312 (-217))))) (-15 -1458 ((-2 (|:| |additions| (-572)) (|:| |multiplications| (-572)) (|:| |exponentiations| (-572)) (|:| |functionCalls| (-572))) (-1259 (-312 (-217))))) (-15 -4447 ((-312 (-413 (-572))) (-312 (-217)))) (-15 -1957 ((-1092 (-841 (-217))) (-1092 (-841 (-217))))) (-15 -1634 ((-638 (-217)) (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))))) (-15 -3530 ((-694) (-217))) (-15 -2501 ((-1259 (-694)) (-638 (-217)))) (-15 -2269 ((-312 (-385)) (-312 (-217)))) (-15 -1359 ((-1259 (-312 (-385))) (-1259 (-312 (-217))))) (-15 -3679 ((-121) (-217) (-1092 (-841 (-217))))) (-15 -1937 ((-1152) (-217))) (-15 -1474 ((-1152) (-385))) (-15 -1417 ((-638 (-1152)) (-638 (-217)))) (-15 -4050 ((-638 (-1152)) (-1150 (-217)))) (-15 -3839 ((-217) (-1092 (-841 (-217))))) (-15 -2567 ((-217) (-1092 (-841 (-217))))) (-15 -4500 ((-1042) (-1042) (-1042))) (-15 -4500 ((-1042) (-638 (-1042)))) (-15 -3223 ((-1152) (-385))) (-15 -4566 ((-1042) (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))))) (-15 -4566 ((-1042) (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042))))) (-15 -2333 ((-1042) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))) (-15 -2976 ((-1042) (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))))) (-15 -2684 ((-312 (-385)) (-959 (-217)))) (-15 -2639 ((-217) (-959 (-217)))) (-15 -4202 ((-312 (-385)) (-217))) (-15 -1864 ((-217) (-413 (-572)))) (-15 -1369 ((-685 (-217)) (-638 (-217)) (-769))))) (T -301)) 
-((-1369 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-217))) (-5 *4 (-769)) (-5 *2 (-685 (-217))) (-5 *1 (-301)))) (-1864 (*1 *2 *3) (-12 (-5 *3 (-413 (-572))) (-5 *2 (-217)) (-5 *1 (-301)))) (-4202 (*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-312 (-385))) (-5 *1 (-301)))) (-2639 (*1 *2 *3) (-12 (-5 *3 (-959 (-217))) (-5 *2 (-217)) (-5 *1 (-301)))) (-2684 (*1 *2 *3) (-12 (-5 *3 (-959 (-217))) (-5 *2 (-312 (-385))) (-5 *1 (-301)))) (-2976 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))) (-5 *2 (-1042)) (-5 *1 (-301)))) (-2333 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *2 (-1042)) (-5 *1 (-301)))) (-4566 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042)))) (-5 *2 (-1042)) (-5 *1 (-301)))) (-4566 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *2 (-1042)) (-5 *1 (-301)))) (-3223 (*1 *2 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1152)) (-5 *1 (-301)))) (-4500 (*1 *2 *3) (-12 (-5 *3 (-638 (-1042))) (-5 *2 (-1042)) (-5 *1 (-301)))) (-4500 (*1 *2 *2 *2) (-12 (-5 *2 (-1042)) (-5 *1 (-301)))) (-2567 (*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-301)))) (-3839 (*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-301)))) (-4050 (*1 *2 *3) (-12 (-5 *3 (-1150 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-301)))) (-1417 (*1 *2 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-301)))) (-1474 (*1 *2 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1152)) (-5 *1 (-301)))) (-1937 (*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-1152)) (-5 *1 (-301)))) (-3679 (*1 *2 *3 *4) (-12 (-5 *4 (-1092 (-841 (-217)))) (-5 *3 (-217)) (-5 *2 (-121)) (-5 *1 (-301)))) (-1359 (*1 *2 *3) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *2 (-1259 (-312 (-385)))) (-5 *1 (-301)))) (-2269 (*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-312 (-385))) (-5 *1 (-301)))) (-2501 (*1 *2 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-1259 (-694))) (-5 *1 (-301)))) (-3530 (*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-694)) (-5 *1 (-301)))) (-1634 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *2 (-638 (-217))) (-5 *1 (-301)))) (-1957 (*1 *2 *2) (-12 (-5 *2 (-1092 (-841 (-217)))) (-5 *1 (-301)))) (-4447 (*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-312 (-413 (-572)))) (-5 *1 (-301)))) (-1458 (*1 *2 *3) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *2 (-2 (|:| |additions| (-572)) (|:| |multiplications| (-572)) (|:| |exponentiations| (-572)) (|:| |functionCalls| (-572)))) (-5 *1 (-301)))) (-2477 (*1 *2 *3) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *2 (-385)) (-5 *1 (-301)))) (-3978 (*1 *2 *2) (|partial| -12 (-5 *2 (-312 (-217))) (-5 *1 (-301)))) (-3021 (*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-217)) (-5 *1 (-301)))) (-1954 (*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-413 (-572))) (-5 *1 (-301)))) (-1616 (*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-413 (-572))) (-5 *1 (-301)))) (-4081 (*1 *2 *3) (-12 (-5 *3 (-638 (-1092 (-841 (-385))))) (-5 *2 (-638 (-1092 (-841 (-217))))) (-5 *1 (-301)))) (-2327 (*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-385)))) (-5 *2 (-1092 (-841 (-217)))) (-5 *1 (-301)))) (-2618 (*1 *2 *3) (-12 (-5 *3 (-841 (-385))) (-5 *2 (-841 (-217))) (-5 *1 (-301)))) (-3061 (*1 *2 *3) (-12 (-5 *3 (-312 (-385))) (-5 *2 (-312 (-217))) (-5 *1 (-301)))) (-3483 (*1 *2 *3) (-12 (-5 *3 (-385)) (-5 *2 (-217)) (-5 *1 (-301))))) 
-(-10 -7 (-15 -3483 ((-217) (-385))) (-15 -3061 ((-312 (-217)) (-312 (-385)))) (-15 -2618 ((-841 (-217)) (-841 (-385)))) (-15 -2327 ((-1092 (-841 (-217))) (-1092 (-841 (-385))))) (-15 -4081 ((-638 (-1092 (-841 (-217)))) (-638 (-1092 (-841 (-385)))))) (-15 -1616 ((-413 (-572)) (-217))) (-15 -1954 ((-413 (-572)) (-312 (-217)))) (-15 -3021 ((-217) (-312 (-217)))) (-15 -3978 ((-3 (-312 (-217)) "failed") (-312 (-217)))) (-15 -2477 ((-385) (-1259 (-312 (-217))))) (-15 -1458 ((-2 (|:| |additions| (-572)) (|:| |multiplications| (-572)) (|:| |exponentiations| (-572)) (|:| |functionCalls| (-572))) (-1259 (-312 (-217))))) (-15 -4447 ((-312 (-413 (-572))) (-312 (-217)))) (-15 -1957 ((-1092 (-841 (-217))) (-1092 (-841 (-217))))) (-15 -1634 ((-638 (-217)) (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))))) (-15 -3530 ((-694) (-217))) (-15 -2501 ((-1259 (-694)) (-638 (-217)))) (-15 -2269 ((-312 (-385)) (-312 (-217)))) (-15 -1359 ((-1259 (-312 (-385))) (-1259 (-312 (-217))))) (-15 -3679 ((-121) (-217) (-1092 (-841 (-217))))) (-15 -1937 ((-1152) (-217))) (-15 -1474 ((-1152) (-385))) (-15 -1417 ((-638 (-1152)) (-638 (-217)))) (-15 -4050 ((-638 (-1152)) (-1150 (-217)))) (-15 -3839 ((-217) (-1092 (-841 (-217))))) (-15 -2567 ((-217) (-1092 (-841 (-217))))) (-15 -4500 ((-1042) (-1042) (-1042))) (-15 -4500 ((-1042) (-638 (-1042)))) (-15 -3223 ((-1152) (-385))) (-15 -4566 ((-1042) (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))))) (-15 -4566 ((-1042) (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042))))) (-15 -2333 ((-1042) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))) (-15 -2976 ((-1042) (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))))) (-15 -2684 ((-312 (-385)) (-959 (-217)))) (-15 -2639 ((-217) (-959 (-217)))) (-15 -4202 ((-312 (-385)) (-217))) (-15 -1864 ((-217) (-413 (-572)))) (-15 -1369 ((-685 (-217)) (-638 (-217)) (-769)))) 
-((-3112 (((-121) $ $) 11)) (-2190 (($ $ $) 15)) (-2208 (($ $ $) 14)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 43)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 52)) (-3069 (($ $ $) 21) (($ (-638 $)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 31) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 36)) (-1803 (((-3 $ "failed") $ $) 18)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 45))) 
-(((-302 |#1|) (-10 -8 (-15 -3570 ((-3 (-638 |#1|) "failed") (-638 |#1|) |#1|)) (-15 -3087 ((-3 (-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|)) "failed") |#1| |#1| |#1|)) (-15 -3087 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2307 |#1|)) |#1| |#1|)) (-15 -2190 (|#1| |#1| |#1|)) (-15 -2208 (|#1| |#1| |#1|)) (-15 -3112 ((-121) |#1| |#1|)) (-15 -4354 ((-3 (-638 |#1|) "failed") (-638 |#1|) |#1|)) (-15 -3326 ((-2 (|:| -4513 (-638 |#1|)) (|:| -2307 |#1|)) (-638 |#1|))) (-15 -3069 (|#1| (-638 |#1|))) (-15 -3069 (|#1| |#1| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#1|))) (-303)) (T -302)) 
-NIL 
-(-10 -8 (-15 -3570 ((-3 (-638 |#1|) "failed") (-638 |#1|) |#1|)) (-15 -3087 ((-3 (-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|)) "failed") |#1| |#1| |#1|)) (-15 -3087 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2307 |#1|)) |#1| |#1|)) (-15 -2190 (|#1| |#1| |#1|)) (-15 -2208 (|#1| |#1| |#1|)) (-15 -3112 ((-121) |#1| |#1|)) (-15 -4354 ((-3 (-638 |#1|) "failed") (-638 |#1|) |#1|)) (-15 -3326 ((-2 (|:| -4513 (-638 |#1|)) (|:| -2307 |#1|)) (-638 |#1|))) (-15 -3069 (|#1| (-638 |#1|))) (-15 -3069 (|#1| |#1| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-3112 (((-121) $ $) 57)) (-2211 (($) 16 T CONST)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-3893 (((-121) $) 30)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-303) (-1290)) (T -303)) 
-((-3112 (*1 *2 *1 *1) (-12 (-4 *1 (-303)) (-5 *2 (-121)))) (-4029 (*1 *2 *1) (-12 (-4 *1 (-303)) (-5 *2 (-769)))) (-2541 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-303)))) (-2208 (*1 *1 *1 *1) (-4 *1 (-303))) (-2190 (*1 *1 *1 *1) (-4 *1 (-303))) (-3087 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2307 *1))) (-4 *1 (-303)))) (-3087 (*1 *2 *1 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-303)))) (-3570 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-638 *1)) (-4 *1 (-303))))) 
-(-13 (-922) (-10 -8 (-15 -3112 ((-121) $ $)) (-15 -4029 ((-769) $)) (-15 -2541 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -2208 ($ $ $)) (-15 -2190 ($ $ $)) (-15 -3087 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $)) (-15 -3087 ((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $)) (-15 -3570 ((-3 (-638 $) "failed") (-638 $) $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-457) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-4485 (($ $ (-638 |#2|) (-638 |#2|)) 14) (($ $ |#2| |#2|) NIL) (($ $ (-290 |#2|)) 11) (($ $ (-638 (-290 |#2|))) NIL))) 
-(((-304 |#1| |#2|) (-10 -8 (-15 -4485 (|#1| |#1| (-638 (-290 |#2|)))) (-15 -4485 (|#1| |#1| (-290 |#2|))) (-15 -4485 (|#1| |#1| |#2| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#2|) (-638 |#2|)))) (-305 |#2|) (-1098)) (T -304)) 
-NIL 
-(-10 -8 (-15 -4485 (|#1| |#1| (-638 (-290 |#2|)))) (-15 -4485 (|#1| |#1| (-290 |#2|))) (-15 -4485 (|#1| |#1| |#2| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#2|) (-638 |#2|)))) 
-((-4485 (($ $ (-638 |#1|) (-638 |#1|)) 7) (($ $ |#1| |#1|) 6) (($ $ (-290 |#1|)) 9) (($ $ (-638 (-290 |#1|))) 8))) 
-(((-305 |#1|) (-1290) (-1098)) (T -305)) 
-((-4485 (*1 *1 *1 *2) (-12 (-5 *2 (-290 *3)) (-4 *1 (-305 *3)) (-4 *3 (-1098)))) (-4485 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-290 *3))) (-4 *1 (-305 *3)) (-4 *3 (-1098))))) 
-(-13 (-527 |t#1| |t#1|) (-10 -8 (-15 -4485 ($ $ (-290 |t#1|))) (-15 -4485 ($ $ (-638 (-290 |t#1|)))))) 
-(((-527 |#1| |#1|) . T)) 
-((-4485 ((|#1| (-1 |#1| (-572)) (-1172 (-413 (-572)))) 24))) 
-(((-306 |#1|) (-10 -7 (-15 -4485 (|#1| (-1 |#1| (-572)) (-1172 (-413 (-572)))))) (-43 (-413 (-572)))) (T -306)) 
-((-4485 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-572))) (-5 *4 (-1172 (-413 (-572)))) (-5 *1 (-306 *2)) (-4 *2 (-43 (-413 (-572))))))) 
-(-10 -7 (-15 -4485 (|#1| (-1 |#1| (-572)) (-1172 (-413 (-572)))))) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 7)) (-1324 (((-121) $ $) 9))) 
-(((-307) (-1098)) (T -307)) 
-NIL 
-(-1098) 
-((-4083 (((-1264) (-1158 3 (-217)) (-1152)) 38))) 
-(((-308) (-10 -7 (-15 -4083 ((-1264) (-1158 3 (-217)) (-1152))))) (T -308)) 
-((-4083 (*1 *2 *3 *4) (-12 (-5 *3 (-1158 3 (-217))) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-308))))) 
-(-10 -7 (-15 -4083 ((-1264) (-1158 3 (-217)) (-1152)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 62)) (-2551 (((-1244 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-1244 |#1| |#2| |#3| |#4|) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1044 (-572)))) (((-3 (-572) "failed") $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1044 (-572)))) (((-3 (-1243 |#2| |#3| |#4|) "failed") $) 24)) (-1318 (((-1244 |#1| |#2| |#3| |#4|) $) NIL) (((-1170) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1044 (-1170)))) (((-413 (-572)) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1044 (-572)))) (((-572) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1044 (-572)))) (((-1243 |#2| |#3| |#4|) $) NIL)) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-1244 |#1| |#2| |#3| |#4|))) (|:| |vec| (-1259 (-1244 |#1| |#2| |#3| |#4|)))) (-685 $) (-1259 $)) NIL) (((-685 (-1244 |#1| |#2| |#3| |#4|)) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-887 (-385))))) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL)) (-4487 (((-1244 |#1| |#2| |#3| |#4|) $) 21)) (-3961 (((-3 $ "failed") $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1144)))) (-4472 (((-121) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-848)))) (-4238 (($ $ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-848)))) (-3828 (($ (-1 (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|)) $) NIL)) (-2022 (((-3 (-841 |#2|) "failed") $) 76)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-303)))) (-1716 (((-1244 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 (-1244 |#1| |#2| |#3| |#4|)) (-638 (-1244 |#1| |#2| |#3| |#4|))) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-305 (-1244 |#1| |#2| |#3| |#4|)))) (($ $ (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-305 (-1244 |#1| |#2| |#3| |#4|)))) (($ $ (-290 (-1244 |#1| |#2| |#3| |#4|))) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-305 (-1244 |#1| |#2| |#3| |#4|)))) (($ $ (-638 (-290 (-1244 |#1| |#2| |#3| |#4|)))) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-305 (-1244 |#1| |#2| |#3| |#4|)))) (($ $ (-638 (-1170)) (-638 (-1244 |#1| |#2| |#3| |#4|))) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-527 (-1170) (-1244 |#1| |#2| |#3| |#4|)))) (($ $ (-1170) (-1244 |#1| |#2| |#3| |#4|)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-527 (-1170) (-1244 |#1| |#2| |#3| |#4|))))) (-4029 (((-769) $) NIL)) (-3277 (($ $ (-1244 |#1| |#2| |#3| |#4|)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-283 (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-227))) (($ $ (-769)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-227))) (($ $ (-1170)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-901 (-1170)))) (($ $ (-1 (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|)) (-769)) NIL) (($ $ (-1 (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|))) NIL)) (-3425 (($ $) NIL)) (-4492 (((-1244 |#1| |#2| |#3| |#4|) $) 17)) (-4081 (((-893 (-572)) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-613 (-893 (-385))))) (((-545) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-613 (-545)))) (((-385) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1028))) (((-217) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1028)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-1244 |#1| |#2| |#3| |#4|) (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-1244 |#1| |#2| |#3| |#4|)) 28) (($ (-1170)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-1044 (-1170)))) (($ (-1243 |#2| |#3| |#4|)) 36)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-1244 |#1| |#2| |#3| |#4|) (-910))) (|has| (-1244 |#1| |#2| |#3| |#4|) (-149))))) (-2140 (((-769)) NIL)) (-2634 (((-1244 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-554)))) (-3774 (((-121) $ $) NIL)) (-2264 (($ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 41 T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-227))) (($ $ (-769)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-227))) (($ $ (-1170)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-901 (-1170)))) (($ $ (-1 (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|)) (-769)) NIL) (($ $ (-1 (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|))) NIL)) (-1349 (((-121) $ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-1244 |#1| |#2| |#3| |#4|) (-848)))) (-1379 (($ $ $) 33) (($ (-1244 |#1| |#2| |#3| |#4|) (-1244 |#1| |#2| |#3| |#4|)) 30)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ (-1244 |#1| |#2| |#3| |#4|) $) 29) (($ $ (-1244 |#1| |#2| |#3| |#4|)) NIL))) 
-(((-309 |#1| |#2| |#3| |#4|) (-13 (-1000 (-1244 |#1| |#2| |#3| |#4|)) (-1044 (-1243 |#2| |#3| |#4|)) (-10 -8 (-15 -2022 ((-3 (-841 |#2|) "failed") $)) (-15 -3972 ($ (-1243 |#2| |#3| |#4|))))) (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457)) (-13 (-27) (-1190) (-436 |#1|)) (-1170) |#2|) (T -309)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1243 *4 *5 *6)) (-4 *4 (-13 (-27) (-1190) (-436 *3))) (-14 *5 (-1170)) (-14 *6 *4) (-4 *3 (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457))) (-5 *1 (-309 *3 *4 *5 *6)))) (-2022 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457))) (-5 *2 (-841 *4)) (-5 *1 (-309 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1190) (-436 *3))) (-14 *5 (-1170)) (-14 *6 *4)))) 
-(-13 (-1000 (-1244 |#1| |#2| |#3| |#4|)) (-1044 (-1243 |#2| |#3| |#4|)) (-10 -8 (-15 -2022 ((-3 (-841 |#2|) "failed") $)) (-15 -3972 ($ (-1243 |#2| |#3| |#4|))))) 
-((-3828 (((-312 |#2|) (-1 |#2| |#1|) (-312 |#1|)) 13))) 
-(((-310 |#1| |#2|) (-10 -7 (-15 -3828 ((-312 |#2|) (-1 |#2| |#1|) (-312 |#1|)))) (-848) (-848)) (T -310)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-312 *5)) (-4 *5 (-848)) (-4 *6 (-848)) (-5 *2 (-312 *6)) (-5 *1 (-310 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-312 |#2|) (-1 |#2| |#1|) (-312 |#1|)))) 
-((-1881 (((-57) |#2| (-290 |#2|) (-769)) 33) (((-57) |#2| (-290 |#2|)) 24) (((-57) |#2| (-769)) 28) (((-57) |#2|) 25) (((-57) (-1170)) 21)) (-4521 (((-57) |#2| (-290 |#2|) (-413 (-572))) 51) (((-57) |#2| (-290 |#2|)) 48) (((-57) |#2| (-413 (-572))) 50) (((-57) |#2|) 49) (((-57) (-1170)) 47)) (-1889 (((-57) |#2| (-290 |#2|) (-413 (-572))) 46) (((-57) |#2| (-290 |#2|)) 43) (((-57) |#2| (-413 (-572))) 45) (((-57) |#2|) 44) (((-57) (-1170)) 42)) (-1885 (((-57) |#2| (-290 |#2|) (-572)) 39) (((-57) |#2| (-290 |#2|)) 35) (((-57) |#2| (-572)) 38) (((-57) |#2|) 36) (((-57) (-1170)) 34))) 
-(((-311 |#1| |#2|) (-10 -7 (-15 -1881 ((-57) (-1170))) (-15 -1881 ((-57) |#2|)) (-15 -1881 ((-57) |#2| (-769))) (-15 -1881 ((-57) |#2| (-290 |#2|))) (-15 -1881 ((-57) |#2| (-290 |#2|) (-769))) (-15 -1885 ((-57) (-1170))) (-15 -1885 ((-57) |#2|)) (-15 -1885 ((-57) |#2| (-572))) (-15 -1885 ((-57) |#2| (-290 |#2|))) (-15 -1885 ((-57) |#2| (-290 |#2|) (-572))) (-15 -1889 ((-57) (-1170))) (-15 -1889 ((-57) |#2|)) (-15 -1889 ((-57) |#2| (-413 (-572)))) (-15 -1889 ((-57) |#2| (-290 |#2|))) (-15 -1889 ((-57) |#2| (-290 |#2|) (-413 (-572)))) (-15 -4521 ((-57) (-1170))) (-15 -4521 ((-57) |#2|)) (-15 -4521 ((-57) |#2| (-413 (-572)))) (-15 -4521 ((-57) |#2| (-290 |#2|))) (-15 -4521 ((-57) |#2| (-290 |#2|) (-413 (-572))))) (-13 (-457) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|))) (T -311)) 
-((-4521 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-290 *3)) (-5 *5 (-413 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) (-4521 (*1 *2 *3 *4) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)))) (-4521 (*1 *2 *3 *4) (-12 (-5 *4 (-413 (-572))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-4521 (*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) (-4521 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *5)) (-4 *5 (-13 (-27) (-1190) (-436 *4))))) (-1889 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-290 *3)) (-5 *5 (-413 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) (-1889 (*1 *2 *3 *4) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)))) (-1889 (*1 *2 *3 *4) (-12 (-5 *4 (-413 (-572))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-1889 (*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) (-1889 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *5)) (-4 *5 (-13 (-27) (-1190) (-436 *4))))) (-1885 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 *5) (-634 *5))) (-5 *5 (-572)) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) (-1885 (*1 *2 *3 *4) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)))) (-1885 (*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-13 (-457) (-848) (-1044 *4) (-634 *4))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-1885 (*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) (-1885 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *5)) (-4 *5 (-13 (-27) (-1190) (-436 *4))))) (-1881 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-290 *3)) (-5 *5 (-769)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) (-1881 (*1 *2 *3 *4) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)))) (-1881 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-1881 (*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) (-1881 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *5)) (-4 *5 (-13 (-27) (-1190) (-436 *4)))))) 
-(-10 -7 (-15 -1881 ((-57) (-1170))) (-15 -1881 ((-57) |#2|)) (-15 -1881 ((-57) |#2| (-769))) (-15 -1881 ((-57) |#2| (-290 |#2|))) (-15 -1881 ((-57) |#2| (-290 |#2|) (-769))) (-15 -1885 ((-57) (-1170))) (-15 -1885 ((-57) |#2|)) (-15 -1885 ((-57) |#2| (-572))) (-15 -1885 ((-57) |#2| (-290 |#2|))) (-15 -1885 ((-57) |#2| (-290 |#2|) (-572))) (-15 -1889 ((-57) (-1170))) (-15 -1889 ((-57) |#2|)) (-15 -1889 ((-57) |#2| (-413 (-572)))) (-15 -1889 ((-57) |#2| (-290 |#2|))) (-15 -1889 ((-57) |#2| (-290 |#2|) (-413 (-572)))) (-15 -4521 ((-57) (-1170))) (-15 -4521 ((-57) |#2|)) (-15 -4521 ((-57) |#2| (-413 (-572)))) (-15 -4521 ((-57) |#2| (-290 |#2|))) (-15 -4521 ((-57) |#2| (-290 |#2|) (-413 (-572))))) 
-((-2262 (((-121) $ $) NIL)) (-1770 (((-638 $) $ (-1170)) NIL (|has| |#1| (-562))) (((-638 $) $) NIL (|has| |#1| (-562))) (((-638 $) (-1166 $) (-1170)) NIL (|has| |#1| (-562))) (((-638 $) (-1166 $)) NIL (|has| |#1| (-562))) (((-638 $) (-959 $)) NIL (|has| |#1| (-562)))) (-1627 (($ $ (-1170)) NIL (|has| |#1| (-562))) (($ $) NIL (|has| |#1| (-562))) (($ (-1166 $) (-1170)) NIL (|has| |#1| (-562))) (($ (-1166 $)) NIL (|has| |#1| (-562))) (($ (-959 $)) NIL (|has| |#1| (-562)))) (-1342 (((-121) $) 27 (-1841 (|has| |#1| (-25)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))))) (-3456 (((-638 (-1170)) $) 348)) (-4297 (((-413 (-1166 $)) $ (-611 $)) NIL (|has| |#1| (-562)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-1337 (((-638 (-611 $)) $) NIL)) (-4284 (($ $) 154 (|has| |#1| (-562)))) (-4224 (($ $) 130 (|has| |#1| (-562)))) (-1415 (($ $ (-1090 $)) 215 (|has| |#1| (-562))) (($ $ (-1170)) 211 (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) NIL (-1841 (|has| |#1| (-21)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))))) (-1952 (($ $ (-290 $)) NIL) (($ $ (-638 (-290 $))) 364) (($ $ (-638 (-611 $)) (-638 $)) 407)) (-4073 (((-424 (-1166 $)) (-1166 $)) 292 (-12 (|has| |#1| (-457)) (|has| |#1| (-562))))) (-2844 (($ $) NIL (|has| |#1| (-562)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-562)))) (-4190 (($ $) NIL (|has| |#1| (-562)))) (-3112 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4273 (($ $) 150 (|has| |#1| (-562)))) (-4217 (($ $) 126 (|has| |#1| (-562)))) (-2272 (($ $ (-572)) 64 (|has| |#1| (-562)))) (-4295 (($ $) 158 (|has| |#1| (-562)))) (-4233 (($ $) 134 (|has| |#1| (-562)))) (-2211 (($) NIL (-1841 (|has| |#1| (-25)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110))) CONST)) (-3584 (((-638 $) $ (-1170)) NIL (|has| |#1| (-562))) (((-638 $) $) NIL (|has| |#1| (-562))) (((-638 $) (-1166 $) (-1170)) NIL (|has| |#1| (-562))) (((-638 $) (-1166 $)) NIL (|has| |#1| (-562))) (((-638 $) (-959 $)) NIL (|has| |#1| (-562)))) (-3733 (($ $ (-1170)) NIL (|has| |#1| (-562))) (($ $) NIL (|has| |#1| (-562))) (($ (-1166 $) (-1170)) 117 (|has| |#1| (-562))) (($ (-1166 $)) NIL (|has| |#1| (-562))) (($ (-959 $)) NIL (|has| |#1| (-562)))) (-3376 (((-3 (-611 $) "failed") $) 17) (((-3 (-1170) "failed") $) NIL) (((-3 |#1| "failed") $) 416) (((-3 (-53) "failed") $) 321 (-12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-959 |#1|)) "failed") $) NIL (|has| |#1| (-562))) (((-3 (-959 |#1|) "failed") $) NIL (|has| |#1| (-1054))) (((-3 (-413 (-572)) "failed") $) 45 (-1841 (-12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572)))) (|has| |#1| (-1044 (-413 (-572))))))) (-1318 (((-611 $) $) 11) (((-1170) $) NIL) ((|#1| $) 398) (((-53) $) NIL (-12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-959 |#1|)) $) NIL (|has| |#1| (-562))) (((-959 |#1|) $) NIL (|has| |#1| (-1054))) (((-413 (-572)) $) 305 (-1841 (-12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572)))) (|has| |#1| (-1044 (-413 (-572))))))) (-2190 (($ $ $) NIL (|has| |#1| (-562)))) (-2284 (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 110 (|has| |#1| (-1054))) (((-685 |#1|) (-685 $)) 102 (|has| |#1| (-1054))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))) (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))))) (-3116 (($ $) 84 (|has| |#1| (-562)))) (-1799 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110))))) (-2208 (($ $ $) NIL (|has| |#1| (-562)))) (-1642 (($ $ (-1090 $)) 219 (|has| |#1| (-562))) (($ $ (-1170)) 217 (|has| |#1| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-562)))) (-1526 (((-121) $) NIL (|has| |#1| (-562)))) (-1459 (($ $ $) 185 (|has| |#1| (-562)))) (-4184 (($) 120 (|has| |#1| (-562)))) (-2133 (($ $ $) 205 (|has| |#1| (-562)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 370 (|has| |#1| (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 376 (|has| |#1| (-887 (-385))))) (-3567 (($ $) NIL) (($ (-638 $)) NIL)) (-4091 (((-638 (-123)) $) NIL)) (-4564 (((-123) (-123)) 264)) (-3893 (((-121) $) 25 (-1841 (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110))))) (-4240 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4347 (($ $) 66 (|has| |#1| (-1054)))) (-4487 (((-1121 |#1| (-611 $)) $) 79 (|has| |#1| (-1054)))) (-1618 (((-121) $) 46 (|has| |#1| (-562)))) (-1451 (($ $ (-572)) NIL (|has| |#1| (-562)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-562)))) (-4127 (((-1166 $) (-611 $)) 265 (|has| $ (-1054)))) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 $ $) (-611 $)) 403)) (-3614 (((-3 (-611 $) "failed") $) NIL)) (-3539 (($ $) 124 (|has| |#1| (-562)))) (-4198 (($ $) 230 (|has| |#1| (-562)))) (-1629 (($ (-638 $)) NIL (|has| |#1| (-562))) (($ $ $) NIL (|has| |#1| (-562)))) (-1658 (((-1152) $) NIL)) (-4291 (((-638 (-611 $)) $) 48)) (-4496 (($ (-123) $) NIL) (($ (-123) (-638 $)) 408)) (-1921 (((-3 (-638 $) "failed") $) NIL (|has| |#1| (-1110)))) (-2472 (((-3 (-2 (|:| |val| $) (|:| -3751 (-572))) "failed") $) NIL (|has| |#1| (-1054)))) (-2336 (((-3 (-638 $) "failed") $) 411 (|has| |#1| (-25)))) (-1595 (((-3 (-2 (|:| -4513 (-572)) (|:| |var| (-611 $))) "failed") $) 415 (|has| |#1| (-25)))) (-3019 (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $) NIL (|has| |#1| (-1110))) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-123)) NIL (|has| |#1| (-1054))) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-1170)) NIL (|has| |#1| (-1054)))) (-3291 (((-121) $ (-123)) NIL) (((-121) $ (-1170)) 52)) (-4350 (($ $) NIL (-1841 (|has| |#1| (-482)) (|has| |#1| (-562))))) (-4282 (($ $ (-1170)) 238 (|has| |#1| (-562))) (($ $ (-1090 $)) 240 (|has| |#1| (-562)))) (-1455 (((-769) $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 43)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 285 (|has| |#1| (-562)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-562))) (($ $ $) NIL (|has| |#1| (-562)))) (-2650 (($ $) 234 (|has| |#1| (-562)))) (-1327 (($ $) 236 (|has| |#1| (-562)))) (-4319 (((-121) $ $) NIL) (((-121) $ (-1170)) NIL)) (-3288 (($ $ (-1170)) 209 (|has| |#1| (-562))) (($ $) 207 (|has| |#1| (-562)))) (-2900 (($ $) 201 (|has| |#1| (-562)))) (-3992 (((-424 (-1166 $)) (-1166 $)) 290 (-12 (|has| |#1| (-457)) (|has| |#1| (-562))))) (-4304 (((-424 $) $) NIL (|has| |#1| (-562)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-562))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-562)))) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-562)))) (-4179 (($ $) 122 (|has| |#1| (-562)))) (-4247 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4485 (($ $ (-611 $) $) NIL) (($ $ (-638 (-611 $)) (-638 $)) 402) (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-1170) (-1 $ (-638 $))) NIL) (($ $ (-1170) (-1 $ $)) NIL) (($ $ (-638 (-123)) (-638 (-1 $ $))) 358) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-123) (-1 $ (-638 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1170)) NIL (|has| |#1| (-613 (-545)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-613 (-545)))) (($ $) NIL (|has| |#1| (-613 (-545)))) (($ $ (-123) $ (-1170)) 346 (|has| |#1| (-613 (-545)))) (($ $ (-638 (-123)) (-638 $) (-1170)) 345 (|has| |#1| (-613 (-545)))) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ $))) NIL (|has| |#1| (-1054))) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ (-638 $)))) NIL (|has| |#1| (-1054))) (($ $ (-1170) (-769) (-1 $ (-638 $))) NIL (|has| |#1| (-1054))) (($ $ (-1170) (-769) (-1 $ $)) NIL (|has| |#1| (-1054)))) (-4029 (((-769) $) NIL (|has| |#1| (-562)))) (-4203 (($ $) 222 (|has| |#1| (-562)))) (-3277 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-638 $)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-2759 (($ $) NIL) (($ $ $) NIL)) (-4213 (($ $) 232 (|has| |#1| (-562)))) (-2350 (($ $) 183 (|has| |#1| (-562)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-1054))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-1054))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-1054))) (($ $ (-1170)) NIL (|has| |#1| (-1054)))) (-3425 (($ $) 67 (|has| |#1| (-562)))) (-4492 (((-1121 |#1| (-611 $)) $) 81 (|has| |#1| (-562)))) (-2830 (($ $) 303 (|has| $ (-1054)))) (-4302 (($ $) 160 (|has| |#1| (-562)))) (-4237 (($ $) 136 (|has| |#1| (-562)))) (-4289 (($ $) 156 (|has| |#1| (-562)))) (-4228 (($ $) 132 (|has| |#1| (-562)))) (-4278 (($ $) 152 (|has| |#1| (-562)))) (-4220 (($ $) 128 (|has| |#1| (-562)))) (-4081 (((-893 (-572)) $) NIL (|has| |#1| (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| |#1| (-613 (-893 (-385))))) (($ (-424 $)) NIL (|has| |#1| (-562))) (((-545) $) 343 (|has| |#1| (-613 (-545))))) (-3018 (($ $ $) NIL (|has| |#1| (-482)))) (-4056 (($ $ $) NIL (|has| |#1| (-482)))) (-3972 (((-856) $) 401) (($ (-611 $)) 392) (($ (-1170)) 360) (($ |#1|) 322) (($ $) NIL (|has| |#1| (-562))) (($ (-53)) 297 (-12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572))))) (($ (-1121 |#1| (-611 $))) 83 (|has| |#1| (-1054))) (($ (-413 |#1|)) NIL (|has| |#1| (-562))) (($ (-959 (-413 |#1|))) NIL (|has| |#1| (-562))) (($ (-413 (-959 (-413 |#1|)))) NIL (|has| |#1| (-562))) (($ (-413 (-959 |#1|))) NIL (|has| |#1| (-562))) (($ (-959 |#1|)) NIL (|has| |#1| (-1054))) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-562)) (|has| |#1| (-1044 (-413 (-572)))))) (($ (-572)) 34 (-1841 (|has| |#1| (-1044 (-572))) (|has| |#1| (-1054))))) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL (|has| |#1| (-1054)))) (-3497 (($ $) NIL) (($ (-638 $)) NIL)) (-3610 (($ $ $) 203 (|has| |#1| (-562)))) (-3045 (($ $ $) 189 (|has| |#1| (-562)))) (-2625 (($ $ $) 193 (|has| |#1| (-562)))) (-2312 (($ $ $) 187 (|has| |#1| (-562)))) (-2638 (($ $ $) 191 (|has| |#1| (-562)))) (-3228 (((-121) (-123)) 9)) (-4321 (($ $) 166 (|has| |#1| (-562)))) (-4251 (($ $) 142 (|has| |#1| (-562)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) 162 (|has| |#1| (-562)))) (-4241 (($ $) 138 (|has| |#1| (-562)))) (-4333 (($ $) 170 (|has| |#1| (-562)))) (-4263 (($ $) 146 (|has| |#1| (-562)))) (-2973 (($ (-1170) $) NIL) (($ (-1170) $ $) NIL) (($ (-1170) $ $ $) NIL) (($ (-1170) $ $ $ $) NIL) (($ (-1170) (-638 $)) NIL)) (-3804 (($ $) 197 (|has| |#1| (-562)))) (-1465 (($ $) 195 (|has| |#1| (-562)))) (-2104 (($ $) 172 (|has| |#1| (-562)))) (-4268 (($ $) 148 (|has| |#1| (-562)))) (-4327 (($ $) 168 (|has| |#1| (-562)))) (-4257 (($ $) 144 (|has| |#1| (-562)))) (-4314 (($ $) 164 (|has| |#1| (-562)))) (-4246 (($ $) 140 (|has| |#1| (-562)))) (-2264 (($ $) 175 (|has| |#1| (-562)))) (-4174 (($ $ (-572)) NIL (-1841 (|has| |#1| (-482)) (|has| |#1| (-562)))) (($ $ (-769)) NIL (-1841 (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110)))) (($ $ (-923)) NIL (-1841 (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110))))) (-2378 (($) 20 (-1841 (|has| |#1| (-25)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))) CONST)) (-2856 (($ $) 226 (|has| |#1| (-562)))) (-3255 (($) 22 (-1841 (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110))) CONST)) (-1877 (($ $) 177 (|has| |#1| (-562))) (($ $ $) 179 (|has| |#1| (-562)))) (-1622 (($ $) 224 (|has| |#1| (-562)))) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-1054))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-1054))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-1054))) (($ $ (-1170)) NIL (|has| |#1| (-1054)))) (-3481 (($ $) 228 (|has| |#1| (-562)))) (-1869 (($ $ $) 181 (|has| |#1| (-562)))) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 76)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 75)) (-1379 (($ (-1121 |#1| (-611 $)) (-1121 |#1| (-611 $))) 93 (|has| |#1| (-562))) (($ $ $) 42 (-1841 (|has| |#1| (-482)) (|has| |#1| (-562))))) (-1373 (($ $ $) 40 (-1841 (|has| |#1| (-21)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))))) (($ $) 29 (-1841 (|has| |#1| (-21)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))))) (-1367 (($ $ $) 38 (-1841 (|has| |#1| (-25)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))))) (** (($ $ $) 61 (|has| |#1| (-562))) (($ $ (-413 (-572))) 300 (|has| |#1| (-562))) (($ $ (-572)) 71 (-1841 (|has| |#1| (-482)) (|has| |#1| (-562)))) (($ $ (-769)) 68 (-1841 (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110)))) (($ $ (-923)) 73 (-1841 (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110))))) (* (($ (-413 (-572)) $) NIL (|has| |#1| (-562))) (($ $ (-413 (-572))) NIL (|has| |#1| (-562))) (($ |#1| $) NIL (|has| |#1| (-174))) (($ $ |#1|) NIL (|has| |#1| (-174))) (($ $ $) 36 (-1841 (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) (|has| |#1| (-1110)))) (($ (-572) $) 32 (-1841 (|has| |#1| (-21)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))))) (($ (-769) $) NIL (-1841 (|has| |#1| (-25)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))))) (($ (-923) $) NIL (-1841 (|has| |#1| (-25)) (-12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))))))) 
-(((-312 |#1|) (-13 (-436 |#1|) (-10 -8 (IF (|has| |#1| (-562)) (PROGN (-6 (-29 |#1|)) (-6 (-1190)) (-6 (-162)) (-6 (-624)) (-6 (-1132)) (-15 -3116 ($ $)) (-15 -1618 ((-121) $)) (-15 -2272 ($ $ (-572))) (IF (|has| |#1| (-457)) (PROGN (-15 -3992 ((-424 (-1166 $)) (-1166 $))) (-15 -4073 ((-424 (-1166 $)) (-1166 $)))) |noBranch|) (IF (|has| |#1| (-1044 (-572))) (-6 (-1044 (-53))) |noBranch|)) |noBranch|))) (-848)) (T -312)) 
-((-3116 (*1 *1 *1) (-12 (-5 *1 (-312 *2)) (-4 *2 (-562)) (-4 *2 (-848)))) (-1618 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-312 *3)) (-4 *3 (-562)) (-4 *3 (-848)))) (-2272 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-312 *3)) (-4 *3 (-562)) (-4 *3 (-848)))) (-3992 (*1 *2 *3) (-12 (-5 *2 (-424 (-1166 *1))) (-5 *1 (-312 *4)) (-5 *3 (-1166 *1)) (-4 *4 (-457)) (-4 *4 (-562)) (-4 *4 (-848)))) (-4073 (*1 *2 *3) (-12 (-5 *2 (-424 (-1166 *1))) (-5 *1 (-312 *4)) (-5 *3 (-1166 *1)) (-4 *4 (-457)) (-4 *4 (-562)) (-4 *4 (-848))))) 
-(-13 (-436 |#1|) (-10 -8 (IF (|has| |#1| (-562)) (PROGN (-6 (-29 |#1|)) (-6 (-1190)) (-6 (-162)) (-6 (-624)) (-6 (-1132)) (-15 -3116 ($ $)) (-15 -1618 ((-121) $)) (-15 -2272 ($ $ (-572))) (IF (|has| |#1| (-457)) (PROGN (-15 -3992 ((-424 (-1166 $)) (-1166 $))) (-15 -4073 ((-424 (-1166 $)) (-1166 $)))) |noBranch|) (IF (|has| |#1| (-1044 (-572))) (-6 (-1044 (-53))) |noBranch|)) |noBranch|))) 
-((-3542 (((-57) |#2| (-123) (-290 |#2|) (-638 |#2|)) 86) (((-57) |#2| (-123) (-290 |#2|) (-290 |#2|)) 82) (((-57) |#2| (-123) (-290 |#2|) |#2|) 84) (((-57) (-290 |#2|) (-123) (-290 |#2|) |#2|) 85) (((-57) (-638 |#2|) (-638 (-123)) (-290 |#2|) (-638 (-290 |#2|))) 78) (((-57) (-638 |#2|) (-638 (-123)) (-290 |#2|) (-638 |#2|)) 80) (((-57) (-638 (-290 |#2|)) (-638 (-123)) (-290 |#2|) (-638 |#2|)) 81) (((-57) (-638 (-290 |#2|)) (-638 (-123)) (-290 |#2|) (-638 (-290 |#2|))) 79) (((-57) (-290 |#2|) (-123) (-290 |#2|) (-638 |#2|)) 87) (((-57) (-290 |#2|) (-123) (-290 |#2|) (-290 |#2|)) 83))) 
-(((-313 |#1| |#2|) (-10 -7 (-15 -3542 ((-57) (-290 |#2|) (-123) (-290 |#2|) (-290 |#2|))) (-15 -3542 ((-57) (-290 |#2|) (-123) (-290 |#2|) (-638 |#2|))) (-15 -3542 ((-57) (-638 (-290 |#2|)) (-638 (-123)) (-290 |#2|) (-638 (-290 |#2|)))) (-15 -3542 ((-57) (-638 (-290 |#2|)) (-638 (-123)) (-290 |#2|) (-638 |#2|))) (-15 -3542 ((-57) (-638 |#2|) (-638 (-123)) (-290 |#2|) (-638 |#2|))) (-15 -3542 ((-57) (-638 |#2|) (-638 (-123)) (-290 |#2|) (-638 (-290 |#2|)))) (-15 -3542 ((-57) (-290 |#2|) (-123) (-290 |#2|) |#2|)) (-15 -3542 ((-57) |#2| (-123) (-290 |#2|) |#2|)) (-15 -3542 ((-57) |#2| (-123) (-290 |#2|) (-290 |#2|))) (-15 -3542 ((-57) |#2| (-123) (-290 |#2|) (-638 |#2|)))) (-13 (-848) (-562) (-613 (-545))) (-436 |#1|)) (T -313)) 
-((-3542 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-290 *3)) (-5 *6 (-638 *3)) (-4 *3 (-436 *7)) (-4 *7 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *7 *3)))) (-3542 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-123)) (-5 *5 (-290 *3)) (-4 *3 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *3)))) (-3542 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-123)) (-5 *5 (-290 *3)) (-4 *3 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *3)))) (-3542 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-290 *5)) (-5 *4 (-123)) (-4 *5 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *5)))) (-3542 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 (-123))) (-5 *6 (-638 (-290 *8))) (-4 *8 (-436 *7)) (-5 *5 (-290 *8)) (-4 *7 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *7 *8)))) (-3542 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-638 *7)) (-5 *4 (-638 (-123))) (-5 *5 (-290 *7)) (-4 *7 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *7)))) (-3542 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 (-290 *8))) (-5 *4 (-638 (-123))) (-5 *5 (-290 *8)) (-5 *6 (-638 *8)) (-4 *8 (-436 *7)) (-4 *7 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *7 *8)))) (-3542 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-638 (-290 *7))) (-5 *4 (-638 (-123))) (-5 *5 (-290 *7)) (-4 *7 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *7)))) (-3542 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-290 *7)) (-5 *4 (-123)) (-5 *5 (-638 *7)) (-4 *7 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *7)))) (-3542 (*1 *2 *3 *4 *3 *3) (-12 (-5 *3 (-290 *6)) (-5 *4 (-123)) (-4 *6 (-436 *5)) (-4 *5 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *5 *6))))) 
-(-10 -7 (-15 -3542 ((-57) (-290 |#2|) (-123) (-290 |#2|) (-290 |#2|))) (-15 -3542 ((-57) (-290 |#2|) (-123) (-290 |#2|) (-638 |#2|))) (-15 -3542 ((-57) (-638 (-290 |#2|)) (-638 (-123)) (-290 |#2|) (-638 (-290 |#2|)))) (-15 -3542 ((-57) (-638 (-290 |#2|)) (-638 (-123)) (-290 |#2|) (-638 |#2|))) (-15 -3542 ((-57) (-638 |#2|) (-638 (-123)) (-290 |#2|) (-638 |#2|))) (-15 -3542 ((-57) (-638 |#2|) (-638 (-123)) (-290 |#2|) (-638 (-290 |#2|)))) (-15 -3542 ((-57) (-290 |#2|) (-123) (-290 |#2|) |#2|)) (-15 -3542 ((-57) |#2| (-123) (-290 |#2|) |#2|)) (-15 -3542 ((-57) |#2| (-123) (-290 |#2|) (-290 |#2|))) (-15 -3542 ((-57) |#2| (-123) (-290 |#2|) (-638 |#2|)))) 
-((-3542 ((|#3| |#2| (-123) (-1170) (-638 |#2|)) 53)) (-2452 ((|#2| |#2| (-123) (-1170)) 30))) 
-(((-314 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3542 (|#3| |#2| (-123) (-1170) (-638 |#2|))) (-15 -2452 (|#2| |#2| (-123) (-1170)))) (-13 (-848) (-562) (-613 (-545))) (-436 |#1|) (-1249 |#2|) (-1249 (-1164 |#2|))) (T -314)) 
-((-2452 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-123)) (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-562) (-613 (-545)))) (-4 *2 (-436 *5)) (-5 *1 (-314 *5 *2 *6 *7)) (-4 *6 (-1249 *2)) (-4 *7 (-1249 (-1164 *2))))) (-3542 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-1170)) (-5 *6 (-638 *3)) (-4 *3 (-436 *7)) (-4 *7 (-13 (-848) (-562) (-613 (-545)))) (-4 *2 (-1249 *3)) (-5 *1 (-314 *7 *3 *2 *8)) (-4 *8 (-1249 (-1164 *3)))))) 
-(-10 -7 (-15 -3542 (|#3| |#2| (-123) (-1170) (-638 |#2|))) (-15 -2452 (|#2| |#2| (-123) (-1170)))) 
-((-4455 (((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-217) (-572) (-1152)) 45) (((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-217) (-572)) 46) (((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-1 (-217) (-217)) (-572) (-1152)) 42) (((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-1 (-217) (-217)) (-572)) 43)) (-2474 (((-1 (-217) (-217)) (-217)) 44))) 
-(((-315) (-10 -7 (-15 -2474 ((-1 (-217) (-217)) (-217))) (-15 -4455 ((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-1 (-217) (-217)) (-572))) (-15 -4455 ((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-1 (-217) (-217)) (-572) (-1152))) (-15 -4455 ((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-217) (-572))) (-15 -4455 ((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-217) (-572) (-1152))))) (T -315)) 
-((-4455 (*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-217)) (-5 *7 (-572)) (-5 *8 (-1152)) (-5 *2 (-1200 (-932))) (-5 *1 (-315)))) (-4455 (*1 *2 *3 *3 *3 *4 *5 *6 *7) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-217)) (-5 *7 (-572)) (-5 *2 (-1200 (-932))) (-5 *1 (-315)))) (-4455 (*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-572)) (-5 *7 (-1152)) (-5 *2 (-1200 (-932))) (-5 *1 (-315)))) (-4455 (*1 *2 *3 *3 *3 *4 *5 *4 *6) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-572)) (-5 *2 (-1200 (-932))) (-5 *1 (-315)))) (-2474 (*1 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *1 (-315)) (-5 *3 (-217))))) 
-(-10 -7 (-15 -2474 ((-1 (-217) (-217)) (-217))) (-15 -4455 ((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-1 (-217) (-217)) (-572))) (-15 -4455 ((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-1 (-217) (-217)) (-572) (-1152))) (-15 -4455 ((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-217) (-572))) (-15 -4455 ((-1200 (-932)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-217) (-572) (-1152)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 24)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-413 (-572))) NIL) (($ $ (-413 (-572)) (-413 (-572))) NIL)) (-2640 (((-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|))) $) 19)) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-769) (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|)))) NIL)) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) 30)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-413 (-572)) $) NIL) (((-413 (-572)) $ (-413 (-572))) 15)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) NIL) (($ $ (-413 (-572))) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-413 (-572))) NIL) (($ $ (-1082) (-413 (-572))) NIL) (($ $ (-638 (-1082)) (-638 (-413 (-572)))) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-2774 (($ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190)))))) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1977 (($ $ (-413 (-572))) NIL)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-3936 (((-413 (-572)) $) 16)) (-3703 (($ (-1243 |#1| |#2| |#3|)) 11)) (-3751 (((-1243 |#1| |#2| |#3|) $) 12)) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ (-413 (-572))) NIL) (($ $ $) NIL (|has| (-413 (-572)) (-1110)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-4316 (((-413 (-572)) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 10)) (-3972 (((-856) $) 36) (($ (-572)) NIL) (($ |#1|) NIL (|has| |#1| (-174))) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562)))) (-1958 ((|#1| $ (-413 (-572))) 28)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) NIL)) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-413 (-572))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 26)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 31)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-316 |#1| |#2| |#3|) (-13 (-1239 |#1|) (-793) (-10 -8 (-15 -3703 ($ (-1243 |#1| |#2| |#3|))) (-15 -3751 ((-1243 |#1| |#2| |#3|) $)) (-15 -3936 ((-413 (-572)) $)))) (-13 (-368) (-848)) (-1170) |#1|) (T -316)) 
-((-3703 (*1 *1 *2) (-12 (-5 *2 (-1243 *3 *4 *5)) (-4 *3 (-13 (-368) (-848))) (-14 *4 (-1170)) (-14 *5 *3) (-5 *1 (-316 *3 *4 *5)))) (-3751 (*1 *2 *1) (-12 (-5 *2 (-1243 *3 *4 *5)) (-5 *1 (-316 *3 *4 *5)) (-4 *3 (-13 (-368) (-848))) (-14 *4 (-1170)) (-14 *5 *3))) (-3936 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-316 *3 *4 *5)) (-4 *3 (-13 (-368) (-848))) (-14 *4 (-1170)) (-14 *5 *3)))) 
-(-13 (-1239 |#1|) (-793) (-10 -8 (-15 -3703 ($ (-1243 |#1| |#2| |#3|))) (-15 -3751 ((-1243 |#1| |#2| |#3|) $)) (-15 -3936 ((-413 (-572)) $)))) 
-((-4248 (((-424 (-1166 |#1|)) (-1166 |#1|) |#1|) 15)) (-4304 (((-424 (-1166 |#1|)) (-1166 |#1|) |#1|) 24))) 
-(((-317 |#1|) (-10 -7 (-15 -4304 ((-424 (-1166 |#1|)) (-1166 |#1|) |#1|)) (-15 -4248 ((-424 (-1166 |#1|)) (-1166 |#1|) |#1|))) (-860)) (T -317)) 
-((-4248 (*1 *2 *3 *4) (-12 (-4 *4 (-860)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1166 *4)))) (-4304 (*1 *2 *3 *4) (-12 (-4 *4 (-860)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1166 *4))))) 
-(-10 -7 (-15 -4304 ((-424 (-1166 |#1|)) (-1166 |#1|) |#1|)) (-15 -4248 ((-424 (-1166 |#1|)) (-1166 |#1|) |#1|))) 
-((-1451 (((-2 (|:| -3751 (-769)) (|:| -4513 |#1|) (|:| |radicand| (-638 |#1|))) (-424 |#1|) (-769)) 24)) (-3539 (((-638 (-2 (|:| -4513 (-769)) (|:| |logand| |#1|))) (-424 |#1|)) 28))) 
-(((-318 |#1|) (-10 -7 (-15 -1451 ((-2 (|:| -3751 (-769)) (|:| -4513 |#1|) (|:| |radicand| (-638 |#1|))) (-424 |#1|) (-769))) (-15 -3539 ((-638 (-2 (|:| -4513 (-769)) (|:| |logand| |#1|))) (-424 |#1|)))) (-562)) (T -318)) 
-((-3539 (*1 *2 *3) (-12 (-5 *3 (-424 *4)) (-4 *4 (-562)) (-5 *2 (-638 (-2 (|:| -4513 (-769)) (|:| |logand| *4)))) (-5 *1 (-318 *4)))) (-1451 (*1 *2 *3 *4) (-12 (-5 *3 (-424 *5)) (-4 *5 (-562)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *5) (|:| |radicand| (-638 *5)))) (-5 *1 (-318 *5)) (-5 *4 (-769))))) 
-(-10 -7 (-15 -1451 ((-2 (|:| -3751 (-769)) (|:| -4513 |#1|) (|:| |radicand| (-638 |#1|))) (-424 |#1|) (-769))) (-15 -3539 ((-638 (-2 (|:| -4513 (-769)) (|:| |logand| |#1|))) (-424 |#1|)))) 
-((-4248 (((-424 (-1166 |#1|)) (-1166 |#1|) |#1|) 15)) (-4304 (((-424 (-1166 |#1|)) (-1166 |#1|) |#1|) 24))) 
-(((-319 |#1|) (-10 -7 (-15 -4304 ((-424 (-1166 |#1|)) (-1166 |#1|) |#1|)) (-15 -4248 ((-424 (-1166 |#1|)) (-1166 |#1|) |#1|))) (-865)) (T -319)) 
-((-4248 (*1 *2 *3 *4) (-12 (-4 *4 (-865)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-319 *4)) (-5 *3 (-1166 *4)))) (-4304 (*1 *2 *3 *4) (-12 (-4 *4 (-865)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-319 *4)) (-5 *3 (-1166 *4))))) 
-(-10 -7 (-15 -4304 ((-424 (-1166 |#1|)) (-1166 |#1|) |#1|)) (-15 -4248 ((-424 (-1166 |#1|)) (-1166 |#1|) |#1|))) 
-((-3456 (((-638 |#2|) (-1166 |#4|)) 43)) (-4477 ((|#3| (-572)) 46)) (-3007 (((-1166 |#4|) (-1166 |#3|)) 30)) (-2412 (((-1166 |#4|) (-1166 |#4|) (-572)) 55)) (-1772 (((-1166 |#3|) (-1166 |#4|)) 21)) (-4316 (((-638 (-769)) (-1166 |#4|) (-638 |#2|)) 40)) (-2347 (((-1166 |#3|) (-1166 |#4|) (-638 |#2|) (-638 |#3|)) 35))) 
-(((-320 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2347 ((-1166 |#3|) (-1166 |#4|) (-638 |#2|) (-638 |#3|))) (-15 -4316 ((-638 (-769)) (-1166 |#4|) (-638 |#2|))) (-15 -3456 ((-638 |#2|) (-1166 |#4|))) (-15 -1772 ((-1166 |#3|) (-1166 |#4|))) (-15 -3007 ((-1166 |#4|) (-1166 |#3|))) (-15 -2412 ((-1166 |#4|) (-1166 |#4|) (-572))) (-15 -4477 (|#3| (-572)))) (-794) (-848) (-1054) (-956 |#3| |#1| |#2|)) (T -320)) 
-((-4477 (*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1054)) (-5 *1 (-320 *4 *5 *2 *6)) (-4 *6 (-956 *2 *4 *5)))) (-2412 (*1 *2 *2 *3) (-12 (-5 *2 (-1166 *7)) (-5 *3 (-572)) (-4 *7 (-956 *6 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-5 *1 (-320 *4 *5 *6 *7)))) (-3007 (*1 *2 *3) (-12 (-5 *3 (-1166 *6)) (-4 *6 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-1166 *7)) (-5 *1 (-320 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5)))) (-1772 (*1 *2 *3) (-12 (-5 *3 (-1166 *7)) (-4 *7 (-956 *6 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-5 *2 (-1166 *6)) (-5 *1 (-320 *4 *5 *6 *7)))) (-3456 (*1 *2 *3) (-12 (-5 *3 (-1166 *7)) (-4 *7 (-956 *6 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-5 *2 (-638 *5)) (-5 *1 (-320 *4 *5 *6 *7)))) (-4316 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 *8)) (-5 *4 (-638 *6)) (-4 *6 (-848)) (-4 *8 (-956 *7 *5 *6)) (-4 *5 (-794)) (-4 *7 (-1054)) (-5 *2 (-638 (-769))) (-5 *1 (-320 *5 *6 *7 *8)))) (-2347 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1166 *9)) (-5 *4 (-638 *7)) (-5 *5 (-638 *8)) (-4 *7 (-848)) (-4 *8 (-1054)) (-4 *9 (-956 *8 *6 *7)) (-4 *6 (-794)) (-5 *2 (-1166 *8)) (-5 *1 (-320 *6 *7 *8 *9))))) 
-(-10 -7 (-15 -2347 ((-1166 |#3|) (-1166 |#4|) (-638 |#2|) (-638 |#3|))) (-15 -4316 ((-638 (-769)) (-1166 |#4|) (-638 |#2|))) (-15 -3456 ((-638 |#2|) (-1166 |#4|))) (-15 -1772 ((-1166 |#3|) (-1166 |#4|))) (-15 -3007 ((-1166 |#4|) (-1166 |#3|))) (-15 -2412 ((-1166 |#4|) (-1166 |#4|) (-572))) (-15 -4477 (|#3| (-572)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 14)) (-2640 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-572)))) $) 18)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1685 (((-769) $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-4351 ((|#1| $ (-572)) NIL)) (-1333 (((-572) $ (-572)) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3629 (($ (-1 |#1| |#1|) $) NIL)) (-2966 (($ (-1 (-572) (-572)) $) 10)) (-1658 (((-1152) $) NIL)) (-3696 (($ $ $) NIL (|has| (-572) (-793)))) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL) (($ |#1|) NIL)) (-1958 (((-572) |#1| $) NIL)) (-2378 (($) 15 T CONST)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) 21 (|has| |#1| (-848)))) (-1373 (($ $) 11) (($ $ $) 20)) (-1367 (($ $ $) NIL) (($ |#1| $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ (-572)) NIL) (($ (-572) |#1|) 19))) 
-(((-321 |#1|) (-13 (-21) (-713 (-572)) (-322 |#1| (-572)) (-10 -7 (IF (|has| |#1| (-848)) (-6 (-848)) |noBranch|))) (-1098)) (T -321)) 
-NIL 
-(-13 (-21) (-713 (-572)) (-322 |#1| (-572)) (-10 -7 (IF (|has| |#1| (-848)) (-6 (-848)) |noBranch|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2640 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 |#2|))) $) 26)) (-1572 (((-3 $ "failed") $ $) 18)) (-1685 (((-769) $) 27)) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 31)) (-1318 ((|#1| $) 30)) (-4351 ((|#1| $ (-572)) 24)) (-1333 ((|#2| $ (-572)) 25)) (-3629 (($ (-1 |#1| |#1|) $) 21)) (-2966 (($ (-1 |#2| |#2|) $) 22)) (-1658 (((-1152) $) 9)) (-3696 (($ $ $) 20 (|has| |#2| (-793)))) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ |#1|) 32)) (-1958 ((|#2| |#1| $) 23)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1367 (($ $ $) 13) (($ |#1| $) 29)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ |#2| |#1|) 28))) 
-(((-322 |#1| |#2|) (-1290) (-1098) (-138)) (T -322)) 
-((-1367 (*1 *1 *2 *1) (-12 (-4 *1 (-322 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-138)))) (* (*1 *1 *2 *3) (-12 (-4 *1 (-322 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-138)))) (-1685 (*1 *2 *1) (-12 (-4 *1 (-322 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-138)) (-5 *2 (-769)))) (-2640 (*1 *2 *1) (-12 (-4 *1 (-322 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-138)) (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 *4)))))) (-1333 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-322 *4 *2)) (-4 *4 (-1098)) (-4 *2 (-138)))) (-4351 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-322 *2 *4)) (-4 *4 (-138)) (-4 *2 (-1098)))) (-1958 (*1 *2 *3 *1) (-12 (-4 *1 (-322 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-138)))) (-2966 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-322 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-138)))) (-3629 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-322 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-138)))) (-3696 (*1 *1 *1 *1) (-12 (-4 *1 (-322 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-138)) (-4 *3 (-793))))) 
-(-13 (-138) (-1044 |t#1|) (-10 -8 (-15 -1367 ($ |t#1| $)) (-15 * ($ |t#2| |t#1|)) (-15 -1685 ((-769) $)) (-15 -2640 ((-638 (-2 (|:| |gen| |t#1|) (|:| -4179 |t#2|))) $)) (-15 -1333 (|t#2| $ (-572))) (-15 -4351 (|t#1| $ (-572))) (-15 -1958 (|t#2| |t#1| $)) (-15 -2966 ($ (-1 |t#2| |t#2|) $)) (-15 -3629 ($ (-1 |t#1| |t#1|) $)) (IF (|has| |t#2| (-793)) (-15 -3696 ($ $ $)) |noBranch|))) 
-(((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-1044 |#1|) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2640 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-769)))) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1685 (((-769) $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-4351 ((|#1| $ (-572)) NIL)) (-1333 (((-769) $ (-572)) NIL)) (-3629 (($ (-1 |#1| |#1|) $) NIL)) (-2966 (($ (-1 (-769) (-769)) $) NIL)) (-1658 (((-1152) $) NIL)) (-3696 (($ $ $) NIL (|has| (-769) (-793)))) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL) (($ |#1|) NIL)) (-1958 (((-769) |#1| $) NIL)) (-2378 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1367 (($ $ $) NIL) (($ |#1| $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-769) |#1|) NIL))) 
-(((-323 |#1|) (-322 |#1| (-769)) (-1098)) (T -323)) 
-NIL 
-(-322 |#1| (-769)) 
-((-3828 ((|#5| (-1 |#4| |#2|) |#3|) 19))) 
-(((-324 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3828 (|#5| (-1 |#4| |#2|) |#3|))) (-793) (-1054) (-326 |#2| |#1|) (-1054) (-326 |#4| |#1|)) (T -324)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-4 *6 (-1054)) (-4 *7 (-1054)) (-4 *5 (-793)) (-4 *2 (-326 *7 *5)) (-5 *1 (-324 *5 *6 *4 *7 *2)) (-4 *4 (-326 *6 *5))))) 
-(-10 -7 (-15 -3828 (|#5| (-1 |#4| |#2|) |#3|))) 
-((-3988 (($ $) 52)) (-3977 (($ $ |#2| |#3| $) 14)) (-3918 (($ (-1 |#3| |#3|) $) 35)) (-4357 (((-121) $) 27)) (-4362 ((|#2| $) 29)) (-1803 (((-3 $ "failed") $ $) NIL) (((-3 $ "failed") $ |#2|) 45)) (-3694 ((|#2| $) 48)) (-3193 (((-638 |#2|) $) 38)) (-2565 (($ $ $ (-769)) 23)) (-1379 (($ $ |#2|) 42))) 
-(((-325 |#1| |#2| |#3|) (-10 -8 (-15 -3988 (|#1| |#1|)) (-15 -3694 (|#2| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#2|)) (-15 -2565 (|#1| |#1| |#1| (-769))) (-15 -3977 (|#1| |#1| |#2| |#3| |#1|)) (-15 -3918 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3193 ((-638 |#2|) |#1|)) (-15 -4362 (|#2| |#1|)) (-15 -4357 ((-121) |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1379 (|#1| |#1| |#2|))) (-326 |#2| |#3|) (-1054) (-793)) (T -325)) 
-NIL 
-(-10 -8 (-15 -3988 (|#1| |#1|)) (-15 -3694 (|#2| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#2|)) (-15 -2565 (|#1| |#1| |#1| (-769))) (-15 -3977 (|#1| |#1| |#2| |#3| |#1|)) (-15 -3918 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3193 ((-638 |#2|) |#1|)) (-15 -4362 (|#2| |#1|)) (-15 -4357 ((-121) |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1379 (|#1| |#1| |#2|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 86 (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 84 (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 83)) (-1318 (((-572) $) 87 (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) 85 (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 82)) (-4383 (($ $) 59)) (-1799 (((-3 $ "failed") $) 33)) (-3988 (($ $) 71 (|has| |#1| (-457)))) (-3977 (($ $ |#1| |#2| $) 75)) (-3893 (((-121) $) 30)) (-3475 (((-769) $) 78)) (-4581 (((-121) $) 61)) (-4328 (($ |#1| |#2|) 60)) (-1784 ((|#2| $) 77)) (-3918 (($ (-1 |#2| |#2|) $) 76)) (-3828 (($ (-1 |#1| |#1|) $) 62)) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 81)) (-4362 ((|#1| $) 80)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562))) (((-3 $ "failed") $ |#1|) 73 (|has| |#1| (-562)))) (-4316 ((|#2| $) 63)) (-3694 ((|#1| $) 72 (|has| |#1| (-457)))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 48 (|has| |#1| (-562))) (($ |#1|) 46) (($ (-413 (-572))) 56 (-1841 (|has| |#1| (-1044 (-413 (-572)))) (|has| |#1| (-43 (-413 (-572))))))) (-3193 (((-638 |#1|) $) 79)) (-1958 ((|#1| $ |#2|) 58)) (-2779 (((-3 $ "failed") $) 47 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-2565 (($ $ $ (-769)) 74 (|has| |#1| (-174)))) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-326 |#1| |#2|) (-1290) (-1054) (-793)) (T -326)) 
-((-4357 (*1 *2 *1) (-12 (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-121)))) (-4362 (*1 *2 *1) (-12 (-4 *1 (-326 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) (-3193 (*1 *2 *1) (-12 (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-638 *3)))) (-3475 (*1 *2 *1) (-12 (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-769)))) (-1784 (*1 *2 *1) (-12 (-4 *1 (-326 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) (-3918 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)))) (-3977 (*1 *1 *1 *2 *3 *1) (-12 (-4 *1 (-326 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)))) (-2565 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-4 *3 (-174)))) (-1803 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-326 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *2 (-562)))) (-3694 (*1 *2 *1) (-12 (-4 *1 (-326 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)) (-4 *2 (-457)))) (-3988 (*1 *1 *1) (-12 (-4 *1 (-326 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *2 (-457))))) 
-(-13 (-52 |t#1| |t#2|) (-417 |t#1|) (-10 -8 (-15 -4357 ((-121) $)) (-15 -4362 (|t#1| $)) (-15 -3193 ((-638 |t#1|) $)) (-15 -3475 ((-769) $)) (-15 -1784 (|t#2| $)) (-15 -3918 ($ (-1 |t#2| |t#2|) $)) (-15 -3977 ($ $ |t#1| |t#2| $)) (IF (|has| |t#1| (-174)) (-15 -2565 ($ $ $ (-769))) |noBranch|) (IF (|has| |t#1| (-562)) (-15 -1803 ((-3 $ "failed") $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-457)) (PROGN (-15 -3694 (|t#1| $)) (-15 -3988 ($ $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) |has| |#1| (-562)) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-287) |has| |#1| (-562)) ((-417 |#1|) . T) ((-562) |has| |#1| (-562)) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) |has| |#1| (-562)) ((-722) . T) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-4538 (((-121) (-121)) NIL)) (-3283 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603)))) (-1550 (($ (-1 (-121) |#1|) $) NIL)) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-3259 (($ $) NIL (|has| |#1| (-1098)))) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1544 (($ |#1| $) NIL (|has| |#1| (-1098))) (($ (-1 (-121) |#1|) $) NIL)) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-4014 (((-572) (-1 (-121) |#1|) $) NIL) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098)))) (-3558 (($ $ (-572)) NIL)) (-1570 (((-769) $) NIL)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) |#1|) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-3279 (($ $ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-1335 (($ $ $ (-572)) NIL) (($ |#1| $ (-572)) NIL)) (-2603 (($ |#1| $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2742 (($ (-638 |#1|)) NIL)) (-1837 ((|#1| $) NIL (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) |#1|) NIL) ((|#1| $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-2145 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-2977 (($ $ $) NIL) (($ $ |#1|) NIL)) (-4500 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-327 |#1|) (-13 (-19 |#1|) (-279 |#1|) (-10 -8 (-15 -2742 ($ (-638 |#1|))) (-15 -1570 ((-769) $)) (-15 -3558 ($ $ (-572))) (-15 -4538 ((-121) (-121))))) (-1204)) (T -327)) 
-((-2742 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-327 *3)))) (-1570 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-327 *3)) (-4 *3 (-1204)))) (-3558 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-327 *3)) (-4 *3 (-1204)))) (-4538 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-327 *3)) (-4 *3 (-1204))))) 
-(-13 (-19 |#1|) (-279 |#1|) (-10 -8 (-15 -2742 ($ (-638 |#1|))) (-15 -1570 ((-769) $)) (-15 -3558 ($ $ (-572))) (-15 -4538 ((-121) (-121))))) 
-((-2376 (((-121) $) 37)) (-1486 (((-769)) 22)) (-3520 ((|#2| $) 41) (($ $ (-923)) 99)) (-1685 (((-769)) 93)) (-4337 (($ (-1259 |#2|)) 20)) (-3880 (((-121) $) 111)) (-4429 ((|#2| $) 43) (($ $ (-923)) 97)) (-3251 (((-1166 |#2|) $) NIL) (((-1166 $) $ (-923)) 88)) (-4064 (((-1166 |#2|) $) 78)) (-4484 (((-1166 |#2|) $) 75) (((-3 (-1166 |#2|) "failed") $ $) 72)) (-2359 (($ $ (-1166 |#2|)) 48)) (-2728 (((-834 (-923))) 91) (((-923)) 38)) (-2502 (((-140)) 25)) (-4316 (((-834 (-923)) $) NIL) (((-923) $) 112)) (-3627 (($) 105)) (-3160 (((-1259 |#2|) $) NIL) (((-685 |#2|) (-1259 $)) 34)) (-2779 (($ $) NIL) (((-3 $ "failed") $) 81)) (-2213 (((-121) $) 36))) 
-(((-328 |#1| |#2|) (-10 -8 (-15 -2779 ((-3 |#1| "failed") |#1|)) (-15 -1685 ((-769))) (-15 -2779 (|#1| |#1|)) (-15 -4484 ((-3 (-1166 |#2|) "failed") |#1| |#1|)) (-15 -4484 ((-1166 |#2|) |#1|)) (-15 -4064 ((-1166 |#2|) |#1|)) (-15 -2359 (|#1| |#1| (-1166 |#2|))) (-15 -3880 ((-121) |#1|)) (-15 -3627 (|#1|)) (-15 -3520 (|#1| |#1| (-923))) (-15 -4429 (|#1| |#1| (-923))) (-15 -3251 ((-1166 |#1|) |#1| (-923))) (-15 -3520 (|#2| |#1|)) (-15 -4429 (|#2| |#1|)) (-15 -4316 ((-923) |#1|)) (-15 -2728 ((-923))) (-15 -3251 ((-1166 |#2|) |#1|)) (-15 -4337 (|#1| (-1259 |#2|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1|)) (-15 -1486 ((-769))) (-15 -2728 ((-834 (-923)))) (-15 -4316 ((-834 (-923)) |#1|)) (-15 -2376 ((-121) |#1|)) (-15 -2213 ((-121) |#1|)) (-15 -2502 ((-140)))) (-329 |#2|) (-368)) (T -328)) 
-((-2502 (*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-140)) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) (-2728 (*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-834 (-923))) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) (-1486 (*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-769)) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) (-2728 (*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-923)) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) (-1685 (*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-769)) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4))))) 
-(-10 -8 (-15 -2779 ((-3 |#1| "failed") |#1|)) (-15 -1685 ((-769))) (-15 -2779 (|#1| |#1|)) (-15 -4484 ((-3 (-1166 |#2|) "failed") |#1| |#1|)) (-15 -4484 ((-1166 |#2|) |#1|)) (-15 -4064 ((-1166 |#2|) |#1|)) (-15 -2359 (|#1| |#1| (-1166 |#2|))) (-15 -3880 ((-121) |#1|)) (-15 -3627 (|#1|)) (-15 -3520 (|#1| |#1| (-923))) (-15 -4429 (|#1| |#1| (-923))) (-15 -3251 ((-1166 |#1|) |#1| (-923))) (-15 -3520 (|#2| |#1|)) (-15 -4429 (|#2| |#1|)) (-15 -4316 ((-923) |#1|)) (-15 -2728 ((-923))) (-15 -3251 ((-1166 |#2|) |#1|)) (-15 -4337 (|#1| (-1259 |#2|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1|)) (-15 -1486 ((-769))) (-15 -2728 ((-834 (-923)))) (-15 -4316 ((-834 (-923)) |#1|)) (-15 -2376 ((-121) |#1|)) (-15 -2213 ((-121) |#1|)) (-15 -2502 ((-140)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-2376 (((-121) $) 90)) (-1486 (((-769)) 86)) (-3520 ((|#1| $) 134) (($ $ (-923)) 131 (|has| |#1| (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) 116 (|has| |#1| (-374)))) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-1685 (((-769)) 106 (|has| |#1| (-374)))) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 97)) (-1318 ((|#1| $) 96)) (-4337 (($ (-1259 |#1|)) 140)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 122 (|has| |#1| (-374)))) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-3286 (($) 103 (|has| |#1| (-374)))) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-2754 (($) 118 (|has| |#1| (-374)))) (-1297 (((-121) $) 119 (|has| |#1| (-374)))) (-4486 (($ $ (-769)) 83 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374)))) (($ $) 82 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-1526 (((-121) $) 69)) (-3377 (((-923) $) 121 (|has| |#1| (-374))) (((-834 (-923)) $) 80 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-3893 (((-121) $) 30)) (-1664 (($) 129 (|has| |#1| (-374)))) (-3880 (((-121) $) 128 (|has| |#1| (-374)))) (-4429 ((|#1| $) 135) (($ $ (-923)) 132 (|has| |#1| (-374)))) (-3961 (((-3 $ "failed") $) 107 (|has| |#1| (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-3251 (((-1166 |#1|) $) 139) (((-1166 $) $ (-923)) 133 (|has| |#1| (-374)))) (-3633 (((-923) $) 104 (|has| |#1| (-374)))) (-4064 (((-1166 |#1|) $) 125 (|has| |#1| (-374)))) (-4484 (((-1166 |#1|) $) 124 (|has| |#1| (-374))) (((-3 (-1166 |#1|) "failed") $ $) 123 (|has| |#1| (-374)))) (-2359 (($ $ (-1166 |#1|)) 126 (|has| |#1| (-374)))) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-1773 (($) 108 (|has| |#1| (-374)) CONST)) (-1763 (($ (-923)) 105 (|has| |#1| (-374)))) (-1336 (((-121) $) 89)) (-2607 (((-1116) $) 10)) (-2307 (($) 127 (|has| |#1| (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 115 (|has| |#1| (-374)))) (-4304 (((-424 $) $) 72)) (-2728 (((-834 (-923))) 87) (((-923)) 137)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-3587 (((-638 $)) 102 (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3158 (((-769) $) 120 (|has| |#1| (-374))) (((-3 (-769) "failed") $ $) 81 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2502 (((-140)) 95)) (-3139 (($ $) 112 (|has| |#1| (-374))) (($ $ (-769)) 110 (|has| |#1| (-374)))) (-4316 (((-834 (-923)) $) 88) (((-923) $) 136)) (-2830 (((-1166 |#1|)) 138)) (-2278 (($) 117 (|has| |#1| (-374)))) (-3627 (($) 130 (|has| |#1| (-374)))) (-3160 (((-1259 |#1|) $) 142) (((-685 |#1|) (-1259 $)) 141)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 114 (|has| |#1| (-374)))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ |#1|) 98)) (-2779 (($ $) 113 (|has| |#1| (-374))) (((-3 $ "failed") $) 79 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2140 (((-769)) 28)) (-2237 (((-1259 $)) 144) (((-1259 $) (-923)) 143)) (-3774 (((-121) $ $) 38)) (-2213 (((-121) $) 91)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-2611 (($ $) 85 (|has| |#1| (-374))) (($ $ (-769)) 84 (|has| |#1| (-374)))) (-1557 (($ $) 111 (|has| |#1| (-374))) (($ $ (-769)) 109 (|has| |#1| (-374)))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62) (($ $ |#1|) 94)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64) (($ $ |#1|) 93) (($ |#1| $) 92))) 
-(((-329 |#1|) (-1290) (-368)) (T -329)) 
-((-2237 (*1 *2) (-12 (-4 *3 (-368)) (-5 *2 (-1259 *1)) (-4 *1 (-329 *3)))) (-2237 (*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-368)) (-5 *2 (-1259 *1)) (-4 *1 (-329 *4)))) (-3160 (*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-1259 *3)))) (-3160 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-329 *4)) (-4 *4 (-368)) (-5 *2 (-685 *4)))) (-4337 (*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-368)) (-4 *1 (-329 *3)))) (-3251 (*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-1166 *3)))) (-2830 (*1 *2) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-1166 *3)))) (-2728 (*1 *2) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-923)))) (-4316 (*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-923)))) (-4429 (*1 *2 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-368)))) (-3520 (*1 *2 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-368)))) (-3251 (*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-5 *2 (-1166 *1)) (-4 *1 (-329 *4)))) (-4429 (*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)))) (-3520 (*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)))) (-3627 (*1 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-374)) (-4 *2 (-368)))) (-1664 (*1 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-374)) (-4 *2 (-368)))) (-3880 (*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)) (-5 *2 (-121)))) (-2307 (*1 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-374)) (-4 *2 (-368)))) (-2359 (*1 *1 *1 *2) (-12 (-5 *2 (-1166 *3)) (-4 *3 (-374)) (-4 *1 (-329 *3)) (-4 *3 (-368)))) (-4064 (*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)) (-5 *2 (-1166 *3)))) (-4484 (*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)) (-5 *2 (-1166 *3)))) (-4484 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)) (-5 *2 (-1166 *3))))) 
-(-13 (-1276 |t#1|) (-1044 |t#1|) (-10 -8 (-15 -2237 ((-1259 $))) (-15 -2237 ((-1259 $) (-923))) (-15 -3160 ((-1259 |t#1|) $)) (-15 -3160 ((-685 |t#1|) (-1259 $))) (-15 -4337 ($ (-1259 |t#1|))) (-15 -3251 ((-1166 |t#1|) $)) (-15 -2830 ((-1166 |t#1|))) (-15 -2728 ((-923))) (-15 -4316 ((-923) $)) (-15 -4429 (|t#1| $)) (-15 -3520 (|t#1| $)) (IF (|has| |t#1| (-374)) (PROGN (-6 (-353)) (-15 -3251 ((-1166 $) $ (-923))) (-15 -4429 ($ $ (-923))) (-15 -3520 ($ $ (-923))) (-15 -3627 ($)) (-15 -1664 ($)) (-15 -3880 ((-121) $)) (-15 -2307 ($)) (-15 -2359 ($ $ (-1166 |t#1|))) (-15 -4064 ((-1166 |t#1|) $)) (-15 -4484 ((-1166 |t#1|) $)) (-15 -4484 ((-3 (-1166 |t#1|) "failed") $ $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-138) . T) ((-149) -1841 (|has| |#1| (-374)) (|has| |#1| (-149))) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) . T) ((-227) |has| |#1| (-374)) ((-240) . T) ((-287) . T) ((-303) . T) ((-1276 |#1|) . T) ((-368) . T) ((-408) -1841 (|has| |#1| (-374)) (|has| |#1| (-149))) ((-374) |has| |#1| (-374)) ((-353) |has| |#1| (-374)) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 |#1|) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) . T) ((-1060 |#1|) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) |has| |#1| (-374)) ((-1214) . T) ((-1266 |#1|) . T)) 
-((-2262 (((-121) $ $) NIL)) (-2009 (($ (-1169) $) 88)) (-4126 (($) 76)) (-2627 (((-1116) (-1116)) 11)) (-3329 (($) 77)) (-1987 (($) 90) (($ (-312 (-694))) 96) (($ (-312 (-696))) 93) (($ (-312 (-689))) 99) (($ (-312 (-385))) 105) (($ (-312 (-572))) 102) (($ (-312 (-171 (-385)))) 108)) (-1325 (($ (-1169) $) 89)) (-1660 (($ (-638 (-856))) 79)) (-2108 (((-1264) $) 73)) (-1469 (((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $) 27)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1445 (($ (-1116)) 45)) (-2246 (((-1102) $) 25)) (-4582 (($ (-1090 (-959 (-572))) $) 85) (($ (-1090 (-959 (-572))) (-959 (-572)) $) 86)) (-2818 (($ (-1116)) 87)) (-1546 (($ (-1169) $) 110) (($ (-1169) $ $) 111)) (-2804 (($ (-1170) (-638 (-1170))) 75)) (-3990 (($ (-1152)) 82) (($ (-638 (-1152))) 80)) (-3972 (((-856) $) 113)) (-1831 (((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1170)) (|:| |arrayIndex| (-638 (-959 (-572)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1170)) (|:| |rand| (-856)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1169)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -4037 (-121)) (|:| -2148 (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |blockBranch| (-638 $)) (|:| |commentBranch| (-638 (-1152))) (|:| |callBranch| (-1152)) (|:| |forBranch| (-2 (|:| -1441 (-1090 (-959 (-572)))) (|:| |span| (-959 (-572))) (|:| |body| $))) (|:| |labelBranch| (-1116)) (|:| |loopBranch| (-2 (|:| |switch| (-1169)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3201 (-1170)) (|:| |contents| (-638 (-1170))))) (|:| |printBranch| (-638 (-856)))) $) 37)) (-1313 (($ (-1152)) 182)) (-2100 (($ (-638 $)) 109)) (-3863 (($ (-1170) (-1152)) 115) (($ (-1170) (-312 (-696))) 155) (($ (-1170) (-312 (-694))) 156) (($ (-1170) (-312 (-689))) 157) (($ (-1170) (-685 (-696))) 118) (($ (-1170) (-685 (-694))) 121) (($ (-1170) (-685 (-689))) 124) (($ (-1170) (-1259 (-696))) 127) (($ (-1170) (-1259 (-694))) 130) (($ (-1170) (-1259 (-689))) 133) (($ (-1170) (-685 (-312 (-696)))) 136) (($ (-1170) (-685 (-312 (-694)))) 139) (($ (-1170) (-685 (-312 (-689)))) 142) (($ (-1170) (-1259 (-312 (-696)))) 145) (($ (-1170) (-1259 (-312 (-694)))) 148) (($ (-1170) (-1259 (-312 (-689)))) 151) (($ (-1170) (-638 (-959 (-572))) (-312 (-696))) 152) (($ (-1170) (-638 (-959 (-572))) (-312 (-694))) 153) (($ (-1170) (-638 (-959 (-572))) (-312 (-689))) 154) (($ (-1170) (-312 (-572))) 179) (($ (-1170) (-312 (-385))) 180) (($ (-1170) (-312 (-171 (-385)))) 181) (($ (-1170) (-685 (-312 (-572)))) 160) (($ (-1170) (-685 (-312 (-385)))) 163) (($ (-1170) (-685 (-312 (-171 (-385))))) 166) (($ (-1170) (-1259 (-312 (-572)))) 169) (($ (-1170) (-1259 (-312 (-385)))) 172) (($ (-1170) (-1259 (-312 (-171 (-385))))) 175) (($ (-1170) (-638 (-959 (-572))) (-312 (-572))) 176) (($ (-1170) (-638 (-959 (-572))) (-312 (-385))) 177) (($ (-1170) (-638 (-959 (-572))) (-312 (-171 (-385)))) 178)) (-1324 (((-121) $ $) NIL))) 
-(((-330) (-13 (-1098) (-10 -8 (-15 -3972 ((-856) $)) (-15 -4582 ($ (-1090 (-959 (-572))) $)) (-15 -4582 ($ (-1090 (-959 (-572))) (-959 (-572)) $)) (-15 -2009 ($ (-1169) $)) (-15 -1325 ($ (-1169) $)) (-15 -1445 ($ (-1116))) (-15 -2818 ($ (-1116))) (-15 -3990 ($ (-1152))) (-15 -3990 ($ (-638 (-1152)))) (-15 -1313 ($ (-1152))) (-15 -1987 ($)) (-15 -1987 ($ (-312 (-694)))) (-15 -1987 ($ (-312 (-696)))) (-15 -1987 ($ (-312 (-689)))) (-15 -1987 ($ (-312 (-385)))) (-15 -1987 ($ (-312 (-572)))) (-15 -1987 ($ (-312 (-171 (-385))))) (-15 -1546 ($ (-1169) $)) (-15 -1546 ($ (-1169) $ $)) (-15 -3863 ($ (-1170) (-1152))) (-15 -3863 ($ (-1170) (-312 (-696)))) (-15 -3863 ($ (-1170) (-312 (-694)))) (-15 -3863 ($ (-1170) (-312 (-689)))) (-15 -3863 ($ (-1170) (-685 (-696)))) (-15 -3863 ($ (-1170) (-685 (-694)))) (-15 -3863 ($ (-1170) (-685 (-689)))) (-15 -3863 ($ (-1170) (-1259 (-696)))) (-15 -3863 ($ (-1170) (-1259 (-694)))) (-15 -3863 ($ (-1170) (-1259 (-689)))) (-15 -3863 ($ (-1170) (-685 (-312 (-696))))) (-15 -3863 ($ (-1170) (-685 (-312 (-694))))) (-15 -3863 ($ (-1170) (-685 (-312 (-689))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-696))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-694))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-689))))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-696)))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-694)))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-689)))) (-15 -3863 ($ (-1170) (-312 (-572)))) (-15 -3863 ($ (-1170) (-312 (-385)))) (-15 -3863 ($ (-1170) (-312 (-171 (-385))))) (-15 -3863 ($ (-1170) (-685 (-312 (-572))))) (-15 -3863 ($ (-1170) (-685 (-312 (-385))))) (-15 -3863 ($ (-1170) (-685 (-312 (-171 (-385)))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-572))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-385))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-171 (-385)))))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-572)))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-385)))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-171 (-385))))) (-15 -2100 ($ (-638 $))) (-15 -4126 ($)) (-15 -3329 ($)) (-15 -1660 ($ (-638 (-856)))) (-15 -2804 ($ (-1170) (-638 (-1170)))) (-15 -1469 ((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $)) (-15 -1831 ((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1170)) (|:| |arrayIndex| (-638 (-959 (-572)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1170)) (|:| |rand| (-856)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1169)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -4037 (-121)) (|:| -2148 (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |blockBranch| (-638 $)) (|:| |commentBranch| (-638 (-1152))) (|:| |callBranch| (-1152)) (|:| |forBranch| (-2 (|:| -1441 (-1090 (-959 (-572)))) (|:| |span| (-959 (-572))) (|:| |body| $))) (|:| |labelBranch| (-1116)) (|:| |loopBranch| (-2 (|:| |switch| (-1169)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3201 (-1170)) (|:| |contents| (-638 (-1170))))) (|:| |printBranch| (-638 (-856)))) $)) (-15 -2108 ((-1264) $)) (-15 -2246 ((-1102) $)) (-15 -2627 ((-1116) (-1116)))))) (T -330)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-330)))) (-4582 (*1 *1 *2 *1) (-12 (-5 *2 (-1090 (-959 (-572)))) (-5 *1 (-330)))) (-4582 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-1090 (-959 (-572)))) (-5 *3 (-959 (-572))) (-5 *1 (-330)))) (-2009 (*1 *1 *2 *1) (-12 (-5 *2 (-1169)) (-5 *1 (-330)))) (-1325 (*1 *1 *2 *1) (-12 (-5 *2 (-1169)) (-5 *1 (-330)))) (-1445 (*1 *1 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-330)))) (-2818 (*1 *1 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-330)))) (-3990 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-330)))) (-3990 (*1 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-330)))) (-1313 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-330)))) (-1987 (*1 *1) (-5 *1 (-330))) (-1987 (*1 *1 *2) (-12 (-5 *2 (-312 (-694))) (-5 *1 (-330)))) (-1987 (*1 *1 *2) (-12 (-5 *2 (-312 (-696))) (-5 *1 (-330)))) (-1987 (*1 *1 *2) (-12 (-5 *2 (-312 (-689))) (-5 *1 (-330)))) (-1987 (*1 *1 *2) (-12 (-5 *2 (-312 (-385))) (-5 *1 (-330)))) (-1987 (*1 *1 *2) (-12 (-5 *2 (-312 (-572))) (-5 *1 (-330)))) (-1987 (*1 *1 *2) (-12 (-5 *2 (-312 (-171 (-385)))) (-5 *1 (-330)))) (-1546 (*1 *1 *2 *1) (-12 (-5 *2 (-1169)) (-5 *1 (-330)))) (-1546 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1169)) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1152)) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-696))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-694))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-689))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-696))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-694))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-689))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-696))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-694))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-689))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-696)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-694)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-689)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-696)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-694)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-689)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-696))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-694))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-689))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-572))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-385))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-171 (-385)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-572)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-385)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-171 (-385))))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-572)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-385)))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-171 (-385))))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-572))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-385))) (-5 *1 (-330)))) (-3863 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-171 (-385)))) (-5 *1 (-330)))) (-2100 (*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-5 *1 (-330)))) (-4126 (*1 *1) (-5 *1 (-330))) (-3329 (*1 *1) (-5 *1 (-330))) (-1660 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-330)))) (-2804 (*1 *1 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-5 *2 (-1170)) (-5 *1 (-330)))) (-1469 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (-5 *1 (-330)))) (-1831 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1170)) (|:| |arrayIndex| (-638 (-959 (-572)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1170)) (|:| |rand| (-856)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1169)) (|:| |thenClause| (-330)) (|:| |elseClause| (-330)))) (|:| |returnBranch| (-2 (|:| -4037 (-121)) (|:| -2148 (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |blockBranch| (-638 (-330))) (|:| |commentBranch| (-638 (-1152))) (|:| |callBranch| (-1152)) (|:| |forBranch| (-2 (|:| -1441 (-1090 (-959 (-572)))) (|:| |span| (-959 (-572))) (|:| |body| (-330)))) (|:| |labelBranch| (-1116)) (|:| |loopBranch| (-2 (|:| |switch| (-1169)) (|:| |body| (-330)))) (|:| |commonBranch| (-2 (|:| -3201 (-1170)) (|:| |contents| (-638 (-1170))))) (|:| |printBranch| (-638 (-856))))) (-5 *1 (-330)))) (-2108 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-330)))) (-2246 (*1 *2 *1) (-12 (-5 *2 (-1102)) (-5 *1 (-330)))) (-2627 (*1 *2 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-330))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ((-856) $)) (-15 -4582 ($ (-1090 (-959 (-572))) $)) (-15 -4582 ($ (-1090 (-959 (-572))) (-959 (-572)) $)) (-15 -2009 ($ (-1169) $)) (-15 -1325 ($ (-1169) $)) (-15 -1445 ($ (-1116))) (-15 -2818 ($ (-1116))) (-15 -3990 ($ (-1152))) (-15 -3990 ($ (-638 (-1152)))) (-15 -1313 ($ (-1152))) (-15 -1987 ($)) (-15 -1987 ($ (-312 (-694)))) (-15 -1987 ($ (-312 (-696)))) (-15 -1987 ($ (-312 (-689)))) (-15 -1987 ($ (-312 (-385)))) (-15 -1987 ($ (-312 (-572)))) (-15 -1987 ($ (-312 (-171 (-385))))) (-15 -1546 ($ (-1169) $)) (-15 -1546 ($ (-1169) $ $)) (-15 -3863 ($ (-1170) (-1152))) (-15 -3863 ($ (-1170) (-312 (-696)))) (-15 -3863 ($ (-1170) (-312 (-694)))) (-15 -3863 ($ (-1170) (-312 (-689)))) (-15 -3863 ($ (-1170) (-685 (-696)))) (-15 -3863 ($ (-1170) (-685 (-694)))) (-15 -3863 ($ (-1170) (-685 (-689)))) (-15 -3863 ($ (-1170) (-1259 (-696)))) (-15 -3863 ($ (-1170) (-1259 (-694)))) (-15 -3863 ($ (-1170) (-1259 (-689)))) (-15 -3863 ($ (-1170) (-685 (-312 (-696))))) (-15 -3863 ($ (-1170) (-685 (-312 (-694))))) (-15 -3863 ($ (-1170) (-685 (-312 (-689))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-696))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-694))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-689))))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-696)))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-694)))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-689)))) (-15 -3863 ($ (-1170) (-312 (-572)))) (-15 -3863 ($ (-1170) (-312 (-385)))) (-15 -3863 ($ (-1170) (-312 (-171 (-385))))) (-15 -3863 ($ (-1170) (-685 (-312 (-572))))) (-15 -3863 ($ (-1170) (-685 (-312 (-385))))) (-15 -3863 ($ (-1170) (-685 (-312 (-171 (-385)))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-572))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-385))))) (-15 -3863 ($ (-1170) (-1259 (-312 (-171 (-385)))))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-572)))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-385)))) (-15 -3863 ($ (-1170) (-638 (-959 (-572))) (-312 (-171 (-385))))) (-15 -2100 ($ (-638 $))) (-15 -4126 ($)) (-15 -3329 ($)) (-15 -1660 ($ (-638 (-856)))) (-15 -2804 ($ (-1170) (-638 (-1170)))) (-15 -1469 ((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $)) (-15 -1831 ((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1170)) (|:| |arrayIndex| (-638 (-959 (-572)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1170)) (|:| |rand| (-856)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1169)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -4037 (-121)) (|:| -2148 (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |blockBranch| (-638 $)) (|:| |commentBranch| (-638 (-1152))) (|:| |callBranch| (-1152)) (|:| |forBranch| (-2 (|:| -1441 (-1090 (-959 (-572)))) (|:| |span| (-959 (-572))) (|:| |body| $))) (|:| |labelBranch| (-1116)) (|:| |loopBranch| (-2 (|:| |switch| (-1169)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3201 (-1170)) (|:| |contents| (-638 (-1170))))) (|:| |printBranch| (-638 (-856)))) $)) (-15 -2108 ((-1264) $)) (-15 -2246 ((-1102) $)) (-15 -2627 ((-1116) (-1116))))) 
-((-2262 (((-121) $ $) NIL)) (-3124 (((-121) $) 11)) (-4217 (($ |#1|) 8)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4220 (($ |#1|) 9)) (-3972 (((-856) $) 17)) (-2917 ((|#1| $) 12)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 19))) 
-(((-331 |#1|) (-13 (-848) (-10 -8 (-15 -4217 ($ |#1|)) (-15 -4220 ($ |#1|)) (-15 -3124 ((-121) $)) (-15 -2917 (|#1| $)))) (-848)) (T -331)) 
-((-4217 (*1 *1 *2) (-12 (-5 *1 (-331 *2)) (-4 *2 (-848)))) (-4220 (*1 *1 *2) (-12 (-5 *1 (-331 *2)) (-4 *2 (-848)))) (-3124 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-331 *3)) (-4 *3 (-848)))) (-2917 (*1 *2 *1) (-12 (-5 *1 (-331 *2)) (-4 *2 (-848))))) 
-(-13 (-848) (-10 -8 (-15 -4217 ($ |#1|)) (-15 -4220 ($ |#1|)) (-15 -3124 ((-121) $)) (-15 -2917 (|#1| $)))) 
-((-4318 (((-330) (-1170) (-959 (-572))) 22)) (-3660 (((-330) (-1170) (-959 (-572))) 26)) (-3841 (((-330) (-1170) (-1090 (-959 (-572))) (-1090 (-959 (-572)))) 25) (((-330) (-1170) (-959 (-572)) (-959 (-572))) 23)) (-1637 (((-330) (-1170) (-959 (-572))) 30))) 
-(((-332) (-10 -7 (-15 -4318 ((-330) (-1170) (-959 (-572)))) (-15 -3841 ((-330) (-1170) (-959 (-572)) (-959 (-572)))) (-15 -3841 ((-330) (-1170) (-1090 (-959 (-572))) (-1090 (-959 (-572))))) (-15 -3660 ((-330) (-1170) (-959 (-572)))) (-15 -1637 ((-330) (-1170) (-959 (-572)))))) (T -332)) 
-((-1637 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-959 (-572))) (-5 *2 (-330)) (-5 *1 (-332)))) (-3660 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-959 (-572))) (-5 *2 (-330)) (-5 *1 (-332)))) (-3841 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-1090 (-959 (-572)))) (-5 *2 (-330)) (-5 *1 (-332)))) (-3841 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-959 (-572))) (-5 *2 (-330)) (-5 *1 (-332)))) (-4318 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-959 (-572))) (-5 *2 (-330)) (-5 *1 (-332))))) 
-(-10 -7 (-15 -4318 ((-330) (-1170) (-959 (-572)))) (-15 -3841 ((-330) (-1170) (-959 (-572)) (-959 (-572)))) (-15 -3841 ((-330) (-1170) (-1090 (-959 (-572))) (-1090 (-959 (-572))))) (-15 -3660 ((-330) (-1170) (-959 (-572)))) (-15 -1637 ((-330) (-1170) (-959 (-572))))) 
-((-3828 (((-336 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-336 |#1| |#2| |#3| |#4|)) 31))) 
-(((-333 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -3828 ((-336 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-336 |#1| |#2| |#3| |#4|)))) (-368) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|) (-368) (-1234 |#5|) (-1234 (-413 |#6|)) (-342 |#5| |#6| |#7|)) (T -333)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-336 *5 *6 *7 *8)) (-4 *5 (-368)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *8 (-342 *5 *6 *7)) (-4 *9 (-368)) (-4 *10 (-1234 *9)) (-4 *11 (-1234 (-413 *10))) (-5 *2 (-336 *9 *10 *11 *12)) (-5 *1 (-333 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-342 *9 *10 *11))))) 
-(-10 -7 (-15 -3828 ((-336 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-336 |#1| |#2| |#3| |#4|)))) 
-((-2422 (((-121) $) 14))) 
-(((-334 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2422 ((-121) |#1|))) (-335 |#2| |#3| |#4| |#5|) (-368) (-1234 |#2|) (-1234 (-413 |#3|)) (-342 |#2| |#3| |#4|)) (T -334)) 
-NIL 
-(-10 -8 (-15 -2422 ((-121) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-3116 (($ $) 25)) (-2422 (((-121) $) 24)) (-1658 (((-1152) $) 9)) (-1730 (((-419 |#2| (-413 |#2|) |#3| |#4|) $) 31)) (-2607 (((-1116) $) 10)) (-2307 (((-3 |#4| "failed") $) 23)) (-3873 (($ (-419 |#2| (-413 |#2|) |#3| |#4|)) 30) (($ |#4|) 29) (($ |#1| |#1|) 28) (($ |#1| |#1| (-572)) 27) (($ |#4| |#2| |#2| |#2| |#1|) 22)) (-2880 (((-2 (|:| -4004 (-419 |#2| (-413 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 26)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19))) 
-(((-335 |#1| |#2| |#3| |#4|) (-1290) (-368) (-1234 |t#1|) (-1234 (-413 |t#2|)) (-342 |t#1| |t#2| |t#3|)) (T -335)) 
-((-1730 (*1 *2 *1) (-12 (-4 *1 (-335 *3 *4 *5 *6)) (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 *3 *4 *5)) (-5 *2 (-419 *4 (-413 *4) *5 *6)))) (-3873 (*1 *1 *2) (-12 (-5 *2 (-419 *4 (-413 *4) *5 *6)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 *3 *4 *5)) (-4 *3 (-368)) (-4 *1 (-335 *3 *4 *5 *6)))) (-3873 (*1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *1 (-335 *3 *4 *5 *2)) (-4 *2 (-342 *3 *4 *5)))) (-3873 (*1 *1 *2 *2) (-12 (-4 *2 (-368)) (-4 *3 (-1234 *2)) (-4 *4 (-1234 (-413 *3))) (-4 *1 (-335 *2 *3 *4 *5)) (-4 *5 (-342 *2 *3 *4)))) (-3873 (*1 *1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *2 (-368)) (-4 *4 (-1234 *2)) (-4 *5 (-1234 (-413 *4))) (-4 *1 (-335 *2 *4 *5 *6)) (-4 *6 (-342 *2 *4 *5)))) (-2880 (*1 *2 *1) (-12 (-4 *1 (-335 *3 *4 *5 *6)) (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 *3 *4 *5)) (-5 *2 (-2 (|:| -4004 (-419 *4 (-413 *4) *5 *6)) (|:| |principalPart| *6))))) (-3116 (*1 *1 *1) (-12 (-4 *1 (-335 *2 *3 *4 *5)) (-4 *2 (-368)) (-4 *3 (-1234 *2)) (-4 *4 (-1234 (-413 *3))) (-4 *5 (-342 *2 *3 *4)))) (-2422 (*1 *2 *1) (-12 (-4 *1 (-335 *3 *4 *5 *6)) (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 *3 *4 *5)) (-5 *2 (-121)))) (-2307 (*1 *2 *1) (|partial| -12 (-4 *1 (-335 *3 *4 *5 *2)) (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *2 (-342 *3 *4 *5)))) (-3873 (*1 *1 *2 *3 *3 *3 *4) (-12 (-4 *4 (-368)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-4 *1 (-335 *4 *3 *5 *2)) (-4 *2 (-342 *4 *3 *5))))) 
-(-13 (-21) (-10 -8 (-15 -1730 ((-419 |t#2| (-413 |t#2|) |t#3| |t#4|) $)) (-15 -3873 ($ (-419 |t#2| (-413 |t#2|) |t#3| |t#4|))) (-15 -3873 ($ |t#4|)) (-15 -3873 ($ |t#1| |t#1|)) (-15 -3873 ($ |t#1| |t#1| (-572))) (-15 -2880 ((-2 (|:| -4004 (-419 |t#2| (-413 |t#2|) |t#3| |t#4|)) (|:| |principalPart| |t#4|)) $)) (-15 -3116 ($ $)) (-15 -2422 ((-121) $)) (-15 -2307 ((-3 |t#4| "failed") $)) (-15 -3873 ($ |t#4| |t#2| |t#2| |t#2| |t#1|)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3116 (($ $) 32)) (-2422 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-3603 (((-1259 |#4|) $) 124)) (-1730 (((-419 |#2| (-413 |#2|) |#3| |#4|) $) 30)) (-2607 (((-1116) $) NIL)) (-2307 (((-3 |#4| "failed") $) 35)) (-2170 (((-1259 |#4|) $) 117)) (-3873 (($ (-419 |#2| (-413 |#2|) |#3| |#4|)) 40) (($ |#4|) 42) (($ |#1| |#1|) 44) (($ |#1| |#1| (-572)) 46) (($ |#4| |#2| |#2| |#2| |#1|) 48)) (-2880 (((-2 (|:| -4004 (-419 |#2| (-413 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 38)) (-3972 (((-856) $) 17)) (-2378 (($) 14 T CONST)) (-1324 (((-121) $ $) 20)) (-1373 (($ $) 27) (($ $ $) NIL)) (-1367 (($ $ $) 25)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 23))) 
-(((-336 |#1| |#2| |#3| |#4|) (-13 (-335 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2170 ((-1259 |#4|) $)) (-15 -3603 ((-1259 |#4|) $)))) (-368) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|)) (T -336)) 
-((-2170 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-1259 *6)) (-5 *1 (-336 *3 *4 *5 *6)) (-4 *6 (-342 *3 *4 *5)))) (-3603 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-1259 *6)) (-5 *1 (-336 *3 *4 *5 *6)) (-4 *6 (-342 *3 *4 *5))))) 
-(-13 (-335 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2170 ((-1259 |#4|) $)) (-15 -3603 ((-1259 |#4|) $)))) 
-((-4485 (($ $ (-1170) |#2|) NIL) (($ $ (-638 (-1170)) (-638 |#2|)) 18) (($ $ (-638 (-290 |#2|))) 14) (($ $ (-290 |#2|)) NIL) (($ $ |#2| |#2|) NIL) (($ $ (-638 |#2|) (-638 |#2|)) NIL)) (-3277 (($ $ |#2|) 11))) 
-(((-337 |#1| |#2|) (-10 -8 (-15 -3277 (|#1| |#1| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#2|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#2| |#2|)) (-15 -4485 (|#1| |#1| (-290 |#2|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#2|)))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 |#2|))) (-15 -4485 (|#1| |#1| (-1170) |#2|))) (-338 |#2|) (-1098)) (T -337)) 
-NIL 
-(-10 -8 (-15 -3277 (|#1| |#1| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#2|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#2| |#2|)) (-15 -4485 (|#1| |#1| (-290 |#2|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#2|)))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 |#2|))) (-15 -4485 (|#1| |#1| (-1170) |#2|))) 
-((-3828 (($ (-1 |#1| |#1|) $) 6)) (-4485 (($ $ (-1170) |#1|) 16 (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) 15 (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-638 (-290 |#1|))) 14 (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) 13 (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) 12 (|has| |#1| (-305 |#1|))) (($ $ (-638 |#1|) (-638 |#1|)) 11 (|has| |#1| (-305 |#1|)))) (-3277 (($ $ |#1|) 10 (|has| |#1| (-283 |#1| |#1|))))) 
-(((-338 |#1|) (-1290) (-1098)) (T -338)) 
-((-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-338 *3)) (-4 *3 (-1098))))) 
-(-13 (-10 -8 (-15 -3828 ($ (-1 |t#1| |t#1|) $)) (IF (|has| |t#1| (-283 |t#1| |t#1|)) (-6 (-283 |t#1| $)) |noBranch|) (IF (|has| |t#1| (-305 |t#1|)) (-6 (-305 |t#1|)) |noBranch|) (IF (|has| |t#1| (-527 (-1170) |t#1|)) (-6 (-527 (-1170) |t#1|)) |noBranch|))) 
-(((-283 |#1| $) |has| |#1| (-283 |#1| |#1|)) ((-305 |#1|) |has| |#1| (-305 |#1|)) ((-527 (-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((-527 |#1| |#1|) |has| |#1| (-305 |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1170)) $) NIL)) (-3547 (((-121)) 87) (((-121) (-121)) 88)) (-1337 (((-638 (-611 $)) $) NIL)) (-4284 (($ $) NIL)) (-4224 (($ $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1952 (($ $ (-290 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL)) (-4190 (($ $) NIL)) (-4273 (($ $) NIL)) (-4217 (($ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-611 $) "failed") $) NIL) (((-3 |#3| "failed") $) NIL) (((-3 $ "failed") (-312 |#3|)) 69) (((-3 $ "failed") (-1170)) 93) (((-3 $ "failed") (-312 (-572))) 56 (|has| |#3| (-1044 (-572)))) (((-3 $ "failed") (-413 (-959 (-572)))) 62 (|has| |#3| (-1044 (-572)))) (((-3 $ "failed") (-959 (-572))) 57 (|has| |#3| (-1044 (-572)))) (((-3 $ "failed") (-312 (-385))) 74 (|has| |#3| (-1044 (-385)))) (((-3 $ "failed") (-413 (-959 (-385)))) 80 (|has| |#3| (-1044 (-385)))) (((-3 $ "failed") (-959 (-385))) 75 (|has| |#3| (-1044 (-385))))) (-1318 (((-611 $) $) NIL) ((|#3| $) NIL) (($ (-312 |#3|)) 70) (($ (-1170)) 94) (($ (-312 (-572))) 58 (|has| |#3| (-1044 (-572)))) (($ (-413 (-959 (-572)))) 63 (|has| |#3| (-1044 (-572)))) (($ (-959 (-572))) 59 (|has| |#3| (-1044 (-572)))) (($ (-312 (-385))) 76 (|has| |#3| (-1044 (-385)))) (($ (-413 (-959 (-385)))) 81 (|has| |#3| (-1044 (-385)))) (($ (-959 (-385))) 77 (|has| |#3| (-1044 (-385))))) (-1799 (((-3 $ "failed") $) NIL)) (-4184 (($) 10)) (-3567 (($ $) NIL) (($ (-638 $)) NIL)) (-4091 (((-638 (-123)) $) NIL)) (-4564 (((-123) (-123)) NIL)) (-3893 (((-121) $) NIL)) (-4240 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4127 (((-1166 $) (-611 $)) NIL (|has| $ (-1054)))) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 $ $) (-611 $)) NIL)) (-3614 (((-3 (-611 $) "failed") $) NIL)) (-4082 (($ $) 90)) (-3539 (($ $) NIL)) (-1658 (((-1152) $) NIL)) (-4291 (((-638 (-611 $)) $) NIL)) (-4496 (($ (-123) $) 89) (($ (-123) (-638 $)) NIL)) (-3291 (((-121) $ (-123)) NIL) (((-121) $ (-1170)) NIL)) (-1455 (((-769) $) NIL)) (-2607 (((-1116) $) NIL)) (-4319 (((-121) $ $) NIL) (((-121) $ (-1170)) NIL)) (-4179 (($ $) NIL)) (-4247 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4485 (($ $ (-611 $) $) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-1170) (-1 $ (-638 $))) NIL) (($ $ (-1170) (-1 $ $)) NIL) (($ $ (-638 (-123)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-123) (-1 $ (-638 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-3277 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-638 $)) NIL)) (-2759 (($ $) NIL) (($ $ $) NIL)) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL)) (-2830 (($ $) NIL (|has| $ (-1054)))) (-4278 (($ $) NIL)) (-4220 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-611 $)) NIL) (($ |#3|) NIL) (($ (-572)) NIL) (((-312 |#3|) $) 92)) (-2140 (((-769)) NIL)) (-3497 (($ $) NIL) (($ (-638 $)) NIL)) (-3228 (((-121) (-123)) NIL)) (-4251 (($ $) NIL)) (-4241 (($ $) NIL)) (-4246 (($ $) NIL)) (-2264 (($ $) NIL)) (-4174 (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (-2378 (($) 91 T CONST)) (-3255 (($) 22 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (* (($ |#3| $) NIL) (($ $ |#3|) NIL) (($ $ $) NIL) (($ (-572) $) NIL) (($ (-769) $) NIL) (($ (-923) $) NIL))) 
-(((-339 |#1| |#2| |#3|) (-13 (-298) (-43 |#3|) (-1044 |#3|) (-901 (-1170)) (-10 -8 (-15 -1318 ($ (-312 |#3|))) (-15 -3376 ((-3 $ "failed") (-312 |#3|))) (-15 -1318 ($ (-1170))) (-15 -3376 ((-3 $ "failed") (-1170))) (-15 -3972 ((-312 |#3|) $)) (IF (|has| |#3| (-1044 (-572))) (PROGN (-15 -1318 ($ (-312 (-572)))) (-15 -3376 ((-3 $ "failed") (-312 (-572)))) (-15 -1318 ($ (-413 (-959 (-572))))) (-15 -3376 ((-3 $ "failed") (-413 (-959 (-572))))) (-15 -1318 ($ (-959 (-572)))) (-15 -3376 ((-3 $ "failed") (-959 (-572))))) |noBranch|) (IF (|has| |#3| (-1044 (-385))) (PROGN (-15 -1318 ($ (-312 (-385)))) (-15 -3376 ((-3 $ "failed") (-312 (-385)))) (-15 -1318 ($ (-413 (-959 (-385))))) (-15 -3376 ((-3 $ "failed") (-413 (-959 (-385))))) (-15 -1318 ($ (-959 (-385)))) (-15 -3376 ((-3 $ "failed") (-959 (-385))))) |noBranch|) (-15 -2264 ($ $)) (-15 -4190 ($ $)) (-15 -4179 ($ $)) (-15 -3539 ($ $)) (-15 -4082 ($ $)) (-15 -4217 ($ $)) (-15 -4220 ($ $)) (-15 -4224 ($ $)) (-15 -4241 ($ $)) (-15 -4246 ($ $)) (-15 -4251 ($ $)) (-15 -4273 ($ $)) (-15 -4278 ($ $)) (-15 -4284 ($ $)) (-15 -4184 ($)) (-15 -3456 ((-638 (-1170)) $)) (-15 -3547 ((-121))) (-15 -3547 ((-121) (-121))))) (-638 (-1170)) (-638 (-1170)) (-393)) (T -339)) 
-((-1318 (*1 *1 *2) (-12 (-5 *2 (-312 *5)) (-4 *5 (-393)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-312 *5)) (-4 *5 (-393)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 *2)) (-14 *4 (-638 *2)) (-4 *5 (-393)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 *2)) (-14 *4 (-638 *2)) (-4 *5 (-393)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-312 *5)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-312 (-572))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-312 (-572))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-572)))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-413 (-959 (-572)))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-959 (-572))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-572))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-312 (-385))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-312 (-385))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-385)))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-413 (-959 (-385)))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-959 (-385))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-385))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-2264 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4190 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4179 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-3539 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4082 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4217 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4220 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4224 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4241 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4246 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4251 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4273 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4278 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4284 (*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-4184 (*1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) (-3456 (*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-339 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-393)))) (-3547 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) (-3547 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393))))) 
-(-13 (-298) (-43 |#3|) (-1044 |#3|) (-901 (-1170)) (-10 -8 (-15 -1318 ($ (-312 |#3|))) (-15 -3376 ((-3 $ "failed") (-312 |#3|))) (-15 -1318 ($ (-1170))) (-15 -3376 ((-3 $ "failed") (-1170))) (-15 -3972 ((-312 |#3|) $)) (IF (|has| |#3| (-1044 (-572))) (PROGN (-15 -1318 ($ (-312 (-572)))) (-15 -3376 ((-3 $ "failed") (-312 (-572)))) (-15 -1318 ($ (-413 (-959 (-572))))) (-15 -3376 ((-3 $ "failed") (-413 (-959 (-572))))) (-15 -1318 ($ (-959 (-572)))) (-15 -3376 ((-3 $ "failed") (-959 (-572))))) |noBranch|) (IF (|has| |#3| (-1044 (-385))) (PROGN (-15 -1318 ($ (-312 (-385)))) (-15 -3376 ((-3 $ "failed") (-312 (-385)))) (-15 -1318 ($ (-413 (-959 (-385))))) (-15 -3376 ((-3 $ "failed") (-413 (-959 (-385))))) (-15 -1318 ($ (-959 (-385)))) (-15 -3376 ((-3 $ "failed") (-959 (-385))))) |noBranch|) (-15 -2264 ($ $)) (-15 -4190 ($ $)) (-15 -4179 ($ $)) (-15 -3539 ($ $)) (-15 -4082 ($ $)) (-15 -4217 ($ $)) (-15 -4220 ($ $)) (-15 -4224 ($ $)) (-15 -4241 ($ $)) (-15 -4246 ($ $)) (-15 -4251 ($ $)) (-15 -4273 ($ $)) (-15 -4278 ($ $)) (-15 -4284 ($ $)) (-15 -4184 ($)) (-15 -3456 ((-638 (-1170)) $)) (-15 -3547 ((-121))) (-15 -3547 ((-121) (-121))))) 
-((-3828 ((|#8| (-1 |#5| |#1|) |#4|) 19))) 
-(((-340 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -3828 (|#8| (-1 |#5| |#1|) |#4|))) (-1214) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|) (-1214) (-1234 |#5|) (-1234 (-413 |#6|)) (-342 |#5| |#6| |#7|)) (T -340)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1214)) (-4 *8 (-1214)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *9 (-1234 *8)) (-4 *2 (-342 *8 *9 *10)) (-5 *1 (-340 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-342 *5 *6 *7)) (-4 *10 (-1234 (-413 *9)))))) 
-(-10 -7 (-15 -3828 (|#8| (-1 |#5| |#1|) |#4|))) 
-((-3970 (((-2 (|:| |num| (-1259 |#3|)) (|:| |den| |#3|)) $) 37)) (-4337 (($ (-1259 (-413 |#3|)) (-1259 $)) NIL) (($ (-1259 (-413 |#3|))) NIL) (($ (-1259 |#3|) |#3|) 158)) (-4442 (((-1259 $) (-1259 $)) 142)) (-3356 (((-638 (-638 |#2|))) 115)) (-2575 (((-121) |#2| |#2|) 71)) (-3988 (($ $) 136)) (-1602 (((-769)) 30)) (-2077 (((-1259 $) (-1259 $)) 195)) (-2380 (((-638 (-959 |#2|)) (-1170)) 108)) (-4503 (((-121) $) 155)) (-3829 (((-121) $) 24) (((-121) $ |#2|) 28) (((-121) $ |#3|) 199)) (-1380 (((-3 |#3| "failed")) 48)) (-1774 (((-769)) 167)) (-3277 ((|#2| $ |#2| |#2|) 129)) (-2447 (((-3 |#3| "failed")) 66)) (-3139 (($ $ (-1 (-413 |#3|) (-413 |#3|)) (-769)) NIL) (($ $ (-1 (-413 |#3|) (-413 |#3|))) NIL) (($ $ (-1 |#3| |#3|)) 203) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL) (($ $ (-769)) NIL) (($ $) NIL)) (-2139 (((-1259 $) (-1259 $)) 148)) (-3516 (((-2 (|:| |num| $) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) $ (-1 |#3| |#3|)) 64)) (-3920 (((-121)) 32))) 
-(((-341 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3356 ((-638 (-638 |#2|)))) (-15 -2380 ((-638 (-959 |#2|)) (-1170))) (-15 -3516 ((-2 (|:| |num| |#1|) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) |#1| (-1 |#3| |#3|))) (-15 -1380 ((-3 |#3| "failed"))) (-15 -2447 ((-3 |#3| "failed"))) (-15 -3277 (|#2| |#1| |#2| |#2|)) (-15 -3988 (|#1| |#1|)) (-15 -4337 (|#1| (-1259 |#3|) |#3|)) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|))) (-15 -3829 ((-121) |#1| |#3|)) (-15 -3829 ((-121) |#1| |#2|)) (-15 -3970 ((-2 (|:| |num| (-1259 |#3|)) (|:| |den| |#3|)) |#1|)) (-15 -4442 ((-1259 |#1|) (-1259 |#1|))) (-15 -2077 ((-1259 |#1|) (-1259 |#1|))) (-15 -2139 ((-1259 |#1|) (-1259 |#1|))) (-15 -3829 ((-121) |#1|)) (-15 -4503 ((-121) |#1|)) (-15 -2575 ((-121) |#2| |#2|)) (-15 -3920 ((-121))) (-15 -1774 ((-769))) (-15 -1602 ((-769))) (-15 -3139 (|#1| |#1| (-1 (-413 |#3|) (-413 |#3|)))) (-15 -3139 (|#1| |#1| (-1 (-413 |#3|) (-413 |#3|)) (-769))) (-15 -4337 (|#1| (-1259 (-413 |#3|)))) (-15 -4337 (|#1| (-1259 (-413 |#3|)) (-1259 |#1|)))) (-342 |#2| |#3| |#4|) (-1214) (-1234 |#2|) (-1234 (-413 |#3|))) (T -341)) 
-((-1602 (*1 *2) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-769)) (-5 *1 (-341 *3 *4 *5 *6)) (-4 *3 (-342 *4 *5 *6)))) (-1774 (*1 *2) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-769)) (-5 *1 (-341 *3 *4 *5 *6)) (-4 *3 (-342 *4 *5 *6)))) (-3920 (*1 *2) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-121)) (-5 *1 (-341 *3 *4 *5 *6)) (-4 *3 (-342 *4 *5 *6)))) (-2575 (*1 *2 *3 *3) (-12 (-4 *3 (-1214)) (-4 *5 (-1234 *3)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-121)) (-5 *1 (-341 *4 *3 *5 *6)) (-4 *4 (-342 *3 *5 *6)))) (-2447 (*1 *2) (|partial| -12 (-4 *4 (-1214)) (-4 *5 (-1234 (-413 *2))) (-4 *2 (-1234 *4)) (-5 *1 (-341 *3 *4 *2 *5)) (-4 *3 (-342 *4 *2 *5)))) (-1380 (*1 *2) (|partial| -12 (-4 *4 (-1214)) (-4 *5 (-1234 (-413 *2))) (-4 *2 (-1234 *4)) (-5 *1 (-341 *3 *4 *2 *5)) (-4 *3 (-342 *4 *2 *5)))) (-2380 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *5 (-1214)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-5 *2 (-638 (-959 *5))) (-5 *1 (-341 *4 *5 *6 *7)) (-4 *4 (-342 *5 *6 *7)))) (-3356 (*1 *2) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-638 (-638 *4))) (-5 *1 (-341 *3 *4 *5 *6)) (-4 *3 (-342 *4 *5 *6))))) 
-(-10 -8 (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3356 ((-638 (-638 |#2|)))) (-15 -2380 ((-638 (-959 |#2|)) (-1170))) (-15 -3516 ((-2 (|:| |num| |#1|) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) |#1| (-1 |#3| |#3|))) (-15 -1380 ((-3 |#3| "failed"))) (-15 -2447 ((-3 |#3| "failed"))) (-15 -3277 (|#2| |#1| |#2| |#2|)) (-15 -3988 (|#1| |#1|)) (-15 -4337 (|#1| (-1259 |#3|) |#3|)) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|))) (-15 -3829 ((-121) |#1| |#3|)) (-15 -3829 ((-121) |#1| |#2|)) (-15 -3970 ((-2 (|:| |num| (-1259 |#3|)) (|:| |den| |#3|)) |#1|)) (-15 -4442 ((-1259 |#1|) (-1259 |#1|))) (-15 -2077 ((-1259 |#1|) (-1259 |#1|))) (-15 -2139 ((-1259 |#1|) (-1259 |#1|))) (-15 -3829 ((-121) |#1|)) (-15 -4503 ((-121) |#1|)) (-15 -2575 ((-121) |#2| |#2|)) (-15 -3920 ((-121))) (-15 -1774 ((-769))) (-15 -1602 ((-769))) (-15 -3139 (|#1| |#1| (-1 (-413 |#3|) (-413 |#3|)))) (-15 -3139 (|#1| |#1| (-1 (-413 |#3|) (-413 |#3|)) (-769))) (-15 -4337 (|#1| (-1259 (-413 |#3|)))) (-15 -4337 (|#1| (-1259 (-413 |#3|)) (-1259 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3970 (((-2 (|:| |num| (-1259 |#2|)) (|:| |den| |#2|)) $) 181)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 88 (|has| (-413 |#2|) (-368)))) (-3946 (($ $) 89 (|has| (-413 |#2|) (-368)))) (-3686 (((-121) $) 91 (|has| (-413 |#2|) (-368)))) (-1845 (((-685 (-413 |#2|)) (-1259 $)) 44) (((-685 (-413 |#2|))) 55)) (-3520 (((-413 |#2|) $) 50)) (-3617 (((-1178 (-923) (-769)) (-572)) 142 (|has| (-413 |#2|) (-353)))) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 108 (|has| (-413 |#2|) (-368)))) (-1466 (((-424 $) $) 109 (|has| (-413 |#2|) (-368)))) (-3112 (((-121) $ $) 99 (|has| (-413 |#2|) (-368)))) (-1685 (((-769)) 81 (|has| (-413 |#2|) (-374)))) (-3182 (((-121)) 198)) (-1688 (((-121) |#1|) 197) (((-121) |#2|) 196)) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 164 (|has| (-413 |#2|) (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 162 (|has| (-413 |#2|) (-1044 (-413 (-572))))) (((-3 (-413 |#2|) "failed") $) 161)) (-1318 (((-572) $) 165 (|has| (-413 |#2|) (-1044 (-572)))) (((-413 (-572)) $) 163 (|has| (-413 |#2|) (-1044 (-413 (-572))))) (((-413 |#2|) $) 160)) (-4337 (($ (-1259 (-413 |#2|)) (-1259 $)) 46) (($ (-1259 (-413 |#2|))) 58) (($ (-1259 |#2|) |#2|) 174)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 148 (|has| (-413 |#2|) (-353)))) (-2190 (($ $ $) 103 (|has| (-413 |#2|) (-368)))) (-1741 (((-685 (-413 |#2|)) $ (-1259 $)) 51) (((-685 (-413 |#2|)) $) 53)) (-2284 (((-685 (-572)) (-685 $)) 159 (|has| (-413 |#2|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 158 (|has| (-413 |#2|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-413 |#2|))) (|:| |vec| (-1259 (-413 |#2|)))) (-685 $) (-1259 $)) 157) (((-685 (-413 |#2|)) (-685 $)) 156)) (-4442 (((-1259 $) (-1259 $)) 186)) (-3116 (($ |#3|) 153) (((-3 $ "failed") (-413 |#3|)) 150 (|has| (-413 |#2|) (-368)))) (-1799 (((-3 $ "failed") $) 33)) (-3356 (((-638 (-638 |#1|))) 167 (|has| |#1| (-374)))) (-2575 (((-121) |#1| |#1|) 202)) (-2667 (((-923)) 52)) (-3286 (($) 84 (|has| (-413 |#2|) (-374)))) (-1906 (((-121)) 195)) (-1418 (((-121) |#1|) 194) (((-121) |#2|) 193)) (-2208 (($ $ $) 102 (|has| (-413 |#2|) (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 97 (|has| (-413 |#2|) (-368)))) (-3988 (($ $) 173)) (-2754 (($) 144 (|has| (-413 |#2|) (-353)))) (-1297 (((-121) $) 145 (|has| (-413 |#2|) (-353)))) (-4486 (($ $ (-769)) 136 (|has| (-413 |#2|) (-353))) (($ $) 135 (|has| (-413 |#2|) (-353)))) (-1526 (((-121) $) 110 (|has| (-413 |#2|) (-368)))) (-3377 (((-923) $) 147 (|has| (-413 |#2|) (-353))) (((-834 (-923)) $) 133 (|has| (-413 |#2|) (-353)))) (-3893 (((-121) $) 30)) (-1602 (((-769)) 205)) (-2077 (((-1259 $) (-1259 $)) 187)) (-4429 (((-413 |#2|) $) 49)) (-2380 (((-638 (-959 |#1|)) (-1170)) 168 (|has| |#1| (-368)))) (-3961 (((-3 $ "failed") $) 137 (|has| (-413 |#2|) (-353)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 106 (|has| (-413 |#2|) (-368)))) (-3251 ((|#3| $) 42 (|has| (-413 |#2|) (-368)))) (-3633 (((-923) $) 83 (|has| (-413 |#2|) (-374)))) (-3111 ((|#3| $) 151)) (-1629 (($ (-638 $)) 95 (|has| (-413 |#2|) (-368))) (($ $ $) 94 (|has| (-413 |#2|) (-368)))) (-1658 (((-1152) $) 9)) (-3639 (((-685 (-413 |#2|))) 182)) (-4322 (((-685 (-413 |#2|))) 184)) (-4350 (($ $) 111 (|has| (-413 |#2|) (-368)))) (-2984 (($ (-1259 |#2|) |#2|) 179)) (-2488 (((-685 (-413 |#2|))) 183)) (-3378 (((-685 (-413 |#2|))) 185)) (-2457 (((-2 (|:| |num| (-685 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 178)) (-3697 (((-2 (|:| |num| (-1259 |#2|)) (|:| |den| |#2|)) $) 180)) (-4009 (((-1259 $)) 191)) (-1778 (((-1259 $)) 192)) (-4503 (((-121) $) 190)) (-3829 (((-121) $) 189) (((-121) $ |#1|) 177) (((-121) $ |#2|) 176)) (-1773 (($) 138 (|has| (-413 |#2|) (-353)) CONST)) (-1763 (($ (-923)) 82 (|has| (-413 |#2|) (-374)))) (-1380 (((-3 |#2| "failed")) 170)) (-2607 (((-1116) $) 10)) (-1774 (((-769)) 204)) (-2307 (($) 155)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 96 (|has| (-413 |#2|) (-368)))) (-3069 (($ (-638 $)) 93 (|has| (-413 |#2|) (-368))) (($ $ $) 92 (|has| (-413 |#2|) (-368)))) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 141 (|has| (-413 |#2|) (-353)))) (-4304 (((-424 $) $) 107 (|has| (-413 |#2|) (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105 (|has| (-413 |#2|) (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 104 (|has| (-413 |#2|) (-368)))) (-1803 (((-3 $ "failed") $ $) 87 (|has| (-413 |#2|) (-368)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 98 (|has| (-413 |#2|) (-368)))) (-4029 (((-769) $) 100 (|has| (-413 |#2|) (-368)))) (-3587 (((-638 $)) 85 (|has| (-413 |#2|) (-374)))) (-3277 ((|#1| $ |#1| |#1|) 172)) (-2447 (((-3 |#2| "failed")) 171)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 101 (|has| (-413 |#2|) (-368)))) (-2119 (((-413 |#2|) (-1259 $)) 45) (((-413 |#2|)) 54)) (-3158 (((-769) $) 146 (|has| (-413 |#2|) (-353))) (((-3 (-769) "failed") $ $) 134 (|has| (-413 |#2|) (-353)))) (-3139 (($ $ (-1 (-413 |#2|) (-413 |#2|)) (-769)) 118 (|has| (-413 |#2|) (-368))) (($ $ (-1 (-413 |#2|) (-413 |#2|))) 117 (|has| (-413 |#2|) (-368))) (($ $ (-1 |#2| |#2|)) 175) (($ $ (-638 (-1170)) (-638 (-769))) 125 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) (-4028 (|has| (-413 |#2|) (-901 (-1170))) (|has| (-413 |#2|) (-368))))) (($ $ (-1170) (-769)) 126 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) (-4028 (|has| (-413 |#2|) (-901 (-1170))) (|has| (-413 |#2|) (-368))))) (($ $ (-638 (-1170))) 127 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) (-4028 (|has| (-413 |#2|) (-901 (-1170))) (|has| (-413 |#2|) (-368))))) (($ $ (-1170)) 128 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) (-4028 (|has| (-413 |#2|) (-901 (-1170))) (|has| (-413 |#2|) (-368))))) (($ $ (-769)) 130 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-227))) (-4028 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353)))) (($ $) 132 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-227))) (-4028 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353))))) (-3482 (((-685 (-413 |#2|)) (-1259 $) (-1 (-413 |#2|) (-413 |#2|))) 149 (|has| (-413 |#2|) (-368)))) (-2830 ((|#3|) 154)) (-2278 (($) 143 (|has| (-413 |#2|) (-353)))) (-3160 (((-1259 (-413 |#2|)) $ (-1259 $)) 48) (((-685 (-413 |#2|)) (-1259 $) (-1259 $)) 47) (((-1259 (-413 |#2|)) $) 60) (((-685 (-413 |#2|)) (-1259 $)) 59)) (-4081 (((-1259 (-413 |#2|)) $) 57) (($ (-1259 (-413 |#2|))) 56) ((|#3| $) 166) (($ |#3|) 152)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 140 (|has| (-413 |#2|) (-353)))) (-2139 (((-1259 $) (-1259 $)) 188)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 |#2|)) 36) (($ (-413 (-572))) 80 (-1841 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-1044 (-413 (-572)))))) (($ $) 86 (|has| (-413 |#2|) (-368)))) (-2779 (($ $) 139 (|has| (-413 |#2|) (-353))) (((-3 $ "failed") $) 41 (|has| (-413 |#2|) (-149)))) (-2707 ((|#3| $) 43)) (-2140 (((-769)) 28)) (-3640 (((-121)) 201)) (-1825 (((-121) |#1|) 200) (((-121) |#2|) 199)) (-2237 (((-1259 $)) 61)) (-3774 (((-121) $ $) 90 (|has| (-413 |#2|) (-368)))) (-3516 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) 169)) (-3920 (((-121)) 203)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 112 (|has| (-413 |#2|) (-368)))) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-1 (-413 |#2|) (-413 |#2|)) (-769)) 120 (|has| (-413 |#2|) (-368))) (($ $ (-1 (-413 |#2|) (-413 |#2|))) 119 (|has| (-413 |#2|) (-368))) (($ $ (-638 (-1170)) (-638 (-769))) 121 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) (-4028 (|has| (-413 |#2|) (-901 (-1170))) (|has| (-413 |#2|) (-368))))) (($ $ (-1170) (-769)) 122 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) (-4028 (|has| (-413 |#2|) (-901 (-1170))) (|has| (-413 |#2|) (-368))))) (($ $ (-638 (-1170))) 123 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) (-4028 (|has| (-413 |#2|) (-901 (-1170))) (|has| (-413 |#2|) (-368))))) (($ $ (-1170)) 124 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) (-4028 (|has| (-413 |#2|) (-901 (-1170))) (|has| (-413 |#2|) (-368))))) (($ $ (-769)) 129 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-227))) (-4028 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353)))) (($ $) 131 (-1841 (-4028 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-227))) (-4028 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353))))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 116 (|has| (-413 |#2|) (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 113 (|has| (-413 |#2|) (-368)))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 |#2|)) 38) (($ (-413 |#2|) $) 37) (($ (-413 (-572)) $) 115 (|has| (-413 |#2|) (-368))) (($ $ (-413 (-572))) 114 (|has| (-413 |#2|) (-368))))) 
-(((-342 |#1| |#2| |#3|) (-1290) (-1214) (-1234 |t#1|) (-1234 (-413 |t#2|))) (T -342)) 
-((-1602 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-769)))) (-1774 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-769)))) (-3920 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-2575 (*1 *2 *3 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-3640 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-1825 (*1 *2 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-1825 (*1 *2 *3) (-12 (-4 *1 (-342 *4 *3 *5)) (-4 *4 (-1214)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-5 *2 (-121)))) (-3182 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-1688 (*1 *2 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-1688 (*1 *2 *3) (-12 (-4 *1 (-342 *4 *3 *5)) (-4 *4 (-1214)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-5 *2 (-121)))) (-1906 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-1418 (*1 *2 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-1418 (*1 *2 *3) (-12 (-4 *1 (-342 *4 *3 *5)) (-4 *4 (-1214)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-5 *2 (-121)))) (-1778 (*1 *2) (-12 (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)))) (-4009 (*1 *2) (-12 (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)))) (-4503 (*1 *2 *1) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-3829 (*1 *2 *1) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-2139 (*1 *2 *2) (-12 (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))))) (-2077 (*1 *2 *2) (-12 (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))))) (-4442 (*1 *2 *2) (-12 (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))))) (-3378 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-685 (-413 *4))))) (-4322 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-685 (-413 *4))))) (-2488 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-685 (-413 *4))))) (-3639 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-685 (-413 *4))))) (-3970 (*1 *2 *1) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-2 (|:| |num| (-1259 *4)) (|:| |den| *4))))) (-3697 (*1 *2 *1) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-2 (|:| |num| (-1259 *4)) (|:| |den| *4))))) (-2984 (*1 *1 *2 *3) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-1234 *4)) (-4 *4 (-1214)) (-4 *1 (-342 *4 *3 *5)) (-4 *5 (-1234 (-413 *3))))) (-2457 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *1 (-342 *4 *5 *6)) (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-2 (|:| |num| (-685 *5)) (|:| |den| *5))))) (-3829 (*1 *2 *1 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) (-3829 (*1 *2 *1 *3) (-12 (-4 *1 (-342 *4 *3 *5)) (-4 *4 (-1214)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-5 *2 (-121)))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))))) (-4337 (*1 *1 *2 *3) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-1234 *4)) (-4 *4 (-1214)) (-4 *1 (-342 *4 *3 *5)) (-4 *5 (-1234 (-413 *3))))) (-3988 (*1 *1 *1) (-12 (-4 *1 (-342 *2 *3 *4)) (-4 *2 (-1214)) (-4 *3 (-1234 *2)) (-4 *4 (-1234 (-413 *3))))) (-3277 (*1 *2 *1 *2 *2) (-12 (-4 *1 (-342 *2 *3 *4)) (-4 *2 (-1214)) (-4 *3 (-1234 *2)) (-4 *4 (-1234 (-413 *3))))) (-2447 (*1 *2) (|partial| -12 (-4 *1 (-342 *3 *2 *4)) (-4 *3 (-1214)) (-4 *4 (-1234 (-413 *2))) (-4 *2 (-1234 *3)))) (-1380 (*1 *2) (|partial| -12 (-4 *1 (-342 *3 *2 *4)) (-4 *3 (-1214)) (-4 *4 (-1234 (-413 *2))) (-4 *2 (-1234 *3)))) (-3516 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-1214)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-2 (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (-4 *1 (-342 *4 *5 *6)))) (-2380 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *1 (-342 *4 *5 *6)) (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-4 *4 (-368)) (-5 *2 (-638 (-959 *4))))) (-3356 (*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *3 (-374)) (-5 *2 (-638 (-638 *3)))))) 
-(-13 (-720 (-413 |t#2|) |t#3|) (-10 -8 (-15 -1602 ((-769))) (-15 -1774 ((-769))) (-15 -3920 ((-121))) (-15 -2575 ((-121) |t#1| |t#1|)) (-15 -3640 ((-121))) (-15 -1825 ((-121) |t#1|)) (-15 -1825 ((-121) |t#2|)) (-15 -3182 ((-121))) (-15 -1688 ((-121) |t#1|)) (-15 -1688 ((-121) |t#2|)) (-15 -1906 ((-121))) (-15 -1418 ((-121) |t#1|)) (-15 -1418 ((-121) |t#2|)) (-15 -1778 ((-1259 $))) (-15 -4009 ((-1259 $))) (-15 -4503 ((-121) $)) (-15 -3829 ((-121) $)) (-15 -2139 ((-1259 $) (-1259 $))) (-15 -2077 ((-1259 $) (-1259 $))) (-15 -4442 ((-1259 $) (-1259 $))) (-15 -3378 ((-685 (-413 |t#2|)))) (-15 -4322 ((-685 (-413 |t#2|)))) (-15 -2488 ((-685 (-413 |t#2|)))) (-15 -3639 ((-685 (-413 |t#2|)))) (-15 -3970 ((-2 (|:| |num| (-1259 |t#2|)) (|:| |den| |t#2|)) $)) (-15 -4337 ($ (-1259 |t#2|) |t#2|)) (-15 -3697 ((-2 (|:| |num| (-1259 |t#2|)) (|:| |den| |t#2|)) $)) (-15 -2984 ($ (-1259 |t#2|) |t#2|)) (-15 -2457 ((-2 (|:| |num| (-685 |t#2|)) (|:| |den| |t#2|)) (-1 |t#2| |t#2|))) (-15 -3829 ((-121) $ |t#1|)) (-15 -3829 ((-121) $ |t#2|)) (-15 -3139 ($ $ (-1 |t#2| |t#2|))) (-15 -4337 ($ (-1259 |t#2|) |t#2|)) (-15 -3988 ($ $)) (-15 -3277 (|t#1| $ |t#1| |t#1|)) (-15 -2447 ((-3 |t#2| "failed"))) (-15 -1380 ((-3 |t#2| "failed"))) (-15 -3516 ((-2 (|:| |num| $) (|:| |den| |t#2|) (|:| |derivden| |t#2|) (|:| |gd| |t#2|)) $ (-1 |t#2| |t#2|))) (IF (|has| |t#1| (-368)) (-15 -2380 ((-638 (-959 |t#1|)) (-1170))) |noBranch|) (IF (|has| |t#1| (-374)) (-15 -3356 ((-638 (-638 |t#1|)))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-43 (-413 |#2|)) . T) ((-43 $) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-120 (-413 |#2|) (-413 |#2|)) . T) ((-120 $ $) . T) ((-138) . T) ((-149) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-149))) ((-151) |has| (-413 |#2|) (-151)) ((-612 (-856)) . T) ((-174) . T) ((-613 |#3|) . T) ((-225 (-413 |#2|)) |has| (-413 |#2|) (-368)) ((-227) -1841 (|has| (-413 |#2|) (-353)) (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368)))) ((-240) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-287) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-303) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-368) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-408) |has| (-413 |#2|) (-353)) ((-374) -1841 (|has| (-413 |#2|) (-374)) (|has| (-413 |#2|) (-353))) ((-353) |has| (-413 |#2|) (-353)) ((-376 (-413 |#2|) |#3|) . T) ((-415 (-413 |#2|) |#3|) . T) ((-383 (-413 |#2|)) . T) ((-417 (-413 |#2|)) . T) ((-457) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-562) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-641 (-413 (-572))) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-641 (-413 |#2|)) . T) ((-641 $) . T) ((-634 (-413 |#2|)) . T) ((-634 (-572)) |has| (-413 |#2|) (-634 (-572))) ((-713 (-413 (-572))) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-713 (-413 |#2|)) . T) ((-713 $) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-720 (-413 |#2|) |#3|) . T) ((-722) . T) ((-901 (-1170)) -12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170)))) ((-922) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-1044 (-413 (-572))) |has| (-413 |#2|) (-1044 (-413 (-572)))) ((-1044 (-413 |#2|)) . T) ((-1044 (-572)) |has| (-413 |#2|) (-1044 (-572))) ((-1060 (-413 (-572))) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368))) ((-1060 (-413 |#2|)) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) |has| (-413 |#2|) (-353)) ((-1214) -1841 (|has| (-413 |#2|) (-353)) (|has| (-413 |#2|) (-368)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 (((-911 |#1|) $) NIL) (($ $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| (-911 |#1|) (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL (|has| (-911 |#1|) (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-911 |#1|) "failed") $) NIL)) (-1318 (((-911 |#1|) $) NIL)) (-4337 (($ (-1259 (-911 |#1|))) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-911 |#1|) (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-911 |#1|) (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL (|has| (-911 |#1|) (-374)))) (-1297 (((-121) $) NIL (|has| (-911 |#1|) (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374)))) (($ $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| (-911 |#1|) (-374))) (((-834 (-923)) $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) NIL (|has| (-911 |#1|) (-374)))) (-3880 (((-121) $) NIL (|has| (-911 |#1|) (-374)))) (-4429 (((-911 |#1|) $) NIL) (($ $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| (-911 |#1|) (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 (-911 |#1|)) $) NIL) (((-1166 $) $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3633 (((-923) $) NIL (|has| (-911 |#1|) (-374)))) (-4064 (((-1166 (-911 |#1|)) $) NIL (|has| (-911 |#1|) (-374)))) (-4484 (((-1166 (-911 |#1|)) $) NIL (|has| (-911 |#1|) (-374))) (((-3 (-1166 (-911 |#1|)) "failed") $ $) NIL (|has| (-911 |#1|) (-374)))) (-2359 (($ $ (-1166 (-911 |#1|))) NIL (|has| (-911 |#1|) (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-911 |#1|) (-374)) CONST)) (-1763 (($ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-1395 (((-965 (-1116))) NIL)) (-2307 (($) NIL (|has| (-911 |#1|) (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| (-911 |#1|) (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| (-911 |#1|) (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| (-911 |#1|) (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-2830 (((-1166 (-911 |#1|))) NIL)) (-2278 (($) NIL (|has| (-911 |#1|) (-374)))) (-3627 (($) NIL (|has| (-911 |#1|) (-374)))) (-3160 (((-1259 (-911 |#1|)) $) NIL) (((-685 (-911 |#1|)) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| (-911 |#1|) (-374)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-911 |#1|)) NIL)) (-2779 (($ $) NIL (|has| (-911 |#1|) (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL) (((-1259 $) (-923)) NIL)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-2611 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-1557 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL) (($ $ (-911 |#1|)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ (-911 |#1|)) NIL) (($ (-911 |#1|) $) NIL))) 
-(((-343 |#1| |#2|) (-13 (-329 (-911 |#1|)) (-10 -7 (-15 -1395 ((-965 (-1116)))))) (-923) (-923)) (T -343)) 
-((-1395 (*1 *2) (-12 (-5 *2 (-965 (-1116))) (-5 *1 (-343 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923))))) 
-(-13 (-329 (-911 |#1|)) (-10 -7 (-15 -1395 ((-965 (-1116)))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 46)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) 43 (|has| |#1| (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL (|has| |#1| (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 113)) (-1318 ((|#1| $) 84)) (-4337 (($ (-1259 |#1|)) 102)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 93 (|has| |#1| (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) 96 (|has| |#1| (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) 128 (|has| |#1| (-374)))) (-1297 (((-121) $) 49 (|has| |#1| (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374)))) (($ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) 47 (|has| |#1| (-374))) (((-834 (-923)) $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) 130 (|has| |#1| (-374)))) (-3880 (((-121) $) NIL (|has| |#1| (-374)))) (-4429 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 |#1|) $) 88) (((-1166 $) $ (-923)) NIL (|has| |#1| (-374)))) (-3633 (((-923) $) 138 (|has| |#1| (-374)))) (-4064 (((-1166 |#1|) $) NIL (|has| |#1| (-374)))) (-4484 (((-1166 |#1|) $) NIL (|has| |#1| (-374))) (((-3 (-1166 |#1|) "failed") $ $) NIL (|has| |#1| (-374)))) (-2359 (($ $ (-1166 |#1|)) NIL (|has| |#1| (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 145)) (-1773 (($) NIL (|has| |#1| (-374)) CONST)) (-1763 (($ (-923)) 70 (|has| |#1| (-374)))) (-1336 (((-121) $) 116)) (-2607 (((-1116) $) NIL)) (-1395 (((-965 (-1116))) 44)) (-2307 (($) 126 (|has| |#1| (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 91 (|has| |#1| (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) 67) (((-923)) 68)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) 129 (|has| |#1| (-374))) (((-3 (-769) "failed") $ $) 123 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-2830 (((-1166 |#1|)) 94)) (-2278 (($) 127 (|has| |#1| (-374)))) (-3627 (($) 135 (|has| |#1| (-374)))) (-3160 (((-1259 |#1|) $) 59) (((-685 |#1|) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| |#1| (-374)))) (-3972 (((-856) $) 141) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) 74)) (-2779 (($ $) NIL (|has| |#1| (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2140 (((-769)) 137)) (-2237 (((-1259 $)) 115) (((-1259 $) (-923)) 72)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 32 T CONST)) (-3255 (($) 19 T CONST)) (-2611 (($ $) 80 (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1557 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1324 (((-121) $ $) 48)) (-1379 (($ $ $) 143) (($ $ |#1|) 144)) (-1373 (($ $) 125) (($ $ $) NIL)) (-1367 (($ $ $) 61)) (** (($ $ (-923)) 147) (($ $ (-769)) 148) (($ $ (-572)) 146)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 76) (($ $ $) 75) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 142))) 
-(((-344 |#1| |#2|) (-13 (-329 |#1|) (-10 -7 (-15 -1395 ((-965 (-1116)))))) (-353) (-1166 |#1|)) (T -344)) 
-((-1395 (*1 *2) (-12 (-5 *2 (-965 (-1116))) (-5 *1 (-344 *3 *4)) (-4 *3 (-353)) (-14 *4 (-1166 *3))))) 
-(-13 (-329 |#1|) (-10 -7 (-15 -1395 ((-965 (-1116)))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| |#1| (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL (|has| |#1| (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-4337 (($ (-1259 |#1|)) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| |#1| (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL (|has| |#1| (-374)))) (-1297 (((-121) $) NIL (|has| |#1| (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374)))) (($ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| |#1| (-374))) (((-834 (-923)) $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) NIL (|has| |#1| (-374)))) (-3880 (((-121) $) NIL (|has| |#1| (-374)))) (-4429 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 |#1|) $) NIL) (((-1166 $) $ (-923)) NIL (|has| |#1| (-374)))) (-3633 (((-923) $) NIL (|has| |#1| (-374)))) (-4064 (((-1166 |#1|) $) NIL (|has| |#1| (-374)))) (-4484 (((-1166 |#1|) $) NIL (|has| |#1| (-374))) (((-3 (-1166 |#1|) "failed") $ $) NIL (|has| |#1| (-374)))) (-2359 (($ $ (-1166 |#1|)) NIL (|has| |#1| (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| |#1| (-374)) CONST)) (-1763 (($ (-923)) NIL (|has| |#1| (-374)))) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-1395 (((-965 (-1116))) NIL)) (-2307 (($) NIL (|has| |#1| (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| |#1| (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| |#1| (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-2830 (((-1166 |#1|)) NIL)) (-2278 (($) NIL (|has| |#1| (-374)))) (-3627 (($) NIL (|has| |#1| (-374)))) (-3160 (((-1259 |#1|) $) NIL) (((-685 |#1|) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| |#1| (-374)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) NIL)) (-2779 (($ $) NIL (|has| |#1| (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL) (((-1259 $) (-923)) NIL)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-2611 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1557 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-345 |#1| |#2|) (-13 (-329 |#1|) (-10 -7 (-15 -1395 ((-965 (-1116)))))) (-353) (-923)) (T -345)) 
-((-1395 (*1 *2) (-12 (-5 *2 (-965 (-1116))) (-5 *1 (-345 *3 *4)) (-4 *3 (-353)) (-14 *4 (-923))))) 
-(-13 (-329 |#1|) (-10 -7 (-15 -1395 ((-965 (-1116)))))) 
-((-4452 (((-121) |#2|) 68)) (-4353 (((-424 |#2|) |#2|) 56)) (-2088 (((-424 |#2|) |#2|) 58)) (-2602 (((-638 |#2|) |#2|) 61)) (-2356 (((-638 |#2|) |#2| (-769)) 62)) (-4304 (((-424 |#2|) |#2|) 59))) 
-(((-346 |#1| |#2|) (-10 -7 (-15 -2602 ((-638 |#2|) |#2|)) (-15 -2356 ((-638 |#2|) |#2| (-769))) (-15 -4304 ((-424 |#2|) |#2|)) (-15 -4353 ((-424 |#2|) |#2|)) (-15 -2088 ((-424 |#2|) |#2|)) (-15 -4452 ((-121) |#2|))) (-353) (-1234 |#1|)) (T -346)) 
-((-4452 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) (-2088 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) (-4353 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) (-4304 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) (-2356 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-353)) (-5 *2 (-638 *3)) (-5 *1 (-346 *5 *3)) (-4 *3 (-1234 *5)))) (-2602 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-638 *3)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -2602 ((-638 |#2|) |#2|)) (-15 -2356 ((-638 |#2|) |#2| (-769))) (-15 -4304 ((-424 |#2|) |#2|)) (-15 -4353 ((-424 |#2|) |#2|)) (-15 -2088 ((-424 |#2|) |#2|)) (-15 -4452 ((-121) |#2|))) 
-((-4452 (((-121) |#2|) 68)) (-4353 (((-424 |#2|) |#2|) 56)) (-2088 (((-424 |#2|) |#2|) 58)) (-2602 (((-638 |#2|) |#2|) 61)) (-2356 (((-638 |#2|) |#2| (-769)) 62)) (-4304 (((-424 |#2|) |#2|) 59))) 
-(((-347 |#1| |#2|) (-10 -7 (-15 -2602 ((-638 |#2|) |#2|)) (-15 -2356 ((-638 |#2|) |#2| (-769))) (-15 -4304 ((-424 |#2|) |#2|)) (-15 -4353 ((-424 |#2|) |#2|)) (-15 -2088 ((-424 |#2|) |#2|)) (-15 -4452 ((-121) |#2|))) (-353) (-1234 |#1|)) (T -347)) 
-((-4452 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4)))) (-2088 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4)))) (-4353 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4)))) (-4304 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4)))) (-2356 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-353)) (-5 *2 (-638 *3)) (-5 *1 (-347 *5 *3)) (-4 *3 (-1234 *5)))) (-2602 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-638 *3)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -2602 ((-638 |#2|) |#2|)) (-15 -2356 ((-638 |#2|) |#2| (-769))) (-15 -4304 ((-424 |#2|) |#2|)) (-15 -4353 ((-424 |#2|) |#2|)) (-15 -2088 ((-424 |#2|) |#2|)) (-15 -4452 ((-121) |#2|))) 
-((-4557 (((-1150 (-685 (-1166 |#1|))) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#3|) (-769) (-769)) 54) (((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#3|) (-638 (-769))) 42))) 
-(((-348 |#1| |#2| |#3|) (-10 -7 (-15 -4557 ((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#3|) (-638 (-769)))) (-15 -4557 ((-1150 (-685 (-1166 |#1|))) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#3|) (-769) (-769)))) (-13 (-562) (-457)) (-326 |#1| (-769)) (-326 (-413 |#1|) (-769))) (T -348)) 
-((-4557 (*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-638 *7)) (-5 *4 (-1 *7 (-769) (-769) *8)) (-5 *5 (-1259 *9)) (-5 *6 (-769)) (-4 *7 (-13 (-562) (-457))) (-4 *8 (-326 *7 *6)) (-4 *9 (-326 (-413 *7) *6)) (-5 *2 (-1150 (-685 (-1166 *7)))) (-5 *1 (-348 *7 *8 *9)))) (-4557 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 *7)) (-5 *4 (-1 *7 (-769) (-769) *8)) (-5 *5 (-1259 *9)) (-5 *6 (-638 (-769))) (-4 *7 (-13 (-562) (-457))) (-4 *8 (-326 *7 (-769))) (-4 *9 (-326 (-413 *7) (-769))) (-5 *2 (-685 (-1166 *7))) (-5 *1 (-348 *7 *8 *9))))) 
-(-10 -7 (-15 -4557 ((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#3|) (-638 (-769)))) (-15 -4557 ((-1150 (-685 (-1166 |#1|))) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#3|) (-769) (-769)))) 
-((-1853 (((-638 |#1|) |#1| (-769)) 21)) (-2617 ((|#1| |#1| (-769) (-769) |#2|) 20)) (-4435 (((-413 (-1166 |#1|)) (-638 (-413 |#1|)) (-638 (-413 |#1|)) (-769)) 75) (((-413 (-1166 |#1|)) (-638 |#1|) (-638 |#1|) (-769)) 68)) (-4557 (((-1150 (-685 (-1166 |#1|))) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-769) (-769)) 62) (((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-638 (-769))) 44)) (-2489 ((|#1| (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-769) (-1259 (-1166 |#1|))) 37)) (-3233 (((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-1259 (-1166 |#1|))) (-638 (-769))) 43)) (-2680 (((-638 |#1|) (-769)) 17)) (-1798 ((|#1| (-769) (-769) |#2|) 11)) (-4197 (((-638 |#1|) (-769)) 24)) (-2035 ((|#1| (-769) (-769) |#2|) 22))) 
-(((-349 |#1| |#2|) (-10 -7 (-15 -3233 ((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-1259 (-1166 |#1|))) (-638 (-769)))) (-15 -4435 ((-413 (-1166 |#1|)) (-638 |#1|) (-638 |#1|) (-769))) (-15 -4435 ((-413 (-1166 |#1|)) (-638 (-413 |#1|)) (-638 (-413 |#1|)) (-769))) (-15 -4557 ((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-638 (-769)))) (-15 -4557 ((-1150 (-685 (-1166 |#1|))) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-769) (-769))) (-15 -2489 (|#1| (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-769) (-1259 (-1166 |#1|)))) (-15 -1798 (|#1| (-769) (-769) |#2|)) (-15 -2680 ((-638 |#1|) (-769))) (-15 -2035 (|#1| (-769) (-769) |#2|)) (-15 -4197 ((-638 |#1|) (-769))) (-15 -2617 (|#1| |#1| (-769) (-769) |#2|)) (-15 -1853 ((-638 |#1|) |#1| (-769)))) (-13 (-562) (-457)) (-52 |#1| (-769))) (T -349)) 
-((-1853 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *3 (-13 (-562) (-457))) (-5 *2 (-638 *3)) (-5 *1 (-349 *3 *5)) (-4 *5 (-52 *3 *4)))) (-2617 (*1 *2 *2 *3 *3 *4) (-12 (-5 *3 (-769)) (-4 *2 (-13 (-562) (-457))) (-5 *1 (-349 *2 *4)) (-4 *4 (-52 *2 *3)))) (-4197 (*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-562) (-457))) (-5 *2 (-638 *4)) (-5 *1 (-349 *4 *5)) (-4 *5 (-52 *4 *3)))) (-2035 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-769)) (-4 *2 (-13 (-562) (-457))) (-5 *1 (-349 *2 *4)) (-4 *4 (-52 *2 *3)))) (-2680 (*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-562) (-457))) (-5 *2 (-638 *4)) (-5 *1 (-349 *4 *5)) (-4 *5 (-52 *4 *3)))) (-1798 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-769)) (-4 *2 (-13 (-562) (-457))) (-5 *1 (-349 *2 *4)) (-4 *4 (-52 *2 *3)))) (-2489 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *2 (-769) (-769) *7)) (-5 *4 (-1259 *7)) (-5 *5 (-769)) (-5 *6 (-1259 (-1166 *2))) (-4 *7 (-52 *2 *5)) (-4 *2 (-13 (-562) (-457))) (-5 *1 (-349 *2 *7)))) (-4557 (*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-638 *7)) (-5 *4 (-1 *7 (-769) (-769) *8)) (-5 *5 (-1259 *8)) (-5 *6 (-769)) (-4 *7 (-13 (-562) (-457))) (-4 *8 (-52 *7 *6)) (-5 *2 (-1150 (-685 (-1166 *7)))) (-5 *1 (-349 *7 *8)))) (-4557 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 *7)) (-5 *4 (-1 *7 (-769) (-769) *8)) (-5 *5 (-1259 *8)) (-5 *6 (-638 (-769))) (-4 *7 (-13 (-562) (-457))) (-4 *8 (-52 *7 (-769))) (-5 *2 (-685 (-1166 *7))) (-5 *1 (-349 *7 *8)))) (-4435 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 (-413 *5))) (-4 *5 (-13 (-562) (-457))) (-5 *4 (-769)) (-5 *2 (-413 (-1166 *5))) (-5 *1 (-349 *5 *6)) (-4 *6 (-52 *5 *4)))) (-4435 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 *5)) (-4 *5 (-13 (-562) (-457))) (-5 *4 (-769)) (-5 *2 (-413 (-1166 *5))) (-5 *1 (-349 *5 *6)) (-4 *6 (-52 *5 *4)))) (-3233 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *6)) (-5 *4 (-1 *6 (-769) (-1259 (-1166 *6)))) (-5 *5 (-638 (-769))) (-4 *6 (-13 (-562) (-457))) (-5 *2 (-685 (-1166 *6))) (-5 *1 (-349 *6 *7)) (-4 *7 (-52 *6 (-769)))))) 
-(-10 -7 (-15 -3233 ((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-1259 (-1166 |#1|))) (-638 (-769)))) (-15 -4435 ((-413 (-1166 |#1|)) (-638 |#1|) (-638 |#1|) (-769))) (-15 -4435 ((-413 (-1166 |#1|)) (-638 (-413 |#1|)) (-638 (-413 |#1|)) (-769))) (-15 -4557 ((-685 (-1166 |#1|)) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-638 (-769)))) (-15 -4557 ((-1150 (-685 (-1166 |#1|))) (-638 |#1|) (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-769) (-769))) (-15 -2489 (|#1| (-1 |#1| (-769) (-769) |#2|) (-1259 |#2|) (-769) (-1259 (-1166 |#1|)))) (-15 -1798 (|#1| (-769) (-769) |#2|)) (-15 -2680 ((-638 |#1|) (-769))) (-15 -2035 (|#1| (-769) (-769) |#2|)) (-15 -4197 ((-638 |#1|) (-769))) (-15 -2617 (|#1| |#1| (-769) (-769) |#2|)) (-15 -1853 ((-638 |#1|) |#1| (-769)))) 
-((-4473 (((-769) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116)))))) 40)) (-3612 (((-965 (-1116)) (-1166 |#1|)) 84)) (-3214 (((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) (-1166 |#1|)) 77)) (-1527 (((-685 |#1|) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116)))))) 85)) (-1579 (((-3 (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) "failed") (-923)) 10)) (-2321 (((-3 (-1166 |#1|) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116)))))) (-923)) 15))) 
-(((-350 |#1|) (-10 -7 (-15 -3612 ((-965 (-1116)) (-1166 |#1|))) (-15 -3214 ((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) (-1166 |#1|))) (-15 -1527 ((-685 |#1|) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (-15 -4473 ((-769) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (-15 -1579 ((-3 (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) "failed") (-923))) (-15 -2321 ((-3 (-1166 |#1|) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116)))))) (-923)))) (-353)) (T -350)) 
-((-2321 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-3 (-1166 *4) (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116))))))) (-5 *1 (-350 *4)) (-4 *4 (-353)))) (-1579 (*1 *2 *3) (|partial| -12 (-5 *3 (-923)) (-5 *2 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-5 *1 (-350 *4)) (-4 *4 (-353)))) (-4473 (*1 *2 *3) (-12 (-5 *3 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-4 *4 (-353)) (-5 *2 (-769)) (-5 *1 (-350 *4)))) (-1527 (*1 *2 *3) (-12 (-5 *3 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-4 *4 (-353)) (-5 *2 (-685 *4)) (-5 *1 (-350 *4)))) (-3214 (*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-5 *2 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-5 *1 (-350 *4)))) (-3612 (*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-5 *2 (-965 (-1116))) (-5 *1 (-350 *4))))) 
-(-10 -7 (-15 -3612 ((-965 (-1116)) (-1166 |#1|))) (-15 -3214 ((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) (-1166 |#1|))) (-15 -1527 ((-685 |#1|) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (-15 -4473 ((-769) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (-15 -1579 ((-3 (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) "failed") (-923))) (-15 -2321 ((-3 (-1166 |#1|) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116)))))) (-923)))) 
-((-3972 ((|#1| |#3|) 84) ((|#3| |#1|) 68))) 
-(((-351 |#1| |#2| |#3|) (-10 -7 (-15 -3972 (|#3| |#1|)) (-15 -3972 (|#1| |#3|))) (-329 |#2|) (-353) (-329 |#2|)) (T -351)) 
-((-3972 (*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *2 (-329 *4)) (-5 *1 (-351 *2 *4 *3)) (-4 *3 (-329 *4)))) (-3972 (*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *2 (-329 *4)) (-5 *1 (-351 *3 *4 *2)) (-4 *3 (-329 *4))))) 
-(-10 -7 (-15 -3972 (|#3| |#1|)) (-15 -3972 (|#1| |#3|))) 
-((-1297 (((-121) $) 50)) (-3377 (((-834 (-923)) $) 21) (((-923) $) 51)) (-3961 (((-3 $ "failed") $) 16)) (-1773 (($) 9)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 91)) (-3158 (((-3 (-769) "failed") $ $) 70) (((-769) $) 59)) (-3139 (($ $ (-769)) NIL) (($ $) 8)) (-2278 (($) 44)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 33)) (-2779 (((-3 $ "failed") $) 39) (($ $) 38))) 
-(((-352 |#1|) (-10 -8 (-15 -3377 ((-923) |#1|)) (-15 -3158 ((-769) |#1|)) (-15 -1297 ((-121) |#1|)) (-15 -2278 (|#1|)) (-15 -1696 ((-3 (-1259 |#1|) "failed") (-685 |#1|))) (-15 -2779 (|#1| |#1|)) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -1773 (|#1|)) (-15 -3961 ((-3 |#1| "failed") |#1|)) (-15 -3158 ((-3 (-769) "failed") |#1| |#1|)) (-15 -3377 ((-834 (-923)) |#1|)) (-15 -2779 ((-3 |#1| "failed") |#1|)) (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|)))) (-353)) (T -352)) 
-NIL 
-(-10 -8 (-15 -3377 ((-923) |#1|)) (-15 -3158 ((-769) |#1|)) (-15 -1297 ((-121) |#1|)) (-15 -2278 (|#1|)) (-15 -1696 ((-3 (-1259 |#1|) "failed") (-685 |#1|))) (-15 -2779 (|#1| |#1|)) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -1773 (|#1|)) (-15 -3961 ((-3 |#1| "failed") |#1|)) (-15 -3158 ((-3 (-769) "failed") |#1| |#1|)) (-15 -3377 ((-834 (-923)) |#1|)) (-15 -2779 ((-3 |#1| "failed") |#1|)) (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-3617 (((-1178 (-923) (-769)) (-572)) 88)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-1685 (((-769)) 98)) (-2211 (($) 16 T CONST)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 82)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-3286 (($) 101)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-2754 (($) 86)) (-1297 (((-121) $) 85)) (-4486 (($ $) 75) (($ $ (-769)) 74)) (-1526 (((-121) $) 69)) (-3377 (((-834 (-923)) $) 77) (((-923) $) 83)) (-3893 (((-121) $) 30)) (-3961 (((-3 $ "failed") $) 97)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-3633 (((-923) $) 100)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-1773 (($) 96 T CONST)) (-1763 (($ (-923)) 99)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 89)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-3587 (((-638 $)) 102)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3158 (((-3 (-769) "failed") $ $) 76) (((-769) $) 84)) (-3139 (($ $ (-769)) 94) (($ $) 92)) (-2278 (($) 87)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 90)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63)) (-2779 (((-3 $ "failed") $) 78) (($ $) 91)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-769)) 95) (($ $) 93)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64))) 
-(((-353) (-1290)) (T -353)) 
-((-2779 (*1 *1 *1) (-4 *1 (-353))) (-1696 (*1 *2 *3) (|partial| -12 (-5 *3 (-685 *1)) (-4 *1 (-353)) (-5 *2 (-1259 *1)))) (-2503 (*1 *2) (-12 (-4 *1 (-353)) (-5 *2 (-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))))) (-3617 (*1 *2 *3) (-12 (-4 *1 (-353)) (-5 *3 (-572)) (-5 *2 (-1178 (-923) (-769))))) (-2278 (*1 *1) (-4 *1 (-353))) (-2754 (*1 *1) (-4 *1 (-353))) (-1297 (*1 *2 *1) (-12 (-4 *1 (-353)) (-5 *2 (-121)))) (-3158 (*1 *2 *1) (-12 (-4 *1 (-353)) (-5 *2 (-769)))) (-3377 (*1 *2 *1) (-12 (-4 *1 (-353)) (-5 *2 (-923)))) (-1317 (*1 *2) (-12 (-4 *1 (-353)) (-5 *2 (-3 "prime" "polynomial" "normal" "cyclic"))))) 
-(-13 (-408) (-374) (-1144) (-227) (-10 -8 (-15 -2779 ($ $)) (-15 -1696 ((-3 (-1259 $) "failed") (-685 $))) (-15 -2503 ((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572)))))) (-15 -3617 ((-1178 (-923) (-769)) (-572))) (-15 -2278 ($)) (-15 -2754 ($)) (-15 -1297 ((-121) $)) (-15 -3158 ((-769) $)) (-15 -3377 ((-923) $)) (-15 -1317 ((-3 "prime" "polynomial" "normal" "cyclic"))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-149) . T) ((-612 (-856)) . T) ((-174) . T) ((-227) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-408) . T) ((-374) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) . T) ((-1214) . T)) 
-((-4122 (((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) |#1|) 51)) (-1778 (((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|)))) 49))) 
-(((-354 |#1| |#2| |#3|) (-10 -7 (-15 -1778 ((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))))) (-15 -4122 ((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) |#1|))) (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $)))) (-1234 |#1|) (-415 |#1| |#2|)) (T -354)) 
-((-4122 (*1 *2 *3) (-12 (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-354 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) (-1778 (*1 *2) (-12 (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-354 *3 *4 *5)) (-4 *5 (-415 *3 *4))))) 
-(-10 -7 (-15 -1778 ((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))))) (-15 -4122 ((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 (((-911 |#1|) $) NIL) (($ $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| (-911 |#1|) (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4473 (((-769)) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL (|has| (-911 |#1|) (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-911 |#1|) "failed") $) NIL)) (-1318 (((-911 |#1|) $) NIL)) (-4337 (($ (-1259 (-911 |#1|))) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-911 |#1|) (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-911 |#1|) (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL (|has| (-911 |#1|) (-374)))) (-1297 (((-121) $) NIL (|has| (-911 |#1|) (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374)))) (($ $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| (-911 |#1|) (-374))) (((-834 (-923)) $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) NIL (|has| (-911 |#1|) (-374)))) (-3880 (((-121) $) NIL (|has| (-911 |#1|) (-374)))) (-4429 (((-911 |#1|) $) NIL) (($ $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| (-911 |#1|) (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 (-911 |#1|)) $) NIL) (((-1166 $) $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3633 (((-923) $) NIL (|has| (-911 |#1|) (-374)))) (-4064 (((-1166 (-911 |#1|)) $) NIL (|has| (-911 |#1|) (-374)))) (-4484 (((-1166 (-911 |#1|)) $) NIL (|has| (-911 |#1|) (-374))) (((-3 (-1166 (-911 |#1|)) "failed") $ $) NIL (|has| (-911 |#1|) (-374)))) (-2359 (($ $ (-1166 (-911 |#1|))) NIL (|has| (-911 |#1|) (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-911 |#1|) (-374)) CONST)) (-1763 (($ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-2315 (((-1259 (-638 (-2 (|:| -2148 (-911 |#1|)) (|:| -1763 (-1116)))))) NIL)) (-4522 (((-685 (-911 |#1|))) NIL)) (-2307 (($) NIL (|has| (-911 |#1|) (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| (-911 |#1|) (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| (-911 |#1|) (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| (-911 |#1|) (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-2830 (((-1166 (-911 |#1|))) NIL)) (-2278 (($) NIL (|has| (-911 |#1|) (-374)))) (-3627 (($) NIL (|has| (-911 |#1|) (-374)))) (-3160 (((-1259 (-911 |#1|)) $) NIL) (((-685 (-911 |#1|)) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| (-911 |#1|) (-374)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-911 |#1|)) NIL)) (-2779 (($ $) NIL (|has| (-911 |#1|) (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL) (((-1259 $) (-923)) NIL)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-2611 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-1557 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL) (($ $ (-911 |#1|)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ (-911 |#1|)) NIL) (($ (-911 |#1|) $) NIL))) 
-(((-355 |#1| |#2|) (-13 (-329 (-911 |#1|)) (-10 -7 (-15 -2315 ((-1259 (-638 (-2 (|:| -2148 (-911 |#1|)) (|:| -1763 (-1116))))))) (-15 -4522 ((-685 (-911 |#1|)))) (-15 -4473 ((-769))))) (-923) (-923)) (T -355)) 
-((-2315 (*1 *2) (-12 (-5 *2 (-1259 (-638 (-2 (|:| -2148 (-911 *3)) (|:| -1763 (-1116)))))) (-5 *1 (-355 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) (-4522 (*1 *2) (-12 (-5 *2 (-685 (-911 *3))) (-5 *1 (-355 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) (-4473 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-355 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923))))) 
-(-13 (-329 (-911 |#1|)) (-10 -7 (-15 -2315 ((-1259 (-638 (-2 (|:| -2148 (-911 |#1|)) (|:| -1763 (-1116))))))) (-15 -4522 ((-685 (-911 |#1|)))) (-15 -4473 ((-769))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 74)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 ((|#1| $) 92) (($ $ (-923)) 90 (|has| |#1| (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) 148 (|has| |#1| (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4473 (((-769)) 89)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) 162 (|has| |#1| (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 111)) (-1318 ((|#1| $) 91)) (-4337 (($ (-1259 |#1|)) 57)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 187 (|has| |#1| (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) 158 (|has| |#1| (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) 149 (|has| |#1| (-374)))) (-1297 (((-121) $) NIL (|has| |#1| (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374)))) (($ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| |#1| (-374))) (((-834 (-923)) $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) 97 (|has| |#1| (-374)))) (-3880 (((-121) $) 175 (|has| |#1| (-374)))) (-4429 ((|#1| $) 94) (($ $ (-923)) 93 (|has| |#1| (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 |#1|) $) 188) (((-1166 $) $ (-923)) NIL (|has| |#1| (-374)))) (-3633 (((-923) $) 133 (|has| |#1| (-374)))) (-4064 (((-1166 |#1|) $) 73 (|has| |#1| (-374)))) (-4484 (((-1166 |#1|) $) 70 (|has| |#1| (-374))) (((-3 (-1166 |#1|) "failed") $ $) 82 (|has| |#1| (-374)))) (-2359 (($ $ (-1166 |#1|)) 69 (|has| |#1| (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 191)) (-1773 (($) NIL (|has| |#1| (-374)) CONST)) (-1763 (($ (-923)) 136 (|has| |#1| (-374)))) (-1336 (((-121) $) 107)) (-2607 (((-1116) $) NIL)) (-2315 (((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116)))))) 83)) (-4522 (((-685 |#1|)) 87)) (-2307 (($) 96 (|has| |#1| (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 150 (|has| |#1| (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) 151)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| |#1| (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) 62)) (-2830 (((-1166 |#1|)) 152)) (-2278 (($) 132 (|has| |#1| (-374)))) (-3627 (($) NIL (|has| |#1| (-374)))) (-3160 (((-1259 |#1|) $) 105) (((-685 |#1|) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| |#1| (-374)))) (-3972 (((-856) $) 123) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) 56)) (-2779 (($ $) NIL (|has| |#1| (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2140 (((-769)) 156)) (-2237 (((-1259 $)) 172) (((-1259 $) (-923)) 100)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 30 T CONST)) (-3255 (($) 22 T CONST)) (-2611 (($ $) 106 (|has| |#1| (-374))) (($ $ (-769)) 98 (|has| |#1| (-374)))) (-1557 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1324 (((-121) $ $) 60)) (-1379 (($ $ $) 103) (($ $ |#1|) 104)) (-1373 (($ $) 177) (($ $ $) 181)) (-1367 (($ $ $) 179)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 137)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 185) (($ $ $) 142) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 102))) 
-(((-356 |#1| |#2|) (-13 (-329 |#1|) (-10 -7 (-15 -2315 ((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (-15 -4522 ((-685 |#1|))) (-15 -4473 ((-769))))) (-353) (-3 (-1166 |#1|) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (T -356)) 
-((-2315 (*1 *2) (-12 (-5 *2 (-1259 (-638 (-2 (|:| -2148 *3) (|:| -1763 (-1116)))))) (-5 *1 (-356 *3 *4)) (-4 *3 (-353)) (-14 *4 (-3 (-1166 *3) *2)))) (-4522 (*1 *2) (-12 (-5 *2 (-685 *3)) (-5 *1 (-356 *3 *4)) (-4 *3 (-353)) (-14 *4 (-3 (-1166 *3) (-1259 (-638 (-2 (|:| -2148 *3) (|:| -1763 (-1116))))))))) (-4473 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-356 *3 *4)) (-4 *3 (-353)) (-14 *4 (-3 (-1166 *3) (-1259 (-638 (-2 (|:| -2148 *3) (|:| -1763 (-1116)))))))))) 
-(-13 (-329 |#1|) (-10 -7 (-15 -2315 ((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (-15 -4522 ((-685 |#1|))) (-15 -4473 ((-769))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| |#1| (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4473 (((-769)) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL (|has| |#1| (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-4337 (($ (-1259 |#1|)) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| |#1| (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL (|has| |#1| (-374)))) (-1297 (((-121) $) NIL (|has| |#1| (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374)))) (($ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| |#1| (-374))) (((-834 (-923)) $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) NIL (|has| |#1| (-374)))) (-3880 (((-121) $) NIL (|has| |#1| (-374)))) (-4429 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 |#1|) $) NIL) (((-1166 $) $ (-923)) NIL (|has| |#1| (-374)))) (-3633 (((-923) $) NIL (|has| |#1| (-374)))) (-4064 (((-1166 |#1|) $) NIL (|has| |#1| (-374)))) (-4484 (((-1166 |#1|) $) NIL (|has| |#1| (-374))) (((-3 (-1166 |#1|) "failed") $ $) NIL (|has| |#1| (-374)))) (-2359 (($ $ (-1166 |#1|)) NIL (|has| |#1| (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| |#1| (-374)) CONST)) (-1763 (($ (-923)) NIL (|has| |#1| (-374)))) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-2315 (((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116)))))) NIL)) (-4522 (((-685 |#1|)) NIL)) (-2307 (($) NIL (|has| |#1| (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| |#1| (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| |#1| (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-2830 (((-1166 |#1|)) NIL)) (-2278 (($) NIL (|has| |#1| (-374)))) (-3627 (($) NIL (|has| |#1| (-374)))) (-3160 (((-1259 |#1|) $) NIL) (((-685 |#1|) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| |#1| (-374)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) NIL)) (-2779 (($ $) NIL (|has| |#1| (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL) (((-1259 $) (-923)) NIL)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-2611 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1557 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-357 |#1| |#2|) (-13 (-329 |#1|) (-10 -7 (-15 -2315 ((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (-15 -4522 ((-685 |#1|))) (-15 -4473 ((-769))))) (-353) (-923)) (T -357)) 
-((-2315 (*1 *2) (-12 (-5 *2 (-1259 (-638 (-2 (|:| -2148 *3) (|:| -1763 (-1116)))))) (-5 *1 (-357 *3 *4)) (-4 *3 (-353)) (-14 *4 (-923)))) (-4522 (*1 *2) (-12 (-5 *2 (-685 *3)) (-5 *1 (-357 *3 *4)) (-4 *3 (-353)) (-14 *4 (-923)))) (-4473 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-357 *3 *4)) (-4 *3 (-353)) (-14 *4 (-923))))) 
-(-13 (-329 |#1|) (-10 -7 (-15 -2315 ((-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))))) (-15 -4522 ((-685 |#1|))) (-15 -4473 ((-769))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 (((-911 |#1|) $) NIL) (($ $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| (-911 |#1|) (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL (|has| (-911 |#1|) (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-911 |#1|) "failed") $) NIL)) (-1318 (((-911 |#1|) $) NIL)) (-4337 (($ (-1259 (-911 |#1|))) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-911 |#1|) (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-911 |#1|) (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL (|has| (-911 |#1|) (-374)))) (-1297 (((-121) $) NIL (|has| (-911 |#1|) (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374)))) (($ $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| (-911 |#1|) (-374))) (((-834 (-923)) $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) NIL (|has| (-911 |#1|) (-374)))) (-3880 (((-121) $) NIL (|has| (-911 |#1|) (-374)))) (-4429 (((-911 |#1|) $) NIL) (($ $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| (-911 |#1|) (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 (-911 |#1|)) $) NIL) (((-1166 $) $ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-3633 (((-923) $) NIL (|has| (-911 |#1|) (-374)))) (-4064 (((-1166 (-911 |#1|)) $) NIL (|has| (-911 |#1|) (-374)))) (-4484 (((-1166 (-911 |#1|)) $) NIL (|has| (-911 |#1|) (-374))) (((-3 (-1166 (-911 |#1|)) "failed") $ $) NIL (|has| (-911 |#1|) (-374)))) (-2359 (($ $ (-1166 (-911 |#1|))) NIL (|has| (-911 |#1|) (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-911 |#1|) (-374)) CONST)) (-1763 (($ (-923)) NIL (|has| (-911 |#1|) (-374)))) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-2307 (($) NIL (|has| (-911 |#1|) (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| (-911 |#1|) (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| (-911 |#1|) (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| (-911 |#1|) (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-2830 (((-1166 (-911 |#1|))) NIL)) (-2278 (($) NIL (|has| (-911 |#1|) (-374)))) (-3627 (($) NIL (|has| (-911 |#1|) (-374)))) (-3160 (((-1259 (-911 |#1|)) $) NIL) (((-685 (-911 |#1|)) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| (-911 |#1|) (-374)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-911 |#1|)) NIL)) (-2779 (($ $) NIL (|has| (-911 |#1|) (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| (-911 |#1|) (-149)) (|has| (-911 |#1|) (-374))))) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL) (((-1259 $) (-923)) NIL)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-2611 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-1557 (($ $) NIL (|has| (-911 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-911 |#1|) (-374)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL) (($ $ (-911 |#1|)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ (-911 |#1|)) NIL) (($ (-911 |#1|) $) NIL))) 
-(((-358 |#1| |#2|) (-329 (-911 |#1|)) (-923) (-923)) (T -358)) 
-NIL 
-(-329 (-911 |#1|)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) 119 (|has| |#1| (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) 138 (|has| |#1| (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 91)) (-1318 ((|#1| $) 88)) (-4337 (($ (-1259 |#1|)) 83)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 115 (|has| |#1| (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) 80 (|has| |#1| (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) 39 (|has| |#1| (-374)))) (-1297 (((-121) $) NIL (|has| |#1| (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374)))) (($ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| |#1| (-374))) (((-834 (-923)) $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) 120 (|has| |#1| (-374)))) (-3880 (((-121) $) 72 (|has| |#1| (-374)))) (-4429 ((|#1| $) 38) (($ $ (-923)) 40 (|has| |#1| (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 |#1|) $) 62) (((-1166 $) $ (-923)) NIL (|has| |#1| (-374)))) (-3633 (((-923) $) 95 (|has| |#1| (-374)))) (-4064 (((-1166 |#1|) $) NIL (|has| |#1| (-374)))) (-4484 (((-1166 |#1|) $) NIL (|has| |#1| (-374))) (((-3 (-1166 |#1|) "failed") $ $) NIL (|has| |#1| (-374)))) (-2359 (($ $ (-1166 |#1|)) NIL (|has| |#1| (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| |#1| (-374)) CONST)) (-1763 (($ (-923)) 93 (|has| |#1| (-374)))) (-1336 (((-121) $) 140)) (-2607 (((-1116) $) NIL)) (-2307 (($) 35 (|has| |#1| (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 113 (|has| |#1| (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) 137)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| |#1| (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) 56)) (-2830 (((-1166 |#1|)) 86)) (-2278 (($) 125 (|has| |#1| (-374)))) (-3627 (($) NIL (|has| |#1| (-374)))) (-3160 (((-1259 |#1|) $) 50) (((-685 |#1|) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| |#1| (-374)))) (-3972 (((-856) $) 136) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) 85)) (-2779 (($ $) NIL (|has| |#1| (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2140 (((-769)) 142)) (-2237 (((-1259 $)) 107) (((-1259 $) (-923)) 46)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 109 T CONST)) (-3255 (($) 31 T CONST)) (-2611 (($ $) 65 (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1557 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1324 (((-121) $ $) 105)) (-1379 (($ $ $) 97) (($ $ |#1|) 98)) (-1373 (($ $) 78) (($ $ $) 103)) (-1367 (($ $ $) 101)) (** (($ $ (-923)) NIL) (($ $ (-769)) 41) (($ $ (-572)) 128)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 76) (($ $ $) 53) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 74))) 
-(((-359 |#1| |#2|) (-329 |#1|) (-353) (-1166 |#1|)) (T -359)) 
-NIL 
-(-329 |#1|) 
-((-1566 ((|#1| (-1166 |#2|)) 51))) 
-(((-360 |#1| |#2|) (-10 -7 (-15 -1566 (|#1| (-1166 |#2|)))) (-13 (-408) (-10 -7 (-15 -3972 (|#1| |#2|)) (-15 -3633 ((-923) |#1|)) (-15 -2237 ((-1259 |#1|) (-923))) (-15 -2611 (|#1| |#1|)))) (-353)) (T -360)) 
-((-1566 (*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-4 *2 (-13 (-408) (-10 -7 (-15 -3972 (*2 *4)) (-15 -3633 ((-923) *2)) (-15 -2237 ((-1259 *2) (-923))) (-15 -2611 (*2 *2))))) (-5 *1 (-360 *2 *4))))) 
-(-10 -7 (-15 -1566 (|#1| (-1166 |#2|)))) 
-((-3926 (((-965 (-1166 |#1|)) (-1166 |#1|)) 36)) (-3286 (((-1166 |#1|) (-923) (-923)) 109) (((-1166 |#1|) (-923)) 108)) (-1297 (((-121) (-1166 |#1|)) 81)) (-1995 (((-923) (-923)) 71)) (-3843 (((-923) (-923)) 73)) (-3244 (((-923) (-923)) 69)) (-3880 (((-121) (-1166 |#1|)) 85)) (-2044 (((-3 (-1166 |#1|) "failed") (-1166 |#1|)) 97)) (-4235 (((-3 (-1166 |#1|) "failed") (-1166 |#1|)) 100)) (-2484 (((-3 (-1166 |#1|) "failed") (-1166 |#1|)) 99)) (-3942 (((-3 (-1166 |#1|) "failed") (-1166 |#1|)) 98)) (-3752 (((-3 (-1166 |#1|) "failed") (-1166 |#1|)) 94)) (-1619 (((-1166 |#1|) (-1166 |#1|)) 62)) (-2700 (((-1166 |#1|) (-923)) 103)) (-2576 (((-1166 |#1|) (-923)) 106)) (-1907 (((-1166 |#1|) (-923)) 105)) (-4305 (((-1166 |#1|) (-923)) 104)) (-2286 (((-1166 |#1|) (-923)) 101))) 
-(((-361 |#1|) (-10 -7 (-15 -1297 ((-121) (-1166 |#1|))) (-15 -3880 ((-121) (-1166 |#1|))) (-15 -3244 ((-923) (-923))) (-15 -1995 ((-923) (-923))) (-15 -3843 ((-923) (-923))) (-15 -2286 ((-1166 |#1|) (-923))) (-15 -2700 ((-1166 |#1|) (-923))) (-15 -4305 ((-1166 |#1|) (-923))) (-15 -1907 ((-1166 |#1|) (-923))) (-15 -2576 ((-1166 |#1|) (-923))) (-15 -3752 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -2044 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -3942 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -2484 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -4235 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -3286 ((-1166 |#1|) (-923))) (-15 -3286 ((-1166 |#1|) (-923) (-923))) (-15 -1619 ((-1166 |#1|) (-1166 |#1|))) (-15 -3926 ((-965 (-1166 |#1|)) (-1166 |#1|)))) (-353)) (T -361)) 
-((-3926 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-965 (-1166 *4))) (-5 *1 (-361 *4)) (-5 *3 (-1166 *4)))) (-1619 (*1 *2 *2) (-12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3)))) (-3286 (*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) (-3286 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) (-4235 (*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3)))) (-2484 (*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3)))) (-3942 (*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3)))) (-2044 (*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3)))) (-3752 (*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3)))) (-2576 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) (-1907 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) (-4305 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) (-2700 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) (-2286 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) (-3843 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-361 *3)) (-4 *3 (-353)))) (-1995 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-361 *3)) (-4 *3 (-353)))) (-3244 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-361 *3)) (-4 *3 (-353)))) (-3880 (*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-361 *4)))) (-1297 (*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-361 *4))))) 
-(-10 -7 (-15 -1297 ((-121) (-1166 |#1|))) (-15 -3880 ((-121) (-1166 |#1|))) (-15 -3244 ((-923) (-923))) (-15 -1995 ((-923) (-923))) (-15 -3843 ((-923) (-923))) (-15 -2286 ((-1166 |#1|) (-923))) (-15 -2700 ((-1166 |#1|) (-923))) (-15 -4305 ((-1166 |#1|) (-923))) (-15 -1907 ((-1166 |#1|) (-923))) (-15 -2576 ((-1166 |#1|) (-923))) (-15 -3752 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -2044 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -3942 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -2484 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -4235 ((-3 (-1166 |#1|) "failed") (-1166 |#1|))) (-15 -3286 ((-1166 |#1|) (-923))) (-15 -3286 ((-1166 |#1|) (-923) (-923))) (-15 -1619 ((-1166 |#1|) (-1166 |#1|))) (-15 -3926 ((-965 (-1166 |#1|)) (-1166 |#1|)))) 
-((-2462 (((-3 (-638 |#3|) "failed") (-638 |#3|) |#3|) 33))) 
-(((-362 |#1| |#2| |#3|) (-10 -7 (-15 -2462 ((-3 (-638 |#3|) "failed") (-638 |#3|) |#3|))) (-353) (-1234 |#1|) (-1234 |#2|)) (T -362)) 
-((-2462 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-353)) (-5 *1 (-362 *4 *5 *3))))) 
-(-10 -7 (-15 -2462 ((-3 (-638 |#3|) "failed") (-638 |#3|) |#3|))) 
-((-3913 (((-424 |#2|) |#2|) 46)) (-4408 (((-424 |#2|) |#2|) 36))) 
-(((-363 |#1| |#2|) (-10 -7 (-15 -4408 ((-424 |#2|) |#2|)) (-15 -3913 ((-424 |#2|) |#2|))) (-353) (-1234 |#1|)) (T -363)) 
-((-3913 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-363 *4 *3)) (-4 *3 (-1234 *4)))) (-4408 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-363 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -4408 ((-424 |#2|) |#2|)) (-15 -3913 ((-424 |#2|) |#2|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| |#1| (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL (|has| |#1| (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-4337 (($ (-1259 |#1|)) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| |#1| (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL (|has| |#1| (-374)))) (-1297 (((-121) $) NIL (|has| |#1| (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374)))) (($ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| |#1| (-374))) (((-834 (-923)) $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) NIL (|has| |#1| (-374)))) (-3880 (((-121) $) NIL (|has| |#1| (-374)))) (-4429 ((|#1| $) NIL) (($ $ (-923)) NIL (|has| |#1| (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 |#1|) $) NIL) (((-1166 $) $ (-923)) NIL (|has| |#1| (-374)))) (-3633 (((-923) $) NIL (|has| |#1| (-374)))) (-4064 (((-1166 |#1|) $) NIL (|has| |#1| (-374)))) (-4484 (((-1166 |#1|) $) NIL (|has| |#1| (-374))) (((-3 (-1166 |#1|) "failed") $ $) NIL (|has| |#1| (-374)))) (-2359 (($ $ (-1166 |#1|)) NIL (|has| |#1| (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| |#1| (-374)) CONST)) (-1763 (($ (-923)) NIL (|has| |#1| (-374)))) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-2307 (($) NIL (|has| |#1| (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| |#1| (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| |#1| (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-2830 (((-1166 |#1|)) NIL)) (-2278 (($) NIL (|has| |#1| (-374)))) (-3627 (($) NIL (|has| |#1| (-374)))) (-3160 (((-1259 |#1|) $) NIL) (((-685 |#1|) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| |#1| (-374)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) NIL)) (-2779 (($ $) NIL (|has| |#1| (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL) (((-1259 $) (-923)) NIL)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-2611 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1557 (($ $) NIL (|has| |#1| (-374))) (($ $ (-769)) NIL (|has| |#1| (-374)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-364 |#1| |#2|) (-329 |#1|) (-353) (-923)) (T -364)) 
-NIL 
-(-329 |#1|) 
-((-2414 (((-121) (-638 (-959 |#1|))) 31)) (-3604 (((-638 (-959 |#1|)) (-638 (-959 |#1|))) 42)) (-1623 (((-3 (-638 (-959 |#1|)) "failed") (-638 (-959 |#1|))) 38))) 
-(((-365 |#1| |#2|) (-10 -7 (-15 -2414 ((-121) (-638 (-959 |#1|)))) (-15 -1623 ((-3 (-638 (-959 |#1|)) "failed") (-638 (-959 |#1|)))) (-15 -3604 ((-638 (-959 |#1|)) (-638 (-959 |#1|))))) (-457) (-638 (-1170))) (T -365)) 
-((-3604 (*1 *2 *2) (-12 (-5 *2 (-638 (-959 *3))) (-4 *3 (-457)) (-5 *1 (-365 *3 *4)) (-14 *4 (-638 (-1170))))) (-1623 (*1 *2 *2) (|partial| -12 (-5 *2 (-638 (-959 *3))) (-4 *3 (-457)) (-5 *1 (-365 *3 *4)) (-14 *4 (-638 (-1170))))) (-2414 (*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-457)) (-5 *2 (-121)) (-5 *1 (-365 *4 *5)) (-14 *5 (-638 (-1170)))))) 
-(-10 -7 (-15 -2414 ((-121) (-638 (-959 |#1|)))) (-15 -1623 ((-3 (-638 (-959 |#1|)) "failed") (-638 (-959 |#1|)))) (-15 -3604 ((-638 (-959 |#1|)) (-638 (-959 |#1|))))) 
-((-2262 (((-121) $ $) NIL)) (-1685 (((-769) $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) 14)) (-4351 ((|#1| $ (-572)) NIL)) (-1606 (((-572) $ (-572)) NIL)) (-3629 (($ (-1 |#1| |#1|) $) 32)) (-1538 (($ (-1 (-572) (-572)) $) 24)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 26)) (-2607 (((-1116) $) NIL)) (-4547 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-572)))) $) 28)) (-3018 (($ $ $) NIL)) (-4056 (($ $ $) NIL)) (-3972 (((-856) $) 38) (($ |#1|) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-3255 (($) 9 T CONST)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL) (($ |#1| (-572)) 17)) (* (($ $ $) 43) (($ |#1| $) 21) (($ $ |#1|) 19))) 
-(((-366 |#1|) (-13 (-482) (-1044 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-572))) (-15 -1685 ((-769) $)) (-15 -1606 ((-572) $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -1538 ($ (-1 (-572) (-572)) $)) (-15 -3629 ($ (-1 |#1| |#1|) $)) (-15 -4547 ((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-572)))) $)))) (-1098)) (T -366)) 
-((* (*1 *1 *2 *1) (-12 (-5 *1 (-366 *2)) (-4 *2 (-1098)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-366 *2)) (-4 *2 (-1098)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-366 *2)) (-4 *2 (-1098)))) (-1685 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-366 *3)) (-4 *3 (-1098)))) (-1606 (*1 *2 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-366 *3)) (-4 *3 (-1098)))) (-4351 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-366 *2)) (-4 *2 (-1098)))) (-1538 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-572) (-572))) (-5 *1 (-366 *3)) (-4 *3 (-1098)))) (-3629 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-366 *3)))) (-4547 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 (-572))))) (-5 *1 (-366 *3)) (-4 *3 (-1098))))) 
-(-13 (-482) (-1044 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-572))) (-15 -1685 ((-769) $)) (-15 -1606 ((-572) $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -1538 ($ (-1 (-572) (-572)) $)) (-15 -3629 ($ (-1 |#1| |#1|) $)) (-15 -4547 ((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-572)))) $)))) 
-((-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 13)) (-3946 (($ $) 14)) (-1466 (((-424 $) $) 29)) (-1526 (((-121) $) 25)) (-4350 (($ $) 18)) (-3069 (($ $ $) 22) (($ (-638 $)) NIL)) (-4304 (((-424 $) $) 30)) (-1803 (((-3 $ "failed") $ $) 21)) (-4029 (((-769) $) 24)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 34)) (-3774 (((-121) $ $) 15)) (-1379 (($ $ $) 32))) 
-(((-367 |#1|) (-10 -8 (-15 -1379 (|#1| |#1| |#1|)) (-15 -4350 (|#1| |#1|)) (-15 -1526 ((-121) |#1|)) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -2541 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -4029 ((-769) |#1|)) (-15 -3069 (|#1| (-638 |#1|))) (-15 -3069 (|#1| |#1| |#1|)) (-15 -3774 ((-121) |#1| |#1|)) (-15 -3946 (|#1| |#1|)) (-15 -4109 ((-2 (|:| -3029 |#1|) (|:| -4589 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#1|))) (-368)) (T -367)) 
-NIL 
-(-10 -8 (-15 -1379 (|#1| |#1| |#1|)) (-15 -4350 (|#1| |#1|)) (-15 -1526 ((-121) |#1|)) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -2541 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -4029 ((-769) |#1|)) (-15 -3069 (|#1| (-638 |#1|))) (-15 -3069 (|#1| |#1| |#1|)) (-15 -3774 ((-121) |#1| |#1|)) (-15 -3946 (|#1| |#1|)) (-15 -4109 ((-2 (|:| -3029 |#1|) (|:| -4589 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-2211 (($) 16 T CONST)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-1526 (((-121) $) 69)) (-3893 (((-121) $) 30)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64))) 
-(((-368) (-1290)) (T -368)) 
-((-1379 (*1 *1 *1 *1) (-4 *1 (-368)))) 
-(-13 (-303) (-1214) (-240) (-10 -8 (-15 -1379 ($ $ $)) (-6 -4600) (-6 -4594))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T)) 
-((-2262 (((-121) $ $) 7)) (-3757 ((|#2| $ |#2|) 13)) (-2582 (($ $ (-1152)) 18)) (-2159 ((|#2| $) 14)) (-1428 (($ |#1|) 20) (($ |#1| (-1152)) 19)) (-3201 ((|#1| $) 16)) (-1658 (((-1152) $) 9)) (-1828 (((-1152) $) 15)) (-2607 (((-1116) $) 10)) (-1734 (((-1264) $) 12)) (-3972 (((-856) $) 11)) (-1391 (($ $) 17)) (-1324 (((-121) $ $) 6))) 
-(((-369 |#1| |#2|) (-1290) (-1098) (-1098)) (T -369)) 
-((-1428 (*1 *1 *2) (-12 (-4 *1 (-369 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) (-1428 (*1 *1 *2 *3) (-12 (-5 *3 (-1152)) (-4 *1 (-369 *2 *4)) (-4 *2 (-1098)) (-4 *4 (-1098)))) (-2582 (*1 *1 *1 *2) (-12 (-5 *2 (-1152)) (-4 *1 (-369 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-1391 (*1 *1 *1) (-12 (-4 *1 (-369 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) (-3201 (*1 *2 *1) (-12 (-4 *1 (-369 *2 *3)) (-4 *3 (-1098)) (-4 *2 (-1098)))) (-1828 (*1 *2 *1) (-12 (-4 *1 (-369 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-1152)))) (-2159 (*1 *2 *1) (-12 (-4 *1 (-369 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098)))) (-3757 (*1 *2 *1 *2) (-12 (-4 *1 (-369 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098)))) (-1734 (*1 *2 *1) (-12 (-4 *1 (-369 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-1264))))) 
-(-13 (-1098) (-10 -8 (-15 -1428 ($ |t#1|)) (-15 -1428 ($ |t#1| (-1152))) (-15 -2582 ($ $ (-1152))) (-15 -1391 ($ $)) (-15 -3201 (|t#1| $)) (-15 -1828 ((-1152) $)) (-15 -2159 (|t#2| $)) (-15 -3757 (|t#2| $ |t#2|)) (-15 -1734 ((-1264) $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-3757 ((|#1| $ |#1|) 29)) (-2582 (($ $ (-1152)) 22)) (-1515 (((-3 |#1| "failed") $) 28)) (-2159 ((|#1| $) 26)) (-1428 (($ (-394)) 21) (($ (-394) (-1152)) 20)) (-3201 (((-394) $) 24)) (-1658 (((-1152) $) NIL)) (-1828 (((-1152) $) 25)) (-2607 (((-1116) $) NIL)) (-1734 (((-1264) $) 31)) (-3972 (((-856) $) 19)) (-1391 (($ $) 23)) (-1324 (((-121) $ $) 18))) 
-(((-370 |#1|) (-13 (-369 (-394) |#1|) (-10 -8 (-15 -1515 ((-3 |#1| "failed") $)))) (-1098)) (T -370)) 
-((-1515 (*1 *2 *1) (|partial| -12 (-5 *1 (-370 *2)) (-4 *2 (-1098))))) 
-(-13 (-369 (-394) |#1|) (-10 -8 (-15 -1515 ((-3 |#1| "failed") $)))) 
-((-1354 (((-1259 (-685 |#2|)) (-1259 $)) 62)) (-2882 (((-685 |#2|) (-1259 $)) 120)) (-3487 ((|#2| $) 32)) (-3700 (((-685 |#2|) $ (-1259 $)) 124)) (-2848 (((-3 $ "failed") $) 76)) (-3588 ((|#2| $) 35)) (-2135 (((-1166 |#2|) $) 84)) (-4146 ((|#2| (-1259 $)) 107)) (-1593 (((-1166 |#2|) $) 28)) (-2048 (((-121)) 101)) (-4337 (($ (-1259 |#2|) (-1259 $)) 114)) (-1799 (((-3 $ "failed") $) 80)) (-1814 (((-121)) 96)) (-2209 (((-121)) 91)) (-1648 (((-121)) 54)) (-1663 (((-685 |#2|) (-1259 $)) 118)) (-3550 ((|#2| $) 31)) (-3343 (((-685 |#2|) $ (-1259 $)) 123)) (-2046 (((-3 $ "failed") $) 74)) (-2340 ((|#2| $) 34)) (-3665 (((-1166 |#2|) $) 83)) (-2110 ((|#2| (-1259 $)) 105)) (-1989 (((-1166 |#2|) $) 26)) (-3602 (((-121)) 100)) (-4219 (((-121)) 93)) (-2395 (((-121)) 52)) (-3046 (((-121)) 88)) (-4128 (((-121)) 102)) (-3160 (((-1259 |#2|) $ (-1259 $)) NIL) (((-685 |#2|) (-1259 $) (-1259 $)) 112)) (-2073 (((-121)) 98)) (-4414 (((-638 (-1259 |#2|))) 87)) (-2928 (((-121)) 99)) (-2773 (((-121)) 97)) (-2756 (((-121)) 46)) (-1447 (((-121)) 103))) 
-(((-371 |#1| |#2|) (-10 -8 (-15 -2135 ((-1166 |#2|) |#1|)) (-15 -3665 ((-1166 |#2|) |#1|)) (-15 -4414 ((-638 (-1259 |#2|)))) (-15 -2848 ((-3 |#1| "failed") |#1|)) (-15 -2046 ((-3 |#1| "failed") |#1|)) (-15 -1799 ((-3 |#1| "failed") |#1|)) (-15 -2209 ((-121))) (-15 -4219 ((-121))) (-15 -1814 ((-121))) (-15 -2395 ((-121))) (-15 -1648 ((-121))) (-15 -3046 ((-121))) (-15 -1447 ((-121))) (-15 -4128 ((-121))) (-15 -2048 ((-121))) (-15 -3602 ((-121))) (-15 -2756 ((-121))) (-15 -2928 ((-121))) (-15 -2773 ((-121))) (-15 -2073 ((-121))) (-15 -1593 ((-1166 |#2|) |#1|)) (-15 -1989 ((-1166 |#2|) |#1|)) (-15 -2882 ((-685 |#2|) (-1259 |#1|))) (-15 -1663 ((-685 |#2|) (-1259 |#1|))) (-15 -4146 (|#2| (-1259 |#1|))) (-15 -2110 (|#2| (-1259 |#1|))) (-15 -4337 (|#1| (-1259 |#2|) (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -3588 (|#2| |#1|)) (-15 -2340 (|#2| |#1|)) (-15 -3487 (|#2| |#1|)) (-15 -3550 (|#2| |#1|)) (-15 -3700 ((-685 |#2|) |#1| (-1259 |#1|))) (-15 -3343 ((-685 |#2|) |#1| (-1259 |#1|))) (-15 -1354 ((-1259 (-685 |#2|)) (-1259 |#1|)))) (-372 |#2|) (-174)) (T -371)) 
-((-2073 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-2773 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-2928 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-2756 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-3602 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-2048 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-4128 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-1447 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-3046 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-1648 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-2395 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-1814 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-4219 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-2209 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) (-4414 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-638 (-1259 *4))) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4))))) 
-(-10 -8 (-15 -2135 ((-1166 |#2|) |#1|)) (-15 -3665 ((-1166 |#2|) |#1|)) (-15 -4414 ((-638 (-1259 |#2|)))) (-15 -2848 ((-3 |#1| "failed") |#1|)) (-15 -2046 ((-3 |#1| "failed") |#1|)) (-15 -1799 ((-3 |#1| "failed") |#1|)) (-15 -2209 ((-121))) (-15 -4219 ((-121))) (-15 -1814 ((-121))) (-15 -2395 ((-121))) (-15 -1648 ((-121))) (-15 -3046 ((-121))) (-15 -1447 ((-121))) (-15 -4128 ((-121))) (-15 -2048 ((-121))) (-15 -3602 ((-121))) (-15 -2756 ((-121))) (-15 -2928 ((-121))) (-15 -2773 ((-121))) (-15 -2073 ((-121))) (-15 -1593 ((-1166 |#2|) |#1|)) (-15 -1989 ((-1166 |#2|) |#1|)) (-15 -2882 ((-685 |#2|) (-1259 |#1|))) (-15 -1663 ((-685 |#2|) (-1259 |#1|))) (-15 -4146 (|#2| (-1259 |#1|))) (-15 -2110 (|#2| (-1259 |#1|))) (-15 -4337 (|#1| (-1259 |#2|) (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -3588 (|#2| |#1|)) (-15 -2340 (|#2| |#1|)) (-15 -3487 (|#2| |#1|)) (-15 -3550 (|#2| |#1|)) (-15 -3700 ((-685 |#2|) |#1| (-1259 |#1|))) (-15 -3343 ((-685 |#2|) |#1| (-1259 |#1|))) (-15 -1354 ((-1259 (-685 |#2|)) (-1259 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3029 (((-3 $ "failed")) 35 (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) 18)) (-1354 (((-1259 (-685 |#1|)) (-1259 $)) 76)) (-2167 (((-1259 $)) 79)) (-2211 (($) 16 T CONST)) (-4511 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) 38 (|has| |#1| (-562)))) (-2095 (((-3 $ "failed")) 36 (|has| |#1| (-562)))) (-2882 (((-685 |#1|) (-1259 $)) 63)) (-3487 ((|#1| $) 72)) (-3700 (((-685 |#1|) $ (-1259 $)) 74)) (-2848 (((-3 $ "failed") $) 43 (|has| |#1| (-562)))) (-3014 (($ $ (-923)) 27)) (-3588 ((|#1| $) 70)) (-2135 (((-1166 |#1|) $) 40 (|has| |#1| (-562)))) (-4146 ((|#1| (-1259 $)) 65)) (-1593 (((-1166 |#1|) $) 61)) (-2048 (((-121)) 55)) (-4337 (($ (-1259 |#1|) (-1259 $)) 67)) (-1799 (((-3 $ "failed") $) 45 (|has| |#1| (-562)))) (-2667 (((-923)) 78)) (-4160 (((-121)) 52)) (-2027 (($ $ (-923)) 32)) (-1814 (((-121)) 48)) (-2209 (((-121)) 46)) (-1648 (((-121)) 50)) (-1903 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) 39 (|has| |#1| (-562)))) (-2036 (((-3 $ "failed")) 37 (|has| |#1| (-562)))) (-1663 (((-685 |#1|) (-1259 $)) 64)) (-3550 ((|#1| $) 73)) (-3343 (((-685 |#1|) $ (-1259 $)) 75)) (-2046 (((-3 $ "failed") $) 44 (|has| |#1| (-562)))) (-3276 (($ $ (-923)) 28)) (-2340 ((|#1| $) 71)) (-3665 (((-1166 |#1|) $) 41 (|has| |#1| (-562)))) (-2110 ((|#1| (-1259 $)) 66)) (-1989 (((-1166 |#1|) $) 62)) (-3602 (((-121)) 56)) (-1658 (((-1152) $) 9)) (-4219 (((-121)) 47)) (-2395 (((-121)) 49)) (-3046 (((-121)) 51)) (-2607 (((-1116) $) 10)) (-4128 (((-121)) 54)) (-3160 (((-1259 |#1|) $ (-1259 $)) 69) (((-685 |#1|) (-1259 $) (-1259 $)) 68)) (-3188 (((-638 (-959 |#1|)) (-1259 $)) 77)) (-4056 (($ $ $) 24)) (-2073 (((-121)) 60)) (-3972 (((-856) $) 11)) (-4414 (((-638 (-1259 |#1|))) 42 (|has| |#1| (-562)))) (-4250 (($ $ $ $) 25)) (-2928 (((-121)) 58)) (-1397 (($ $ $) 23)) (-2773 (((-121)) 59)) (-2756 (((-121)) 57)) (-1447 (((-121)) 53)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 29)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
-(((-372 |#1|) (-1290) (-174)) (T -372)) 
-((-2167 (*1 *2) (-12 (-4 *3 (-174)) (-5 *2 (-1259 *1)) (-4 *1 (-372 *3)))) (-2667 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-923)))) (-3188 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-638 (-959 *4))))) (-1354 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-1259 (-685 *4))))) (-3343 (*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) (-3700 (*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) (-3550 (*1 *2 *1) (-12 (-4 *1 (-372 *2)) (-4 *2 (-174)))) (-3487 (*1 *2 *1) (-12 (-4 *1 (-372 *2)) (-4 *2 (-174)))) (-2340 (*1 *2 *1) (-12 (-4 *1 (-372 *2)) (-4 *2 (-174)))) (-3588 (*1 *2 *1) (-12 (-4 *1 (-372 *2)) (-4 *2 (-174)))) (-3160 (*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-1259 *4)))) (-3160 (*1 *2 *3 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) (-4337 (*1 *1 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-1259 *1)) (-4 *4 (-174)) (-4 *1 (-372 *4)))) (-2110 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *2)) (-4 *2 (-174)))) (-4146 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *2)) (-4 *2 (-174)))) (-1663 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) (-2882 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) (-1989 (*1 *2 *1) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-1166 *3)))) (-1593 (*1 *2 *1) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-1166 *3)))) (-2073 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-2773 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-2928 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-2756 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-3602 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-2048 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-4128 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-1447 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-4160 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-3046 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-1648 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-2395 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-1814 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-4219 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-2209 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121)))) (-1799 (*1 *1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-174)) (-4 *2 (-562)))) (-2046 (*1 *1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-174)) (-4 *2 (-562)))) (-2848 (*1 *1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-174)) (-4 *2 (-562)))) (-4414 (*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-4 *3 (-562)) (-5 *2 (-638 (-1259 *3))))) (-3665 (*1 *2 *1) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-4 *3 (-562)) (-5 *2 (-1166 *3)))) (-2135 (*1 *2 *1) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-4 *3 (-562)) (-5 *2 (-1166 *3)))) (-1903 (*1 *2) (|partial| -12 (-4 *3 (-562)) (-4 *3 (-174)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2237 (-638 *1)))) (-4 *1 (-372 *3)))) (-4511 (*1 *2) (|partial| -12 (-4 *3 (-562)) (-4 *3 (-174)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2237 (-638 *1)))) (-4 *1 (-372 *3)))) (-2036 (*1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-562)) (-4 *2 (-174)))) (-2095 (*1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-562)) (-4 *2 (-174)))) (-3029 (*1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-562)) (-4 *2 (-174))))) 
-(-13 (-742 |t#1|) (-10 -8 (-15 -2167 ((-1259 $))) (-15 -2667 ((-923))) (-15 -3188 ((-638 (-959 |t#1|)) (-1259 $))) (-15 -1354 ((-1259 (-685 |t#1|)) (-1259 $))) (-15 -3343 ((-685 |t#1|) $ (-1259 $))) (-15 -3700 ((-685 |t#1|) $ (-1259 $))) (-15 -3550 (|t#1| $)) (-15 -3487 (|t#1| $)) (-15 -2340 (|t#1| $)) (-15 -3588 (|t#1| $)) (-15 -3160 ((-1259 |t#1|) $ (-1259 $))) (-15 -3160 ((-685 |t#1|) (-1259 $) (-1259 $))) (-15 -4337 ($ (-1259 |t#1|) (-1259 $))) (-15 -2110 (|t#1| (-1259 $))) (-15 -4146 (|t#1| (-1259 $))) (-15 -1663 ((-685 |t#1|) (-1259 $))) (-15 -2882 ((-685 |t#1|) (-1259 $))) (-15 -1989 ((-1166 |t#1|) $)) (-15 -1593 ((-1166 |t#1|) $)) (-15 -2073 ((-121))) (-15 -2773 ((-121))) (-15 -2928 ((-121))) (-15 -2756 ((-121))) (-15 -3602 ((-121))) (-15 -2048 ((-121))) (-15 -4128 ((-121))) (-15 -1447 ((-121))) (-15 -4160 ((-121))) (-15 -3046 ((-121))) (-15 -1648 ((-121))) (-15 -2395 ((-121))) (-15 -1814 ((-121))) (-15 -4219 ((-121))) (-15 -2209 ((-121))) (IF (|has| |t#1| (-562)) (PROGN (-15 -1799 ((-3 $ "failed") $)) (-15 -2046 ((-3 $ "failed") $)) (-15 -2848 ((-3 $ "failed") $)) (-15 -4414 ((-638 (-1259 |t#1|)))) (-15 -3665 ((-1166 |t#1|) $)) (-15 -2135 ((-1166 |t#1|) $)) (-15 -1903 ((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed"))) (-15 -4511 ((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed"))) (-15 -2036 ((-3 $ "failed"))) (-15 -2095 ((-3 $ "failed"))) (-15 -3029 ((-3 $ "failed"))) (-6 -4599)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-713 |#1|) . T) ((-716) . T) ((-742 |#1|) . T) ((-759) . T) ((-1060 |#1|) . T) ((-1098) . T)) 
-((-3286 (($) 13)) (-3587 (((-638 $)) 15))) 
-(((-373 |#1|) (-10 -8 (-15 -3587 ((-638 |#1|))) (-15 -3286 (|#1|))) (-374)) (T -373)) 
-NIL 
-(-10 -8 (-15 -3587 ((-638 |#1|))) (-15 -3286 (|#1|))) 
-((-2262 (((-121) $ $) 7)) (-1685 (((-769)) 16)) (-3286 (($) 13)) (-3633 (((-923) $) 14)) (-1658 (((-1152) $) 9)) (-1763 (($ (-923)) 15)) (-2607 (((-1116) $) 10)) (-3587 (((-638 $)) 12)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-374) (-1290)) (T -374)) 
-((-1685 (*1 *2) (-12 (-4 *1 (-374)) (-5 *2 (-769)))) (-1763 (*1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-374)))) (-3633 (*1 *2 *1) (-12 (-4 *1 (-374)) (-5 *2 (-923)))) (-3286 (*1 *1) (-4 *1 (-374))) (-3587 (*1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-374))))) 
-(-13 (-1098) (-10 -8 (-15 -1685 ((-769))) (-15 -1763 ($ (-923))) (-15 -3633 ((-923) $)) (-15 -3286 ($)) (-15 -3587 ((-638 $))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-1845 (((-685 |#2|) (-1259 $)) 40)) (-4337 (($ (-1259 |#2|) (-1259 $)) 35)) (-1741 (((-685 |#2|) $ (-1259 $)) 43)) (-2119 ((|#2| (-1259 $)) 13)) (-3160 (((-1259 |#2|) $ (-1259 $)) NIL) (((-685 |#2|) (-1259 $) (-1259 $)) 25))) 
-(((-375 |#1| |#2| |#3|) (-10 -8 (-15 -1845 ((-685 |#2|) (-1259 |#1|))) (-15 -2119 (|#2| (-1259 |#1|))) (-15 -4337 (|#1| (-1259 |#2|) (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -1741 ((-685 |#2|) |#1| (-1259 |#1|)))) (-376 |#2| |#3|) (-174) (-1234 |#2|)) (T -375)) 
-NIL 
-(-10 -8 (-15 -1845 ((-685 |#2|) (-1259 |#1|))) (-15 -2119 (|#2| (-1259 |#1|))) (-15 -4337 (|#1| (-1259 |#2|) (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -1741 ((-685 |#2|) |#1| (-1259 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1845 (((-685 |#1|) (-1259 $)) 44)) (-3520 ((|#1| $) 50)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-4337 (($ (-1259 |#1|) (-1259 $)) 46)) (-1741 (((-685 |#1|) $ (-1259 $)) 51)) (-1799 (((-3 $ "failed") $) 33)) (-2667 (((-923)) 52)) (-3893 (((-121) $) 30)) (-4429 ((|#1| $) 49)) (-3251 ((|#2| $) 42 (|has| |#1| (-368)))) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-2119 ((|#1| (-1259 $)) 45)) (-3160 (((-1259 |#1|) $ (-1259 $)) 48) (((-685 |#1|) (-1259 $) (-1259 $)) 47)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 36)) (-2779 (((-3 $ "failed") $) 41 (|has| |#1| (-149)))) (-2707 ((|#2| $) 43)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
-(((-376 |#1| |#2|) (-1290) (-174) (-1234 |t#1|)) (T -376)) 
-((-2667 (*1 *2) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-923)))) (-1741 (*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)))) (-3520 (*1 *2 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *3 (-1234 *2)) (-4 *2 (-174)))) (-4429 (*1 *2 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *3 (-1234 *2)) (-4 *2 (-174)))) (-3160 (*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-1259 *4)))) (-3160 (*1 *2 *3 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)))) (-4337 (*1 *1 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-1259 *1)) (-4 *4 (-174)) (-4 *1 (-376 *4 *5)) (-4 *5 (-1234 *4)))) (-2119 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *2 *4)) (-4 *4 (-1234 *2)) (-4 *2 (-174)))) (-1845 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)))) (-2707 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *2)) (-4 *3 (-174)) (-4 *2 (-1234 *3)))) (-3251 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *2)) (-4 *3 (-174)) (-4 *3 (-368)) (-4 *2 (-1234 *3))))) 
-(-13 (-43 |t#1|) (-10 -8 (-15 -2667 ((-923))) (-15 -1741 ((-685 |t#1|) $ (-1259 $))) (-15 -3520 (|t#1| $)) (-15 -4429 (|t#1| $)) (-15 -3160 ((-1259 |t#1|) $ (-1259 $))) (-15 -3160 ((-685 |t#1|) (-1259 $) (-1259 $))) (-15 -4337 ($ (-1259 |t#1|) (-1259 $))) (-15 -2119 (|t#1| (-1259 $))) (-15 -1845 ((-685 |t#1|) (-1259 $))) (-15 -2707 (|t#2| $)) (IF (|has| |t#1| (-368)) (-15 -3251 (|t#2| $)) |noBranch|) (IF (|has| |t#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |t#1| (-149)) (-6 (-149)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 |#1|) . T) ((-722) . T) ((-1060 |#1|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-1911 ((|#4| (-1 |#3| |#1| |#3|) |#2| |#3|) 23)) (-3116 ((|#3| (-1 |#3| |#1| |#3|) |#2| |#3|) 15)) (-3828 ((|#4| (-1 |#3| |#1|) |#2|) 21))) 
-(((-377 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3116 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1911 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) (-1204) (-379 |#1|) (-1204) (-379 |#3|)) (T -377)) 
-((-1911 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-4 *2 (-379 *5)) (-5 *1 (-377 *6 *4 *5 *2)) (-4 *4 (-379 *6)))) (-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-377 *5 *4 *2 *6)) (-4 *4 (-379 *5)) (-4 *6 (-379 *2)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-4 *2 (-379 *6)) (-5 *1 (-377 *5 *4 *6 *2)) (-4 *4 (-379 *5))))) 
-(-10 -7 (-15 -3828 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3116 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1911 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) 
-((-2041 (((-121) (-1 (-121) |#2| |#2|) $) NIL) (((-121) $) 18)) (-4131 (($ (-1 (-121) |#2| |#2|) $) NIL) (($ $) 28)) (-3008 (($ (-1 (-121) |#2| |#2|) $) 27) (($ $) 22)) (-1656 (($ $) 25)) (-4014 (((-572) (-1 (-121) |#2|) $) NIL) (((-572) |#2| $) 11) (((-572) |#2| $ (-572)) NIL)) (-4475 (($ (-1 (-121) |#2| |#2|) $ $) NIL) (($ $ $) 20))) 
-(((-378 |#1| |#2|) (-10 -8 (-15 -4131 (|#1| |#1|)) (-15 -4131 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -2041 ((-121) |#1|)) (-15 -3008 (|#1| |#1|)) (-15 -4475 (|#1| |#1| |#1|)) (-15 -4014 ((-572) |#2| |#1| (-572))) (-15 -4014 ((-572) |#2| |#1|)) (-15 -4014 ((-572) (-1 (-121) |#2|) |#1|)) (-15 -2041 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -3008 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -1656 (|#1| |#1|)) (-15 -4475 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|))) (-379 |#2|) (-1204)) (T -378)) 
-NIL 
-(-10 -8 (-15 -4131 (|#1| |#1|)) (-15 -4131 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -2041 ((-121) |#1|)) (-15 -3008 (|#1| |#1|)) (-15 -4475 (|#1| |#1| |#1|)) (-15 -4014 ((-572) |#2| |#1| (-572))) (-15 -4014 ((-572) |#2| |#1|)) (-15 -4014 ((-572) (-1 (-121) |#2|) |#1|)) (-15 -2041 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -3008 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -1656 (|#1| |#1|)) (-15 -4475 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4603))) (($ $) 81 (-12 (|has| |#1| (-848)) (|has| $ (-6 -4603))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#1| $ (-572) |#1|) 49 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 53 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-2985 (($ $) 83 (|has| $ (-6 -4603)))) (-1656 (($ $) 93)) (-1643 (($ $) 73 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#1| $) 72 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) 50 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 48)) (-4014 (((-572) (-1 (-121) |#1|) $) 90) (((-572) |#1| $) 89 (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) 88 (|has| |#1| (-1098)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-1364 (($ (-769) |#1|) 64)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-1771 (($ $ $) 80 (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-4238 (($ $ $) 79 (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) 55) (($ $ $ (-572)) 54)) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 39 (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3299 (($ $ |#1|) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ (-572) |#1|) 47) ((|#1| $ (-572)) 46) (($ $ (-1225 (-572))) 58)) (-1940 (($ $ (-572)) 57) (($ $ (-1225 (-572))) 56)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2907 (($ $ $ (-572)) 84 (|has| $ (-6 -4603)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 74 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 65)) (-4500 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-638 $)) 60)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) 77 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 76 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-1343 (((-121) $ $) 78 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 75 (|has| |#1| (-848)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-379 |#1|) (-1290) (-1204)) (T -379)) 
-((-4475 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-379 *3)) (-4 *3 (-1204)))) (-1656 (*1 *1 *1) (-12 (-4 *1 (-379 *2)) (-4 *2 (-1204)))) (-3008 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-379 *3)) (-4 *3 (-1204)))) (-2041 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *1 (-379 *4)) (-4 *4 (-1204)) (-5 *2 (-121)))) (-4014 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (-4 *1 (-379 *4)) (-4 *4 (-1204)) (-5 *2 (-572)))) (-4014 (*1 *2 *3 *1) (-12 (-4 *1 (-379 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-572)))) (-4014 (*1 *2 *3 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-379 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)))) (-4475 (*1 *1 *1 *1) (-12 (-4 *1 (-379 *2)) (-4 *2 (-1204)) (-4 *2 (-848)))) (-3008 (*1 *1 *1) (-12 (-4 *1 (-379 *2)) (-4 *2 (-1204)) (-4 *2 (-848)))) (-2041 (*1 *2 *1) (-12 (-4 *1 (-379 *3)) (-4 *3 (-1204)) (-4 *3 (-848)) (-5 *2 (-121)))) (-2907 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-572)) (|has| *1 (-6 -4603)) (-4 *1 (-379 *3)) (-4 *3 (-1204)))) (-2985 (*1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-379 *2)) (-4 *2 (-1204)))) (-4131 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (|has| *1 (-6 -4603)) (-4 *1 (-379 *3)) (-4 *3 (-1204)))) (-4131 (*1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-379 *2)) (-4 *2 (-1204)) (-4 *2 (-848))))) 
-(-13 (-644 |t#1|) (-10 -8 (-6 -4602) (-15 -4475 ($ (-1 (-121) |t#1| |t#1|) $ $)) (-15 -1656 ($ $)) (-15 -3008 ($ (-1 (-121) |t#1| |t#1|) $)) (-15 -2041 ((-121) (-1 (-121) |t#1| |t#1|) $)) (-15 -4014 ((-572) (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1098)) (PROGN (-15 -4014 ((-572) |t#1| $)) (-15 -4014 ((-572) |t#1| $ (-572)))) |noBranch|) (IF (|has| |t#1| (-848)) (PROGN (-6 (-848)) (-15 -4475 ($ $ $)) (-15 -3008 ($ $)) (-15 -2041 ((-121) $))) |noBranch|) (IF (|has| $ (-6 -4603)) (PROGN (-15 -2907 ($ $ $ (-572))) (-15 -2985 ($ $)) (-15 -4131 ($ (-1 (-121) |t#1| |t#1|) $)) (IF (|has| |t#1| (-848)) (-15 -4131 ($ $)) |noBranch|)) |noBranch|))) 
-(((-39) . T) ((-105) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-612 (-856)) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-644 |#1|) . T) ((-848) |has| |#1| (-848)) ((-1098) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-1204) . T)) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2199 (((-638 |#1|) $) 29)) (-2007 (($ $ (-769)) 30)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-3754 (((-1281 |#1| |#2|) (-1281 |#1| |#2|) $) 33)) (-4076 (($ $) 31)) (-3561 (((-1281 |#1| |#2|) (-1281 |#1| |#2|) $) 34)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4485 (($ $ |#1| $) 28) (($ $ (-638 |#1|) (-638 $)) 27)) (-4316 (((-769) $) 35)) (-3921 (($ $ $) 26)) (-3972 (((-856) $) 11) (($ |#1|) 38) (((-1272 |#1| |#2|) $) 37) (((-1281 |#1| |#2|) $) 36)) (-4513 ((|#2| (-1281 |#1| |#2|) $) 39)) (-2378 (($) 17 T CONST)) (-1960 (($ (-667 |#1|)) 32)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#2|) 25 (|has| |#2| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ |#2| $) 22) (($ $ |#2|) 24))) 
-(((-380 |#1| |#2|) (-1290) (-848) (-174)) (T -380)) 
-((-4513 (*1 *2 *3 *1) (-12 (-5 *3 (-1281 *4 *2)) (-4 *1 (-380 *4 *2)) (-4 *4 (-848)) (-4 *2 (-174)))) (-3972 (*1 *1 *2) (-12 (-4 *1 (-380 *2 *3)) (-4 *2 (-848)) (-4 *3 (-174)))) (-3972 (*1 *2 *1) (-12 (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *2 (-1272 *3 *4)))) (-3972 (*1 *2 *1) (-12 (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *2 (-1281 *3 *4)))) (-4316 (*1 *2 *1) (-12 (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *2 (-769)))) (-3561 (*1 *2 *2 *1) (-12 (-5 *2 (-1281 *3 *4)) (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) (-3754 (*1 *2 *2 *1) (-12 (-5 *2 (-1281 *3 *4)) (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) (-1960 (*1 *1 *2) (-12 (-5 *2 (-667 *3)) (-4 *3 (-848)) (-4 *1 (-380 *3 *4)) (-4 *4 (-174)))) (-4076 (*1 *1 *1) (-12 (-4 *1 (-380 *2 *3)) (-4 *2 (-848)) (-4 *3 (-174)))) (-2007 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) (-2199 (*1 *2 *1) (-12 (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *2 (-638 *3)))) (-4485 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-380 *2 *3)) (-4 *2 (-848)) (-4 *3 (-174)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *4)) (-5 *3 (-638 *1)) (-4 *1 (-380 *4 *5)) (-4 *4 (-848)) (-4 *5 (-174))))) 
-(-13 (-629 |t#2|) (-10 -8 (-15 -4513 (|t#2| (-1281 |t#1| |t#2|) $)) (-15 -3972 ($ |t#1|)) (-15 -3972 ((-1272 |t#1| |t#2|) $)) (-15 -3972 ((-1281 |t#1| |t#2|) $)) (-15 -4316 ((-769) $)) (-15 -3561 ((-1281 |t#1| |t#2|) (-1281 |t#1| |t#2|) $)) (-15 -3754 ((-1281 |t#1| |t#2|) (-1281 |t#1| |t#2|) $)) (-15 -1960 ($ (-667 |t#1|))) (-15 -4076 ($ $)) (-15 -2007 ($ $ (-769))) (-15 -2199 ((-638 |t#1|) $)) (-15 -4485 ($ $ |t#1| $)) (-15 -4485 ($ $ (-638 |t#1|) (-638 $))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#2| |#2|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#2|) . T) ((-629 |#2|) . T) ((-713 |#2|) . T) ((-1060 |#2|) . T) ((-1098) . T)) 
-((-1832 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 22)) (-2287 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 12)) (-1873 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 21))) 
-(((-381 |#1| |#2|) (-10 -7 (-15 -2287 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -1873 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -1832 (|#2| (-1 (-121) |#1| |#1|) |#2|))) (-1204) (-13 (-379 |#1|) (-10 -7 (-6 -4603)))) (T -381)) 
-((-1832 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-381 *4 *2)) (-4 *2 (-13 (-379 *4) (-10 -7 (-6 -4603)))))) (-1873 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-381 *4 *2)) (-4 *2 (-13 (-379 *4) (-10 -7 (-6 -4603)))))) (-2287 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-381 *4 *2)) (-4 *2 (-13 (-379 *4) (-10 -7 (-6 -4603))))))) 
-(-10 -7 (-15 -2287 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -1873 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -1832 (|#2| (-1 (-121) |#1| |#1|) |#2|))) 
-((-2284 (((-685 |#2|) (-685 $)) NIL) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 19) (((-685 (-572)) (-685 $)) 13))) 
-(((-382 |#1| |#2|) (-10 -8 (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 |#2|) (-685 |#1|)))) (-383 |#2|) (-1054)) (T -382)) 
-NIL 
-(-10 -8 (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 |#2|) (-685 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-2284 (((-685 |#1|) (-685 $)) 35) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 34) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 38 (|has| |#1| (-634 (-572)))) (((-685 (-572)) (-685 $)) 37 (|has| |#1| (-634 (-572))))) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-383 |#1|) (-1290) (-1054)) (T -383)) 
-NIL 
-(-13 (-634 |t#1|) (-10 -7 (IF (|has| |t#1| (-634 (-572))) (-6 (-634 (-572))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-722) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-4456 (((-638 (-290 (-959 (-171 |#1|)))) (-290 (-413 (-959 (-171 (-572))))) |#1|) 52) (((-638 (-290 (-959 (-171 |#1|)))) (-413 (-959 (-171 (-572)))) |#1|) 51) (((-638 (-638 (-290 (-959 (-171 |#1|))))) (-638 (-290 (-413 (-959 (-171 (-572)))))) |#1|) 47) (((-638 (-638 (-290 (-959 (-171 |#1|))))) (-638 (-413 (-959 (-171 (-572))))) |#1|) 40)) (-3950 (((-638 (-638 (-171 |#1|))) (-638 (-413 (-959 (-171 (-572))))) (-638 (-1170)) |#1|) 28) (((-638 (-171 |#1|)) (-413 (-959 (-171 (-572)))) |#1|) 15))) 
-(((-384 |#1|) (-10 -7 (-15 -4456 ((-638 (-638 (-290 (-959 (-171 |#1|))))) (-638 (-413 (-959 (-171 (-572))))) |#1|)) (-15 -4456 ((-638 (-638 (-290 (-959 (-171 |#1|))))) (-638 (-290 (-413 (-959 (-171 (-572)))))) |#1|)) (-15 -4456 ((-638 (-290 (-959 (-171 |#1|)))) (-413 (-959 (-171 (-572)))) |#1|)) (-15 -4456 ((-638 (-290 (-959 (-171 |#1|)))) (-290 (-413 (-959 (-171 (-572))))) |#1|)) (-15 -3950 ((-638 (-171 |#1|)) (-413 (-959 (-171 (-572)))) |#1|)) (-15 -3950 ((-638 (-638 (-171 |#1|))) (-638 (-413 (-959 (-171 (-572))))) (-638 (-1170)) |#1|))) (-13 (-368) (-846))) (T -384)) 
-((-3950 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-413 (-959 (-171 (-572)))))) (-5 *4 (-638 (-1170))) (-5 *2 (-638 (-638 (-171 *5)))) (-5 *1 (-384 *5)) (-4 *5 (-13 (-368) (-846))))) (-3950 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-171 (-572))))) (-5 *2 (-638 (-171 *4))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846))))) (-4456 (*1 *2 *3 *4) (-12 (-5 *3 (-290 (-413 (-959 (-171 (-572)))))) (-5 *2 (-638 (-290 (-959 (-171 *4))))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846))))) (-4456 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-171 (-572))))) (-5 *2 (-638 (-290 (-959 (-171 *4))))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846))))) (-4456 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-290 (-413 (-959 (-171 (-572))))))) (-5 *2 (-638 (-638 (-290 (-959 (-171 *4)))))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846))))) (-4456 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-171 (-572)))))) (-5 *2 (-638 (-638 (-290 (-959 (-171 *4)))))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846)))))) 
-(-10 -7 (-15 -4456 ((-638 (-638 (-290 (-959 (-171 |#1|))))) (-638 (-413 (-959 (-171 (-572))))) |#1|)) (-15 -4456 ((-638 (-638 (-290 (-959 (-171 |#1|))))) (-638 (-290 (-413 (-959 (-171 (-572)))))) |#1|)) (-15 -4456 ((-638 (-290 (-959 (-171 |#1|)))) (-413 (-959 (-171 (-572)))) |#1|)) (-15 -4456 ((-638 (-290 (-959 (-171 |#1|)))) (-290 (-413 (-959 (-171 (-572))))) |#1|)) (-15 -3950 ((-638 (-171 |#1|)) (-413 (-959 (-171 (-572)))) |#1|)) (-15 -3950 ((-638 (-638 (-171 |#1|))) (-638 (-413 (-959 (-171 (-572))))) (-638 (-1170)) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 33)) (-2551 (((-572) $) 55)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2525 (($ $) 109)) (-4284 (($ $) 81)) (-4224 (($ $) 70)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4190 (($ $) 44)) (-3112 (((-121) $ $) NIL)) (-4273 (($ $) 79)) (-4217 (($ $) 68)) (-2433 (((-572) $) 63)) (-3351 (($ $ (-572)) 62)) (-4295 (($ $) NIL)) (-4233 (($ $) NIL)) (-2211 (($) NIL T CONST)) (-3599 (($ $) 111)) (-3376 (((-3 (-572) "failed") $) 187) (((-3 (-413 (-572)) "failed") $) 183)) (-1318 (((-572) $) 185) (((-413 (-572)) $) 181)) (-2190 (($ $ $) NIL)) (-4051 (((-572) $ $) 101)) (-1799 (((-3 $ "failed") $) 113)) (-4428 (((-413 (-572)) $ (-769)) 188) (((-413 (-572)) $ (-769) (-769)) 180)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1539 (((-923)) 72) (((-923) (-923)) 97 (|has| $ (-6 -4593)))) (-1908 (((-121) $) 105)) (-4184 (($) 40)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL)) (-2455 (((-1264) (-769)) 150)) (-4140 (((-1264)) 155) (((-1264) (-769)) 156)) (-4115 (((-1264)) 157) (((-1264) (-769)) 158)) (-3110 (((-1264)) 153) (((-1264) (-769)) 154)) (-3377 (((-572) $) 58)) (-3893 (((-121) $) 103)) (-1451 (($ $ (-572)) NIL)) (-3985 (($ $) 48)) (-4429 (($ $) NIL)) (-4472 (((-121) $) 35)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL) (($) NIL (-12 (-2959 (|has| $ (-6 -4585))) (-2959 (|has| $ (-6 -4593)))))) (-4238 (($ $ $) NIL) (($) 98 (-12 (-2959 (|has| $ (-6 -4585))) (-2959 (|has| $ (-6 -4593)))))) (-3917 (((-572) $) 17)) (-2504 (($) 86) (($ $) 91)) (-4082 (($) 90) (($ $) 92)) (-3539 (($ $) 82)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 115)) (-3794 (((-923) (-572)) 43 (|has| $ (-6 -4593)))) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) 53)) (-1716 (($ $) 108)) (-3997 (($ (-572) (-572)) 106) (($ (-572) (-572) (-923)) 107)) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3751 (((-572) $) 19)) (-2557 (($) 93)) (-4179 (($ $) 78)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-4465 (((-923)) 99) (((-923) (-923)) 100 (|has| $ (-6 -4593)))) (-3139 (($ $ (-769)) NIL) (($ $) 114)) (-1506 (((-923) (-572)) 47 (|has| $ (-6 -4593)))) (-4302 (($ $) NIL)) (-4237 (($ $) NIL)) (-4289 (($ $) NIL)) (-4228 (($ $) NIL)) (-4278 (($ $) 80)) (-4220 (($ $) 69)) (-4081 (((-385) $) 173) (((-217) $) 175) (((-893 (-385)) $) NIL) (((-1152) $) 160) (((-545) $) 171) (($ (-217)) 179)) (-3972 (((-856) $) 162) (($ (-572)) 184) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-572)) 184) (($ (-413 (-572))) NIL) (((-217) $) 176)) (-2140 (((-769)) NIL)) (-2634 (($ $) 110)) (-1813 (((-923)) 54) (((-923) (-923)) 65 (|has| $ (-6 -4593)))) (-4393 (((-923)) 102)) (-4321 (($ $) 85)) (-4251 (($ $) 46) (($ $ $) 52)) (-3774 (((-121) $ $) NIL)) (-4308 (($ $) 83)) (-4241 (($ $) 37)) (-4333 (($ $) NIL)) (-4263 (($ $) NIL)) (-2104 (($ $) NIL)) (-4268 (($ $) NIL)) (-4327 (($ $) NIL)) (-4257 (($ $) NIL)) (-4314 (($ $) 84)) (-4246 (($ $) 49)) (-2264 (($ $) 51)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 34 T CONST)) (-3255 (($) 38 T CONST)) (-3594 (((-1152) $) 27) (((-1152) $ (-121)) 29) (((-1264) (-823) $) 30) (((-1264) (-823) $ (-121)) 31)) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 39)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 42)) (-1379 (($ $ $) 45) (($ $ (-572)) 41)) (-1373 (($ $) 36) (($ $ $) 50)) (-1367 (($ $ $) 61)) (** (($ $ (-923)) 66) (($ $ (-769)) NIL) (($ $ (-572)) 87) (($ $ (-413 (-572))) 124) (($ $ $) 116)) (* (($ (-923) $) 64) (($ (-769) $) NIL) (($ (-572) $) 67) (($ $ $) 60) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL))) 
-(((-385) (-13 (-410) (-227) (-613 (-1152)) (-829) (-612 (-217)) (-1190) (-613 (-545)) (-10 -8 (-15 -1379 ($ $ (-572))) (-15 ** ($ $ $)) (-15 -3985 ($ $)) (-15 -4051 ((-572) $ $)) (-15 -3351 ($ $ (-572))) (-15 -4428 ((-413 (-572)) $ (-769))) (-15 -4428 ((-413 (-572)) $ (-769) (-769))) (-15 -2504 ($)) (-15 -4082 ($)) (-15 -2557 ($)) (-15 -4251 ($ $ $)) (-15 -2504 ($ $)) (-15 -4082 ($ $)) (-15 -4081 ($ (-217))) (-15 -4115 ((-1264))) (-15 -4115 ((-1264) (-769))) (-15 -3110 ((-1264))) (-15 -3110 ((-1264) (-769))) (-15 -4140 ((-1264))) (-15 -4140 ((-1264) (-769))) (-15 -2455 ((-1264) (-769))) (-6 -4593) (-6 -4585)))) (T -385)) 
-((** (*1 *1 *1 *1) (-5 *1 (-385))) (-1379 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-385)))) (-3985 (*1 *1 *1) (-5 *1 (-385))) (-4051 (*1 *2 *1 *1) (-12 (-5 *2 (-572)) (-5 *1 (-385)))) (-3351 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-385)))) (-4428 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-413 (-572))) (-5 *1 (-385)))) (-4428 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-413 (-572))) (-5 *1 (-385)))) (-2504 (*1 *1) (-5 *1 (-385))) (-4082 (*1 *1) (-5 *1 (-385))) (-2557 (*1 *1) (-5 *1 (-385))) (-4251 (*1 *1 *1 *1) (-5 *1 (-385))) (-2504 (*1 *1 *1) (-5 *1 (-385))) (-4082 (*1 *1 *1) (-5 *1 (-385))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-217)) (-5 *1 (-385)))) (-4115 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-385)))) (-4115 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-385)))) (-3110 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-385)))) (-3110 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-385)))) (-4140 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-385)))) (-4140 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-385)))) (-2455 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-385))))) 
-(-13 (-410) (-227) (-613 (-1152)) (-829) (-612 (-217)) (-1190) (-613 (-545)) (-10 -8 (-15 -1379 ($ $ (-572))) (-15 ** ($ $ $)) (-15 -3985 ($ $)) (-15 -4051 ((-572) $ $)) (-15 -3351 ($ $ (-572))) (-15 -4428 ((-413 (-572)) $ (-769))) (-15 -4428 ((-413 (-572)) $ (-769) (-769))) (-15 -2504 ($)) (-15 -4082 ($)) (-15 -2557 ($)) (-15 -4251 ($ $ $)) (-15 -2504 ($ $)) (-15 -4082 ($ $)) (-15 -4081 ($ (-217))) (-15 -4115 ((-1264))) (-15 -4115 ((-1264) (-769))) (-15 -3110 ((-1264))) (-15 -3110 ((-1264) (-769))) (-15 -4140 ((-1264))) (-15 -4140 ((-1264) (-769))) (-15 -2455 ((-1264) (-769))) (-6 -4593) (-6 -4585))) 
-((-2800 (((-638 (-290 (-959 |#1|))) (-290 (-413 (-959 (-572)))) |#1|) 47) (((-638 (-290 (-959 |#1|))) (-413 (-959 (-572))) |#1|) 46) (((-638 (-638 (-290 (-959 |#1|)))) (-638 (-290 (-413 (-959 (-572))))) |#1|) 42) (((-638 (-638 (-290 (-959 |#1|)))) (-638 (-413 (-959 (-572)))) |#1|) 36)) (-3400 (((-638 |#1|) (-413 (-959 (-572))) |#1|) 19) (((-638 (-638 |#1|)) (-638 (-413 (-959 (-572)))) (-638 (-1170)) |#1|) 31))) 
-(((-386 |#1|) (-10 -7 (-15 -2800 ((-638 (-638 (-290 (-959 |#1|)))) (-638 (-413 (-959 (-572)))) |#1|)) (-15 -2800 ((-638 (-638 (-290 (-959 |#1|)))) (-638 (-290 (-413 (-959 (-572))))) |#1|)) (-15 -2800 ((-638 (-290 (-959 |#1|))) (-413 (-959 (-572))) |#1|)) (-15 -2800 ((-638 (-290 (-959 |#1|))) (-290 (-413 (-959 (-572)))) |#1|)) (-15 -3400 ((-638 (-638 |#1|)) (-638 (-413 (-959 (-572)))) (-638 (-1170)) |#1|)) (-15 -3400 ((-638 |#1|) (-413 (-959 (-572))) |#1|))) (-13 (-846) (-368))) (T -386)) 
-((-3400 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-572)))) (-5 *2 (-638 *4)) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368))))) (-3400 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-1170))) (-5 *2 (-638 (-638 *5))) (-5 *1 (-386 *5)) (-4 *5 (-13 (-846) (-368))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-290 (-413 (-959 (-572))))) (-5 *2 (-638 (-290 (-959 *4)))) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-572)))) (-5 *2 (-638 (-290 (-959 *4)))) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-290 (-413 (-959 (-572)))))) (-5 *2 (-638 (-638 (-290 (-959 *4))))) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-638 (-290 (-959 *4))))) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368)))))) 
-(-10 -7 (-15 -2800 ((-638 (-638 (-290 (-959 |#1|)))) (-638 (-413 (-959 (-572)))) |#1|)) (-15 -2800 ((-638 (-638 (-290 (-959 |#1|)))) (-638 (-290 (-413 (-959 (-572))))) |#1|)) (-15 -2800 ((-638 (-290 (-959 |#1|))) (-413 (-959 (-572))) |#1|)) (-15 -2800 ((-638 (-290 (-959 |#1|))) (-290 (-413 (-959 (-572)))) |#1|)) (-15 -3400 ((-638 (-638 |#1|)) (-638 (-413 (-959 (-572)))) (-638 (-1170)) |#1|)) (-15 -3400 ((-638 |#1|) (-413 (-959 (-572))) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) 25)) (-1318 ((|#2| $) 27)) (-4383 (($ $) NIL)) (-3475 (((-769) $) 10)) (-3658 (((-638 $) $) 20)) (-4581 (((-121) $) NIL)) (-4518 (($ |#2| |#1|) 18)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-2081 (((-638 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 13)) (-4136 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) 14)) (-4368 ((|#2| $) 15)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 43) (($ |#2|) 26)) (-3193 (((-638 |#1|) $) 17)) (-1958 ((|#1| $ |#2|) 45)) (-2378 (($) 28 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ |#1| $) 31) (($ $ |#1|) 32) (($ |#1| |#2|) 33) (($ |#2| |#1|) 34))) 
-(((-387 |#1| |#2|) (-13 (-388 |#1| |#2|) (-10 -8 (-15 * ($ |#2| |#1|)))) (-1054) (-848)) (T -387)) 
-((* (*1 *1 *2 *3) (-12 (-5 *1 (-387 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-848))))) 
-(-13 (-388 |#1| |#2|) (-10 -8 (-15 * ($ |#2| |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#2| "failed") $) 41)) (-1318 ((|#2| $) 40)) (-4383 (($ $) 27)) (-3475 (((-769) $) 31)) (-3658 (((-638 $) $) 32)) (-4581 (((-121) $) 35)) (-4518 (($ |#2| |#1|) 36)) (-3828 (($ (-1 |#1| |#1|) $) 37)) (-2081 (((-638 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 34)) (-4136 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) 28)) (-4368 ((|#2| $) 30)) (-4373 ((|#1| $) 29)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ |#2|) 42)) (-3193 (((-638 |#1|) $) 33)) (-1958 ((|#1| $ |#2|) 38)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24) (($ |#1| |#2|) 39))) 
-(((-388 |#1| |#2|) (-1290) (-1054) (-1098)) (T -388)) 
-((* (*1 *1 *2 *3) (-12 (-4 *1 (-388 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-1098)))) (-1958 (*1 *2 *1 *3) (-12 (-4 *1 (-388 *2 *3)) (-4 *3 (-1098)) (-4 *2 (-1054)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)))) (-4518 (*1 *1 *2 *3) (-12 (-4 *1 (-388 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1098)))) (-4581 (*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-121)))) (-2081 (*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-638 (-2 (|:| |k| *4) (|:| |c| *3)))))) (-3193 (*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-638 *3)))) (-3658 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-638 *1)) (-4 *1 (-388 *3 *4)))) (-3475 (*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-769)))) (-4368 (*1 *2 *1) (-12 (-4 *1 (-388 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1098)))) (-4373 (*1 *2 *1) (-12 (-4 *1 (-388 *2 *3)) (-4 *3 (-1098)) (-4 *2 (-1054)))) (-4136 (*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-2 (|:| |k| *4) (|:| |c| *3))))) (-4383 (*1 *1 *1) (-12 (-4 *1 (-388 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-1098))))) 
-(-13 (-120 |t#1| |t#1|) (-1044 |t#2|) (-10 -8 (-15 * ($ |t#1| |t#2|)) (-15 -1958 (|t#1| $ |t#2|)) (-15 -3828 ($ (-1 |t#1| |t#1|) $)) (-15 -4518 ($ |t#2| |t#1|)) (-15 -4581 ((-121) $)) (-15 -2081 ((-638 (-2 (|:| |k| |t#2|) (|:| |c| |t#1|))) $)) (-15 -3193 ((-638 |t#1|) $)) (-15 -3658 ((-638 $) $)) (-15 -3475 ((-769) $)) (-15 -4368 (|t#2| $)) (-15 -4373 (|t#1| $)) (-15 -4136 ((-2 (|:| |k| |t#2|) (|:| |c| |t#1|)) $)) (-15 -4383 ($ $)) (IF (|has| |t#1| (-174)) (-6 (-713 |t#1|)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-713 |#1|) |has| |#1| (-174)) ((-1044 |#2|) . T) ((-1060 |#1|) . T) ((-1098) . T)) 
-((-4355 (((-1264) $) 7)) (-3972 (((-856) $) 8) (($ (-685 (-694))) 12) (($ (-638 (-330))) 11) (($ (-330)) 10) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 9))) 
-(((-389) (-1290)) (T -389)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-685 (-694))) (-4 *1 (-389)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-389)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-389)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-389))))) 
-(-13 (-401) (-10 -8 (-15 -3972 ($ (-685 (-694)))) (-15 -3972 ($ (-638 (-330)))) (-15 -3972 ($ (-330))) (-15 -3972 ($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330)))))))) 
-(((-612 (-856)) . T) ((-401) . T) ((-1204) . T)) 
-((-3376 (((-3 $ "failed") (-685 (-312 (-385)))) 19) (((-3 $ "failed") (-685 (-312 (-572)))) 17) (((-3 $ "failed") (-685 (-959 (-385)))) 15) (((-3 $ "failed") (-685 (-959 (-572)))) 13) (((-3 $ "failed") (-685 (-413 (-959 (-385))))) 11) (((-3 $ "failed") (-685 (-413 (-959 (-572))))) 9)) (-1318 (($ (-685 (-312 (-385)))) 20) (($ (-685 (-312 (-572)))) 18) (($ (-685 (-959 (-385)))) 16) (($ (-685 (-959 (-572)))) 14) (($ (-685 (-413 (-959 (-385))))) 12) (($ (-685 (-413 (-959 (-572))))) 10)) (-4355 (((-1264) $) 7)) (-3972 (((-856) $) 8) (($ (-638 (-330))) 23) (($ (-330)) 22) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 21))) 
-(((-390) (-1290)) (T -390)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-390)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-390)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-390)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-685 (-312 (-385)))) (-4 *1 (-390)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-312 (-385)))) (-4 *1 (-390)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-685 (-312 (-572)))) (-4 *1 (-390)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-312 (-572)))) (-4 *1 (-390)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-685 (-959 (-385)))) (-4 *1 (-390)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-959 (-385)))) (-4 *1 (-390)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-685 (-959 (-572)))) (-4 *1 (-390)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-959 (-572)))) (-4 *1 (-390)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-685 (-413 (-959 (-385))))) (-4 *1 (-390)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-413 (-959 (-385))))) (-4 *1 (-390)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-685 (-413 (-959 (-572))))) (-4 *1 (-390)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-413 (-959 (-572))))) (-4 *1 (-390))))) 
-(-13 (-401) (-10 -8 (-15 -3972 ($ (-638 (-330)))) (-15 -3972 ($ (-330))) (-15 -3972 ($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330)))))) (-15 -1318 ($ (-685 (-312 (-385))))) (-15 -3376 ((-3 $ "failed") (-685 (-312 (-385))))) (-15 -1318 ($ (-685 (-312 (-572))))) (-15 -3376 ((-3 $ "failed") (-685 (-312 (-572))))) (-15 -1318 ($ (-685 (-959 (-385))))) (-15 -3376 ((-3 $ "failed") (-685 (-959 (-385))))) (-15 -1318 ($ (-685 (-959 (-572))))) (-15 -3376 ((-3 $ "failed") (-685 (-959 (-572))))) (-15 -1318 ($ (-685 (-413 (-959 (-385)))))) (-15 -3376 ((-3 $ "failed") (-685 (-413 (-959 (-385)))))) (-15 -1318 ($ (-685 (-413 (-959 (-572)))))) (-15 -3376 ((-3 $ "failed") (-685 (-413 (-959 (-572)))))))) 
-(((-612 (-856)) . T) ((-401) . T) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-4328 (($ |#1| |#2|) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-1692 ((|#2| $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 27)) (-2378 (($) 12 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ |#1| $) 16) (($ $ |#1|) 18))) 
-(((-391 |#1| |#2|) (-13 (-120 |#1| |#1|) (-522 |#1| |#2|) (-10 -7 (IF (|has| |#1| (-174)) (-6 (-713 |#1|)) |noBranch|))) (-1054) (-848)) (T -391)) 
-NIL 
-(-13 (-120 |#1| |#1|) (-522 |#1| |#2|) (-10 -7 (IF (|has| |#1| (-174)) (-6 (-713 |#1|)) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1685 (((-769) $) 56)) (-2211 (($) NIL T CONST)) (-3754 (((-3 $ "failed") $ $) 58)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2946 (((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) 52)) (-3893 (((-121) $) 14)) (-4351 ((|#1| $ (-572)) NIL)) (-1606 (((-769) $ (-572)) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3629 (($ (-1 |#1| |#1|) $) 37)) (-1538 (($ (-1 (-769) (-769)) $) 34)) (-3561 (((-3 $ "failed") $ $) 49)) (-1658 (((-1152) $) NIL)) (-2716 (($ $ $) 25)) (-3852 (($ $ $) 23)) (-2607 (((-1116) $) NIL)) (-4547 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-769)))) $) 31)) (-2541 (((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $) 55)) (-3972 (((-856) $) 21) (($ |#1|) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-3255 (($) 9 T CONST)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) 41)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) 60 (|has| |#1| (-848)))) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ |#1| (-769)) 40)) (* (($ $ $) 47) (($ |#1| $) 29) (($ $ |#1|) 27))) 
-(((-392 |#1|) (-13 (-722) (-1044 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-769))) (-15 -3852 ($ $ $)) (-15 -2716 ($ $ $)) (-15 -3561 ((-3 $ "failed") $ $)) (-15 -3754 ((-3 $ "failed") $ $)) (-15 -2541 ((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $)) (-15 -2946 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -1685 ((-769) $)) (-15 -4547 ((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-769)))) $)) (-15 -1606 ((-769) $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -1538 ($ (-1 (-769) (-769)) $)) (-15 -3629 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-848)) (-6 (-848)) |noBranch|))) (-1098)) (T -392)) 
-((* (*1 *1 *2 *1) (-12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-5 *1 (-392 *2)) (-4 *2 (-1098)))) (-3852 (*1 *1 *1 *1) (-12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) (-2716 (*1 *1 *1 *1) (-12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) (-3561 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) (-3754 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) (-2541 (*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-392 *3)) (|:| |rm| (-392 *3)))) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) (-2946 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-392 *3)) (|:| |mm| (-392 *3)) (|:| |rm| (-392 *3)))) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) (-1685 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) (-4547 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 (-769))))) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) (-1606 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-769)) (-5 *1 (-392 *4)) (-4 *4 (-1098)))) (-4351 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-392 *2)) (-4 *2 (-1098)))) (-1538 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-769) (-769))) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) (-3629 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-392 *3))))) 
-(-13 (-722) (-1044 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-769))) (-15 -3852 ($ $ $)) (-15 -2716 ($ $ $)) (-15 -3561 ((-3 $ "failed") $ $)) (-15 -3754 ((-3 $ "failed") $ $)) (-15 -2541 ((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $)) (-15 -2946 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -1685 ((-769) $)) (-15 -4547 ((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-769)))) $)) (-15 -1606 ((-769) $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -1538 ($ (-1 (-769) (-769)) $)) (-15 -3629 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-848)) (-6 (-848)) |noBranch|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 46)) (-1318 (((-572) $) 45)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1771 (($ $ $) 53)) (-4238 (($ $ $) 52)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ $) 41)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-572)) 47)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1349 (((-121) $ $) 50)) (-1338 (((-121) $ $) 49)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 51)) (-1334 (((-121) $ $) 48)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-393) (-1290)) (T -393)) 
-NIL 
-(-13 (-562) (-848) (-1044 (-572))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-848) . T) ((-1044 (-572)) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1852 (((-121) $) 20)) (-3689 (((-121) $) 19)) (-1364 (($ (-1152) (-1152) (-1152)) 21)) (-3201 (((-1152) $) 16)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4344 (($ (-1152) (-1152) (-1152)) 14)) (-1476 (((-1152) $) 17)) (-4481 (((-121) $) 18)) (-1577 (((-1152) $) 15)) (-3972 (((-856) $) 12) (($ (-1152)) 13) (((-1152) $) 9)) (-1324 (((-121) $ $) 7))) 
-(((-394) (-395)) (T -394)) 
-NIL 
-(-395) 
-((-2262 (((-121) $ $) 7)) (-1852 (((-121) $) 13)) (-3689 (((-121) $) 14)) (-1364 (($ (-1152) (-1152) (-1152)) 12)) (-3201 (((-1152) $) 17)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4344 (($ (-1152) (-1152) (-1152)) 19)) (-1476 (((-1152) $) 16)) (-4481 (((-121) $) 15)) (-1577 (((-1152) $) 18)) (-3972 (((-856) $) 11) (($ (-1152)) 21) (((-1152) $) 20)) (-1324 (((-121) $ $) 6))) 
-(((-395) (-1290)) (T -395)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-4 *1 (-395)))) (-3972 (*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-1152)))) (-4344 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-1152)) (-4 *1 (-395)))) (-1577 (*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-1152)))) (-3201 (*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-1152)))) (-1476 (*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-1152)))) (-4481 (*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-121)))) (-3689 (*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-121)))) (-1852 (*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-121)))) (-1364 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-1152)) (-4 *1 (-395))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-1152))) (-15 -3972 ((-1152) $)) (-15 -4344 ($ (-1152) (-1152) (-1152))) (-15 -1577 ((-1152) $)) (-15 -3201 ((-1152) $)) (-15 -1476 ((-1152) $)) (-15 -4481 ((-121) $)) (-15 -3689 ((-121) $)) (-15 -1852 ((-121) $)) (-15 -1364 ($ (-1152) (-1152) (-1152))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-3477 (((-856) $) 50)) (-2211 (($) NIL T CONST)) (-3014 (($ $ (-923)) NIL)) (-2027 (($ $ (-923)) NIL)) (-3276 (($ $ (-923)) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2307 (($ (-769)) 26)) (-2502 (((-769)) 15)) (-3023 (((-856) $) 52)) (-4056 (($ $ $) NIL)) (-3972 (((-856) $) NIL)) (-4250 (($ $ $ $) NIL)) (-1397 (($ $ $) NIL)) (-2378 (($) 20 T CONST)) (-1324 (((-121) $ $) 28)) (-1373 (($ $) 34) (($ $ $) 36)) (-1367 (($ $ $) 37)) (** (($ $ (-923)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 38) (($ $ |#3|) NIL) (($ |#3| $) 33))) 
-(((-396 |#1| |#2| |#3|) (-13 (-742 |#3|) (-10 -8 (-15 -2502 ((-769))) (-15 -3023 ((-856) $)) (-15 -3477 ((-856) $)) (-15 -2307 ($ (-769))))) (-769) (-769) (-174)) (T -396)) 
-((-2502 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-396 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-174)))) (-3023 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-396 *3 *4 *5)) (-14 *3 (-769)) (-14 *4 (-769)) (-4 *5 (-174)))) (-3477 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-396 *3 *4 *5)) (-14 *3 (-769)) (-14 *4 (-769)) (-4 *5 (-174)))) (-2307 (*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-396 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-174))))) 
-(-13 (-742 |#3|) (-10 -8 (-15 -2502 ((-769))) (-15 -3023 ((-856) $)) (-15 -3477 ((-856) $)) (-15 -2307 ($ (-769))))) 
-((-3862 (((-1152)) 10)) (-4396 (((-1140 (-1152))) 28)) (-4339 (((-1264) (-1152)) 25) (((-1264) (-394)) 24)) (-4349 (((-1264)) 26)) (-1777 (((-1140 (-1152))) 27))) 
-(((-397) (-10 -7 (-15 -1777 ((-1140 (-1152)))) (-15 -4396 ((-1140 (-1152)))) (-15 -4349 ((-1264))) (-15 -4339 ((-1264) (-394))) (-15 -4339 ((-1264) (-1152))) (-15 -3862 ((-1152))))) (T -397)) 
-((-3862 (*1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-397)))) (-4339 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-397)))) (-4339 (*1 *2 *3) (-12 (-5 *3 (-394)) (-5 *2 (-1264)) (-5 *1 (-397)))) (-4349 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-397)))) (-4396 (*1 *2) (-12 (-5 *2 (-1140 (-1152))) (-5 *1 (-397)))) (-1777 (*1 *2) (-12 (-5 *2 (-1140 (-1152))) (-5 *1 (-397))))) 
-(-10 -7 (-15 -1777 ((-1140 (-1152)))) (-15 -4396 ((-1140 (-1152)))) (-15 -4349 ((-1264))) (-15 -4339 ((-1264) (-394))) (-15 -4339 ((-1264) (-1152))) (-15 -3862 ((-1152)))) 
-((-3377 (((-769) (-336 |#1| |#2| |#3| |#4|)) 16))) 
-(((-398 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3377 ((-769) (-336 |#1| |#2| |#3| |#4|)))) (-13 (-374) (-368)) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|)) (T -398)) 
-((-3377 (*1 *2 *3) (-12 (-5 *3 (-336 *4 *5 *6 *7)) (-4 *4 (-13 (-374) (-368))) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-4 *7 (-342 *4 *5 *6)) (-5 *2 (-769)) (-5 *1 (-398 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -3377 ((-769) (-336 |#1| |#2| |#3| |#4|)))) 
-((-3972 (((-400) |#1|) 11))) 
-(((-399 |#1|) (-10 -7 (-15 -3972 ((-400) |#1|))) (-1098)) (T -399)) 
-((-3972 (*1 *2 *3) (-12 (-5 *2 (-400)) (-5 *1 (-399 *3)) (-4 *3 (-1098))))) 
-(-10 -7 (-15 -3972 ((-400) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-3044 (((-638 (-1152)) $ (-638 (-1152))) 37)) (-4186 (((-638 (-1152)) $ (-638 (-1152))) 38)) (-2926 (((-638 (-1152)) $ (-638 (-1152))) 39)) (-2741 (((-638 (-1152)) $) 34)) (-1364 (($) 23)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3742 (((-638 (-1152)) $) 35)) (-2443 (((-638 (-1152)) $) 36)) (-2415 (((-1264) $ (-572)) 32) (((-1264) $) 33)) (-4081 (($ (-856) (-572)) 29)) (-3972 (((-856) $) 41) (($ (-856)) 25)) (-1324 (((-121) $ $) NIL))) 
-(((-400) (-13 (-1098) (-10 -8 (-15 -3972 ($ (-856))) (-15 -4081 ($ (-856) (-572))) (-15 -2415 ((-1264) $ (-572))) (-15 -2415 ((-1264) $)) (-15 -2443 ((-638 (-1152)) $)) (-15 -3742 ((-638 (-1152)) $)) (-15 -1364 ($)) (-15 -2741 ((-638 (-1152)) $)) (-15 -2926 ((-638 (-1152)) $ (-638 (-1152)))) (-15 -4186 ((-638 (-1152)) $ (-638 (-1152)))) (-15 -3044 ((-638 (-1152)) $ (-638 (-1152))))))) (T -400)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-400)))) (-4081 (*1 *1 *2 *3) (-12 (-5 *2 (-856)) (-5 *3 (-572)) (-5 *1 (-400)))) (-2415 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-400)))) (-2415 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-400)))) (-2443 (*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) (-3742 (*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) (-1364 (*1 *1) (-5 *1 (-400))) (-2741 (*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) (-2926 (*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) (-4186 (*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) (-3044 (*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-856))) (-15 -4081 ($ (-856) (-572))) (-15 -2415 ((-1264) $ (-572))) (-15 -2415 ((-1264) $)) (-15 -2443 ((-638 (-1152)) $)) (-15 -3742 ((-638 (-1152)) $)) (-15 -1364 ($)) (-15 -2741 ((-638 (-1152)) $)) (-15 -2926 ((-638 (-1152)) $ (-638 (-1152)))) (-15 -4186 ((-638 (-1152)) $ (-638 (-1152)))) (-15 -3044 ((-638 (-1152)) $ (-638 (-1152)))))) 
-((-4355 (((-1264) $) 7)) (-3972 (((-856) $) 8))) 
-(((-401) (-1290)) (T -401)) 
-((-4355 (*1 *2 *1) (-12 (-4 *1 (-401)) (-5 *2 (-1264))))) 
-(-13 (-1204) (-612 (-856)) (-10 -8 (-15 -4355 ((-1264) $)))) 
-(((-612 (-856)) . T) ((-1204) . T)) 
-((-3376 (((-3 $ "failed") (-312 (-385))) 19) (((-3 $ "failed") (-312 (-572))) 17) (((-3 $ "failed") (-959 (-385))) 15) (((-3 $ "failed") (-959 (-572))) 13) (((-3 $ "failed") (-413 (-959 (-385)))) 11) (((-3 $ "failed") (-413 (-959 (-572)))) 9)) (-1318 (($ (-312 (-385))) 20) (($ (-312 (-572))) 18) (($ (-959 (-385))) 16) (($ (-959 (-572))) 14) (($ (-413 (-959 (-385)))) 12) (($ (-413 (-959 (-572)))) 10)) (-4355 (((-1264) $) 7)) (-3972 (((-856) $) 8) (($ (-638 (-330))) 23) (($ (-330)) 22) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 21))) 
-(((-402) (-1290)) (T -402)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-402)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-402)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-402)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-312 (-385))) (-4 *1 (-402)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-312 (-385))) (-4 *1 (-402)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-312 (-572))) (-4 *1 (-402)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-312 (-572))) (-4 *1 (-402)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-959 (-385))) (-4 *1 (-402)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-385))) (-4 *1 (-402)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-959 (-572))) (-4 *1 (-402)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-572))) (-4 *1 (-402)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-385)))) (-4 *1 (-402)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-413 (-959 (-385)))) (-4 *1 (-402)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-572)))) (-4 *1 (-402)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-413 (-959 (-572)))) (-4 *1 (-402))))) 
-(-13 (-401) (-10 -8 (-15 -3972 ($ (-638 (-330)))) (-15 -3972 ($ (-330))) (-15 -3972 ($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330)))))) (-15 -1318 ($ (-312 (-385)))) (-15 -3376 ((-3 $ "failed") (-312 (-385)))) (-15 -1318 ($ (-312 (-572)))) (-15 -3376 ((-3 $ "failed") (-312 (-572)))) (-15 -1318 ($ (-959 (-385)))) (-15 -3376 ((-3 $ "failed") (-959 (-385)))) (-15 -1318 ($ (-959 (-572)))) (-15 -3376 ((-3 $ "failed") (-959 (-572)))) (-15 -1318 ($ (-413 (-959 (-385))))) (-15 -3376 ((-3 $ "failed") (-413 (-959 (-385))))) (-15 -1318 ($ (-413 (-959 (-572))))) (-15 -3376 ((-3 $ "failed") (-413 (-959 (-572))))))) 
-(((-612 (-856)) . T) ((-401) . T) ((-1204) . T)) 
-((-4443 (((-638 (-1152)) (-638 (-1152))) 8)) (-4355 (((-1264) (-394)) 27)) (-3994 (((-1102) (-1170) (-638 (-1170)) (-1173) (-638 (-1170))) 59) (((-1102) (-1170) (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170)))) (-638 (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170))))) (-638 (-1170)) (-1170)) 35) (((-1102) (-1170) (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170)))) (-638 (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170))))) (-638 (-1170))) 34))) 
-(((-403) (-10 -7 (-15 -3994 ((-1102) (-1170) (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170)))) (-638 (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170))))) (-638 (-1170)))) (-15 -3994 ((-1102) (-1170) (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170)))) (-638 (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170))))) (-638 (-1170)) (-1170))) (-15 -3994 ((-1102) (-1170) (-638 (-1170)) (-1173) (-638 (-1170)))) (-15 -4355 ((-1264) (-394))) (-15 -4443 ((-638 (-1152)) (-638 (-1152)))))) (T -403)) 
-((-4443 (*1 *2 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-403)))) (-4355 (*1 *2 *3) (-12 (-5 *3 (-394)) (-5 *2 (-1264)) (-5 *1 (-403)))) (-3994 (*1 *2 *3 *4 *5 *4) (-12 (-5 *4 (-638 (-1170))) (-5 *5 (-1173)) (-5 *3 (-1170)) (-5 *2 (-1102)) (-5 *1 (-403)))) (-3994 (*1 *2 *3 *4 *5 *6 *3) (-12 (-5 *5 (-638 (-638 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-638 (-3 (|:| |array| (-638 *3)) (|:| |scalar| (-1170))))) (-5 *6 (-638 (-1170))) (-5 *3 (-1170)) (-5 *2 (-1102)) (-5 *1 (-403)))) (-3994 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-638 (-638 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-638 (-3 (|:| |array| (-638 *3)) (|:| |scalar| (-1170))))) (-5 *6 (-638 (-1170))) (-5 *3 (-1170)) (-5 *2 (-1102)) (-5 *1 (-403))))) 
-(-10 -7 (-15 -3994 ((-1102) (-1170) (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170)))) (-638 (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170))))) (-638 (-1170)))) (-15 -3994 ((-1102) (-1170) (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170)))) (-638 (-638 (-3 (|:| |array| (-638 (-1170))) (|:| |scalar| (-1170))))) (-638 (-1170)) (-1170))) (-15 -3994 ((-1102) (-1170) (-638 (-1170)) (-1173) (-638 (-1170)))) (-15 -4355 ((-1264) (-394))) (-15 -4443 ((-638 (-1152)) (-638 (-1152))))) 
-((-4355 (((-1264) $) 37)) (-3972 (((-856) $) 89) (($ (-330)) 92) (($ (-638 (-330))) 91) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 88) (($ (-312 (-696))) 52) (($ (-312 (-694))) 66) (($ (-312 (-689))) 78) (($ (-290 (-312 (-696)))) 62) (($ (-290 (-312 (-694)))) 74) (($ (-290 (-312 (-689)))) 86) (($ (-312 (-572))) 96) (($ (-312 (-385))) 108) (($ (-312 (-171 (-385)))) 120) (($ (-290 (-312 (-572)))) 104) (($ (-290 (-312 (-385)))) 116) (($ (-290 (-312 (-171 (-385))))) 128))) 
-(((-404 |#1| |#2| |#3| |#4|) (-13 (-401) (-10 -8 (-15 -3972 ($ (-330))) (-15 -3972 ($ (-638 (-330)))) (-15 -3972 ($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330)))))) (-15 -3972 ($ (-312 (-696)))) (-15 -3972 ($ (-312 (-694)))) (-15 -3972 ($ (-312 (-689)))) (-15 -3972 ($ (-290 (-312 (-696))))) (-15 -3972 ($ (-290 (-312 (-694))))) (-15 -3972 ($ (-290 (-312 (-689))))) (-15 -3972 ($ (-312 (-572)))) (-15 -3972 ($ (-312 (-385)))) (-15 -3972 ($ (-312 (-171 (-385))))) (-15 -3972 ($ (-290 (-312 (-572))))) (-15 -3972 ($ (-290 (-312 (-385))))) (-15 -3972 ($ (-290 (-312 (-171 (-385)))))))) (-1170) (-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-638 (-1170)) (-1174)) (T -404)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-330)) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-312 (-696))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-312 (-694))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-312 (-689))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-696)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-694)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-689)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-312 (-572))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-312 (-385))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-312 (-171 (-385)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-572)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-385)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-171 (-385))))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174))))) 
-(-13 (-401) (-10 -8 (-15 -3972 ($ (-330))) (-15 -3972 ($ (-638 (-330)))) (-15 -3972 ($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330)))))) (-15 -3972 ($ (-312 (-696)))) (-15 -3972 ($ (-312 (-694)))) (-15 -3972 ($ (-312 (-689)))) (-15 -3972 ($ (-290 (-312 (-696))))) (-15 -3972 ($ (-290 (-312 (-694))))) (-15 -3972 ($ (-290 (-312 (-689))))) (-15 -3972 ($ (-312 (-572)))) (-15 -3972 ($ (-312 (-385)))) (-15 -3972 ($ (-312 (-171 (-385))))) (-15 -3972 ($ (-290 (-312 (-572))))) (-15 -3972 ($ (-290 (-312 (-385))))) (-15 -3972 ($ (-290 (-312 (-171 (-385)))))))) 
-((-2262 (((-121) $ $) NIL)) (-2701 ((|#2| $) 36)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2001 (($ (-413 |#2|)) 84)) (-2146 (((-638 (-2 (|:| -3751 (-769)) (|:| -1694 |#2|) (|:| |num| |#2|))) $) 37)) (-3139 (($ $) 32) (($ $ (-769)) 34)) (-4081 (((-413 |#2|) $) 46)) (-3921 (($ (-638 (-2 (|:| -3751 (-769)) (|:| -1694 |#2|) (|:| |num| |#2|)))) 31)) (-3972 (((-856) $) 120)) (-1557 (($ $) 33) (($ $ (-769)) 35)) (-1324 (((-121) $ $) NIL)) (-1367 (($ |#2| $) 39))) 
-(((-405 |#1| |#2|) (-13 (-1098) (-613 (-413 |#2|)) (-10 -8 (-15 -1367 ($ |#2| $)) (-15 -2001 ($ (-413 |#2|))) (-15 -2701 (|#2| $)) (-15 -2146 ((-638 (-2 (|:| -3751 (-769)) (|:| -1694 |#2|) (|:| |num| |#2|))) $)) (-15 -3921 ($ (-638 (-2 (|:| -3751 (-769)) (|:| -1694 |#2|) (|:| |num| |#2|))))) (-15 -3139 ($ $)) (-15 -1557 ($ $)) (-15 -3139 ($ $ (-769))) (-15 -1557 ($ $ (-769))))) (-13 (-368) (-151)) (-1234 |#1|)) (T -405)) 
-((-1367 (*1 *1 *2 *1) (-12 (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *2)) (-4 *2 (-1234 *3)))) (-2001 (*1 *1 *2) (-12 (-5 *2 (-413 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *4)))) (-2701 (*1 *2 *1) (-12 (-4 *2 (-1234 *3)) (-5 *1 (-405 *3 *2)) (-4 *3 (-13 (-368) (-151))))) (-2146 (*1 *2 *1) (-12 (-4 *3 (-13 (-368) (-151))) (-5 *2 (-638 (-2 (|:| -3751 (-769)) (|:| -1694 *4) (|:| |num| *4)))) (-5 *1 (-405 *3 *4)) (-4 *4 (-1234 *3)))) (-3921 (*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -3751 (-769)) (|:| -1694 *4) (|:| |num| *4)))) (-4 *4 (-1234 *3)) (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *4)))) (-3139 (*1 *1 *1) (-12 (-4 *2 (-13 (-368) (-151))) (-5 *1 (-405 *2 *3)) (-4 *3 (-1234 *2)))) (-1557 (*1 *1 *1) (-12 (-4 *2 (-13 (-368) (-151))) (-5 *1 (-405 *2 *3)) (-4 *3 (-1234 *2)))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *4)) (-4 *4 (-1234 *3)))) (-1557 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *4)) (-4 *4 (-1234 *3))))) 
-(-13 (-1098) (-613 (-413 |#2|)) (-10 -8 (-15 -1367 ($ |#2| $)) (-15 -2001 ($ (-413 |#2|))) (-15 -2701 (|#2| $)) (-15 -2146 ((-638 (-2 (|:| -3751 (-769)) (|:| -1694 |#2|) (|:| |num| |#2|))) $)) (-15 -3921 ($ (-638 (-2 (|:| -3751 (-769)) (|:| -1694 |#2|) (|:| |num| |#2|))))) (-15 -3139 ($ $)) (-15 -1557 ($ $)) (-15 -3139 ($ $ (-769))) (-15 -1557 ($ $ (-769))))) 
-((-2262 (((-121) $ $) 9 (-1841 (|has| |#1| (-887 (-572))) (|has| |#1| (-887 (-385)))))) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 15 (|has| |#1| (-887 (-385)))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 14 (|has| |#1| (-887 (-572))))) (-1658 (((-1152) $) 13 (-1841 (|has| |#1| (-887 (-572))) (|has| |#1| (-887 (-385)))))) (-2607 (((-1116) $) 12 (-1841 (|has| |#1| (-887 (-572))) (|has| |#1| (-887 (-385)))))) (-3972 (((-856) $) 11 (-1841 (|has| |#1| (-887 (-572))) (|has| |#1| (-887 (-385)))))) (-1324 (((-121) $ $) 10 (-1841 (|has| |#1| (-887 (-572))) (|has| |#1| (-887 (-385))))))) 
-(((-406 |#1|) (-1290) (-1204)) (T -406)) 
-NIL 
-(-13 (-1204) (-10 -7 (IF (|has| |t#1| (-887 (-572))) (-6 (-887 (-572))) |noBranch|) (IF (|has| |t#1| (-887 (-385))) (-6 (-887 (-385))) |noBranch|))) 
-(((-105) -1841 (|has| |#1| (-887 (-572))) (|has| |#1| (-887 (-385)))) ((-612 (-856)) -1841 (|has| |#1| (-887 (-572))) (|has| |#1| (-887 (-385)))) ((-887 (-385)) |has| |#1| (-887 (-385))) ((-887 (-572)) |has| |#1| (-887 (-572))) ((-1098) -1841 (|has| |#1| (-887 (-572))) (|has| |#1| (-887 (-385)))) ((-1204) . T)) 
-((-4486 (($ $) 10) (($ $ (-769)) 11))) 
-(((-407 |#1|) (-10 -8 (-15 -4486 (|#1| |#1| (-769))) (-15 -4486 (|#1| |#1|))) (-408)) (T -407)) 
-NIL 
-(-10 -8 (-15 -4486 (|#1| |#1| (-769))) (-15 -4486 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-2211 (($) 16 T CONST)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-4486 (($ $) 75) (($ $ (-769)) 74)) (-1526 (((-121) $) 69)) (-3377 (((-834 (-923)) $) 77)) (-3893 (((-121) $) 30)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3158 (((-3 (-769) "failed") $ $) 76)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63)) (-2779 (((-3 $ "failed") $) 78)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64))) 
-(((-408) (-1290)) (T -408)) 
-((-3377 (*1 *2 *1) (-12 (-4 *1 (-408)) (-5 *2 (-834 (-923))))) (-3158 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-408)) (-5 *2 (-769)))) (-4486 (*1 *1 *1) (-4 *1 (-408))) (-4486 (*1 *1 *1 *2) (-12 (-4 *1 (-408)) (-5 *2 (-769))))) 
-(-13 (-368) (-149) (-10 -8 (-15 -3377 ((-834 (-923)) $)) (-15 -3158 ((-3 (-769) "failed") $ $)) (-15 -4486 ($ $)) (-15 -4486 ($ $ (-769))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-149) . T) ((-612 (-856)) . T) ((-174) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T)) 
-((-3997 (($ (-572) (-572)) 11) (($ (-572) (-572) (-923)) NIL)) (-4465 (((-923)) 16) (((-923) (-923)) NIL))) 
-(((-409 |#1|) (-10 -8 (-15 -4465 ((-923) (-923))) (-15 -4465 ((-923))) (-15 -3997 (|#1| (-572) (-572) (-923))) (-15 -3997 (|#1| (-572) (-572)))) (-410)) (T -409)) 
-((-4465 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-409 *3)) (-4 *3 (-410)))) (-4465 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-409 *3)) (-4 *3 (-410))))) 
-(-10 -8 (-15 -4465 ((-923) (-923))) (-15 -4465 ((-923))) (-15 -3997 (|#1| (-572) (-572) (-923))) (-15 -3997 (|#1| (-572) (-572)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2551 (((-572) $) 85)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-2525 (($ $) 83)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-4190 (($ $) 93)) (-3112 (((-121) $ $) 57)) (-2433 (((-572) $) 110)) (-2211 (($) 16 T CONST)) (-3599 (($ $) 82)) (-3376 (((-3 (-572) "failed") $) 98) (((-3 (-413 (-572)) "failed") $) 95)) (-1318 (((-572) $) 97) (((-413 (-572)) $) 94)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-1526 (((-121) $) 69)) (-1539 (((-923)) 119) (((-923) (-923)) 116 (|has| $ (-6 -4593)))) (-1908 (((-121) $) 108)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 89)) (-3377 (((-572) $) 125)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 92)) (-4429 (($ $) 88)) (-4472 (((-121) $) 109)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-1771 (($ $ $) 107) (($) 113 (-12 (-2959 (|has| $ (-6 -4593))) (-2959 (|has| $ (-6 -4585)))))) (-4238 (($ $ $) 106) (($) 112 (-12 (-2959 (|has| $ (-6 -4593))) (-2959 (|has| $ (-6 -4585)))))) (-3917 (((-572) $) 122)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-3794 (((-923) (-572)) 115 (|has| $ (-6 -4593)))) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-3346 (($ $) 84)) (-1716 (($ $) 86)) (-3997 (($ (-572) (-572)) 127) (($ (-572) (-572) (-923)) 126)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-3751 (((-572) $) 123)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-4465 (((-923)) 120) (((-923) (-923)) 117 (|has| $ (-6 -4593)))) (-1506 (((-923) (-572)) 114 (|has| $ (-6 -4593)))) (-4081 (((-385) $) 101) (((-217) $) 100) (((-893 (-385)) $) 90)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ (-572)) 99) (($ (-413 (-572))) 96)) (-2140 (((-769)) 28)) (-2634 (($ $) 87)) (-1813 (((-923)) 121) (((-923) (-923)) 118 (|has| $ (-6 -4593)))) (-4393 (((-923)) 124)) (-3774 (((-121) $ $) 38)) (-2264 (($ $) 111)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1349 (((-121) $ $) 104)) (-1338 (((-121) $ $) 103)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 105)) (-1334 (((-121) $ $) 102)) (-1379 (($ $ $) 62)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66) (($ $ (-413 (-572))) 91)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64))) 
-(((-410) (-1290)) (T -410)) 
-((-3997 (*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-4 *1 (-410)))) (-3997 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-572)) (-5 *3 (-923)) (-4 *1 (-410)))) (-3377 (*1 *2 *1) (-12 (-4 *1 (-410)) (-5 *2 (-572)))) (-4393 (*1 *2) (-12 (-4 *1 (-410)) (-5 *2 (-923)))) (-3751 (*1 *2 *1) (-12 (-4 *1 (-410)) (-5 *2 (-572)))) (-3917 (*1 *2 *1) (-12 (-4 *1 (-410)) (-5 *2 (-572)))) (-1813 (*1 *2) (-12 (-4 *1 (-410)) (-5 *2 (-923)))) (-4465 (*1 *2) (-12 (-4 *1 (-410)) (-5 *2 (-923)))) (-1539 (*1 *2) (-12 (-4 *1 (-410)) (-5 *2 (-923)))) (-1813 (*1 *2 *2) (-12 (-5 *2 (-923)) (|has| *1 (-6 -4593)) (-4 *1 (-410)))) (-4465 (*1 *2 *2) (-12 (-5 *2 (-923)) (|has| *1 (-6 -4593)) (-4 *1 (-410)))) (-1539 (*1 *2 *2) (-12 (-5 *2 (-923)) (|has| *1 (-6 -4593)) (-4 *1 (-410)))) (-3794 (*1 *2 *3) (-12 (-5 *3 (-572)) (|has| *1 (-6 -4593)) (-4 *1 (-410)) (-5 *2 (-923)))) (-1506 (*1 *2 *3) (-12 (-5 *3 (-572)) (|has| *1 (-6 -4593)) (-4 *1 (-410)) (-5 *2 (-923)))) (-1771 (*1 *1) (-12 (-4 *1 (-410)) (-2959 (|has| *1 (-6 -4593))) (-2959 (|has| *1 (-6 -4585))))) (-4238 (*1 *1) (-12 (-4 *1 (-410)) (-2959 (|has| *1 (-6 -4593))) (-2959 (|has| *1 (-6 -4585)))))) 
-(-13 (-1063) (-10 -8 (-6 -3410) (-15 -3997 ($ (-572) (-572))) (-15 -3997 ($ (-572) (-572) (-923))) (-15 -3377 ((-572) $)) (-15 -4393 ((-923))) (-15 -3751 ((-572) $)) (-15 -3917 ((-572) $)) (-15 -1813 ((-923))) (-15 -4465 ((-923))) (-15 -1539 ((-923))) (IF (|has| $ (-6 -4593)) (PROGN (-15 -1813 ((-923) (-923))) (-15 -4465 ((-923) (-923))) (-15 -1539 ((-923) (-923))) (-15 -3794 ((-923) (-572))) (-15 -1506 ((-923) (-572)))) |noBranch|) (IF (|has| $ (-6 -4585)) |noBranch| (IF (|has| $ (-6 -4593)) |noBranch| (PROGN (-15 -1771 ($)) (-15 -4238 ($))))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-151) . T) ((-612 (-856)) . T) ((-174) . T) ((-613 (-217)) . T) ((-613 (-385)) . T) ((-613 (-893 (-385))) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-792) . T) ((-793) . T) ((-795) . T) ((-796) . T) ((-846) . T) ((-848) . T) ((-887 (-385)) . T) ((-922) . T) ((-1009) . T) ((-1028) . T) ((-1063) . T) ((-1044 (-413 (-572))) . T) ((-1044 (-572)) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T)) 
-((-3828 (((-424 |#2|) (-1 |#2| |#1|) (-424 |#1|)) 20))) 
-(((-411 |#1| |#2|) (-10 -7 (-15 -3828 ((-424 |#2|) (-1 |#2| |#1|) (-424 |#1|)))) (-562) (-562)) (T -411)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-424 *5)) (-4 *5 (-562)) (-4 *6 (-562)) (-5 *2 (-424 *6)) (-5 *1 (-411 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-424 |#2|) (-1 |#2| |#1|) (-424 |#1|)))) 
-((-3828 (((-413 |#2|) (-1 |#2| |#1|) (-413 |#1|)) 13))) 
-(((-412 |#1| |#2|) (-10 -7 (-15 -3828 ((-413 |#2|) (-1 |#2| |#1|) (-413 |#1|)))) (-562) (-562)) (T -412)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-413 *5)) (-4 *5 (-562)) (-4 *6 (-562)) (-5 *2 (-413 *6)) (-5 *1 (-412 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-413 |#2|) (-1 |#2| |#1|) (-413 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 13)) (-2551 ((|#1| $) 21 (|has| |#1| (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| |#1| (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 17) (((-3 (-1170) "failed") $) NIL (|has| |#1| (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) 70 (|has| |#1| (-1044 (-572)))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572))))) (-1318 ((|#1| $) 15) (((-1170) $) NIL (|has| |#1| (-1044 (-1170)))) (((-413 (-572)) $) 67 (|has| |#1| (-1044 (-572)))) (((-572) $) NIL (|has| |#1| (-1044 (-572))))) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) 50)) (-3286 (($) NIL (|has| |#1| (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) NIL (|has| |#1| (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| |#1| (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| |#1| (-887 (-385))))) (-3893 (((-121) $) 64)) (-4347 (($ $) NIL)) (-4487 ((|#1| $) 71)) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-1144)))) (-4472 (((-121) $) NIL (|has| |#1| (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| |#1| (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 97)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| |#1| (-303)))) (-1716 ((|#1| $) 28 (|has| |#1| (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) 133 (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) 129 (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) NIL (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) NIL (|has| |#1| (-527 (-1170) |#1|)))) (-4029 (((-769) $) NIL)) (-3277 (($ $ |#1|) NIL (|has| |#1| (-283 |#1| |#1|)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) 63)) (-3425 (($ $) NIL)) (-4492 ((|#1| $) 73)) (-4081 (((-893 (-572)) $) NIL (|has| |#1| (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| |#1| (-613 (-893 (-385))))) (((-545) $) NIL (|has| |#1| (-613 (-545)))) (((-385) $) NIL (|has| |#1| (-1028))) (((-217) $) NIL (|has| |#1| (-1028)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 113 (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) 10) (($ (-1170)) NIL (|has| |#1| (-1044 (-1170))))) (-2779 (((-3 $ "failed") $) 99 (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) 100)) (-2634 ((|#1| $) 26 (|has| |#1| (-554)))) (-3774 (((-121) $ $) NIL)) (-2264 (($ $) NIL (|has| |#1| (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 22 T CONST)) (-3255 (($) 8 T CONST)) (-3594 (((-1152) $) 43 (-12 (|has| |#1| (-554)) (|has| |#1| (-829)))) (((-1152) $ (-121)) 44 (-12 (|has| |#1| (-554)) (|has| |#1| (-829)))) (((-1264) (-823) $) 45 (-12 (|has| |#1| (-554)) (|has| |#1| (-829)))) (((-1264) (-823) $ (-121)) 46 (-12 (|has| |#1| (-554)) (|has| |#1| (-829))))) (-1557 (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) 56)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) 24 (|has| |#1| (-848)))) (-1379 (($ $ $) 124) (($ |#1| |#1|) 52)) (-1373 (($ $) 25) (($ $ $) 55)) (-1367 (($ $ $) 53)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 123)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 60) (($ $ $) 57) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ |#1| $) 61) (($ $ |#1|) 85))) 
-(((-413 |#1|) (-13 (-1000 |#1|) (-10 -7 (IF (|has| |#1| (-554)) (IF (|has| |#1| (-829)) (-6 (-829)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4589)) (IF (|has| |#1| (-457)) (IF (|has| |#1| (-6 -4600)) (-6 -4589) |noBranch|) |noBranch|) |noBranch|))) (-562)) (T -413)) 
-NIL 
-(-13 (-1000 |#1|) (-10 -7 (IF (|has| |#1| (-554)) (IF (|has| |#1| (-829)) (-6 (-829)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4589)) (IF (|has| |#1| (-457)) (IF (|has| |#1| (-6 -4600)) (-6 -4589) |noBranch|) |noBranch|) |noBranch|))) 
-((-1845 (((-685 |#2|) (-1259 $)) NIL) (((-685 |#2|)) 18)) (-4337 (($ (-1259 |#2|) (-1259 $)) NIL) (($ (-1259 |#2|)) 26)) (-1741 (((-685 |#2|) $ (-1259 $)) NIL) (((-685 |#2|) $) 22)) (-3251 ((|#3| $) 59)) (-2119 ((|#2| (-1259 $)) NIL) ((|#2|) 20)) (-3160 (((-1259 |#2|) $ (-1259 $)) NIL) (((-685 |#2|) (-1259 $) (-1259 $)) NIL) (((-1259 |#2|) $) NIL) (((-685 |#2|) (-1259 $)) 24)) (-4081 (((-1259 |#2|) $) 11) (($ (-1259 |#2|)) 13)) (-2707 ((|#3| $) 51))) 
-(((-414 |#1| |#2| |#3|) (-10 -8 (-15 -1741 ((-685 |#2|) |#1|)) (-15 -2119 (|#2|)) (-15 -1845 ((-685 |#2|))) (-15 -4081 (|#1| (-1259 |#2|))) (-15 -4081 ((-1259 |#2|) |#1|)) (-15 -4337 (|#1| (-1259 |#2|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1|)) (-15 -3251 (|#3| |#1|)) (-15 -2707 (|#3| |#1|)) (-15 -1845 ((-685 |#2|) (-1259 |#1|))) (-15 -2119 (|#2| (-1259 |#1|))) (-15 -4337 (|#1| (-1259 |#2|) (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -1741 ((-685 |#2|) |#1| (-1259 |#1|)))) (-415 |#2| |#3|) (-174) (-1234 |#2|)) (T -414)) 
-((-1845 (*1 *2) (-12 (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)) (-5 *1 (-414 *3 *4 *5)) (-4 *3 (-415 *4 *5)))) (-2119 (*1 *2) (-12 (-4 *4 (-1234 *2)) (-4 *2 (-174)) (-5 *1 (-414 *3 *2 *4)) (-4 *3 (-415 *2 *4))))) 
-(-10 -8 (-15 -1741 ((-685 |#2|) |#1|)) (-15 -2119 (|#2|)) (-15 -1845 ((-685 |#2|))) (-15 -4081 (|#1| (-1259 |#2|))) (-15 -4081 ((-1259 |#2|) |#1|)) (-15 -4337 (|#1| (-1259 |#2|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1|)) (-15 -3251 (|#3| |#1|)) (-15 -2707 (|#3| |#1|)) (-15 -1845 ((-685 |#2|) (-1259 |#1|))) (-15 -2119 (|#2| (-1259 |#1|))) (-15 -4337 (|#1| (-1259 |#2|) (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -1741 ((-685 |#2|) |#1| (-1259 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1845 (((-685 |#1|) (-1259 $)) 44) (((-685 |#1|)) 55)) (-3520 ((|#1| $) 50)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-4337 (($ (-1259 |#1|) (-1259 $)) 46) (($ (-1259 |#1|)) 58)) (-1741 (((-685 |#1|) $ (-1259 $)) 51) (((-685 |#1|) $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-2667 (((-923)) 52)) (-3893 (((-121) $) 30)) (-4429 ((|#1| $) 49)) (-3251 ((|#2| $) 42 (|has| |#1| (-368)))) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-2119 ((|#1| (-1259 $)) 45) ((|#1|) 54)) (-3160 (((-1259 |#1|) $ (-1259 $)) 48) (((-685 |#1|) (-1259 $) (-1259 $)) 47) (((-1259 |#1|) $) 60) (((-685 |#1|) (-1259 $)) 59)) (-4081 (((-1259 |#1|) $) 57) (($ (-1259 |#1|)) 56)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 36)) (-2779 (((-3 $ "failed") $) 41 (|has| |#1| (-149)))) (-2707 ((|#2| $) 43)) (-2140 (((-769)) 28)) (-2237 (((-1259 $)) 61)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
-(((-415 |#1| |#2|) (-1290) (-174) (-1234 |t#1|)) (T -415)) 
-((-2237 (*1 *2) (-12 (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-1259 *1)) (-4 *1 (-415 *3 *4)))) (-3160 (*1 *2 *1) (-12 (-4 *1 (-415 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-1259 *3)))) (-3160 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-415 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)))) (-4337 (*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-174)) (-4 *1 (-415 *3 *4)) (-4 *4 (-1234 *3)))) (-4081 (*1 *2 *1) (-12 (-4 *1 (-415 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-1259 *3)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-174)) (-4 *1 (-415 *3 *4)) (-4 *4 (-1234 *3)))) (-1845 (*1 *2) (-12 (-4 *1 (-415 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-685 *3)))) (-2119 (*1 *2) (-12 (-4 *1 (-415 *2 *3)) (-4 *3 (-1234 *2)) (-4 *2 (-174)))) (-1741 (*1 *2 *1) (-12 (-4 *1 (-415 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-685 *3))))) 
-(-13 (-376 |t#1| |t#2|) (-10 -8 (-15 -2237 ((-1259 $))) (-15 -3160 ((-1259 |t#1|) $)) (-15 -3160 ((-685 |t#1|) (-1259 $))) (-15 -4337 ($ (-1259 |t#1|))) (-15 -4081 ((-1259 |t#1|) $)) (-15 -4081 ($ (-1259 |t#1|))) (-15 -1845 ((-685 |t#1|))) (-15 -2119 (|t#1|)) (-15 -1741 ((-685 |t#1|) $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-376 |#1| |#2|) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 |#1|) . T) ((-722) . T) ((-1060 |#1|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) 27) (((-3 (-572) "failed") $) 19)) (-1318 ((|#2| $) NIL) (((-413 (-572)) $) 24) (((-572) $) 14)) (-3972 (($ |#2|) NIL) (($ (-413 (-572))) 22) (($ (-572)) 11))) 
-(((-416 |#1| |#2|) (-10 -8 (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -3972 (|#1| (-572))) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -1318 (|#2| |#1|))) (-417 |#2|) (-1204)) (T -416)) 
-NIL 
-(-10 -8 (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -3972 (|#1| (-572))) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -1318 (|#2| |#1|))) 
-((-3376 (((-3 |#1| "failed") $) 7) (((-3 (-413 (-572)) "failed") $) 15 (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) 12 (|has| |#1| (-1044 (-572))))) (-1318 ((|#1| $) 8) (((-413 (-572)) $) 14 (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) 11 (|has| |#1| (-1044 (-572))))) (-3972 (($ |#1|) 6) (($ (-413 (-572))) 16 (|has| |#1| (-1044 (-413 (-572))))) (($ (-572)) 13 (|has| |#1| (-1044 (-572)))))) 
-(((-417 |#1|) (-1290) (-1204)) (T -417)) 
-NIL 
-(-13 (-1044 |t#1|) (-10 -7 (IF (|has| |t#1| (-1044 (-572))) (-6 (-1044 (-572))) |noBranch|) (IF (|has| |t#1| (-1044 (-413 (-572)))) (-6 (-1044 (-413 (-572)))) |noBranch|))) 
-(((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T)) 
-((-3828 (((-419 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-419 |#1| |#2| |#3| |#4|)) 33))) 
-(((-418 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -3828 ((-419 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-419 |#1| |#2| |#3| |#4|)))) (-303) (-1000 |#1|) (-1234 |#2|) (-13 (-415 |#2| |#3|) (-1044 |#2|)) (-303) (-1000 |#5|) (-1234 |#6|) (-13 (-415 |#6| |#7|) (-1044 |#6|))) (T -418)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-419 *5 *6 *7 *8)) (-4 *5 (-303)) (-4 *6 (-1000 *5)) (-4 *7 (-1234 *6)) (-4 *8 (-13 (-415 *6 *7) (-1044 *6))) (-4 *9 (-303)) (-4 *10 (-1000 *9)) (-4 *11 (-1234 *10)) (-5 *2 (-419 *9 *10 *11 *12)) (-5 *1 (-418 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-13 (-415 *10 *11) (-1044 *10)))))) 
-(-10 -7 (-15 -3828 ((-419 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-419 |#1| |#2| |#3| |#4|)))) 
-((-2262 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-1888 ((|#4| (-769) (-1259 |#4|)) 55)) (-3893 (((-121) $) NIL)) (-4487 (((-1259 |#4|) $) 17)) (-4429 ((|#2| $) 53)) (-2594 (($ $) 136)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 98)) (-1730 (($ (-1259 |#4|)) 97)) (-2607 (((-1116) $) NIL)) (-4492 ((|#1| $) 18)) (-3018 (($ $ $) NIL)) (-4056 (($ $ $) NIL)) (-3972 (((-856) $) 131)) (-2237 (((-1259 |#4|) $) 126)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-3255 (($) 11 T CONST)) (-1324 (((-121) $ $) 39)) (-1379 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 119)) (* (($ $ $) 118))) 
-(((-419 |#1| |#2| |#3| |#4|) (-13 (-482) (-10 -8 (-15 -1730 ($ (-1259 |#4|))) (-15 -2237 ((-1259 |#4|) $)) (-15 -4429 (|#2| $)) (-15 -4487 ((-1259 |#4|) $)) (-15 -4492 (|#1| $)) (-15 -2594 ($ $)) (-15 -1888 (|#4| (-769) (-1259 |#4|))))) (-303) (-1000 |#1|) (-1234 |#2|) (-13 (-415 |#2| |#3|) (-1044 |#2|))) (T -419)) 
-((-1730 (*1 *1 *2) (-12 (-5 *2 (-1259 *6)) (-4 *6 (-13 (-415 *4 *5) (-1044 *4))) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-4 *3 (-303)) (-5 *1 (-419 *3 *4 *5 *6)))) (-2237 (*1 *2 *1) (-12 (-4 *3 (-303)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-1259 *6)) (-5 *1 (-419 *3 *4 *5 *6)) (-4 *6 (-13 (-415 *4 *5) (-1044 *4))))) (-4429 (*1 *2 *1) (-12 (-4 *4 (-1234 *2)) (-4 *2 (-1000 *3)) (-5 *1 (-419 *3 *2 *4 *5)) (-4 *3 (-303)) (-4 *5 (-13 (-415 *2 *4) (-1044 *2))))) (-4487 (*1 *2 *1) (-12 (-4 *3 (-303)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-1259 *6)) (-5 *1 (-419 *3 *4 *5 *6)) (-4 *6 (-13 (-415 *4 *5) (-1044 *4))))) (-4492 (*1 *2 *1) (-12 (-4 *3 (-1000 *2)) (-4 *4 (-1234 *3)) (-4 *2 (-303)) (-5 *1 (-419 *2 *3 *4 *5)) (-4 *5 (-13 (-415 *3 *4) (-1044 *3))))) (-2594 (*1 *1 *1) (-12 (-4 *2 (-303)) (-4 *3 (-1000 *2)) (-4 *4 (-1234 *3)) (-5 *1 (-419 *2 *3 *4 *5)) (-4 *5 (-13 (-415 *3 *4) (-1044 *3))))) (-1888 (*1 *2 *3 *4) (-12 (-5 *3 (-769)) (-5 *4 (-1259 *2)) (-4 *5 (-303)) (-4 *6 (-1000 *5)) (-4 *2 (-13 (-415 *6 *7) (-1044 *6))) (-5 *1 (-419 *5 *6 *7 *2)) (-4 *7 (-1234 *6))))) 
-(-13 (-482) (-10 -8 (-15 -1730 ($ (-1259 |#4|))) (-15 -2237 ((-1259 |#4|) $)) (-15 -4429 (|#2| $)) (-15 -4487 ((-1259 |#4|) $)) (-15 -4492 (|#1| $)) (-15 -2594 ($ $)) (-15 -1888 (|#4| (-769) (-1259 |#4|))))) 
-((-2262 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-4429 ((|#2| $) 60)) (-1668 (($ (-1259 |#4|)) 25) (($ (-419 |#1| |#2| |#3| |#4|)) 75 (|has| |#4| (-1044 |#2|)))) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 34)) (-2237 (((-1259 |#4|) $) 26)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-3255 (($) 23 T CONST)) (-1324 (((-121) $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ $ $) 72))) 
-(((-420 |#1| |#2| |#3| |#4| |#5|) (-13 (-722) (-10 -8 (-15 -2237 ((-1259 |#4|) $)) (-15 -4429 (|#2| $)) (-15 -1668 ($ (-1259 |#4|))) (IF (|has| |#4| (-1044 |#2|)) (-15 -1668 ($ (-419 |#1| |#2| |#3| |#4|))) |noBranch|))) (-303) (-1000 |#1|) (-1234 |#2|) (-415 |#2| |#3|) (-1259 |#4|)) (T -420)) 
-((-2237 (*1 *2 *1) (-12 (-4 *3 (-303)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-1259 *6)) (-5 *1 (-420 *3 *4 *5 *6 *7)) (-4 *6 (-415 *4 *5)) (-14 *7 *2))) (-4429 (*1 *2 *1) (-12 (-4 *4 (-1234 *2)) (-4 *2 (-1000 *3)) (-5 *1 (-420 *3 *2 *4 *5 *6)) (-4 *3 (-303)) (-4 *5 (-415 *2 *4)) (-14 *6 (-1259 *5)))) (-1668 (*1 *1 *2) (-12 (-5 *2 (-1259 *6)) (-4 *6 (-415 *4 *5)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-4 *3 (-303)) (-5 *1 (-420 *3 *4 *5 *6 *7)) (-14 *7 *2))) (-1668 (*1 *1 *2) (-12 (-5 *2 (-419 *3 *4 *5 *6)) (-4 *6 (-1044 *4)) (-4 *3 (-303)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-4 *6 (-415 *4 *5)) (-14 *7 (-1259 *6)) (-5 *1 (-420 *3 *4 *5 *6 *7))))) 
-(-13 (-722) (-10 -8 (-15 -2237 ((-1259 |#4|) $)) (-15 -4429 (|#2| $)) (-15 -1668 ($ (-1259 |#4|))) (IF (|has| |#4| (-1044 |#2|)) (-15 -1668 ($ (-419 |#1| |#2| |#3| |#4|))) |noBranch|))) 
-((-3828 ((|#3| (-1 |#4| |#2|) |#1|) 26))) 
-(((-421 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#3| (-1 |#4| |#2|) |#1|))) (-423 |#2|) (-174) (-423 |#4|) (-174)) (T -421)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-174)) (-4 *6 (-174)) (-4 *2 (-423 *6)) (-5 *1 (-421 *4 *5 *2 *6)) (-4 *4 (-423 *5))))) 
-(-10 -7 (-15 -3828 (|#3| (-1 |#4| |#2|) |#1|))) 
-((-3029 (((-3 $ "failed")) 85)) (-1354 (((-1259 (-685 |#2|)) (-1259 $)) NIL) (((-1259 (-685 |#2|))) 90)) (-4511 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) 84)) (-2095 (((-3 $ "failed")) 83)) (-2882 (((-685 |#2|) (-1259 $)) NIL) (((-685 |#2|)) 101)) (-3700 (((-685 |#2|) $ (-1259 $)) NIL) (((-685 |#2|) $) 109)) (-4535 (((-1166 (-959 |#2|))) 54)) (-4146 ((|#2| (-1259 $)) NIL) ((|#2|) 105)) (-4337 (($ (-1259 |#2|) (-1259 $)) NIL) (($ (-1259 |#2|)) 112)) (-1903 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) 82)) (-2036 (((-3 $ "failed")) 74)) (-1663 (((-685 |#2|) (-1259 $)) NIL) (((-685 |#2|)) 99)) (-3343 (((-685 |#2|) $ (-1259 $)) NIL) (((-685 |#2|) $) 107)) (-2339 (((-1166 (-959 |#2|))) 53)) (-2110 ((|#2| (-1259 $)) NIL) ((|#2|) 103)) (-3160 (((-1259 |#2|) $ (-1259 $)) NIL) (((-685 |#2|) (-1259 $) (-1259 $)) NIL) (((-1259 |#2|) $) NIL) (((-685 |#2|) (-1259 $)) 111)) (-4081 (((-1259 |#2|) $) 95) (($ (-1259 |#2|)) 97)) (-3188 (((-638 (-959 |#2|)) (-1259 $)) NIL) (((-638 (-959 |#2|))) 93)) (-1591 (($ (-685 |#2|) $) 89))) 
-(((-422 |#1| |#2|) (-10 -8 (-15 -1591 (|#1| (-685 |#2|) |#1|)) (-15 -4535 ((-1166 (-959 |#2|)))) (-15 -2339 ((-1166 (-959 |#2|)))) (-15 -3700 ((-685 |#2|) |#1|)) (-15 -3343 ((-685 |#2|) |#1|)) (-15 -2882 ((-685 |#2|))) (-15 -1663 ((-685 |#2|))) (-15 -4146 (|#2|)) (-15 -2110 (|#2|)) (-15 -4081 (|#1| (-1259 |#2|))) (-15 -4081 ((-1259 |#2|) |#1|)) (-15 -4337 (|#1| (-1259 |#2|))) (-15 -3188 ((-638 (-959 |#2|)))) (-15 -1354 ((-1259 (-685 |#2|)))) (-15 -3160 ((-685 |#2|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1|)) (-15 -3029 ((-3 |#1| "failed"))) (-15 -2095 ((-3 |#1| "failed"))) (-15 -2036 ((-3 |#1| "failed"))) (-15 -4511 ((-3 (-2 (|:| |particular| |#1|) (|:| -2237 (-638 |#1|))) "failed"))) (-15 -1903 ((-3 (-2 (|:| |particular| |#1|) (|:| -2237 (-638 |#1|))) "failed"))) (-15 -2882 ((-685 |#2|) (-1259 |#1|))) (-15 -1663 ((-685 |#2|) (-1259 |#1|))) (-15 -4146 (|#2| (-1259 |#1|))) (-15 -2110 (|#2| (-1259 |#1|))) (-15 -4337 (|#1| (-1259 |#2|) (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -3700 ((-685 |#2|) |#1| (-1259 |#1|))) (-15 -3343 ((-685 |#2|) |#1| (-1259 |#1|))) (-15 -1354 ((-1259 (-685 |#2|)) (-1259 |#1|))) (-15 -3188 ((-638 (-959 |#2|)) (-1259 |#1|)))) (-423 |#2|) (-174)) (T -422)) 
-((-1354 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-1259 (-685 *4))) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) (-3188 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-638 (-959 *4))) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) (-2110 (*1 *2) (-12 (-4 *2 (-174)) (-5 *1 (-422 *3 *2)) (-4 *3 (-423 *2)))) (-4146 (*1 *2) (-12 (-4 *2 (-174)) (-5 *1 (-422 *3 *2)) (-4 *3 (-423 *2)))) (-1663 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-685 *4)) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) (-2882 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-685 *4)) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) (-2339 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-1166 (-959 *4))) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) (-4535 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-1166 (-959 *4))) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4))))) 
-(-10 -8 (-15 -1591 (|#1| (-685 |#2|) |#1|)) (-15 -4535 ((-1166 (-959 |#2|)))) (-15 -2339 ((-1166 (-959 |#2|)))) (-15 -3700 ((-685 |#2|) |#1|)) (-15 -3343 ((-685 |#2|) |#1|)) (-15 -2882 ((-685 |#2|))) (-15 -1663 ((-685 |#2|))) (-15 -4146 (|#2|)) (-15 -2110 (|#2|)) (-15 -4081 (|#1| (-1259 |#2|))) (-15 -4081 ((-1259 |#2|) |#1|)) (-15 -4337 (|#1| (-1259 |#2|))) (-15 -3188 ((-638 (-959 |#2|)))) (-15 -1354 ((-1259 (-685 |#2|)))) (-15 -3160 ((-685 |#2|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1|)) (-15 -3029 ((-3 |#1| "failed"))) (-15 -2095 ((-3 |#1| "failed"))) (-15 -2036 ((-3 |#1| "failed"))) (-15 -4511 ((-3 (-2 (|:| |particular| |#1|) (|:| -2237 (-638 |#1|))) "failed"))) (-15 -1903 ((-3 (-2 (|:| |particular| |#1|) (|:| -2237 (-638 |#1|))) "failed"))) (-15 -2882 ((-685 |#2|) (-1259 |#1|))) (-15 -1663 ((-685 |#2|) (-1259 |#1|))) (-15 -4146 (|#2| (-1259 |#1|))) (-15 -2110 (|#2| (-1259 |#1|))) (-15 -4337 (|#1| (-1259 |#2|) (-1259 |#1|))) (-15 -3160 ((-685 |#2|) (-1259 |#1|) (-1259 |#1|))) (-15 -3160 ((-1259 |#2|) |#1| (-1259 |#1|))) (-15 -3700 ((-685 |#2|) |#1| (-1259 |#1|))) (-15 -3343 ((-685 |#2|) |#1| (-1259 |#1|))) (-15 -1354 ((-1259 (-685 |#2|)) (-1259 |#1|))) (-15 -3188 ((-638 (-959 |#2|)) (-1259 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3029 (((-3 $ "failed")) 35 (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) 18)) (-1354 (((-1259 (-685 |#1|)) (-1259 $)) 76) (((-1259 (-685 |#1|))) 93)) (-2167 (((-1259 $)) 79)) (-2211 (($) 16 T CONST)) (-4511 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) 38 (|has| |#1| (-562)))) (-2095 (((-3 $ "failed")) 36 (|has| |#1| (-562)))) (-2882 (((-685 |#1|) (-1259 $)) 63) (((-685 |#1|)) 85)) (-3487 ((|#1| $) 72)) (-3700 (((-685 |#1|) $ (-1259 $)) 74) (((-685 |#1|) $) 83)) (-2848 (((-3 $ "failed") $) 43 (|has| |#1| (-562)))) (-4535 (((-1166 (-959 |#1|))) 81 (|has| |#1| (-368)))) (-3014 (($ $ (-923)) 27)) (-3588 ((|#1| $) 70)) (-2135 (((-1166 |#1|) $) 40 (|has| |#1| (-562)))) (-4146 ((|#1| (-1259 $)) 65) ((|#1|) 87)) (-1593 (((-1166 |#1|) $) 61)) (-2048 (((-121)) 55)) (-4337 (($ (-1259 |#1|) (-1259 $)) 67) (($ (-1259 |#1|)) 91)) (-1799 (((-3 $ "failed") $) 45 (|has| |#1| (-562)))) (-2667 (((-923)) 78)) (-4160 (((-121)) 52)) (-2027 (($ $ (-923)) 32)) (-1814 (((-121)) 48)) (-2209 (((-121)) 46)) (-1648 (((-121)) 50)) (-1903 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) 39 (|has| |#1| (-562)))) (-2036 (((-3 $ "failed")) 37 (|has| |#1| (-562)))) (-1663 (((-685 |#1|) (-1259 $)) 64) (((-685 |#1|)) 86)) (-3550 ((|#1| $) 73)) (-3343 (((-685 |#1|) $ (-1259 $)) 75) (((-685 |#1|) $) 84)) (-2046 (((-3 $ "failed") $) 44 (|has| |#1| (-562)))) (-2339 (((-1166 (-959 |#1|))) 82 (|has| |#1| (-368)))) (-3276 (($ $ (-923)) 28)) (-2340 ((|#1| $) 71)) (-3665 (((-1166 |#1|) $) 41 (|has| |#1| (-562)))) (-2110 ((|#1| (-1259 $)) 66) ((|#1|) 88)) (-1989 (((-1166 |#1|) $) 62)) (-3602 (((-121)) 56)) (-1658 (((-1152) $) 9)) (-4219 (((-121)) 47)) (-2395 (((-121)) 49)) (-3046 (((-121)) 51)) (-2607 (((-1116) $) 10)) (-4128 (((-121)) 54)) (-3277 ((|#1| $ (-572)) 94)) (-3160 (((-1259 |#1|) $ (-1259 $)) 69) (((-685 |#1|) (-1259 $) (-1259 $)) 68) (((-1259 |#1|) $) 96) (((-685 |#1|) (-1259 $)) 95)) (-4081 (((-1259 |#1|) $) 90) (($ (-1259 |#1|)) 89)) (-3188 (((-638 (-959 |#1|)) (-1259 $)) 77) (((-638 (-959 |#1|))) 92)) (-4056 (($ $ $) 24)) (-2073 (((-121)) 60)) (-3972 (((-856) $) 11)) (-2237 (((-1259 $)) 97)) (-4414 (((-638 (-1259 |#1|))) 42 (|has| |#1| (-562)))) (-4250 (($ $ $ $) 25)) (-2928 (((-121)) 58)) (-1591 (($ (-685 |#1|) $) 80)) (-1397 (($ $ $) 23)) (-2773 (((-121)) 59)) (-2756 (((-121)) 57)) (-1447 (((-121)) 53)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 29)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
-(((-423 |#1|) (-1290) (-174)) (T -423)) 
-((-2237 (*1 *2) (-12 (-4 *3 (-174)) (-5 *2 (-1259 *1)) (-4 *1 (-423 *3)))) (-3160 (*1 *2 *1) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-1259 *3)))) (-3160 (*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-423 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-423 *2)) (-4 *2 (-174)))) (-1354 (*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-1259 (-685 *3))))) (-3188 (*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-638 (-959 *3))))) (-4337 (*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-174)) (-4 *1 (-423 *3)))) (-4081 (*1 *2 *1) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-1259 *3)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-174)) (-4 *1 (-423 *3)))) (-2110 (*1 *2) (-12 (-4 *1 (-423 *2)) (-4 *2 (-174)))) (-4146 (*1 *2) (-12 (-4 *1 (-423 *2)) (-4 *2 (-174)))) (-1663 (*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-685 *3)))) (-2882 (*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-685 *3)))) (-3343 (*1 *2 *1) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-685 *3)))) (-3700 (*1 *2 *1) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-685 *3)))) (-2339 (*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-4 *3 (-368)) (-5 *2 (-1166 (-959 *3))))) (-4535 (*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-4 *3 (-368)) (-5 *2 (-1166 (-959 *3))))) (-1591 (*1 *1 *2 *1) (-12 (-5 *2 (-685 *3)) (-4 *1 (-423 *3)) (-4 *3 (-174))))) 
-(-13 (-372 |t#1|) (-10 -8 (-15 -2237 ((-1259 $))) (-15 -3160 ((-1259 |t#1|) $)) (-15 -3160 ((-685 |t#1|) (-1259 $))) (-15 -3277 (|t#1| $ (-572))) (-15 -1354 ((-1259 (-685 |t#1|)))) (-15 -3188 ((-638 (-959 |t#1|)))) (-15 -4337 ($ (-1259 |t#1|))) (-15 -4081 ((-1259 |t#1|) $)) (-15 -4081 ($ (-1259 |t#1|))) (-15 -2110 (|t#1|)) (-15 -4146 (|t#1|)) (-15 -1663 ((-685 |t#1|))) (-15 -2882 ((-685 |t#1|))) (-15 -3343 ((-685 |t#1|) $)) (-15 -3700 ((-685 |t#1|) $)) (IF (|has| |t#1| (-368)) (PROGN (-15 -2339 ((-1166 (-959 |t#1|)))) (-15 -4535 ((-1166 (-959 |t#1|))))) |noBranch|) (-15 -1591 ($ (-685 |t#1|) $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-372 |#1|) . T) ((-641 |#1|) . T) ((-713 |#1|) . T) ((-716) . T) ((-742 |#1|) . T) ((-759) . T) ((-1060 |#1|) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 40)) (-3231 (($ $) 55)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 142)) (-3946 (($ $) NIL)) (-3686 (((-121) $) 34)) (-3029 ((|#1| $) 12)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| |#1| (-1214)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-1214)))) (-1480 (($ |#1| (-572)) 30)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 112)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 53)) (-1799 (((-3 $ "failed") $) 127)) (-2956 (((-3 (-413 (-572)) "failed") $) 61 (|has| |#1| (-554)))) (-3175 (((-121) $) 57 (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) 59 (|has| |#1| (-554)))) (-2348 (($ |#1| (-572)) 32)) (-1526 (((-121) $) 148 (|has| |#1| (-1214)))) (-3893 (((-121) $) 41)) (-4017 (((-769) $) 36)) (-2402 (((-3 "nil" "sqfr" "irred" "prime") $ (-572)) 133)) (-4351 ((|#1| $ (-572)) 132)) (-4287 (((-572) $ (-572)) 131)) (-1738 (($ |#1| (-572)) 29)) (-3828 (($ (-1 |#1| |#1|) $) 139)) (-3533 (($ |#1| (-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-572))))) 56)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-1306 (($ |#1| (-572)) 31)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) 143 (|has| |#1| (-457)))) (-2855 (($ |#1| (-572) (-3 "nil" "sqfr" "irred" "prime")) 28)) (-4547 (((-638 (-2 (|:| -4304 |#1|) (|:| -3751 (-572)))) $) 52)) (-3102 (((-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-572)))) $) 11)) (-4304 (((-424 $) $) NIL (|has| |#1| (-1214)))) (-1803 (((-3 $ "failed") $ $) 134)) (-3751 (((-572) $) 128)) (-2534 ((|#1| $) 54)) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) 76 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) 81 (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) NIL (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) $) NIL (|has| |#1| (-527 (-1170) $))) (($ $ (-638 (-1170)) (-638 $)) 82 (|has| |#1| (-527 (-1170) $))) (($ $ (-638 (-290 $))) 78 (|has| |#1| (-305 $))) (($ $ (-290 $)) NIL (|has| |#1| (-305 $))) (($ $ $ $) NIL (|has| |#1| (-305 $))) (($ $ (-638 $) (-638 $)) NIL (|has| |#1| (-305 $)))) (-3277 (($ $ |#1|) 68 (|has| |#1| (-283 |#1| |#1|))) (($ $ $) 69 (|has| |#1| (-283 $ $)))) (-3139 (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) 138)) (-4081 (((-545) $) 26 (|has| |#1| (-613 (-545)))) (((-385) $) 88 (|has| |#1| (-1028))) (((-217) $) 91 (|has| |#1| (-1028)))) (-3972 (((-856) $) 110) (($ (-572)) 44) (($ $) NIL) (($ |#1|) 43) (($ (-413 (-572))) NIL (|has| |#1| (-1044 (-413 (-572)))))) (-2140 (((-769)) 46)) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 38 T CONST)) (-3255 (($) 37 T CONST)) (-1557 (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1324 (((-121) $ $) 92)) (-1373 (($ $) 124) (($ $ $) NIL)) (-1367 (($ $ $) 136)) (** (($ $ (-923)) NIL) (($ $ (-769)) 98)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 48) (($ $ $) 47) (($ |#1| $) 49) (($ $ |#1|) NIL))) 
-(((-424 |#1|) (-13 (-562) (-225 |#1|) (-43 |#1|) (-338 |#1|) (-417 |#1|) (-10 -8 (-15 -2534 (|#1| $)) (-15 -3751 ((-572) $)) (-15 -3533 ($ |#1| (-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-572)))))) (-15 -3102 ((-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-572)))) $)) (-15 -1738 ($ |#1| (-572))) (-15 -4547 ((-638 (-2 (|:| -4304 |#1|) (|:| -3751 (-572)))) $)) (-15 -1306 ($ |#1| (-572))) (-15 -4287 ((-572) $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -2402 ((-3 "nil" "sqfr" "irred" "prime") $ (-572))) (-15 -4017 ((-769) $)) (-15 -2348 ($ |#1| (-572))) (-15 -1480 ($ |#1| (-572))) (-15 -2855 ($ |#1| (-572) (-3 "nil" "sqfr" "irred" "prime"))) (-15 -3029 (|#1| $)) (-15 -3231 ($ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-457)) (-6 (-457)) |noBranch|) (IF (|has| |#1| (-1028)) (-6 (-1028)) |noBranch|) (IF (|has| |#1| (-1214)) (-6 (-1214)) |noBranch|) (IF (|has| |#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (IF (|has| |#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|) (IF (|has| |#1| (-283 $ $)) (-6 (-283 $ $)) |noBranch|) (IF (|has| |#1| (-305 $)) (-6 (-305 $)) |noBranch|) (IF (|has| |#1| (-527 (-1170) $)) (-6 (-527 (-1170) $)) |noBranch|))) (-562)) (T -424)) 
-((-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-562)) (-5 *1 (-424 *3)))) (-2534 (*1 *2 *1) (-12 (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-3751 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-424 *3)) (-4 *3 (-562)))) (-3533 (*1 *1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (-572))))) (-4 *2 (-562)) (-5 *1 (-424 *2)))) (-3102 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (-572))))) (-5 *1 (-424 *3)) (-4 *3 (-562)))) (-1738 (*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-4547 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| -4304 *3) (|:| -3751 (-572))))) (-5 *1 (-424 *3)) (-4 *3 (-562)))) (-1306 (*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-4287 (*1 *2 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-424 *3)) (-4 *3 (-562)))) (-4351 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-2402 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-424 *4)) (-4 *4 (-562)))) (-4017 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-424 *3)) (-4 *3 (-562)))) (-2348 (*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-1480 (*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-2855 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-572)) (-5 *4 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-3029 (*1 *2 *1) (-12 (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-3231 (*1 *1 *1) (-12 (-5 *1 (-424 *2)) (-4 *2 (-562)))) (-3175 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-424 *3)) (-4 *3 (-554)) (-4 *3 (-562)))) (-4299 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-424 *3)) (-4 *3 (-554)) (-4 *3 (-562)))) (-2956 (*1 *2 *1) (|partial| -12 (-5 *2 (-413 (-572))) (-5 *1 (-424 *3)) (-4 *3 (-554)) (-4 *3 (-562))))) 
-(-13 (-562) (-225 |#1|) (-43 |#1|) (-338 |#1|) (-417 |#1|) (-10 -8 (-15 -2534 (|#1| $)) (-15 -3751 ((-572) $)) (-15 -3533 ($ |#1| (-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-572)))))) (-15 -3102 ((-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-572)))) $)) (-15 -1738 ($ |#1| (-572))) (-15 -4547 ((-638 (-2 (|:| -4304 |#1|) (|:| -3751 (-572)))) $)) (-15 -1306 ($ |#1| (-572))) (-15 -4287 ((-572) $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -2402 ((-3 "nil" "sqfr" "irred" "prime") $ (-572))) (-15 -4017 ((-769) $)) (-15 -2348 ($ |#1| (-572))) (-15 -1480 ($ |#1| (-572))) (-15 -2855 ($ |#1| (-572) (-3 "nil" "sqfr" "irred" "prime"))) (-15 -3029 (|#1| $)) (-15 -3231 ($ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-457)) (-6 (-457)) |noBranch|) (IF (|has| |#1| (-1028)) (-6 (-1028)) |noBranch|) (IF (|has| |#1| (-1214)) (-6 (-1214)) |noBranch|) (IF (|has| |#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (IF (|has| |#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|) (IF (|has| |#1| (-283 $ $)) (-6 (-283 $ $)) |noBranch|) (IF (|has| |#1| (-305 $)) (-6 (-305 $)) |noBranch|) (IF (|has| |#1| (-527 (-1170) $)) (-6 (-527 (-1170) $)) |noBranch|))) 
-((-2436 (((-424 |#1|) (-424 |#1|) (-1 (-424 |#1|) |#1|)) 20)) (-1846 (((-424 |#1|) (-424 |#1|) (-424 |#1|)) 15))) 
-(((-425 |#1|) (-10 -7 (-15 -2436 ((-424 |#1|) (-424 |#1|) (-1 (-424 |#1|) |#1|))) (-15 -1846 ((-424 |#1|) (-424 |#1|) (-424 |#1|)))) (-562)) (T -425)) 
-((-1846 (*1 *2 *2 *2) (-12 (-5 *2 (-424 *3)) (-4 *3 (-562)) (-5 *1 (-425 *3)))) (-2436 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-424 *4) *4)) (-4 *4 (-562)) (-5 *2 (-424 *4)) (-5 *1 (-425 *4))))) 
-(-10 -7 (-15 -2436 ((-424 |#1|) (-424 |#1|) (-1 (-424 |#1|) |#1|))) (-15 -1846 ((-424 |#1|) (-424 |#1|) (-424 |#1|)))) 
-((-4509 ((|#2| |#2|) 160)) (-2743 (((-3 (|:| |%expansion| (-309 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121)) 55))) 
-(((-426 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2743 ((-3 (|:| |%expansion| (-309 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121))) (-15 -4509 (|#2| |#2|))) (-13 (-457) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|)) (-1170) |#2|) (T -426)) 
-((-4509 (*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-426 *3 *2 *4 *5)) (-4 *2 (-13 (-27) (-1190) (-436 *3))) (-14 *4 (-1170)) (-14 *5 *2))) (-2743 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |%expansion| (-309 *5 *3 *6 *7)) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152)))))) (-5 *1 (-426 *5 *3 *6 *7)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-14 *6 (-1170)) (-14 *7 *3)))) 
-(-10 -7 (-15 -2743 ((-3 (|:| |%expansion| (-309 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121))) (-15 -4509 (|#2| |#2|))) 
-((-3828 ((|#4| (-1 |#3| |#1|) |#2|) 11))) 
-(((-427 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#4| (-1 |#3| |#1|) |#2|))) (-13 (-1054) (-848)) (-436 |#1|) (-13 (-1054) (-848)) (-436 |#3|)) (T -427)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-13 (-1054) (-848))) (-4 *6 (-13 (-1054) (-848))) (-4 *2 (-436 *6)) (-5 *1 (-427 *5 *4 *6 *2)) (-4 *4 (-436 *5))))) 
-(-10 -7 (-15 -3828 (|#4| (-1 |#3| |#1|) |#2|))) 
-((-4509 ((|#2| |#2|) 87)) (-3084 (((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121) (-1152)) 46)) (-2948 (((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121) (-1152)) 152))) 
-(((-428 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -3084 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121) (-1152))) (-15 -2948 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121) (-1152))) (-15 -4509 (|#2| |#2|))) (-13 (-457) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|) (-10 -8 (-15 -3972 ($ |#3|)))) (-846) (-13 (-1236 |#2| |#3|) (-368) (-1190) (-10 -8 (-15 -3139 ($ $)) (-15 -2774 ($ $)))) (-991 |#4|) (-1170)) (T -428)) 
-((-4509 (*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-4 *2 (-13 (-27) (-1190) (-436 *3) (-10 -8 (-15 -3972 ($ *4))))) (-4 *4 (-846)) (-4 *5 (-13 (-1236 *2 *4) (-368) (-1190) (-10 -8 (-15 -3139 ($ $)) (-15 -2774 ($ $))))) (-5 *1 (-428 *3 *2 *4 *5 *6 *7)) (-4 *6 (-991 *5)) (-14 *7 (-1170)))) (-2948 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-4 *3 (-13 (-27) (-1190) (-436 *6) (-10 -8 (-15 -3972 ($ *7))))) (-4 *7 (-846)) (-4 *8 (-13 (-1236 *3 *7) (-368) (-1190) (-10 -8 (-15 -3139 ($ $)) (-15 -2774 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152)))))) (-5 *1 (-428 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1152)) (-4 *9 (-991 *8)) (-14 *10 (-1170)))) (-3084 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-4 *3 (-13 (-27) (-1190) (-436 *6) (-10 -8 (-15 -3972 ($ *7))))) (-4 *7 (-846)) (-4 *8 (-13 (-1236 *3 *7) (-368) (-1190) (-10 -8 (-15 -3139 ($ $)) (-15 -2774 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152)))))) (-5 *1 (-428 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1152)) (-4 *9 (-991 *8)) (-14 *10 (-1170))))) 
-(-10 -7 (-15 -3084 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121) (-1152))) (-15 -2948 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152))))) |#2| (-121) (-1152))) (-15 -4509 (|#2| |#2|))) 
-((-1911 ((|#4| (-1 |#3| |#1| |#3|) |#2| |#3|) 22)) (-3116 ((|#3| (-1 |#3| |#1| |#3|) |#2| |#3|) 20)) (-3828 ((|#4| (-1 |#3| |#1|) |#2|) 17))) 
-(((-429 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3116 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1911 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) (-1098) (-431 |#1|) (-1098) (-431 |#3|)) (T -429)) 
-((-1911 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1098)) (-4 *5 (-1098)) (-4 *2 (-431 *5)) (-5 *1 (-429 *6 *4 *5 *2)) (-4 *4 (-431 *6)))) (-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1098)) (-4 *2 (-1098)) (-5 *1 (-429 *5 *4 *2 *6)) (-4 *4 (-431 *5)) (-4 *6 (-431 *2)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-431 *6)) (-5 *1 (-429 *5 *4 *6 *2)) (-4 *4 (-431 *5))))) 
-(-10 -7 (-15 -3828 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3116 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1911 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) 
-((-1554 (($) 44)) (-3518 (($ |#2| $) NIL) (($ $ |#2|) NIL) (($ $ $) 40)) (-3710 (($ $ $) 39)) (-3771 (((-121) $ $) 28)) (-1685 (((-769)) 47)) (-4462 (($ (-638 |#2|)) 20) (($) NIL)) (-3286 (($) 53)) (-1771 ((|#2| $) 61)) (-4238 ((|#2| $) 59)) (-3633 (((-923) $) 55)) (-1931 (($ $ $) 35)) (-1763 (($ (-923)) 50)) (-3982 (($ $ |#2|) NIL) (($ $ $) 38)) (-1571 (((-769) (-1 (-121) |#2|) $) NIL) (((-769) |#2| $) 26)) (-3921 (($ (-638 |#2|)) 24)) (-3563 (($ $) 46)) (-3972 (((-856) $) 33)) (-1961 (((-769) $) 21)) (-1599 (($ (-638 |#2|)) 19) (($) NIL)) (-1324 (((-121) $ $) 16)) (-1334 (((-121) $ $) 13))) 
-(((-430 |#1| |#2|) (-10 -8 (-15 -1685 ((-769))) (-15 -1763 (|#1| (-923))) (-15 -3633 ((-923) |#1|)) (-15 -3286 (|#1|)) (-15 -1771 (|#2| |#1|)) (-15 -4238 (|#2| |#1|)) (-15 -1554 (|#1|)) (-15 -3563 (|#1| |#1|)) (-15 -1961 ((-769) |#1|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -1599 (|#1|)) (-15 -1599 (|#1| (-638 |#2|))) (-15 -4462 (|#1|)) (-15 -4462 (|#1| (-638 |#2|))) (-15 -1931 (|#1| |#1| |#1|)) (-15 -3982 (|#1| |#1| |#1|)) (-15 -3982 (|#1| |#1| |#2|)) (-15 -3710 (|#1| |#1| |#1|)) (-15 -3771 ((-121) |#1| |#1|)) (-15 -3518 (|#1| |#1| |#1|)) (-15 -3518 (|#1| |#1| |#2|)) (-15 -3518 (|#1| |#2| |#1|)) (-15 -3921 (|#1| (-638 |#2|))) (-15 -1571 ((-769) |#2| |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|))) (-431 |#2|) (-1098)) (T -430)) 
-((-1685 (*1 *2) (-12 (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-430 *3 *4)) (-4 *3 (-431 *4))))) 
-(-10 -8 (-15 -1685 ((-769))) (-15 -1763 (|#1| (-923))) (-15 -3633 ((-923) |#1|)) (-15 -3286 (|#1|)) (-15 -1771 (|#2| |#1|)) (-15 -4238 (|#2| |#1|)) (-15 -1554 (|#1|)) (-15 -3563 (|#1| |#1|)) (-15 -1961 ((-769) |#1|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -1599 (|#1|)) (-15 -1599 (|#1| (-638 |#2|))) (-15 -4462 (|#1|)) (-15 -4462 (|#1| (-638 |#2|))) (-15 -1931 (|#1| |#1| |#1|)) (-15 -3982 (|#1| |#1| |#1|)) (-15 -3982 (|#1| |#1| |#2|)) (-15 -3710 (|#1| |#1| |#1|)) (-15 -3771 ((-121) |#1| |#1|)) (-15 -3518 (|#1| |#1| |#1|)) (-15 -3518 (|#1| |#1| |#2|)) (-15 -3518 (|#1| |#2| |#1|)) (-15 -3921 (|#1| (-638 |#2|))) (-15 -1571 ((-769) |#2| |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|))) 
-((-2262 (((-121) $ $) 18)) (-1554 (($) 64 (|has| |#1| (-374)))) (-3518 (($ |#1| $) 79) (($ $ |#1|) 78) (($ $ $) 77)) (-3710 (($ $ $) 75)) (-3771 (((-121) $ $) 76)) (-1946 (((-121) $ (-769)) 8)) (-1685 (((-769)) 57 (|has| |#1| (-374)))) (-4462 (($ (-638 |#1|)) 71) (($) 70)) (-1550 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-1643 (($ $) 55 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ |#1| $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4602)))) (-3445 (($ |#1| $) 54 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4602)))) (-3286 (($) 60 (|has| |#1| (-374)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-1771 ((|#1| $) 62 (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-4238 ((|#1| $) 63 (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3633 (((-923) $) 59 (|has| |#1| (-374)))) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22)) (-1931 (($ $ $) 72)) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37)) (-1763 (($ (-923)) 58 (|has| |#1| (-374)))) (-2607 (((-1116) $) 21)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3587 (((-638 $)) 61 (|has| |#1| (-374)))) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3982 (($ $ |#1|) 74) (($ $ $) 73)) (-1535 (($) 46) (($ (-638 |#1|)) 45)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 47)) (-3563 (($ $) 65 (|has| |#1| (-374)))) (-3972 (((-856) $) 20)) (-1961 (((-769) $) 66)) (-1599 (($ (-638 |#1|)) 69) (($) 68)) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19)) (-1334 (((-121) $ $) 67)) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-431 |#1|) (-1290) (-1098)) (T -431)) 
-((-1961 (*1 *2 *1) (-12 (-4 *1 (-431 *3)) (-4 *3 (-1098)) (-5 *2 (-769)))) (-3563 (*1 *1 *1) (-12 (-4 *1 (-431 *2)) (-4 *2 (-1098)) (-4 *2 (-374)))) (-1554 (*1 *1) (-12 (-4 *1 (-431 *2)) (-4 *2 (-374)) (-4 *2 (-1098)))) (-4238 (*1 *2 *1) (-12 (-4 *1 (-431 *2)) (-4 *2 (-1098)) (-4 *2 (-848)))) (-1771 (*1 *2 *1) (-12 (-4 *1 (-431 *2)) (-4 *2 (-1098)) (-4 *2 (-848))))) 
-(-13 (-223 |t#1|) (-1095 |t#1|) (-10 -8 (-6 -4602) (-15 -1961 ((-769) $)) (IF (|has| |t#1| (-374)) (PROGN (-6 (-374)) (-15 -3563 ($ $)) (-15 -1554 ($))) |noBranch|) (IF (|has| |t#1| (-848)) (PROGN (-15 -4238 (|t#1| $)) (-15 -1771 (|t#1| $))) |noBranch|))) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) . T) ((-612 (-856)) . T) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-223 |#1|) . T) ((-229 |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-374) |has| |#1| (-374)) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1095 |#1|) . T) ((-1098) . T) ((-1204) . T)) 
-((-3461 (((-589 |#2|) |#2| (-1170)) 35)) (-3280 (((-589 |#2|) |#2| (-1170)) 19)) (-2464 ((|#2| |#2| (-1170)) 24))) 
-(((-432 |#1| |#2|) (-10 -7 (-15 -3280 ((-589 |#2|) |#2| (-1170))) (-15 -3461 ((-589 |#2|) |#2| (-1170))) (-15 -2464 (|#2| |#2| (-1170)))) (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572))) (-13 (-1190) (-29 |#1|))) (T -432)) 
-((-2464 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-432 *4 *2)) (-4 *2 (-13 (-1190) (-29 *4))))) (-3461 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-432 *5 *3)) (-4 *3 (-13 (-1190) (-29 *5))))) (-3280 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-432 *5 *3)) (-4 *3 (-13 (-1190) (-29 *5)))))) 
-(-10 -7 (-15 -3280 ((-589 |#2|) |#2| (-1170))) (-15 -3461 ((-589 |#2|) |#2| (-1170))) (-15 -2464 (|#2| |#2| (-1170)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-1406 (($ |#2| |#1|) 35)) (-2981 (($ |#2| |#1|) 33)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-331 |#2|)) 25)) (-2140 (((-769)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 10 T CONST)) (-3255 (($) 16 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 34)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 36) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-433 |#1| |#2|) (-13 (-43 |#1|) (-10 -8 (IF (|has| |#2| (-6 -4589)) (IF (|has| |#1| (-6 -4589)) (-6 -4589) |noBranch|) |noBranch|) (-15 -3972 ($ |#1|)) (-15 -3972 ($ (-331 |#2|))) (-15 -1406 ($ |#2| |#1|)) (-15 -2981 ($ |#2| |#1|)))) (-13 (-174) (-43 (-413 (-572)))) (-13 (-848) (-21))) (T -433)) 
-((-3972 (*1 *1 *2) (-12 (-5 *1 (-433 *2 *3)) (-4 *2 (-13 (-174) (-43 (-413 (-572))))) (-4 *3 (-13 (-848) (-21))))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-331 *4)) (-4 *4 (-13 (-848) (-21))) (-5 *1 (-433 *3 *4)) (-4 *3 (-13 (-174) (-43 (-413 (-572))))))) (-1406 (*1 *1 *2 *3) (-12 (-5 *1 (-433 *3 *2)) (-4 *3 (-13 (-174) (-43 (-413 (-572))))) (-4 *2 (-13 (-848) (-21))))) (-2981 (*1 *1 *2 *3) (-12 (-5 *1 (-433 *3 *2)) (-4 *3 (-13 (-174) (-43 (-413 (-572))))) (-4 *2 (-13 (-848) (-21)))))) 
-(-13 (-43 |#1|) (-10 -8 (IF (|has| |#2| (-6 -4589)) (IF (|has| |#1| (-6 -4589)) (-6 -4589) |noBranch|) |noBranch|) (-15 -3972 ($ |#1|)) (-15 -3972 ($ (-331 |#2|))) (-15 -1406 ($ |#2| |#1|)) (-15 -2981 ($ |#2| |#1|)))) 
-((-2774 (((-3 |#2| (-638 |#2|)) |#2| (-1170)) 104))) 
-(((-434 |#1| |#2|) (-10 -7 (-15 -2774 ((-3 |#2| (-638 |#2|)) |#2| (-1170)))) (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572))) (-13 (-1190) (-966) (-29 |#1|))) (T -434)) 
-((-2774 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 *3 (-638 *3))) (-5 *1 (-434 *5 *3)) (-4 *3 (-13 (-1190) (-966) (-29 *5)))))) 
-(-10 -7 (-15 -2774 ((-3 |#2| (-638 |#2|)) |#2| (-1170)))) 
-((-3456 (((-638 (-1170)) $) 72)) (-4297 (((-413 (-1166 $)) $ (-611 $)) 268)) (-1952 (($ $ (-290 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-638 (-611 $)) (-638 $)) 233)) (-3376 (((-3 (-611 $) "failed") $) NIL) (((-3 (-1170) "failed") $) 75) (((-3 (-572) "failed") $) NIL) (((-3 |#2| "failed") $) 229) (((-3 (-413 (-959 |#2|)) "failed") $) 319) (((-3 (-959 |#2|) "failed") $) 231) (((-3 (-413 (-572)) "failed") $) NIL)) (-1318 (((-611 $) $) NIL) (((-1170) $) 30) (((-572) $) NIL) ((|#2| $) 227) (((-413 (-959 |#2|)) $) 300) (((-959 |#2|) $) 228) (((-413 (-572)) $) NIL)) (-4564 (((-123) (-123)) 47)) (-4347 (($ $) 87)) (-3614 (((-3 (-611 $) "failed") $) 224)) (-4291 (((-638 (-611 $)) $) 225)) (-1921 (((-3 (-638 $) "failed") $) 243)) (-2472 (((-3 (-2 (|:| |val| $) (|:| -3751 (-572))) "failed") $) 250)) (-2336 (((-3 (-638 $) "failed") $) 241)) (-1595 (((-3 (-2 (|:| -4513 (-572)) (|:| |var| (-611 $))) "failed") $) 259)) (-3019 (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $) 247) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-123)) 214) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-1170)) 216)) (-4357 (((-121) $) 19)) (-4362 ((|#2| $) 21)) (-4485 (($ $ (-611 $) $) NIL) (($ $ (-638 (-611 $)) (-638 $)) 232) (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) 96) (($ $ (-1170) (-1 $ (-638 $))) NIL) (($ $ (-1170) (-1 $ $)) NIL) (($ $ (-638 (-123)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-123) (-1 $ (-638 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1170)) 57) (($ $ (-638 (-1170))) 236) (($ $) 237) (($ $ (-123) $ (-1170)) 60) (($ $ (-638 (-123)) (-638 $) (-1170)) 67) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ $))) 107) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ (-638 $)))) 238) (($ $ (-1170) (-769) (-1 $ (-638 $))) 94) (($ $ (-1170) (-769) (-1 $ $)) 93)) (-3277 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-638 $)) 106)) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) 234)) (-3425 (($ $) 279)) (-4081 (((-893 (-572)) $) 253) (((-893 (-385)) $) 256) (($ (-424 $)) 315) (((-545) $) NIL)) (-3972 (((-856) $) 235) (($ (-611 $)) 84) (($ (-1170)) 26) (($ |#2|) NIL) (($ (-1121 |#2| (-611 $))) NIL) (($ (-413 |#2|)) 284) (($ (-959 (-413 |#2|))) 324) (($ (-413 (-959 (-413 |#2|)))) 296) (($ (-413 (-959 |#2|))) 290) (($ $) NIL) (($ (-959 |#2|)) 183) (($ (-413 (-572))) 329) (($ (-572)) NIL)) (-2140 (((-769)) 79)) (-3228 (((-121) (-123)) 41)) (-2973 (($ (-1170) $) 33) (($ (-1170) $ $) 34) (($ (-1170) $ $ $) 35) (($ (-1170) $ $ $ $) 36) (($ (-1170) (-638 $)) 39)) (* (($ (-413 (-572)) $) NIL) (($ $ (-413 (-572))) NIL) (($ |#2| $) 261) (($ $ |#2|) NIL) (($ $ $) NIL) (($ (-572) $) NIL) (($ (-769) $) NIL) (($ (-923) $) NIL))) 
-(((-435 |#1| |#2|) (-10 -8 (-15 * (|#1| (-923) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -2140 ((-769))) (-15 -3972 (|#1| (-572))) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -4081 ((-545) |#1|)) (-15 -1318 ((-959 |#2|) |#1|)) (-15 -3376 ((-3 (-959 |#2|) "failed") |#1|)) (-15 -3972 (|#1| (-959 |#2|))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -3972 (|#1| |#1|)) (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 -1318 ((-413 (-959 |#2|)) |#1|)) (-15 -3376 ((-3 (-413 (-959 |#2|)) "failed") |#1|)) (-15 -3972 (|#1| (-413 (-959 |#2|)))) (-15 -4297 ((-413 (-1166 |#1|)) |#1| (-611 |#1|))) (-15 -3972 (|#1| (-413 (-959 (-413 |#2|))))) (-15 -3972 (|#1| (-959 (-413 |#2|)))) (-15 -3972 (|#1| (-413 |#2|))) (-15 -3425 (|#1| |#1|)) (-15 -4081 (|#1| (-424 |#1|))) (-15 -4485 (|#1| |#1| (-1170) (-769) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-1170) (-769) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-769)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-769)) (-638 (-1 |#1| |#1|)))) (-15 -2472 ((-3 (-2 (|:| |val| |#1|) (|:| -3751 (-572))) "failed") |#1|)) (-15 -3019 ((-3 (-2 (|:| |var| (-611 |#1|)) (|:| -3751 (-572))) "failed") |#1| (-1170))) (-15 -3019 ((-3 (-2 (|:| |var| (-611 |#1|)) (|:| -3751 (-572))) "failed") |#1| (-123))) (-15 -4347 (|#1| |#1|)) (-15 -3972 (|#1| (-1121 |#2| (-611 |#1|)))) (-15 -1595 ((-3 (-2 (|:| -4513 (-572)) (|:| |var| (-611 |#1|))) "failed") |#1|)) (-15 -2336 ((-3 (-638 |#1|) "failed") |#1|)) (-15 -3019 ((-3 (-2 (|:| |var| (-611 |#1|)) (|:| -3751 (-572))) "failed") |#1|)) (-15 -1921 ((-3 (-638 |#1|) "failed") |#1|)) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 |#1|) (-1170))) (-15 -4485 (|#1| |#1| (-123) |#1| (-1170))) (-15 -4485 (|#1| |#1|)) (-15 -4485 (|#1| |#1| (-638 (-1170)))) (-15 -4485 (|#1| |#1| (-1170))) (-15 -2973 (|#1| (-1170) (-638 |#1|))) (-15 -2973 (|#1| (-1170) |#1| |#1| |#1| |#1|)) (-15 -2973 (|#1| (-1170) |#1| |#1| |#1|)) (-15 -2973 (|#1| (-1170) |#1| |#1|)) (-15 -2973 (|#1| (-1170) |#1|)) (-15 -3456 ((-638 (-1170)) |#1|)) (-15 -4362 (|#2| |#1|)) (-15 -4357 ((-121) |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -1318 ((-1170) |#1|)) (-15 -3376 ((-3 (-1170) "failed") |#1|)) (-15 -3972 (|#1| (-1170))) (-15 -4485 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-123) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 (-1 |#1| |#1|)))) (-15 -4485 (|#1| |#1| (-1170) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-1170) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-1 |#1| |#1|)))) (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -4291 ((-638 (-611 |#1|)) |#1|)) (-15 -3614 ((-3 (-611 |#1|) "failed") |#1|)) (-15 -1952 (|#1| |#1| (-638 (-611 |#1|)) (-638 |#1|))) (-15 -1952 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -1952 (|#1| |#1| (-290 |#1|))) (-15 -3277 (|#1| (-123) (-638 |#1|))) (-15 -3277 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1| |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-611 |#1|)) (-638 |#1|))) (-15 -4485 (|#1| |#1| (-611 |#1|) |#1|)) (-15 -1318 ((-611 |#1|) |#1|)) (-15 -3376 ((-3 (-611 |#1|) "failed") |#1|)) (-15 -3972 (|#1| (-611 |#1|))) (-15 -3972 ((-856) |#1|))) (-436 |#2|) (-848)) (T -435)) 
-((-4564 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *4 (-848)) (-5 *1 (-435 *3 *4)) (-4 *3 (-436 *4)))) (-3228 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-435 *4 *5)) (-4 *4 (-436 *5)))) (-2140 (*1 *2) (-12 (-4 *4 (-848)) (-5 *2 (-769)) (-5 *1 (-435 *3 *4)) (-4 *3 (-436 *4))))) 
-(-10 -8 (-15 * (|#1| (-923) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -2140 ((-769))) (-15 -3972 (|#1| (-572))) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -4081 ((-545) |#1|)) (-15 -1318 ((-959 |#2|) |#1|)) (-15 -3376 ((-3 (-959 |#2|) "failed") |#1|)) (-15 -3972 (|#1| (-959 |#2|))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -3972 (|#1| |#1|)) (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 -1318 ((-413 (-959 |#2|)) |#1|)) (-15 -3376 ((-3 (-413 (-959 |#2|)) "failed") |#1|)) (-15 -3972 (|#1| (-413 (-959 |#2|)))) (-15 -4297 ((-413 (-1166 |#1|)) |#1| (-611 |#1|))) (-15 -3972 (|#1| (-413 (-959 (-413 |#2|))))) (-15 -3972 (|#1| (-959 (-413 |#2|)))) (-15 -3972 (|#1| (-413 |#2|))) (-15 -3425 (|#1| |#1|)) (-15 -4081 (|#1| (-424 |#1|))) (-15 -4485 (|#1| |#1| (-1170) (-769) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-1170) (-769) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-769)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-769)) (-638 (-1 |#1| |#1|)))) (-15 -2472 ((-3 (-2 (|:| |val| |#1|) (|:| -3751 (-572))) "failed") |#1|)) (-15 -3019 ((-3 (-2 (|:| |var| (-611 |#1|)) (|:| -3751 (-572))) "failed") |#1| (-1170))) (-15 -3019 ((-3 (-2 (|:| |var| (-611 |#1|)) (|:| -3751 (-572))) "failed") |#1| (-123))) (-15 -4347 (|#1| |#1|)) (-15 -3972 (|#1| (-1121 |#2| (-611 |#1|)))) (-15 -1595 ((-3 (-2 (|:| -4513 (-572)) (|:| |var| (-611 |#1|))) "failed") |#1|)) (-15 -2336 ((-3 (-638 |#1|) "failed") |#1|)) (-15 -3019 ((-3 (-2 (|:| |var| (-611 |#1|)) (|:| -3751 (-572))) "failed") |#1|)) (-15 -1921 ((-3 (-638 |#1|) "failed") |#1|)) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 |#1|) (-1170))) (-15 -4485 (|#1| |#1| (-123) |#1| (-1170))) (-15 -4485 (|#1| |#1|)) (-15 -4485 (|#1| |#1| (-638 (-1170)))) (-15 -4485 (|#1| |#1| (-1170))) (-15 -2973 (|#1| (-1170) (-638 |#1|))) (-15 -2973 (|#1| (-1170) |#1| |#1| |#1| |#1|)) (-15 -2973 (|#1| (-1170) |#1| |#1| |#1|)) (-15 -2973 (|#1| (-1170) |#1| |#1|)) (-15 -2973 (|#1| (-1170) |#1|)) (-15 -3456 ((-638 (-1170)) |#1|)) (-15 -4362 (|#2| |#1|)) (-15 -4357 ((-121) |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -1318 ((-1170) |#1|)) (-15 -3376 ((-3 (-1170) "failed") |#1|)) (-15 -3972 (|#1| (-1170))) (-15 -4485 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-123) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-123)) (-638 (-1 |#1| |#1|)))) (-15 -4485 (|#1| |#1| (-1170) (-1 |#1| |#1|))) (-15 -4485 (|#1| |#1| (-1170) (-1 |#1| (-638 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-1 |#1| (-638 |#1|))))) (-15 -4485 (|#1| |#1| (-638 (-1170)) (-638 (-1 |#1| |#1|)))) (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -4291 ((-638 (-611 |#1|)) |#1|)) (-15 -3614 ((-3 (-611 |#1|) "failed") |#1|)) (-15 -1952 (|#1| |#1| (-638 (-611 |#1|)) (-638 |#1|))) (-15 -1952 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -1952 (|#1| |#1| (-290 |#1|))) (-15 -3277 (|#1| (-123) (-638 |#1|))) (-15 -3277 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1| |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1| |#1|)) (-15 -3277 (|#1| (-123) |#1|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4485 (|#1| |#1| (-638 (-611 |#1|)) (-638 |#1|))) (-15 -4485 (|#1| |#1| (-611 |#1|) |#1|)) (-15 -1318 ((-611 |#1|) |#1|)) (-15 -3376 ((-3 (-611 |#1|) "failed") |#1|)) (-15 -3972 (|#1| (-611 |#1|))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 108 (|has| |#1| (-25)))) (-3456 (((-638 (-1170)) $) 195)) (-4297 (((-413 (-1166 $)) $ (-611 $)) 163 (|has| |#1| (-562)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 135 (|has| |#1| (-562)))) (-3946 (($ $) 136 (|has| |#1| (-562)))) (-3686 (((-121) $) 138 (|has| |#1| (-562)))) (-1337 (((-638 (-611 $)) $) 43)) (-1572 (((-3 $ "failed") $ $) 110 (|has| |#1| (-21)))) (-1952 (($ $ (-290 $)) 55) (($ $ (-638 (-290 $))) 54) (($ $ (-638 (-611 $)) (-638 $)) 53)) (-2844 (($ $) 155 (|has| |#1| (-562)))) (-1466 (((-424 $) $) 156 (|has| |#1| (-562)))) (-3112 (((-121) $ $) 146 (|has| |#1| (-562)))) (-2211 (($) 94 (-1841 (|has| |#1| (-1110)) (|has| |#1| (-25))) CONST)) (-3376 (((-3 (-611 $) "failed") $) 68) (((-3 (-1170) "failed") $) 208) (((-3 (-572) "failed") $) 201 (|has| |#1| (-1044 (-572)))) (((-3 |#1| "failed") $) 199) (((-3 (-413 (-959 |#1|)) "failed") $) 161 (|has| |#1| (-562))) (((-3 (-959 |#1|) "failed") $) 115 (|has| |#1| (-1054))) (((-3 (-413 (-572)) "failed") $) 87 (-1841 (-12 (|has| |#1| (-1044 (-572))) (|has| |#1| (-562))) (|has| |#1| (-1044 (-413 (-572))))))) (-1318 (((-611 $) $) 67) (((-1170) $) 207) (((-572) $) 202 (|has| |#1| (-1044 (-572)))) ((|#1| $) 198) (((-413 (-959 |#1|)) $) 160 (|has| |#1| (-562))) (((-959 |#1|) $) 114 (|has| |#1| (-1054))) (((-413 (-572)) $) 86 (-1841 (-12 (|has| |#1| (-1044 (-572))) (|has| |#1| (-562))) (|has| |#1| (-1044 (-413 (-572))))))) (-2190 (($ $ $) 150 (|has| |#1| (-562)))) (-2284 (((-685 (-572)) (-685 $)) 129 (-4028 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 128 (-4028 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 127 (|has| |#1| (-1054))) (((-685 |#1|) (-685 $)) 126 (|has| |#1| (-1054)))) (-1799 (((-3 $ "failed") $) 97 (|has| |#1| (-1110)))) (-2208 (($ $ $) 149 (|has| |#1| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 144 (|has| |#1| (-562)))) (-1526 (((-121) $) 157 (|has| |#1| (-562)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 204 (|has| |#1| (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 203 (|has| |#1| (-887 (-385))))) (-3567 (($ $) 50) (($ (-638 $)) 49)) (-4091 (((-638 (-123)) $) 42)) (-4564 (((-123) (-123)) 41)) (-3893 (((-121) $) 95 (|has| |#1| (-1110)))) (-4240 (((-121) $) 21 (|has| $ (-1044 (-572))))) (-4347 (($ $) 178 (|has| |#1| (-1054)))) (-4487 (((-1121 |#1| (-611 $)) $) 179 (|has| |#1| (-1054)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 153 (|has| |#1| (-562)))) (-4127 (((-1166 $) (-611 $)) 24 (|has| $ (-1054)))) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-3828 (($ (-1 $ $) (-611 $)) 35)) (-3614 (((-3 (-611 $) "failed") $) 45)) (-1629 (($ (-638 $)) 142 (|has| |#1| (-562))) (($ $ $) 141 (|has| |#1| (-562)))) (-1658 (((-1152) $) 9)) (-4291 (((-638 (-611 $)) $) 44)) (-4496 (($ (-123) $) 37) (($ (-123) (-638 $)) 36)) (-1921 (((-3 (-638 $) "failed") $) 184 (|has| |#1| (-1110)))) (-2472 (((-3 (-2 (|:| |val| $) (|:| -3751 (-572))) "failed") $) 175 (|has| |#1| (-1054)))) (-2336 (((-3 (-638 $) "failed") $) 182 (|has| |#1| (-25)))) (-1595 (((-3 (-2 (|:| -4513 (-572)) (|:| |var| (-611 $))) "failed") $) 181 (|has| |#1| (-25)))) (-3019 (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $) 183 (|has| |#1| (-1110))) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-123)) 177 (|has| |#1| (-1054))) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-1170)) 176 (|has| |#1| (-1054)))) (-3291 (((-121) $ (-123)) 39) (((-121) $ (-1170)) 38)) (-4350 (($ $) 99 (-1841 (|has| |#1| (-482)) (|has| |#1| (-562))))) (-1455 (((-769) $) 46)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 197)) (-4362 ((|#1| $) 196)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 143 (|has| |#1| (-562)))) (-3069 (($ (-638 $)) 140 (|has| |#1| (-562))) (($ $ $) 139 (|has| |#1| (-562)))) (-4319 (((-121) $ $) 34) (((-121) $ (-1170)) 33)) (-4304 (((-424 $) $) 154 (|has| |#1| (-562)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 152 (|has| |#1| (-562))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 151 (|has| |#1| (-562)))) (-1803 (((-3 $ "failed") $ $) 134 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 145 (|has| |#1| (-562)))) (-4247 (((-121) $) 22 (|has| $ (-1044 (-572))))) (-4485 (($ $ (-611 $) $) 66) (($ $ (-638 (-611 $)) (-638 $)) 65) (($ $ (-638 (-290 $))) 64) (($ $ (-290 $)) 63) (($ $ $ $) 62) (($ $ (-638 $) (-638 $)) 61) (($ $ (-638 (-1170)) (-638 (-1 $ $))) 32) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) 31) (($ $ (-1170) (-1 $ (-638 $))) 30) (($ $ (-1170) (-1 $ $)) 29) (($ $ (-638 (-123)) (-638 (-1 $ $))) 28) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) 27) (($ $ (-123) (-1 $ (-638 $))) 26) (($ $ (-123) (-1 $ $)) 25) (($ $ (-1170)) 189 (|has| |#1| (-613 (-545)))) (($ $ (-638 (-1170))) 188 (|has| |#1| (-613 (-545)))) (($ $) 187 (|has| |#1| (-613 (-545)))) (($ $ (-123) $ (-1170)) 186 (|has| |#1| (-613 (-545)))) (($ $ (-638 (-123)) (-638 $) (-1170)) 185 (|has| |#1| (-613 (-545)))) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ $))) 174 (|has| |#1| (-1054))) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ (-638 $)))) 173 (|has| |#1| (-1054))) (($ $ (-1170) (-769) (-1 $ (-638 $))) 172 (|has| |#1| (-1054))) (($ $ (-1170) (-769) (-1 $ $)) 171 (|has| |#1| (-1054)))) (-4029 (((-769) $) 147 (|has| |#1| (-562)))) (-3277 (($ (-123) $) 60) (($ (-123) $ $) 59) (($ (-123) $ $ $) 58) (($ (-123) $ $ $ $) 57) (($ (-123) (-638 $)) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 148 (|has| |#1| (-562)))) (-2759 (($ $) 48) (($ $ $) 47)) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) 120 (|has| |#1| (-1054))) (($ $ (-1170) (-769)) 119 (|has| |#1| (-1054))) (($ $ (-638 (-1170))) 118 (|has| |#1| (-1054))) (($ $ (-1170)) 117 (|has| |#1| (-1054)))) (-3425 (($ $) 168 (|has| |#1| (-562)))) (-4492 (((-1121 |#1| (-611 $)) $) 169 (|has| |#1| (-562)))) (-2830 (($ $) 23 (|has| $ (-1054)))) (-4081 (((-893 (-572)) $) 206 (|has| |#1| (-613 (-893 (-572))))) (((-893 (-385)) $) 205 (|has| |#1| (-613 (-893 (-385))))) (($ (-424 $)) 170 (|has| |#1| (-562))) (((-545) $) 89 (|has| |#1| (-613 (-545))))) (-3018 (($ $ $) 103 (|has| |#1| (-482)))) (-4056 (($ $ $) 104 (|has| |#1| (-482)))) (-3972 (((-856) $) 11) (($ (-611 $)) 69) (($ (-1170)) 209) (($ |#1|) 200) (($ (-1121 |#1| (-611 $))) 180 (|has| |#1| (-1054))) (($ (-413 |#1|)) 166 (|has| |#1| (-562))) (($ (-959 (-413 |#1|))) 165 (|has| |#1| (-562))) (($ (-413 (-959 (-413 |#1|)))) 164 (|has| |#1| (-562))) (($ (-413 (-959 |#1|))) 162 (|has| |#1| (-562))) (($ $) 133 (|has| |#1| (-562))) (($ (-959 |#1|)) 116 (|has| |#1| (-1054))) (($ (-413 (-572))) 88 (-1841 (|has| |#1| (-562)) (-12 (|has| |#1| (-1044 (-572))) (|has| |#1| (-562))) (|has| |#1| (-1044 (-413 (-572)))))) (($ (-572)) 85 (-1841 (|has| |#1| (-1054)) (|has| |#1| (-1044 (-572)))))) (-2779 (((-3 $ "failed") $) 130 (|has| |#1| (-149)))) (-2140 (((-769)) 125 (|has| |#1| (-1054)))) (-3497 (($ $) 52) (($ (-638 $)) 51)) (-3228 (((-121) (-123)) 40)) (-3774 (((-121) $ $) 137 (|has| |#1| (-562)))) (-2973 (($ (-1170) $) 194) (($ (-1170) $ $) 193) (($ (-1170) $ $ $) 192) (($ (-1170) $ $ $ $) 191) (($ (-1170) (-638 $)) 190)) (-4174 (($ $ (-572)) 102 (-1841 (|has| |#1| (-482)) (|has| |#1| (-562)))) (($ $ (-769)) 96 (|has| |#1| (-1110))) (($ $ (-923)) 92 (|has| |#1| (-1110)))) (-2378 (($) 107 (|has| |#1| (-25)) CONST)) (-3255 (($) 93 (|has| |#1| (-1110)) CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) 124 (|has| |#1| (-1054))) (($ $ (-1170) (-769)) 123 (|has| |#1| (-1054))) (($ $ (-638 (-1170))) 122 (|has| |#1| (-1054))) (($ $ (-1170)) 121 (|has| |#1| (-1054)))) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (-1379 (($ (-1121 |#1| (-611 $)) (-1121 |#1| (-611 $))) 167 (|has| |#1| (-562))) (($ $ $) 100 (-1841 (|has| |#1| (-482)) (|has| |#1| (-562))))) (-1373 (($ $ $) 112 (|has| |#1| (-21))) (($ $) 111 (|has| |#1| (-21)))) (-1367 (($ $ $) 105 (|has| |#1| (-25)))) (** (($ $ (-572)) 101 (-1841 (|has| |#1| (-482)) (|has| |#1| (-562)))) (($ $ (-769)) 98 (|has| |#1| (-1110))) (($ $ (-923)) 91 (|has| |#1| (-1110)))) (* (($ (-413 (-572)) $) 159 (|has| |#1| (-562))) (($ $ (-413 (-572))) 158 (|has| |#1| (-562))) (($ |#1| $) 132 (|has| |#1| (-174))) (($ $ |#1|) 131 (|has| |#1| (-174))) (($ (-572) $) 113 (|has| |#1| (-21))) (($ (-769) $) 109 (|has| |#1| (-25))) (($ (-923) $) 106 (|has| |#1| (-25))) (($ $ $) 90 (|has| |#1| (-1110))))) 
-(((-436 |#1|) (-1290) (-848)) (T -436)) 
-((-4357 (*1 *2 *1) (-12 (-4 *1 (-436 *3)) (-4 *3 (-848)) (-5 *2 (-121)))) (-4362 (*1 *2 *1) (-12 (-4 *1 (-436 *2)) (-4 *2 (-848)))) (-3456 (*1 *2 *1) (-12 (-4 *1 (-436 *3)) (-4 *3 (-848)) (-5 *2 (-638 (-1170))))) (-2973 (*1 *1 *2 *1) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)))) (-2973 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)))) (-2973 (*1 *1 *2 *1 *1 *1) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)))) (-2973 (*1 *1 *2 *1 *1 *1 *1) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)))) (-2973 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-638 *1)) (-4 *1 (-436 *4)) (-4 *4 (-848)))) (-4485 (*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)) (-4 *3 (-613 (-545))))) (-4485 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-1170))) (-4 *1 (-436 *3)) (-4 *3 (-848)) (-4 *3 (-613 (-545))))) (-4485 (*1 *1 *1) (-12 (-4 *1 (-436 *2)) (-4 *2 (-848)) (-4 *2 (-613 (-545))))) (-4485 (*1 *1 *1 *2 *1 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1170)) (-4 *1 (-436 *4)) (-4 *4 (-848)) (-4 *4 (-613 (-545))))) (-4485 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-123))) (-5 *3 (-638 *1)) (-5 *4 (-1170)) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-613 (-545))))) (-1921 (*1 *2 *1) (|partial| -12 (-4 *3 (-1110)) (-4 *3 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-436 *3)))) (-3019 (*1 *2 *1) (|partial| -12 (-4 *3 (-1110)) (-4 *3 (-848)) (-5 *2 (-2 (|:| |var| (-611 *1)) (|:| -3751 (-572)))) (-4 *1 (-436 *3)))) (-2336 (*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-436 *3)))) (-1595 (*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-848)) (-5 *2 (-2 (|:| -4513 (-572)) (|:| |var| (-611 *1)))) (-4 *1 (-436 *3)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1121 *3 (-611 *1))) (-4 *3 (-1054)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) (-4487 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *3 (-848)) (-5 *2 (-1121 *3 (-611 *1))) (-4 *1 (-436 *3)))) (-4347 (*1 *1 *1) (-12 (-4 *1 (-436 *2)) (-4 *2 (-848)) (-4 *2 (-1054)))) (-3019 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-4 *4 (-1054)) (-4 *4 (-848)) (-5 *2 (-2 (|:| |var| (-611 *1)) (|:| -3751 (-572)))) (-4 *1 (-436 *4)))) (-3019 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1170)) (-4 *4 (-1054)) (-4 *4 (-848)) (-5 *2 (-2 (|:| |var| (-611 *1)) (|:| -3751 (-572)))) (-4 *1 (-436 *4)))) (-2472 (*1 *2 *1) (|partial| -12 (-4 *3 (-1054)) (-4 *3 (-848)) (-5 *2 (-2 (|:| |val| *1) (|:| -3751 (-572)))) (-4 *1 (-436 *3)))) (-4485 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-638 (-769))) (-5 *4 (-638 (-1 *1 *1))) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-1054)))) (-4485 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-638 (-769))) (-5 *4 (-638 (-1 *1 (-638 *1)))) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-1054)))) (-4485 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-769)) (-5 *4 (-1 *1 (-638 *1))) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-1054)))) (-4485 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-769)) (-5 *4 (-1 *1 *1)) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-1054)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-424 *1)) (-4 *1 (-436 *3)) (-4 *3 (-562)) (-4 *3 (-848)))) (-4492 (*1 *2 *1) (-12 (-4 *3 (-562)) (-4 *3 (-848)) (-5 *2 (-1121 *3 (-611 *1))) (-4 *1 (-436 *3)))) (-3425 (*1 *1 *1) (-12 (-4 *1 (-436 *2)) (-4 *2 (-848)) (-4 *2 (-562)))) (-1379 (*1 *1 *2 *2) (-12 (-5 *2 (-1121 *3 (-611 *1))) (-4 *3 (-562)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-413 *3)) (-4 *3 (-562)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-959 (-413 *3))) (-4 *3 (-562)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-413 *3)))) (-4 *3 (-562)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) (-4297 (*1 *2 *1 *3) (-12 (-5 *3 (-611 *1)) (-4 *1 (-436 *4)) (-4 *4 (-848)) (-4 *4 (-562)) (-5 *2 (-413 (-1166 *1))))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-436 *3)) (-4 *3 (-848)) (-4 *3 (-1110))))) 
-(-13 (-298) (-1044 (-1170)) (-885 |t#1|) (-406 |t#1|) (-417 |t#1|) (-10 -8 (-15 -4357 ((-121) $)) (-15 -4362 (|t#1| $)) (-15 -3456 ((-638 (-1170)) $)) (-15 -2973 ($ (-1170) $)) (-15 -2973 ($ (-1170) $ $)) (-15 -2973 ($ (-1170) $ $ $)) (-15 -2973 ($ (-1170) $ $ $ $)) (-15 -2973 ($ (-1170) (-638 $))) (IF (|has| |t#1| (-613 (-545))) (PROGN (-6 (-613 (-545))) (-15 -4485 ($ $ (-1170))) (-15 -4485 ($ $ (-638 (-1170)))) (-15 -4485 ($ $)) (-15 -4485 ($ $ (-123) $ (-1170))) (-15 -4485 ($ $ (-638 (-123)) (-638 $) (-1170)))) |noBranch|) (IF (|has| |t#1| (-1110)) (PROGN (-6 (-722)) (-15 ** ($ $ (-769))) (-15 -1921 ((-3 (-638 $) "failed") $)) (-15 -3019 ((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $))) |noBranch|) (IF (|has| |t#1| (-482)) (-6 (-482)) |noBranch|) (IF (|has| |t#1| (-25)) (PROGN (-6 (-23)) (-15 -2336 ((-3 (-638 $) "failed") $)) (-15 -1595 ((-3 (-2 (|:| -4513 (-572)) (|:| |var| (-611 $))) "failed") $))) |noBranch|) (IF (|has| |t#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |t#1| (-1054)) (PROGN (-6 (-1054)) (-6 (-1044 (-959 |t#1|))) (-6 (-901 (-1170))) (-6 (-383 |t#1|)) (-15 -3972 ($ (-1121 |t#1| (-611 $)))) (-15 -4487 ((-1121 |t#1| (-611 $)) $)) (-15 -4347 ($ $)) (-15 -3019 ((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-123))) (-15 -3019 ((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-1170))) (-15 -2472 ((-3 (-2 (|:| |val| $) (|:| -3751 (-572))) "failed") $)) (-15 -4485 ($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ $)))) (-15 -4485 ($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ (-638 $))))) (-15 -4485 ($ $ (-1170) (-769) (-1 $ (-638 $)))) (-15 -4485 ($ $ (-1170) (-769) (-1 $ $)))) |noBranch|) (IF (|has| |t#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |t#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |t#1| (-174)) (-6 (-43 |t#1|)) |noBranch|) (IF (|has| |t#1| (-562)) (PROGN (-6 (-368)) (-6 (-1044 (-413 (-959 |t#1|)))) (-15 -4081 ($ (-424 $))) (-15 -4492 ((-1121 |t#1| (-611 $)) $)) (-15 -3425 ($ $)) (-15 -1379 ($ (-1121 |t#1| (-611 $)) (-1121 |t#1| (-611 $)))) (-15 -3972 ($ (-413 |t#1|))) (-15 -3972 ($ (-959 (-413 |t#1|)))) (-15 -3972 ($ (-413 (-959 (-413 |t#1|))))) (-15 -4297 ((-413 (-1166 $)) $ (-611 $))) (IF (|has| |t#1| (-1044 (-572))) (-6 (-1044 (-413 (-572)))) |noBranch|)) |noBranch|))) 
-(((-21) -1841 (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149)) (|has| |#1| (-21))) ((-23) -1841 (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149)) (|has| |#1| (-25)) (|has| |#1| (-21))) ((-25) -1841 (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149)) (|has| |#1| (-25)) (|has| |#1| (-21))) ((-43 (-413 (-572))) |has| |#1| (-562)) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) |has| |#1| (-562)) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-562)) ((-120 |#1| |#1|) |has| |#1| (-174)) ((-120 $ $) |has| |#1| (-562)) ((-138) -1841 (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149)) (|has| |#1| (-21))) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) |has| |#1| (-562)) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-613 (-893 (-385))) |has| |#1| (-613 (-893 (-385)))) ((-613 (-893 (-572))) |has| |#1| (-613 (-893 (-572)))) ((-240) |has| |#1| (-562)) ((-287) |has| |#1| (-562)) ((-303) |has| |#1| (-562)) ((-305 $) . T) ((-298) . T) ((-368) |has| |#1| (-562)) ((-383 |#1|) |has| |#1| (-1054)) ((-406 |#1|) . T) ((-417 |#1|) . T) ((-457) |has| |#1| (-562)) ((-482) |has| |#1| (-482)) ((-527 (-611 $) $) . T) ((-527 $ $) . T) ((-562) |has| |#1| (-562)) ((-641 (-413 (-572))) |has| |#1| (-562)) ((-641 |#1|) |has| |#1| (-174)) ((-641 $) -1841 (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149))) ((-634 (-572)) -12 (|has| |#1| (-634 (-572))) (|has| |#1| (-1054))) ((-634 |#1|) |has| |#1| (-1054)) ((-713 (-413 (-572))) |has| |#1| (-562)) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) |has| |#1| (-562)) ((-722) -1841 (|has| |#1| (-1110)) (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-482)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149))) ((-848) . T) ((-901 (-1170)) |has| |#1| (-1054)) ((-887 (-385)) |has| |#1| (-887 (-385))) ((-887 (-572)) |has| |#1| (-887 (-572))) ((-885 |#1|) . T) ((-922) |has| |#1| (-562)) ((-1044 (-413 (-572))) -1841 (|has| |#1| (-1044 (-413 (-572)))) (-12 (|has| |#1| (-562)) (|has| |#1| (-1044 (-572))))) ((-1044 (-413 (-959 |#1|))) |has| |#1| (-562)) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 (-611 $)) . T) ((-1044 (-959 |#1|)) |has| |#1| (-1054)) ((-1044 (-1170)) . T) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) |has| |#1| (-562)) ((-1060 |#1|) |has| |#1| (-174)) ((-1060 $) |has| |#1| (-562)) ((-1054) -1841 (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149))) ((-1061) -1841 (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149))) ((-1110) -1841 (|has| |#1| (-1110)) (|has| |#1| (-1054)) (|has| |#1| (-562)) (|has| |#1| (-482)) (|has| |#1| (-174)) (|has| |#1| (-151)) (|has| |#1| (-149))) ((-1098) . T) ((-1204) . T) ((-1214) |has| |#1| (-562))) 
-((-1459 ((|#2| |#2| |#2|) 33)) (-4564 (((-123) (-123)) 44)) (-1371 ((|#2| (-638 |#2|)) 79)) (-3788 ((|#2| |#2|) 77)) (-4112 ((|#2| |#2|) 68)) (-3180 ((|#2| |#2|) 71)) (-2601 ((|#2| (-638 |#2|)) 75)) (-1393 ((|#2| (-638 |#2|)) 83)) (-4196 ((|#2| (-638 |#2|)) 87)) (-2387 ((|#2| (-638 |#2|)) 81)) (-3641 ((|#2| (-638 |#2|)) 85)) (-4005 ((|#2| |#2|) 91)) (-2932 ((|#2| |#2|) 89)) (-2350 ((|#2| |#2|) 32)) (-3045 ((|#2| |#2| |#2|) 35)) (-2625 ((|#2| |#2| |#2|) 37)) (-2312 ((|#2| |#2| |#2|) 34)) (-2638 ((|#2| |#2| |#2|) 36)) (-3228 (((-121) (-123)) 42)) (-3804 ((|#2| |#2|) 39)) (-1465 ((|#2| |#2|) 38)) (-2264 ((|#2| |#2|) 27)) (-1877 ((|#2| |#2| |#2|) 30) ((|#2| |#2|) 28)) (-1869 ((|#2| |#2| |#2|) 31))) 
-(((-437 |#1| |#2|) (-10 -7 (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -2264 (|#2| |#2|)) (-15 -1877 (|#2| |#2|)) (-15 -1877 (|#2| |#2| |#2|)) (-15 -1869 (|#2| |#2| |#2|)) (-15 -2350 (|#2| |#2|)) (-15 -1459 (|#2| |#2| |#2|)) (-15 -2312 (|#2| |#2| |#2|)) (-15 -3045 (|#2| |#2| |#2|)) (-15 -2638 (|#2| |#2| |#2|)) (-15 -2625 (|#2| |#2| |#2|)) (-15 -1465 (|#2| |#2|)) (-15 -3804 (|#2| |#2|)) (-15 -3180 (|#2| |#2|)) (-15 -4112 (|#2| |#2|)) (-15 -2601 (|#2| (-638 |#2|))) (-15 -3788 (|#2| |#2|)) (-15 -1371 (|#2| (-638 |#2|))) (-15 -2387 (|#2| (-638 |#2|))) (-15 -1393 (|#2| (-638 |#2|))) (-15 -3641 (|#2| (-638 |#2|))) (-15 -4196 (|#2| (-638 |#2|))) (-15 -2932 (|#2| |#2|)) (-15 -4005 (|#2| |#2|))) (-13 (-848) (-562)) (-436 |#1|)) (T -437)) 
-((-4005 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-2932 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-4196 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-3641 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-1393 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-2387 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-1371 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-3788 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-2601 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562))))) (-4112 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-3180 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-3804 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-1465 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-2625 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-2638 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-3045 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-2312 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-1459 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-2350 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-1869 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-1877 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-1877 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-2264 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) (-4564 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *4)) (-4 *4 (-436 *3)))) (-3228 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-437 *4 *5)) (-4 *5 (-436 *4))))) 
-(-10 -7 (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -2264 (|#2| |#2|)) (-15 -1877 (|#2| |#2|)) (-15 -1877 (|#2| |#2| |#2|)) (-15 -1869 (|#2| |#2| |#2|)) (-15 -2350 (|#2| |#2|)) (-15 -1459 (|#2| |#2| |#2|)) (-15 -2312 (|#2| |#2| |#2|)) (-15 -3045 (|#2| |#2| |#2|)) (-15 -2638 (|#2| |#2| |#2|)) (-15 -2625 (|#2| |#2| |#2|)) (-15 -1465 (|#2| |#2|)) (-15 -3804 (|#2| |#2|)) (-15 -3180 (|#2| |#2|)) (-15 -4112 (|#2| |#2|)) (-15 -2601 (|#2| (-638 |#2|))) (-15 -3788 (|#2| |#2|)) (-15 -1371 (|#2| (-638 |#2|))) (-15 -2387 (|#2| (-638 |#2|))) (-15 -1393 (|#2| (-638 |#2|))) (-15 -3641 (|#2| (-638 |#2|))) (-15 -4196 (|#2| (-638 |#2|))) (-15 -2932 (|#2| |#2|)) (-15 -4005 (|#2| |#2|))) 
-((-2754 (((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1166 |#2|)) (|:| |pol2| (-1166 |#2|)) (|:| |prim| (-1166 |#2|))) |#2| |#2|) 93 (|has| |#2| (-27))) (((-2 (|:| |primelt| |#2|) (|:| |poly| (-638 (-1166 |#2|))) (|:| |prim| (-1166 |#2|))) (-638 |#2|)) 58))) 
-(((-438 |#1| |#2|) (-10 -7 (-15 -2754 ((-2 (|:| |primelt| |#2|) (|:| |poly| (-638 (-1166 |#2|))) (|:| |prim| (-1166 |#2|))) (-638 |#2|))) (IF (|has| |#2| (-27)) (-15 -2754 ((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1166 |#2|)) (|:| |pol2| (-1166 |#2|)) (|:| |prim| (-1166 |#2|))) |#2| |#2|)) |noBranch|)) (-13 (-562) (-848) (-151)) (-436 |#1|)) (T -438)) 
-((-2754 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-562) (-848) (-151))) (-5 *2 (-2 (|:| |primelt| *3) (|:| |pol1| (-1166 *3)) (|:| |pol2| (-1166 *3)) (|:| |prim| (-1166 *3)))) (-5 *1 (-438 *4 *3)) (-4 *3 (-27)) (-4 *3 (-436 *4)))) (-2754 (*1 *2 *3) (-12 (-5 *3 (-638 *5)) (-4 *5 (-436 *4)) (-4 *4 (-13 (-562) (-848) (-151))) (-5 *2 (-2 (|:| |primelt| *5) (|:| |poly| (-638 (-1166 *5))) (|:| |prim| (-1166 *5)))) (-5 *1 (-438 *4 *5))))) 
-(-10 -7 (-15 -2754 ((-2 (|:| |primelt| |#2|) (|:| |poly| (-638 (-1166 |#2|))) (|:| |prim| (-1166 |#2|))) (-638 |#2|))) (IF (|has| |#2| (-27)) (-15 -2754 ((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1166 |#2|)) (|:| |pol2| (-1166 |#2|)) (|:| |prim| (-1166 |#2|))) |#2| |#2|)) |noBranch|)) 
-((-2585 (((-1264)) 18)) (-4421 (((-1166 (-413 (-572))) |#2| (-611 |#2|)) 40) (((-413 (-572)) |#2|) 23))) 
-(((-439 |#1| |#2|) (-10 -7 (-15 -4421 ((-413 (-572)) |#2|)) (-15 -4421 ((-1166 (-413 (-572))) |#2| (-611 |#2|))) (-15 -2585 ((-1264)))) (-13 (-848) (-562) (-1044 (-572))) (-436 |#1|)) (T -439)) 
-((-2585 (*1 *2) (-12 (-4 *3 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-1264)) (-5 *1 (-439 *3 *4)) (-4 *4 (-436 *3)))) (-4421 (*1 *2 *3 *4) (-12 (-5 *4 (-611 *3)) (-4 *3 (-436 *5)) (-4 *5 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-1166 (-413 (-572)))) (-5 *1 (-439 *5 *3)))) (-4421 (*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-413 (-572))) (-5 *1 (-439 *4 *3)) (-4 *3 (-436 *4))))) 
-(-10 -7 (-15 -4421 ((-413 (-572)) |#2|)) (-15 -4421 ((-1166 (-413 (-572))) |#2| (-611 |#2|))) (-15 -2585 ((-1264)))) 
-((-4523 (((-121) $) 28)) (-2076 (((-121) $) 30)) (-2814 (((-121) $) 31)) (-4326 (((-121) $) 34)) (-1949 (((-121) $) 29)) (-3687 (((-121) $) 33)) (-3972 (((-856) $) 18) (($ (-1152)) 27) (($ (-1170)) 23) (((-1170) $) 22) (((-1102) $) 21)) (-2727 (((-121) $) 32)) (-1324 (((-121) $ $) 15))) 
-(((-440) (-13 (-612 (-856)) (-10 -8 (-15 -3972 ($ (-1152))) (-15 -3972 ($ (-1170))) (-15 -3972 ((-1170) $)) (-15 -3972 ((-1102) $)) (-15 -4523 ((-121) $)) (-15 -1949 ((-121) $)) (-15 -2814 ((-121) $)) (-15 -3687 ((-121) $)) (-15 -4326 ((-121) $)) (-15 -2727 ((-121) $)) (-15 -2076 ((-121) $)) (-15 -1324 ((-121) $ $))))) (T -440)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-440)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-440)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-440)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1102)) (-5 *1 (-440)))) (-4523 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) (-1949 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) (-2814 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) (-3687 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) (-4326 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) (-2727 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) (-2076 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) (-1324 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440))))) 
-(-13 (-612 (-856)) (-10 -8 (-15 -3972 ($ (-1152))) (-15 -3972 ($ (-1170))) (-15 -3972 ((-1170) $)) (-15 -3972 ((-1102) $)) (-15 -4523 ((-121) $)) (-15 -1949 ((-121) $)) (-15 -2814 ((-121) $)) (-15 -3687 ((-121) $)) (-15 -4326 ((-121) $)) (-15 -2727 ((-121) $)) (-15 -2076 ((-121) $)) (-15 -1324 ((-121) $ $)))) 
-((-1434 (((-3 (-424 (-1166 (-413 (-572)))) "failed") |#3|) 68)) (-1411 (((-424 |#3|) |#3|) 33)) (-3423 (((-3 (-424 (-1166 (-53))) "failed") |#3|) 27 (|has| |#2| (-1044 (-53))))) (-3781 (((-3 (|:| |overq| (-1166 (-413 (-572)))) (|:| |overan| (-1166 (-53))) (|:| -1638 (-121))) |#3|) 35))) 
-(((-441 |#1| |#2| |#3|) (-10 -7 (-15 -1411 ((-424 |#3|) |#3|)) (-15 -1434 ((-3 (-424 (-1166 (-413 (-572)))) "failed") |#3|)) (-15 -3781 ((-3 (|:| |overq| (-1166 (-413 (-572)))) (|:| |overan| (-1166 (-53))) (|:| -1638 (-121))) |#3|)) (IF (|has| |#2| (-1044 (-53))) (-15 -3423 ((-3 (-424 (-1166 (-53))) "failed") |#3|)) |noBranch|)) (-13 (-562) (-848) (-1044 (-572))) (-436 |#1|) (-1234 |#2|)) (T -441)) 
-((-3423 (*1 *2 *3) (|partial| -12 (-4 *5 (-1044 (-53))) (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-4 *5 (-436 *4)) (-5 *2 (-424 (-1166 (-53)))) (-5 *1 (-441 *4 *5 *3)) (-4 *3 (-1234 *5)))) (-3781 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-4 *5 (-436 *4)) (-5 *2 (-3 (|:| |overq| (-1166 (-413 (-572)))) (|:| |overan| (-1166 (-53))) (|:| -1638 (-121)))) (-5 *1 (-441 *4 *5 *3)) (-4 *3 (-1234 *5)))) (-1434 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-4 *5 (-436 *4)) (-5 *2 (-424 (-1166 (-413 (-572))))) (-5 *1 (-441 *4 *5 *3)) (-4 *3 (-1234 *5)))) (-1411 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-4 *5 (-436 *4)) (-5 *2 (-424 *3)) (-5 *1 (-441 *4 *5 *3)) (-4 *3 (-1234 *5))))) 
-(-10 -7 (-15 -1411 ((-424 |#3|) |#3|)) (-15 -1434 ((-3 (-424 (-1166 (-413 (-572)))) "failed") |#3|)) (-15 -3781 ((-3 (|:| |overq| (-1166 (-413 (-572)))) (|:| |overan| (-1166 (-53))) (|:| -1638 (-121))) |#3|)) (IF (|has| |#2| (-1044 (-53))) (-15 -3423 ((-3 (-424 (-1166 (-53))) "failed") |#3|)) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-3757 (((-1152) $ (-1152)) NIL)) (-2582 (($ $ (-1152)) NIL)) (-2159 (((-1152) $) NIL)) (-3068 (((-394) (-394) (-394)) 17) (((-394) (-394)) 15)) (-1428 (($ (-394)) NIL) (($ (-394) (-1152)) NIL)) (-3201 (((-394) $) NIL)) (-1658 (((-1152) $) NIL)) (-1828 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2410 (((-1264) (-1152)) 9)) (-2612 (((-1264) (-1152)) 10)) (-3876 (((-1264)) 11)) (-1734 (((-1264) $) NIL)) (-3972 (((-856) $) NIL)) (-1391 (($ $) 34)) (-1324 (((-121) $ $) NIL))) 
-(((-442) (-13 (-369 (-394) (-1152)) (-10 -7 (-15 -3068 ((-394) (-394) (-394))) (-15 -3068 ((-394) (-394))) (-15 -2410 ((-1264) (-1152))) (-15 -2612 ((-1264) (-1152))) (-15 -3876 ((-1264)))))) (T -442)) 
-((-3068 (*1 *2 *2 *2) (-12 (-5 *2 (-394)) (-5 *1 (-442)))) (-3068 (*1 *2 *2) (-12 (-5 *2 (-394)) (-5 *1 (-442)))) (-2410 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-442)))) (-2612 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-442)))) (-3876 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-442))))) 
-(-13 (-369 (-394) (-1152)) (-10 -7 (-15 -3068 ((-394) (-394) (-394))) (-15 -3068 ((-394) (-394))) (-15 -2410 ((-1264) (-1152))) (-15 -2612 ((-1264) (-1152))) (-15 -3876 ((-1264))))) 
-((-2262 (((-121) $ $) NIL)) (-1420 (((-3 (|:| |fst| (-440)) (|:| -3166 "void")) $) 10)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4095 (($) 31)) (-2749 (($) 37)) (-2459 (($) 33)) (-3993 (($) 35)) (-3216 (($) 32)) (-4138 (($) 34)) (-1388 (($) 36)) (-3883 (((-121) $) 8)) (-3321 (((-638 (-959 (-572))) $) 16)) (-3921 (($ (-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-638 (-1170)) (-121)) 25) (($ (-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-638 (-959 (-572))) (-121)) 26)) (-3972 (((-856) $) 21) (($ (-440)) 28)) (-1324 (((-121) $ $) NIL))) 
-(((-443) (-13 (-1098) (-10 -8 (-15 -3972 ((-856) $)) (-15 -3972 ($ (-440))) (-15 -1420 ((-3 (|:| |fst| (-440)) (|:| -3166 "void")) $)) (-15 -3321 ((-638 (-959 (-572))) $)) (-15 -3883 ((-121) $)) (-15 -3921 ($ (-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-638 (-1170)) (-121))) (-15 -3921 ($ (-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-638 (-959 (-572))) (-121))) (-15 -4095 ($)) (-15 -3216 ($)) (-15 -2459 ($)) (-15 -2749 ($)) (-15 -4138 ($)) (-15 -3993 ($)) (-15 -1388 ($))))) (T -443)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-443)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-440)) (-5 *1 (-443)))) (-1420 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *1 (-443)))) (-3321 (*1 *2 *1) (-12 (-5 *2 (-638 (-959 (-572)))) (-5 *1 (-443)))) (-3883 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-443)))) (-3921 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *3 (-638 (-1170))) (-5 *4 (-121)) (-5 *1 (-443)))) (-3921 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-121)) (-5 *1 (-443)))) (-4095 (*1 *1) (-5 *1 (-443))) (-3216 (*1 *1) (-5 *1 (-443))) (-2459 (*1 *1) (-5 *1 (-443))) (-2749 (*1 *1) (-5 *1 (-443))) (-4138 (*1 *1) (-5 *1 (-443))) (-3993 (*1 *1) (-5 *1 (-443))) (-1388 (*1 *1) (-5 *1 (-443)))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ((-856) $)) (-15 -3972 ($ (-440))) (-15 -1420 ((-3 (|:| |fst| (-440)) (|:| -3166 "void")) $)) (-15 -3321 ((-638 (-959 (-572))) $)) (-15 -3883 ((-121) $)) (-15 -3921 ($ (-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-638 (-1170)) (-121))) (-15 -3921 ($ (-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-638 (-959 (-572))) (-121))) (-15 -4095 ($)) (-15 -3216 ($)) (-15 -2459 ($)) (-15 -2749 ($)) (-15 -4138 ($)) (-15 -3993 ($)) (-15 -1388 ($)))) 
-((-2262 (((-121) $ $) NIL)) (-3201 (((-1170) $) 8)) (-1658 (((-1152) $) 16)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 13))) 
-(((-444 |#1|) (-13 (-1098) (-10 -8 (-15 -3201 ((-1170) $)))) (-1170)) (T -444)) 
-((-3201 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-444 *3)) (-14 *3 *2)))) 
-(-13 (-1098) (-10 -8 (-15 -3201 ((-1170) $)))) 
-((-4355 (((-1264) $) 7)) (-3972 (((-856) $) 8) (($ (-1259 (-694))) 12) (($ (-638 (-330))) 11) (($ (-330)) 10) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 9))) 
-(((-445) (-1290)) (T -445)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-694))) (-4 *1 (-445)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-445)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-445)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-445))))) 
-(-13 (-401) (-10 -8 (-15 -3972 ($ (-1259 (-694)))) (-15 -3972 ($ (-638 (-330)))) (-15 -3972 ($ (-330))) (-15 -3972 ($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330)))))))) 
-(((-612 (-856)) . T) ((-401) . T) ((-1204) . T)) 
-((-3376 (((-3 $ "failed") (-1259 (-312 (-385)))) 19) (((-3 $ "failed") (-1259 (-312 (-572)))) 17) (((-3 $ "failed") (-1259 (-959 (-385)))) 15) (((-3 $ "failed") (-1259 (-959 (-572)))) 13) (((-3 $ "failed") (-1259 (-413 (-959 (-385))))) 11) (((-3 $ "failed") (-1259 (-413 (-959 (-572))))) 9)) (-1318 (($ (-1259 (-312 (-385)))) 20) (($ (-1259 (-312 (-572)))) 18) (($ (-1259 (-959 (-385)))) 16) (($ (-1259 (-959 (-572)))) 14) (($ (-1259 (-413 (-959 (-385))))) 12) (($ (-1259 (-413 (-959 (-572))))) 10)) (-4355 (((-1264) $) 7)) (-3972 (((-856) $) 8) (($ (-638 (-330))) 23) (($ (-330)) 22) (($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) 21))) 
-(((-446) (-1290)) (T -446)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-446)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-446)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-446)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-1259 (-312 (-385)))) (-4 *1 (-446)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-312 (-385)))) (-4 *1 (-446)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-1259 (-312 (-572)))) (-4 *1 (-446)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-312 (-572)))) (-4 *1 (-446)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-1259 (-959 (-385)))) (-4 *1 (-446)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-959 (-385)))) (-4 *1 (-446)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-1259 (-959 (-572)))) (-4 *1 (-446)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-959 (-572)))) (-4 *1 (-446)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-1259 (-413 (-959 (-385))))) (-4 *1 (-446)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-413 (-959 (-385))))) (-4 *1 (-446)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-1259 (-413 (-959 (-572))))) (-4 *1 (-446)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-413 (-959 (-572))))) (-4 *1 (-446))))) 
-(-13 (-401) (-10 -8 (-15 -3972 ($ (-638 (-330)))) (-15 -3972 ($ (-330))) (-15 -3972 ($ (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330)))))) (-15 -1318 ($ (-1259 (-312 (-385))))) (-15 -3376 ((-3 $ "failed") (-1259 (-312 (-385))))) (-15 -1318 ($ (-1259 (-312 (-572))))) (-15 -3376 ((-3 $ "failed") (-1259 (-312 (-572))))) (-15 -1318 ($ (-1259 (-959 (-385))))) (-15 -3376 ((-3 $ "failed") (-1259 (-959 (-385))))) (-15 -1318 ($ (-1259 (-959 (-572))))) (-15 -3376 ((-3 $ "failed") (-1259 (-959 (-572))))) (-15 -1318 ($ (-1259 (-413 (-959 (-385)))))) (-15 -3376 ((-3 $ "failed") (-1259 (-413 (-959 (-385)))))) (-15 -1318 ($ (-1259 (-413 (-959 (-572)))))) (-15 -3376 ((-3 $ "failed") (-1259 (-413 (-959 (-572)))))))) 
-(((-612 (-856)) . T) ((-401) . T) ((-1204) . T)) 
-((-2056 (((-121)) 17)) (-2102 (((-121) (-121)) 18)) (-2314 (((-121)) 13)) (-4061 (((-121) (-121)) 14)) (-2130 (((-121)) 15)) (-2563 (((-121) (-121)) 16)) (-2297 (((-923) (-923)) 21) (((-923)) 20)) (-4017 (((-769) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572))))) 41)) (-2831 (((-923) (-923)) 23) (((-923)) 22)) (-3618 (((-2 (|:| -4200 (-572)) (|:| -4547 (-638 |#1|))) |#1|) 61)) (-3533 (((-424 |#1|) (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572))))))) 125)) (-3560 (((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121)) 151)) (-2602 (((-424 |#1|) |#1| (-769) (-769)) 164) (((-424 |#1|) |#1| (-638 (-769)) (-769)) 161) (((-424 |#1|) |#1| (-638 (-769))) 163) (((-424 |#1|) |#1| (-769)) 162) (((-424 |#1|) |#1|) 160)) (-3969 (((-3 |#1| "failed") (-923) |#1| (-638 (-769)) (-769) (-121)) 166) (((-3 |#1| "failed") (-923) |#1| (-638 (-769)) (-769)) 167) (((-3 |#1| "failed") (-923) |#1| (-638 (-769))) 169) (((-3 |#1| "failed") (-923) |#1| (-769)) 168) (((-3 |#1| "failed") (-923) |#1|) 170)) (-4304 (((-424 |#1|) |#1| (-769) (-769)) 159) (((-424 |#1|) |#1| (-638 (-769)) (-769)) 155) (((-424 |#1|) |#1| (-638 (-769))) 157) (((-424 |#1|) |#1| (-769)) 156) (((-424 |#1|) |#1|) 154)) (-2929 (((-121) |#1|) 36)) (-2969 (((-733 (-769)) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572))))) 66)) (-1357 (((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121) (-1100 (-769)) (-769)) 153))) 
-(((-447 |#1|) (-10 -7 (-15 -3533 ((-424 |#1|) (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))))) (-15 -2969 ((-733 (-769)) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))))) (-15 -2831 ((-923))) (-15 -2831 ((-923) (-923))) (-15 -2297 ((-923))) (-15 -2297 ((-923) (-923))) (-15 -4017 ((-769) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))))) (-15 -3618 ((-2 (|:| -4200 (-572)) (|:| -4547 (-638 |#1|))) |#1|)) (-15 -2056 ((-121))) (-15 -2102 ((-121) (-121))) (-15 -2314 ((-121))) (-15 -4061 ((-121) (-121))) (-15 -2929 ((-121) |#1|)) (-15 -2130 ((-121))) (-15 -2563 ((-121) (-121))) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -4304 ((-424 |#1|) |#1| (-769))) (-15 -4304 ((-424 |#1|) |#1| (-638 (-769)))) (-15 -4304 ((-424 |#1|) |#1| (-638 (-769)) (-769))) (-15 -4304 ((-424 |#1|) |#1| (-769) (-769))) (-15 -2602 ((-424 |#1|) |#1|)) (-15 -2602 ((-424 |#1|) |#1| (-769))) (-15 -2602 ((-424 |#1|) |#1| (-638 (-769)))) (-15 -2602 ((-424 |#1|) |#1| (-638 (-769)) (-769))) (-15 -2602 ((-424 |#1|) |#1| (-769) (-769))) (-15 -3969 ((-3 |#1| "failed") (-923) |#1|)) (-15 -3969 ((-3 |#1| "failed") (-923) |#1| (-769))) (-15 -3969 ((-3 |#1| "failed") (-923) |#1| (-638 (-769)))) (-15 -3969 ((-3 |#1| "failed") (-923) |#1| (-638 (-769)) (-769))) (-15 -3969 ((-3 |#1| "failed") (-923) |#1| (-638 (-769)) (-769) (-121))) (-15 -3560 ((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121))) (-15 -1357 ((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121) (-1100 (-769)) (-769)))) (-1234 (-572))) (T -447)) 
-((-1357 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-121)) (-5 *5 (-1100 (-769))) (-5 *6 (-769)) (-5 *2 (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| *3) (|:| -3341 (-572))))))) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-3560 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| *3) (|:| -3341 (-572))))))) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-3969 (*1 *2 *3 *2 *4 *5 *6) (|partial| -12 (-5 *3 (-923)) (-5 *4 (-638 (-769))) (-5 *5 (-769)) (-5 *6 (-121)) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) (-3969 (*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *3 (-923)) (-5 *4 (-638 (-769))) (-5 *5 (-769)) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) (-3969 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-923)) (-5 *4 (-638 (-769))) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) (-3969 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-923)) (-5 *4 (-769)) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) (-3969 (*1 *2 *3 *2) (|partial| -12 (-5 *3 (-923)) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) (-2602 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2602 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-769))) (-5 *5 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2602 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-769))) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2602 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2602 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-4304 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-4304 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-769))) (-5 *5 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-769))) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-4304 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2563 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2130 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2929 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-4061 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2314 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2102 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2056 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-3618 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| -4200 (-572)) (|:| -4547 (-638 *3)))) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-4017 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -4304 *4) (|:| -4316 (-572))))) (-4 *4 (-1234 (-572))) (-5 *2 (-769)) (-5 *1 (-447 *4)))) (-2297 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2297 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2831 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2831 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) (-2969 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -4304 *4) (|:| -4316 (-572))))) (-4 *4 (-1234 (-572))) (-5 *2 (-733 (-769))) (-5 *1 (-447 *4)))) (-3533 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| *4) (|:| -3341 (-572))))))) (-4 *4 (-1234 (-572))) (-5 *2 (-424 *4)) (-5 *1 (-447 *4))))) 
-(-10 -7 (-15 -3533 ((-424 |#1|) (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))))) (-15 -2969 ((-733 (-769)) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))))) (-15 -2831 ((-923))) (-15 -2831 ((-923) (-923))) (-15 -2297 ((-923))) (-15 -2297 ((-923) (-923))) (-15 -4017 ((-769) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))))) (-15 -3618 ((-2 (|:| -4200 (-572)) (|:| -4547 (-638 |#1|))) |#1|)) (-15 -2056 ((-121))) (-15 -2102 ((-121) (-121))) (-15 -2314 ((-121))) (-15 -4061 ((-121) (-121))) (-15 -2929 ((-121) |#1|)) (-15 -2130 ((-121))) (-15 -2563 ((-121) (-121))) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -4304 ((-424 |#1|) |#1| (-769))) (-15 -4304 ((-424 |#1|) |#1| (-638 (-769)))) (-15 -4304 ((-424 |#1|) |#1| (-638 (-769)) (-769))) (-15 -4304 ((-424 |#1|) |#1| (-769) (-769))) (-15 -2602 ((-424 |#1|) |#1|)) (-15 -2602 ((-424 |#1|) |#1| (-769))) (-15 -2602 ((-424 |#1|) |#1| (-638 (-769)))) (-15 -2602 ((-424 |#1|) |#1| (-638 (-769)) (-769))) (-15 -2602 ((-424 |#1|) |#1| (-769) (-769))) (-15 -3969 ((-3 |#1| "failed") (-923) |#1|)) (-15 -3969 ((-3 |#1| "failed") (-923) |#1| (-769))) (-15 -3969 ((-3 |#1| "failed") (-923) |#1| (-638 (-769)))) (-15 -3969 ((-3 |#1| "failed") (-923) |#1| (-638 (-769)) (-769))) (-15 -3969 ((-3 |#1| "failed") (-923) |#1| (-638 (-769)) (-769) (-121))) (-15 -3560 ((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121))) (-15 -1357 ((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121) (-1100 (-769)) (-769)))) 
-((-3016 (((-572) |#2|) 48) (((-572) |#2| (-769)) 47)) (-3249 (((-572) |#2|) 55)) (-4470 ((|#3| |#2|) 25)) (-4429 ((|#3| |#2| (-923)) 14)) (-3200 ((|#3| |#2|) 15)) (-1560 ((|#3| |#2|) 9)) (-1455 ((|#3| |#2|) 10)) (-2689 ((|#3| |#2| (-923)) 62) ((|#3| |#2|) 30)) (-3170 (((-572) |#2|) 57))) 
-(((-448 |#1| |#2| |#3|) (-10 -7 (-15 -3170 ((-572) |#2|)) (-15 -2689 (|#3| |#2|)) (-15 -2689 (|#3| |#2| (-923))) (-15 -3249 ((-572) |#2|)) (-15 -3016 ((-572) |#2| (-769))) (-15 -3016 ((-572) |#2|)) (-15 -4429 (|#3| |#2| (-923))) (-15 -4470 (|#3| |#2|)) (-15 -1560 (|#3| |#2|)) (-15 -1455 (|#3| |#2|)) (-15 -3200 (|#3| |#2|))) (-1054) (-1234 |#1|) (-13 (-410) (-1044 |#1|) (-368) (-1190) (-281))) (T -448)) 
-((-3200 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4)))) (-1455 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4)))) (-1560 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4)))) (-4470 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4)))) (-4429 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *2 (-13 (-410) (-1044 *5) (-368) (-1190) (-281))) (-5 *1 (-448 *5 *3 *2)) (-4 *3 (-1234 *5)))) (-3016 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-448 *4 *3 *5)) (-4 *3 (-1234 *4)) (-4 *5 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))))) (-3016 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-1054)) (-5 *2 (-572)) (-5 *1 (-448 *5 *3 *6)) (-4 *3 (-1234 *5)) (-4 *6 (-13 (-410) (-1044 *5) (-368) (-1190) (-281))))) (-3249 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-448 *4 *3 *5)) (-4 *3 (-1234 *4)) (-4 *5 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))))) (-2689 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *2 (-13 (-410) (-1044 *5) (-368) (-1190) (-281))) (-5 *1 (-448 *5 *3 *2)) (-4 *3 (-1234 *5)))) (-2689 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4)))) (-3170 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-448 *4 *3 *5)) (-4 *3 (-1234 *4)) (-4 *5 (-13 (-410) (-1044 *4) (-368) (-1190) (-281)))))) 
-(-10 -7 (-15 -3170 ((-572) |#2|)) (-15 -2689 (|#3| |#2|)) (-15 -2689 (|#3| |#2| (-923))) (-15 -3249 ((-572) |#2|)) (-15 -3016 ((-572) |#2| (-769))) (-15 -3016 ((-572) |#2|)) (-15 -4429 (|#3| |#2| (-923))) (-15 -4470 (|#3| |#2|)) (-15 -1560 (|#3| |#2|)) (-15 -1455 (|#3| |#2|)) (-15 -3200 (|#3| |#2|))) 
-((-3966 ((|#2| (-1259 |#1|)) 36)) (-3901 ((|#2| |#2| |#1|) 49)) (-3040 ((|#2| |#2| |#1|) 41)) (-1656 ((|#2| |#2|) 38)) (-3897 (((-121) |#2|) 30)) (-2318 (((-638 |#2|) (-923) (-424 |#2|)) 16)) (-3969 ((|#2| (-923) (-424 |#2|)) 21)) (-2969 (((-733 (-769)) (-424 |#2|)) 25))) 
-(((-449 |#1| |#2|) (-10 -7 (-15 -3897 ((-121) |#2|)) (-15 -3966 (|#2| (-1259 |#1|))) (-15 -1656 (|#2| |#2|)) (-15 -3040 (|#2| |#2| |#1|)) (-15 -3901 (|#2| |#2| |#1|)) (-15 -2969 ((-733 (-769)) (-424 |#2|))) (-15 -3969 (|#2| (-923) (-424 |#2|))) (-15 -2318 ((-638 |#2|) (-923) (-424 |#2|)))) (-1054) (-1234 |#1|)) (T -449)) 
-((-2318 (*1 *2 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-424 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-1054)) (-5 *2 (-638 *6)) (-5 *1 (-449 *5 *6)))) (-3969 (*1 *2 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-424 *2)) (-4 *2 (-1234 *5)) (-5 *1 (-449 *5 *2)) (-4 *5 (-1054)))) (-2969 (*1 *2 *3) (-12 (-5 *3 (-424 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-1054)) (-5 *2 (-733 (-769))) (-5 *1 (-449 *4 *5)))) (-3901 (*1 *2 *2 *3) (-12 (-4 *3 (-1054)) (-5 *1 (-449 *3 *2)) (-4 *2 (-1234 *3)))) (-3040 (*1 *2 *2 *3) (-12 (-4 *3 (-1054)) (-5 *1 (-449 *3 *2)) (-4 *2 (-1234 *3)))) (-1656 (*1 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-449 *3 *2)) (-4 *2 (-1234 *3)))) (-3966 (*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-1054)) (-4 *2 (-1234 *4)) (-5 *1 (-449 *4 *2)))) (-3897 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-121)) (-5 *1 (-449 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -3897 ((-121) |#2|)) (-15 -3966 (|#2| (-1259 |#1|))) (-15 -1656 (|#2| |#2|)) (-15 -3040 (|#2| |#2| |#1|)) (-15 -3901 (|#2| |#2| |#1|)) (-15 -2969 ((-733 (-769)) (-424 |#2|))) (-15 -3969 (|#2| (-923) (-424 |#2|))) (-15 -2318 ((-638 |#2|) (-923) (-424 |#2|)))) 
-((-3081 (((-769)) 41)) (-3485 (((-769)) 23 (|has| |#1| (-410))) (((-769) (-769)) 22 (|has| |#1| (-410)))) (-3420 (((-572) |#1|) 18 (|has| |#1| (-410)))) (-1912 (((-572) |#1|) 20 (|has| |#1| (-410)))) (-3532 (((-769)) 40) (((-769) (-769)) 39)) (-3932 ((|#1| (-769) (-572)) 29)) (-2138 (((-1264)) 43))) 
-(((-450 |#1|) (-10 -7 (-15 -3932 (|#1| (-769) (-572))) (-15 -3532 ((-769) (-769))) (-15 -3532 ((-769))) (-15 -3081 ((-769))) (-15 -2138 ((-1264))) (IF (|has| |#1| (-410)) (PROGN (-15 -1912 ((-572) |#1|)) (-15 -3420 ((-572) |#1|)) (-15 -3485 ((-769) (-769))) (-15 -3485 ((-769)))) |noBranch|)) (-1054)) (T -450)) 
-((-3485 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-410)) (-4 *3 (-1054)))) (-3485 (*1 *2 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-410)) (-4 *3 (-1054)))) (-3420 (*1 *2 *3) (-12 (-5 *2 (-572)) (-5 *1 (-450 *3)) (-4 *3 (-410)) (-4 *3 (-1054)))) (-1912 (*1 *2 *3) (-12 (-5 *2 (-572)) (-5 *1 (-450 *3)) (-4 *3 (-410)) (-4 *3 (-1054)))) (-2138 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-450 *3)) (-4 *3 (-1054)))) (-3081 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-1054)))) (-3532 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-1054)))) (-3532 (*1 *2 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-1054)))) (-3932 (*1 *2 *3 *4) (-12 (-5 *3 (-769)) (-5 *4 (-572)) (-5 *1 (-450 *2)) (-4 *2 (-1054))))) 
-(-10 -7 (-15 -3932 (|#1| (-769) (-572))) (-15 -3532 ((-769) (-769))) (-15 -3532 ((-769))) (-15 -3081 ((-769))) (-15 -2138 ((-1264))) (IF (|has| |#1| (-410)) (PROGN (-15 -1912 ((-572) |#1|)) (-15 -3420 ((-572) |#1|)) (-15 -3485 ((-769) (-769))) (-15 -3485 ((-769)))) |noBranch|)) 
-((-3953 (((-638 (-572)) (-572)) 57)) (-1526 (((-121) (-171 (-572))) 61)) (-4304 (((-424 (-171 (-572))) (-171 (-572))) 56))) 
-(((-451) (-10 -7 (-15 -4304 ((-424 (-171 (-572))) (-171 (-572)))) (-15 -3953 ((-638 (-572)) (-572))) (-15 -1526 ((-121) (-171 (-572)))))) (T -451)) 
-((-1526 (*1 *2 *3) (-12 (-5 *3 (-171 (-572))) (-5 *2 (-121)) (-5 *1 (-451)))) (-3953 (*1 *2 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-451)) (-5 *3 (-572)))) (-4304 (*1 *2 *3) (-12 (-5 *2 (-424 (-171 (-572)))) (-5 *1 (-451)) (-5 *3 (-171 (-572)))))) 
-(-10 -7 (-15 -4304 ((-424 (-171 (-572))) (-171 (-572)))) (-15 -3953 ((-638 (-572)) (-572))) (-15 -1526 ((-121) (-171 (-572))))) 
-((-3878 ((|#4| |#4| (-638 |#4|)) 57)) (-1809 (((-638 |#4|) (-638 |#4|) (-1152) (-1152)) 17) (((-638 |#4|) (-638 |#4|) (-1152)) 16) (((-638 |#4|) (-638 |#4|)) 11))) 
-(((-452 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3878 (|#4| |#4| (-638 |#4|))) (-15 -1809 ((-638 |#4|) (-638 |#4|))) (-15 -1809 ((-638 |#4|) (-638 |#4|) (-1152))) (-15 -1809 ((-638 |#4|) (-638 |#4|) (-1152) (-1152)))) (-303) (-794) (-848) (-956 |#1| |#2| |#3|)) (T -452)) 
-((-1809 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-1152)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-303)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-452 *4 *5 *6 *7)))) (-1809 (*1 *2 *2 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-1152)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-303)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-452 *4 *5 *6 *7)))) (-1809 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-303)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-452 *3 *4 *5 *6)))) (-3878 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *4 *5 *6)) (-4 *4 (-303)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-452 *4 *5 *6 *2))))) 
-(-10 -7 (-15 -3878 (|#4| |#4| (-638 |#4|))) (-15 -1809 ((-638 |#4|) (-638 |#4|))) (-15 -1809 ((-638 |#4|) (-638 |#4|) (-1152))) (-15 -1809 ((-638 |#4|) (-638 |#4|) (-1152) (-1152)))) 
-((-2964 (((-638 (-638 |#4|)) (-638 |#4|) (-121)) 70) (((-638 (-638 |#4|)) (-638 |#4|)) 69) (((-638 (-638 |#4|)) (-638 |#4|) (-638 |#4|) (-121)) 63) (((-638 (-638 |#4|)) (-638 |#4|) (-638 |#4|)) 64)) (-4397 (((-638 (-638 |#4|)) (-638 |#4|) (-121)) 40) (((-638 (-638 |#4|)) (-638 |#4|)) 60))) 
-(((-453 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4397 ((-638 (-638 |#4|)) (-638 |#4|))) (-15 -4397 ((-638 (-638 |#4|)) (-638 |#4|) (-121))) (-15 -2964 ((-638 (-638 |#4|)) (-638 |#4|) (-638 |#4|))) (-15 -2964 ((-638 (-638 |#4|)) (-638 |#4|) (-638 |#4|) (-121))) (-15 -2964 ((-638 (-638 |#4|)) (-638 |#4|))) (-15 -2964 ((-638 (-638 |#4|)) (-638 |#4|) (-121)))) (-13 (-303) (-151)) (-794) (-848) (-956 |#1| |#2| |#3|)) (T -453)) 
-((-2964 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-956 *5 *6 *7)) (-5 *2 (-638 (-638 *8))) (-5 *1 (-453 *5 *6 *7 *8)) (-5 *3 (-638 *8)))) (-2964 (*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-638 (-638 *7))) (-5 *1 (-453 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) (-2964 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-956 *5 *6 *7)) (-5 *2 (-638 (-638 *8))) (-5 *1 (-453 *5 *6 *7 *8)) (-5 *3 (-638 *8)))) (-2964 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-638 (-638 *7))) (-5 *1 (-453 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) (-4397 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-956 *5 *6 *7)) (-5 *2 (-638 (-638 *8))) (-5 *1 (-453 *5 *6 *7 *8)) (-5 *3 (-638 *8)))) (-4397 (*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-638 (-638 *7))) (-5 *1 (-453 *4 *5 *6 *7)) (-5 *3 (-638 *7))))) 
-(-10 -7 (-15 -4397 ((-638 (-638 |#4|)) (-638 |#4|))) (-15 -4397 ((-638 (-638 |#4|)) (-638 |#4|) (-121))) (-15 -2964 ((-638 (-638 |#4|)) (-638 |#4|) (-638 |#4|))) (-15 -2964 ((-638 (-638 |#4|)) (-638 |#4|) (-638 |#4|) (-121))) (-15 -2964 ((-638 (-638 |#4|)) (-638 |#4|))) (-15 -2964 ((-638 (-638 |#4|)) (-638 |#4|) (-121)))) 
-((-2177 (((-769) |#4|) 12)) (-3741 (((-638 (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|))) |#4| (-769) (-638 (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|)))) 31)) (-3611 (((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 37)) (-1425 ((|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 38)) (-3222 ((|#4| |#4| (-638 |#4|)) 39)) (-3974 (((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-638 |#4|)) 68)) (-3433 (((-1264) |#4|) 41)) (-2591 (((-1264) (-638 |#4|)) 50)) (-2910 (((-572) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-572) (-572) (-572)) 47)) (-3747 (((-1264) (-572)) 75)) (-2924 (((-638 |#4|) (-638 |#4|)) 73)) (-2478 (((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|)) |#4| (-769)) 25)) (-4387 (((-572) |#4|) 74)) (-3736 ((|#4| |#4|) 29)) (-2678 (((-638 |#4|) (-638 |#4|) (-572) (-572)) 54)) (-2805 (((-572) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-572) (-572) (-572) (-572)) 85)) (-3845 (((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 16)) (-1986 (((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 57)) (-2668 (((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 56)) (-4084 (((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 35)) (-1945 (((-121) |#2| |#2|) 55)) (-1918 (((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 36)) (-2706 (((-121) |#2| |#2| |#2| |#2|) 58)) (-2693 ((|#4| |#4| (-638 |#4|)) 69))) 
-(((-454 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2693 (|#4| |#4| (-638 |#4|))) (-15 -3222 (|#4| |#4| (-638 |#4|))) (-15 -2678 ((-638 |#4|) (-638 |#4|) (-572) (-572))) (-15 -1986 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -1945 ((-121) |#2| |#2|)) (-15 -2706 ((-121) |#2| |#2| |#2| |#2|)) (-15 -1918 ((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -4084 ((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2668 ((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3974 ((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-638 |#4|))) (-15 -3736 (|#4| |#4|)) (-15 -3741 ((-638 (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|))) |#4| (-769) (-638 (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|))))) (-15 -1425 (|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -3611 ((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2924 ((-638 |#4|) (-638 |#4|))) (-15 -4387 ((-572) |#4|)) (-15 -3433 ((-1264) |#4|)) (-15 -2910 ((-572) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-572) (-572) (-572))) (-15 -2805 ((-572) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-572) (-572) (-572) (-572))) (-15 -2591 ((-1264) (-638 |#4|))) (-15 -3747 ((-1264) (-572))) (-15 -3845 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2478 ((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|)) |#4| (-769))) (-15 -2177 ((-769) |#4|))) (-457) (-794) (-848) (-956 |#1| |#2| |#3|)) (T -454)) 
-((-2177 (*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-769)) (-5 *1 (-454 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6)))) (-2478 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-2 (|:| |totdeg| (-769)) (|:| -1805 *4))) (-5 *5 (-769)) (-4 *4 (-956 *6 *7 *8)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-5 *2 (-2 (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (-5 *1 (-454 *6 *7 *8 *4)))) (-3845 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-769)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-794)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-454 *4 *5 *6 *7)))) (-3747 (*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1264)) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *7 (-956 *4 *5 *6)))) (-2591 (*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1264)) (-5 *1 (-454 *4 *5 *6 *7)))) (-2805 (*1 *2 *3 *4 *4 *2 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-769)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-794)) (-4 *4 (-956 *5 *6 *7)) (-4 *5 (-457)) (-4 *7 (-848)) (-5 *1 (-454 *5 *6 *7 *4)))) (-2910 (*1 *2 *3 *4 *4 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-769)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-794)) (-4 *4 (-956 *5 *6 *7)) (-4 *5 (-457)) (-4 *7 (-848)) (-5 *1 (-454 *5 *6 *7 *4)))) (-3433 (*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1264)) (-5 *1 (-454 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6)))) (-4387 (*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-572)) (-5 *1 (-454 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6)))) (-2924 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-454 *3 *4 *5 *6)))) (-3611 (*1 *2 *2 *2) (-12 (-5 *2 (-638 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-769)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-794)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-457)) (-4 *5 (-848)) (-5 *1 (-454 *3 *4 *5 *6)))) (-1425 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-769)) (|:| |poli| *2) (|:| |polj| *2))) (-4 *5 (-794)) (-4 *2 (-956 *4 *5 *6)) (-5 *1 (-454 *4 *5 *6 *2)) (-4 *4 (-457)) (-4 *6 (-848)))) (-3741 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-638 (-2 (|:| |totdeg| (-769)) (|:| -1805 *3)))) (-5 *4 (-769)) (-4 *3 (-956 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-454 *5 *6 *7 *3)))) (-3736 (*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-454 *3 *4 *5 *2)) (-4 *2 (-956 *3 *4 *5)))) (-3974 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-956 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |poly| *3) (|:| |mult| *5))) (-5 *1 (-454 *5 *6 *7 *3)))) (-2668 (*1 *2 *3 *2) (-12 (-5 *2 (-638 (-2 (|:| |lcmfij| *3) (|:| |totdeg| (-769)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *3 (-794)) (-4 *6 (-956 *4 *3 *5)) (-4 *4 (-457)) (-4 *5 (-848)) (-5 *1 (-454 *4 *3 *5 *6)))) (-4084 (*1 *2 *2) (-12 (-5 *2 (-638 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-769)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-794)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-457)) (-4 *5 (-848)) (-5 *1 (-454 *3 *4 *5 *6)))) (-1918 (*1 *2 *3 *2) (-12 (-5 *2 (-638 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-769)) (|:| |poli| *3) (|:| |polj| *3)))) (-4 *5 (-794)) (-4 *3 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *6 (-848)) (-5 *1 (-454 *4 *5 *6 *3)))) (-2706 (*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-457)) (-4 *3 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-454 *4 *3 *5 *6)) (-4 *6 (-956 *4 *3 *5)))) (-1945 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *3 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-454 *4 *3 *5 *6)) (-4 *6 (-956 *4 *3 *5)))) (-1986 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-769)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-794)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-454 *4 *5 *6 *7)))) (-2678 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-572)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-454 *4 *5 *6 *7)))) (-3222 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-454 *4 *5 *6 *2)))) (-2693 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-454 *4 *5 *6 *2))))) 
-(-10 -7 (-15 -2693 (|#4| |#4| (-638 |#4|))) (-15 -3222 (|#4| |#4| (-638 |#4|))) (-15 -2678 ((-638 |#4|) (-638 |#4|) (-572) (-572))) (-15 -1986 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -1945 ((-121) |#2| |#2|)) (-15 -2706 ((-121) |#2| |#2| |#2| |#2|)) (-15 -1918 ((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -4084 ((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2668 ((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3974 ((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-638 |#4|))) (-15 -3736 (|#4| |#4|)) (-15 -3741 ((-638 (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|))) |#4| (-769) (-638 (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|))))) (-15 -1425 (|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -3611 ((-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-638 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2924 ((-638 |#4|) (-638 |#4|))) (-15 -4387 ((-572) |#4|)) (-15 -3433 ((-1264) |#4|)) (-15 -2910 ((-572) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-572) (-572) (-572))) (-15 -2805 ((-572) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-572) (-572) (-572) (-572))) (-15 -2591 ((-1264) (-638 |#4|))) (-15 -3747 ((-1264) (-572))) (-15 -3845 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2478 ((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-769)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-769)) (|:| -1805 |#4|)) |#4| (-769))) (-15 -2177 ((-769) |#4|))) 
-((-2310 ((|#4| |#4| (-638 |#4|)) 22 (|has| |#1| (-368)))) (-3604 (((-638 |#4|) (-638 |#4|) (-1152) (-1152)) 41) (((-638 |#4|) (-638 |#4|) (-1152)) 40) (((-638 |#4|) (-638 |#4|)) 35))) 
-(((-455 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3604 ((-638 |#4|) (-638 |#4|))) (-15 -3604 ((-638 |#4|) (-638 |#4|) (-1152))) (-15 -3604 ((-638 |#4|) (-638 |#4|) (-1152) (-1152))) (IF (|has| |#1| (-368)) (-15 -2310 (|#4| |#4| (-638 |#4|))) |noBranch|)) (-457) (-794) (-848) (-956 |#1| |#2| |#3|)) (T -455)) 
-((-2310 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *4 *5 *6)) (-4 *4 (-368)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-455 *4 *5 *6 *2)))) (-3604 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-1152)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-455 *4 *5 *6 *7)))) (-3604 (*1 *2 *2 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-1152)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-455 *4 *5 *6 *7)))) (-3604 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-455 *3 *4 *5 *6))))) 
-(-10 -7 (-15 -3604 ((-638 |#4|) (-638 |#4|))) (-15 -3604 ((-638 |#4|) (-638 |#4|) (-1152))) (-15 -3604 ((-638 |#4|) (-638 |#4|) (-1152) (-1152))) (IF (|has| |#1| (-368)) (-15 -2310 (|#4| |#4| (-638 |#4|))) |noBranch|)) 
-((-1629 (($ $ $) 14) (($ (-638 $)) 21)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 41)) (-3069 (($ $ $) NIL) (($ (-638 $)) 22))) 
-(((-456 |#1|) (-10 -8 (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|))) (-15 -1629 (|#1| (-638 |#1|))) (-15 -1629 (|#1| |#1| |#1|)) (-15 -3069 (|#1| (-638 |#1|))) (-15 -3069 (|#1| |#1| |#1|))) (-457)) (T -456)) 
-NIL 
-(-10 -8 (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|))) (-15 -1629 (|#1| (-638 |#1|))) (-15 -1629 (|#1| |#1| |#1|)) (-15 -3069 (|#1| (-638 |#1|))) (-15 -3069 (|#1| |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-1803 (((-3 $ "failed") $ $) 41)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-457) (-1290)) (T -457)) 
-((-3069 (*1 *1 *1 *1) (-4 *1 (-457))) (-3069 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-457)))) (-1629 (*1 *1 *1 *1) (-4 *1 (-457))) (-1629 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-457)))) (-3905 (*1 *2 *2 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-457))))) 
-(-13 (-562) (-10 -8 (-15 -3069 ($ $ $)) (-15 -3069 ($ (-638 $))) (-15 -1629 ($ $ $)) (-15 -1629 ($ (-638 $))) (-15 -3905 ((-1166 $) (-1166 $) (-1166 $))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3029 (((-3 $ "failed")) NIL (|has| (-413 (-959 |#1|)) (-562)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-1354 (((-1259 (-685 (-413 (-959 |#1|)))) (-1259 $)) NIL) (((-1259 (-685 (-413 (-959 |#1|))))) NIL)) (-2167 (((-1259 $)) NIL)) (-2211 (($) NIL T CONST)) (-4511 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL)) (-2095 (((-3 $ "failed")) NIL (|has| (-413 (-959 |#1|)) (-562)))) (-2882 (((-685 (-413 (-959 |#1|))) (-1259 $)) NIL) (((-685 (-413 (-959 |#1|)))) NIL)) (-3487 (((-413 (-959 |#1|)) $) NIL)) (-3700 (((-685 (-413 (-959 |#1|))) $ (-1259 $)) NIL) (((-685 (-413 (-959 |#1|))) $) NIL)) (-2848 (((-3 $ "failed") $) NIL (|has| (-413 (-959 |#1|)) (-562)))) (-4535 (((-1166 (-959 (-413 (-959 |#1|))))) NIL (|has| (-413 (-959 |#1|)) (-368))) (((-1166 (-413 (-959 |#1|)))) 79 (|has| |#1| (-562)))) (-3014 (($ $ (-923)) NIL)) (-3588 (((-413 (-959 |#1|)) $) NIL)) (-2135 (((-1166 (-413 (-959 |#1|))) $) 77 (|has| (-413 (-959 |#1|)) (-562)))) (-4146 (((-413 (-959 |#1|)) (-1259 $)) NIL) (((-413 (-959 |#1|))) NIL)) (-1593 (((-1166 (-413 (-959 |#1|))) $) NIL)) (-2048 (((-121)) NIL)) (-4337 (($ (-1259 (-413 (-959 |#1|))) (-1259 $)) 97) (($ (-1259 (-413 (-959 |#1|)))) NIL)) (-1799 (((-3 $ "failed") $) NIL (|has| (-413 (-959 |#1|)) (-562)))) (-2667 (((-923)) NIL)) (-4160 (((-121)) NIL)) (-2027 (($ $ (-923)) NIL)) (-1814 (((-121)) NIL)) (-2209 (((-121)) NIL)) (-1648 (((-121)) NIL)) (-1903 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL)) (-2036 (((-3 $ "failed")) NIL (|has| (-413 (-959 |#1|)) (-562)))) (-1663 (((-685 (-413 (-959 |#1|))) (-1259 $)) NIL) (((-685 (-413 (-959 |#1|)))) NIL)) (-3550 (((-413 (-959 |#1|)) $) NIL)) (-3343 (((-685 (-413 (-959 |#1|))) $ (-1259 $)) NIL) (((-685 (-413 (-959 |#1|))) $) NIL)) (-2046 (((-3 $ "failed") $) NIL (|has| (-413 (-959 |#1|)) (-562)))) (-2339 (((-1166 (-959 (-413 (-959 |#1|))))) NIL (|has| (-413 (-959 |#1|)) (-368))) (((-1166 (-413 (-959 |#1|)))) 78 (|has| |#1| (-562)))) (-3276 (($ $ (-923)) NIL)) (-2340 (((-413 (-959 |#1|)) $) NIL)) (-3665 (((-1166 (-413 (-959 |#1|))) $) 72 (|has| (-413 (-959 |#1|)) (-562)))) (-2110 (((-413 (-959 |#1|)) (-1259 $)) NIL) (((-413 (-959 |#1|))) NIL)) (-1989 (((-1166 (-413 (-959 |#1|))) $) NIL)) (-3602 (((-121)) NIL)) (-1658 (((-1152) $) NIL)) (-4219 (((-121)) NIL)) (-2395 (((-121)) NIL)) (-3046 (((-121)) NIL)) (-2607 (((-1116) $) NIL)) (-4438 (((-413 (-959 |#1|)) $ $) 66 (|has| |#1| (-562)))) (-3830 (((-413 (-959 |#1|)) $) 65 (|has| |#1| (-562)))) (-2416 (((-413 (-959 |#1|)) $) 89 (|has| |#1| (-562)))) (-3430 (((-1166 (-413 (-959 |#1|))) $) 83 (|has| |#1| (-562)))) (-1432 (((-413 (-959 |#1|))) 67 (|has| |#1| (-562)))) (-1496 (((-413 (-959 |#1|)) $ $) 54 (|has| |#1| (-562)))) (-4243 (((-413 (-959 |#1|)) $) 53 (|has| |#1| (-562)))) (-3637 (((-413 (-959 |#1|)) $) 88 (|has| |#1| (-562)))) (-3534 (((-1166 (-413 (-959 |#1|))) $) 82 (|has| |#1| (-562)))) (-3744 (((-413 (-959 |#1|))) 64 (|has| |#1| (-562)))) (-2833 (($) 95) (($ (-1170)) 101) (($ (-1259 (-1170))) 100) (($ (-1259 $)) 90) (($ (-1170) (-1259 $)) 99) (($ (-1259 (-1170)) (-1259 $)) 98)) (-4128 (((-121)) NIL)) (-3277 (((-413 (-959 |#1|)) $ (-572)) NIL)) (-3160 (((-1259 (-413 (-959 |#1|))) $ (-1259 $)) 92) (((-685 (-413 (-959 |#1|))) (-1259 $) (-1259 $)) NIL) (((-1259 (-413 (-959 |#1|))) $) 37) (((-685 (-413 (-959 |#1|))) (-1259 $)) NIL)) (-4081 (((-1259 (-413 (-959 |#1|))) $) NIL) (($ (-1259 (-413 (-959 |#1|)))) 34)) (-3188 (((-638 (-959 (-413 (-959 |#1|)))) (-1259 $)) NIL) (((-638 (-959 (-413 (-959 |#1|))))) NIL) (((-638 (-959 |#1|)) (-1259 $)) 93 (|has| |#1| (-562))) (((-638 (-959 |#1|))) 94 (|has| |#1| (-562)))) (-4056 (($ $ $) NIL)) (-2073 (((-121)) NIL)) (-3972 (((-856) $) NIL) (($ (-1259 (-413 (-959 |#1|)))) NIL)) (-2237 (((-1259 $)) 56)) (-4414 (((-638 (-1259 (-413 (-959 |#1|))))) NIL (|has| (-413 (-959 |#1|)) (-562)))) (-4250 (($ $ $ $) NIL)) (-2928 (((-121)) NIL)) (-1591 (($ (-685 (-413 (-959 |#1|))) $) NIL)) (-1397 (($ $ $) NIL)) (-2773 (((-121)) NIL)) (-2756 (((-121)) NIL)) (-1447 (((-121)) NIL)) (-2378 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) 91)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 52) (($ $ (-413 (-959 |#1|))) NIL) (($ (-413 (-959 |#1|)) $) NIL) (($ (-1135 |#2| (-413 (-959 |#1|))) $) NIL))) 
-(((-458 |#1| |#2| |#3| |#4|) (-13 (-423 (-413 (-959 |#1|))) (-641 (-1135 |#2| (-413 (-959 |#1|)))) (-10 -8 (-15 -3972 ($ (-1259 (-413 (-959 |#1|))))) (-15 -1903 ((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed"))) (-15 -4511 ((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed"))) (-15 -2833 ($)) (-15 -2833 ($ (-1170))) (-15 -2833 ($ (-1259 (-1170)))) (-15 -2833 ($ (-1259 $))) (-15 -2833 ($ (-1170) (-1259 $))) (-15 -2833 ($ (-1259 (-1170)) (-1259 $))) (IF (|has| |#1| (-562)) (PROGN (-15 -2339 ((-1166 (-413 (-959 |#1|))))) (-15 -3534 ((-1166 (-413 (-959 |#1|))) $)) (-15 -4243 ((-413 (-959 |#1|)) $)) (-15 -3637 ((-413 (-959 |#1|)) $)) (-15 -4535 ((-1166 (-413 (-959 |#1|))))) (-15 -3430 ((-1166 (-413 (-959 |#1|))) $)) (-15 -3830 ((-413 (-959 |#1|)) $)) (-15 -2416 ((-413 (-959 |#1|)) $)) (-15 -1496 ((-413 (-959 |#1|)) $ $)) (-15 -3744 ((-413 (-959 |#1|)))) (-15 -4438 ((-413 (-959 |#1|)) $ $)) (-15 -1432 ((-413 (-959 |#1|)))) (-15 -3188 ((-638 (-959 |#1|)) (-1259 $))) (-15 -3188 ((-638 (-959 |#1|))))) |noBranch|))) (-174) (-923) (-638 (-1170)) (-1259 (-685 |#1|))) (T -458)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1259 (-413 (-959 *3)))) (-4 *3 (-174)) (-14 *6 (-1259 (-685 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))))) (-1903 (*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-458 *3 *4 *5 *6)) (|:| -2237 (-638 (-458 *3 *4 *5 *6))))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-4511 (*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-458 *3 *4 *5 *6)) (|:| -2237 (-638 (-458 *3 *4 *5 *6))))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-2833 (*1 *1) (-12 (-5 *1 (-458 *2 *3 *4 *5)) (-4 *2 (-174)) (-14 *3 (-923)) (-14 *4 (-638 (-1170))) (-14 *5 (-1259 (-685 *2))))) (-2833 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 *2)) (-14 *6 (-1259 (-685 *3))))) (-2833 (*1 *1 *2) (-12 (-5 *2 (-1259 (-1170))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-2833 (*1 *1 *2) (-12 (-5 *2 (-1259 (-458 *3 *4 *5 *6))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-2833 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-458 *4 *5 *6 *7))) (-5 *1 (-458 *4 *5 *6 *7)) (-4 *4 (-174)) (-14 *5 (-923)) (-14 *6 (-638 *2)) (-14 *7 (-1259 (-685 *4))))) (-2833 (*1 *1 *2 *3) (-12 (-5 *2 (-1259 (-1170))) (-5 *3 (-1259 (-458 *4 *5 *6 *7))) (-5 *1 (-458 *4 *5 *6 *7)) (-4 *4 (-174)) (-14 *5 (-923)) (-14 *6 (-638 (-1170))) (-14 *7 (-1259 (-685 *4))))) (-2339 (*1 *2) (-12 (-5 *2 (-1166 (-413 (-959 *3)))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-3534 (*1 *2 *1) (-12 (-5 *2 (-1166 (-413 (-959 *3)))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-4243 (*1 *2 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-3637 (*1 *2 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-4535 (*1 *2) (-12 (-5 *2 (-1166 (-413 (-959 *3)))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-3430 (*1 *2 *1) (-12 (-5 *2 (-1166 (-413 (-959 *3)))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-3830 (*1 *2 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-2416 (*1 *2 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-1496 (*1 *2 *1 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-3744 (*1 *2) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-4438 (*1 *2 *1 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-1432 (*1 *2) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) (-3188 (*1 *2 *3) (-12 (-5 *3 (-1259 (-458 *4 *5 *6 *7))) (-5 *2 (-638 (-959 *4))) (-5 *1 (-458 *4 *5 *6 *7)) (-4 *4 (-562)) (-4 *4 (-174)) (-14 *5 (-923)) (-14 *6 (-638 (-1170))) (-14 *7 (-1259 (-685 *4))))) (-3188 (*1 *2) (-12 (-5 *2 (-638 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(-13 (-423 (-413 (-959 |#1|))) (-641 (-1135 |#2| (-413 (-959 |#1|)))) (-10 -8 (-15 -3972 ($ (-1259 (-413 (-959 |#1|))))) (-15 -1903 ((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed"))) (-15 -4511 ((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed"))) (-15 -2833 ($)) (-15 -2833 ($ (-1170))) (-15 -2833 ($ (-1259 (-1170)))) (-15 -2833 ($ (-1259 $))) (-15 -2833 ($ (-1170) (-1259 $))) (-15 -2833 ($ (-1259 (-1170)) (-1259 $))) (IF (|has| |#1| (-562)) (PROGN (-15 -2339 ((-1166 (-413 (-959 |#1|))))) (-15 -3534 ((-1166 (-413 (-959 |#1|))) $)) (-15 -4243 ((-413 (-959 |#1|)) $)) (-15 -3637 ((-413 (-959 |#1|)) $)) (-15 -4535 ((-1166 (-413 (-959 |#1|))))) (-15 -3430 ((-1166 (-413 (-959 |#1|))) $)) (-15 -3830 ((-413 (-959 |#1|)) $)) (-15 -2416 ((-413 (-959 |#1|)) $)) (-15 -1496 ((-413 (-959 |#1|)) $ $)) (-15 -3744 ((-413 (-959 |#1|)))) (-15 -4438 ((-413 (-959 |#1|)) $ $)) (-15 -1432 ((-413 (-959 |#1|)))) (-15 -3188 ((-638 (-959 |#1|)) (-1259 $))) (-15 -3188 ((-638 (-959 |#1|))))) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 13)) (-3456 (((-638 (-858 |#1|)) $) 73)) (-4297 (((-1166 $) $ (-858 |#1|)) 46) (((-1166 |#2|) $) 115)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#2| (-562)))) (-3946 (($ $) NIL (|has| |#2| (-562)))) (-3686 (((-121) $) NIL (|has| |#2| (-562)))) (-2357 (((-769) $) 21) (((-769) $ (-638 (-858 |#1|))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2844 (($ $) NIL (|has| |#2| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#2| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) 44) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-858 |#1|) "failed") $) NIL)) (-1318 ((|#2| $) 42) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-858 |#1|) $) NIL)) (-3190 (($ $ $ (-858 |#1|)) NIL (|has| |#2| (-174)))) (-3814 (($ $ (-638 (-572))) 78)) (-4383 (($ $) 67)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#2| (-457))) (($ $ (-858 |#1|)) NIL (|has| |#2| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#2| (-910)))) (-3977 (($ $ |#2| |#3| $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-858 |#1|) (-887 (-385))) (|has| |#2| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-858 |#1|) (-887 (-572))) (|has| |#2| (-887 (-572)))))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) 58)) (-4335 (($ (-1166 |#2|) (-858 |#1|)) 120) (($ (-1166 $) (-858 |#1|)) 52)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) 59)) (-4328 (($ |#2| |#3|) 28) (($ $ (-858 |#1|) (-769)) 30) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-858 |#1|)) NIL)) (-1784 ((|#3| $) NIL) (((-769) $ (-858 |#1|)) 50) (((-638 (-769)) $ (-638 (-858 |#1|))) 57)) (-1771 (($ $ $) NIL (|has| |#2| (-848)))) (-4238 (($ $ $) NIL (|has| |#2| (-848)))) (-3918 (($ (-1 |#3| |#3|) $) NIL)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-1470 (((-3 (-858 |#1|) "failed") $) 39)) (-4368 (($ $) NIL)) (-4373 ((|#2| $) 41)) (-1629 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-1658 (((-1152) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-858 |#1|)) (|:| -3751 (-769))) "failed") $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 40)) (-4362 ((|#2| $) 113)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#2| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) 125 (|has| |#2| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#2| (-910)))) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-858 |#1|) |#2|) 85) (($ $ (-638 (-858 |#1|)) (-638 |#2|)) 88) (($ $ (-858 |#1|) $) 83) (($ $ (-638 (-858 |#1|)) (-638 $)) 104)) (-2119 (($ $ (-858 |#1|)) NIL (|has| |#2| (-174)))) (-3139 (($ $ (-858 |#1|)) 53) (($ $ (-638 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-4316 ((|#3| $) 66) (((-769) $ (-858 |#1|)) 37) (((-638 (-769)) $ (-638 (-858 |#1|))) 56)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-858 |#1|) (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-858 |#1|) (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-858 |#1|) (-613 (-545))) (|has| |#2| (-613 (-545)))))) (-3694 ((|#2| $) 122 (|has| |#2| (-457))) (($ $ (-858 |#1|)) NIL (|has| |#2| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#2| (-910))))) (-3972 (((-856) $) 141) (($ (-572)) NIL) (($ |#2|) 84) (($ (-858 |#1|)) 31) (($ (-413 (-572))) NIL (-1841 (|has| |#2| (-43 (-413 (-572)))) (|has| |#2| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#2| (-562)))) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ |#3|) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#2| (-910))) (|has| |#2| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#2| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#2| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 16 T CONST)) (-3255 (($) 25 T CONST)) (-1557 (($ $ (-858 |#1|)) NIL) (($ $ (-638 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-1349 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1379 (($ $ |#2|) 64 (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 109)) (** (($ $ (-923)) NIL) (($ $ (-769)) 107)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 29) (($ $ (-413 (-572))) NIL (|has| |#2| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#2| (-43 (-413 (-572))))) (($ |#2| $) 63) (($ $ |#2|) NIL))) 
-(((-459 |#1| |#2| |#3|) (-13 (-956 |#2| |#3| (-858 |#1|)) (-10 -8 (-15 -3814 ($ $ (-638 (-572)))))) (-638 (-1170)) (-1054) (-232 (-4032 |#1|) (-769))) (T -459)) 
-((-3814 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-14 *3 (-638 (-1170))) (-5 *1 (-459 *3 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-232 (-4032 *3) (-769)))))) 
-(-13 (-956 |#2| |#3| (-858 |#1|)) (-10 -8 (-15 -3814 ($ $ (-638 (-572)))))) 
-((-2613 (((-1264) (-312 (-385)) (-1090 (-385)) (-1090 (-385)) (-1152)) 49) (((-1264) (-312 (-385)) (-1090 (-385)) (-1090 (-385)) (-1152) (-638 (-258))) 48) (((-1264) (-312 (-385)) (-1090 (-385)) (-1152)) 42) (((-1264) (-312 (-385)) (-1090 (-385)) (-1152) (-638 (-258))) 39))) 
-(((-460) (-10 -7 (-15 -2613 ((-1264) (-312 (-385)) (-1090 (-385)) (-1152) (-638 (-258)))) (-15 -2613 ((-1264) (-312 (-385)) (-1090 (-385)) (-1152))) (-15 -2613 ((-1264) (-312 (-385)) (-1090 (-385)) (-1090 (-385)) (-1152) (-638 (-258)))) (-15 -2613 ((-1264) (-312 (-385)) (-1090 (-385)) (-1090 (-385)) (-1152))))) (T -460)) 
-((-2613 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-385))) (-5 *5 (-1152)) (-5 *2 (-1264)) (-5 *1 (-460)))) (-2613 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-385))) (-5 *5 (-1152)) (-5 *6 (-638 (-258))) (-5 *2 (-1264)) (-5 *1 (-460)))) (-2613 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-385))) (-5 *5 (-1152)) (-5 *2 (-1264)) (-5 *1 (-460)))) (-2613 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-385))) (-5 *5 (-1152)) (-5 *6 (-638 (-258))) (-5 *2 (-1264)) (-5 *1 (-460))))) 
-(-10 -7 (-15 -2613 ((-1264) (-312 (-385)) (-1090 (-385)) (-1152) (-638 (-258)))) (-15 -2613 ((-1264) (-312 (-385)) (-1090 (-385)) (-1152))) (-15 -2613 ((-1264) (-312 (-385)) (-1090 (-385)) (-1090 (-385)) (-1152) (-638 (-258)))) (-15 -2613 ((-1264) (-312 (-385)) (-1090 (-385)) (-1090 (-385)) (-1152)))) 
-((-3077 (((-121) |#1| (-638 |#2|)) 65)) (-4529 (((-3 (-1259 (-638 |#2|)) "failed") (-769) |#1| (-638 |#2|)) 74)) (-1836 (((-3 (-638 |#2|) "failed") |#2| |#1| (-1259 (-638 |#2|))) 76)) (-4007 ((|#2| |#2| |#1|) 28)) (-1536 (((-769) |#2| (-638 |#2|)) 20))) 
-(((-461 |#1| |#2|) (-10 -7 (-15 -4007 (|#2| |#2| |#1|)) (-15 -1536 ((-769) |#2| (-638 |#2|))) (-15 -4529 ((-3 (-1259 (-638 |#2|)) "failed") (-769) |#1| (-638 |#2|))) (-15 -1836 ((-3 (-638 |#2|) "failed") |#2| |#1| (-1259 (-638 |#2|)))) (-15 -3077 ((-121) |#1| (-638 |#2|)))) (-303) (-1234 |#1|)) (T -461)) 
-((-3077 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *5)) (-4 *5 (-1234 *3)) (-4 *3 (-303)) (-5 *2 (-121)) (-5 *1 (-461 *3 *5)))) (-1836 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1259 (-638 *3))) (-4 *4 (-303)) (-5 *2 (-638 *3)) (-5 *1 (-461 *4 *3)) (-4 *3 (-1234 *4)))) (-4529 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-769)) (-4 *4 (-303)) (-4 *6 (-1234 *4)) (-5 *2 (-1259 (-638 *6))) (-5 *1 (-461 *4 *6)) (-5 *5 (-638 *6)))) (-1536 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-303)) (-5 *2 (-769)) (-5 *1 (-461 *5 *3)))) (-4007 (*1 *2 *2 *3) (-12 (-4 *3 (-303)) (-5 *1 (-461 *3 *2)) (-4 *2 (-1234 *3))))) 
-(-10 -7 (-15 -4007 (|#2| |#2| |#1|)) (-15 -1536 ((-769) |#2| (-638 |#2|))) (-15 -4529 ((-3 (-1259 (-638 |#2|)) "failed") (-769) |#1| (-638 |#2|))) (-15 -1836 ((-3 (-638 |#2|) "failed") |#2| |#1| (-1259 (-638 |#2|)))) (-15 -3077 ((-121) |#1| (-638 |#2|)))) 
-((-4304 (((-424 |#5|) |#5|) 24))) 
-(((-462 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4304 ((-424 |#5|) |#5|))) (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170))))) (-794) (-562) (-562) (-956 |#4| |#2| |#1|)) (T -462)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-4 *5 (-794)) (-4 *7 (-562)) (-5 *2 (-424 *3)) (-5 *1 (-462 *4 *5 *6 *7 *3)) (-4 *6 (-562)) (-4 *3 (-956 *7 *5 *4))))) 
-(-10 -7 (-15 -4304 ((-424 |#5|) |#5|))) 
-((-1473 ((|#3|) 36)) (-3905 (((-1166 |#4|) (-1166 |#4|) (-1166 |#4|)) 32))) 
-(((-463 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3905 ((-1166 |#4|) (-1166 |#4|) (-1166 |#4|))) (-15 -1473 (|#3|))) (-794) (-848) (-910) (-956 |#3| |#1| |#2|)) (T -463)) 
-((-1473 (*1 *2) (-12 (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-910)) (-5 *1 (-463 *3 *4 *2 *5)) (-4 *5 (-956 *2 *3 *4)))) (-3905 (*1 *2 *2 *2) (-12 (-5 *2 (-1166 *6)) (-4 *6 (-956 *5 *3 *4)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-910)) (-5 *1 (-463 *3 *4 *5 *6))))) 
-(-10 -7 (-15 -3905 ((-1166 |#4|) (-1166 |#4|) (-1166 |#4|))) (-15 -1473 (|#3|))) 
-((-4304 (((-424 (-1166 |#1|)) (-1166 |#1|)) 41))) 
-(((-464 |#1|) (-10 -7 (-15 -4304 ((-424 (-1166 |#1|)) (-1166 |#1|)))) (-303)) (T -464)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-303)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-464 *4)) (-5 *3 (-1166 *4))))) 
-(-10 -7 (-15 -4304 ((-424 (-1166 |#1|)) (-1166 |#1|)))) 
-((-1881 (((-57) |#2| (-1170) (-290 |#2|) (-1225 (-769))) 42) (((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-769))) 41) (((-57) |#2| (-1170) (-290 |#2|)) 35) (((-57) (-1 |#2| (-572)) (-290 |#2|)) 27)) (-4521 (((-57) |#2| (-1170) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572))) 80) (((-57) (-1 |#2| (-413 (-572))) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572))) 79) (((-57) |#2| (-1170) (-290 |#2|) (-1225 (-572))) 78) (((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-572))) 77) (((-57) |#2| (-1170) (-290 |#2|)) 72) (((-57) (-1 |#2| (-572)) (-290 |#2|)) 71)) (-1889 (((-57) |#2| (-1170) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572))) 66) (((-57) (-1 |#2| (-413 (-572))) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572))) 64)) (-1885 (((-57) |#2| (-1170) (-290 |#2|) (-1225 (-572))) 48) (((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-572))) 47))) 
-(((-465 |#1| |#2|) (-10 -7 (-15 -1881 ((-57) (-1 |#2| (-572)) (-290 |#2|))) (-15 -1881 ((-57) |#2| (-1170) (-290 |#2|))) (-15 -1881 ((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-769)))) (-15 -1881 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-769)))) (-15 -1885 ((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-572)))) (-15 -1885 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-572)))) (-15 -1889 ((-57) (-1 |#2| (-413 (-572))) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572)))) (-15 -1889 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572)))) (-15 -4521 ((-57) (-1 |#2| (-572)) (-290 |#2|))) (-15 -4521 ((-57) |#2| (-1170) (-290 |#2|))) (-15 -4521 ((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-572)))) (-15 -4521 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-572)))) (-15 -4521 ((-57) (-1 |#2| (-413 (-572))) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572)))) (-15 -4521 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572))))) (-13 (-562) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|))) (T -465)) 
-((-4521 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-413 (-572)))) (-5 *7 (-413 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *8))) (-4 *8 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *8 *3)))) (-4521 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-413 (-572)))) (-5 *4 (-290 *8)) (-5 *5 (-1225 (-413 (-572)))) (-5 *6 (-413 (-572))) (-4 *8 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *8)))) (-4521 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *3)))) (-4521 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-572))) (-5 *4 (-290 *7)) (-5 *5 (-1225 (-572))) (-4 *7 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *7)))) (-4521 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *3)))) (-4521 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-572))) (-5 *4 (-290 *6)) (-4 *6 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *5 *6)))) (-1889 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-413 (-572)))) (-5 *7 (-413 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *8))) (-4 *8 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *8 *3)))) (-1889 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-413 (-572)))) (-5 *4 (-290 *8)) (-5 *5 (-1225 (-413 (-572)))) (-5 *6 (-413 (-572))) (-4 *8 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *8)))) (-1885 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *3)))) (-1885 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-572))) (-5 *4 (-290 *7)) (-5 *5 (-1225 (-572))) (-4 *7 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *7)))) (-1881 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-769))) (-4 *3 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *3)))) (-1881 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-572))) (-5 *4 (-290 *7)) (-5 *5 (-1225 (-769))) (-4 *7 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *7)))) (-1881 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *3)))) (-1881 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-572))) (-5 *4 (-290 *6)) (-4 *6 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *5 *6))))) 
-(-10 -7 (-15 -1881 ((-57) (-1 |#2| (-572)) (-290 |#2|))) (-15 -1881 ((-57) |#2| (-1170) (-290 |#2|))) (-15 -1881 ((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-769)))) (-15 -1881 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-769)))) (-15 -1885 ((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-572)))) (-15 -1885 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-572)))) (-15 -1889 ((-57) (-1 |#2| (-413 (-572))) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572)))) (-15 -1889 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572)))) (-15 -4521 ((-57) (-1 |#2| (-572)) (-290 |#2|))) (-15 -4521 ((-57) |#2| (-1170) (-290 |#2|))) (-15 -4521 ((-57) (-1 |#2| (-572)) (-290 |#2|) (-1225 (-572)))) (-15 -4521 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-572)))) (-15 -4521 ((-57) (-1 |#2| (-413 (-572))) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572)))) (-15 -4521 ((-57) |#2| (-1170) (-290 |#2|) (-1225 (-413 (-572))) (-413 (-572))))) 
-((-4007 ((|#2| |#2| |#1|) 15)) (-3513 (((-638 |#2|) |#2| (-638 |#2|) |#1| (-923)) 65)) (-1909 (((-2 (|:| |plist| (-638 |#2|)) (|:| |modulo| |#1|)) |#2| (-638 |#2|) |#1| (-923)) 58))) 
-(((-466 |#1| |#2|) (-10 -7 (-15 -1909 ((-2 (|:| |plist| (-638 |#2|)) (|:| |modulo| |#1|)) |#2| (-638 |#2|) |#1| (-923))) (-15 -3513 ((-638 |#2|) |#2| (-638 |#2|) |#1| (-923))) (-15 -4007 (|#2| |#2| |#1|))) (-303) (-1234 |#1|)) (T -466)) 
-((-4007 (*1 *2 *2 *3) (-12 (-4 *3 (-303)) (-5 *1 (-466 *3 *2)) (-4 *2 (-1234 *3)))) (-3513 (*1 *2 *3 *2 *4 *5) (-12 (-5 *2 (-638 *3)) (-5 *5 (-923)) (-4 *3 (-1234 *4)) (-4 *4 (-303)) (-5 *1 (-466 *4 *3)))) (-1909 (*1 *2 *3 *4 *5 *6) (-12 (-5 *6 (-923)) (-4 *5 (-303)) (-4 *3 (-1234 *5)) (-5 *2 (-2 (|:| |plist| (-638 *3)) (|:| |modulo| *5))) (-5 *1 (-466 *5 *3)) (-5 *4 (-638 *3))))) 
-(-10 -7 (-15 -1909 ((-2 (|:| |plist| (-638 |#2|)) (|:| |modulo| |#1|)) |#2| (-638 |#2|) |#1| (-923))) (-15 -3513 ((-638 |#2|) |#2| (-638 |#2|) |#1| (-923))) (-15 -4007 (|#2| |#2| |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 28)) (-3421 (($ |#3|) 25)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-4383 (($ $) 32)) (-2630 (($ |#2| |#4| $) 33)) (-4328 (($ |#2| (-709 |#3| |#4| |#5|)) 24)) (-4368 (((-709 |#3| |#4| |#5|) $) 15)) (-2214 ((|#3| $) 19)) (-2458 ((|#4| $) 17)) (-4373 ((|#2| $) 29)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-2876 (($ |#2| |#3| |#4|) 26)) (-2378 (($) 36 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 34)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ |#6| $) 40) (($ $ |#6|) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
-(((-467 |#1| |#2| |#3| |#4| |#5| |#6|) (-13 (-713 |#6|) (-713 |#2|) (-10 -8 (-15 -4373 (|#2| $)) (-15 -4368 ((-709 |#3| |#4| |#5|) $)) (-15 -2458 (|#4| $)) (-15 -2214 (|#3| $)) (-15 -4383 ($ $)) (-15 -4328 ($ |#2| (-709 |#3| |#4| |#5|))) (-15 -3421 ($ |#3|)) (-15 -2876 ($ |#2| |#3| |#4|)) (-15 -2630 ($ |#2| |#4| $)) (-15 * ($ |#6| $)))) (-638 (-1170)) (-174) (-848) (-232 (-4032 |#1|) (-769)) (-1 (-121) (-2 (|:| -1763 |#3|) (|:| -3751 |#4|)) (-2 (|:| -1763 |#3|) (|:| -3751 |#4|))) (-956 |#2| |#4| (-858 |#1|))) (T -467)) 
-((* (*1 *1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-4 *6 (-232 (-4032 *3) (-769))) (-14 *7 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *6)) (-2 (|:| -1763 *5) (|:| -3751 *6)))) (-5 *1 (-467 *3 *4 *5 *6 *7 *2)) (-4 *5 (-848)) (-4 *2 (-956 *4 *6 (-858 *3))))) (-4373 (*1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *5 (-232 (-4032 *3) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *4) (|:| -3751 *5)) (-2 (|:| -1763 *4) (|:| -3751 *5)))) (-4 *2 (-174)) (-5 *1 (-467 *3 *2 *4 *5 *6 *7)) (-4 *4 (-848)) (-4 *7 (-956 *2 *5 (-858 *3))))) (-4368 (*1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-4 *6 (-232 (-4032 *3) (-769))) (-14 *7 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *6)) (-2 (|:| -1763 *5) (|:| -3751 *6)))) (-5 *2 (-709 *5 *6 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8)) (-4 *5 (-848)) (-4 *8 (-956 *4 *6 (-858 *3))))) (-2458 (*1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-14 *6 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *2)) (-2 (|:| -1763 *5) (|:| -3751 *2)))) (-4 *2 (-232 (-4032 *3) (-769))) (-5 *1 (-467 *3 *4 *5 *2 *6 *7)) (-4 *5 (-848)) (-4 *7 (-956 *4 *2 (-858 *3))))) (-2214 (*1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-4 *5 (-232 (-4032 *3) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *2) (|:| -3751 *5)) (-2 (|:| -1763 *2) (|:| -3751 *5)))) (-4 *2 (-848)) (-5 *1 (-467 *3 *4 *2 *5 *6 *7)) (-4 *7 (-956 *4 *5 (-858 *3))))) (-4383 (*1 *1 *1) (-12 (-14 *2 (-638 (-1170))) (-4 *3 (-174)) (-4 *5 (-232 (-4032 *2) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *4) (|:| -3751 *5)) (-2 (|:| -1763 *4) (|:| -3751 *5)))) (-5 *1 (-467 *2 *3 *4 *5 *6 *7)) (-4 *4 (-848)) (-4 *7 (-956 *3 *5 (-858 *2))))) (-4328 (*1 *1 *2 *3) (-12 (-5 *3 (-709 *5 *6 *7)) (-4 *5 (-848)) (-4 *6 (-232 (-4032 *4) (-769))) (-14 *7 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *6)) (-2 (|:| -1763 *5) (|:| -3751 *6)))) (-14 *4 (-638 (-1170))) (-4 *2 (-174)) (-5 *1 (-467 *4 *2 *5 *6 *7 *8)) (-4 *8 (-956 *2 *6 (-858 *4))))) (-3421 (*1 *1 *2) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-4 *5 (-232 (-4032 *3) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *2) (|:| -3751 *5)) (-2 (|:| -1763 *2) (|:| -3751 *5)))) (-5 *1 (-467 *3 *4 *2 *5 *6 *7)) (-4 *2 (-848)) (-4 *7 (-956 *4 *5 (-858 *3))))) (-2876 (*1 *1 *2 *3 *4) (-12 (-14 *5 (-638 (-1170))) (-4 *2 (-174)) (-4 *4 (-232 (-4032 *5) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *3) (|:| -3751 *4)) (-2 (|:| -1763 *3) (|:| -3751 *4)))) (-5 *1 (-467 *5 *2 *3 *4 *6 *7)) (-4 *3 (-848)) (-4 *7 (-956 *2 *4 (-858 *5))))) (-2630 (*1 *1 *2 *3 *1) (-12 (-14 *4 (-638 (-1170))) (-4 *2 (-174)) (-4 *3 (-232 (-4032 *4) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *3)) (-2 (|:| -1763 *5) (|:| -3751 *3)))) (-5 *1 (-467 *4 *2 *5 *3 *6 *7)) (-4 *5 (-848)) (-4 *7 (-956 *2 *3 (-858 *4)))))) 
-(-13 (-713 |#6|) (-713 |#2|) (-10 -8 (-15 -4373 (|#2| $)) (-15 -4368 ((-709 |#3| |#4| |#5|) $)) (-15 -2458 (|#4| $)) (-15 -2214 (|#3| $)) (-15 -4383 ($ $)) (-15 -4328 ($ |#2| (-709 |#3| |#4| |#5|))) (-15 -3421 ($ |#3|)) (-15 -2876 ($ |#2| |#3| |#4|)) (-15 -2630 ($ |#2| |#4| $)) (-15 * ($ |#6| $)))) 
-((-2262 (((-121) $ $) NIL)) (-3661 (((-1170) (-638 (-469))) 48)) (-2023 (((-769) (-638 (-469))) 33)) (-4164 (((-121) (-638 (-469))) 39)) (-1389 (((-3 (-923) "arbitrary") (-638 (-469))) 20)) (-1509 (((-3 (-769) "arbitrary") (-638 (-469))) 18)) (-1321 (((-3 (-923) "arbitrary") (-638 (-469))) 32)) (-4067 (((-769) (-638 (-469))) 25)) (-1992 (((-3 (-769) "arbitrary") (-638 (-469))) 16)) (-1765 (((-3 (-769) "arbitrary") (-638 (-469))) 17)) (-2558 (((-3 (-769) "arbitrary") (-638 (-469))) 21)) (-1658 (((-1152) $) NIL)) (-2719 (((-1170) (-638 (-469))) 50)) (-1314 (((-3 (-923) (-121)) (-638 (-469))) 44)) (-2607 (((-1116) $) NIL)) (-3006 (((-1170) (-638 (-469))) 49)) (-2711 (((-121) (-638 (-469))) 51)) (-3889 (((-121) (-638 (-469))) 40)) (-3972 (((-856) $) NIL)) (-2419 (((-1264) (-638 (-469))) 61)) (-4239 (((-121) (-638 (-469))) 38)) (-2285 (((-3 "skip" "MonteCarlo" "deterministic") (-638 (-469))) 37)) (-4245 (((-121) (-638 (-469))) 29)) (-4225 (((-3 (-923) (-121)) (-638 (-469))) 45)) (-1324 (((-121) $ $) NIL))) 
-(((-468) (-13 (-1098) (-10 -7 (-15 -1765 ((-3 (-769) "arbitrary") (-638 (-469)))) (-15 -1509 ((-3 (-769) "arbitrary") (-638 (-469)))) (-15 -1389 ((-3 (-923) "arbitrary") (-638 (-469)))) (-15 -1321 ((-3 (-923) "arbitrary") (-638 (-469)))) (-15 -1314 ((-3 (-923) (-121)) (-638 (-469)))) (-15 -4225 ((-3 (-923) (-121)) (-638 (-469)))) (-15 -1992 ((-3 (-769) "arbitrary") (-638 (-469)))) (-15 -2558 ((-3 (-769) "arbitrary") (-638 (-469)))) (-15 -4067 ((-769) (-638 (-469)))) (-15 -4245 ((-121) (-638 (-469)))) (-15 -2023 ((-769) (-638 (-469)))) (-15 -2285 ((-3 "skip" "MonteCarlo" "deterministic") (-638 (-469)))) (-15 -4239 ((-121) (-638 (-469)))) (-15 -4164 ((-121) (-638 (-469)))) (-15 -3006 ((-1170) (-638 (-469)))) (-15 -3661 ((-1170) (-638 (-469)))) (-15 -2719 ((-1170) (-638 (-469)))) (-15 -2711 ((-121) (-638 (-469)))) (-15 -3889 ((-121) (-638 (-469)))) (-15 -2419 ((-1264) (-638 (-469))))))) (T -468)) 
-((-1765 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-468)))) (-1509 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-468)))) (-1389 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-923) "arbitrary")) (-5 *1 (-468)))) (-1321 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-923) "arbitrary")) (-5 *1 (-468)))) (-1314 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-923) (-121))) (-5 *1 (-468)))) (-4225 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-923) (-121))) (-5 *1 (-468)))) (-1992 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-468)))) (-2558 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-468)))) (-4067 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-769)) (-5 *1 (-468)))) (-4245 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) (-2023 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-769)) (-5 *1 (-468)))) (-2285 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 "skip" "MonteCarlo" "deterministic")) (-5 *1 (-468)))) (-4239 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) (-4164 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) (-3006 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-1170)) (-5 *1 (-468)))) (-3661 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-1170)) (-5 *1 (-468)))) (-2719 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-1170)) (-5 *1 (-468)))) (-2711 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) (-3889 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) (-2419 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-1264)) (-5 *1 (-468))))) 
-(-13 (-1098) (-10 -7 (-15 -1765 ((-3 (-769) "arbitrary") (-638 (-469)))) (-15 -1509 ((-3 (-769) "arbitrary") (-638 (-469)))) (-15 -1389 ((-3 (-923) "arbitrary") (-638 (-469)))) (-15 -1321 ((-3 (-923) "arbitrary") (-638 (-469)))) (-15 -1314 ((-3 (-923) (-121)) (-638 (-469)))) (-15 -4225 ((-3 (-923) (-121)) (-638 (-469)))) (-15 -1992 ((-3 (-769) "arbitrary") (-638 (-469)))) (-15 -2558 ((-3 (-769) "arbitrary") (-638 (-469)))) (-15 -4067 ((-769) (-638 (-469)))) (-15 -4245 ((-121) (-638 (-469)))) (-15 -2023 ((-769) (-638 (-469)))) (-15 -2285 ((-3 "skip" "MonteCarlo" "deterministic") (-638 (-469)))) (-15 -4239 ((-121) (-638 (-469)))) (-15 -4164 ((-121) (-638 (-469)))) (-15 -3006 ((-1170) (-638 (-469)))) (-15 -3661 ((-1170) (-638 (-469)))) (-15 -2719 ((-1170) (-638 (-469)))) (-15 -2711 ((-121) (-638 (-469)))) (-15 -3889 ((-121) (-638 (-469)))) (-15 -2419 ((-1264) (-638 (-469)))))) 
-((-2262 (((-121) $ $) NIL)) (-3661 (($ (-1170)) 49)) (-2023 (($ (-769)) 28)) (-2890 (((-3 (-57) "failed") (-638 $) (-1170)) 61)) (-4164 (($ (-121)) 40)) (-1389 (($ (-3 (-923) "arbitrary")) 15)) (-1509 (($ (-3 (-769) "arbitrary")) 13)) (-1321 (($ (-3 (-923) "arbitrary")) 27)) (-4067 (($ (-769)) 20)) (-1992 (($ (-3 (-769) "arbitrary")) 11)) (-1765 (($ (-3 (-769) "arbitrary")) 12)) (-2558 (($ (-3 (-769) "arbitrary")) 16)) (-1658 (((-1152) $) NIL)) (-2719 (($ (-1170)) 50)) (-1314 (($ (-3 (-923) (-121))) 32)) (-2607 (((-1116) $) NIL)) (-2648 (($ (-638 (-1170))) 48)) (-3006 (($ (-1170)) 44)) (-2703 (($ (-1170)) 51)) (-3889 (($ (-121)) 34)) (-3972 (((-856) $) 56)) (-4239 (($ (-121)) 39)) (-2285 (($ (-3 "skip" "MonteCarlo" "deterministic")) 38)) (-4245 (($ (-121)) 24)) (-4225 (($ (-3 (-923) (-121))) 33)) (-1324 (((-121) $ $) 58))) 
-(((-469) (-13 (-1098) (-10 -8 (-15 -1765 ($ (-3 (-769) "arbitrary"))) (-15 -1509 ($ (-3 (-769) "arbitrary"))) (-15 -1389 ($ (-3 (-923) "arbitrary"))) (-15 -1321 ($ (-3 (-923) "arbitrary"))) (-15 -1314 ($ (-3 (-923) (-121)))) (-15 -4225 ($ (-3 (-923) (-121)))) (-15 -1992 ($ (-3 (-769) "arbitrary"))) (-15 -2558 ($ (-3 (-769) "arbitrary"))) (-15 -4067 ($ (-769))) (-15 -4245 ($ (-121))) (-15 -2023 ($ (-769))) (-15 -2285 ($ (-3 "skip" "MonteCarlo" "deterministic"))) (-15 -4239 ($ (-121))) (-15 -4164 ($ (-121))) (-15 -3889 ($ (-121))) (-15 -3006 ($ (-1170))) (-15 -2648 ($ (-638 (-1170)))) (-15 -3661 ($ (-1170))) (-15 -2719 ($ (-1170))) (-15 -2703 ($ (-1170))) (-15 -2890 ((-3 (-57) "failed") (-638 $) (-1170)))))) (T -469)) 
-((-1765 (*1 *1 *2) (-12 (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-469)))) (-1509 (*1 *1 *2) (-12 (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-469)))) (-1389 (*1 *1 *2) (-12 (-5 *2 (-3 (-923) "arbitrary")) (-5 *1 (-469)))) (-1321 (*1 *1 *2) (-12 (-5 *2 (-3 (-923) "arbitrary")) (-5 *1 (-469)))) (-1314 (*1 *1 *2) (-12 (-5 *2 (-3 (-923) (-121))) (-5 *1 (-469)))) (-4225 (*1 *1 *2) (-12 (-5 *2 (-3 (-923) (-121))) (-5 *1 (-469)))) (-1992 (*1 *1 *2) (-12 (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-469)))) (-2558 (*1 *1 *2) (-12 (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-469)))) (-4067 (*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-469)))) (-4245 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-469)))) (-2023 (*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-469)))) (-2285 (*1 *1 *2) (-12 (-5 *2 (-3 "skip" "MonteCarlo" "deterministic")) (-5 *1 (-469)))) (-4239 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-469)))) (-4164 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-469)))) (-3889 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-469)))) (-3006 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-469)))) (-2648 (*1 *1 *2) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-469)))) (-3661 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-469)))) (-2719 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-469)))) (-2703 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-469)))) (-2890 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-638 (-469))) (-5 *4 (-1170)) (-5 *2 (-57)) (-5 *1 (-469))))) 
-(-13 (-1098) (-10 -8 (-15 -1765 ($ (-3 (-769) "arbitrary"))) (-15 -1509 ($ (-3 (-769) "arbitrary"))) (-15 -1389 ($ (-3 (-923) "arbitrary"))) (-15 -1321 ($ (-3 (-923) "arbitrary"))) (-15 -1314 ($ (-3 (-923) (-121)))) (-15 -4225 ($ (-3 (-923) (-121)))) (-15 -1992 ($ (-3 (-769) "arbitrary"))) (-15 -2558 ($ (-3 (-769) "arbitrary"))) (-15 -4067 ($ (-769))) (-15 -4245 ($ (-121))) (-15 -2023 ($ (-769))) (-15 -2285 ($ (-3 "skip" "MonteCarlo" "deterministic"))) (-15 -4239 ($ (-121))) (-15 -4164 ($ (-121))) (-15 -3889 ($ (-121))) (-15 -3006 ($ (-1170))) (-15 -2648 ($ (-638 (-1170)))) (-15 -3661 ($ (-1170))) (-15 -2719 ($ (-1170))) (-15 -2703 ($ (-1170))) (-15 -2890 ((-3 (-57) "failed") (-638 $) (-1170))))) 
-((-1610 (((-3 |#5| "failed") |#5| |#2| (-1 |#2|)) 35))) 
-(((-470 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1610 ((-3 |#5| "failed") |#5| |#2| (-1 |#2|)))) (-794) (-848) (-562) (-956 |#3| |#1| |#2|) (-13 (-1044 (-413 (-572))) (-368) (-10 -8 (-15 -3972 ($ |#4|)) (-15 -4487 (|#4| $)) (-15 -4492 (|#4| $))))) (T -470)) 
-((-1610 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *4 (-1 *3)) (-4 *3 (-848)) (-4 *5 (-794)) (-4 *6 (-562)) (-4 *7 (-956 *6 *5 *3)) (-5 *1 (-470 *5 *3 *6 *7 *2)) (-4 *2 (-13 (-1044 (-413 (-572))) (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $)))))))) 
-(-10 -7 (-15 -1610 ((-3 |#5| "failed") |#5| |#2| (-1 |#2|)))) 
-((-3391 ((|#3|) 43)) (-2194 (((-638 |#5|)) 47)) (-4265 (((-638 |#5|) (-638 |#5|)) 129)) (-1915 ((|#3| |#3|) 107)) (-3319 (((-1264)) 106)) (-3356 (((-638 |#5|)) 150 (|has| |#1| (-374)))) (-2653 (((-638 |#7|)) 153 (|has| |#1| (-374)))) (-2936 (((-1264) (-638 (-121))) 120)) (-4543 ((|#5| |#7|) 94)) (-2201 (((-638 |#7|) (-923)) 149 (|has| |#1| (-374)))) (-1956 (((-638 |#7|) |#5|) 92)) (-1534 ((|#6| |#3| |#7|) 97)) (-2931 (((-572) (-923)) 194 (|has| |#1| (-374)))) (-1613 (((-572) (-923) (-923)) 193 (|has| |#1| (-374)))) (-4183 (((-572) (-923)) 176 (|has| |#1| (-374)))) (-2528 (((-2 (|:| |num| (-638 |#3|)) (|:| |den| |#3|)) |#8|) 69)) (-2420 ((|#8| |#3|) 50)) (-2390 (((-638 |#3|) |#8| (-638 |#3|)) 136)) (-3711 (((-638 |#3|) |#8| (-769)) 65)) (-3991 ((|#3| |#3| (-572)) 40)) (-1639 (((-572)) 74)) (-1774 (((-769)) 73)) (-2715 (((-2 (|:| -3306 (-572)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-572))) |#8| (-572) (-572)) 114)) (-2655 (((-3 |#1| "failed") (-413 |#3|) |#7|) 144) (((-3 |#1| "failed") |#3| |#3| |#7|) 139) (((-3 |#1| "failed") |#3| |#7|) 104)) (-4485 ((|#1| (-413 |#3|) |#7|) 145) ((|#1| |#3| |#3| |#7|) 140) ((|#1| |#3| |#7|) 105)) (-3064 (((-638 |#10|)) 70)) (-3548 (((-638 |#10|)) 45)) (-3426 (((-572)) 204 (|has| |#1| (-374)))) (-4457 ((|#8|) 54)) (-3647 (((-1254 (-572) -3512) (-923)) 155 (|has| |#1| (-374))) (((-1254 (-572) -3512)) 156 (|has| |#1| (-374)))) (-3282 (((-1166 (-572)) (-923)) 158 (|has| |#1| (-374))) (((-1166 (-572))) 196 (|has| |#1| (-374))))) 
-(((-471 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -3319 ((-1264))) (-15 -1915 (|#3| |#3|)) (-15 -3991 (|#3| |#3| (-572))) (-15 -2936 ((-1264) (-638 (-121)))) (-15 -3391 (|#3|)) (-15 -1774 ((-769))) (-15 -1639 ((-572))) (-15 -3548 ((-638 |#10|))) (-15 -3064 ((-638 |#10|))) (-15 -4265 ((-638 |#5|) (-638 |#5|))) (-15 -2194 ((-638 |#5|))) (-15 -1534 (|#6| |#3| |#7|)) (-15 -2528 ((-2 (|:| |num| (-638 |#3|)) (|:| |den| |#3|)) |#8|)) (-15 -2715 ((-2 (|:| -3306 (-572)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-572))) |#8| (-572) (-572))) (-15 -3711 ((-638 |#3|) |#8| (-769))) (-15 -2390 ((-638 |#3|) |#8| (-638 |#3|))) (-15 -4485 (|#1| |#3| |#7|)) (-15 -4485 (|#1| |#3| |#3| |#7|)) (-15 -4485 (|#1| (-413 |#3|) |#7|)) (-15 -2655 ((-3 |#1| "failed") |#3| |#7|)) (-15 -2655 ((-3 |#1| "failed") |#3| |#3| |#7|)) (-15 -2655 ((-3 |#1| "failed") (-413 |#3|) |#7|)) (-15 -2420 (|#8| |#3|)) (-15 -4457 (|#8|)) (-15 -1956 ((-638 |#7|) |#5|)) (-15 -4543 (|#5| |#7|)) (IF (|has| |#1| (-374)) (PROGN (-15 -2653 ((-638 |#7|))) (-15 -3356 ((-638 |#5|))) (-15 -3282 ((-1166 (-572)))) (-15 -3282 ((-1166 (-572)) (-923))) (-15 -3426 ((-572))) (-15 -2201 ((-638 |#7|) (-923))) (-15 -4183 ((-572) (-923))) (-15 -2931 ((-572) (-923))) (-15 -1613 ((-572) (-923) (-923))) (-15 -3647 ((-1254 (-572) -3512))) (-15 -3647 ((-1254 (-572) -3512) (-923)))) |noBranch|)) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|) (-645 |#1|) (-926 |#1| |#6|) (-237 |#7|) (-540 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-260 |#9|) (-117)) (T -471)) 
-((-3647 (*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) (-3647 (*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-1613 (*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) (-2931 (*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) (-4183 (*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) (-2201 (*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-638 *10)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) (-3426 (*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-3282 (*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1166 (-572))) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) (-3282 (*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1166 (-572))) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-3356 (*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *7)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-2653 (*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *9)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-4543 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-645 *4)) (-4 *3 (-926 *4 *8)) (-4 *9 (-237 *3)) (-4 *10 (-540 *4 *5 *6 *7 *2 *8 *3 *9 *12)) (-4 *12 (-117)) (-4 *2 (-978 *4)) (-5 *1 (-471 *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) (-1956 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *3 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *6 *7 *3 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *9)) (-5 *1 (-471 *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-4457 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-540 *3 *4 *5 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *9)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-260 *10)))) (-2420 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-540 *4 *5 *3 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *9)) (-5 *1 (-471 *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-260 *10)))) (-2655 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 *6)) (-4 *6 (-956 *2 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-14 *5 (-638 (-1170))) (-4 *8 (-978 *2)) (-4 *9 (-645 *2)) (-4 *4 (-926 *2 *9)) (-4 *10 (-237 *4)) (-4 *11 (-540 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-2655 (*1 *2 *3 *3 *4) (|partial| -12 (-14 *5 (-638 (-1170))) (-4 *3 (-956 *2 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *2)) (-4 *8 (-645 *2)) (-4 *4 (-926 *2 *8)) (-4 *9 (-237 *4)) (-4 *10 (-540 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) (-2655 (*1 *2 *3 *4) (|partial| -12 (-14 *5 (-638 (-1170))) (-4 *3 (-956 *2 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *2)) (-4 *8 (-645 *2)) (-4 *4 (-926 *2 *8)) (-4 *9 (-237 *4)) (-4 *10 (-540 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) (-4485 (*1 *2 *3 *4) (-12 (-5 *3 (-413 *6)) (-4 *6 (-956 *2 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-14 *5 (-638 (-1170))) (-4 *8 (-978 *2)) (-4 *9 (-645 *2)) (-4 *4 (-926 *2 *9)) (-4 *10 (-237 *4)) (-4 *11 (-540 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-4485 (*1 *2 *3 *3 *4) (-12 (-14 *5 (-638 (-1170))) (-4 *3 (-956 *2 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *2)) (-4 *8 (-645 *2)) (-4 *4 (-926 *2 *8)) (-4 *9 (-237 *4)) (-4 *10 (-540 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) (-4485 (*1 *2 *3 *4) (-12 (-14 *5 (-638 (-1170))) (-4 *3 (-956 *2 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *2)) (-4 *8 (-645 *2)) (-4 *4 (-926 *2 *8)) (-4 *9 (-237 *4)) (-4 *10 (-540 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) (-2390 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *3 (-237 *10)) (-4 *11 (-540 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-260 *11)))) (-3711 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) *4)) (-4 *9 (-978 *5)) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-4 *3 (-237 *11)) (-4 *12 (-540 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-638 *7)) (-5 *1 (-471 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-4 *13 (-260 *12)))) (-2715 (*1 *2 *3 *4 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) (-769))) (-4 *9 (-978 *5)) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-4 *3 (-237 *11)) (-4 *12 (-540 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-2 (|:| -3306 (-572)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (-572)))) (-5 *1 (-471 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-5 *4 (-572)) (-4 *13 (-260 *12)))) (-2528 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *3 (-237 *10)) (-4 *11 (-540 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *2 (-2 (|:| |num| (-638 *6)) (|:| |den| *6))) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-260 *11)))) (-1534 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *8 (-978 *5)) (-4 *4 (-926 *5 *2)) (-4 *9 (-237 *4)) (-4 *10 (-540 *5 *6 *3 *7 *8 *2 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-645 *5)) (-5 *1 (-471 *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) (-2194 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *7)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-4265 (*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-978 *3)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-3064 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *12)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-3548 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *12)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-1639 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-1774 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-769)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-3391 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-232 (-4032 *4) (-769))) (-4 *6 (-978 *3)) (-4 *7 (-645 *3)) (-4 *8 (-926 *3 *7)) (-4 *9 (-237 *8)) (-4 *10 (-540 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-4 *2 (-956 *3 *5 (-858 *4))) (-5 *1 (-471 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) (-2936 (*1 *2 *3) (-12 (-5 *3 (-638 (-121))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1264)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) (-3991 (*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *2 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *2 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-471 *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) (-1915 (*1 *2 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *2 (-956 *3 *5 (-858 *4))) (-4 *5 (-232 (-4032 *4) (-769))) (-4 *6 (-978 *3)) (-4 *7 (-645 *3)) (-4 *8 (-926 *3 *7)) (-4 *9 (-237 *8)) (-4 *10 (-540 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-5 *1 (-471 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) (-3319 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11))))) 
-(-10 -7 (-15 -3319 ((-1264))) (-15 -1915 (|#3| |#3|)) (-15 -3991 (|#3| |#3| (-572))) (-15 -2936 ((-1264) (-638 (-121)))) (-15 -3391 (|#3|)) (-15 -1774 ((-769))) (-15 -1639 ((-572))) (-15 -3548 ((-638 |#10|))) (-15 -3064 ((-638 |#10|))) (-15 -4265 ((-638 |#5|) (-638 |#5|))) (-15 -2194 ((-638 |#5|))) (-15 -1534 (|#6| |#3| |#7|)) (-15 -2528 ((-2 (|:| |num| (-638 |#3|)) (|:| |den| |#3|)) |#8|)) (-15 -2715 ((-2 (|:| -3306 (-572)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-572))) |#8| (-572) (-572))) (-15 -3711 ((-638 |#3|) |#8| (-769))) (-15 -2390 ((-638 |#3|) |#8| (-638 |#3|))) (-15 -4485 (|#1| |#3| |#7|)) (-15 -4485 (|#1| |#3| |#3| |#7|)) (-15 -4485 (|#1| (-413 |#3|) |#7|)) (-15 -2655 ((-3 |#1| "failed") |#3| |#7|)) (-15 -2655 ((-3 |#1| "failed") |#3| |#3| |#7|)) (-15 -2655 ((-3 |#1| "failed") (-413 |#3|) |#7|)) (-15 -2420 (|#8| |#3|)) (-15 -4457 (|#8|)) (-15 -1956 ((-638 |#7|) |#5|)) (-15 -4543 (|#5| |#7|)) (IF (|has| |#1| (-374)) (PROGN (-15 -2653 ((-638 |#7|))) (-15 -3356 ((-638 |#5|))) (-15 -3282 ((-1166 (-572)))) (-15 -3282 ((-1166 (-572)) (-923))) (-15 -3426 ((-572))) (-15 -2201 ((-638 |#7|) (-923))) (-15 -4183 ((-572) (-923))) (-15 -2931 ((-572) (-923))) (-15 -1613 ((-572) (-923) (-923))) (-15 -3647 ((-1254 (-572) -3512))) (-15 -3647 ((-1254 (-572) -3512) (-923)))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-3456 (((-638 |#3|) $) 41)) (-3049 (((-121) $) NIL)) (-3289 (((-121) $) NIL (|has| |#1| (-562)))) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2561 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-3097 (((-121) $) NIL (|has| |#1| (-562)))) (-3760 (((-121) $ $) NIL (|has| |#1| (-562)))) (-3819 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4331 (((-121) $) NIL (|has| |#1| (-562)))) (-3683 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) 47)) (-1318 (($ (-638 |#4|)) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-3445 (($ |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-562)))) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4602)))) (-2010 (((-638 |#4|) $) 18 (|has| $ (-6 -4602)))) (-1792 ((|#3| $) 45)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#4|) $) 14 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 26 (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-2435 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 21)) (-4062 (((-638 |#3|) $) NIL)) (-1346 (((-121) |#3| $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-562)))) (-2607 (((-1116) $) NIL)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-2109 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 39)) (-1665 (($) 17)) (-1571 (((-769) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (((-769) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) 16)) (-4081 (((-545) $) NIL (|has| |#4| (-613 (-545)))) (($ (-638 |#4|)) 49)) (-3921 (($ (-638 |#4|)) 13)) (-1826 (($ $ |#3|) NIL)) (-2291 (($ $ |#3|) NIL)) (-1650 (($ $ |#3|) NIL)) (-3972 (((-856) $) 38) (((-638 |#4|) $) 48)) (-3501 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 30)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-472 |#1| |#2| |#3| |#4|) (-13 (-984 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4081 ($ (-638 |#4|))) (-6 -4602) (-6 -4603))) (-1054) (-794) (-848) (-1068 |#1| |#2| |#3|)) (T -472)) 
-((-4081 (*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-472 *3 *4 *5 *6))))) 
-(-13 (-984 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4081 ($ (-638 |#4|))) (-6 -4602) (-6 -4603))) 
-((-2378 (($) 11)) (-3255 (($) 13)) (* (($ |#2| $) 15) (($ $ |#2|) 16))) 
-(((-473 |#1| |#2| |#3|) (-10 -8 (-15 -3255 (|#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -2378 (|#1|))) (-474 |#2| |#3|) (-174) (-23)) (T -473)) 
-NIL 
-(-10 -8 (-15 -3255 (|#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -2378 (|#1|))) 
-((-2262 (((-121) $ $) 7)) (-3376 (((-3 |#1| "failed") $) 23)) (-1318 ((|#1| $) 22)) (-1642 (($ $ $) 20)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4316 ((|#2| $) 18)) (-3972 (((-856) $) 11) (($ |#1|) 24)) (-2378 (($) 17 T CONST)) (-3255 (($) 21 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 14) (($ $ $) 12)) (-1367 (($ $ $) 13)) (* (($ |#1| $) 16) (($ $ |#1|) 15))) 
-(((-474 |#1| |#2|) (-1290) (-174) (-23)) (T -474)) 
-((-3255 (*1 *1) (-12 (-4 *1 (-474 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) (-1642 (*1 *1 *1 *1) (-12 (-4 *1 (-474 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23))))) 
-(-13 (-479 |t#1| |t#2|) (-1044 |t#1|) (-10 -8 (-15 (-3255) ($) -3211) (-15 -1642 ($ $ $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-479 |#1| |#2|) . T) ((-1044 |#1|) . T) ((-1098) . T)) 
-((-1356 (((-1259 (-1259 (-572))) (-1259 (-1259 (-572))) (-923)) 18)) (-3662 (((-1259 (-1259 (-572))) (-923)) 16))) 
-(((-475) (-10 -7 (-15 -1356 ((-1259 (-1259 (-572))) (-1259 (-1259 (-572))) (-923))) (-15 -3662 ((-1259 (-1259 (-572))) (-923))))) (T -475)) 
-((-3662 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 (-1259 (-572)))) (-5 *1 (-475)))) (-1356 (*1 *2 *2 *3) (-12 (-5 *2 (-1259 (-1259 (-572)))) (-5 *3 (-923)) (-5 *1 (-475))))) 
-(-10 -7 (-15 -1356 ((-1259 (-1259 (-572))) (-1259 (-1259 (-572))) (-923))) (-15 -3662 ((-1259 (-1259 (-572))) (-923)))) 
-((-3923 (((-572) (-572)) 30) (((-572)) 22)) (-1985 (((-572) (-572)) 26) (((-572)) 18)) (-2028 (((-572) (-572)) 28) (((-572)) 20)) (-4168 (((-121) (-121)) 12) (((-121)) 10)) (-3673 (((-121) (-121)) 11) (((-121)) 9)) (-2496 (((-121) (-121)) 24) (((-121)) 15))) 
-(((-476) (-10 -7 (-15 -3673 ((-121))) (-15 -4168 ((-121))) (-15 -3673 ((-121) (-121))) (-15 -4168 ((-121) (-121))) (-15 -2496 ((-121))) (-15 -2028 ((-572))) (-15 -1985 ((-572))) (-15 -3923 ((-572))) (-15 -2496 ((-121) (-121))) (-15 -2028 ((-572) (-572))) (-15 -1985 ((-572) (-572))) (-15 -3923 ((-572) (-572))))) (T -476)) 
-((-3923 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) (-1985 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) (-2028 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) (-2496 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476)))) (-3923 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) (-1985 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) (-2028 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) (-2496 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476)))) (-4168 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476)))) (-3673 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476)))) (-4168 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476)))) (-3673 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476))))) 
-(-10 -7 (-15 -3673 ((-121))) (-15 -4168 ((-121))) (-15 -3673 ((-121) (-121))) (-15 -4168 ((-121) (-121))) (-15 -2496 ((-121))) (-15 -2028 ((-572))) (-15 -1985 ((-572))) (-15 -3923 ((-572))) (-15 -2496 ((-121) (-121))) (-15 -2028 ((-572) (-572))) (-15 -1985 ((-572) (-572))) (-15 -3923 ((-572) (-572)))) 
-((-2262 (((-121) $ $) NIL)) (-1810 (((-638 (-385)) $) 27) (((-638 (-385)) $ (-638 (-385))) 90)) (-1588 (((-638 (-1092 (-385))) $) 14) (((-638 (-1092 (-385))) $ (-638 (-1092 (-385)))) 87)) (-3657 (((-638 (-638 (-950 (-217)))) (-638 (-638 (-950 (-217)))) (-638 (-875))) 42)) (-3131 (((-638 (-638 (-950 (-217)))) $) 83)) (-1767 (((-1264) $ (-950 (-217)) (-875)) 103)) (-1797 (($ $) 82) (($ (-638 (-638 (-950 (-217))))) 93) (($ (-638 (-638 (-950 (-217)))) (-638 (-875)) (-638 (-875)) (-638 (-923))) 92) (($ (-638 (-638 (-950 (-217)))) (-638 (-875)) (-638 (-875)) (-638 (-923)) (-638 (-258))) 94)) (-1658 (((-1152) $) NIL)) (-4111 (((-572) $) 65)) (-2607 (((-1116) $) NIL)) (-2587 (($) 91)) (-1396 (((-638 (-217)) (-638 (-638 (-950 (-217))))) 52)) (-3041 (((-1264) $ (-638 (-950 (-217))) (-875) (-875) (-923)) 97) (((-1264) $ (-950 (-217))) 99) (((-1264) $ (-950 (-217)) (-875) (-875) (-923)) 98)) (-3972 (((-856) $) 109) (($ (-638 (-638 (-950 (-217))))) 104)) (-2797 (((-1264) $ (-950 (-217))) 102)) (-1324 (((-121) $ $) NIL))) 
-(((-477) (-13 (-1098) (-10 -8 (-15 -2587 ($)) (-15 -1797 ($ $)) (-15 -1797 ($ (-638 (-638 (-950 (-217)))))) (-15 -1797 ($ (-638 (-638 (-950 (-217)))) (-638 (-875)) (-638 (-875)) (-638 (-923)))) (-15 -1797 ($ (-638 (-638 (-950 (-217)))) (-638 (-875)) (-638 (-875)) (-638 (-923)) (-638 (-258)))) (-15 -3131 ((-638 (-638 (-950 (-217)))) $)) (-15 -4111 ((-572) $)) (-15 -1588 ((-638 (-1092 (-385))) $)) (-15 -1588 ((-638 (-1092 (-385))) $ (-638 (-1092 (-385))))) (-15 -1810 ((-638 (-385)) $)) (-15 -1810 ((-638 (-385)) $ (-638 (-385)))) (-15 -3041 ((-1264) $ (-638 (-950 (-217))) (-875) (-875) (-923))) (-15 -3041 ((-1264) $ (-950 (-217)))) (-15 -3041 ((-1264) $ (-950 (-217)) (-875) (-875) (-923))) (-15 -2797 ((-1264) $ (-950 (-217)))) (-15 -1767 ((-1264) $ (-950 (-217)) (-875))) (-15 -3972 ($ (-638 (-638 (-950 (-217)))))) (-15 -3972 ((-856) $)) (-15 -3657 ((-638 (-638 (-950 (-217)))) (-638 (-638 (-950 (-217)))) (-638 (-875)))) (-15 -1396 ((-638 (-217)) (-638 (-638 (-950 (-217))))))))) (T -477)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-477)))) (-2587 (*1 *1) (-5 *1 (-477))) (-1797 (*1 *1 *1) (-5 *1 (-477))) (-1797 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *1 (-477)))) (-1797 (*1 *1 *2 *3 *3 *4) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *3 (-638 (-875))) (-5 *4 (-638 (-923))) (-5 *1 (-477)))) (-1797 (*1 *1 *2 *3 *3 *4 *5) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *3 (-638 (-875))) (-5 *4 (-638 (-923))) (-5 *5 (-638 (-258))) (-5 *1 (-477)))) (-3131 (*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *1 (-477)))) (-4111 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-477)))) (-1588 (*1 *2 *1) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-477)))) (-1588 (*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-477)))) (-1810 (*1 *2 *1) (-12 (-5 *2 (-638 (-385))) (-5 *1 (-477)))) (-1810 (*1 *2 *1 *2) (-12 (-5 *2 (-638 (-385))) (-5 *1 (-477)))) (-3041 (*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-638 (-950 (-217)))) (-5 *4 (-875)) (-5 *5 (-923)) (-5 *2 (-1264)) (-5 *1 (-477)))) (-3041 (*1 *2 *1 *3) (-12 (-5 *3 (-950 (-217))) (-5 *2 (-1264)) (-5 *1 (-477)))) (-3041 (*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-950 (-217))) (-5 *4 (-875)) (-5 *5 (-923)) (-5 *2 (-1264)) (-5 *1 (-477)))) (-2797 (*1 *2 *1 *3) (-12 (-5 *3 (-950 (-217))) (-5 *2 (-1264)) (-5 *1 (-477)))) (-1767 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-950 (-217))) (-5 *4 (-875)) (-5 *2 (-1264)) (-5 *1 (-477)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *1 (-477)))) (-3657 (*1 *2 *2 *3) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *3 (-638 (-875))) (-5 *1 (-477)))) (-1396 (*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *2 (-638 (-217))) (-5 *1 (-477))))) 
-(-13 (-1098) (-10 -8 (-15 -2587 ($)) (-15 -1797 ($ $)) (-15 -1797 ($ (-638 (-638 (-950 (-217)))))) (-15 -1797 ($ (-638 (-638 (-950 (-217)))) (-638 (-875)) (-638 (-875)) (-638 (-923)))) (-15 -1797 ($ (-638 (-638 (-950 (-217)))) (-638 (-875)) (-638 (-875)) (-638 (-923)) (-638 (-258)))) (-15 -3131 ((-638 (-638 (-950 (-217)))) $)) (-15 -4111 ((-572) $)) (-15 -1588 ((-638 (-1092 (-385))) $)) (-15 -1588 ((-638 (-1092 (-385))) $ (-638 (-1092 (-385))))) (-15 -1810 ((-638 (-385)) $)) (-15 -1810 ((-638 (-385)) $ (-638 (-385)))) (-15 -3041 ((-1264) $ (-638 (-950 (-217))) (-875) (-875) (-923))) (-15 -3041 ((-1264) $ (-950 (-217)))) (-15 -3041 ((-1264) $ (-950 (-217)) (-875) (-875) (-923))) (-15 -2797 ((-1264) $ (-950 (-217)))) (-15 -1767 ((-1264) $ (-950 (-217)) (-875))) (-15 -3972 ($ (-638 (-638 (-950 (-217)))))) (-15 -3972 ((-856) $)) (-15 -3657 ((-638 (-638 (-950 (-217)))) (-638 (-638 (-950 (-217)))) (-638 (-875)))) (-15 -1396 ((-638 (-217)) (-638 (-638 (-950 (-217)))))))) 
-((-1373 (($ $) NIL) (($ $ $) 11))) 
-(((-478 |#1| |#2| |#3|) (-10 -8 (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|))) (-479 |#2| |#3|) (-174) (-23)) (T -478)) 
-NIL 
-(-10 -8 (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4316 ((|#2| $) 18)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 14) (($ $ $) 12)) (-1367 (($ $ $) 13)) (* (($ |#1| $) 16) (($ $ |#1|) 15))) 
-(((-479 |#1| |#2|) (-1290) (-174) (-23)) (T -479)) 
-((-4316 (*1 *2 *1) (-12 (-4 *1 (-479 *3 *2)) (-4 *3 (-174)) (-4 *2 (-23)))) (-2378 (*1 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) (-1373 (*1 *1 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) (-1367 (*1 *1 *1 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) (-1373 (*1 *1 *1 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23))))) 
-(-13 (-1098) (-10 -8 (-15 -4316 (|t#2| $)) (-15 (-2378) ($) -3211) (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|)) (-15 -1373 ($ $)) (-15 -1367 ($ $ $)) (-15 -1373 ($ $ $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2644 (((-3 (-638 (-496 |#1| |#2|)) "failed") (-638 (-496 |#1| |#2|)) (-638 (-858 |#1|))) 88)) (-2574 (((-638 (-638 (-244 |#1| |#2|))) (-638 (-244 |#1| |#2|)) (-638 (-858 |#1|))) 86)) (-1788 (((-2 (|:| |dpolys| (-638 (-244 |#1| |#2|))) (|:| |coords| (-638 (-572)))) (-638 (-244 |#1| |#2|)) (-638 (-858 |#1|))) 58))) 
-(((-480 |#1| |#2| |#3|) (-10 -7 (-15 -2574 ((-638 (-638 (-244 |#1| |#2|))) (-638 (-244 |#1| |#2|)) (-638 (-858 |#1|)))) (-15 -2644 ((-3 (-638 (-496 |#1| |#2|)) "failed") (-638 (-496 |#1| |#2|)) (-638 (-858 |#1|)))) (-15 -1788 ((-2 (|:| |dpolys| (-638 (-244 |#1| |#2|))) (|:| |coords| (-638 (-572)))) (-638 (-244 |#1| |#2|)) (-638 (-858 |#1|))))) (-638 (-1170)) (-457) (-457)) (T -480)) 
-((-1788 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-858 *5))) (-14 *5 (-638 (-1170))) (-4 *6 (-457)) (-5 *2 (-2 (|:| |dpolys| (-638 (-244 *5 *6))) (|:| |coords| (-638 (-572))))) (-5 *1 (-480 *5 *6 *7)) (-5 *3 (-638 (-244 *5 *6))) (-4 *7 (-457)))) (-2644 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-496 *4 *5))) (-5 *3 (-638 (-858 *4))) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *1 (-480 *4 *5 *6)) (-4 *6 (-457)))) (-2574 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-858 *5))) (-14 *5 (-638 (-1170))) (-4 *6 (-457)) (-5 *2 (-638 (-638 (-244 *5 *6)))) (-5 *1 (-480 *5 *6 *7)) (-5 *3 (-638 (-244 *5 *6))) (-4 *7 (-457))))) 
-(-10 -7 (-15 -2574 ((-638 (-638 (-244 |#1| |#2|))) (-638 (-244 |#1| |#2|)) (-638 (-858 |#1|)))) (-15 -2644 ((-3 (-638 (-496 |#1| |#2|)) "failed") (-638 (-496 |#1| |#2|)) (-638 (-858 |#1|)))) (-15 -1788 ((-2 (|:| |dpolys| (-638 (-244 |#1| |#2|))) (|:| |coords| (-638 (-572)))) (-638 (-244 |#1| |#2|)) (-638 (-858 |#1|))))) 
-((-1799 (((-3 $ "failed") $) 11)) (-3018 (($ $ $) 20)) (-4056 (($ $ $) 21)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 14)) (-1379 (($ $ $) 9)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 19))) 
-(((-481 |#1|) (-10 -8 (-15 -4056 (|#1| |#1| |#1|)) (-15 -3018 (|#1| |#1| |#1|)) (-15 -4174 (|#1| |#1| (-572))) (-15 ** (|#1| |#1| (-572))) (-15 -1379 (|#1| |#1| |#1|)) (-15 -1799 ((-3 |#1| "failed") |#1|)) (-15 -4174 (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-769))) (-15 -4174 (|#1| |#1| (-923))) (-15 ** (|#1| |#1| (-923)))) (-482)) (T -481)) 
-NIL 
-(-10 -8 (-15 -4056 (|#1| |#1| |#1|)) (-15 -3018 (|#1| |#1| |#1|)) (-15 -4174 (|#1| |#1| (-572))) (-15 ** (|#1| |#1| (-572))) (-15 -1379 (|#1| |#1| |#1|)) (-15 -1799 ((-3 |#1| "failed") |#1|)) (-15 -4174 (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-769))) (-15 -4174 (|#1| |#1| (-923))) (-15 ** (|#1| |#1| (-923)))) 
-((-2262 (((-121) $ $) 7)) (-2211 (($) 19 T CONST)) (-1799 (((-3 $ "failed") $) 15)) (-3893 (((-121) $) 18)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 26)) (-2607 (((-1116) $) 10)) (-3018 (($ $ $) 22)) (-4056 (($ $ $) 21)) (-3972 (((-856) $) 11)) (-4174 (($ $ (-923)) 12) (($ $ (-769)) 16) (($ $ (-572)) 23)) (-3255 (($) 20 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 25)) (** (($ $ (-923)) 13) (($ $ (-769)) 17) (($ $ (-572)) 24)) (* (($ $ $) 14))) 
-(((-482) (-1290)) (T -482)) 
-((-4350 (*1 *1 *1) (-4 *1 (-482))) (-1379 (*1 *1 *1 *1) (-4 *1 (-482))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-482)) (-5 *2 (-572)))) (-4174 (*1 *1 *1 *2) (-12 (-4 *1 (-482)) (-5 *2 (-572)))) (-3018 (*1 *1 *1 *1) (-4 *1 (-482))) (-4056 (*1 *1 *1 *1) (-4 *1 (-482)))) 
-(-13 (-722) (-10 -8 (-15 -4350 ($ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ (-572))) (-15 -4174 ($ $ (-572))) (-6 -4599) (-15 -3018 ($ $ $)) (-15 -4056 ($ $ $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-722) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 17)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-413 (-572))) NIL) (($ $ (-413 (-572)) (-413 (-572))) NIL)) (-2640 (((-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|))) $) NIL)) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-769) (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|)))) NIL)) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-413 (-572)) $) NIL) (((-413 (-572)) $ (-413 (-572))) NIL)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) NIL) (($ $ (-413 (-572))) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-413 (-572))) NIL) (($ $ (-1082) (-413 (-572))) NIL) (($ $ (-638 (-1082)) (-638 (-413 (-572)))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) 22)) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-2774 (($ $) 26 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 33 (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 |#2|)) 27 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1977 (($ $ (-413 (-572))) NIL)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ (-413 (-572))) NIL) (($ $ $) NIL (|has| (-413 (-572)) (-1110)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) 25 (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) 13 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $ (-1255 |#2|)) 15)) (-4316 (((-413 (-572)) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL (|has| |#1| (-174))) (($ (-1255 |#2|)) NIL) (($ (-1243 |#1| |#2| |#3|)) 9) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562)))) (-1958 ((|#1| $ (-413 (-572))) NIL)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) 18)) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-413 (-572))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) 24)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 23) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-483 |#1| |#2| |#3|) (-13 (-1239 |#1|) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3972 ($ (-1243 |#1| |#2| |#3|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) (-1054) (-1170) |#1|) (T -483)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-483 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1243 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3) (-5 *1 (-483 *3 *4 *5)))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-483 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-483 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3)))) 
-(-13 (-1239 |#1|) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3972 ($ (-1243 |#1| |#2| |#3|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2430 (((-1264) $ |#1| |#1|) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#2| $ |#1| |#2|) 18)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 |#2| "failed") |#1| $) 19)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) 16)) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) NIL)) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 ((|#1| $) NIL (|has| |#1| (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 ((|#1| $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2760 (((-638 |#1|) $) NIL)) (-2365 (((-121) |#1| $) NIL)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2739 (((-638 |#1|) $) NIL)) (-1601 (((-121) |#1| $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-1837 ((|#2| $) NIL (|has| |#1| (-848)))) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ |#1|) 13) ((|#2| $ |#1| |#2|) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-484 |#1| |#2| |#3| |#4|) (-1181 |#1| |#2|) (-1098) (-1098) (-1181 |#1| |#2|) |#2|) (T -484)) 
-NIL 
-(-1181 |#1| |#2|) 
-((-2262 (((-121) $ $) NIL)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) NIL)) (-4165 (((-638 $) (-638 |#4|)) NIL)) (-3456 (((-638 |#3|) $) NIL)) (-3049 (((-121) $) NIL)) (-3289 (((-121) $) NIL (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1872 ((|#4| |#4| $) NIL)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2561 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) NIL)) (-2211 (($) NIL T CONST)) (-3097 (((-121) $) 26 (|has| |#1| (-562)))) (-3760 (((-121) $ $) NIL (|has| |#1| (-562)))) (-3819 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4331 (((-121) $) NIL (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3683 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) NIL)) (-1318 (($ (-638 |#4|)) NIL)) (-1651 (((-3 $ "failed") $) 39)) (-2242 ((|#4| |#4| $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-3445 (($ |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-1673 ((|#4| |#4| $) NIL)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) NIL)) (-2010 (((-638 |#4|) $) 16 (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#4|) $) 17 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-2435 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 21)) (-4062 (((-638 |#3|) $) NIL)) (-1346 (((-121) |#3| $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-3253 (((-3 |#4| "failed") $) 37)) (-3727 (((-638 |#4|) $) NIL)) (-1483 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2788 ((|#4| |#4| $) NIL)) (-1843 (((-121) $ $) NIL)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4498 ((|#4| |#4| $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-3 |#4| "failed") $) 35)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1928 (((-3 $ "failed") $ |#4|) 46)) (-1977 (($ $ |#4|) NIL)) (-2109 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 15)) (-1665 (($) 13)) (-4316 (((-769) $) NIL)) (-1571 (((-769) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (((-769) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) 12)) (-4081 (((-545) $) NIL (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 20)) (-1826 (($ $ |#3|) 42)) (-2291 (($ $ |#3|) 43)) (-3134 (($ $) NIL)) (-1650 (($ $ |#3|) NIL)) (-3972 (((-856) $) 31) (((-638 |#4|) $) 40)) (-2498 (((-769) $) NIL (|has| |#3| (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) NIL)) (-3501 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) NIL)) (-2213 (((-121) |#3| $) NIL)) (-1324 (((-121) $ $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-485 |#1| |#2| |#3| |#4|) (-1198 |#1| |#2| |#3| |#4|) (-562) (-794) (-848) (-1068 |#1| |#2| |#3|)) (T -485)) 
-NIL 
-(-1198 |#1| |#2| |#3| |#4|) 
-((-1705 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))) (-1170)) NIL (|has| (-53) (-1044 (-1170)))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))) NIL)) (-2834 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)) NIL (|has| (-53) (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL)) (-3650 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)) NIL (|has| (-53) (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL)) (-1547 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL)) (-3368 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)) NIL (|has| (-53) (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL)) (-3142 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL)) (-3490 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) NIL)) (-4366 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)) NIL (|has| (-53) (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL)) (-2316 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)) NIL (|has| (-53) (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL)) (-2223 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL)) (-2867 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)) NIL (|has| (-53) (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL)) (-1632 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-638 (-1170)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-638 (-1170))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53))) NIL)) (-2494 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))) (-1170)) NIL (|has| (-53) (-1044 (-1170)))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))) NIL))) 
-(((-486) (-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (IF (|has| (-53) (-1044 (-1170))) (IF (|has| (-53) (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (IF (|has| (-53) (-1044 (-1170))) (IF (|has| (-53) (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|))) (T -486)) 
-((-2867 (*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) (-3650 (*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) (-3368 (*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) (-2834 (*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) (-2494 (*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (-5 *1 (-486)))) (-1705 (*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (-5 *1 (-486)))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769))))) (-5 *1 (-486)))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769))))) (-5 *1 (-486)))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-3650 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-3368 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-2834 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-1547 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-3142 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-3142 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-2223 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-2223 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-2867 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-2867 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-3490 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) (-2316 (*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) (-4366 (*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) (-2316 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-4366 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-1632 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-1632 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-1632 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) (-1632 (*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486))))) 
-(-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (IF (|has| (-53) (-1044 (-1170))) (IF (|has| (-53) (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (IF (|has| (-53) (-1044 (-1170))) (IF (|has| (-53) (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|)) 
-((-1537 (((-312 (-572)) |#1|) 11))) 
-(((-487 |#1|) (-10 -7 (-15 -1537 ((-312 (-572)) |#1|))) (-13 (-353) (-613 (-572)))) (T -487)) 
-((-1537 (*1 *2 *3) (-12 (-5 *2 (-312 (-572))) (-5 *1 (-487 *3)) (-4 *3 (-13 (-353) (-613 (-572))))))) 
-(-10 -7 (-15 -1537 ((-312 (-572)) |#1|))) 
-((-1705 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))) (-1170)) NIL (|has| |#1| (-1044 (-1170)))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))) NIL)) (-2834 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) NIL (|has| |#1| (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL)) (-3650 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) NIL (|has| |#1| (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL)) (-1547 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL)) (-3368 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) NIL (|has| |#1| (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL)) (-3142 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL)) (-3490 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469)))) NIL)) (-4366 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) NIL (|has| |#1| (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL)) (-2316 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) NIL (|has| |#1| (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL)) (-2223 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL)) (-2867 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) NIL (|has| |#1| (-1044 (-1170)))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL)) (-1632 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|)) NIL)) (-2494 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))) (-1170)) NIL (|has| |#1| (-1044 (-1170)))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))) NIL))) 
-(((-488 |#1|) (-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (IF (|has| |#1| (-1044 (-1170))) (IF (|has| |#1| (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469)))) (IF (|has| |#1| (-1044 (-1170))) (IF (|has| |#1| (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|)) (-13 (-353) (-613 (-572)))) (T -488)) 
-((-2867 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 *4) (-769)))) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 *4) (-769)))) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 *4) (-769))))) (-5 *1 (-488 *4)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 *4) (-769))))) (-5 *1 (-488 *4)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-3650 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-3368 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-2834 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-1547 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-3142 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-3142 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-2223 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-2223 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-2867 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-2867 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-3490 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 *4) (-769)))) (-638 (-469)))) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) (-2316 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-4366 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) (-1632 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *7) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 *7)) (-4 *7 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *7)))) (-1632 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *6) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 *6)) (-4 *6 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *6)))) (-1632 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) (-1632 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4))))) 
-(-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (IF (|has| |#1| (-1044 (-1170))) (IF (|has| |#1| (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469)))) (IF (|has| |#1| (-1044 (-1170))) (IF (|has| |#1| (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 |#1| (-769) (-769) (-1166 |#1|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 |#1|) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|)) 
-((-1705 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-572)) (-1044 (-1170))) (|has| (-572) (-1044 (-1170))))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))) NIL)) (-2834 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-572)) (-1044 (-1170))) (|has| (-572) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL)) (-3650 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-572)) (-1044 (-1170))) (|has| (-572) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL)) (-1547 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL)) (-3368 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-572)) (-1044 (-1170))) (|has| (-572) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL)) (-3142 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL)) (-3490 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) NIL)) (-4366 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-572)) (-1044 (-1170))) (|has| (-572) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL)) (-2316 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-572)) (-1044 (-1170))) (|has| (-572) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL)) (-2223 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL)) (-2867 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-572)) (-1044 (-1170))) (|has| (-572) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL)) (-1632 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-638 (-1170)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-638 (-1170))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572)))) NIL)) (-2494 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-572)) (-1044 (-1170))) (|has| (-572) (-1044 (-1170))))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))) NIL))) 
-(((-489) (-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (IF (|has| (-413 (-572)) (-1044 (-1170))) (IF (|has| (-572) (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (IF (|has| (-413 (-572)) (-1044 (-1170))) (IF (|has| (-572) (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|))) (T -489)) 
-((-2867 (*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) (-3650 (*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) (-3368 (*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) (-2834 (*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) (-2494 (*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (-5 *1 (-489)))) (-1705 (*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (-5 *1 (-489)))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769))))) (-5 *1 (-489)))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769))))) (-5 *1 (-489)))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-3650 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-3368 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-2834 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-1547 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-3142 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-3142 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-2223 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-2223 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-2867 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-2867 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-3490 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) (-2316 (*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) (-4366 (*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) (-2316 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-4366 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-1632 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-1632 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-1632 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) (-1632 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489))))) 
-(-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (IF (|has| (-413 (-572)) (-1044 (-1170))) (IF (|has| (-572) (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (IF (|has| (-413 (-572)) (-1044 (-1170))) (IF (|has| (-572) (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|)) 
-((-1705 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))) (-1170)) 367 (-12 (|has| |#1| (-1044 (-1170))) (|has| |#2| (-1044 (-1170))))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))) 361)) (-2834 (((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) 484 (-12 (|has| |#1| (-1044 (-1170))) (|has| |#2| (-1044 (-1170))))) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 477) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 478)) (-3650 (((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) 486 (-12 (|has| |#1| (-1044 (-1170))) (|has| |#2| (-1044 (-1170))))) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 483) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 482)) (-1547 (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 475) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 474)) (-3368 (((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) 485 (-12 (|has| |#1| (-1044 (-1170))) (|has| |#2| (-1044 (-1170))))) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 480) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 479)) (-3142 (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 471) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 472)) (-3490 (((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469)))) 463)) (-4366 (((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) 193 (-12 (|has| |#1| (-1044 (-1170))) (|has| |#2| (-1044 (-1170))))) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 191) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 190)) (-2316 (((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) 219 (-12 (|has| |#1| (-1044 (-1170))) (|has| |#2| (-1044 (-1170))))) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 208) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 207)) (-2223 (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 468) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 469)) (-2867 (((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)) 476 (-12 (|has| |#1| (-1044 (-1170))) (|has| |#2| (-1044 (-1170))))) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 464) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 465)) (-1632 (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)) (-638 (-469))) 509) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170))) 514) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) 513) (((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|)) 512)) (-2494 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))) (-1170)) 336 (-12 (|has| |#1| (-1044 (-1170))) (|has| |#2| (-1044 (-1170))))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))) 326))) 
-(((-490 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -1632 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -4366 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2316 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (IF (|has| |#1| (-1044 (-1170))) (IF (|has| |#2| (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2867 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2223 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -3142 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2834 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2834 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -3650 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469)))) (IF (|has| |#1| (-1044 (-1170))) (IF (|has| |#2| (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|)) (-368) (-457) (-13 (-436 (-572)) (-562) (-1044 |#4|) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $)))) (-13 (-848) (-562)) (-1 |#1| |#4|) (-1 |#3| |#1|)) (T -490)) 
-((-2867 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 *3)) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) *3 *6)) (|:| C (-1 (-638 *5) (-769)))) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 *3)) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) *3 *6)) (|:| C (-1 (-638 *5) (-769)))) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 (-1170))) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) (-1170) *6)) (|:| C (-1 (-638 *5) (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 (-1170))) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) (-1170) *6)) (|:| C (-1 (-638 *5) (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-3650 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-3368 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-2834 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-1547 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-3142 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-3142 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-2223 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-2223 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-2867 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-2867 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-3490 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 (-1170))) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) (-1170) *6)) (|:| C (-1 (-638 *5) (-769)))) (-638 (-469)))) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-14 *9 (-1 *6 *4)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-2316 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-4366 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-1632 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 *9) (|:| -3377 (-769)))) (-638 *7) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 *7)) (-4 *7 (-368)) (-14 *12 (-1 *9 *7)) (-4 *10 (-13 (-848) (-562))) (-14 *11 (-1 *7 *10)) (-5 *2 (-638 (-2 (|:| -3616 *9) (|:| -3377 (-769))))) (-5 *1 (-490 *7 *8 *9 *10 *11 *12)) (-4 *8 (-457)) (-4 *9 (-13 (-436 (-572)) (-562) (-1044 *10) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-1632 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 *8) (|:| -3377 (-769)))) (-638 *6) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 *6)) (-4 *6 (-368)) (-14 *11 (-1 *8 *6)) (-4 *9 (-13 (-848) (-562))) (-14 *10 (-1 *6 *9)) (-5 *2 (-638 (-2 (|:| -3616 *8) (|:| -3377 (-769))))) (-5 *1 (-490 *6 *7 *8 *9 *10 *11)) (-4 *7 (-457)) (-4 *8 (-13 (-436 (-572)) (-562) (-1044 *9) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-1632 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) (-1632 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $)))))))) 
-(-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -1632 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -4366 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2316 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (IF (|has| |#1| (-1044 (-1170))) (IF (|has| |#2| (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2867 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2223 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -3142 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2834 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2834 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -3650 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469)))) (IF (|has| |#1| (-1044 (-1170))) (IF (|has| |#2| (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 |#1|)) (-1216 |#1|))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 |#1|))) (-1216 (-1166 |#1|)))) (|:| |exprStream| (-1 (-1150 |#3|) |#3| (-1170))) (|:| A (-1 |#2| (-769) (-769) (-1166 |#2|))) (|:| AF (-1 (-1166 |#1|) (-769) (-769) (-1216 (-1166 |#1|)))) (|:| AX (-1 |#3| (-769) (-1170) |#3|)) (|:| C (-1 (-638 |#2|) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 |#3|) (|:| -3377 (-769)))) (-638 |#1|) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|)) 
-((-1705 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-959 (-572))) (-1044 (-1170))) (|has| (-959 (-572)) (-1044 (-1170))))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))) NIL)) (-2834 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-959 (-572))) (-1044 (-1170))) (|has| (-959 (-572)) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL)) (-3650 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-959 (-572))) (-1044 (-1170))) (|has| (-959 (-572)) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL)) (-1547 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL)) (-3368 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-959 (-572))) (-1044 (-1170))) (|has| (-959 (-572)) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL)) (-3142 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL)) (-3490 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) NIL)) (-4366 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-959 (-572))) (-1044 (-1170))) (|has| (-959 (-572)) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL)) (-2316 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-959 (-572))) (-1044 (-1170))) (|has| (-959 (-572)) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL)) (-2223 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL)) (-2867 (((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-959 (-572))) (-1044 (-1170))) (|has| (-959 (-572)) (-1044 (-1170))))) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL)) (-1632 (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-638 (-1170)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-638 (-1170))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572))))) NIL)) (-2494 (((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))) (-1170)) NIL (-12 (|has| (-413 (-959 (-572))) (-1044 (-1170))) (|has| (-959 (-572)) (-1044 (-1170))))) (((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))) NIL))) 
-(((-491) (-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (IF (|has| (-413 (-959 (-572))) (-1044 (-1170))) (IF (|has| (-959 (-572)) (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (IF (|has| (-413 (-959 (-572))) (-1044 (-1170))) (IF (|has| (-959 (-572)) (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|))) (T -491)) 
-((-2867 (*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) (-3650 (*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) (-3368 (*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) (-2834 (*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) (-2494 (*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (-5 *1 (-491)))) (-1705 (*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (-5 *1 (-491)))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769))))) (-5 *1 (-491)))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769))))) (-5 *1 (-491)))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-3650 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-3368 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-2834 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-1547 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-3142 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-3142 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-2223 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-2223 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-2867 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-2867 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-3490 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) (-2316 (*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) (-4366 (*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) (-2316 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-4366 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-1632 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-1632 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-1632 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) (-1632 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491))))) 
-(-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -4366 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2316 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (IF (|has| (-413 (-959 (-572))) (-1044 (-1170))) (IF (|has| (-959 (-572)) (-1044 (-1170))) (PROGN (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2223 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -3142 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))))) (-15 -2494 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (-15 -1705 ((-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (IF (|has| (-413 (-959 (-572))) (-1044 (-1170))) (IF (|has| (-959 (-572)) (-1044 (-1170))) (PROGN (-15 -1705 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))) (-1170))) (-15 -2494 ((-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))) (-1170)))) |noBranch|) |noBranch|)) 
-((-1705 (((-1 HPSPEC (-638 (-469))) (-1170)) NIL) ((HPSPEC (-638 (-469))) NIL)) (-2834 (((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170)) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL)) (-3650 (((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170)) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL)) (-1547 (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL)) (-3368 (((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170)) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL)) (-3142 (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL)) (-3490 (((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1 HPSPEC (-638 (-469)))) NIL)) (-4366 (((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170)) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL)) (-2316 (((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170)) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL)) (-2223 (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL)) (-2867 (((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170)) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL)) (-1632 (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-638 (-1170)) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-638 (-1170))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) NIL) (((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572))))) NIL)) (-2494 (((-1 HPSPEC (-638 (-469))) (-1170)) NIL) ((HPSPEC (-638 (-469))) NIL))) 
-(((-492 |#1|) (-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -1632 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -4366 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2316 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1 HPSPEC (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2223 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -3142 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -3650 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2494 (HPSPEC (-638 (-469)))) (-15 -1705 (HPSPEC (-638 (-469)))) (-15 -1705 ((-1 HPSPEC (-638 (-469))) (-1170))) (-15 -2494 ((-1 HPSPEC (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170)))) (-1170)) (T -492)) 
-((-2867 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 HPSPEC (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 HPSPEC (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 HPSPEC) (-5 *1 (-492 *4)) (-14 *4 (-1170)))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 HPSPEC) (-5 *1 (-492 *4)) (-14 *4 (-1170)))) (-3650 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-3650 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-3368 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-3368 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-2834 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-1547 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-3142 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-3142 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-2223 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-2223 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-2867 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-2867 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-3490 (*1 *2 *3) (-12 (-5 *3 (-1 HPSPEC (-638 (-469)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 (-1170)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3))) (-2316 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-4366 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) (-1632 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-739 *7 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *7 (-572)))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 (-413 (-740 *7 (-572))))) (-14 *7 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *7 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *7)))) (-1632 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-739 *6 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *6 (-572)))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 (-413 (-740 *6 (-572))))) (-14 *6 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *6 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *6)))) (-1632 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) (-1632 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4))))) 
-(-10 -7 (-15 -1632 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -1632 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-638 (-1170)))) (-15 -1632 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-638 (-1170)) (-638 (-469)))) (-15 -4366 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -4366 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -2316 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2316 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -4366 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -2316 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -3490 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1 HPSPEC (-638 (-469))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2867 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -2223 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2223 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -3142 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -3142 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -1547 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2834 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -3368 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -3650 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469)))) (-15 -3650 ((-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))))) (-15 -2494 (HPSPEC (-638 (-469)))) (-15 -1705 (HPSPEC (-638 (-469)))) (-15 -1705 ((-1 HPSPEC (-638 (-469))) (-1170))) (-15 -2494 ((-1 HPSPEC (-638 (-469))) (-1170))) (-15 -2834 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -3368 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -3650 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170))) (-15 -2867 ((-1 (-638 (-2 (|:| -3616 (-739 |#1| (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 |#1| (-572)))) (-638 (-469))) (-1170)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL)) (-1318 (((-572) $) NIL) (((-413 (-572)) $) NIL)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-4184 (($) 18)) (-3893 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-4081 (((-385) $) 22) (((-217) $) 25) (((-413 (-1166 (-572))) $) 19) (((-545) $) 52)) (-3972 (((-856) $) 50) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (((-217) $) 24) (((-385) $) 21)) (-2140 (((-769)) NIL)) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 36 T CONST)) (-3255 (($) 11 T CONST)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL))) 
-(((-493) (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))) (-1028) (-612 (-217)) (-612 (-385)) (-613 (-413 (-1166 (-572)))) (-613 (-545)) (-10 -8 (-15 -4184 ($))))) (T -493)) 
-((-4184 (*1 *1) (-5 *1 (-493)))) 
-(-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))) (-1028) (-612 (-217)) (-612 (-385)) (-613 (-413 (-1166 (-572)))) (-613 (-545)) (-10 -8 (-15 -4184 ($)))) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2430 (((-1264) $ |#1| |#1|) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#2| $ |#1| |#2|) 16)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 |#2| "failed") |#1| $) 20)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) 18)) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) NIL)) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 ((|#1| $) NIL (|has| |#1| (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 ((|#1| $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2760 (((-638 |#1|) $) 13)) (-2365 (((-121) |#1| $) NIL)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2739 (((-638 |#1|) $) NIL)) (-1601 (((-121) |#1| $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-1837 ((|#2| $) NIL (|has| |#1| (-848)))) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 19)) (-3277 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 11 (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-4032 (((-769) $) 15 (|has| $ (-6 -4602))))) 
-(((-494 |#1| |#2| |#3|) (-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602))) (-1098) (-1098) (-1152)) (T -494)) 
-NIL 
-(-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602))) 
-((-4505 (((-572) (-572) (-572)) 7)) (-2897 (((-121) (-572) (-572) (-572) (-572)) 11)) (-2516 (((-1259 (-638 (-572))) (-769) (-769)) 22))) 
-(((-495) (-10 -7 (-15 -4505 ((-572) (-572) (-572))) (-15 -2897 ((-121) (-572) (-572) (-572) (-572))) (-15 -2516 ((-1259 (-638 (-572))) (-769) (-769))))) (T -495)) 
-((-2516 (*1 *2 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1259 (-638 (-572)))) (-5 *1 (-495)))) (-2897 (*1 *2 *3 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *2 (-121)) (-5 *1 (-495)))) (-4505 (*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-495))))) 
-(-10 -7 (-15 -4505 ((-572) (-572) (-572))) (-15 -2897 ((-121) (-572) (-572) (-572) (-572))) (-15 -2516 ((-1259 (-638 (-572))) (-769) (-769)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-858 |#1|)) $) NIL)) (-4297 (((-1166 $) $ (-858 |#1|)) NIL) (((-1166 |#2|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#2| (-562)))) (-3946 (($ $) NIL (|has| |#2| (-562)))) (-3686 (((-121) $) NIL (|has| |#2| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-858 |#1|))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2844 (($ $) NIL (|has| |#2| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#2| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-858 |#1|) "failed") $) NIL)) (-1318 ((|#2| $) NIL) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-858 |#1|) $) NIL)) (-3190 (($ $ $ (-858 |#1|)) NIL (|has| |#2| (-174)))) (-3814 (($ $ (-638 (-572))) NIL)) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#2| (-457))) (($ $ (-858 |#1|)) NIL (|has| |#2| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#2| (-910)))) (-3977 (($ $ |#2| (-497 (-4032 |#1|) (-769)) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-858 |#1|) (-887 (-385))) (|has| |#2| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-858 |#1|) (-887 (-572))) (|has| |#2| (-887 (-572)))))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-4335 (($ (-1166 |#2|) (-858 |#1|)) NIL) (($ (-1166 $) (-858 |#1|)) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#2| (-497 (-4032 |#1|) (-769))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-858 |#1|)) NIL)) (-1784 (((-497 (-4032 |#1|) (-769)) $) NIL) (((-769) $ (-858 |#1|)) NIL) (((-638 (-769)) $ (-638 (-858 |#1|))) NIL)) (-1771 (($ $ $) NIL (|has| |#2| (-848)))) (-4238 (($ $ $) NIL (|has| |#2| (-848)))) (-3918 (($ (-1 (-497 (-4032 |#1|) (-769)) (-497 (-4032 |#1|) (-769))) $) NIL)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-1470 (((-3 (-858 |#1|) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#2| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-1658 (((-1152) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-858 |#1|)) (|:| -3751 (-769))) "failed") $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#2| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#2| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#2| (-910)))) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-858 |#1|) |#2|) NIL) (($ $ (-638 (-858 |#1|)) (-638 |#2|)) NIL) (($ $ (-858 |#1|) $) NIL) (($ $ (-638 (-858 |#1|)) (-638 $)) NIL)) (-2119 (($ $ (-858 |#1|)) NIL (|has| |#2| (-174)))) (-3139 (($ $ (-858 |#1|)) NIL) (($ $ (-638 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-4316 (((-497 (-4032 |#1|) (-769)) $) NIL) (((-769) $ (-858 |#1|)) NIL) (((-638 (-769)) $ (-638 (-858 |#1|))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-858 |#1|) (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-858 |#1|) (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-858 |#1|) (-613 (-545))) (|has| |#2| (-613 (-545)))))) (-3694 ((|#2| $) NIL (|has| |#2| (-457))) (($ $ (-858 |#1|)) NIL (|has| |#2| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#2| (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) NIL) (($ (-858 |#1|)) NIL) (($ (-413 (-572))) NIL (-1841 (|has| |#2| (-43 (-413 (-572)))) (|has| |#2| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#2| (-562)))) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-497 (-4032 |#1|) (-769))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#2| (-910))) (|has| |#2| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#2| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#2| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-858 |#1|)) NIL) (($ $ (-638 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-1349 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#2| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#2| (-43 (-413 (-572))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-496 |#1| |#2|) (-13 (-956 |#2| (-497 (-4032 |#1|) (-769)) (-858 |#1|)) (-10 -8 (-15 -3814 ($ $ (-638 (-572)))))) (-638 (-1170)) (-1054)) (T -496)) 
-((-3814 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-496 *3 *4)) (-14 *3 (-638 (-1170))) (-4 *4 (-1054))))) 
-(-13 (-956 |#2| (-497 (-4032 |#1|) (-769)) (-858 |#1|)) (-10 -8 (-15 -3814 ($ $ (-638 (-572)))))) 
-((-2262 (((-121) $ $) NIL (|has| |#2| (-1098)))) (-1342 (((-121) $) NIL (|has| |#2| (-138)))) (-3421 (($ (-923)) NIL (|has| |#2| (-1054)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-1614 (($ $ $) NIL (|has| |#2| (-794)))) (-1572 (((-3 $ "failed") $ $) NIL (|has| |#2| (-138)))) (-1946 (((-121) $ (-769)) NIL)) (-1685 (((-769)) NIL (|has| |#2| (-374)))) (-2433 (((-572) $) NIL (|has| |#2| (-846)))) (-3283 ((|#2| $ (-572) |#2|) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) (((-3 |#2| "failed") $) NIL (|has| |#2| (-1098)))) (-1318 (((-572) $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098)))) (((-413 (-572)) $) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) ((|#2| $) NIL (|has| |#2| (-1098)))) (-2284 (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL (|has| |#2| (-1054))) (((-685 |#2|) (-685 $)) NIL (|has| |#2| (-1054)))) (-1799 (((-3 $ "failed") $) NIL (|has| |#2| (-722)))) (-3286 (($) NIL (|has| |#2| (-374)))) (-3037 ((|#2| $ (-572) |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ (-572)) 11)) (-1908 (((-121) $) NIL (|has| |#2| (-846)))) (-2010 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3893 (((-121) $) NIL (|has| |#2| (-722)))) (-4472 (((-121) $) NIL (|has| |#2| (-846)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-4467 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-2435 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-3633 (((-923) $) NIL (|has| |#2| (-374)))) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#2| (-1098)))) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-1763 (($ (-923)) NIL (|has| |#2| (-374)))) (-2607 (((-1116) $) NIL (|has| |#2| (-1098)))) (-1837 ((|#2| $) NIL (|has| (-572) (-848)))) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3587 (((-638 $)) NIL (|has| |#2| (-374)))) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ (-572) |#2|) NIL) ((|#2| $ (-572)) NIL)) (-1436 ((|#2| $ $) NIL (|has| |#2| (-1054)))) (-4315 (($ (-1259 |#2|)) NIL)) (-2502 (((-140)) NIL (|has| |#2| (-368)))) (-3139 (($ $) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1 |#2| |#2|) (-769)) NIL (|has| |#2| (-1054))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1054)))) (-1571 (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-1259 |#2|) $) NIL) (((-856) $) NIL (|has| |#2| (-1098))) (($ (-572)) NIL (-1841 (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098))) (|has| |#2| (-1054)))) (($ (-413 (-572))) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) (($ |#2|) NIL (|has| |#2| (-1098)))) (-2140 (((-769)) NIL (|has| |#2| (-1054)))) (-3501 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-2264 (($ $) NIL (|has| |#2| (-846)))) (-4174 (($ $ (-769)) NIL (|has| |#2| (-722))) (($ $ (-923)) NIL (|has| |#2| (-722)))) (-2378 (($) NIL (|has| |#2| (-138)) CONST)) (-3255 (($) NIL (|has| |#2| (-722)) CONST)) (-1557 (($ $) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1 |#2| |#2|) (-769)) NIL (|has| |#2| (-1054))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1054)))) (-1349 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1338 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1324 (((-121) $ $) NIL (|has| |#2| (-1098)))) (-1343 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1334 (((-121) $ $) 15 (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $ $) NIL (|has| |#2| (-1054))) (($ $) NIL (|has| |#2| (-1054)))) (-1367 (($ $ $) NIL (|has| |#2| (-25)))) (** (($ $ (-769)) NIL (|has| |#2| (-722))) (($ $ (-923)) NIL (|has| |#2| (-722)))) (* (($ (-572) $) NIL (|has| |#2| (-1054))) (($ $ $) NIL (|has| |#2| (-722))) (($ $ |#2|) NIL (|has| |#2| (-722))) (($ |#2| $) NIL (|has| |#2| (-722))) (($ (-769) $) NIL (|has| |#2| (-138))) (($ (-923) $) NIL (|has| |#2| (-25)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-497 |#1| |#2|) (-232 |#1| |#2|) (-769) (-794)) (T -497)) 
-NIL 
-(-232 |#1| |#2|) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) NIL)) (-2211 (($) NIL T CONST)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3279 (($ $ $) 32)) (-4475 (($ $ $) 31)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-4238 ((|#1| $) 26)) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-4221 ((|#1| $) 27)) (-1335 (($ |#1| $) 10)) (-1543 (($ (-638 |#1|)) 12)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2232 ((|#1| $) 23)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 9)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 29)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) 21 (|has| $ (-6 -4602))))) 
-(((-498 |#1|) (-13 (-976 |#1|) (-10 -8 (-15 -1543 ($ (-638 |#1|))) (-15 -3058 ($ (-638 |#1|))) (-15 -1607 ($ $)) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -3598 ((-121) $ $)) (-15 -2232 (|#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (-15 -4238 (|#1| $)) (-15 -4475 ($ $ $)) (-15 -3279 ($ $ $)) (-15 -2211 ($)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) (-848)) (T -498)) 
-((-3598 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) (-1607 (*1 *1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-1665 (*1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-4037 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) (-3524 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-498 *4)) (-4 *4 (-848)))) (-2157 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-498 *4)) (-4 *4 (-848)))) (-1946 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-498 *4)) (-4 *4 (-848)))) (-2211 (*1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-4032 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-848)) (-5 *1 (-498 *3)))) (-2435 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-848)) (-5 *1 (-498 *3)))) (-3501 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-848)) (-5 *2 (-121)) (-5 *1 (-498 *4)))) (-2109 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-848)) (-5 *2 (-121)) (-5 *1 (-498 *4)))) (-1571 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-848)) (-5 *2 (-769)) (-5 *1 (-498 *4)))) (-2010 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) (-1571 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) (-3002 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) (-1658 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) (-2607 (*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) (-1324 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) (-2262 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) (-3058 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-498 *3)))) (-2232 (*1 *2 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-1335 (*1 *1 *2 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-4221 (*1 *2 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-4238 (*1 *2 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-4475 (*1 *1 *1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-3279 (*1 *1 *1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) (-1543 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-498 *3))))) 
-(-13 (-976 |#1|) (-10 -8 (-15 -1543 ($ (-638 |#1|))) (-15 -3058 ($ (-638 |#1|))) (-15 -1607 ($ $)) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -3598 ((-121) $ $)) (-15 -2232 (|#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (-15 -4238 (|#1| $)) (-15 -4475 ($ $ $)) (-15 -3279 ($ $ $)) (-15 -2211 ($)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3116 (($ $) 69)) (-2422 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-1730 (((-419 |#2| (-413 |#2|) |#3| |#4|) $) 43)) (-2607 (((-1116) $) NIL)) (-2307 (((-3 |#4| "failed") $) 105)) (-3873 (($ (-419 |#2| (-413 |#2|) |#3| |#4|)) 76) (($ |#4|) 32) (($ |#1| |#1|) 113) (($ |#1| |#1| (-572)) NIL) (($ |#4| |#2| |#2| |#2| |#1|) 125)) (-2880 (((-2 (|:| -4004 (-419 |#2| (-413 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 45)) (-3972 (((-856) $) 100)) (-2378 (($) 33 T CONST)) (-1324 (((-121) $ $) 107)) (-1373 (($ $) 72) (($ $ $) NIL)) (-1367 (($ $ $) 70)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 73))) 
-(((-499 |#1| |#2| |#3| |#4|) (-335 |#1| |#2| |#3| |#4|) (-368) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|)) (T -499)) 
-NIL 
-(-335 |#1| |#2| |#3| |#4|) 
-((-3235 (((-572) (-638 (-572))) 28)) (-4524 ((|#1| (-638 |#1|)) 56)) (-4400 (((-638 |#1|) (-638 |#1|)) 57)) (-1976 (((-638 |#1|) (-638 |#1|)) 59)) (-3069 ((|#1| (-638 |#1|)) 58)) (-3694 (((-638 (-572)) (-638 |#1|)) 31))) 
-(((-500 |#1|) (-10 -7 (-15 -3069 (|#1| (-638 |#1|))) (-15 -4524 (|#1| (-638 |#1|))) (-15 -1976 ((-638 |#1|) (-638 |#1|))) (-15 -4400 ((-638 |#1|) (-638 |#1|))) (-15 -3694 ((-638 (-572)) (-638 |#1|))) (-15 -3235 ((-572) (-638 (-572))))) (-1234 (-572))) (T -500)) 
-((-3235 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-572)) (-5 *1 (-500 *4)) (-4 *4 (-1234 *2)))) (-3694 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1234 (-572))) (-5 *2 (-638 (-572))) (-5 *1 (-500 *4)))) (-4400 (*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1234 (-572))) (-5 *1 (-500 *3)))) (-1976 (*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1234 (-572))) (-5 *1 (-500 *3)))) (-4524 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-5 *1 (-500 *2)) (-4 *2 (-1234 (-572))))) (-3069 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-5 *1 (-500 *2)) (-4 *2 (-1234 (-572)))))) 
-(-10 -7 (-15 -3069 (|#1| (-638 |#1|))) (-15 -4524 (|#1| (-638 |#1|))) (-15 -1976 ((-638 |#1|) (-638 |#1|))) (-15 -4400 ((-638 |#1|) (-638 |#1|))) (-15 -3694 ((-638 (-572)) (-638 |#1|))) (-15 -3235 ((-572) (-638 (-572))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 (((-572) $) NIL (|has| (-572) (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| (-572) (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL (|has| (-572) (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-572) (-1044 (-572)))) (((-3 (-572) "failed") $) NIL (|has| (-572) (-1044 (-572))))) (-1318 (((-572) $) NIL) (((-1170) $) NIL (|has| (-572) (-1044 (-1170)))) (((-413 (-572)) $) NIL (|has| (-572) (-1044 (-572)))) (((-572) $) NIL (|has| (-572) (-1044 (-572))))) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-572) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-572) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-685 (-572)) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-572) (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) NIL (|has| (-572) (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| (-572) (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| (-572) (-887 (-385))))) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL)) (-4487 (((-572) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| (-572) (-1144)))) (-4472 (((-121) $) NIL (|has| (-572) (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-572) (-848)))) (-3828 (($ (-1 (-572) (-572)) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-572) (-1144)) CONST)) (-1635 (($ (-413 (-572))) 8)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| (-572) (-303))) (((-413 (-572)) $) NIL)) (-1716 (((-572) $) NIL (|has| (-572) (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 (-572)) (-638 (-572))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-572) (-572)) NIL (|has| (-572) (-305 (-572)))) (($ $ (-290 (-572))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-638 (-290 (-572)))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-638 (-1170)) (-638 (-572))) NIL (|has| (-572) (-527 (-1170) (-572)))) (($ $ (-1170) (-572)) NIL (|has| (-572) (-527 (-1170) (-572))))) (-4029 (((-769) $) NIL)) (-3277 (($ $ (-572)) NIL (|has| (-572) (-283 (-572) (-572))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL (|has| (-572) (-227))) (($ $ (-769)) NIL (|has| (-572) (-227))) (($ $ (-1170)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1 (-572) (-572)) (-769)) NIL) (($ $ (-1 (-572) (-572))) NIL)) (-3425 (($ $) NIL)) (-4492 (((-572) $) NIL)) (-4081 (((-893 (-572)) $) NIL (|has| (-572) (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| (-572) (-613 (-893 (-385))))) (((-545) $) NIL (|has| (-572) (-613 (-545)))) (((-385) $) NIL (|has| (-572) (-1028))) (((-217) $) NIL (|has| (-572) (-1028)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-572) (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) 7) (($ (-572)) NIL) (($ (-1170)) NIL (|has| (-572) (-1044 (-1170)))) (((-413 (-572)) $) NIL) (((-1011 16) $) 9)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-572) (-910))) (|has| (-572) (-149))))) (-2140 (((-769)) NIL)) (-2634 (((-572) $) NIL (|has| (-572) (-554)))) (-3774 (((-121) $ $) NIL)) (-2264 (($ $) NIL (|has| (-572) (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $) NIL (|has| (-572) (-227))) (($ $ (-769)) NIL (|has| (-572) (-227))) (($ $ (-1170)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1 (-572) (-572)) (-769)) NIL) (($ $ (-1 (-572) (-572))) NIL)) (-1349 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1379 (($ $ $) NIL) (($ (-572) (-572)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ (-572) $) NIL) (($ $ (-572)) NIL))) 
-(((-501) (-13 (-1000 (-572)) (-10 -8 (-15 -3972 ((-413 (-572)) $)) (-15 -3972 ((-1011 16) $)) (-15 -3346 ((-413 (-572)) $)) (-15 -1635 ($ (-413 (-572))))))) (T -501)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-501)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1011 16)) (-5 *1 (-501)))) (-3346 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-501)))) (-1635 (*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-501))))) 
-(-13 (-1000 (-572)) (-10 -8 (-15 -3972 ((-413 (-572)) $)) (-15 -3972 ((-1011 16) $)) (-15 -3346 ((-413 (-572)) $)) (-15 -1635 ($ (-413 (-572)))))) 
-((-4467 (((-638 |#2|) $) 22)) (-3002 (((-121) |#2| $) 27)) (-2109 (((-121) (-1 (-121) |#2|) $) 20)) (-4485 (($ $ (-638 (-290 |#2|))) 12) (($ $ (-290 |#2|)) NIL) (($ $ |#2| |#2|) NIL) (($ $ (-638 |#2|) (-638 |#2|)) NIL)) (-1571 (((-769) (-1 (-121) |#2|) $) 21) (((-769) |#2| $) 25)) (-3972 (((-856) $) 36)) (-3501 (((-121) (-1 (-121) |#2|) $) 19)) (-1324 (((-121) $ $) 30)) (-4032 (((-769) $) 16))) 
-(((-502 |#1| |#2|) (-10 -8 (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -4485 (|#1| |#1| (-638 |#2|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#2| |#2|)) (-15 -4485 (|#1| |#1| (-290 |#2|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#2|)))) (-15 -3002 ((-121) |#2| |#1|)) (-15 -1571 ((-769) |#2| |#1|)) (-15 -4467 ((-638 |#2|) |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -4032 ((-769) |#1|))) (-503 |#2|) (-1204)) (T -502)) 
-NIL 
-(-10 -8 (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -4485 (|#1| |#1| (-638 |#2|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#2| |#2|)) (-15 -4485 (|#1| |#1| (-290 |#2|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#2|)))) (-15 -3002 ((-121) |#2| |#1|)) (-15 -1571 ((-769) |#2| |#1|)) (-15 -4467 ((-638 |#2|) |#1|)) (-15 -1571 ((-769) (-1 (-121) |#2|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -4032 ((-769) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-2211 (($) 7 T CONST)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-503 |#1|) (-1290) (-1204)) (T -503)) 
-((-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-503 *3)) (-4 *3 (-1204)))) (-2435 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| *1 (-6 -4603)) (-4 *1 (-503 *3)) (-4 *3 (-1204)))) (-3501 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4602)) (-4 *1 (-503 *4)) (-4 *4 (-1204)) (-5 *2 (-121)))) (-2109 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4602)) (-4 *1 (-503 *4)) (-4 *4 (-1204)) (-5 *2 (-121)))) (-1571 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4602)) (-4 *1 (-503 *4)) (-4 *4 (-1204)) (-5 *2 (-769)))) (-2010 (*1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-503 *3)) (-4 *3 (-1204)) (-5 *2 (-638 *3)))) (-4467 (*1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-503 *3)) (-4 *3 (-1204)) (-5 *2 (-638 *3)))) (-1571 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-503 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-769)))) (-3002 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-503 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-121))))) 
-(-13 (-39) (-10 -8 (IF (|has| |t#1| (-1098)) (-6 (-1098)) |noBranch|) (IF (|has| |t#1| (-1098)) (IF (|has| |t#1| (-305 |t#1|)) (-6 (-305 |t#1|)) |noBranch|) |noBranch|) (-15 -3828 ($ (-1 |t#1| |t#1|) $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |t#1| |t#1|) $)) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -3501 ((-121) (-1 (-121) |t#1|) $)) (-15 -2109 ((-121) (-1 (-121) |t#1|) $)) (-15 -1571 ((-769) (-1 (-121) |t#1|) $)) (-15 -2010 ((-638 |t#1|) $)) (-15 -4467 ((-638 |t#1|) $)) (IF (|has| |t#1| (-1098)) (PROGN (-15 -1571 ((-769) |t#1| $)) (-15 -3002 ((-121) |t#1| $))) |noBranch|)) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1438 (((-1152) (-856)) 40)) (-2415 (((-1264) (-1152)) 29)) (-3956 (((-1152) (-856)) 25)) (-2093 (((-1152) (-856)) 26)) (-3972 (((-856) $) NIL) (((-1152) (-856)) 24)) (-1324 (((-121) $ $) NIL))) 
-(((-504) (-13 (-1098) (-10 -7 (-15 -3972 ((-1152) (-856))) (-15 -3956 ((-1152) (-856))) (-15 -2093 ((-1152) (-856))) (-15 -1438 ((-1152) (-856))) (-15 -2415 ((-1264) (-1152)))))) (T -504)) 
-((-3972 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-504)))) (-3956 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-504)))) (-2093 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-504)))) (-1438 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-504)))) (-2415 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-504))))) 
-(-13 (-1098) (-10 -7 (-15 -3972 ((-1152) (-856))) (-15 -3956 ((-1152) (-856))) (-15 -2093 ((-1152) (-856))) (-15 -1438 ((-1152) (-856))) (-15 -2415 ((-1264) (-1152))))) 
-((-4284 (($ $) 15)) (-4273 (($ $) 24)) (-4295 (($ $) 12)) (-4302 (($ $) 10)) (-4289 (($ $) 17)) (-4278 (($ $) 22))) 
-(((-505 |#1|) (-10 -8 (-15 -4278 (|#1| |#1|)) (-15 -4289 (|#1| |#1|)) (-15 -4302 (|#1| |#1|)) (-15 -4295 (|#1| |#1|)) (-15 -4273 (|#1| |#1|)) (-15 -4284 (|#1| |#1|))) (-506)) (T -505)) 
-NIL 
-(-10 -8 (-15 -4278 (|#1| |#1|)) (-15 -4289 (|#1| |#1|)) (-15 -4302 (|#1| |#1|)) (-15 -4295 (|#1| |#1|)) (-15 -4273 (|#1| |#1|)) (-15 -4284 (|#1| |#1|))) 
-((-4284 (($ $) 11)) (-4273 (($ $) 10)) (-4295 (($ $) 9)) (-4302 (($ $) 8)) (-4289 (($ $) 7)) (-4278 (($ $) 6))) 
-(((-506) (-1290)) (T -506)) 
-((-4284 (*1 *1 *1) (-4 *1 (-506))) (-4273 (*1 *1 *1) (-4 *1 (-506))) (-4295 (*1 *1 *1) (-4 *1 (-506))) (-4302 (*1 *1 *1) (-4 *1 (-506))) (-4289 (*1 *1 *1) (-4 *1 (-506))) (-4278 (*1 *1 *1) (-4 *1 (-506)))) 
-(-13 (-10 -8 (-15 -4278 ($ $)) (-15 -4289 ($ $)) (-15 -4302 ($ $)) (-15 -4295 ($ $)) (-15 -4273 ($ $)) (-15 -4284 ($ $)))) 
-((-4304 (((-424 |#4|) |#4| (-1 (-424 |#2|) |#2|)) 42))) 
-(((-507 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4304 ((-424 |#4|) |#4| (-1 (-424 |#2|) |#2|)))) (-368) (-1234 |#1|) (-13 (-368) (-151) (-720 |#1| |#2|)) (-1234 |#3|)) (T -507)) 
-((-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-4 *7 (-13 (-368) (-151) (-720 *5 *6))) (-5 *2 (-424 *3)) (-5 *1 (-507 *5 *6 *7 *3)) (-4 *3 (-1234 *7))))) 
-(-10 -7 (-15 -4304 ((-424 |#4|) |#4| (-1 (-424 |#2|) |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-1770 (((-638 $) (-1166 $) (-1170)) NIL) (((-638 $) (-1166 $)) NIL) (((-638 $) (-959 $)) NIL)) (-1627 (($ (-1166 $) (-1170)) NIL) (($ (-1166 $)) NIL) (($ (-959 $)) NIL)) (-1342 (((-121) $) 36)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1575 (((-121) $ $) 62)) (-1337 (((-638 (-611 $)) $) 46)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1952 (($ $ (-290 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4190 (($ $) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-3584 (((-638 $) (-1166 $) (-1170)) NIL) (((-638 $) (-1166 $)) NIL) (((-638 $) (-959 $)) NIL)) (-3733 (($ (-1166 $) (-1170)) NIL) (($ (-1166 $)) NIL) (($ (-959 $)) NIL)) (-3376 (((-3 (-611 $) "failed") $) NIL) (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL)) (-1318 (((-611 $) $) NIL) (((-572) $) NIL) (((-413 (-572)) $) 48)) (-2190 (($ $ $) NIL)) (-2284 (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-685 (-572)) (-685 $)) NIL) (((-2 (|:| -1369 (-685 (-413 (-572)))) (|:| |vec| (-1259 (-413 (-572))))) (-685 $) (-1259 $)) NIL) (((-685 (-413 (-572))) (-685 $)) NIL)) (-3116 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-3567 (($ $) NIL) (($ (-638 $)) NIL)) (-4091 (((-638 (-123)) $) NIL)) (-4564 (((-123) (-123)) NIL)) (-3893 (((-121) $) 39)) (-4240 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4487 (((-1121 (-572) (-611 $)) $) 34)) (-1451 (($ $ (-572)) NIL)) (-4429 (((-1166 $) (-1166 $) (-611 $)) 77) (((-1166 $) (-1166 $) (-638 (-611 $))) 53) (($ $ (-611 $)) 66) (($ $ (-638 (-611 $))) 67)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4127 (((-1166 $) (-611 $)) 64 (|has| $ (-1054)))) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 $ $) (-611 $)) NIL)) (-3614 (((-3 (-611 $) "failed") $) NIL)) (-1629 (($ (-638 $)) NIL) (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-4291 (((-638 (-611 $)) $) NIL)) (-4496 (($ (-123) $) NIL) (($ (-123) (-638 $)) NIL)) (-3291 (((-121) $ (-123)) NIL) (((-121) $ (-1170)) NIL)) (-4350 (($ $) NIL)) (-1455 (((-769) $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ (-638 $)) NIL) (($ $ $) NIL)) (-4319 (((-121) $ $) NIL) (((-121) $ (-1170)) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4247 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4485 (($ $ (-611 $) $) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-1170) (-1 $ (-638 $))) NIL) (($ $ (-1170) (-1 $ $)) NIL) (($ $ (-638 (-123)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-123) (-1 $ (-638 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-4029 (((-769) $) NIL)) (-3277 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-638 $)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-2759 (($ $) NIL) (($ $ $) NIL)) (-3139 (($ $ (-769)) NIL) (($ $) 33)) (-4492 (((-1121 (-572) (-611 $)) $) 17)) (-2830 (($ $) NIL (|has| $ (-1054)))) (-4081 (((-385) $) 91) (((-217) $) 99) (((-171 (-385)) $) 107)) (-3972 (((-856) $) NIL) (($ (-611 $)) NIL) (($ (-413 (-572))) NIL) (($ $) NIL) (($ (-572)) NIL) (($ (-1121 (-572) (-611 $))) 18)) (-2140 (((-769)) NIL)) (-3497 (($ $) NIL) (($ (-638 $)) NIL)) (-3228 (((-121) (-123)) 83)) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-572)) NIL) (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (-2378 (($) 9 T CONST)) (-3255 (($) 19 T CONST)) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 21)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1379 (($ $ $) 41)) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-413 (-572))) NIL) (($ $ (-572)) 44) (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (* (($ (-413 (-572)) $) NIL) (($ $ (-413 (-572))) NIL) (($ $ $) 24) (($ (-572) $) NIL) (($ (-769) $) NIL) (($ (-923) $) NIL))) 
-(((-508) (-13 (-298) (-27) (-1044 (-572)) (-1044 (-413 (-572))) (-634 (-572)) (-1028) (-634 (-413 (-572))) (-151) (-613 (-171 (-385))) (-227) (-10 -8 (-15 -3972 ($ (-1121 (-572) (-611 $)))) (-15 -4487 ((-1121 (-572) (-611 $)) $)) (-15 -4492 ((-1121 (-572) (-611 $)) $)) (-15 -3116 ($ $)) (-15 -1575 ((-121) $ $)) (-15 -4429 ((-1166 $) (-1166 $) (-611 $))) (-15 -4429 ((-1166 $) (-1166 $) (-638 (-611 $)))) (-15 -4429 ($ $ (-611 $))) (-15 -4429 ($ $ (-638 (-611 $))))))) (T -508)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1121 (-572) (-611 (-508)))) (-5 *1 (-508)))) (-4487 (*1 *2 *1) (-12 (-5 *2 (-1121 (-572) (-611 (-508)))) (-5 *1 (-508)))) (-4492 (*1 *2 *1) (-12 (-5 *2 (-1121 (-572) (-611 (-508)))) (-5 *1 (-508)))) (-3116 (*1 *1 *1) (-5 *1 (-508))) (-1575 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-508)))) (-4429 (*1 *2 *2 *3) (-12 (-5 *2 (-1166 (-508))) (-5 *3 (-611 (-508))) (-5 *1 (-508)))) (-4429 (*1 *2 *2 *3) (-12 (-5 *2 (-1166 (-508))) (-5 *3 (-638 (-611 (-508)))) (-5 *1 (-508)))) (-4429 (*1 *1 *1 *2) (-12 (-5 *2 (-611 (-508))) (-5 *1 (-508)))) (-4429 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-611 (-508)))) (-5 *1 (-508))))) 
-(-13 (-298) (-27) (-1044 (-572)) (-1044 (-413 (-572))) (-634 (-572)) (-1028) (-634 (-413 (-572))) (-151) (-613 (-171 (-385))) (-227) (-10 -8 (-15 -3972 ($ (-1121 (-572) (-611 $)))) (-15 -4487 ((-1121 (-572) (-611 $)) $)) (-15 -4492 ((-1121 (-572) (-611 $)) $)) (-15 -3116 ($ $)) (-15 -1575 ((-121) $ $)) (-15 -4429 ((-1166 $) (-1166 $) (-611 $))) (-15 -4429 ((-1166 $) (-1166 $) (-638 (-611 $)))) (-15 -4429 ($ $ (-611 $))) (-15 -4429 ($ $ (-638 (-611 $)))))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) |#1|) 25 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) 22 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 21)) (-4014 (((-572) (-1 (-121) |#1|) $) NIL) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098)))) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) |#1|) 14)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 12 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) 23 (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 16 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 17) (($ (-1 |#1| |#1| |#1|) $ $) 19)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) NIL (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) 10 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 13)) (-3277 ((|#1| $ (-572) |#1|) NIL) ((|#1| $ (-572)) 24) (($ $ (-1225 (-572))) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-4500 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-4032 (((-769) $) 9 (|has| $ (-6 -4602))))) 
-(((-509 |#1| |#2|) (-19 |#1|) (-1204) (-572)) (T -509)) 
+((-4546 (($ $) 6)) (-1430 (($ $) 7)) (** (($ $ $) 8))) 
+(((-301) (-1311)) (T -301)) 
+((** (*1 *1 *1 *1) (-4 *1 (-301))) (-1430 (*1 *1 *1) (-4 *1 (-301))) (-4546 (*1 *1 *1) (-4 *1 (-301)))) 
+(-13 (-10 -8 (-15 -4546 ($ $)) (-15 -1430 ($ $)) (-15 ** ($ $ $)))) 
+((-4268 (((-658 (-1171 |#1|)) (-1171 |#1|) |#1|) 35)) (-4305 ((|#2| |#2| |#1|) 38)) (-2383 ((|#2| |#2| |#1|) 40)) (-2878 ((|#2| |#2| |#1|) 39))) 
+(((-302 |#1| |#2|) (-10 -7 (-15 -4305 (|#2| |#2| |#1|)) (-15 -2878 (|#2| |#2| |#1|)) (-15 -2383 (|#2| |#2| |#1|)) (-15 -4268 ((-658 (-1171 |#1|)) (-1171 |#1|) |#1|))) (-388) (-1270 |#1|)) (T -302)) 
+((-4268 (*1 *2 *3 *4) (-12 (-4 *4 (-388)) (-5 *2 (-658 (-1171 *4))) (-5 *1 (-302 *4 *5)) (-5 *3 (-1171 *4)) (-4 *5 (-1270 *4)))) (-2383 (*1 *2 *2 *3) (-12 (-4 *3 (-388)) (-5 *1 (-302 *3 *2)) (-4 *2 (-1270 *3)))) (-2878 (*1 *2 *2 *3) (-12 (-4 *3 (-388)) (-5 *1 (-302 *3 *2)) (-4 *2 (-1270 *3)))) (-4305 (*1 *2 *2 *3) (-12 (-4 *3 (-388)) (-5 *1 (-302 *3 *2)) (-4 *2 (-1270 *3))))) 
+(-10 -7 (-15 -4305 (|#2| |#2| |#1|)) (-15 -2878 (|#2| |#2| |#1|)) (-15 -2383 (|#2| |#2| |#1|)) (-15 -4268 ((-658 (-1171 |#1|)) (-1171 |#1|) |#1|))) 
+((-3927 ((|#2| $ |#1|) 6))) 
+(((-303 |#1| |#2|) (-1311) (-1119) (-1225)) (T -303)) 
+((-3927 (*1 *2 *1 *3) (-12 (-4 *1 (-303 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225))))) 
+(-13 (-10 -8 (-15 -3927 (|t#2| $ |t#1|)))) 
+((-1426 ((|#3| $ |#2| |#3|) 12)) (-3959 ((|#3| $ |#2|) 10))) 
+(((-304 |#1| |#2| |#3|) (-10 -8 (-15 -1426 (|#3| |#1| |#2| |#3|)) (-15 -3959 (|#3| |#1| |#2|))) (-305 |#2| |#3|) (-1119) (-1225)) (T -304)) 
+NIL 
+(-10 -8 (-15 -1426 (|#3| |#1| |#2| |#3|)) (-15 -3959 (|#3| |#1| |#2|))) 
+((-3932 ((|#2| $ |#1| |#2|) 8 (|has| $ (-6 -4626)))) (-1426 ((|#2| $ |#1| |#2|) 7 (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) 9)) (-3927 ((|#2| $ |#1|) 6) ((|#2| $ |#1| |#2|) 10))) 
+(((-305 |#1| |#2|) (-1311) (-1119) (-1225)) (T -305)) 
+((-3927 (*1 *2 *1 *3 *2) (-12 (-4 *1 (-305 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225)))) (-3959 (*1 *2 *1 *3) (-12 (-4 *1 (-305 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225)))) (-3932 (*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-305 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225)))) (-1426 (*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-305 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225))))) 
+(-13 (-303 |t#1| |t#2|) (-10 -8 (-15 -3927 (|t#2| $ |t#1| |t#2|)) (-15 -3959 (|t#2| $ |t#1|)) (IF (|has| $ (-6 -4626)) (PROGN (-15 -3932 (|t#2| $ |t#1| |t#2|)) (-15 -1426 (|t#2| $ |t#1| |t#2|))) |noBranch|))) 
+(((-303 |#1| |#2|) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 34)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 39)) (-1555 (($ $) 37)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-1586 (($ $ $) 32)) (-3657 (($ |#2| |#3|) 19)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-3558 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1704 ((|#3| $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 20)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2314 (((-3 $ "failed") $ $) NIL)) (-2769 (((-790) $) 33)) (-3927 ((|#2| $ |#2|) 41)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 24)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) ((|#2| $) NIL)) (-4010 (((-790)) NIL)) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 27 T CONST)) (-4257 (($) 35 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 36))) 
+(((-306 |#1| |#2| |#3| |#4| |#5| |#6|) (-13 (-323) (-10 -8 (-15 -1704 (|#3| $)) (-15 -1683 (|#2| $)) (-15 -3657 ($ |#2| |#3|)) (-15 -2314 ((-3 $ "failed") $ $)) (-15 -3371 ((-3 $ "failed") $)) (-15 -4552 ($ $)) (-15 -3927 (|#2| $ |#2|)))) (-194) (-1255 |#1|) (-23) (-1 |#2| |#2| |#3|) (-1 (-3 |#3| "failed") |#3| |#3|) (-1 (-3 |#2| "failed") |#2| |#2| |#3|)) (T -306)) 
+((-3371 (*1 *1 *1) (|partial| -12 (-4 *2 (-194)) (-5 *1 (-306 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1255 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-1704 (*1 *2 *1) (-12 (-4 *3 (-194)) (-4 *2 (-23)) (-5 *1 (-306 *3 *4 *2 *5 *6 *7)) (-4 *4 (-1255 *3)) (-14 *5 (-1 *4 *4 *2)) (-14 *6 (-1 (-3 *2 "failed") *2 *2)) (-14 *7 (-1 (-3 *4 "failed") *4 *4 *2)))) (-1683 (*1 *2 *1) (-12 (-4 *2 (-1255 *3)) (-5 *1 (-306 *3 *2 *4 *5 *6 *7)) (-4 *3 (-194)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) (-3657 (*1 *1 *2 *3) (-12 (-4 *4 (-194)) (-5 *1 (-306 *4 *2 *3 *5 *6 *7)) (-4 *2 (-1255 *4)) (-4 *3 (-23)) (-14 *5 (-1 *2 *2 *3)) (-14 *6 (-1 (-3 *3 "failed") *3 *3)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2314 (*1 *1 *1 *1) (|partial| -12 (-4 *2 (-194)) (-5 *1 (-306 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1255 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-4552 (*1 *1 *1) (-12 (-4 *2 (-194)) (-5 *1 (-306 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1255 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-3927 (*1 *2 *1 *2) (-12 (-4 *3 (-194)) (-5 *1 (-306 *3 *2 *4 *5 *6 *7)) (-4 *2 (-1255 *3)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4))))) 
+(-13 (-323) (-10 -8 (-15 -1704 (|#3| $)) (-15 -1683 (|#2| $)) (-15 -3657 ($ |#2| |#3|)) (-15 -2314 ((-3 $ "failed") $ $)) (-15 -3371 ((-3 $ "failed") $)) (-15 -4552 ($ $)) (-15 -3927 (|#2| $ |#2|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-307) (-1311)) (T -307)) 
+NIL 
+(-13 (-1075) (-140 $ $) (-10 -7 (-6 -4618))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-2693 (((-658 (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |geneigvec| (-658 (-706 (-433 (-980 |#1|))))))) (-706 (-433 (-980 |#1|)))) 83)) (-1820 (((-658 (-706 (-433 (-980 |#1|)))) (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 (-706 (-433 (-980 |#1|)))))) (-706 (-433 (-980 |#1|)))) 78) (((-658 (-706 (-433 (-980 |#1|)))) (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|))) (-706 (-433 (-980 |#1|))) (-790) (-790)) 36)) (-2798 (((-658 (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 (-706 (-433 (-980 |#1|))))))) (-706 (-433 (-980 |#1|)))) 80)) (-2287 (((-658 (-706 (-433 (-980 |#1|)))) (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|))) (-706 (-433 (-980 |#1|)))) 60)) (-2014 (((-658 (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (-706 (-433 (-980 |#1|)))) 59)) (-4198 (((-980 |#1|) (-706 (-433 (-980 |#1|)))) 47) (((-980 |#1|) (-706 (-433 (-980 |#1|))) (-1191)) 48))) 
+(((-308 |#1|) (-10 -7 (-15 -4198 ((-980 |#1|) (-706 (-433 (-980 |#1|))) (-1191))) (-15 -4198 ((-980 |#1|) (-706 (-433 (-980 |#1|))))) (-15 -2014 ((-658 (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (-706 (-433 (-980 |#1|))))) (-15 -2287 ((-658 (-706 (-433 (-980 |#1|)))) (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|))) (-706 (-433 (-980 |#1|))))) (-15 -1820 ((-658 (-706 (-433 (-980 |#1|)))) (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|))) (-706 (-433 (-980 |#1|))) (-790) (-790))) (-15 -1820 ((-658 (-706 (-433 (-980 |#1|)))) (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 (-706 (-433 (-980 |#1|)))))) (-706 (-433 (-980 |#1|))))) (-15 -2693 ((-658 (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |geneigvec| (-658 (-706 (-433 (-980 |#1|))))))) (-706 (-433 (-980 |#1|))))) (-15 -2798 ((-658 (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 (-706 (-433 (-980 |#1|))))))) (-706 (-433 (-980 |#1|)))))) (-477)) (T -308)) 
+((-2798 (*1 *2 *3) (-12 (-4 *4 (-477)) (-5 *2 (-658 (-2 (|:| |eigval| (-3 (-433 (-980 *4)) (-1180 (-1191) (-980 *4)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 (-706 (-433 (-980 *4)))))))) (-5 *1 (-308 *4)) (-5 *3 (-706 (-433 (-980 *4)))))) (-2693 (*1 *2 *3) (-12 (-4 *4 (-477)) (-5 *2 (-658 (-2 (|:| |eigval| (-3 (-433 (-980 *4)) (-1180 (-1191) (-980 *4)))) (|:| |geneigvec| (-658 (-706 (-433 (-980 *4)))))))) (-5 *1 (-308 *4)) (-5 *3 (-706 (-433 (-980 *4)))))) (-1820 (*1 *2 *3 *4) (-12 (-5 *3 (-2 (|:| |eigval| (-3 (-433 (-980 *5)) (-1180 (-1191) (-980 *5)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 *4)))) (-4 *5 (-477)) (-5 *2 (-658 (-706 (-433 (-980 *5))))) (-5 *1 (-308 *5)) (-5 *4 (-706 (-433 (-980 *5)))))) (-1820 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-3 (-433 (-980 *6)) (-1180 (-1191) (-980 *6)))) (-5 *5 (-790)) (-4 *6 (-477)) (-5 *2 (-658 (-706 (-433 (-980 *6))))) (-5 *1 (-308 *6)) (-5 *4 (-706 (-433 (-980 *6)))))) (-2287 (*1 *2 *3 *4) (-12 (-5 *3 (-3 (-433 (-980 *5)) (-1180 (-1191) (-980 *5)))) (-4 *5 (-477)) (-5 *2 (-658 (-706 (-433 (-980 *5))))) (-5 *1 (-308 *5)) (-5 *4 (-706 (-433 (-980 *5)))))) (-2014 (*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 *4)))) (-4 *4 (-477)) (-5 *2 (-658 (-3 (-433 (-980 *4)) (-1180 (-1191) (-980 *4))))) (-5 *1 (-308 *4)))) (-4198 (*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 *4)))) (-5 *2 (-980 *4)) (-5 *1 (-308 *4)) (-4 *4 (-477)))) (-4198 (*1 *2 *3 *4) (-12 (-5 *3 (-706 (-433 (-980 *5)))) (-5 *4 (-1191)) (-5 *2 (-980 *5)) (-5 *1 (-308 *5)) (-4 *5 (-477))))) 
+(-10 -7 (-15 -4198 ((-980 |#1|) (-706 (-433 (-980 |#1|))) (-1191))) (-15 -4198 ((-980 |#1|) (-706 (-433 (-980 |#1|))))) (-15 -2014 ((-658 (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (-706 (-433 (-980 |#1|))))) (-15 -2287 ((-658 (-706 (-433 (-980 |#1|)))) (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|))) (-706 (-433 (-980 |#1|))))) (-15 -1820 ((-658 (-706 (-433 (-980 |#1|)))) (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|))) (-706 (-433 (-980 |#1|))) (-790) (-790))) (-15 -1820 ((-658 (-706 (-433 (-980 |#1|)))) (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 (-706 (-433 (-980 |#1|)))))) (-706 (-433 (-980 |#1|))))) (-15 -2693 ((-658 (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |geneigvec| (-658 (-706 (-433 (-980 |#1|))))))) (-706 (-433 (-980 |#1|))))) (-15 -2798 ((-658 (-2 (|:| |eigval| (-3 (-433 (-980 |#1|)) (-1180 (-1191) (-980 |#1|)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 (-706 (-433 (-980 |#1|))))))) (-706 (-433 (-980 |#1|)))))) 
+((-2731 (((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)) 14))) 
+(((-309 |#1| |#2|) (-10 -7 (-15 -2731 ((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)))) (-1225) (-1225)) (T -309)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-310 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-310 *6)) (-5 *1 (-309 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2272 (((-141) $) NIL (|has| |#1| (-21)))) (-1905 (($ $) 22)) (-2350 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-3147 (($ $ $) 93 (|has| |#1| (-318)))) (-3001 (($) NIL (-3836 (|has| |#1| (-21)) (|has| |#1| (-743))) CONST)) (-2151 (($ $) 8 (|has| |#1| (-21)))) (-3837 (((-3 $ "failed") $) 68 (|has| |#1| (-743)))) (-1673 ((|#1| $) 21)) (-3371 (((-3 $ "failed") $) 66 (|has| |#1| (-743)))) (-3558 (((-141) $) NIL (|has| |#1| (-743)))) (-2731 (($ (-1 |#1| |#1|) $) 24)) (-3634 ((|#1| $) 9)) (-2527 (($ $) 57 (|has| |#1| (-21)))) (-3256 (((-3 $ "failed") $) 67 (|has| |#1| (-743)))) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4552 (($ $) 70 (-3836 (|has| |#1| (-388)) (|has| |#1| (-502))))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-2497 (((-658 $) $) 19 (|has| |#1| (-582)))) (-2806 (($ $ $) 34 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 $)) 37 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-1191) |#1|) 27 (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) 31 (|has| |#1| (-547 (-1191) |#1|)))) (-2724 (($ |#1| |#1|) 17)) (-1936 (((-160)) 88 (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191)) 85 (|has| |#1| (-922 (-1191))))) (-2227 (($ $ $) NIL (|has| |#1| (-502)))) (-2131 (($ $ $) NIL (|has| |#1| (-502)))) (-1683 (($ (-592)) NIL (|has| |#1| (-1075))) (((-141) $) 45 (|has| |#1| (-1119))) (((-877) $) 44 (|has| |#1| (-1119)))) (-4010 (((-790)) 73 (|has| |#1| (-1075)))) (-1424 (($ $ (-592)) NIL (|has| |#1| (-502))) (($ $ (-790)) NIL (|has| |#1| (-743))) (($ $ (-944)) NIL (|has| |#1| (-1131)))) (-3514 (($) 55 (|has| |#1| (-21)) CONST)) (-4257 (($) 63 (|has| |#1| (-743)) CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191))))) (-3255 (($ |#1| |#1|) 20) (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) 90 (-3836 (|has| |#1| (-388)) (|has| |#1| (-502))))) (-3306 (($ |#1| $) 53 (|has| |#1| (-21))) (($ $ |#1|) 54 (|has| |#1| (-21))) (($ $ $) 52 (|has| |#1| (-21))) (($ $) 51 (|has| |#1| (-21)))) (-3300 (($ |#1| $) 48 (|has| |#1| (-25))) (($ $ |#1|) 49 (|has| |#1| (-25))) (($ $ $) 47 (|has| |#1| (-25)))) (** (($ $ (-592)) NIL (|has| |#1| (-502))) (($ $ (-790)) NIL (|has| |#1| (-743))) (($ $ (-944)) NIL (|has| |#1| (-1131)))) (* (($ $ |#1|) 61 (|has| |#1| (-1131))) (($ |#1| $) 60 (|has| |#1| (-1131))) (($ $ $) 59 (|has| |#1| (-1131))) (($ (-592) $) 76 (|has| |#1| (-21))) (($ (-790) $) NIL (|has| |#1| (-21))) (($ (-944) $) NIL (|has| |#1| (-25))))) 
+(((-310 |#1|) (-13 (-1225) (-10 -8 (-15 -3255 ($ |#1| |#1|)) (-15 -2724 ($ |#1| |#1|)) (-15 -1905 ($ $)) (-15 -3634 (|#1| $)) (-15 -1673 (|#1| $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-547 (-1191) |#1|)) (-6 (-547 (-1191) |#1|)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-6 (-1119)) (-6 (-632 (-141))) (IF (|has| |#1| (-325 |#1|)) (PROGN (-15 -2806 ($ $ $)) (-15 -2806 ($ $ (-658 $)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-25)) (PROGN (-6 (-25)) (-15 -3300 ($ |#1| $)) (-15 -3300 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-21)) (PROGN (-6 (-21)) (-15 -2527 ($ $)) (-15 -2151 ($ $)) (-15 -3306 ($ |#1| $)) (-15 -3306 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-1131)) (PROGN (-6 (-1131)) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-743)) (PROGN (-6 (-743)) (-15 -3256 ((-3 $ "failed") $)) (-15 -3837 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-502)) (PROGN (-6 (-502)) (-15 -3256 ((-3 $ "failed") $)) (-15 -3837 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-1075)) (PROGN (-6 (-1075)) (-6 (-140 |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-194)) (-6 (-734 |#1|)) |noBranch|) (IF (|has| |#1| (-582)) (-15 -2497 ((-658 $) $)) |noBranch|) (IF (|has| |#1| (-922 (-1191))) (-6 (-922 (-1191))) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-6 (-1287 |#1|)) (-15 -3313 ($ $ $)) (-15 -4552 ($ $))) |noBranch|) (IF (|has| |#1| (-318)) (-15 -3147 ($ $ $)) |noBranch|))) (-1225)) (T -310)) 
+((-3255 (*1 *1 *2 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) (-2724 (*1 *1 *2 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) (-1905 (*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) (-3634 (*1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) (-1673 (*1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1225)) (-5 *1 (-310 *3)))) (-2806 (*1 *1 *1 *1) (-12 (-4 *2 (-325 *2)) (-4 *2 (-1119)) (-4 *2 (-1225)) (-5 *1 (-310 *2)))) (-2806 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-310 *3))) (-4 *3 (-325 *3)) (-4 *3 (-1119)) (-4 *3 (-1225)) (-5 *1 (-310 *3)))) (-3300 (*1 *1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-25)) (-4 *2 (-1225)))) (-3300 (*1 *1 *1 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-25)) (-4 *2 (-1225)))) (-2527 (*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-21)) (-4 *2 (-1225)))) (-2151 (*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-21)) (-4 *2 (-1225)))) (-3306 (*1 *1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-21)) (-4 *2 (-1225)))) (-3306 (*1 *1 *1 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-21)) (-4 *2 (-1225)))) (-3256 (*1 *1 *1) (|partial| -12 (-5 *1 (-310 *2)) (-4 *2 (-743)) (-4 *2 (-1225)))) (-3837 (*1 *1 *1) (|partial| -12 (-5 *1 (-310 *2)) (-4 *2 (-743)) (-4 *2 (-1225)))) (-2497 (*1 *2 *1) (-12 (-5 *2 (-658 (-310 *3))) (-5 *1 (-310 *3)) (-4 *3 (-582)) (-4 *3 (-1225)))) (-3147 (*1 *1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-318)) (-4 *2 (-1225)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1131)) (-4 *2 (-1225)))) (* (*1 *1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1131)) (-4 *2 (-1225)))) (-3313 (*1 *1 *1 *1) (-3836 (-12 (-5 *1 (-310 *2)) (-4 *2 (-388)) (-4 *2 (-1225))) (-12 (-5 *1 (-310 *2)) (-4 *2 (-502)) (-4 *2 (-1225))))) (-4552 (*1 *1 *1) (-3836 (-12 (-5 *1 (-310 *2)) (-4 *2 (-388)) (-4 *2 (-1225))) (-12 (-5 *1 (-310 *2)) (-4 *2 (-502)) (-4 *2 (-1225)))))) 
+(-13 (-1225) (-10 -8 (-15 -3255 ($ |#1| |#1|)) (-15 -2724 ($ |#1| |#1|)) (-15 -1905 ($ $)) (-15 -3634 (|#1| $)) (-15 -1673 (|#1| $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-547 (-1191) |#1|)) (-6 (-547 (-1191) |#1|)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-6 (-1119)) (-6 (-632 (-141))) (IF (|has| |#1| (-325 |#1|)) (PROGN (-15 -2806 ($ $ $)) (-15 -2806 ($ $ (-658 $)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-25)) (PROGN (-6 (-25)) (-15 -3300 ($ |#1| $)) (-15 -3300 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-21)) (PROGN (-6 (-21)) (-15 -2527 ($ $)) (-15 -2151 ($ $)) (-15 -3306 ($ |#1| $)) (-15 -3306 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-1131)) (PROGN (-6 (-1131)) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-743)) (PROGN (-6 (-743)) (-15 -3256 ((-3 $ "failed") $)) (-15 -3837 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-502)) (PROGN (-6 (-502)) (-15 -3256 ((-3 $ "failed") $)) (-15 -3837 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-1075)) (PROGN (-6 (-1075)) (-6 (-140 |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-194)) (-6 (-734 |#1|)) |noBranch|) (IF (|has| |#1| (-582)) (-15 -2497 ((-658 $) $)) |noBranch|) (IF (|has| |#1| (-922 (-1191))) (-6 (-922 (-1191))) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-6 (-1287 |#1|)) (-15 -3313 ($ $ $)) (-15 -4552 ($ $))) |noBranch|) (IF (|has| |#1| (-318)) (-15 -3147 ($ $ $)) |noBranch|))) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3898 (((-1285) $ |#1| |#1|) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#2| $ |#1| |#2|) NIL)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 |#2| "failed") |#1| $) NIL)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) NIL)) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) NIL)) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 ((|#1| $) NIL (|has| |#1| (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 ((|#1| $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-2840 (((-658 |#1|) $) NIL)) (-2396 (((-141) |#1| $) NIL)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3708 (((-658 |#1|) $) NIL)) (-3780 (((-141) |#1| $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1918 ((|#2| $) NIL (|has| |#1| (-869)))) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-311 |#1| |#2|) (-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625))) (-1119) (-1119)) (T -311)) 
+NIL 
+(-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625))) 
+((-1615 (((-327) (-1173) (-658 (-1173))) 16) (((-327) (-1173) (-1173)) 15) (((-327) (-658 (-1173))) 14) (((-327) (-1173)) 12))) 
+(((-312) (-10 -7 (-15 -1615 ((-327) (-1173))) (-15 -1615 ((-327) (-658 (-1173)))) (-15 -1615 ((-327) (-1173) (-1173))) (-15 -1615 ((-327) (-1173) (-658 (-1173)))))) (T -312)) 
+((-1615 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-1173))) (-5 *3 (-1173)) (-5 *2 (-327)) (-5 *1 (-312)))) (-1615 (*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-327)) (-5 *1 (-312)))) (-1615 (*1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-327)) (-5 *1 (-312)))) (-1615 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-327)) (-5 *1 (-312))))) 
+(-10 -7 (-15 -1615 ((-327) (-1173))) (-15 -1615 ((-327) (-658 (-1173)))) (-15 -1615 ((-327) (-1173) (-1173))) (-15 -1615 ((-327) (-1173) (-658 (-1173))))) 
+((-2731 ((|#2| (-1 |#2| |#1|) (-1173) (-631 |#1|)) 17))) 
+(((-313 |#1| |#2|) (-10 -7 (-15 -2731 (|#2| (-1 |#2| |#1|) (-1173) (-631 |#1|)))) (-318) (-1225)) (T -313)) 
+((-2731 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1173)) (-5 *5 (-631 *6)) (-4 *6 (-318)) (-4 *2 (-1225)) (-5 *1 (-313 *6 *2))))) 
+(-10 -7 (-15 -2731 (|#2| (-1 |#2| |#1|) (-1173) (-631 |#1|)))) 
+((-2731 ((|#2| (-1 |#2| |#1|) (-631 |#1|)) 17))) 
+(((-314 |#1| |#2|) (-10 -7 (-15 -2731 (|#2| (-1 |#2| |#1|) (-631 |#1|)))) (-318) (-318)) (T -314)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5)) (-5 *4 (-631 *5)) (-4 *5 (-318)) (-4 *2 (-318)) (-5 *1 (-314 *5 *2))))) 
+(-10 -7 (-15 -2731 (|#2| (-1 |#2| |#1|) (-631 |#1|)))) 
+((-4430 (((-141) (-237)) 10))) 
+(((-315 |#1| |#2|) (-10 -7 (-15 -4430 ((-141) (-237)))) (-237) (-237)) (T -315)) 
+((-4430 (*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-141)) (-5 *1 (-315 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
+(-10 -7 (-15 -4430 ((-141) (-237)))) 
+((-3863 (((-1171 (-237)) (-332 (-237)) (-658 (-1191)) (-1113 (-862 (-237)))) 88)) (-1914 (((-1171 (-237)) (-1280 (-332 (-237))) (-658 (-1191)) (-1113 (-862 (-237)))) 103) (((-1171 (-237)) (-332 (-237)) (-658 (-1191)) (-1113 (-862 (-237)))) 58)) (-1945 (((-658 (-1173)) (-1171 (-237))) NIL)) (-2990 (((-658 (-237)) (-332 (-237)) (-1191) (-1113 (-862 (-237)))) 55)) (-1775 (((-658 (-237)) (-980 (-433 (-592))) (-1191) (-1113 (-862 (-237)))) 47)) (-2247 (((-658 (-1173)) (-658 (-237))) NIL)) (-1550 (((-237) (-1113 (-862 (-237)))) 23)) (-3896 (((-237) (-1113 (-862 (-237)))) 24)) (-4129 (((-141) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 51)) (-3058 (((-1173) (-237)) NIL))) 
+(((-316) (-10 -7 (-15 -1550 ((-237) (-1113 (-862 (-237))))) (-15 -3896 ((-237) (-1113 (-862 (-237))))) (-15 -4129 ((-141) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -2990 ((-658 (-237)) (-332 (-237)) (-1191) (-1113 (-862 (-237))))) (-15 -3863 ((-1171 (-237)) (-332 (-237)) (-658 (-1191)) (-1113 (-862 (-237))))) (-15 -1914 ((-1171 (-237)) (-332 (-237)) (-658 (-1191)) (-1113 (-862 (-237))))) (-15 -1914 ((-1171 (-237)) (-1280 (-332 (-237))) (-658 (-1191)) (-1113 (-862 (-237))))) (-15 -1775 ((-658 (-237)) (-980 (-433 (-592))) (-1191) (-1113 (-862 (-237))))) (-15 -3058 ((-1173) (-237))) (-15 -2247 ((-658 (-1173)) (-658 (-237)))) (-15 -1945 ((-658 (-1173)) (-1171 (-237)))))) (T -316)) 
+((-1945 (*1 *2 *3) (-12 (-5 *3 (-1171 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-316)))) (-2247 (*1 *2 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-316)))) (-3058 (*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-1173)) (-5 *1 (-316)))) (-1775 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-980 (-433 (-592)))) (-5 *4 (-1191)) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-658 (-237))) (-5 *1 (-316)))) (-1914 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *4 (-658 (-1191))) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-1171 (-237))) (-5 *1 (-316)))) (-1914 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-658 (-1191))) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-1171 (-237))) (-5 *1 (-316)))) (-3863 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-658 (-1191))) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-1171 (-237))) (-5 *1 (-316)))) (-2990 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-1191)) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-658 (-237))) (-5 *1 (-316)))) (-4129 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-141)) (-5 *1 (-316)))) (-3896 (*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-316)))) (-1550 (*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-316))))) 
+(-10 -7 (-15 -1550 ((-237) (-1113 (-862 (-237))))) (-15 -3896 ((-237) (-1113 (-862 (-237))))) (-15 -4129 ((-141) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -2990 ((-658 (-237)) (-332 (-237)) (-1191) (-1113 (-862 (-237))))) (-15 -3863 ((-1171 (-237)) (-332 (-237)) (-658 (-1191)) (-1113 (-862 (-237))))) (-15 -1914 ((-1171 (-237)) (-332 (-237)) (-658 (-1191)) (-1113 (-862 (-237))))) (-15 -1914 ((-1171 (-237)) (-1280 (-332 (-237))) (-658 (-1191)) (-1113 (-862 (-237))))) (-15 -1775 ((-658 (-237)) (-980 (-433 (-592))) (-1191) (-1113 (-862 (-237))))) (-15 -3058 ((-1173) (-237))) (-15 -2247 ((-658 (-1173)) (-658 (-237)))) (-15 -1945 ((-658 (-1173)) (-1171 (-237))))) 
+((-2165 (((-658 (-631 $)) $) 28)) (-3147 (($ $ (-310 $)) 80) (($ $ (-658 (-310 $))) 120) (($ $ (-658 (-631 $)) (-658 $)) NIL)) (-4368 (((-3 (-631 $) "failed") $) 110)) (-2400 (((-631 $) $) 109)) (-2243 (($ $) 19) (($ (-658 $)) 54)) (-4388 (((-658 (-143)) $) 37)) (-2791 (((-143) (-143)) 90)) (-3372 (((-141) $) 128)) (-2731 (($ (-1 $ $) (-631 $)) 88)) (-4160 (((-3 (-631 $) "failed") $) 92)) (-1462 (($ (-143) $) 60) (($ (-143) (-658 $)) 98)) (-3013 (((-141) $ (-143)) 114) (((-141) $ (-1191)) 113)) (-2535 (((-790) $) 45)) (-1319 (((-141) $ $) 58) (((-141) $ (-1191)) 49)) (-3554 (((-141) $) 126)) (-2806 (($ $ (-631 $) $) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL) (($ $ (-658 (-310 $))) 118) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ $))) 83) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-1191) (-1 $ (-658 $))) 68) (($ $ (-1191) (-1 $ $)) 74) (($ $ (-658 (-143)) (-658 (-1 $ $))) 82) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) 84) (($ $ (-143) (-1 $ (-658 $))) 70) (($ $ (-143) (-1 $ $)) 76)) (-3927 (($ (-143) $) 61) (($ (-143) $ $) 62) (($ (-143) $ $ $) 63) (($ (-143) $ $ $ $) 64) (($ (-143) (-658 $)) 106)) (-2818 (($ $) 51) (($ $ $) 116)) (-3280 (($ $) 17) (($ (-658 $)) 53)) (-3038 (((-141) (-143)) 22))) 
+(((-317 |#1|) (-10 -8 (-15 -3372 ((-141) |#1|)) (-15 -3554 ((-141) |#1|)) (-15 -2806 (|#1| |#1| (-143) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-143) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 (-1 |#1| |#1|)))) (-15 -2806 (|#1| |#1| (-1191) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-1191) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-1 |#1| |#1|)))) (-15 -1319 ((-141) |#1| (-1191))) (-15 -1319 ((-141) |#1| |#1|)) (-15 -2731 (|#1| (-1 |#1| |#1|) (-631 |#1|))) (-15 -1462 (|#1| (-143) (-658 |#1|))) (-15 -1462 (|#1| (-143) |#1|)) (-15 -3013 ((-141) |#1| (-1191))) (-15 -3013 ((-141) |#1| (-143))) (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -4388 ((-658 (-143)) |#1|)) (-15 -2165 ((-658 (-631 |#1|)) |#1|)) (-15 -4160 ((-3 (-631 |#1|) "failed") |#1|)) (-15 -2535 ((-790) |#1|)) (-15 -2818 (|#1| |#1| |#1|)) (-15 -2818 (|#1| |#1|)) (-15 -2243 (|#1| (-658 |#1|))) (-15 -2243 (|#1| |#1|)) (-15 -3280 (|#1| (-658 |#1|))) (-15 -3280 (|#1| |#1|)) (-15 -3147 (|#1| |#1| (-658 (-631 |#1|)) (-658 |#1|))) (-15 -3147 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -3147 (|#1| |#1| (-310 |#1|))) (-15 -3927 (|#1| (-143) (-658 |#1|))) (-15 -3927 (|#1| (-143) |#1| |#1| |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1| |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-631 |#1|)) (-658 |#1|))) (-15 -2806 (|#1| |#1| (-631 |#1|) |#1|)) (-15 -2400 ((-631 |#1|) |#1|)) (-15 -4368 ((-3 (-631 |#1|) "failed") |#1|))) (-318)) (T -317)) 
+((-2791 (*1 *2 *2) (-12 (-5 *2 (-143)) (-5 *1 (-317 *3)) (-4 *3 (-318)))) (-3038 (*1 *2 *3) (-12 (-5 *3 (-143)) (-5 *2 (-141)) (-5 *1 (-317 *4)) (-4 *4 (-318))))) 
+(-10 -8 (-15 -3372 ((-141) |#1|)) (-15 -3554 ((-141) |#1|)) (-15 -2806 (|#1| |#1| (-143) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-143) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 (-1 |#1| |#1|)))) (-15 -2806 (|#1| |#1| (-1191) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-1191) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-1 |#1| |#1|)))) (-15 -1319 ((-141) |#1| (-1191))) (-15 -1319 ((-141) |#1| |#1|)) (-15 -2731 (|#1| (-1 |#1| |#1|) (-631 |#1|))) (-15 -1462 (|#1| (-143) (-658 |#1|))) (-15 -1462 (|#1| (-143) |#1|)) (-15 -3013 ((-141) |#1| (-1191))) (-15 -3013 ((-141) |#1| (-143))) (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -4388 ((-658 (-143)) |#1|)) (-15 -2165 ((-658 (-631 |#1|)) |#1|)) (-15 -4160 ((-3 (-631 |#1|) "failed") |#1|)) (-15 -2535 ((-790) |#1|)) (-15 -2818 (|#1| |#1| |#1|)) (-15 -2818 (|#1| |#1|)) (-15 -2243 (|#1| (-658 |#1|))) (-15 -2243 (|#1| |#1|)) (-15 -3280 (|#1| (-658 |#1|))) (-15 -3280 (|#1| |#1|)) (-15 -3147 (|#1| |#1| (-658 (-631 |#1|)) (-658 |#1|))) (-15 -3147 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -3147 (|#1| |#1| (-310 |#1|))) (-15 -3927 (|#1| (-143) (-658 |#1|))) (-15 -3927 (|#1| (-143) |#1| |#1| |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1| |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-631 |#1|)) (-658 |#1|))) (-15 -2806 (|#1| |#1| (-631 |#1|) |#1|)) (-15 -2400 ((-631 |#1|) |#1|)) (-15 -4368 ((-3 (-631 |#1|) "failed") |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2165 (((-658 (-631 $)) $) 43)) (-3147 (($ $ (-310 $)) 55) (($ $ (-658 (-310 $))) 54) (($ $ (-658 (-631 $)) (-658 $)) 53)) (-4368 (((-3 (-631 $) "failed") $) 68)) (-2400 (((-631 $) $) 67)) (-2243 (($ $) 50) (($ (-658 $)) 49)) (-4388 (((-658 (-143)) $) 42)) (-2791 (((-143) (-143)) 41)) (-3372 (((-141) $) 21 (|has| $ (-1065 (-592))))) (-2710 (((-1187 $) (-631 $)) 24 (|has| $ (-1075)))) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2731 (($ (-1 $ $) (-631 $)) 35)) (-4160 (((-3 (-631 $) "failed") $) 45)) (-2685 (((-1173) $) 9)) (-4486 (((-658 (-631 $)) $) 44)) (-1462 (($ (-143) $) 37) (($ (-143) (-658 $)) 36)) (-3013 (((-141) $ (-143)) 39) (((-141) $ (-1191)) 38)) (-2535 (((-790) $) 46)) (-2951 (((-1137) $) 10)) (-1319 (((-141) $ $) 34) (((-141) $ (-1191)) 33)) (-3554 (((-141) $) 22 (|has| $ (-1065 (-592))))) (-2806 (($ $ (-631 $) $) 66) (($ $ (-658 (-631 $)) (-658 $)) 65) (($ $ (-658 (-310 $))) 64) (($ $ (-310 $)) 63) (($ $ $ $) 62) (($ $ (-658 $) (-658 $)) 61) (($ $ (-658 (-1191)) (-658 (-1 $ $))) 32) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) 31) (($ $ (-1191) (-1 $ (-658 $))) 30) (($ $ (-1191) (-1 $ $)) 29) (($ $ (-658 (-143)) (-658 (-1 $ $))) 28) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) 27) (($ $ (-143) (-1 $ (-658 $))) 26) (($ $ (-143) (-1 $ $)) 25)) (-3927 (($ (-143) $) 60) (($ (-143) $ $) 59) (($ (-143) $ $ $) 58) (($ (-143) $ $ $ $) 57) (($ (-143) (-658 $)) 56)) (-2818 (($ $) 48) (($ $ $) 47)) (-3390 (($ $) 23 (|has| $ (-1075)))) (-1683 (((-877) $) 11) (($ (-631 $)) 69)) (-3280 (($ $) 52) (($ (-658 $)) 51)) (-3038 (((-141) (-143)) 40)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17))) 
+(((-318) (-1311)) (T -318)) 
+((-3927 (*1 *1 *2 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) (-3927 (*1 *1 *2 *1 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) (-3927 (*1 *1 *2 *1 *1 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) (-3927 (*1 *1 *2 *1 *1 *1 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) (-3927 (*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-658 *1)) (-4 *1 (-318)))) (-3147 (*1 *1 *1 *2) (-12 (-5 *2 (-310 *1)) (-4 *1 (-318)))) (-3147 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-310 *1))) (-4 *1 (-318)))) (-3147 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-631 *1))) (-5 *3 (-658 *1)) (-4 *1 (-318)))) (-3280 (*1 *1 *1) (-4 *1 (-318))) (-3280 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-318)))) (-2243 (*1 *1 *1) (-4 *1 (-318))) (-2243 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-318)))) (-2818 (*1 *1 *1) (-4 *1 (-318))) (-2818 (*1 *1 *1 *1) (-4 *1 (-318))) (-2535 (*1 *2 *1) (-12 (-4 *1 (-318)) (-5 *2 (-790)))) (-4160 (*1 *2 *1) (|partial| -12 (-5 *2 (-631 *1)) (-4 *1 (-318)))) (-4486 (*1 *2 *1) (-12 (-5 *2 (-658 (-631 *1))) (-4 *1 (-318)))) (-2165 (*1 *2 *1) (-12 (-5 *2 (-658 (-631 *1))) (-4 *1 (-318)))) (-4388 (*1 *2 *1) (-12 (-4 *1 (-318)) (-5 *2 (-658 (-143))))) (-2791 (*1 *2 *2) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) (-3038 (*1 *2 *3) (-12 (-4 *1 (-318)) (-5 *3 (-143)) (-5 *2 (-141)))) (-3013 (*1 *2 *1 *3) (-12 (-4 *1 (-318)) (-5 *3 (-143)) (-5 *2 (-141)))) (-3013 (*1 *2 *1 *3) (-12 (-4 *1 (-318)) (-5 *3 (-1191)) (-5 *2 (-141)))) (-1462 (*1 *1 *2 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) (-1462 (*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-658 *1)) (-4 *1 (-318)))) (-2731 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *1 *1)) (-5 *3 (-631 *1)) (-4 *1 (-318)))) (-1319 (*1 *2 *1 *1) (-12 (-4 *1 (-318)) (-5 *2 (-141)))) (-1319 (*1 *2 *1 *3) (-12 (-4 *1 (-318)) (-5 *3 (-1191)) (-5 *2 (-141)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-658 (-1 *1 *1))) (-4 *1 (-318)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-658 (-1 *1 (-658 *1)))) (-4 *1 (-318)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1 *1 (-658 *1))) (-4 *1 (-318)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1 *1 *1)) (-4 *1 (-318)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-143))) (-5 *3 (-658 (-1 *1 *1))) (-4 *1 (-318)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-143))) (-5 *3 (-658 (-1 *1 (-658 *1)))) (-4 *1 (-318)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *1 (-658 *1))) (-4 *1 (-318)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *1 *1)) (-4 *1 (-318)))) (-2710 (*1 *2 *3) (-12 (-5 *3 (-631 *1)) (-4 *1 (-1075)) (-4 *1 (-318)) (-5 *2 (-1187 *1)))) (-3390 (*1 *1 *1) (-12 (-4 *1 (-1075)) (-4 *1 (-318)))) (-3554 (*1 *2 *1) (-12 (-4 *1 (-1065 (-592))) (-4 *1 (-318)) (-5 *2 (-141)))) (-3372 (*1 *2 *1) (-12 (-4 *1 (-1065 (-592))) (-4 *1 (-318)) (-5 *2 (-141))))) 
+(-13 (-869) (-1065 (-631 $)) (-547 (-631 $) $) (-325 $) (-10 -8 (-15 -3927 ($ (-143) $)) (-15 -3927 ($ (-143) $ $)) (-15 -3927 ($ (-143) $ $ $)) (-15 -3927 ($ (-143) $ $ $ $)) (-15 -3927 ($ (-143) (-658 $))) (-15 -3147 ($ $ (-310 $))) (-15 -3147 ($ $ (-658 (-310 $)))) (-15 -3147 ($ $ (-658 (-631 $)) (-658 $))) (-15 -3280 ($ $)) (-15 -3280 ($ (-658 $))) (-15 -2243 ($ $)) (-15 -2243 ($ (-658 $))) (-15 -2818 ($ $)) (-15 -2818 ($ $ $)) (-15 -2535 ((-790) $)) (-15 -4160 ((-3 (-631 $) "failed") $)) (-15 -4486 ((-658 (-631 $)) $)) (-15 -2165 ((-658 (-631 $)) $)) (-15 -4388 ((-658 (-143)) $)) (-15 -2791 ((-143) (-143))) (-15 -3038 ((-141) (-143))) (-15 -3013 ((-141) $ (-143))) (-15 -3013 ((-141) $ (-1191))) (-15 -1462 ($ (-143) $)) (-15 -1462 ($ (-143) (-658 $))) (-15 -2731 ($ (-1 $ $) (-631 $))) (-15 -1319 ((-141) $ $)) (-15 -1319 ((-141) $ (-1191))) (-15 -2806 ($ $ (-658 (-1191)) (-658 (-1 $ $)))) (-15 -2806 ($ $ (-658 (-1191)) (-658 (-1 $ (-658 $))))) (-15 -2806 ($ $ (-1191) (-1 $ (-658 $)))) (-15 -2806 ($ $ (-1191) (-1 $ $))) (-15 -2806 ($ $ (-658 (-143)) (-658 (-1 $ $)))) (-15 -2806 ($ $ (-658 (-143)) (-658 (-1 $ (-658 $))))) (-15 -2806 ($ $ (-143) (-1 $ (-658 $)))) (-15 -2806 ($ $ (-143) (-1 $ $))) (IF (|has| $ (-1075)) (PROGN (-15 -2710 ((-1187 $) (-631 $))) (-15 -3390 ($ $))) |noBranch|) (IF (|has| $ (-1065 (-592))) (PROGN (-15 -3554 ((-141) $)) (-15 -3372 ((-141) $))) |noBranch|))) 
+(((-125) . T) ((-632 (-877)) . T) ((-325 $) . T) ((-547 (-631 $) $) . T) ((-547 $ $) . T) ((-869) . T) ((-1065 (-631 $)) . T) ((-1119) . T)) 
+((-1627 (((-658 |#1|) (-658 |#1|)) 10))) 
+(((-319 |#1|) (-10 -7 (-15 -1627 ((-658 |#1|) (-658 |#1|)))) (-867)) (T -319)) 
+((-1627 (*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-867)) (-5 *1 (-319 *3))))) 
+(-10 -7 (-15 -1627 ((-658 |#1|) (-658 |#1|)))) 
+((-2731 (((-706 |#2|) (-1 |#2| |#1|) (-706 |#1|)) 15))) 
+(((-320 |#1| |#2|) (-10 -7 (-15 -2731 ((-706 |#2|) (-1 |#2| |#1|) (-706 |#1|)))) (-1075) (-1075)) (T -320)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-706 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-706 *6)) (-5 *1 (-320 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-706 |#2|) (-1 |#2| |#1|) (-706 |#1|)))) 
+((-4196 (((-1280 (-332 (-405))) (-1280 (-332 (-237)))) 105)) (-2614 (((-1113 (-862 (-237))) (-1113 (-862 (-405)))) 39)) (-1945 (((-658 (-1173)) (-1171 (-237))) 87)) (-1796 (((-332 (-405)) (-980 (-237))) 49)) (-2938 (((-237) (-980 (-237))) 45)) (-2866 (((-1173) (-405)) 167)) (-1485 (((-862 (-237)) (-862 (-405))) 33)) (-3746 (((-2 (|:| |additions| (-592)) (|:| |multiplications| (-592)) (|:| |exponentiations| (-592)) (|:| |functionCalls| (-592))) (-1280 (-332 (-237)))) 142)) (-2873 (((-1063) (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063)))) 180) (((-1063) (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) 178)) (-3253 (((-706 (-237)) (-658 (-237)) (-790)) 13)) (-1908 (((-1280 (-715)) (-658 (-237))) 94)) (-2247 (((-658 (-1173)) (-658 (-237))) 74)) (-1688 (((-3 (-332 (-237)) "failed") (-332 (-237))) 120)) (-4430 (((-141) (-237) (-1113 (-862 (-237)))) 109)) (-3581 (((-1063) (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))) 198)) (-1550 (((-237) (-1113 (-862 (-237)))) 107)) (-3896 (((-237) (-1113 (-862 (-237)))) 108)) (-2044 (((-237) (-433 (-592))) 26)) (-2646 (((-1173) (-405)) 72)) (-4193 (((-237) (-405)) 17)) (-2552 (((-405) (-1280 (-332 (-237)))) 153)) (-1355 (((-332 (-237)) (-332 (-405))) 23)) (-3227 (((-433 (-592)) (-332 (-237))) 52)) (-2017 (((-332 (-433 (-592))) (-332 (-237))) 68)) (-1553 (((-332 (-405)) (-332 (-237))) 98)) (-2330 (((-237) (-332 (-237))) 53)) (-3413 (((-658 (-237)) (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) 63)) (-3571 (((-1113 (-862 (-237))) (-1113 (-862 (-237)))) 60)) (-3058 (((-1173) (-237)) 71)) (-2704 (((-715) (-237)) 90)) (-4112 (((-433 (-592)) (-237)) 54)) (-1701 (((-332 (-405)) (-237)) 48)) (-1778 (((-658 (-1113 (-862 (-237)))) (-658 (-1113 (-862 (-405))))) 42)) (-2266 (((-1063) (-658 (-1063))) 163) (((-1063) (-1063) (-1063)) 160)) (-2809 (((-1063) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) 194))) 
+(((-321) (-10 -7 (-15 -4193 ((-237) (-405))) (-15 -1355 ((-332 (-237)) (-332 (-405)))) (-15 -1485 ((-862 (-237)) (-862 (-405)))) (-15 -2614 ((-1113 (-862 (-237))) (-1113 (-862 (-405))))) (-15 -1778 ((-658 (-1113 (-862 (-237)))) (-658 (-1113 (-862 (-405)))))) (-15 -4112 ((-433 (-592)) (-237))) (-15 -3227 ((-433 (-592)) (-332 (-237)))) (-15 -2330 ((-237) (-332 (-237)))) (-15 -1688 ((-3 (-332 (-237)) "failed") (-332 (-237)))) (-15 -2552 ((-405) (-1280 (-332 (-237))))) (-15 -3746 ((-2 (|:| |additions| (-592)) (|:| |multiplications| (-592)) (|:| |exponentiations| (-592)) (|:| |functionCalls| (-592))) (-1280 (-332 (-237))))) (-15 -2017 ((-332 (-433 (-592))) (-332 (-237)))) (-15 -3571 ((-1113 (-862 (-237))) (-1113 (-862 (-237))))) (-15 -3413 ((-658 (-237)) (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))))) (-15 -2704 ((-715) (-237))) (-15 -1908 ((-1280 (-715)) (-658 (-237)))) (-15 -1553 ((-332 (-405)) (-332 (-237)))) (-15 -4196 ((-1280 (-332 (-405))) (-1280 (-332 (-237))))) (-15 -4430 ((-141) (-237) (-1113 (-862 (-237))))) (-15 -3058 ((-1173) (-237))) (-15 -2646 ((-1173) (-405))) (-15 -2247 ((-658 (-1173)) (-658 (-237)))) (-15 -1945 ((-658 (-1173)) (-1171 (-237)))) (-15 -1550 ((-237) (-1113 (-862 (-237))))) (-15 -3896 ((-237) (-1113 (-862 (-237))))) (-15 -2266 ((-1063) (-1063) (-1063))) (-15 -2266 ((-1063) (-658 (-1063)))) (-15 -2866 ((-1173) (-405))) (-15 -2873 ((-1063) (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))))) (-15 -2873 ((-1063) (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063))))) (-15 -2809 ((-1063) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))) (-15 -3581 ((-1063) (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))))) (-15 -1796 ((-332 (-405)) (-980 (-237)))) (-15 -2938 ((-237) (-980 (-237)))) (-15 -1701 ((-332 (-405)) (-237))) (-15 -2044 ((-237) (-433 (-592)))) (-15 -3253 ((-706 (-237)) (-658 (-237)) (-790))))) (T -321)) 
+((-3253 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-237))) (-5 *4 (-790)) (-5 *2 (-706 (-237))) (-5 *1 (-321)))) (-2044 (*1 *2 *3) (-12 (-5 *3 (-433 (-592))) (-5 *2 (-237)) (-5 *1 (-321)))) (-1701 (*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-332 (-405))) (-5 *1 (-321)))) (-2938 (*1 *2 *3) (-12 (-5 *3 (-980 (-237))) (-5 *2 (-237)) (-5 *1 (-321)))) (-1796 (*1 *2 *3) (-12 (-5 *3 (-980 (-237))) (-5 *2 (-332 (-405))) (-5 *1 (-321)))) (-3581 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))) (-5 *2 (-1063)) (-5 *1 (-321)))) (-2809 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *2 (-1063)) (-5 *1 (-321)))) (-2873 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063)))) (-5 *2 (-1063)) (-5 *1 (-321)))) (-2873 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *2 (-1063)) (-5 *1 (-321)))) (-2866 (*1 *2 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1173)) (-5 *1 (-321)))) (-2266 (*1 *2 *3) (-12 (-5 *3 (-658 (-1063))) (-5 *2 (-1063)) (-5 *1 (-321)))) (-2266 (*1 *2 *2 *2) (-12 (-5 *2 (-1063)) (-5 *1 (-321)))) (-3896 (*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-321)))) (-1550 (*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-321)))) (-1945 (*1 *2 *3) (-12 (-5 *3 (-1171 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-321)))) (-2247 (*1 *2 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-321)))) (-2646 (*1 *2 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1173)) (-5 *1 (-321)))) (-3058 (*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-1173)) (-5 *1 (-321)))) (-4430 (*1 *2 *3 *4) (-12 (-5 *4 (-1113 (-862 (-237)))) (-5 *3 (-237)) (-5 *2 (-141)) (-5 *1 (-321)))) (-4196 (*1 *2 *3) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *2 (-1280 (-332 (-405)))) (-5 *1 (-321)))) (-1553 (*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-332 (-405))) (-5 *1 (-321)))) (-1908 (*1 *2 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-1280 (-715))) (-5 *1 (-321)))) (-2704 (*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-715)) (-5 *1 (-321)))) (-3413 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *2 (-658 (-237))) (-5 *1 (-321)))) (-3571 (*1 *2 *2) (-12 (-5 *2 (-1113 (-862 (-237)))) (-5 *1 (-321)))) (-2017 (*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-332 (-433 (-592)))) (-5 *1 (-321)))) (-3746 (*1 *2 *3) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *2 (-2 (|:| |additions| (-592)) (|:| |multiplications| (-592)) (|:| |exponentiations| (-592)) (|:| |functionCalls| (-592)))) (-5 *1 (-321)))) (-2552 (*1 *2 *3) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *2 (-405)) (-5 *1 (-321)))) (-1688 (*1 *2 *2) (|partial| -12 (-5 *2 (-332 (-237))) (-5 *1 (-321)))) (-2330 (*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-237)) (-5 *1 (-321)))) (-3227 (*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-433 (-592))) (-5 *1 (-321)))) (-4112 (*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-433 (-592))) (-5 *1 (-321)))) (-1778 (*1 *2 *3) (-12 (-5 *3 (-658 (-1113 (-862 (-405))))) (-5 *2 (-658 (-1113 (-862 (-237))))) (-5 *1 (-321)))) (-2614 (*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-405)))) (-5 *2 (-1113 (-862 (-237)))) (-5 *1 (-321)))) (-1485 (*1 *2 *3) (-12 (-5 *3 (-862 (-405))) (-5 *2 (-862 (-237))) (-5 *1 (-321)))) (-1355 (*1 *2 *3) (-12 (-5 *3 (-332 (-405))) (-5 *2 (-332 (-237))) (-5 *1 (-321)))) (-4193 (*1 *2 *3) (-12 (-5 *3 (-405)) (-5 *2 (-237)) (-5 *1 (-321))))) 
+(-10 -7 (-15 -4193 ((-237) (-405))) (-15 -1355 ((-332 (-237)) (-332 (-405)))) (-15 -1485 ((-862 (-237)) (-862 (-405)))) (-15 -2614 ((-1113 (-862 (-237))) (-1113 (-862 (-405))))) (-15 -1778 ((-658 (-1113 (-862 (-237)))) (-658 (-1113 (-862 (-405)))))) (-15 -4112 ((-433 (-592)) (-237))) (-15 -3227 ((-433 (-592)) (-332 (-237)))) (-15 -2330 ((-237) (-332 (-237)))) (-15 -1688 ((-3 (-332 (-237)) "failed") (-332 (-237)))) (-15 -2552 ((-405) (-1280 (-332 (-237))))) (-15 -3746 ((-2 (|:| |additions| (-592)) (|:| |multiplications| (-592)) (|:| |exponentiations| (-592)) (|:| |functionCalls| (-592))) (-1280 (-332 (-237))))) (-15 -2017 ((-332 (-433 (-592))) (-332 (-237)))) (-15 -3571 ((-1113 (-862 (-237))) (-1113 (-862 (-237))))) (-15 -3413 ((-658 (-237)) (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))))) (-15 -2704 ((-715) (-237))) (-15 -1908 ((-1280 (-715)) (-658 (-237)))) (-15 -1553 ((-332 (-405)) (-332 (-237)))) (-15 -4196 ((-1280 (-332 (-405))) (-1280 (-332 (-237))))) (-15 -4430 ((-141) (-237) (-1113 (-862 (-237))))) (-15 -3058 ((-1173) (-237))) (-15 -2646 ((-1173) (-405))) (-15 -2247 ((-658 (-1173)) (-658 (-237)))) (-15 -1945 ((-658 (-1173)) (-1171 (-237)))) (-15 -1550 ((-237) (-1113 (-862 (-237))))) (-15 -3896 ((-237) (-1113 (-862 (-237))))) (-15 -2266 ((-1063) (-1063) (-1063))) (-15 -2266 ((-1063) (-658 (-1063)))) (-15 -2866 ((-1173) (-405))) (-15 -2873 ((-1063) (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))))) (-15 -2873 ((-1063) (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063))))) (-15 -2809 ((-1063) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))) (-15 -3581 ((-1063) (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))))) (-15 -1796 ((-332 (-405)) (-980 (-237)))) (-15 -2938 ((-237) (-980 (-237)))) (-15 -1701 ((-332 (-405)) (-237))) (-15 -2044 ((-237) (-433 (-592)))) (-15 -3253 ((-706 (-237)) (-658 (-237)) (-790)))) 
+((-3652 (((-141) $ $) 11)) (-1586 (($ $ $) 15)) (-1599 (($ $ $) 14)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 43)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 52)) (-3548 (($ $ $) 21) (($ (-658 $)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 31) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 36)) (-3616 (((-3 $ "failed") $ $) 18)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 45))) 
+(((-322 |#1|) (-10 -8 (-15 -2310 ((-3 (-658 |#1|) "failed") (-658 |#1|) |#1|)) (-15 -4159 ((-3 (-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|)) "failed") |#1| |#1| |#1|)) (-15 -4159 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2934 |#1|)) |#1| |#1|)) (-15 -1586 (|#1| |#1| |#1|)) (-15 -1599 (|#1| |#1| |#1|)) (-15 -3652 ((-141) |#1| |#1|)) (-15 -4539 ((-3 (-658 |#1|) "failed") (-658 |#1|) |#1|)) (-15 -1491 ((-2 (|:| -1487 (-658 |#1|)) (|:| -2934 |#1|)) (-658 |#1|))) (-15 -3548 (|#1| (-658 |#1|))) (-15 -3548 (|#1| |#1| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#1|))) (-323)) (T -322)) 
+NIL 
+(-10 -8 (-15 -2310 ((-3 (-658 |#1|) "failed") (-658 |#1|) |#1|)) (-15 -4159 ((-3 (-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|)) "failed") |#1| |#1| |#1|)) (-15 -4159 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2934 |#1|)) |#1| |#1|)) (-15 -1586 (|#1| |#1| |#1|)) (-15 -1599 (|#1| |#1| |#1|)) (-15 -3652 ((-141) |#1| |#1|)) (-15 -4539 ((-3 (-658 |#1|) "failed") (-658 |#1|) |#1|)) (-15 -1491 ((-2 (|:| -1487 (-658 |#1|)) (|:| -2934 |#1|)) (-658 |#1|))) (-15 -3548 (|#1| (-658 |#1|))) (-15 -3548 (|#1| |#1| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3652 (((-141) $ $) 57)) (-3001 (($) 16 T CONST)) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-3558 (((-141) $) 30)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-323) (-1311)) (T -323)) 
+((-3652 (*1 *2 *1 *1) (-12 (-4 *1 (-323)) (-5 *2 (-141)))) (-2769 (*1 *2 *1) (-12 (-4 *1 (-323)) (-5 *2 (-790)))) (-4570 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-323)))) (-1599 (*1 *1 *1 *1) (-4 *1 (-323))) (-1586 (*1 *1 *1 *1) (-4 *1 (-323))) (-4159 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2934 *1))) (-4 *1 (-323)))) (-4159 (*1 *2 *1 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-323)))) (-2310 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-658 *1)) (-4 *1 (-323))))) 
+(-13 (-943) (-10 -8 (-15 -3652 ((-141) $ $)) (-15 -2769 ((-790) $)) (-15 -4570 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -1599 ($ $ $)) (-15 -1586 ($ $ $)) (-15 -4159 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $)) (-15 -4159 ((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $)) (-15 -2310 ((-3 (-658 $) "failed") (-658 $) $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-477) . T) ((-582) . T) ((-661 $) . T) ((-678) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-2806 (($ $ (-658 |#2|) (-658 |#2|)) 14) (($ $ |#2| |#2|) NIL) (($ $ (-310 |#2|)) 11) (($ $ (-658 (-310 |#2|))) NIL))) 
+(((-324 |#1| |#2|) (-10 -8 (-15 -2806 (|#1| |#1| (-658 (-310 |#2|)))) (-15 -2806 (|#1| |#1| (-310 |#2|))) (-15 -2806 (|#1| |#1| |#2| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#2|) (-658 |#2|)))) (-325 |#2|) (-1119)) (T -324)) 
+NIL 
+(-10 -8 (-15 -2806 (|#1| |#1| (-658 (-310 |#2|)))) (-15 -2806 (|#1| |#1| (-310 |#2|))) (-15 -2806 (|#1| |#1| |#2| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#2|) (-658 |#2|)))) 
+((-2806 (($ $ (-658 |#1|) (-658 |#1|)) 7) (($ $ |#1| |#1|) 6) (($ $ (-310 |#1|)) 9) (($ $ (-658 (-310 |#1|))) 8))) 
+(((-325 |#1|) (-1311) (-1119)) (T -325)) 
+((-2806 (*1 *1 *1 *2) (-12 (-5 *2 (-310 *3)) (-4 *1 (-325 *3)) (-4 *3 (-1119)))) (-2806 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-310 *3))) (-4 *1 (-325 *3)) (-4 *3 (-1119))))) 
+(-13 (-547 |t#1| |t#1|) (-10 -8 (-15 -2806 ($ $ (-310 |t#1|))) (-15 -2806 ($ $ (-658 (-310 |t#1|)))))) 
+(((-547 |#1| |#1|) . T)) 
+((-2806 ((|#1| (-1 |#1| (-592)) (-1193 (-433 (-592)))) 24))) 
+(((-326 |#1|) (-10 -7 (-15 -2806 (|#1| (-1 |#1| (-592)) (-1193 (-433 (-592)))))) (-43 (-433 (-592)))) (T -326)) 
+((-2806 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-592))) (-5 *4 (-1193 (-433 (-592)))) (-5 *1 (-326 *2)) (-4 *2 (-43 (-433 (-592))))))) 
+(-10 -7 (-15 -2806 (|#1| (-1 |#1| (-592)) (-1193 (-433 (-592)))))) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 7)) (-3255 (((-141) $ $) 9))) 
+(((-327) (-1119)) (T -327)) 
+NIL 
+(-1119) 
+((-4218 (((-1285) (-1179 3 (-237)) (-1173)) 38))) 
+(((-328) (-10 -7 (-15 -4218 ((-1285) (-1179 3 (-237)) (-1173))))) (T -328)) 
+((-4218 (*1 *2 *3 *4) (-12 (-5 *3 (-1179 3 (-237))) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-328))))) 
+(-10 -7 (-15 -4218 ((-1285) (-1179 3 (-237)) (-1173)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 62)) (-1505 (((-1265 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-1265 |#1| |#2| |#3| |#4|) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1065 (-592)))) (((-3 (-592) "failed") $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1065 (-592)))) (((-3 (-1264 |#2| |#3| |#4|) "failed") $) 24)) (-2400 (((-1265 |#1| |#2| |#3| |#4|) $) NIL) (((-1191) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1065 (-1191)))) (((-433 (-592)) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1065 (-592)))) (((-592) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1065 (-592)))) (((-1264 |#2| |#3| |#4|) $) NIL)) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-1265 |#1| |#2| |#3| |#4|))) (|:| |vec| (-1280 (-1265 |#1| |#2| |#3| |#4|)))) (-706 $) (-1280 $)) NIL) (((-706 (-1265 |#1| |#2| |#3| |#4|)) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-908 (-405))))) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL)) (-1448 (((-1265 |#1| |#2| |#3| |#4|) $) 21)) (-3921 (((-3 $ "failed") $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1165)))) (-1324 (((-141) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-869)))) (-3319 (($ $ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-869)))) (-2731 (($ (-1 (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|)) $) NIL)) (-1722 (((-3 (-862 |#2|) "failed") $) 76)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-323)))) (-2039 (((-1265 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 (-1265 |#1| |#2| |#3| |#4|)) (-658 (-1265 |#1| |#2| |#3| |#4|))) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-325 (-1265 |#1| |#2| |#3| |#4|)))) (($ $ (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-325 (-1265 |#1| |#2| |#3| |#4|)))) (($ $ (-310 (-1265 |#1| |#2| |#3| |#4|))) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-325 (-1265 |#1| |#2| |#3| |#4|)))) (($ $ (-658 (-310 (-1265 |#1| |#2| |#3| |#4|)))) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-325 (-1265 |#1| |#2| |#3| |#4|)))) (($ $ (-658 (-1191)) (-658 (-1265 |#1| |#2| |#3| |#4|))) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-547 (-1191) (-1265 |#1| |#2| |#3| |#4|)))) (($ $ (-1191) (-1265 |#1| |#2| |#3| |#4|)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-547 (-1191) (-1265 |#1| |#2| |#3| |#4|))))) (-2769 (((-790) $) NIL)) (-3927 (($ $ (-1265 |#1| |#2| |#3| |#4|)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-303 (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-247))) (($ $ (-790)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-247))) (($ $ (-1191)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-922 (-1191)))) (($ $ (-1 (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|)) (-790)) NIL) (($ $ (-1 (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|))) NIL)) (-2782 (($ $) NIL)) (-1456 (((-1265 |#1| |#2| |#3| |#4|) $) 17)) (-1778 (((-914 (-592)) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-633 (-914 (-405))))) (((-565) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-633 (-565)))) (((-405) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1049))) (((-237) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1049)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-1265 |#1| |#2| |#3| |#4|) (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-1265 |#1| |#2| |#3| |#4|)) 28) (($ (-1191)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-1065 (-1191)))) (($ (-1264 |#2| |#3| |#4|)) 36)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-1265 |#1| |#2| |#3| |#4|) (-931))) (|has| (-1265 |#1| |#2| |#3| |#4|) (-169))))) (-4010 (((-790)) NIL)) (-2744 (((-1265 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-574)))) (-2537 (((-141) $ $) NIL)) (-1392 (($ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 41 T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-247))) (($ $ (-790)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-247))) (($ $ (-1191)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-922 (-1191)))) (($ $ (-1 (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|)) (-790)) NIL) (($ $ (-1 (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|))) NIL)) (-3286 (((-141) $ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-1265 |#1| |#2| |#3| |#4|) (-869)))) (-3313 (($ $ $) 33) (($ (-1265 |#1| |#2| |#3| |#4|) (-1265 |#1| |#2| |#3| |#4|)) 30)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ (-1265 |#1| |#2| |#3| |#4|) $) 29) (($ $ (-1265 |#1| |#2| |#3| |#4|)) NIL))) 
+(((-329 |#1| |#2| |#3| |#4|) (-13 (-1021 (-1265 |#1| |#2| |#3| |#4|)) (-1065 (-1264 |#2| |#3| |#4|)) (-10 -8 (-15 -1722 ((-3 (-862 |#2|) "failed") $)) (-15 -1683 ($ (-1264 |#2| |#3| |#4|))))) (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477)) (-13 (-27) (-1211) (-456 |#1|)) (-1191) |#2|) (T -329)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1264 *4 *5 *6)) (-4 *4 (-13 (-27) (-1211) (-456 *3))) (-14 *5 (-1191)) (-14 *6 *4) (-4 *3 (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477))) (-5 *1 (-329 *3 *4 *5 *6)))) (-1722 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477))) (-5 *2 (-862 *4)) (-5 *1 (-329 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1211) (-456 *3))) (-14 *5 (-1191)) (-14 *6 *4)))) 
+(-13 (-1021 (-1265 |#1| |#2| |#3| |#4|)) (-1065 (-1264 |#2| |#3| |#4|)) (-10 -8 (-15 -1722 ((-3 (-862 |#2|) "failed") $)) (-15 -1683 ($ (-1264 |#2| |#3| |#4|))))) 
+((-2731 (((-332 |#2|) (-1 |#2| |#1|) (-332 |#1|)) 13))) 
+(((-330 |#1| |#2|) (-10 -7 (-15 -2731 ((-332 |#2|) (-1 |#2| |#1|) (-332 |#1|)))) (-869) (-869)) (T -330)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-332 *5)) (-4 *5 (-869)) (-4 *6 (-869)) (-5 *2 (-332 *6)) (-5 *1 (-330 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-332 |#2|) (-1 |#2| |#1|) (-332 |#1|)))) 
+((-1986 (((-57) |#2| (-310 |#2|) (-790)) 33) (((-57) |#2| (-310 |#2|)) 24) (((-57) |#2| (-790)) 28) (((-57) |#2|) 25) (((-57) (-1191)) 21)) (-2881 (((-57) |#2| (-310 |#2|) (-433 (-592))) 51) (((-57) |#2| (-310 |#2|)) 48) (((-57) |#2| (-433 (-592))) 50) (((-57) |#2|) 49) (((-57) (-1191)) 47)) (-2001 (((-57) |#2| (-310 |#2|) (-433 (-592))) 46) (((-57) |#2| (-310 |#2|)) 43) (((-57) |#2| (-433 (-592))) 45) (((-57) |#2|) 44) (((-57) (-1191)) 42)) (-1994 (((-57) |#2| (-310 |#2|) (-592)) 39) (((-57) |#2| (-310 |#2|)) 35) (((-57) |#2| (-592)) 38) (((-57) |#2|) 36) (((-57) (-1191)) 34))) 
+(((-331 |#1| |#2|) (-10 -7 (-15 -1986 ((-57) (-1191))) (-15 -1986 ((-57) |#2|)) (-15 -1986 ((-57) |#2| (-790))) (-15 -1986 ((-57) |#2| (-310 |#2|))) (-15 -1986 ((-57) |#2| (-310 |#2|) (-790))) (-15 -1994 ((-57) (-1191))) (-15 -1994 ((-57) |#2|)) (-15 -1994 ((-57) |#2| (-592))) (-15 -1994 ((-57) |#2| (-310 |#2|))) (-15 -1994 ((-57) |#2| (-310 |#2|) (-592))) (-15 -2001 ((-57) (-1191))) (-15 -2001 ((-57) |#2|)) (-15 -2001 ((-57) |#2| (-433 (-592)))) (-15 -2001 ((-57) |#2| (-310 |#2|))) (-15 -2001 ((-57) |#2| (-310 |#2|) (-433 (-592)))) (-15 -2881 ((-57) (-1191))) (-15 -2881 ((-57) |#2|)) (-15 -2881 ((-57) |#2| (-433 (-592)))) (-15 -2881 ((-57) |#2| (-310 |#2|))) (-15 -2881 ((-57) |#2| (-310 |#2|) (-433 (-592))))) (-13 (-477) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|))) (T -331)) 
+((-2881 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-310 *3)) (-5 *5 (-433 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *6 *3)))) (-2881 (*1 *2 *3 *4) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)))) (-2881 (*1 *2 *3 *4) (-12 (-5 *4 (-433 (-592))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-2881 (*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) (-2881 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *5)) (-4 *5 (-13 (-27) (-1211) (-456 *4))))) (-2001 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-310 *3)) (-5 *5 (-433 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *6 *3)))) (-2001 (*1 *2 *3 *4) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)))) (-2001 (*1 *2 *3 *4) (-12 (-5 *4 (-433 (-592))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-2001 (*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) (-2001 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *5)) (-4 *5 (-13 (-27) (-1211) (-456 *4))))) (-1994 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 *5) (-654 *5))) (-5 *5 (-592)) (-5 *2 (-57)) (-5 *1 (-331 *6 *3)))) (-1994 (*1 *2 *3 *4) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)))) (-1994 (*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-13 (-477) (-869) (-1065 *4) (-654 *4))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-1994 (*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) (-1994 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *5)) (-4 *5 (-13 (-27) (-1211) (-456 *4))))) (-1986 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-310 *3)) (-5 *5 (-790)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *6 *3)))) (-1986 (*1 *2 *3 *4) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)))) (-1986 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-1986 (*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) (-1986 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *5)) (-4 *5 (-13 (-27) (-1211) (-456 *4)))))) 
+(-10 -7 (-15 -1986 ((-57) (-1191))) (-15 -1986 ((-57) |#2|)) (-15 -1986 ((-57) |#2| (-790))) (-15 -1986 ((-57) |#2| (-310 |#2|))) (-15 -1986 ((-57) |#2| (-310 |#2|) (-790))) (-15 -1994 ((-57) (-1191))) (-15 -1994 ((-57) |#2|)) (-15 -1994 ((-57) |#2| (-592))) (-15 -1994 ((-57) |#2| (-310 |#2|))) (-15 -1994 ((-57) |#2| (-310 |#2|) (-592))) (-15 -2001 ((-57) (-1191))) (-15 -2001 ((-57) |#2|)) (-15 -2001 ((-57) |#2| (-433 (-592)))) (-15 -2001 ((-57) |#2| (-310 |#2|))) (-15 -2001 ((-57) |#2| (-310 |#2|) (-433 (-592)))) (-15 -2881 ((-57) (-1191))) (-15 -2881 ((-57) |#2|)) (-15 -2881 ((-57) |#2| (-433 (-592)))) (-15 -2881 ((-57) |#2| (-310 |#2|))) (-15 -2881 ((-57) |#2| (-310 |#2|) (-433 (-592))))) 
+((-1641 (((-141) $ $) NIL)) (-3863 (((-658 $) $ (-1191)) NIL (|has| |#1| (-582))) (((-658 $) $) NIL (|has| |#1| (-582))) (((-658 $) (-1187 $) (-1191)) NIL (|has| |#1| (-582))) (((-658 $) (-1187 $)) NIL (|has| |#1| (-582))) (((-658 $) (-980 $)) NIL (|has| |#1| (-582)))) (-3224 (($ $ (-1191)) NIL (|has| |#1| (-582))) (($ $) NIL (|has| |#1| (-582))) (($ (-1187 $) (-1191)) NIL (|has| |#1| (-582))) (($ (-1187 $)) NIL (|has| |#1| (-582))) (($ (-980 $)) NIL (|has| |#1| (-582)))) (-2272 (((-141) $) 27 (-3836 (|has| |#1| (-25)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))))) (-4085 (((-658 (-1191)) $) 348)) (-4492 (((-433 (-1187 $)) $ (-631 $)) NIL (|has| |#1| (-582)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2165 (((-658 (-631 $)) $) NIL)) (-1588 (($ $) 154 (|has| |#1| (-582)))) (-1507 (($ $) 130 (|has| |#1| (-582)))) (-2178 (($ $ (-1111 $)) 215 (|has| |#1| (-582))) (($ $ (-1191)) 211 (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) NIL (-3836 (|has| |#1| (-21)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))))) (-3147 (($ $ (-310 $)) NIL) (($ $ (-658 (-310 $))) 364) (($ $ (-658 (-631 $)) (-658 $)) 407)) (-4043 (((-444 (-1187 $)) (-1187 $)) 292 (-12 (|has| |#1| (-477)) (|has| |#1| (-582))))) (-3743 (($ $) NIL (|has| |#1| (-582)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-582)))) (-1442 (($ $) NIL (|has| |#1| (-582)))) (-3652 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1575 (($ $) 150 (|has| |#1| (-582)))) (-1495 (($ $) 126 (|has| |#1| (-582)))) (-1654 (($ $ (-592)) 64 (|has| |#1| (-582)))) (-1601 (($ $) 158 (|has| |#1| (-582)))) (-1521 (($ $) 134 (|has| |#1| (-582)))) (-3001 (($) NIL (-3836 (|has| |#1| (-25)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131))) CONST)) (-1316 (((-658 $) $ (-1191)) NIL (|has| |#1| (-582))) (((-658 $) $) NIL (|has| |#1| (-582))) (((-658 $) (-1187 $) (-1191)) NIL (|has| |#1| (-582))) (((-658 $) (-1187 $)) NIL (|has| |#1| (-582))) (((-658 $) (-980 $)) NIL (|has| |#1| (-582)))) (-3906 (($ $ (-1191)) NIL (|has| |#1| (-582))) (($ $) NIL (|has| |#1| (-582))) (($ (-1187 $) (-1191)) 117 (|has| |#1| (-582))) (($ (-1187 $)) NIL (|has| |#1| (-582))) (($ (-980 $)) NIL (|has| |#1| (-582)))) (-4368 (((-3 (-631 $) "failed") $) 17) (((-3 (-1191) "failed") $) NIL) (((-3 |#1| "failed") $) 416) (((-3 (-53) "failed") $) 321 (-12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-980 |#1|)) "failed") $) NIL (|has| |#1| (-582))) (((-3 (-980 |#1|) "failed") $) NIL (|has| |#1| (-1075))) (((-3 (-433 (-592)) "failed") $) 45 (-3836 (-12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592)))) (|has| |#1| (-1065 (-433 (-592))))))) (-2400 (((-631 $) $) 11) (((-1191) $) NIL) ((|#1| $) 398) (((-53) $) NIL (-12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-980 |#1|)) $) NIL (|has| |#1| (-582))) (((-980 |#1|) $) NIL (|has| |#1| (-1075))) (((-433 (-592)) $) 305 (-3836 (-12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592)))) (|has| |#1| (-1065 (-433 (-592))))))) (-1586 (($ $ $) NIL (|has| |#1| (-582)))) (-3945 (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 110 (|has| |#1| (-1075))) (((-706 |#1|) (-706 $)) 102 (|has| |#1| (-1075))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))) (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))))) (-3657 (($ $) 84 (|has| |#1| (-582)))) (-3371 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131))))) (-1599 (($ $ $) NIL (|has| |#1| (-582)))) (-3679 (($ $ (-1111 $)) 219 (|has| |#1| (-582))) (($ $ (-1191)) 217 (|has| |#1| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-582)))) (-2802 (((-141) $) NIL (|has| |#1| (-582)))) (-4018 (($ $ $) 185 (|has| |#1| (-582)))) (-1435 (($) 120 (|has| |#1| (-582)))) (-3870 (($ $ $) 205 (|has| |#1| (-582)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 370 (|has| |#1| (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 376 (|has| |#1| (-908 (-405))))) (-2243 (($ $) NIL) (($ (-658 $)) NIL)) (-4388 (((-658 (-143)) $) NIL)) (-2791 (((-143) (-143)) 264)) (-3558 (((-141) $) 25 (-3836 (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131))))) (-3372 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-3838 (($ $) 66 (|has| |#1| (-1075)))) (-1448 (((-1142 |#1| (-631 $)) $) 79 (|has| |#1| (-1075)))) (-4168 (((-141) $) 46 (|has| |#1| (-582)))) (-4422 (($ $ (-592)) NIL (|has| |#1| (-582)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-582)))) (-2710 (((-1187 $) (-631 $)) 265 (|has| $ (-1075)))) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 $ $) (-631 $)) 403)) (-4160 (((-3 (-631 $) "failed") $) NIL)) (-4546 (($ $) 124 (|has| |#1| (-582)))) (-1457 (($ $) 230 (|has| |#1| (-582)))) (-2750 (($ (-658 $)) NIL (|has| |#1| (-582))) (($ $ $) NIL (|has| |#1| (-582)))) (-2685 (((-1173) $) NIL)) (-4486 (((-658 (-631 $)) $) 48)) (-1462 (($ (-143) $) NIL) (($ (-143) (-658 $)) 408)) (-4421 (((-3 (-658 $) "failed") $) NIL (|has| |#1| (-1131)))) (-2427 (((-3 (-2 (|:| |val| $) (|:| -3215 (-592))) "failed") $) NIL (|has| |#1| (-1075)))) (-2947 (((-3 (-658 $) "failed") $) 411 (|has| |#1| (-25)))) (-1649 (((-3 (-2 (|:| -1487 (-592)) (|:| |var| (-631 $))) "failed") $) 415 (|has| |#1| (-25)))) (-2257 (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $) NIL (|has| |#1| (-1131))) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-143)) NIL (|has| |#1| (-1075))) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-1191)) NIL (|has| |#1| (-1075)))) (-3013 (((-141) $ (-143)) NIL) (((-141) $ (-1191)) 52)) (-4552 (($ $) NIL (-3836 (|has| |#1| (-502)) (|has| |#1| (-582))))) (-1868 (($ $ (-1191)) 238 (|has| |#1| (-582))) (($ $ (-1111 $)) 240 (|has| |#1| (-582)))) (-2535 (((-790) $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 43)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 285 (|has| |#1| (-582)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-582))) (($ $ $) NIL (|has| |#1| (-582)))) (-2424 (($ $) 234 (|has| |#1| (-582)))) (-1927 (($ $) 236 (|has| |#1| (-582)))) (-1319 (((-141) $ $) NIL) (((-141) $ (-1191)) NIL)) (-2944 (($ $ (-1191)) 209 (|has| |#1| (-582))) (($ $) 207 (|has| |#1| (-582)))) (-2283 (($ $) 201 (|has| |#1| (-582)))) (-3339 (((-444 (-1187 $)) (-1187 $)) 290 (-12 (|has| |#1| (-477)) (|has| |#1| (-582))))) (-4500 (((-444 $) $) NIL (|has| |#1| (-582)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-582))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-582)))) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-582)))) (-1430 (($ $) 122 (|has| |#1| (-582)))) (-3554 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-2806 (($ $ (-631 $) $) NIL) (($ $ (-658 (-631 $)) (-658 $)) 402) (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-1191) (-1 $ (-658 $))) NIL) (($ $ (-1191) (-1 $ $)) NIL) (($ $ (-658 (-143)) (-658 (-1 $ $))) 358) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-143) (-1 $ (-658 $))) NIL) (($ $ (-143) (-1 $ $)) NIL) (($ $ (-1191)) NIL (|has| |#1| (-633 (-565)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-633 (-565)))) (($ $) NIL (|has| |#1| (-633 (-565)))) (($ $ (-143) $ (-1191)) 346 (|has| |#1| (-633 (-565)))) (($ $ (-658 (-143)) (-658 $) (-1191)) 345 (|has| |#1| (-633 (-565)))) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ $))) NIL (|has| |#1| (-1075))) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ (-658 $)))) NIL (|has| |#1| (-1075))) (($ $ (-1191) (-790) (-1 $ (-658 $))) NIL (|has| |#1| (-1075))) (($ $ (-1191) (-790) (-1 $ $)) NIL (|has| |#1| (-1075)))) (-2769 (((-790) $) NIL (|has| |#1| (-582)))) (-1463 (($ $) 222 (|has| |#1| (-582)))) (-3927 (($ (-143) $) NIL) (($ (-143) $ $) NIL) (($ (-143) $ $ $) NIL) (($ (-143) $ $ $ $) NIL) (($ (-143) (-658 $)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-2818 (($ $) NIL) (($ $ $) NIL)) (-1486 (($ $) 232 (|has| |#1| (-582)))) (-2002 (($ $) 183 (|has| |#1| (-582)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-1075))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-1075))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-1075))) (($ $ (-1191)) NIL (|has| |#1| (-1075)))) (-2782 (($ $) 67 (|has| |#1| (-582)))) (-1456 (((-1142 |#1| (-631 $)) $) 81 (|has| |#1| (-582)))) (-3390 (($ $) 303 (|has| $ (-1075)))) (-1609 (($ $) 160 (|has| |#1| (-582)))) (-1527 (($ $) 136 (|has| |#1| (-582)))) (-1594 (($ $) 156 (|has| |#1| (-582)))) (-1515 (($ $) 132 (|has| |#1| (-582)))) (-1581 (($ $) 152 (|has| |#1| (-582)))) (-1501 (($ $) 128 (|has| |#1| (-582)))) (-1778 (((-914 (-592)) $) NIL (|has| |#1| (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| |#1| (-633 (-914 (-405))))) (($ (-444 $)) NIL (|has| |#1| (-582))) (((-565) $) 343 (|has| |#1| (-633 (-565))))) (-2227 (($ $ $) NIL (|has| |#1| (-502)))) (-2131 (($ $ $) NIL (|has| |#1| (-502)))) (-1683 (((-877) $) 401) (($ (-631 $)) 392) (($ (-1191)) 360) (($ |#1|) 322) (($ $) NIL (|has| |#1| (-582))) (($ (-53)) 297 (-12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592))))) (($ (-1142 |#1| (-631 $))) 83 (|has| |#1| (-1075))) (($ (-433 |#1|)) NIL (|has| |#1| (-582))) (($ (-980 (-433 |#1|))) NIL (|has| |#1| (-582))) (($ (-433 (-980 (-433 |#1|)))) NIL (|has| |#1| (-582))) (($ (-433 (-980 |#1|))) NIL (|has| |#1| (-582))) (($ (-980 |#1|)) NIL (|has| |#1| (-1075))) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-582)) (|has| |#1| (-1065 (-433 (-592)))))) (($ (-592)) 34 (-3836 (|has| |#1| (-1065 (-592))) (|has| |#1| (-1075))))) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL (|has| |#1| (-1075)))) (-3280 (($ $) NIL) (($ (-658 $)) NIL)) (-4042 (($ $ $) 203 (|has| |#1| (-582)))) (-2280 (($ $ $) 189 (|has| |#1| (-582)))) (-2500 (($ $ $) 193 (|has| |#1| (-582)))) (-3468 (($ $ $) 187 (|has| |#1| (-582)))) (-2894 (($ $ $) 191 (|has| |#1| (-582)))) (-3038 (((-141) (-143)) 9)) (-1630 (($ $) 166 (|has| |#1| (-582)))) (-1546 (($ $) 142 (|has| |#1| (-582)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) 162 (|has| |#1| (-582)))) (-1533 (($ $) 138 (|has| |#1| (-582)))) (-1642 (($ $) 170 (|has| |#1| (-582)))) (-1559 (($ $) 146 (|has| |#1| (-582)))) (-3270 (($ (-1191) $) NIL) (($ (-1191) $ $) NIL) (($ (-1191) $ $ $) NIL) (($ (-1191) $ $ $ $) NIL) (($ (-1191) (-658 $)) NIL)) (-2156 (($ $) 197 (|has| |#1| (-582)))) (-3132 (($ $) 195 (|has| |#1| (-582)))) (-2892 (($ $) 172 (|has| |#1| (-582)))) (-1567 (($ $) 148 (|has| |#1| (-582)))) (-1636 (($ $) 168 (|has| |#1| (-582)))) (-1552 (($ $) 144 (|has| |#1| (-582)))) (-1624 (($ $) 164 (|has| |#1| (-582)))) (-1540 (($ $) 140 (|has| |#1| (-582)))) (-1392 (($ $) 175 (|has| |#1| (-582)))) (-1424 (($ $ (-592)) NIL (-3836 (|has| |#1| (-502)) (|has| |#1| (-582)))) (($ $ (-790)) NIL (-3836 (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131)))) (($ $ (-944)) NIL (-3836 (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131))))) (-3514 (($) 20 (-3836 (|has| |#1| (-25)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))) CONST)) (-2672 (($ $) 226 (|has| |#1| (-582)))) (-4257 (($) 22 (-3836 (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131))) CONST)) (-2348 (($ $) 177 (|has| |#1| (-582))) (($ $ $) 179 (|has| |#1| (-582)))) (-4299 (($ $) 224 (|has| |#1| (-582)))) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-1075))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-1075))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-1075))) (($ $ (-1191)) NIL (|has| |#1| (-1075)))) (-4157 (($ $) 228 (|has| |#1| (-582)))) (-2170 (($ $ $) 181 (|has| |#1| (-582)))) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 76)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 75)) (-3313 (($ (-1142 |#1| (-631 $)) (-1142 |#1| (-631 $))) 93 (|has| |#1| (-582))) (($ $ $) 42 (-3836 (|has| |#1| (-502)) (|has| |#1| (-582))))) (-3306 (($ $ $) 40 (-3836 (|has| |#1| (-21)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))))) (($ $) 29 (-3836 (|has| |#1| (-21)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))))) (-3300 (($ $ $) 38 (-3836 (|has| |#1| (-25)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))))) (** (($ $ $) 61 (|has| |#1| (-582))) (($ $ (-433 (-592))) 300 (|has| |#1| (-582))) (($ $ (-592)) 71 (-3836 (|has| |#1| (-502)) (|has| |#1| (-582)))) (($ $ (-790)) 68 (-3836 (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131)))) (($ $ (-944)) 73 (-3836 (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131))))) (* (($ (-433 (-592)) $) NIL (|has| |#1| (-582))) (($ $ (-433 (-592))) NIL (|has| |#1| (-582))) (($ |#1| $) NIL (|has| |#1| (-194))) (($ $ |#1|) NIL (|has| |#1| (-194))) (($ $ $) 36 (-3836 (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) (|has| |#1| (-1131)))) (($ (-592) $) 32 (-3836 (|has| |#1| (-21)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))))) (($ (-790) $) NIL (-3836 (|has| |#1| (-25)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))))) (($ (-944) $) NIL (-3836 (|has| |#1| (-25)) (-12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))))))) 
+(((-332 |#1|) (-13 (-456 |#1|) (-10 -8 (IF (|has| |#1| (-582)) (PROGN (-6 (-29 |#1|)) (-6 (-1211)) (-6 (-182)) (-6 (-644)) (-6 (-1153)) (-15 -3657 ($ $)) (-15 -4168 ((-141) $)) (-15 -1654 ($ $ (-592))) (IF (|has| |#1| (-477)) (PROGN (-15 -3339 ((-444 (-1187 $)) (-1187 $))) (-15 -4043 ((-444 (-1187 $)) (-1187 $)))) |noBranch|) (IF (|has| |#1| (-1065 (-592))) (-6 (-1065 (-53))) |noBranch|)) |noBranch|))) (-869)) (T -332)) 
+((-3657 (*1 *1 *1) (-12 (-5 *1 (-332 *2)) (-4 *2 (-582)) (-4 *2 (-869)))) (-4168 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-332 *3)) (-4 *3 (-582)) (-4 *3 (-869)))) (-1654 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-332 *3)) (-4 *3 (-582)) (-4 *3 (-869)))) (-3339 (*1 *2 *3) (-12 (-5 *2 (-444 (-1187 *1))) (-5 *1 (-332 *4)) (-5 *3 (-1187 *1)) (-4 *4 (-477)) (-4 *4 (-582)) (-4 *4 (-869)))) (-4043 (*1 *2 *3) (-12 (-5 *2 (-444 (-1187 *1))) (-5 *1 (-332 *4)) (-5 *3 (-1187 *1)) (-4 *4 (-477)) (-4 *4 (-582)) (-4 *4 (-869))))) 
+(-13 (-456 |#1|) (-10 -8 (IF (|has| |#1| (-582)) (PROGN (-6 (-29 |#1|)) (-6 (-1211)) (-6 (-182)) (-6 (-644)) (-6 (-1153)) (-15 -3657 ($ $)) (-15 -4168 ((-141) $)) (-15 -1654 ($ $ (-592))) (IF (|has| |#1| (-477)) (PROGN (-15 -3339 ((-444 (-1187 $)) (-1187 $))) (-15 -4043 ((-444 (-1187 $)) (-1187 $)))) |noBranch|) (IF (|has| |#1| (-1065 (-592))) (-6 (-1065 (-53))) |noBranch|)) |noBranch|))) 
+((-3016 (((-57) |#2| (-143) (-310 |#2|) (-658 |#2|)) 86) (((-57) |#2| (-143) (-310 |#2|) (-310 |#2|)) 82) (((-57) |#2| (-143) (-310 |#2|) |#2|) 84) (((-57) (-310 |#2|) (-143) (-310 |#2|) |#2|) 85) (((-57) (-658 |#2|) (-658 (-143)) (-310 |#2|) (-658 (-310 |#2|))) 78) (((-57) (-658 |#2|) (-658 (-143)) (-310 |#2|) (-658 |#2|)) 80) (((-57) (-658 (-310 |#2|)) (-658 (-143)) (-310 |#2|) (-658 |#2|)) 81) (((-57) (-658 (-310 |#2|)) (-658 (-143)) (-310 |#2|) (-658 (-310 |#2|))) 79) (((-57) (-310 |#2|) (-143) (-310 |#2|) (-658 |#2|)) 87) (((-57) (-310 |#2|) (-143) (-310 |#2|) (-310 |#2|)) 83))) 
+(((-333 |#1| |#2|) (-10 -7 (-15 -3016 ((-57) (-310 |#2|) (-143) (-310 |#2|) (-310 |#2|))) (-15 -3016 ((-57) (-310 |#2|) (-143) (-310 |#2|) (-658 |#2|))) (-15 -3016 ((-57) (-658 (-310 |#2|)) (-658 (-143)) (-310 |#2|) (-658 (-310 |#2|)))) (-15 -3016 ((-57) (-658 (-310 |#2|)) (-658 (-143)) (-310 |#2|) (-658 |#2|))) (-15 -3016 ((-57) (-658 |#2|) (-658 (-143)) (-310 |#2|) (-658 |#2|))) (-15 -3016 ((-57) (-658 |#2|) (-658 (-143)) (-310 |#2|) (-658 (-310 |#2|)))) (-15 -3016 ((-57) (-310 |#2|) (-143) (-310 |#2|) |#2|)) (-15 -3016 ((-57) |#2| (-143) (-310 |#2|) |#2|)) (-15 -3016 ((-57) |#2| (-143) (-310 |#2|) (-310 |#2|))) (-15 -3016 ((-57) |#2| (-143) (-310 |#2|) (-658 |#2|)))) (-13 (-869) (-582) (-633 (-565))) (-456 |#1|)) (T -333)) 
+((-3016 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-143)) (-5 *5 (-310 *3)) (-5 *6 (-658 *3)) (-4 *3 (-456 *7)) (-4 *7 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *7 *3)))) (-3016 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-143)) (-5 *5 (-310 *3)) (-4 *3 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *3)))) (-3016 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-143)) (-5 *5 (-310 *3)) (-4 *3 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *3)))) (-3016 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-310 *5)) (-5 *4 (-143)) (-4 *5 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *5)))) (-3016 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 (-143))) (-5 *6 (-658 (-310 *8))) (-4 *8 (-456 *7)) (-5 *5 (-310 *8)) (-4 *7 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *7 *8)))) (-3016 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-658 *7)) (-5 *4 (-658 (-143))) (-5 *5 (-310 *7)) (-4 *7 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *7)))) (-3016 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 (-310 *8))) (-5 *4 (-658 (-143))) (-5 *5 (-310 *8)) (-5 *6 (-658 *8)) (-4 *8 (-456 *7)) (-4 *7 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *7 *8)))) (-3016 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-658 (-310 *7))) (-5 *4 (-658 (-143))) (-5 *5 (-310 *7)) (-4 *7 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *7)))) (-3016 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-310 *7)) (-5 *4 (-143)) (-5 *5 (-658 *7)) (-4 *7 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *7)))) (-3016 (*1 *2 *3 *4 *3 *3) (-12 (-5 *3 (-310 *6)) (-5 *4 (-143)) (-4 *6 (-456 *5)) (-4 *5 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *5 *6))))) 
+(-10 -7 (-15 -3016 ((-57) (-310 |#2|) (-143) (-310 |#2|) (-310 |#2|))) (-15 -3016 ((-57) (-310 |#2|) (-143) (-310 |#2|) (-658 |#2|))) (-15 -3016 ((-57) (-658 (-310 |#2|)) (-658 (-143)) (-310 |#2|) (-658 (-310 |#2|)))) (-15 -3016 ((-57) (-658 (-310 |#2|)) (-658 (-143)) (-310 |#2|) (-658 |#2|))) (-15 -3016 ((-57) (-658 |#2|) (-658 (-143)) (-310 |#2|) (-658 |#2|))) (-15 -3016 ((-57) (-658 |#2|) (-658 (-143)) (-310 |#2|) (-658 (-310 |#2|)))) (-15 -3016 ((-57) (-310 |#2|) (-143) (-310 |#2|) |#2|)) (-15 -3016 ((-57) |#2| (-143) (-310 |#2|) |#2|)) (-15 -3016 ((-57) |#2| (-143) (-310 |#2|) (-310 |#2|))) (-15 -3016 ((-57) |#2| (-143) (-310 |#2|) (-658 |#2|)))) 
+((-3016 ((|#3| |#2| (-143) (-1191) (-658 |#2|)) 53)) (-3294 ((|#2| |#2| (-143) (-1191)) 30))) 
+(((-334 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3016 (|#3| |#2| (-143) (-1191) (-658 |#2|))) (-15 -3294 (|#2| |#2| (-143) (-1191)))) (-13 (-869) (-582) (-633 (-565))) (-456 |#1|) (-1270 |#2|) (-1270 (-1185 |#2|))) (T -334)) 
+((-3294 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-143)) (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-582) (-633 (-565)))) (-4 *2 (-456 *5)) (-5 *1 (-334 *5 *2 *6 *7)) (-4 *6 (-1270 *2)) (-4 *7 (-1270 (-1185 *2))))) (-3016 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-143)) (-5 *5 (-1191)) (-5 *6 (-658 *3)) (-4 *3 (-456 *7)) (-4 *7 (-13 (-869) (-582) (-633 (-565)))) (-4 *2 (-1270 *3)) (-5 *1 (-334 *7 *3 *2 *8)) (-4 *8 (-1270 (-1185 *3)))))) 
+(-10 -7 (-15 -3016 (|#3| |#2| (-143) (-1191) (-658 |#2|))) (-15 -3294 (|#2| |#2| (-143) (-1191)))) 
+((-2215 (((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-237) (-592) (-1173)) 45) (((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-237) (-592)) 46) (((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-1 (-237) (-237)) (-592) (-1173)) 42) (((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-1 (-237) (-237)) (-592)) 43)) (-2477 (((-1 (-237) (-237)) (-237)) 44))) 
+(((-335) (-10 -7 (-15 -2477 ((-1 (-237) (-237)) (-237))) (-15 -2215 ((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-1 (-237) (-237)) (-592))) (-15 -2215 ((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-1 (-237) (-237)) (-592) (-1173))) (-15 -2215 ((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-237) (-592))) (-15 -2215 ((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-237) (-592) (-1173))))) (T -335)) 
+((-2215 (*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-237)) (-5 *7 (-592)) (-5 *8 (-1173)) (-5 *2 (-1221 (-953))) (-5 *1 (-335)))) (-2215 (*1 *2 *3 *3 *3 *4 *5 *6 *7) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-237)) (-5 *7 (-592)) (-5 *2 (-1221 (-953))) (-5 *1 (-335)))) (-2215 (*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-592)) (-5 *7 (-1173)) (-5 *2 (-1221 (-953))) (-5 *1 (-335)))) (-2215 (*1 *2 *3 *3 *3 *4 *5 *4 *6) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-592)) (-5 *2 (-1221 (-953))) (-5 *1 (-335)))) (-2477 (*1 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *1 (-335)) (-5 *3 (-237))))) 
+(-10 -7 (-15 -2477 ((-1 (-237) (-237)) (-237))) (-15 -2215 ((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-1 (-237) (-237)) (-592))) (-15 -2215 ((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-1 (-237) (-237)) (-592) (-1173))) (-15 -2215 ((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-237) (-592))) (-15 -2215 ((-1221 (-953)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-237) (-592) (-1173)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 24)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-433 (-592))) NIL) (($ $ (-433 (-592)) (-433 (-592))) NIL)) (-2982 (((-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|))) $) 19)) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-790) (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|)))) NIL)) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) 30)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-433 (-592)) $) NIL) (((-433 (-592)) $ (-433 (-592))) 15)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) NIL) (($ $ (-433 (-592))) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-433 (-592))) NIL) (($ $ (-1103) (-433 (-592))) NIL) (($ $ (-658 (-1103)) (-658 (-433 (-592)))) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-3162 (($ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211)))))) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-2807 (($ $ (-433 (-592))) NIL)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2160 (((-433 (-592)) $) 16)) (-4331 (($ (-1264 |#1| |#2| |#3|)) 11)) (-3215 (((-1264 |#1| |#2| |#3|) $) 12)) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ (-433 (-592))) NIL) (($ $ $) NIL (|has| (-433 (-592)) (-1131)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-4525 (((-433 (-592)) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 10)) (-1683 (((-877) $) 36) (($ (-592)) NIL) (($ |#1|) NIL (|has| |#1| (-194))) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582)))) (-1937 ((|#1| $ (-433 (-592))) 28)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) NIL)) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-433 (-592))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 26)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 31)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-336 |#1| |#2| |#3|) (-13 (-1260 |#1|) (-814) (-10 -8 (-15 -4331 ($ (-1264 |#1| |#2| |#3|))) (-15 -3215 ((-1264 |#1| |#2| |#3|) $)) (-15 -2160 ((-433 (-592)) $)))) (-13 (-388) (-869)) (-1191) |#1|) (T -336)) 
+((-4331 (*1 *1 *2) (-12 (-5 *2 (-1264 *3 *4 *5)) (-4 *3 (-13 (-388) (-869))) (-14 *4 (-1191)) (-14 *5 *3) (-5 *1 (-336 *3 *4 *5)))) (-3215 (*1 *2 *1) (-12 (-5 *2 (-1264 *3 *4 *5)) (-5 *1 (-336 *3 *4 *5)) (-4 *3 (-13 (-388) (-869))) (-14 *4 (-1191)) (-14 *5 *3))) (-2160 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-336 *3 *4 *5)) (-4 *3 (-13 (-388) (-869))) (-14 *4 (-1191)) (-14 *5 *3)))) 
+(-13 (-1260 |#1|) (-814) (-10 -8 (-15 -4331 ($ (-1264 |#1| |#2| |#3|))) (-15 -3215 ((-1264 |#1| |#2| |#3|) $)) (-15 -2160 ((-433 (-592)) $)))) 
+((-3594 (((-444 (-1187 |#1|)) (-1187 |#1|) |#1|) 15)) (-4500 (((-444 (-1187 |#1|)) (-1187 |#1|) |#1|) 24))) 
+(((-337 |#1|) (-10 -7 (-15 -4500 ((-444 (-1187 |#1|)) (-1187 |#1|) |#1|)) (-15 -3594 ((-444 (-1187 |#1|)) (-1187 |#1|) |#1|))) (-881)) (T -337)) 
+((-3594 (*1 *2 *3 *4) (-12 (-4 *4 (-881)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-337 *4)) (-5 *3 (-1187 *4)))) (-4500 (*1 *2 *3 *4) (-12 (-4 *4 (-881)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-337 *4)) (-5 *3 (-1187 *4))))) 
+(-10 -7 (-15 -4500 ((-444 (-1187 |#1|)) (-1187 |#1|) |#1|)) (-15 -3594 ((-444 (-1187 |#1|)) (-1187 |#1|) |#1|))) 
+((-4422 (((-2 (|:| -3215 (-790)) (|:| -1487 |#1|) (|:| |radicand| (-658 |#1|))) (-444 |#1|) (-790)) 24)) (-4546 (((-658 (-2 (|:| -1487 (-790)) (|:| |logand| |#1|))) (-444 |#1|)) 28))) 
+(((-338 |#1|) (-10 -7 (-15 -4422 ((-2 (|:| -3215 (-790)) (|:| -1487 |#1|) (|:| |radicand| (-658 |#1|))) (-444 |#1|) (-790))) (-15 -4546 ((-658 (-2 (|:| -1487 (-790)) (|:| |logand| |#1|))) (-444 |#1|)))) (-582)) (T -338)) 
+((-4546 (*1 *2 *3) (-12 (-5 *3 (-444 *4)) (-4 *4 (-582)) (-5 *2 (-658 (-2 (|:| -1487 (-790)) (|:| |logand| *4)))) (-5 *1 (-338 *4)))) (-4422 (*1 *2 *3 *4) (-12 (-5 *3 (-444 *5)) (-4 *5 (-582)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *5) (|:| |radicand| (-658 *5)))) (-5 *1 (-338 *5)) (-5 *4 (-790))))) 
+(-10 -7 (-15 -4422 ((-2 (|:| -3215 (-790)) (|:| -1487 |#1|) (|:| |radicand| (-658 |#1|))) (-444 |#1|) (-790))) (-15 -4546 ((-658 (-2 (|:| -1487 (-790)) (|:| |logand| |#1|))) (-444 |#1|)))) 
+((-3594 (((-444 (-1187 |#1|)) (-1187 |#1|) |#1|) 15)) (-4500 (((-444 (-1187 |#1|)) (-1187 |#1|) |#1|) 24))) 
+(((-339 |#1|) (-10 -7 (-15 -4500 ((-444 (-1187 |#1|)) (-1187 |#1|) |#1|)) (-15 -3594 ((-444 (-1187 |#1|)) (-1187 |#1|) |#1|))) (-886)) (T -339)) 
+((-3594 (*1 *2 *3 *4) (-12 (-4 *4 (-886)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-339 *4)) (-5 *3 (-1187 *4)))) (-4500 (*1 *2 *3 *4) (-12 (-4 *4 (-886)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-339 *4)) (-5 *3 (-1187 *4))))) 
+(-10 -7 (-15 -4500 ((-444 (-1187 |#1|)) (-1187 |#1|) |#1|)) (-15 -3594 ((-444 (-1187 |#1|)) (-1187 |#1|) |#1|))) 
+((-4085 (((-658 |#2|) (-1187 |#4|)) 43)) (-4558 ((|#3| (-592)) 46)) (-1922 (((-1187 |#4|) (-1187 |#3|)) 30)) (-1396 (((-1187 |#4|) (-1187 |#4|) (-592)) 55)) (-3893 (((-1187 |#3|) (-1187 |#4|)) 21)) (-4525 (((-658 (-790)) (-1187 |#4|) (-658 |#2|)) 40)) (-1883 (((-1187 |#3|) (-1187 |#4|) (-658 |#2|) (-658 |#3|)) 35))) 
+(((-340 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1883 ((-1187 |#3|) (-1187 |#4|) (-658 |#2|) (-658 |#3|))) (-15 -4525 ((-658 (-790)) (-1187 |#4|) (-658 |#2|))) (-15 -4085 ((-658 |#2|) (-1187 |#4|))) (-15 -3893 ((-1187 |#3|) (-1187 |#4|))) (-15 -1922 ((-1187 |#4|) (-1187 |#3|))) (-15 -1396 ((-1187 |#4|) (-1187 |#4|) (-592))) (-15 -4558 (|#3| (-592)))) (-815) (-869) (-1075) (-977 |#3| |#1| |#2|)) (T -340)) 
+((-4558 (*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1075)) (-5 *1 (-340 *4 *5 *2 *6)) (-4 *6 (-977 *2 *4 *5)))) (-1396 (*1 *2 *2 *3) (-12 (-5 *2 (-1187 *7)) (-5 *3 (-592)) (-4 *7 (-977 *6 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-5 *1 (-340 *4 *5 *6 *7)))) (-1922 (*1 *2 *3) (-12 (-5 *3 (-1187 *6)) (-4 *6 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-1187 *7)) (-5 *1 (-340 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5)))) (-3893 (*1 *2 *3) (-12 (-5 *3 (-1187 *7)) (-4 *7 (-977 *6 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-5 *2 (-1187 *6)) (-5 *1 (-340 *4 *5 *6 *7)))) (-4085 (*1 *2 *3) (-12 (-5 *3 (-1187 *7)) (-4 *7 (-977 *6 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-5 *2 (-658 *5)) (-5 *1 (-340 *4 *5 *6 *7)))) (-4525 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 *8)) (-5 *4 (-658 *6)) (-4 *6 (-869)) (-4 *8 (-977 *7 *5 *6)) (-4 *5 (-815)) (-4 *7 (-1075)) (-5 *2 (-658 (-790))) (-5 *1 (-340 *5 *6 *7 *8)))) (-1883 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1187 *9)) (-5 *4 (-658 *7)) (-5 *5 (-658 *8)) (-4 *7 (-869)) (-4 *8 (-1075)) (-4 *9 (-977 *8 *6 *7)) (-4 *6 (-815)) (-5 *2 (-1187 *8)) (-5 *1 (-340 *6 *7 *8 *9))))) 
+(-10 -7 (-15 -1883 ((-1187 |#3|) (-1187 |#4|) (-658 |#2|) (-658 |#3|))) (-15 -4525 ((-658 (-790)) (-1187 |#4|) (-658 |#2|))) (-15 -4085 ((-658 |#2|) (-1187 |#4|))) (-15 -3893 ((-1187 |#3|) (-1187 |#4|))) (-15 -1922 ((-1187 |#4|) (-1187 |#3|))) (-15 -1396 ((-1187 |#4|) (-1187 |#4|) (-592))) (-15 -4558 (|#3| (-592)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 14)) (-2982 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-592)))) $) 18)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1403 (((-790) $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-4449 ((|#1| $ (-592)) NIL)) (-2077 (((-592) $ (-592)) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3401 (($ (-1 |#1| |#1|) $) NIL)) (-3271 (($ (-1 (-592) (-592)) $) 10)) (-2685 (((-1173) $) NIL)) (-1619 (($ $ $) NIL (|has| (-592) (-814)))) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL) (($ |#1|) NIL)) (-1937 (((-592) |#1| $) NIL)) (-3514 (($) 15 T CONST)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) 21 (|has| |#1| (-869)))) (-3306 (($ $) 11) (($ $ $) 20)) (-3300 (($ $ $) NIL) (($ |#1| $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ (-592)) NIL) (($ (-592) |#1|) 19))) 
+(((-341 |#1|) (-13 (-21) (-734 (-592)) (-342 |#1| (-592)) (-10 -7 (IF (|has| |#1| (-869)) (-6 (-869)) |noBranch|))) (-1119)) (T -341)) 
+NIL 
+(-13 (-21) (-734 (-592)) (-342 |#1| (-592)) (-10 -7 (IF (|has| |#1| (-869)) (-6 (-869)) |noBranch|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2982 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 |#2|))) $) 26)) (-2350 (((-3 $ "failed") $ $) 18)) (-1403 (((-790) $) 27)) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 31)) (-2400 ((|#1| $) 30)) (-4449 ((|#1| $ (-592)) 24)) (-2077 ((|#2| $ (-592)) 25)) (-3401 (($ (-1 |#1| |#1|) $) 21)) (-3271 (($ (-1 |#2| |#2|) $) 22)) (-2685 (((-1173) $) 9)) (-1619 (($ $ $) 20 (|has| |#2| (-814)))) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ |#1|) 32)) (-1937 ((|#2| |#1| $) 23)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3300 (($ $ $) 13) (($ |#1| $) 29)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ |#2| |#1|) 28))) 
+(((-342 |#1| |#2|) (-1311) (-1119) (-158)) (T -342)) 
+((-3300 (*1 *1 *2 *1) (-12 (-4 *1 (-342 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-158)))) (* (*1 *1 *2 *3) (-12 (-4 *1 (-342 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-158)))) (-1403 (*1 *2 *1) (-12 (-4 *1 (-342 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-158)) (-5 *2 (-790)))) (-2982 (*1 *2 *1) (-12 (-4 *1 (-342 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-158)) (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 *4)))))) (-2077 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-342 *4 *2)) (-4 *4 (-1119)) (-4 *2 (-158)))) (-4449 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-342 *2 *4)) (-4 *4 (-158)) (-4 *2 (-1119)))) (-1937 (*1 *2 *3 *1) (-12 (-4 *1 (-342 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-158)))) (-3271 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-342 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-158)))) (-3401 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-342 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-158)))) (-1619 (*1 *1 *1 *1) (-12 (-4 *1 (-342 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-158)) (-4 *3 (-814))))) 
+(-13 (-158) (-1065 |t#1|) (-10 -8 (-15 -3300 ($ |t#1| $)) (-15 * ($ |t#2| |t#1|)) (-15 -1403 ((-790) $)) (-15 -2982 ((-658 (-2 (|:| |gen| |t#1|) (|:| -1430 |t#2|))) $)) (-15 -2077 (|t#2| $ (-592))) (-15 -4449 (|t#1| $ (-592))) (-15 -1937 (|t#2| |t#1| $)) (-15 -3271 ($ (-1 |t#2| |t#2|) $)) (-15 -3401 ($ (-1 |t#1| |t#1|) $)) (IF (|has| |t#2| (-814)) (-15 -1619 ($ $ $)) |noBranch|))) 
+(((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-1065 |#1|) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2982 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-790)))) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1403 (((-790) $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-4449 ((|#1| $ (-592)) NIL)) (-2077 (((-790) $ (-592)) NIL)) (-3401 (($ (-1 |#1| |#1|) $) NIL)) (-3271 (($ (-1 (-790) (-790)) $) NIL)) (-2685 (((-1173) $) NIL)) (-1619 (($ $ $) NIL (|has| (-790) (-814)))) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL) (($ |#1|) NIL)) (-1937 (((-790) |#1| $) NIL)) (-3514 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3300 (($ $ $) NIL) (($ |#1| $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-790) |#1|) NIL))) 
+(((-343 |#1|) (-342 |#1| (-790)) (-1119)) (T -343)) 
+NIL 
+(-342 |#1| (-790)) 
+((-2731 ((|#5| (-1 |#4| |#2|) |#3|) 19))) 
+(((-344 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2731 (|#5| (-1 |#4| |#2|) |#3|))) (-814) (-1075) (-346 |#2| |#1|) (-1075) (-346 |#4| |#1|)) (T -344)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-4 *6 (-1075)) (-4 *7 (-1075)) (-4 *5 (-814)) (-4 *2 (-346 *7 *5)) (-5 *1 (-344 *5 *6 *4 *7 *2)) (-4 *4 (-346 *6 *5))))) 
+(-10 -7 (-15 -2731 (|#5| (-1 |#4| |#2|) |#3|))) 
+((-3262 (($ $) 52)) (-4209 (($ $ |#2| |#3| $) 14)) (-2976 (($ (-1 |#3| |#3|) $) 35)) (-4559 (((-141) $) 27)) (-4565 ((|#2| $) 29)) (-3616 (((-3 $ "failed") $ $) NIL) (((-3 $ "failed") $ |#2|) 45)) (-1554 ((|#2| $) 48)) (-1647 (((-658 |#2|) $) 38)) (-4064 (($ $ $ (-790)) 23)) (-3313 (($ $ |#2|) 42))) 
+(((-345 |#1| |#2| |#3|) (-10 -8 (-15 -3262 (|#1| |#1|)) (-15 -1554 (|#2| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#2|)) (-15 -4064 (|#1| |#1| |#1| (-790))) (-15 -4209 (|#1| |#1| |#2| |#3| |#1|)) (-15 -2976 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -1647 ((-658 |#2|) |#1|)) (-15 -4565 (|#2| |#1|)) (-15 -4559 ((-141) |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3313 (|#1| |#1| |#2|))) (-346 |#2| |#3|) (-1075) (-814)) (T -345)) 
+NIL 
+(-10 -8 (-15 -3262 (|#1| |#1|)) (-15 -1554 (|#2| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#2|)) (-15 -4064 (|#1| |#1| |#1| (-790))) (-15 -4209 (|#1| |#1| |#2| |#3| |#1|)) (-15 -2976 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -1647 ((-658 |#2|) |#1|)) (-15 -4565 (|#2| |#1|)) (-15 -4559 ((-141) |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3313 (|#1| |#1| |#2|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 86 (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 84 (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 83)) (-2400 (((-592) $) 87 (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) 85 (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 82)) (-4593 (($ $) 59)) (-3371 (((-3 $ "failed") $) 33)) (-3262 (($ $) 71 (|has| |#1| (-477)))) (-4209 (($ $ |#1| |#2| $) 75)) (-3558 (((-141) $) 30)) (-4036 (((-790) $) 78)) (-2027 (((-141) $) 61)) (-4526 (($ |#1| |#2|) 60)) (-4206 ((|#2| $) 77)) (-2976 (($ (-1 |#2| |#2|) $) 76)) (-2731 (($ (-1 |#1| |#1|) $) 62)) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 81)) (-4565 ((|#1| $) 80)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582))) (((-3 $ "failed") $ |#1|) 73 (|has| |#1| (-582)))) (-4525 ((|#2| $) 63)) (-1554 ((|#1| $) 72 (|has| |#1| (-477)))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 48 (|has| |#1| (-582))) (($ |#1|) 46) (($ (-433 (-592))) 56 (-3836 (|has| |#1| (-1065 (-433 (-592)))) (|has| |#1| (-43 (-433 (-592))))))) (-1647 (((-658 |#1|) $) 79)) (-1937 ((|#1| $ |#2|) 58)) (-1517 (((-3 $ "failed") $) 47 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-4064 (($ $ $ (-790)) 74 (|has| |#1| (-194)))) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-346 |#1| |#2|) (-1311) (-1075) (-814)) (T -346)) 
+((-4559 (*1 *2 *1) (-12 (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-141)))) (-4565 (*1 *2 *1) (-12 (-4 *1 (-346 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) (-1647 (*1 *2 *1) (-12 (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-658 *3)))) (-4036 (*1 *2 *1) (-12 (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-790)))) (-4206 (*1 *2 *1) (-12 (-4 *1 (-346 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) (-2976 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)))) (-4209 (*1 *1 *1 *2 *3 *1) (-12 (-4 *1 (-346 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)))) (-4064 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-4 *3 (-194)))) (-3616 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-346 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *2 (-582)))) (-1554 (*1 *2 *1) (-12 (-4 *1 (-346 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)) (-4 *2 (-477)))) (-3262 (*1 *1 *1) (-12 (-4 *1 (-346 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *2 (-477))))) 
+(-13 (-52 |t#1| |t#2|) (-437 |t#1|) (-10 -8 (-15 -4559 ((-141) $)) (-15 -4565 (|t#1| $)) (-15 -1647 ((-658 |t#1|) $)) (-15 -4036 ((-790) $)) (-15 -4206 (|t#2| $)) (-15 -2976 ($ (-1 |t#2| |t#2|) $)) (-15 -4209 ($ $ |t#1| |t#2| $)) (IF (|has| |t#1| (-194)) (-15 -4064 ($ $ $ (-790))) |noBranch|) (IF (|has| |t#1| (-582)) (-15 -3616 ((-3 $ "failed") $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-477)) (PROGN (-15 -1554 (|t#1| $)) (-15 -3262 ($ $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) |has| |#1| (-582)) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-307) |has| |#1| (-582)) ((-437 |#1|) . T) ((-582) |has| |#1| (-582)) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) |has| |#1| (-582)) ((-743) . T) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) NIL) (((-141) $) NIL (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3071 (((-141) (-141)) NIL)) (-3932 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626)))) (-4125 (($ (-1 (-141) |#1|) $) NIL)) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1461 (($ $) NIL (|has| |#1| (-1119)))) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4065 (($ |#1| $) NIL (|has| |#1| (-1119))) (($ (-1 (-141) |#1|) $) NIL)) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-1721 (((-592) (-1 (-141) |#1|) $) NIL) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119)))) (-2056 (($ $ (-592)) NIL)) (-2329 (((-790) $) NIL)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) |#1|) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-2713 (($ $ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) NIL)) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2113 (($ $ $ (-592)) NIL) (($ |#1| $ (-592)) NIL)) (-3666 (($ |#1| $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3769 (($ (-658 |#1|)) NIL)) (-1918 ((|#1| $) NIL (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) |#1|) NIL) ((|#1| $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-4113 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-3619 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2266 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-347 |#1|) (-13 (-19 |#1|) (-299 |#1|) (-10 -8 (-15 -3769 ($ (-658 |#1|))) (-15 -2329 ((-790) $)) (-15 -2056 ($ $ (-592))) (-15 -3071 ((-141) (-141))))) (-1225)) (T -347)) 
+((-3769 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-347 *3)))) (-2329 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-347 *3)) (-4 *3 (-1225)))) (-2056 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-347 *3)) (-4 *3 (-1225)))) (-3071 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-347 *3)) (-4 *3 (-1225))))) 
+(-13 (-19 |#1|) (-299 |#1|) (-10 -8 (-15 -3769 ($ (-658 |#1|))) (-15 -2329 ((-790) $)) (-15 -2056 ($ $ (-592))) (-15 -3071 ((-141) (-141))))) 
+((-1917 (((-141) $) 37)) (-4424 (((-790)) 22)) (-4529 ((|#2| $) 41) (($ $ (-944)) 99)) (-1403 (((-790)) 93)) (-1626 (($ (-1280 |#2|)) 20)) (-2114 (((-141) $) 111)) (-2793 ((|#2| $) 43) (($ $ (-944)) 97)) (-3504 (((-1187 |#2|) $) NIL) (((-1187 $) $ (-944)) 88)) (-2343 (((-1187 |#2|) $) 78)) (-1492 (((-1187 |#2|) $) 75) (((-3 (-1187 |#2|) "failed") $ $) 72)) (-2252 (($ $ (-1187 |#2|)) 48)) (-3470 (((-855 (-944))) 91) (((-944)) 38)) (-1936 (((-160)) 25)) (-4525 (((-855 (-944)) $) NIL) (((-944) $) 112)) (-3342 (($) 105)) (-2231 (((-1280 |#2|) $) NIL) (((-706 |#2|) (-1280 $)) 34)) (-1517 (($ $) NIL) (((-3 $ "failed") $) 81)) (-3069 (((-141) $) 36))) 
+(((-348 |#1| |#2|) (-10 -8 (-15 -1517 ((-3 |#1| "failed") |#1|)) (-15 -1403 ((-790))) (-15 -1517 (|#1| |#1|)) (-15 -1492 ((-3 (-1187 |#2|) "failed") |#1| |#1|)) (-15 -1492 ((-1187 |#2|) |#1|)) (-15 -2343 ((-1187 |#2|) |#1|)) (-15 -2252 (|#1| |#1| (-1187 |#2|))) (-15 -2114 ((-141) |#1|)) (-15 -3342 (|#1|)) (-15 -4529 (|#1| |#1| (-944))) (-15 -2793 (|#1| |#1| (-944))) (-15 -3504 ((-1187 |#1|) |#1| (-944))) (-15 -4529 (|#2| |#1|)) (-15 -2793 (|#2| |#1|)) (-15 -4525 ((-944) |#1|)) (-15 -3470 ((-944))) (-15 -3504 ((-1187 |#2|) |#1|)) (-15 -1626 (|#1| (-1280 |#2|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1|)) (-15 -4424 ((-790))) (-15 -3470 ((-855 (-944)))) (-15 -4525 ((-855 (-944)) |#1|)) (-15 -1917 ((-141) |#1|)) (-15 -3069 ((-141) |#1|)) (-15 -1936 ((-160)))) (-349 |#2|) (-388)) (T -348)) 
+((-1936 (*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-160)) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) (-3470 (*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-855 (-944))) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) (-4424 (*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-790)) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) (-3470 (*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-944)) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) (-1403 (*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-790)) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4))))) 
+(-10 -8 (-15 -1517 ((-3 |#1| "failed") |#1|)) (-15 -1403 ((-790))) (-15 -1517 (|#1| |#1|)) (-15 -1492 ((-3 (-1187 |#2|) "failed") |#1| |#1|)) (-15 -1492 ((-1187 |#2|) |#1|)) (-15 -2343 ((-1187 |#2|) |#1|)) (-15 -2252 (|#1| |#1| (-1187 |#2|))) (-15 -2114 ((-141) |#1|)) (-15 -3342 (|#1|)) (-15 -4529 (|#1| |#1| (-944))) (-15 -2793 (|#1| |#1| (-944))) (-15 -3504 ((-1187 |#1|) |#1| (-944))) (-15 -4529 (|#2| |#1|)) (-15 -2793 (|#2| |#1|)) (-15 -4525 ((-944) |#1|)) (-15 -3470 ((-944))) (-15 -3504 ((-1187 |#2|) |#1|)) (-15 -1626 (|#1| (-1280 |#2|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1|)) (-15 -4424 ((-790))) (-15 -3470 ((-855 (-944)))) (-15 -4525 ((-855 (-944)) |#1|)) (-15 -1917 ((-141) |#1|)) (-15 -3069 ((-141) |#1|)) (-15 -1936 ((-160)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-1917 (((-141) $) 90)) (-4424 (((-790)) 86)) (-4529 ((|#1| $) 134) (($ $ (-944)) 131 (|has| |#1| (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) 116 (|has| |#1| (-394)))) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-1403 (((-790)) 106 (|has| |#1| (-394)))) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 97)) (-2400 ((|#1| $) 96)) (-1626 (($ (-1280 |#1|)) 140)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 122 (|has| |#1| (-394)))) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-4290 (($) 103 (|has| |#1| (-394)))) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2667 (($) 118 (|has| |#1| (-394)))) (-3293 (((-141) $) 119 (|has| |#1| (-394)))) (-1525 (($ $ (-790)) 83 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394)))) (($ $) 82 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-2802 (((-141) $) 69)) (-4346 (((-944) $) 121 (|has| |#1| (-394))) (((-855 (-944)) $) 80 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-3558 (((-141) $) 30)) (-2834 (($) 129 (|has| |#1| (-394)))) (-2114 (((-141) $) 128 (|has| |#1| (-394)))) (-2793 ((|#1| $) 135) (($ $ (-944)) 132 (|has| |#1| (-394)))) (-3921 (((-3 $ "failed") $) 107 (|has| |#1| (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-3504 (((-1187 |#1|) $) 139) (((-1187 $) $ (-944)) 133 (|has| |#1| (-394)))) (-3546 (((-944) $) 104 (|has| |#1| (-394)))) (-2343 (((-1187 |#1|) $) 125 (|has| |#1| (-394)))) (-1492 (((-1187 |#1|) $) 124 (|has| |#1| (-394))) (((-3 (-1187 |#1|) "failed") $ $) 123 (|has| |#1| (-394)))) (-2252 (($ $ (-1187 |#1|)) 126 (|has| |#1| (-394)))) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-3703 (($) 108 (|has| |#1| (-394)) CONST)) (-1825 (($ (-944)) 105 (|has| |#1| (-394)))) (-2142 (((-141) $) 89)) (-2951 (((-1137) $) 10)) (-2934 (($) 127 (|has| |#1| (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 115 (|has| |#1| (-394)))) (-4500 (((-444 $) $) 72)) (-3470 (((-855 (-944))) 87) (((-944)) 137)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-1405 (((-658 $)) 102 (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-2177 (((-790) $) 120 (|has| |#1| (-394))) (((-3 (-790) "failed") $ $) 81 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-1936 (((-160)) 95)) (-3644 (($ $) 112 (|has| |#1| (-394))) (($ $ (-790)) 110 (|has| |#1| (-394)))) (-4525 (((-855 (-944)) $) 88) (((-944) $) 136)) (-3390 (((-1187 |#1|)) 138)) (-3809 (($) 117 (|has| |#1| (-394)))) (-3342 (($) 130 (|has| |#1| (-394)))) (-2231 (((-1280 |#1|) $) 142) (((-706 |#1|) (-1280 $)) 141)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 114 (|has| |#1| (-394)))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63) (($ |#1|) 98)) (-1517 (($ $) 113 (|has| |#1| (-394))) (((-3 $ "failed") $) 79 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-4010 (((-790)) 28)) (-2195 (((-1280 $)) 144) (((-1280 $) (-944)) 143)) (-2537 (((-141) $ $) 38)) (-3069 (((-141) $) 91)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3417 (($ $) 85 (|has| |#1| (-394))) (($ $ (-790)) 84 (|has| |#1| (-394)))) (-1940 (($ $) 111 (|has| |#1| (-394))) (($ $ (-790)) 109 (|has| |#1| (-394)))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62) (($ $ |#1|) 94)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64) (($ $ |#1|) 93) (($ |#1| $) 92))) 
+(((-349 |#1|) (-1311) (-388)) (T -349)) 
+((-2195 (*1 *2) (-12 (-4 *3 (-388)) (-5 *2 (-1280 *1)) (-4 *1 (-349 *3)))) (-2195 (*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-388)) (-5 *2 (-1280 *1)) (-4 *1 (-349 *4)))) (-2231 (*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-1280 *3)))) (-2231 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-349 *4)) (-4 *4 (-388)) (-5 *2 (-706 *4)))) (-1626 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-388)) (-4 *1 (-349 *3)))) (-3504 (*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-1187 *3)))) (-3390 (*1 *2) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-1187 *3)))) (-3470 (*1 *2) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-944)))) (-4525 (*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-944)))) (-2793 (*1 *2 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-388)))) (-4529 (*1 *2 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-388)))) (-3504 (*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-5 *2 (-1187 *1)) (-4 *1 (-349 *4)))) (-2793 (*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)))) (-4529 (*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)))) (-3342 (*1 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-394)) (-4 *2 (-388)))) (-2834 (*1 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-394)) (-4 *2 (-388)))) (-2114 (*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)) (-5 *2 (-141)))) (-2934 (*1 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-394)) (-4 *2 (-388)))) (-2252 (*1 *1 *1 *2) (-12 (-5 *2 (-1187 *3)) (-4 *3 (-394)) (-4 *1 (-349 *3)) (-4 *3 (-388)))) (-2343 (*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)) (-5 *2 (-1187 *3)))) (-1492 (*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)) (-5 *2 (-1187 *3)))) (-1492 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)) (-5 *2 (-1187 *3))))) 
+(-13 (-1297 |t#1|) (-1065 |t#1|) (-10 -8 (-15 -2195 ((-1280 $))) (-15 -2195 ((-1280 $) (-944))) (-15 -2231 ((-1280 |t#1|) $)) (-15 -2231 ((-706 |t#1|) (-1280 $))) (-15 -1626 ($ (-1280 |t#1|))) (-15 -3504 ((-1187 |t#1|) $)) (-15 -3390 ((-1187 |t#1|))) (-15 -3470 ((-944))) (-15 -4525 ((-944) $)) (-15 -2793 (|t#1| $)) (-15 -4529 (|t#1| $)) (IF (|has| |t#1| (-394)) (PROGN (-6 (-373)) (-15 -3504 ((-1187 $) $ (-944))) (-15 -2793 ($ $ (-944))) (-15 -4529 ($ $ (-944))) (-15 -3342 ($)) (-15 -2834 ($)) (-15 -2114 ((-141) $)) (-15 -2934 ($)) (-15 -2252 ($ $ (-1187 |t#1|))) (-15 -2343 ((-1187 |t#1|) $)) (-15 -1492 ((-1187 |t#1|) $)) (-15 -1492 ((-3 (-1187 |t#1|) "failed") $ $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 |#1| |#1|) . T) ((-140 $ $) . T) ((-158) . T) ((-169) -3836 (|has| |#1| (-394)) (|has| |#1| (-169))) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) . T) ((-247) |has| |#1| (-394)) ((-260) . T) ((-307) . T) ((-323) . T) ((-1297 |#1|) . T) ((-388) . T) ((-428) -3836 (|has| |#1| (-394)) (|has| |#1| (-169))) ((-394) |has| |#1| (-394)) ((-373) |has| |#1| (-394)) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 |#1|) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) . T) ((-1081 |#1|) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) |has| |#1| (-394)) ((-1235) . T) ((-1287 |#1|) . T)) 
+((-1641 (((-141) $ $) NIL)) (-1445 (($ (-1190) $) 88)) (-2686 (($) 76)) (-2551 (((-1137) (-1137)) 11)) (-3806 (($) 77)) (-2362 (($) 90) (($ (-332 (-715))) 96) (($ (-332 (-717))) 93) (($ (-332 (-710))) 99) (($ (-332 (-405))) 105) (($ (-332 (-592))) 102) (($ (-332 (-191 (-405)))) 108)) (-3203 (($ (-1190) $) 89)) (-2754 (($ (-658 (-877))) 79)) (-2974 (((-1285) $) 73)) (-1990 (((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $) 27)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2307 (($ (-1137)) 45)) (-2335 (((-1123) $) 25)) (-2067 (($ (-1111 (-980 (-592))) $) 85) (($ (-1111 (-980 (-592))) (-980 (-592)) $) 86)) (-3797 (($ (-1137)) 87)) (-3418 (($ (-1190) $) 110) (($ (-1190) $ $) 111)) (-4087 (($ (-1191) (-658 (-1191))) 75)) (-4532 (($ (-1173)) 82) (($ (-658 (-1173))) 80)) (-1683 (((-877) $) 113)) (-3702 (((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1191)) (|:| |arrayIndex| (-658 (-980 (-592)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1191)) (|:| |rand| (-877)) (|:| |ints2Floats?| (-141)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1190)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -2943 (-141)) (|:| -2324 (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |blockBranch| (-658 $)) (|:| |commentBranch| (-658 (-1173))) (|:| |callBranch| (-1173)) (|:| |forBranch| (-2 (|:| -2166 (-1111 (-980 (-592)))) (|:| |span| (-980 (-592))) (|:| |body| $))) (|:| |labelBranch| (-1137)) (|:| |loopBranch| (-2 (|:| |switch| (-1190)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -4095 (-1191)) (|:| |contents| (-658 (-1191))))) (|:| |printBranch| (-658 (-877)))) $) 37)) (-1853 (($ (-1173)) 182)) (-2775 (($ (-658 $)) 109)) (-2733 (($ (-1191) (-1173)) 115) (($ (-1191) (-332 (-717))) 155) (($ (-1191) (-332 (-715))) 156) (($ (-1191) (-332 (-710))) 157) (($ (-1191) (-706 (-717))) 118) (($ (-1191) (-706 (-715))) 121) (($ (-1191) (-706 (-710))) 124) (($ (-1191) (-1280 (-717))) 127) (($ (-1191) (-1280 (-715))) 130) (($ (-1191) (-1280 (-710))) 133) (($ (-1191) (-706 (-332 (-717)))) 136) (($ (-1191) (-706 (-332 (-715)))) 139) (($ (-1191) (-706 (-332 (-710)))) 142) (($ (-1191) (-1280 (-332 (-717)))) 145) (($ (-1191) (-1280 (-332 (-715)))) 148) (($ (-1191) (-1280 (-332 (-710)))) 151) (($ (-1191) (-658 (-980 (-592))) (-332 (-717))) 152) (($ (-1191) (-658 (-980 (-592))) (-332 (-715))) 153) (($ (-1191) (-658 (-980 (-592))) (-332 (-710))) 154) (($ (-1191) (-332 (-592))) 179) (($ (-1191) (-332 (-405))) 180) (($ (-1191) (-332 (-191 (-405)))) 181) (($ (-1191) (-706 (-332 (-592)))) 160) (($ (-1191) (-706 (-332 (-405)))) 163) (($ (-1191) (-706 (-332 (-191 (-405))))) 166) (($ (-1191) (-1280 (-332 (-592)))) 169) (($ (-1191) (-1280 (-332 (-405)))) 172) (($ (-1191) (-1280 (-332 (-191 (-405))))) 175) (($ (-1191) (-658 (-980 (-592))) (-332 (-592))) 176) (($ (-1191) (-658 (-980 (-592))) (-332 (-405))) 177) (($ (-1191) (-658 (-980 (-592))) (-332 (-191 (-405)))) 178)) (-3255 (((-141) $ $) NIL))) 
+(((-350) (-13 (-1119) (-10 -8 (-15 -1683 ((-877) $)) (-15 -2067 ($ (-1111 (-980 (-592))) $)) (-15 -2067 ($ (-1111 (-980 (-592))) (-980 (-592)) $)) (-15 -1445 ($ (-1190) $)) (-15 -3203 ($ (-1190) $)) (-15 -2307 ($ (-1137))) (-15 -3797 ($ (-1137))) (-15 -4532 ($ (-1173))) (-15 -4532 ($ (-658 (-1173)))) (-15 -1853 ($ (-1173))) (-15 -2362 ($)) (-15 -2362 ($ (-332 (-715)))) (-15 -2362 ($ (-332 (-717)))) (-15 -2362 ($ (-332 (-710)))) (-15 -2362 ($ (-332 (-405)))) (-15 -2362 ($ (-332 (-592)))) (-15 -2362 ($ (-332 (-191 (-405))))) (-15 -3418 ($ (-1190) $)) (-15 -3418 ($ (-1190) $ $)) (-15 -2733 ($ (-1191) (-1173))) (-15 -2733 ($ (-1191) (-332 (-717)))) (-15 -2733 ($ (-1191) (-332 (-715)))) (-15 -2733 ($ (-1191) (-332 (-710)))) (-15 -2733 ($ (-1191) (-706 (-717)))) (-15 -2733 ($ (-1191) (-706 (-715)))) (-15 -2733 ($ (-1191) (-706 (-710)))) (-15 -2733 ($ (-1191) (-1280 (-717)))) (-15 -2733 ($ (-1191) (-1280 (-715)))) (-15 -2733 ($ (-1191) (-1280 (-710)))) (-15 -2733 ($ (-1191) (-706 (-332 (-717))))) (-15 -2733 ($ (-1191) (-706 (-332 (-715))))) (-15 -2733 ($ (-1191) (-706 (-332 (-710))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-717))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-715))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-710))))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-717)))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-715)))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-710)))) (-15 -2733 ($ (-1191) (-332 (-592)))) (-15 -2733 ($ (-1191) (-332 (-405)))) (-15 -2733 ($ (-1191) (-332 (-191 (-405))))) (-15 -2733 ($ (-1191) (-706 (-332 (-592))))) (-15 -2733 ($ (-1191) (-706 (-332 (-405))))) (-15 -2733 ($ (-1191) (-706 (-332 (-191 (-405)))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-592))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-405))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-191 (-405)))))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-592)))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-405)))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-191 (-405))))) (-15 -2775 ($ (-658 $))) (-15 -2686 ($)) (-15 -3806 ($)) (-15 -2754 ($ (-658 (-877)))) (-15 -4087 ($ (-1191) (-658 (-1191)))) (-15 -1990 ((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $)) (-15 -3702 ((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1191)) (|:| |arrayIndex| (-658 (-980 (-592)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1191)) (|:| |rand| (-877)) (|:| |ints2Floats?| (-141)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1190)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -2943 (-141)) (|:| -2324 (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |blockBranch| (-658 $)) (|:| |commentBranch| (-658 (-1173))) (|:| |callBranch| (-1173)) (|:| |forBranch| (-2 (|:| -2166 (-1111 (-980 (-592)))) (|:| |span| (-980 (-592))) (|:| |body| $))) (|:| |labelBranch| (-1137)) (|:| |loopBranch| (-2 (|:| |switch| (-1190)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -4095 (-1191)) (|:| |contents| (-658 (-1191))))) (|:| |printBranch| (-658 (-877)))) $)) (-15 -2974 ((-1285) $)) (-15 -2335 ((-1123) $)) (-15 -2551 ((-1137) (-1137)))))) (T -350)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-350)))) (-2067 (*1 *1 *2 *1) (-12 (-5 *2 (-1111 (-980 (-592)))) (-5 *1 (-350)))) (-2067 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-1111 (-980 (-592)))) (-5 *3 (-980 (-592))) (-5 *1 (-350)))) (-1445 (*1 *1 *2 *1) (-12 (-5 *2 (-1190)) (-5 *1 (-350)))) (-3203 (*1 *1 *2 *1) (-12 (-5 *2 (-1190)) (-5 *1 (-350)))) (-2307 (*1 *1 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-350)))) (-3797 (*1 *1 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-350)))) (-4532 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-350)))) (-4532 (*1 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-350)))) (-1853 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-350)))) (-2362 (*1 *1) (-5 *1 (-350))) (-2362 (*1 *1 *2) (-12 (-5 *2 (-332 (-715))) (-5 *1 (-350)))) (-2362 (*1 *1 *2) (-12 (-5 *2 (-332 (-717))) (-5 *1 (-350)))) (-2362 (*1 *1 *2) (-12 (-5 *2 (-332 (-710))) (-5 *1 (-350)))) (-2362 (*1 *1 *2) (-12 (-5 *2 (-332 (-405))) (-5 *1 (-350)))) (-2362 (*1 *1 *2) (-12 (-5 *2 (-332 (-592))) (-5 *1 (-350)))) (-2362 (*1 *1 *2) (-12 (-5 *2 (-332 (-191 (-405)))) (-5 *1 (-350)))) (-3418 (*1 *1 *2 *1) (-12 (-5 *2 (-1190)) (-5 *1 (-350)))) (-3418 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1190)) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1173)) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-717))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-715))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-710))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-717))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-715))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-710))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-717))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-715))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-710))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-717)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-715)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-710)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-717)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-715)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-710)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-717))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-715))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-710))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-592))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-405))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-191 (-405)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-592)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-405)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-191 (-405))))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-592)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-405)))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-191 (-405))))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-592))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-405))) (-5 *1 (-350)))) (-2733 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-191 (-405)))) (-5 *1 (-350)))) (-2775 (*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-5 *1 (-350)))) (-2686 (*1 *1) (-5 *1 (-350))) (-3806 (*1 *1) (-5 *1 (-350))) (-2754 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-350)))) (-4087 (*1 *1 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-5 *2 (-1191)) (-5 *1 (-350)))) (-1990 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (-5 *1 (-350)))) (-3702 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1191)) (|:| |arrayIndex| (-658 (-980 (-592)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1191)) (|:| |rand| (-877)) (|:| |ints2Floats?| (-141)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1190)) (|:| |thenClause| (-350)) (|:| |elseClause| (-350)))) (|:| |returnBranch| (-2 (|:| -2943 (-141)) (|:| -2324 (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |blockBranch| (-658 (-350))) (|:| |commentBranch| (-658 (-1173))) (|:| |callBranch| (-1173)) (|:| |forBranch| (-2 (|:| -2166 (-1111 (-980 (-592)))) (|:| |span| (-980 (-592))) (|:| |body| (-350)))) (|:| |labelBranch| (-1137)) (|:| |loopBranch| (-2 (|:| |switch| (-1190)) (|:| |body| (-350)))) (|:| |commonBranch| (-2 (|:| -4095 (-1191)) (|:| |contents| (-658 (-1191))))) (|:| |printBranch| (-658 (-877))))) (-5 *1 (-350)))) (-2974 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-350)))) (-2335 (*1 *2 *1) (-12 (-5 *2 (-1123)) (-5 *1 (-350)))) (-2551 (*1 *2 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-350))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ((-877) $)) (-15 -2067 ($ (-1111 (-980 (-592))) $)) (-15 -2067 ($ (-1111 (-980 (-592))) (-980 (-592)) $)) (-15 -1445 ($ (-1190) $)) (-15 -3203 ($ (-1190) $)) (-15 -2307 ($ (-1137))) (-15 -3797 ($ (-1137))) (-15 -4532 ($ (-1173))) (-15 -4532 ($ (-658 (-1173)))) (-15 -1853 ($ (-1173))) (-15 -2362 ($)) (-15 -2362 ($ (-332 (-715)))) (-15 -2362 ($ (-332 (-717)))) (-15 -2362 ($ (-332 (-710)))) (-15 -2362 ($ (-332 (-405)))) (-15 -2362 ($ (-332 (-592)))) (-15 -2362 ($ (-332 (-191 (-405))))) (-15 -3418 ($ (-1190) $)) (-15 -3418 ($ (-1190) $ $)) (-15 -2733 ($ (-1191) (-1173))) (-15 -2733 ($ (-1191) (-332 (-717)))) (-15 -2733 ($ (-1191) (-332 (-715)))) (-15 -2733 ($ (-1191) (-332 (-710)))) (-15 -2733 ($ (-1191) (-706 (-717)))) (-15 -2733 ($ (-1191) (-706 (-715)))) (-15 -2733 ($ (-1191) (-706 (-710)))) (-15 -2733 ($ (-1191) (-1280 (-717)))) (-15 -2733 ($ (-1191) (-1280 (-715)))) (-15 -2733 ($ (-1191) (-1280 (-710)))) (-15 -2733 ($ (-1191) (-706 (-332 (-717))))) (-15 -2733 ($ (-1191) (-706 (-332 (-715))))) (-15 -2733 ($ (-1191) (-706 (-332 (-710))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-717))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-715))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-710))))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-717)))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-715)))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-710)))) (-15 -2733 ($ (-1191) (-332 (-592)))) (-15 -2733 ($ (-1191) (-332 (-405)))) (-15 -2733 ($ (-1191) (-332 (-191 (-405))))) (-15 -2733 ($ (-1191) (-706 (-332 (-592))))) (-15 -2733 ($ (-1191) (-706 (-332 (-405))))) (-15 -2733 ($ (-1191) (-706 (-332 (-191 (-405)))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-592))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-405))))) (-15 -2733 ($ (-1191) (-1280 (-332 (-191 (-405)))))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-592)))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-405)))) (-15 -2733 ($ (-1191) (-658 (-980 (-592))) (-332 (-191 (-405))))) (-15 -2775 ($ (-658 $))) (-15 -2686 ($)) (-15 -3806 ($)) (-15 -2754 ($ (-658 (-877)))) (-15 -4087 ($ (-1191) (-658 (-1191)))) (-15 -1990 ((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $)) (-15 -3702 ((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1191)) (|:| |arrayIndex| (-658 (-980 (-592)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1191)) (|:| |rand| (-877)) (|:| |ints2Floats?| (-141)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1190)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -2943 (-141)) (|:| -2324 (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |blockBranch| (-658 $)) (|:| |commentBranch| (-658 (-1173))) (|:| |callBranch| (-1173)) (|:| |forBranch| (-2 (|:| -2166 (-1111 (-980 (-592)))) (|:| |span| (-980 (-592))) (|:| |body| $))) (|:| |labelBranch| (-1137)) (|:| |loopBranch| (-2 (|:| |switch| (-1190)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -4095 (-1191)) (|:| |contents| (-658 (-1191))))) (|:| |printBranch| (-658 (-877)))) $)) (-15 -2974 ((-1285) $)) (-15 -2335 ((-1123) $)) (-15 -2551 ((-1137) (-1137))))) 
+((-1641 (((-141) $ $) NIL)) (-2627 (((-141) $) 11)) (-1495 (($ |#1|) 8)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1501 (($ |#1|) 9)) (-1683 (((-877) $) 17)) (-4575 ((|#1| $) 12)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 19))) 
+(((-351 |#1|) (-13 (-869) (-10 -8 (-15 -1495 ($ |#1|)) (-15 -1501 ($ |#1|)) (-15 -2627 ((-141) $)) (-15 -4575 (|#1| $)))) (-869)) (T -351)) 
+((-1495 (*1 *1 *2) (-12 (-5 *1 (-351 *2)) (-4 *2 (-869)))) (-1501 (*1 *1 *2) (-12 (-5 *1 (-351 *2)) (-4 *2 (-869)))) (-2627 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-351 *3)) (-4 *3 (-869)))) (-4575 (*1 *2 *1) (-12 (-5 *1 (-351 *2)) (-4 *2 (-869))))) 
+(-13 (-869) (-10 -8 (-15 -1495 ($ |#1|)) (-15 -1501 ($ |#1|)) (-15 -2627 ((-141) $)) (-15 -4575 (|#1| $)))) 
+((-4582 (((-350) (-1191) (-980 (-592))) 22)) (-1832 (((-350) (-1191) (-980 (-592))) 26)) (-1621 (((-350) (-1191) (-1111 (-980 (-592))) (-1111 (-980 (-592)))) 25) (((-350) (-1191) (-980 (-592)) (-980 (-592))) 23)) (-3525 (((-350) (-1191) (-980 (-592))) 30))) 
+(((-352) (-10 -7 (-15 -4582 ((-350) (-1191) (-980 (-592)))) (-15 -1621 ((-350) (-1191) (-980 (-592)) (-980 (-592)))) (-15 -1621 ((-350) (-1191) (-1111 (-980 (-592))) (-1111 (-980 (-592))))) (-15 -1832 ((-350) (-1191) (-980 (-592)))) (-15 -3525 ((-350) (-1191) (-980 (-592)))))) (T -352)) 
+((-3525 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-980 (-592))) (-5 *2 (-350)) (-5 *1 (-352)))) (-1832 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-980 (-592))) (-5 *2 (-350)) (-5 *1 (-352)))) (-1621 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-1111 (-980 (-592)))) (-5 *2 (-350)) (-5 *1 (-352)))) (-1621 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-980 (-592))) (-5 *2 (-350)) (-5 *1 (-352)))) (-4582 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-980 (-592))) (-5 *2 (-350)) (-5 *1 (-352))))) 
+(-10 -7 (-15 -4582 ((-350) (-1191) (-980 (-592)))) (-15 -1621 ((-350) (-1191) (-980 (-592)) (-980 (-592)))) (-15 -1621 ((-350) (-1191) (-1111 (-980 (-592))) (-1111 (-980 (-592))))) (-15 -1832 ((-350) (-1191) (-980 (-592)))) (-15 -3525 ((-350) (-1191) (-980 (-592))))) 
+((-2731 (((-356 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-356 |#1| |#2| |#3| |#4|)) 31))) 
+(((-353 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2731 ((-356 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-356 |#1| |#2| |#3| |#4|)))) (-388) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|) (-388) (-1255 |#5|) (-1255 (-433 |#6|)) (-362 |#5| |#6| |#7|)) (T -353)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-356 *5 *6 *7 *8)) (-4 *5 (-388)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *8 (-362 *5 *6 *7)) (-4 *9 (-388)) (-4 *10 (-1255 *9)) (-4 *11 (-1255 (-433 *10))) (-5 *2 (-356 *9 *10 *11 *12)) (-5 *1 (-353 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-362 *9 *10 *11))))) 
+(-10 -7 (-15 -2731 ((-356 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-356 |#1| |#2| |#3| |#4|)))) 
+((-1663 (((-141) $) 14))) 
+(((-354 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -1663 ((-141) |#1|))) (-355 |#2| |#3| |#4| |#5|) (-388) (-1255 |#2|) (-1255 (-433 |#3|)) (-362 |#2| |#3| |#4|)) (T -354)) 
+NIL 
+(-10 -8 (-15 -1663 ((-141) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3657 (($ $) 25)) (-1663 (((-141) $) 24)) (-2685 (((-1173) $) 9)) (-2312 (((-439 |#2| (-433 |#2|) |#3| |#4|) $) 31)) (-2951 (((-1137) $) 10)) (-2934 (((-3 |#4| "failed") $) 23)) (-4096 (($ (-439 |#2| (-433 |#2|) |#3| |#4|)) 30) (($ |#4|) 29) (($ |#1| |#1|) 28) (($ |#1| |#1| (-592)) 27) (($ |#4| |#2| |#2| |#2| |#1|) 22)) (-1906 (((-2 (|:| -4547 (-439 |#2| (-433 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 26)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19))) 
+(((-355 |#1| |#2| |#3| |#4|) (-1311) (-388) (-1255 |t#1|) (-1255 (-433 |t#2|)) (-362 |t#1| |t#2| |t#3|)) (T -355)) 
+((-2312 (*1 *2 *1) (-12 (-4 *1 (-355 *3 *4 *5 *6)) (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 *3 *4 *5)) (-5 *2 (-439 *4 (-433 *4) *5 *6)))) (-4096 (*1 *1 *2) (-12 (-5 *2 (-439 *4 (-433 *4) *5 *6)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 *3 *4 *5)) (-4 *3 (-388)) (-4 *1 (-355 *3 *4 *5 *6)))) (-4096 (*1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *1 (-355 *3 *4 *5 *2)) (-4 *2 (-362 *3 *4 *5)))) (-4096 (*1 *1 *2 *2) (-12 (-4 *2 (-388)) (-4 *3 (-1255 *2)) (-4 *4 (-1255 (-433 *3))) (-4 *1 (-355 *2 *3 *4 *5)) (-4 *5 (-362 *2 *3 *4)))) (-4096 (*1 *1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *2 (-388)) (-4 *4 (-1255 *2)) (-4 *5 (-1255 (-433 *4))) (-4 *1 (-355 *2 *4 *5 *6)) (-4 *6 (-362 *2 *4 *5)))) (-1906 (*1 *2 *1) (-12 (-4 *1 (-355 *3 *4 *5 *6)) (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 *3 *4 *5)) (-5 *2 (-2 (|:| -4547 (-439 *4 (-433 *4) *5 *6)) (|:| |principalPart| *6))))) (-3657 (*1 *1 *1) (-12 (-4 *1 (-355 *2 *3 *4 *5)) (-4 *2 (-388)) (-4 *3 (-1255 *2)) (-4 *4 (-1255 (-433 *3))) (-4 *5 (-362 *2 *3 *4)))) (-1663 (*1 *2 *1) (-12 (-4 *1 (-355 *3 *4 *5 *6)) (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 *3 *4 *5)) (-5 *2 (-141)))) (-2934 (*1 *2 *1) (|partial| -12 (-4 *1 (-355 *3 *4 *5 *2)) (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *2 (-362 *3 *4 *5)))) (-4096 (*1 *1 *2 *3 *3 *3 *4) (-12 (-4 *4 (-388)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-4 *1 (-355 *4 *3 *5 *2)) (-4 *2 (-362 *4 *3 *5))))) 
+(-13 (-21) (-10 -8 (-15 -2312 ((-439 |t#2| (-433 |t#2|) |t#3| |t#4|) $)) (-15 -4096 ($ (-439 |t#2| (-433 |t#2|) |t#3| |t#4|))) (-15 -4096 ($ |t#4|)) (-15 -4096 ($ |t#1| |t#1|)) (-15 -4096 ($ |t#1| |t#1| (-592))) (-15 -1906 ((-2 (|:| -4547 (-439 |t#2| (-433 |t#2|) |t#3| |t#4|)) (|:| |principalPart| |t#4|)) $)) (-15 -3657 ($ $)) (-15 -1663 ((-141) $)) (-15 -2934 ((-3 |t#4| "failed") $)) (-15 -4096 ($ |t#4| |t#2| |t#2| |t#2| |t#1|)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3657 (($ $) 32)) (-1663 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-3874 (((-1280 |#4|) $) 124)) (-2312 (((-439 |#2| (-433 |#2|) |#3| |#4|) $) 30)) (-2951 (((-1137) $) NIL)) (-2934 (((-3 |#4| "failed") $) 35)) (-3437 (((-1280 |#4|) $) 117)) (-4096 (($ (-439 |#2| (-433 |#2|) |#3| |#4|)) 40) (($ |#4|) 42) (($ |#1| |#1|) 44) (($ |#1| |#1| (-592)) 46) (($ |#4| |#2| |#2| |#2| |#1|) 48)) (-1906 (((-2 (|:| -4547 (-439 |#2| (-433 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 38)) (-1683 (((-877) $) 17)) (-3514 (($) 14 T CONST)) (-3255 (((-141) $ $) 20)) (-3306 (($ $) 27) (($ $ $) NIL)) (-3300 (($ $ $) 25)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 23))) 
+(((-356 |#1| |#2| |#3| |#4|) (-13 (-355 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3437 ((-1280 |#4|) $)) (-15 -3874 ((-1280 |#4|) $)))) (-388) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|)) (T -356)) 
+((-3437 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-1280 *6)) (-5 *1 (-356 *3 *4 *5 *6)) (-4 *6 (-362 *3 *4 *5)))) (-3874 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-1280 *6)) (-5 *1 (-356 *3 *4 *5 *6)) (-4 *6 (-362 *3 *4 *5))))) 
+(-13 (-355 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3437 ((-1280 |#4|) $)) (-15 -3874 ((-1280 |#4|) $)))) 
+((-2806 (($ $ (-1191) |#2|) NIL) (($ $ (-658 (-1191)) (-658 |#2|)) 18) (($ $ (-658 (-310 |#2|))) 14) (($ $ (-310 |#2|)) NIL) (($ $ |#2| |#2|) NIL) (($ $ (-658 |#2|) (-658 |#2|)) NIL)) (-3927 (($ $ |#2|) 11))) 
+(((-357 |#1| |#2|) (-10 -8 (-15 -3927 (|#1| |#1| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#2|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#2| |#2|)) (-15 -2806 (|#1| |#1| (-310 |#2|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#2|)))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 |#2|))) (-15 -2806 (|#1| |#1| (-1191) |#2|))) (-358 |#2|) (-1119)) (T -357)) 
+NIL 
+(-10 -8 (-15 -3927 (|#1| |#1| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#2|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#2| |#2|)) (-15 -2806 (|#1| |#1| (-310 |#2|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#2|)))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 |#2|))) (-15 -2806 (|#1| |#1| (-1191) |#2|))) 
+((-2731 (($ (-1 |#1| |#1|) $) 6)) (-2806 (($ $ (-1191) |#1|) 16 (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) 15 (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-658 (-310 |#1|))) 14 (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) 13 (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) 12 (|has| |#1| (-325 |#1|))) (($ $ (-658 |#1|) (-658 |#1|)) 11 (|has| |#1| (-325 |#1|)))) (-3927 (($ $ |#1|) 10 (|has| |#1| (-303 |#1| |#1|))))) 
+(((-358 |#1|) (-1311) (-1119)) (T -358)) 
+((-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-358 *3)) (-4 *3 (-1119))))) 
+(-13 (-10 -8 (-15 -2731 ($ (-1 |t#1| |t#1|) $)) (IF (|has| |t#1| (-303 |t#1| |t#1|)) (-6 (-303 |t#1| $)) |noBranch|) (IF (|has| |t#1| (-325 |t#1|)) (-6 (-325 |t#1|)) |noBranch|) (IF (|has| |t#1| (-547 (-1191) |t#1|)) (-6 (-547 (-1191) |t#1|)) |noBranch|))) 
+(((-303 |#1| $) |has| |#1| (-303 |#1| |#1|)) ((-325 |#1|) |has| |#1| (-325 |#1|)) ((-547 (-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((-547 |#1| |#1|) |has| |#1| (-325 |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1191)) $) NIL)) (-3145 (((-141)) 87) (((-141) (-141)) 88)) (-2165 (((-658 (-631 $)) $) NIL)) (-1588 (($ $) NIL)) (-1507 (($ $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3147 (($ $ (-310 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL)) (-1442 (($ $) NIL)) (-1575 (($ $) NIL)) (-1495 (($ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-631 $) "failed") $) NIL) (((-3 |#3| "failed") $) NIL) (((-3 $ "failed") (-332 |#3|)) 69) (((-3 $ "failed") (-1191)) 93) (((-3 $ "failed") (-332 (-592))) 56 (|has| |#3| (-1065 (-592)))) (((-3 $ "failed") (-433 (-980 (-592)))) 62 (|has| |#3| (-1065 (-592)))) (((-3 $ "failed") (-980 (-592))) 57 (|has| |#3| (-1065 (-592)))) (((-3 $ "failed") (-332 (-405))) 74 (|has| |#3| (-1065 (-405)))) (((-3 $ "failed") (-433 (-980 (-405)))) 80 (|has| |#3| (-1065 (-405)))) (((-3 $ "failed") (-980 (-405))) 75 (|has| |#3| (-1065 (-405))))) (-2400 (((-631 $) $) NIL) ((|#3| $) NIL) (($ (-332 |#3|)) 70) (($ (-1191)) 94) (($ (-332 (-592))) 58 (|has| |#3| (-1065 (-592)))) (($ (-433 (-980 (-592)))) 63 (|has| |#3| (-1065 (-592)))) (($ (-980 (-592))) 59 (|has| |#3| (-1065 (-592)))) (($ (-332 (-405))) 76 (|has| |#3| (-1065 (-405)))) (($ (-433 (-980 (-405)))) 81 (|has| |#3| (-1065 (-405)))) (($ (-980 (-405))) 77 (|has| |#3| (-1065 (-405))))) (-3371 (((-3 $ "failed") $) NIL)) (-1435 (($) 10)) (-2243 (($ $) NIL) (($ (-658 $)) NIL)) (-4388 (((-658 (-143)) $) NIL)) (-2791 (((-143) (-143)) NIL)) (-3558 (((-141) $) NIL)) (-3372 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-2710 (((-1187 $) (-631 $)) NIL (|has| $ (-1075)))) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 $ $) (-631 $)) NIL)) (-4160 (((-3 (-631 $) "failed") $) NIL)) (-4197 (($ $) 90)) (-4546 (($ $) NIL)) (-2685 (((-1173) $) NIL)) (-4486 (((-658 (-631 $)) $) NIL)) (-1462 (($ (-143) $) 89) (($ (-143) (-658 $)) NIL)) (-3013 (((-141) $ (-143)) NIL) (((-141) $ (-1191)) NIL)) (-2535 (((-790) $) NIL)) (-2951 (((-1137) $) NIL)) (-1319 (((-141) $ $) NIL) (((-141) $ (-1191)) NIL)) (-1430 (($ $) NIL)) (-3554 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-2806 (($ $ (-631 $) $) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-1191) (-1 $ (-658 $))) NIL) (($ $ (-1191) (-1 $ $)) NIL) (($ $ (-658 (-143)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-143) (-1 $ (-658 $))) NIL) (($ $ (-143) (-1 $ $)) NIL)) (-3927 (($ (-143) $) NIL) (($ (-143) $ $) NIL) (($ (-143) $ $ $) NIL) (($ (-143) $ $ $ $) NIL) (($ (-143) (-658 $)) NIL)) (-2818 (($ $) NIL) (($ $ $) NIL)) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL)) (-3390 (($ $) NIL (|has| $ (-1075)))) (-1581 (($ $) NIL)) (-1501 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-631 $)) NIL) (($ |#3|) NIL) (($ (-592)) NIL) (((-332 |#3|) $) 92)) (-4010 (((-790)) NIL)) (-3280 (($ $) NIL) (($ (-658 $)) NIL)) (-3038 (((-141) (-143)) NIL)) (-1546 (($ $) NIL)) (-1533 (($ $) NIL)) (-1540 (($ $) NIL)) (-1392 (($ $) NIL)) (-1424 (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (-3514 (($) 91 T CONST)) (-4257 (($) 22 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (* (($ |#3| $) NIL) (($ $ |#3|) NIL) (($ $ $) NIL) (($ (-592) $) NIL) (($ (-790) $) NIL) (($ (-944) $) NIL))) 
+(((-359 |#1| |#2| |#3|) (-13 (-318) (-43 |#3|) (-1065 |#3|) (-922 (-1191)) (-10 -8 (-15 -2400 ($ (-332 |#3|))) (-15 -4368 ((-3 $ "failed") (-332 |#3|))) (-15 -2400 ($ (-1191))) (-15 -4368 ((-3 $ "failed") (-1191))) (-15 -1683 ((-332 |#3|) $)) (IF (|has| |#3| (-1065 (-592))) (PROGN (-15 -2400 ($ (-332 (-592)))) (-15 -4368 ((-3 $ "failed") (-332 (-592)))) (-15 -2400 ($ (-433 (-980 (-592))))) (-15 -4368 ((-3 $ "failed") (-433 (-980 (-592))))) (-15 -2400 ($ (-980 (-592)))) (-15 -4368 ((-3 $ "failed") (-980 (-592))))) |noBranch|) (IF (|has| |#3| (-1065 (-405))) (PROGN (-15 -2400 ($ (-332 (-405)))) (-15 -4368 ((-3 $ "failed") (-332 (-405)))) (-15 -2400 ($ (-433 (-980 (-405))))) (-15 -4368 ((-3 $ "failed") (-433 (-980 (-405))))) (-15 -2400 ($ (-980 (-405)))) (-15 -4368 ((-3 $ "failed") (-980 (-405))))) |noBranch|) (-15 -1392 ($ $)) (-15 -1442 ($ $)) (-15 -1430 ($ $)) (-15 -4546 ($ $)) (-15 -4197 ($ $)) (-15 -1495 ($ $)) (-15 -1501 ($ $)) (-15 -1507 ($ $)) (-15 -1533 ($ $)) (-15 -1540 ($ $)) (-15 -1546 ($ $)) (-15 -1575 ($ $)) (-15 -1581 ($ $)) (-15 -1588 ($ $)) (-15 -1435 ($)) (-15 -4085 ((-658 (-1191)) $)) (-15 -3145 ((-141))) (-15 -3145 ((-141) (-141))))) (-658 (-1191)) (-658 (-1191)) (-413)) (T -359)) 
+((-2400 (*1 *1 *2) (-12 (-5 *2 (-332 *5)) (-4 *5 (-413)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-332 *5)) (-4 *5 (-413)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 *2)) (-14 *4 (-658 *2)) (-4 *5 (-413)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 *2)) (-14 *4 (-658 *2)) (-4 *5 (-413)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-332 *5)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-332 (-592))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-332 (-592))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-592)))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-433 (-980 (-592)))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-980 (-592))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-592))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-332 (-405))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-332 (-405))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-405)))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-433 (-980 (-405)))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-980 (-405))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-405))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-1392 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1442 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1430 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-4546 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-4197 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1495 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1501 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1507 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1533 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1540 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1546 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1575 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1581 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1588 (*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-1435 (*1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) (-4085 (*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-359 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-413)))) (-3145 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) (-3145 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413))))) 
+(-13 (-318) (-43 |#3|) (-1065 |#3|) (-922 (-1191)) (-10 -8 (-15 -2400 ($ (-332 |#3|))) (-15 -4368 ((-3 $ "failed") (-332 |#3|))) (-15 -2400 ($ (-1191))) (-15 -4368 ((-3 $ "failed") (-1191))) (-15 -1683 ((-332 |#3|) $)) (IF (|has| |#3| (-1065 (-592))) (PROGN (-15 -2400 ($ (-332 (-592)))) (-15 -4368 ((-3 $ "failed") (-332 (-592)))) (-15 -2400 ($ (-433 (-980 (-592))))) (-15 -4368 ((-3 $ "failed") (-433 (-980 (-592))))) (-15 -2400 ($ (-980 (-592)))) (-15 -4368 ((-3 $ "failed") (-980 (-592))))) |noBranch|) (IF (|has| |#3| (-1065 (-405))) (PROGN (-15 -2400 ($ (-332 (-405)))) (-15 -4368 ((-3 $ "failed") (-332 (-405)))) (-15 -2400 ($ (-433 (-980 (-405))))) (-15 -4368 ((-3 $ "failed") (-433 (-980 (-405))))) (-15 -2400 ($ (-980 (-405)))) (-15 -4368 ((-3 $ "failed") (-980 (-405))))) |noBranch|) (-15 -1392 ($ $)) (-15 -1442 ($ $)) (-15 -1430 ($ $)) (-15 -4546 ($ $)) (-15 -4197 ($ $)) (-15 -1495 ($ $)) (-15 -1501 ($ $)) (-15 -1507 ($ $)) (-15 -1533 ($ $)) (-15 -1540 ($ $)) (-15 -1546 ($ $)) (-15 -1575 ($ $)) (-15 -1581 ($ $)) (-15 -1588 ($ $)) (-15 -1435 ($)) (-15 -4085 ((-658 (-1191)) $)) (-15 -3145 ((-141))) (-15 -3145 ((-141) (-141))))) 
+((-2731 ((|#8| (-1 |#5| |#1|) |#4|) 19))) 
+(((-360 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2731 (|#8| (-1 |#5| |#1|) |#4|))) (-1235) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|) (-1235) (-1255 |#5|) (-1255 (-433 |#6|)) (-362 |#5| |#6| |#7|)) (T -360)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1235)) (-4 *8 (-1235)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *9 (-1255 *8)) (-4 *2 (-362 *8 *9 *10)) (-5 *1 (-360 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-362 *5 *6 *7)) (-4 *10 (-1255 (-433 *9)))))) 
+(-10 -7 (-15 -2731 (|#8| (-1 |#5| |#1|) |#4|))) 
+((-4094 (((-2 (|:| |num| (-1280 |#3|)) (|:| |den| |#3|)) $) 37)) (-1626 (($ (-1280 (-433 |#3|)) (-1280 $)) NIL) (($ (-1280 (-433 |#3|))) NIL) (($ (-1280 |#3|) |#3|) 158)) (-1872 (((-1280 $) (-1280 $)) 142)) (-3969 (((-658 (-658 |#2|))) 115)) (-2619 (((-141) |#2| |#2|) 71)) (-3262 (($ $) 136)) (-3804 (((-790)) 30)) (-3655 (((-1280 $) (-1280 $)) 195)) (-2010 (((-658 (-980 |#2|)) (-1191)) 108)) (-3717 (((-141) $) 155)) (-4551 (((-141) $) 24) (((-141) $ |#2|) 28) (((-141) $ |#3|) 199)) (-3560 (((-3 |#3| "failed")) 48)) (-3918 (((-790)) 167)) (-3927 ((|#2| $ |#2| |#2|) 129)) (-3143 (((-3 |#3| "failed")) 66)) (-3644 (($ $ (-1 (-433 |#3|) (-433 |#3|)) (-790)) NIL) (($ $ (-1 (-433 |#3|) (-433 |#3|))) NIL) (($ $ (-1 |#3| |#3|)) 203) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL) (($ $ (-790)) NIL) (($ $) NIL)) (-3985 (((-1280 $) (-1280 $)) 148)) (-3748 (((-2 (|:| |num| $) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) $ (-1 |#3| |#3|)) 64)) (-3059 (((-141)) 32))) 
+(((-361 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3969 ((-658 (-658 |#2|)))) (-15 -2010 ((-658 (-980 |#2|)) (-1191))) (-15 -3748 ((-2 (|:| |num| |#1|) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) |#1| (-1 |#3| |#3|))) (-15 -3560 ((-3 |#3| "failed"))) (-15 -3143 ((-3 |#3| "failed"))) (-15 -3927 (|#2| |#1| |#2| |#2|)) (-15 -3262 (|#1| |#1|)) (-15 -1626 (|#1| (-1280 |#3|) |#3|)) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|))) (-15 -4551 ((-141) |#1| |#3|)) (-15 -4551 ((-141) |#1| |#2|)) (-15 -4094 ((-2 (|:| |num| (-1280 |#3|)) (|:| |den| |#3|)) |#1|)) (-15 -1872 ((-1280 |#1|) (-1280 |#1|))) (-15 -3655 ((-1280 |#1|) (-1280 |#1|))) (-15 -3985 ((-1280 |#1|) (-1280 |#1|))) (-15 -4551 ((-141) |#1|)) (-15 -3717 ((-141) |#1|)) (-15 -2619 ((-141) |#2| |#2|)) (-15 -3059 ((-141))) (-15 -3918 ((-790))) (-15 -3804 ((-790))) (-15 -3644 (|#1| |#1| (-1 (-433 |#3|) (-433 |#3|)))) (-15 -3644 (|#1| |#1| (-1 (-433 |#3|) (-433 |#3|)) (-790))) (-15 -1626 (|#1| (-1280 (-433 |#3|)))) (-15 -1626 (|#1| (-1280 (-433 |#3|)) (-1280 |#1|)))) (-362 |#2| |#3| |#4|) (-1235) (-1255 |#2|) (-1255 (-433 |#3|))) (T -361)) 
+((-3804 (*1 *2) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-790)) (-5 *1 (-361 *3 *4 *5 *6)) (-4 *3 (-362 *4 *5 *6)))) (-3918 (*1 *2) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-790)) (-5 *1 (-361 *3 *4 *5 *6)) (-4 *3 (-362 *4 *5 *6)))) (-3059 (*1 *2) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-141)) (-5 *1 (-361 *3 *4 *5 *6)) (-4 *3 (-362 *4 *5 *6)))) (-2619 (*1 *2 *3 *3) (-12 (-4 *3 (-1235)) (-4 *5 (-1255 *3)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-141)) (-5 *1 (-361 *4 *3 *5 *6)) (-4 *4 (-362 *3 *5 *6)))) (-3143 (*1 *2) (|partial| -12 (-4 *4 (-1235)) (-4 *5 (-1255 (-433 *2))) (-4 *2 (-1255 *4)) (-5 *1 (-361 *3 *4 *2 *5)) (-4 *3 (-362 *4 *2 *5)))) (-3560 (*1 *2) (|partial| -12 (-4 *4 (-1235)) (-4 *5 (-1255 (-433 *2))) (-4 *2 (-1255 *4)) (-5 *1 (-361 *3 *4 *2 *5)) (-4 *3 (-362 *4 *2 *5)))) (-2010 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *5 (-1235)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-5 *2 (-658 (-980 *5))) (-5 *1 (-361 *4 *5 *6 *7)) (-4 *4 (-362 *5 *6 *7)))) (-3969 (*1 *2) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-658 (-658 *4))) (-5 *1 (-361 *3 *4 *5 *6)) (-4 *3 (-362 *4 *5 *6))))) 
+(-10 -8 (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3969 ((-658 (-658 |#2|)))) (-15 -2010 ((-658 (-980 |#2|)) (-1191))) (-15 -3748 ((-2 (|:| |num| |#1|) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) |#1| (-1 |#3| |#3|))) (-15 -3560 ((-3 |#3| "failed"))) (-15 -3143 ((-3 |#3| "failed"))) (-15 -3927 (|#2| |#1| |#2| |#2|)) (-15 -3262 (|#1| |#1|)) (-15 -1626 (|#1| (-1280 |#3|) |#3|)) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|))) (-15 -4551 ((-141) |#1| |#3|)) (-15 -4551 ((-141) |#1| |#2|)) (-15 -4094 ((-2 (|:| |num| (-1280 |#3|)) (|:| |den| |#3|)) |#1|)) (-15 -1872 ((-1280 |#1|) (-1280 |#1|))) (-15 -3655 ((-1280 |#1|) (-1280 |#1|))) (-15 -3985 ((-1280 |#1|) (-1280 |#1|))) (-15 -4551 ((-141) |#1|)) (-15 -3717 ((-141) |#1|)) (-15 -2619 ((-141) |#2| |#2|)) (-15 -3059 ((-141))) (-15 -3918 ((-790))) (-15 -3804 ((-790))) (-15 -3644 (|#1| |#1| (-1 (-433 |#3|) (-433 |#3|)))) (-15 -3644 (|#1| |#1| (-1 (-433 |#3|) (-433 |#3|)) (-790))) (-15 -1626 (|#1| (-1280 (-433 |#3|)))) (-15 -1626 (|#1| (-1280 (-433 |#3|)) (-1280 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4094 (((-2 (|:| |num| (-1280 |#2|)) (|:| |den| |#2|)) $) 181)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 88 (|has| (-433 |#2|) (-388)))) (-1555 (($ $) 89 (|has| (-433 |#2|) (-388)))) (-1313 (((-141) $) 91 (|has| (-433 |#2|) (-388)))) (-1800 (((-706 (-433 |#2|)) (-1280 $)) 44) (((-706 (-433 |#2|))) 55)) (-4529 (((-433 |#2|) $) 50)) (-4217 (((-1199 (-944) (-790)) (-592)) 142 (|has| (-433 |#2|) (-373)))) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 108 (|has| (-433 |#2|) (-388)))) (-3164 (((-444 $) $) 109 (|has| (-433 |#2|) (-388)))) (-3652 (((-141) $ $) 99 (|has| (-433 |#2|) (-388)))) (-1403 (((-790)) 81 (|has| (-433 |#2|) (-394)))) (-4578 (((-141)) 198)) (-2105 (((-141) |#1|) 197) (((-141) |#2|) 196)) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 164 (|has| (-433 |#2|) (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 162 (|has| (-433 |#2|) (-1065 (-433 (-592))))) (((-3 (-433 |#2|) "failed") $) 161)) (-2400 (((-592) $) 165 (|has| (-433 |#2|) (-1065 (-592)))) (((-433 (-592)) $) 163 (|has| (-433 |#2|) (-1065 (-433 (-592))))) (((-433 |#2|) $) 160)) (-1626 (($ (-1280 (-433 |#2|)) (-1280 $)) 46) (($ (-1280 (-433 |#2|))) 58) (($ (-1280 |#2|) |#2|) 174)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 148 (|has| (-433 |#2|) (-373)))) (-1586 (($ $ $) 103 (|has| (-433 |#2|) (-388)))) (-4493 (((-706 (-433 |#2|)) $ (-1280 $)) 51) (((-706 (-433 |#2|)) $) 53)) (-3945 (((-706 (-592)) (-706 $)) 159 (|has| (-433 |#2|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 158 (|has| (-433 |#2|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-433 |#2|))) (|:| |vec| (-1280 (-433 |#2|)))) (-706 $) (-1280 $)) 157) (((-706 (-433 |#2|)) (-706 $)) 156)) (-1872 (((-1280 $) (-1280 $)) 186)) (-3657 (($ |#3|) 153) (((-3 $ "failed") (-433 |#3|)) 150 (|has| (-433 |#2|) (-388)))) (-3371 (((-3 $ "failed") $) 33)) (-3969 (((-658 (-658 |#1|))) 167 (|has| |#1| (-394)))) (-2619 (((-141) |#1| |#1|) 202)) (-4175 (((-944)) 52)) (-4290 (($) 84 (|has| (-433 |#2|) (-394)))) (-1634 (((-141)) 195)) (-2282 (((-141) |#1|) 194) (((-141) |#2|) 193)) (-1599 (($ $ $) 102 (|has| (-433 |#2|) (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 97 (|has| (-433 |#2|) (-388)))) (-3262 (($ $) 173)) (-2667 (($) 144 (|has| (-433 |#2|) (-373)))) (-3293 (((-141) $) 145 (|has| (-433 |#2|) (-373)))) (-1525 (($ $ (-790)) 136 (|has| (-433 |#2|) (-373))) (($ $) 135 (|has| (-433 |#2|) (-373)))) (-2802 (((-141) $) 110 (|has| (-433 |#2|) (-388)))) (-4346 (((-944) $) 147 (|has| (-433 |#2|) (-373))) (((-855 (-944)) $) 133 (|has| (-433 |#2|) (-373)))) (-3558 (((-141) $) 30)) (-3804 (((-790)) 205)) (-3655 (((-1280 $) (-1280 $)) 187)) (-2793 (((-433 |#2|) $) 49)) (-2010 (((-658 (-980 |#1|)) (-1191)) 168 (|has| |#1| (-388)))) (-3921 (((-3 $ "failed") $) 137 (|has| (-433 |#2|) (-373)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 106 (|has| (-433 |#2|) (-388)))) (-3504 ((|#3| $) 42 (|has| (-433 |#2|) (-388)))) (-3546 (((-944) $) 83 (|has| (-433 |#2|) (-394)))) (-3650 ((|#3| $) 151)) (-2750 (($ (-658 $)) 95 (|has| (-433 |#2|) (-388))) (($ $ $) 94 (|has| (-433 |#2|) (-388)))) (-2685 (((-1173) $) 9)) (-3757 (((-706 (-433 |#2|))) 182)) (-1346 (((-706 (-433 |#2|))) 184)) (-4552 (($ $) 111 (|has| (-433 |#2|) (-388)))) (-2482 (($ (-1280 |#2|) |#2|) 179)) (-2925 (((-706 (-433 |#2|))) 183)) (-4373 (((-706 (-433 |#2|))) 185)) (-3406 (((-2 (|:| |num| (-706 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 178)) (-1645 (((-2 (|:| |num| (-1280 |#2|)) (|:| |den| |#2|)) $) 180)) (-3720 (((-1280 $)) 191)) (-4023 (((-1280 $)) 192)) (-3717 (((-141) $) 190)) (-4551 (((-141) $) 189) (((-141) $ |#1|) 177) (((-141) $ |#2|) 176)) (-3703 (($) 138 (|has| (-433 |#2|) (-373)) CONST)) (-1825 (($ (-944)) 82 (|has| (-433 |#2|) (-394)))) (-3560 (((-3 |#2| "failed")) 170)) (-2951 (((-1137) $) 10)) (-3918 (((-790)) 204)) (-2934 (($) 155)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 96 (|has| (-433 |#2|) (-388)))) (-3548 (($ (-658 $)) 93 (|has| (-433 |#2|) (-388))) (($ $ $) 92 (|has| (-433 |#2|) (-388)))) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 141 (|has| (-433 |#2|) (-373)))) (-4500 (((-444 $) $) 107 (|has| (-433 |#2|) (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105 (|has| (-433 |#2|) (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 104 (|has| (-433 |#2|) (-388)))) (-3616 (((-3 $ "failed") $ $) 87 (|has| (-433 |#2|) (-388)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 98 (|has| (-433 |#2|) (-388)))) (-2769 (((-790) $) 100 (|has| (-433 |#2|) (-388)))) (-1405 (((-658 $)) 85 (|has| (-433 |#2|) (-394)))) (-3927 ((|#1| $ |#1| |#1|) 172)) (-3143 (((-3 |#2| "failed")) 171)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 101 (|has| (-433 |#2|) (-388)))) (-1482 (((-433 |#2|) (-1280 $)) 45) (((-433 |#2|)) 54)) (-2177 (((-790) $) 146 (|has| (-433 |#2|) (-373))) (((-3 (-790) "failed") $ $) 134 (|has| (-433 |#2|) (-373)))) (-3644 (($ $ (-1 (-433 |#2|) (-433 |#2|)) (-790)) 118 (|has| (-433 |#2|) (-388))) (($ $ (-1 (-433 |#2|) (-433 |#2|))) 117 (|has| (-433 |#2|) (-388))) (($ $ (-1 |#2| |#2|)) 175) (($ $ (-658 (-1191)) (-658 (-790))) 125 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) (-1732 (|has| (-433 |#2|) (-922 (-1191))) (|has| (-433 |#2|) (-388))))) (($ $ (-1191) (-790)) 126 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) (-1732 (|has| (-433 |#2|) (-922 (-1191))) (|has| (-433 |#2|) (-388))))) (($ $ (-658 (-1191))) 127 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) (-1732 (|has| (-433 |#2|) (-922 (-1191))) (|has| (-433 |#2|) (-388))))) (($ $ (-1191)) 128 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) (-1732 (|has| (-433 |#2|) (-922 (-1191))) (|has| (-433 |#2|) (-388))))) (($ $ (-790)) 130 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-247))) (-1732 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373)))) (($ $) 132 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-247))) (-1732 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373))))) (-4174 (((-706 (-433 |#2|)) (-1280 $) (-1 (-433 |#2|) (-433 |#2|))) 149 (|has| (-433 |#2|) (-388)))) (-3390 ((|#3|) 154)) (-3809 (($) 143 (|has| (-433 |#2|) (-373)))) (-2231 (((-1280 (-433 |#2|)) $ (-1280 $)) 48) (((-706 (-433 |#2|)) (-1280 $) (-1280 $)) 47) (((-1280 (-433 |#2|)) $) 60) (((-706 (-433 |#2|)) (-1280 $)) 59)) (-1778 (((-1280 (-433 |#2|)) $) 57) (($ (-1280 (-433 |#2|))) 56) ((|#3| $) 166) (($ |#3|) 152)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 140 (|has| (-433 |#2|) (-373)))) (-3985 (((-1280 $) (-1280 $)) 188)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 |#2|)) 36) (($ (-433 (-592))) 80 (-3836 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-1065 (-433 (-592)))))) (($ $) 86 (|has| (-433 |#2|) (-388)))) (-1517 (($ $) 139 (|has| (-433 |#2|) (-373))) (((-3 $ "failed") $) 41 (|has| (-433 |#2|) (-169)))) (-4198 ((|#3| $) 43)) (-4010 (((-790)) 28)) (-2457 (((-141)) 201)) (-2576 (((-141) |#1|) 200) (((-141) |#2|) 199)) (-2195 (((-1280 $)) 61)) (-2537 (((-141) $ $) 90 (|has| (-433 |#2|) (-388)))) (-3748 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) 169)) (-3059 (((-141)) 203)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 112 (|has| (-433 |#2|) (-388)))) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-1 (-433 |#2|) (-433 |#2|)) (-790)) 120 (|has| (-433 |#2|) (-388))) (($ $ (-1 (-433 |#2|) (-433 |#2|))) 119 (|has| (-433 |#2|) (-388))) (($ $ (-658 (-1191)) (-658 (-790))) 121 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) (-1732 (|has| (-433 |#2|) (-922 (-1191))) (|has| (-433 |#2|) (-388))))) (($ $ (-1191) (-790)) 122 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) (-1732 (|has| (-433 |#2|) (-922 (-1191))) (|has| (-433 |#2|) (-388))))) (($ $ (-658 (-1191))) 123 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) (-1732 (|has| (-433 |#2|) (-922 (-1191))) (|has| (-433 |#2|) (-388))))) (($ $ (-1191)) 124 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) (-1732 (|has| (-433 |#2|) (-922 (-1191))) (|has| (-433 |#2|) (-388))))) (($ $ (-790)) 129 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-247))) (-1732 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373)))) (($ $) 131 (-3836 (-1732 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-247))) (-1732 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373))))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 116 (|has| (-433 |#2|) (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 113 (|has| (-433 |#2|) (-388)))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 |#2|)) 38) (($ (-433 |#2|) $) 37) (($ (-433 (-592)) $) 115 (|has| (-433 |#2|) (-388))) (($ $ (-433 (-592))) 114 (|has| (-433 |#2|) (-388))))) 
+(((-362 |#1| |#2| |#3|) (-1311) (-1235) (-1255 |t#1|) (-1255 (-433 |t#2|))) (T -362)) 
+((-3804 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-790)))) (-3918 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-790)))) (-3059 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-2619 (*1 *2 *3 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-2457 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-2576 (*1 *2 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-2576 (*1 *2 *3) (-12 (-4 *1 (-362 *4 *3 *5)) (-4 *4 (-1235)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-5 *2 (-141)))) (-4578 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-2105 (*1 *2 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-2105 (*1 *2 *3) (-12 (-4 *1 (-362 *4 *3 *5)) (-4 *4 (-1235)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-5 *2 (-141)))) (-1634 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-2282 (*1 *2 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-2282 (*1 *2 *3) (-12 (-4 *1 (-362 *4 *3 *5)) (-4 *4 (-1235)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-5 *2 (-141)))) (-4023 (*1 *2) (-12 (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)))) (-3720 (*1 *2) (-12 (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)))) (-3717 (*1 *2 *1) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-4551 (*1 *2 *1) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-3985 (*1 *2 *2) (-12 (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))))) (-3655 (*1 *2 *2) (-12 (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))))) (-1872 (*1 *2 *2) (-12 (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))))) (-4373 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-706 (-433 *4))))) (-1346 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-706 (-433 *4))))) (-2925 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-706 (-433 *4))))) (-3757 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-706 (-433 *4))))) (-4094 (*1 *2 *1) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-2 (|:| |num| (-1280 *4)) (|:| |den| *4))))) (-1645 (*1 *2 *1) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-2 (|:| |num| (-1280 *4)) (|:| |den| *4))))) (-2482 (*1 *1 *2 *3) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1255 *4)) (-4 *4 (-1235)) (-4 *1 (-362 *4 *3 *5)) (-4 *5 (-1255 (-433 *3))))) (-3406 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *1 (-362 *4 *5 *6)) (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-2 (|:| |num| (-706 *5)) (|:| |den| *5))))) (-4551 (*1 *2 *1 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) (-4551 (*1 *2 *1 *3) (-12 (-4 *1 (-362 *4 *3 *5)) (-4 *4 (-1235)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-5 *2 (-141)))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))))) (-1626 (*1 *1 *2 *3) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1255 *4)) (-4 *4 (-1235)) (-4 *1 (-362 *4 *3 *5)) (-4 *5 (-1255 (-433 *3))))) (-3262 (*1 *1 *1) (-12 (-4 *1 (-362 *2 *3 *4)) (-4 *2 (-1235)) (-4 *3 (-1255 *2)) (-4 *4 (-1255 (-433 *3))))) (-3927 (*1 *2 *1 *2 *2) (-12 (-4 *1 (-362 *2 *3 *4)) (-4 *2 (-1235)) (-4 *3 (-1255 *2)) (-4 *4 (-1255 (-433 *3))))) (-3143 (*1 *2) (|partial| -12 (-4 *1 (-362 *3 *2 *4)) (-4 *3 (-1235)) (-4 *4 (-1255 (-433 *2))) (-4 *2 (-1255 *3)))) (-3560 (*1 *2) (|partial| -12 (-4 *1 (-362 *3 *2 *4)) (-4 *3 (-1235)) (-4 *4 (-1255 (-433 *2))) (-4 *2 (-1255 *3)))) (-3748 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-1235)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-2 (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (-4 *1 (-362 *4 *5 *6)))) (-2010 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *1 (-362 *4 *5 *6)) (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-4 *4 (-388)) (-5 *2 (-658 (-980 *4))))) (-3969 (*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *3 (-394)) (-5 *2 (-658 (-658 *3)))))) 
+(-13 (-741 (-433 |t#2|) |t#3|) (-10 -8 (-15 -3804 ((-790))) (-15 -3918 ((-790))) (-15 -3059 ((-141))) (-15 -2619 ((-141) |t#1| |t#1|)) (-15 -2457 ((-141))) (-15 -2576 ((-141) |t#1|)) (-15 -2576 ((-141) |t#2|)) (-15 -4578 ((-141))) (-15 -2105 ((-141) |t#1|)) (-15 -2105 ((-141) |t#2|)) (-15 -1634 ((-141))) (-15 -2282 ((-141) |t#1|)) (-15 -2282 ((-141) |t#2|)) (-15 -4023 ((-1280 $))) (-15 -3720 ((-1280 $))) (-15 -3717 ((-141) $)) (-15 -4551 ((-141) $)) (-15 -3985 ((-1280 $) (-1280 $))) (-15 -3655 ((-1280 $) (-1280 $))) (-15 -1872 ((-1280 $) (-1280 $))) (-15 -4373 ((-706 (-433 |t#2|)))) (-15 -1346 ((-706 (-433 |t#2|)))) (-15 -2925 ((-706 (-433 |t#2|)))) (-15 -3757 ((-706 (-433 |t#2|)))) (-15 -4094 ((-2 (|:| |num| (-1280 |t#2|)) (|:| |den| |t#2|)) $)) (-15 -1626 ($ (-1280 |t#2|) |t#2|)) (-15 -1645 ((-2 (|:| |num| (-1280 |t#2|)) (|:| |den| |t#2|)) $)) (-15 -2482 ($ (-1280 |t#2|) |t#2|)) (-15 -3406 ((-2 (|:| |num| (-706 |t#2|)) (|:| |den| |t#2|)) (-1 |t#2| |t#2|))) (-15 -4551 ((-141) $ |t#1|)) (-15 -4551 ((-141) $ |t#2|)) (-15 -3644 ($ $ (-1 |t#2| |t#2|))) (-15 -1626 ($ (-1280 |t#2|) |t#2|)) (-15 -3262 ($ $)) (-15 -3927 (|t#1| $ |t#1| |t#1|)) (-15 -3143 ((-3 |t#2| "failed"))) (-15 -3560 ((-3 |t#2| "failed"))) (-15 -3748 ((-2 (|:| |num| $) (|:| |den| |t#2|) (|:| |derivden| |t#2|) (|:| |gd| |t#2|)) $ (-1 |t#2| |t#2|))) (IF (|has| |t#1| (-388)) (-15 -2010 ((-658 (-980 |t#1|)) (-1191))) |noBranch|) (IF (|has| |t#1| (-394)) (-15 -3969 ((-658 (-658 |t#1|)))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-43 (-433 |#2|)) . T) ((-43 $) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-140 (-433 |#2|) (-433 |#2|)) . T) ((-140 $ $) . T) ((-158) . T) ((-169) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-169))) ((-171) |has| (-433 |#2|) (-171)) ((-632 (-877)) . T) ((-194) . T) ((-633 |#3|) . T) ((-245 (-433 |#2|)) |has| (-433 |#2|) (-388)) ((-247) -3836 (|has| (-433 |#2|) (-373)) (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388)))) ((-260) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-307) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-323) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-388) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-428) |has| (-433 |#2|) (-373)) ((-394) -3836 (|has| (-433 |#2|) (-394)) (|has| (-433 |#2|) (-373))) ((-373) |has| (-433 |#2|) (-373)) ((-396 (-433 |#2|) |#3|) . T) ((-435 (-433 |#2|) |#3|) . T) ((-403 (-433 |#2|)) . T) ((-437 (-433 |#2|)) . T) ((-477) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-582) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-661 (-433 (-592))) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-661 (-433 |#2|)) . T) ((-661 $) . T) ((-678) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-654 (-433 |#2|)) . T) ((-654 (-592)) |has| (-433 |#2|) (-654 (-592))) ((-734 (-433 (-592))) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-734 (-433 |#2|)) . T) ((-734 $) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-741 (-433 |#2|) |#3|) . T) ((-743) . T) ((-922 (-1191)) -12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191)))) ((-943) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-1065 (-433 (-592))) |has| (-433 |#2|) (-1065 (-433 (-592)))) ((-1065 (-433 |#2|)) . T) ((-1065 (-592)) |has| (-433 |#2|) (-1065 (-592))) ((-1081 (-433 (-592))) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388))) ((-1081 (-433 |#2|)) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) |has| (-433 |#2|) (-373)) ((-1235) -3836 (|has| (-433 |#2|) (-373)) (|has| (-433 |#2|) (-388)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 (((-932 |#1|) $) NIL) (($ $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| (-932 |#1|) (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL (|has| (-932 |#1|) (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-932 |#1|) "failed") $) NIL)) (-2400 (((-932 |#1|) $) NIL)) (-1626 (($ (-1280 (-932 |#1|))) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-932 |#1|) (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-932 |#1|) (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL (|has| (-932 |#1|) (-394)))) (-3293 (((-141) $) NIL (|has| (-932 |#1|) (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394)))) (($ $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| (-932 |#1|) (-394))) (((-855 (-944)) $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) NIL (|has| (-932 |#1|) (-394)))) (-2114 (((-141) $) NIL (|has| (-932 |#1|) (-394)))) (-2793 (((-932 |#1|) $) NIL) (($ $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| (-932 |#1|) (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 (-932 |#1|)) $) NIL) (((-1187 $) $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-3546 (((-944) $) NIL (|has| (-932 |#1|) (-394)))) (-2343 (((-1187 (-932 |#1|)) $) NIL (|has| (-932 |#1|) (-394)))) (-1492 (((-1187 (-932 |#1|)) $) NIL (|has| (-932 |#1|) (-394))) (((-3 (-1187 (-932 |#1|)) "failed") $ $) NIL (|has| (-932 |#1|) (-394)))) (-2252 (($ $ (-1187 (-932 |#1|))) NIL (|has| (-932 |#1|) (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-932 |#1|) (-394)) CONST)) (-1825 (($ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-2761 (((-986 (-1137))) NIL)) (-2934 (($) NIL (|has| (-932 |#1|) (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| (-932 |#1|) (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| (-932 |#1|) (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| (-932 |#1|) (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3390 (((-1187 (-932 |#1|))) NIL)) (-3809 (($) NIL (|has| (-932 |#1|) (-394)))) (-3342 (($) NIL (|has| (-932 |#1|) (-394)))) (-2231 (((-1280 (-932 |#1|)) $) NIL) (((-706 (-932 |#1|)) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| (-932 |#1|) (-394)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-932 |#1|)) NIL)) (-1517 (($ $) NIL (|has| (-932 |#1|) (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL) (((-1280 $) (-944)) NIL)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3417 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-1940 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL) (($ $ (-932 |#1|)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ (-932 |#1|)) NIL) (($ (-932 |#1|) $) NIL))) 
+(((-363 |#1| |#2|) (-13 (-349 (-932 |#1|)) (-10 -7 (-15 -2761 ((-986 (-1137)))))) (-944) (-944)) (T -363)) 
+((-2761 (*1 *2) (-12 (-5 *2 (-986 (-1137))) (-5 *1 (-363 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944))))) 
+(-13 (-349 (-932 |#1|)) (-10 -7 (-15 -2761 ((-986 (-1137)))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 46)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) 43 (|has| |#1| (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL (|has| |#1| (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 113)) (-2400 ((|#1| $) 84)) (-1626 (($ (-1280 |#1|)) 102)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 93 (|has| |#1| (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) 96 (|has| |#1| (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) 128 (|has| |#1| (-394)))) (-3293 (((-141) $) 49 (|has| |#1| (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394)))) (($ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) 47 (|has| |#1| (-394))) (((-855 (-944)) $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) 130 (|has| |#1| (-394)))) (-2114 (((-141) $) NIL (|has| |#1| (-394)))) (-2793 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 |#1|) $) 88) (((-1187 $) $ (-944)) NIL (|has| |#1| (-394)))) (-3546 (((-944) $) 138 (|has| |#1| (-394)))) (-2343 (((-1187 |#1|) $) NIL (|has| |#1| (-394)))) (-1492 (((-1187 |#1|) $) NIL (|has| |#1| (-394))) (((-3 (-1187 |#1|) "failed") $ $) NIL (|has| |#1| (-394)))) (-2252 (($ $ (-1187 |#1|)) NIL (|has| |#1| (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 145)) (-3703 (($) NIL (|has| |#1| (-394)) CONST)) (-1825 (($ (-944)) 70 (|has| |#1| (-394)))) (-2142 (((-141) $) 116)) (-2951 (((-1137) $) NIL)) (-2761 (((-986 (-1137))) 44)) (-2934 (($) 126 (|has| |#1| (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 91 (|has| |#1| (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) 67) (((-944)) 68)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) 129 (|has| |#1| (-394))) (((-3 (-790) "failed") $ $) 123 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3390 (((-1187 |#1|)) 94)) (-3809 (($) 127 (|has| |#1| (-394)))) (-3342 (($) 135 (|has| |#1| (-394)))) (-2231 (((-1280 |#1|) $) 59) (((-706 |#1|) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| |#1| (-394)))) (-1683 (((-877) $) 141) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) 74)) (-1517 (($ $) NIL (|has| |#1| (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-4010 (((-790)) 137)) (-2195 (((-1280 $)) 115) (((-1280 $) (-944)) 72)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 32 T CONST)) (-4257 (($) 19 T CONST)) (-3417 (($ $) 80 (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-1940 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-3255 (((-141) $ $) 48)) (-3313 (($ $ $) 143) (($ $ |#1|) 144)) (-3306 (($ $) 125) (($ $ $) NIL)) (-3300 (($ $ $) 61)) (** (($ $ (-944)) 147) (($ $ (-790)) 148) (($ $ (-592)) 146)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 76) (($ $ $) 75) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 142))) 
+(((-364 |#1| |#2|) (-13 (-349 |#1|) (-10 -7 (-15 -2761 ((-986 (-1137)))))) (-373) (-1187 |#1|)) (T -364)) 
+((-2761 (*1 *2) (-12 (-5 *2 (-986 (-1137))) (-5 *1 (-364 *3 *4)) (-4 *3 (-373)) (-14 *4 (-1187 *3))))) 
+(-13 (-349 |#1|) (-10 -7 (-15 -2761 ((-986 (-1137)))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| |#1| (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL (|has| |#1| (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-1626 (($ (-1280 |#1|)) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| |#1| (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL (|has| |#1| (-394)))) (-3293 (((-141) $) NIL (|has| |#1| (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394)))) (($ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| |#1| (-394))) (((-855 (-944)) $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) NIL (|has| |#1| (-394)))) (-2114 (((-141) $) NIL (|has| |#1| (-394)))) (-2793 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 |#1|) $) NIL) (((-1187 $) $ (-944)) NIL (|has| |#1| (-394)))) (-3546 (((-944) $) NIL (|has| |#1| (-394)))) (-2343 (((-1187 |#1|) $) NIL (|has| |#1| (-394)))) (-1492 (((-1187 |#1|) $) NIL (|has| |#1| (-394))) (((-3 (-1187 |#1|) "failed") $ $) NIL (|has| |#1| (-394)))) (-2252 (($ $ (-1187 |#1|)) NIL (|has| |#1| (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| |#1| (-394)) CONST)) (-1825 (($ (-944)) NIL (|has| |#1| (-394)))) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-2761 (((-986 (-1137))) NIL)) (-2934 (($) NIL (|has| |#1| (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| |#1| (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| |#1| (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3390 (((-1187 |#1|)) NIL)) (-3809 (($) NIL (|has| |#1| (-394)))) (-3342 (($) NIL (|has| |#1| (-394)))) (-2231 (((-1280 |#1|) $) NIL) (((-706 |#1|) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| |#1| (-394)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) NIL)) (-1517 (($ $) NIL (|has| |#1| (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL) (((-1280 $) (-944)) NIL)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3417 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-1940 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL) (($ $ |#1|) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-365 |#1| |#2|) (-13 (-349 |#1|) (-10 -7 (-15 -2761 ((-986 (-1137)))))) (-373) (-944)) (T -365)) 
+((-2761 (*1 *2) (-12 (-5 *2 (-986 (-1137))) (-5 *1 (-365 *3 *4)) (-4 *3 (-373)) (-14 *4 (-944))))) 
+(-13 (-349 |#1|) (-10 -7 (-15 -2761 ((-986 (-1137)))))) 
+((-2139 (((-141) |#2|) 68)) (-4487 (((-444 |#2|) |#2|) 56)) (-3845 (((-444 |#2|) |#2|) 58)) (-3082 (((-658 |#2|) |#2|) 61)) (-2152 (((-658 |#2|) |#2| (-790)) 62)) (-4500 (((-444 |#2|) |#2|) 59))) 
+(((-366 |#1| |#2|) (-10 -7 (-15 -3082 ((-658 |#2|) |#2|)) (-15 -2152 ((-658 |#2|) |#2| (-790))) (-15 -4500 ((-444 |#2|) |#2|)) (-15 -4487 ((-444 |#2|) |#2|)) (-15 -3845 ((-444 |#2|) |#2|)) (-15 -2139 ((-141) |#2|))) (-373) (-1255 |#1|)) (T -366)) 
+((-2139 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) (-3845 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) (-4487 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) (-4500 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) (-2152 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-373)) (-5 *2 (-658 *3)) (-5 *1 (-366 *5 *3)) (-4 *3 (-1255 *5)))) (-3082 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-658 *3)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -3082 ((-658 |#2|) |#2|)) (-15 -2152 ((-658 |#2|) |#2| (-790))) (-15 -4500 ((-444 |#2|) |#2|)) (-15 -4487 ((-444 |#2|) |#2|)) (-15 -3845 ((-444 |#2|) |#2|)) (-15 -2139 ((-141) |#2|))) 
+((-2139 (((-141) |#2|) 68)) (-4487 (((-444 |#2|) |#2|) 56)) (-3845 (((-444 |#2|) |#2|) 58)) (-3082 (((-658 |#2|) |#2|) 61)) (-2152 (((-658 |#2|) |#2| (-790)) 62)) (-4500 (((-444 |#2|) |#2|) 59))) 
+(((-367 |#1| |#2|) (-10 -7 (-15 -3082 ((-658 |#2|) |#2|)) (-15 -2152 ((-658 |#2|) |#2| (-790))) (-15 -4500 ((-444 |#2|) |#2|)) (-15 -4487 ((-444 |#2|) |#2|)) (-15 -3845 ((-444 |#2|) |#2|)) (-15 -2139 ((-141) |#2|))) (-373) (-1255 |#1|)) (T -367)) 
+((-2139 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4)))) (-3845 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4)))) (-4487 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4)))) (-4500 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4)))) (-2152 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-373)) (-5 *2 (-658 *3)) (-5 *1 (-367 *5 *3)) (-4 *3 (-1255 *5)))) (-3082 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-658 *3)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -3082 ((-658 |#2|) |#2|)) (-15 -2152 ((-658 |#2|) |#2| (-790))) (-15 -4500 ((-444 |#2|) |#2|)) (-15 -4487 ((-444 |#2|) |#2|)) (-15 -3845 ((-444 |#2|) |#2|)) (-15 -2139 ((-141) |#2|))) 
+((-2569 (((-1171 (-706 (-1187 |#1|))) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#3|) (-790) (-790)) 54) (((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#3|) (-658 (-790))) 42))) 
+(((-368 |#1| |#2| |#3|) (-10 -7 (-15 -2569 ((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#3|) (-658 (-790)))) (-15 -2569 ((-1171 (-706 (-1187 |#1|))) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#3|) (-790) (-790)))) (-13 (-582) (-477)) (-346 |#1| (-790)) (-346 (-433 |#1|) (-790))) (T -368)) 
+((-2569 (*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-658 *7)) (-5 *4 (-1 *7 (-790) (-790) *8)) (-5 *5 (-1280 *9)) (-5 *6 (-790)) (-4 *7 (-13 (-582) (-477))) (-4 *8 (-346 *7 *6)) (-4 *9 (-346 (-433 *7) *6)) (-5 *2 (-1171 (-706 (-1187 *7)))) (-5 *1 (-368 *7 *8 *9)))) (-2569 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 *7)) (-5 *4 (-1 *7 (-790) (-790) *8)) (-5 *5 (-1280 *9)) (-5 *6 (-658 (-790))) (-4 *7 (-13 (-582) (-477))) (-4 *8 (-346 *7 (-790))) (-4 *9 (-346 (-433 *7) (-790))) (-5 *2 (-706 (-1187 *7))) (-5 *1 (-368 *7 *8 *9))))) 
+(-10 -7 (-15 -2569 ((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#3|) (-658 (-790)))) (-15 -2569 ((-1171 (-706 (-1187 |#1|))) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#3|) (-790) (-790)))) 
+((-3125 (((-658 |#1|) |#1| (-790)) 21)) (-2084 ((|#1| |#1| (-790) (-790) |#2|) 20)) (-3014 (((-433 (-1187 |#1|)) (-658 (-433 |#1|)) (-658 (-433 |#1|)) (-790)) 75) (((-433 (-1187 |#1|)) (-658 |#1|) (-658 |#1|) (-790)) 68)) (-2569 (((-1171 (-706 (-1187 |#1|))) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-790) (-790)) 62) (((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-658 (-790))) 44)) (-2959 ((|#1| (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-790) (-1280 (-1187 |#1|))) 37)) (-1741 (((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-1280 (-1187 |#1|))) (-658 (-790))) 43)) (-1703 (((-658 |#1|) (-790)) 17)) (-3350 ((|#1| (-790) (-790) |#2|) 11)) (-1610 (((-658 |#1|) (-790)) 24)) (-3977 ((|#1| (-790) (-790) |#2|) 22))) 
+(((-369 |#1| |#2|) (-10 -7 (-15 -1741 ((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-1280 (-1187 |#1|))) (-658 (-790)))) (-15 -3014 ((-433 (-1187 |#1|)) (-658 |#1|) (-658 |#1|) (-790))) (-15 -3014 ((-433 (-1187 |#1|)) (-658 (-433 |#1|)) (-658 (-433 |#1|)) (-790))) (-15 -2569 ((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-658 (-790)))) (-15 -2569 ((-1171 (-706 (-1187 |#1|))) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-790) (-790))) (-15 -2959 (|#1| (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-790) (-1280 (-1187 |#1|)))) (-15 -3350 (|#1| (-790) (-790) |#2|)) (-15 -1703 ((-658 |#1|) (-790))) (-15 -3977 (|#1| (-790) (-790) |#2|)) (-15 -1610 ((-658 |#1|) (-790))) (-15 -2084 (|#1| |#1| (-790) (-790) |#2|)) (-15 -3125 ((-658 |#1|) |#1| (-790)))) (-13 (-582) (-477)) (-52 |#1| (-790))) (T -369)) 
+((-3125 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *3 (-13 (-582) (-477))) (-5 *2 (-658 *3)) (-5 *1 (-369 *3 *5)) (-4 *5 (-52 *3 *4)))) (-2084 (*1 *2 *2 *3 *3 *4) (-12 (-5 *3 (-790)) (-4 *2 (-13 (-582) (-477))) (-5 *1 (-369 *2 *4)) (-4 *4 (-52 *2 *3)))) (-1610 (*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-582) (-477))) (-5 *2 (-658 *4)) (-5 *1 (-369 *4 *5)) (-4 *5 (-52 *4 *3)))) (-3977 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-790)) (-4 *2 (-13 (-582) (-477))) (-5 *1 (-369 *2 *4)) (-4 *4 (-52 *2 *3)))) (-1703 (*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-582) (-477))) (-5 *2 (-658 *4)) (-5 *1 (-369 *4 *5)) (-4 *5 (-52 *4 *3)))) (-3350 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-790)) (-4 *2 (-13 (-582) (-477))) (-5 *1 (-369 *2 *4)) (-4 *4 (-52 *2 *3)))) (-2959 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *2 (-790) (-790) *7)) (-5 *4 (-1280 *7)) (-5 *5 (-790)) (-5 *6 (-1280 (-1187 *2))) (-4 *7 (-52 *2 *5)) (-4 *2 (-13 (-582) (-477))) (-5 *1 (-369 *2 *7)))) (-2569 (*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-658 *7)) (-5 *4 (-1 *7 (-790) (-790) *8)) (-5 *5 (-1280 *8)) (-5 *6 (-790)) (-4 *7 (-13 (-582) (-477))) (-4 *8 (-52 *7 *6)) (-5 *2 (-1171 (-706 (-1187 *7)))) (-5 *1 (-369 *7 *8)))) (-2569 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 *7)) (-5 *4 (-1 *7 (-790) (-790) *8)) (-5 *5 (-1280 *8)) (-5 *6 (-658 (-790))) (-4 *7 (-13 (-582) (-477))) (-4 *8 (-52 *7 (-790))) (-5 *2 (-706 (-1187 *7))) (-5 *1 (-369 *7 *8)))) (-3014 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 (-433 *5))) (-4 *5 (-13 (-582) (-477))) (-5 *4 (-790)) (-5 *2 (-433 (-1187 *5))) (-5 *1 (-369 *5 *6)) (-4 *6 (-52 *5 *4)))) (-3014 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 *5)) (-4 *5 (-13 (-582) (-477))) (-5 *4 (-790)) (-5 *2 (-433 (-1187 *5))) (-5 *1 (-369 *5 *6)) (-4 *6 (-52 *5 *4)))) (-1741 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *6)) (-5 *4 (-1 *6 (-790) (-1280 (-1187 *6)))) (-5 *5 (-658 (-790))) (-4 *6 (-13 (-582) (-477))) (-5 *2 (-706 (-1187 *6))) (-5 *1 (-369 *6 *7)) (-4 *7 (-52 *6 (-790)))))) 
+(-10 -7 (-15 -1741 ((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-1280 (-1187 |#1|))) (-658 (-790)))) (-15 -3014 ((-433 (-1187 |#1|)) (-658 |#1|) (-658 |#1|) (-790))) (-15 -3014 ((-433 (-1187 |#1|)) (-658 (-433 |#1|)) (-658 (-433 |#1|)) (-790))) (-15 -2569 ((-706 (-1187 |#1|)) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-658 (-790)))) (-15 -2569 ((-1171 (-706 (-1187 |#1|))) (-658 |#1|) (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-790) (-790))) (-15 -2959 (|#1| (-1 |#1| (-790) (-790) |#2|) (-1280 |#2|) (-790) (-1280 (-1187 |#1|)))) (-15 -3350 (|#1| (-790) (-790) |#2|)) (-15 -1703 ((-658 |#1|) (-790))) (-15 -3977 (|#1| (-790) (-790) |#2|)) (-15 -1610 ((-658 |#1|) (-790))) (-15 -2084 (|#1| |#1| (-790) (-790) |#2|)) (-15 -3125 ((-658 |#1|) |#1| (-790)))) 
+((-1351 (((-790) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137)))))) 40)) (-4102 (((-986 (-1137)) (-1187 |#1|)) 84)) (-1372 (((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) (-1187 |#1|)) 77)) (-2839 (((-706 |#1|) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137)))))) 85)) (-4472 (((-3 (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) "failed") (-944)) 10)) (-3747 (((-3 (-1187 |#1|) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137)))))) (-944)) 15))) 
+(((-370 |#1|) (-10 -7 (-15 -4102 ((-986 (-1137)) (-1187 |#1|))) (-15 -1372 ((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) (-1187 |#1|))) (-15 -2839 ((-706 |#1|) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (-15 -1351 ((-790) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (-15 -4472 ((-3 (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) "failed") (-944))) (-15 -3747 ((-3 (-1187 |#1|) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137)))))) (-944)))) (-373)) (T -370)) 
+((-3747 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-3 (-1187 *4) (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137))))))) (-5 *1 (-370 *4)) (-4 *4 (-373)))) (-4472 (*1 *2 *3) (|partial| -12 (-5 *3 (-944)) (-5 *2 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-5 *1 (-370 *4)) (-4 *4 (-373)))) (-1351 (*1 *2 *3) (-12 (-5 *3 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-4 *4 (-373)) (-5 *2 (-790)) (-5 *1 (-370 *4)))) (-2839 (*1 *2 *3) (-12 (-5 *3 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-4 *4 (-373)) (-5 *2 (-706 *4)) (-5 *1 (-370 *4)))) (-1372 (*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-5 *2 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-5 *1 (-370 *4)))) (-4102 (*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-5 *2 (-986 (-1137))) (-5 *1 (-370 *4))))) 
+(-10 -7 (-15 -4102 ((-986 (-1137)) (-1187 |#1|))) (-15 -1372 ((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) (-1187 |#1|))) (-15 -2839 ((-706 |#1|) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (-15 -1351 ((-790) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (-15 -4472 ((-3 (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) "failed") (-944))) (-15 -3747 ((-3 (-1187 |#1|) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137)))))) (-944)))) 
+((-1683 ((|#1| |#3|) 84) ((|#3| |#1|) 68))) 
+(((-371 |#1| |#2| |#3|) (-10 -7 (-15 -1683 (|#3| |#1|)) (-15 -1683 (|#1| |#3|))) (-349 |#2|) (-373) (-349 |#2|)) (T -371)) 
+((-1683 (*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *2 (-349 *4)) (-5 *1 (-371 *2 *4 *3)) (-4 *3 (-349 *4)))) (-1683 (*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *2 (-349 *4)) (-5 *1 (-371 *3 *4 *2)) (-4 *3 (-349 *4))))) 
+(-10 -7 (-15 -1683 (|#3| |#1|)) (-15 -1683 (|#1| |#3|))) 
+((-3293 (((-141) $) 50)) (-4346 (((-855 (-944)) $) 21) (((-944) $) 51)) (-3921 (((-3 $ "failed") $) 16)) (-3703 (($) 9)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 91)) (-2177 (((-3 (-790) "failed") $ $) 70) (((-790) $) 59)) (-3644 (($ $ (-790)) NIL) (($ $) 8)) (-3809 (($) 44)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 33)) (-1517 (((-3 $ "failed") $) 39) (($ $) 38))) 
+(((-372 |#1|) (-10 -8 (-15 -4346 ((-944) |#1|)) (-15 -2177 ((-790) |#1|)) (-15 -3293 ((-141) |#1|)) (-15 -3809 (|#1|)) (-15 -2288 ((-3 (-1280 |#1|) "failed") (-706 |#1|))) (-15 -1517 (|#1| |#1|)) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3703 (|#1|)) (-15 -3921 ((-3 |#1| "failed") |#1|)) (-15 -2177 ((-3 (-790) "failed") |#1| |#1|)) (-15 -4346 ((-855 (-944)) |#1|)) (-15 -1517 ((-3 |#1| "failed") |#1|)) (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|)))) (-373)) (T -372)) 
+NIL 
+(-10 -8 (-15 -4346 ((-944) |#1|)) (-15 -2177 ((-790) |#1|)) (-15 -3293 ((-141) |#1|)) (-15 -3809 (|#1|)) (-15 -2288 ((-3 (-1280 |#1|) "failed") (-706 |#1|))) (-15 -1517 (|#1| |#1|)) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3703 (|#1|)) (-15 -3921 ((-3 |#1| "failed") |#1|)) (-15 -2177 ((-3 (-790) "failed") |#1| |#1|)) (-15 -4346 ((-855 (-944)) |#1|)) (-15 -1517 ((-3 |#1| "failed") |#1|)) (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-4217 (((-1199 (-944) (-790)) (-592)) 88)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-1403 (((-790)) 98)) (-3001 (($) 16 T CONST)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 82)) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-4290 (($) 101)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2667 (($) 86)) (-3293 (((-141) $) 85)) (-1525 (($ $) 75) (($ $ (-790)) 74)) (-2802 (((-141) $) 69)) (-4346 (((-855 (-944)) $) 77) (((-944) $) 83)) (-3558 (((-141) $) 30)) (-3921 (((-3 $ "failed") $) 97)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-3546 (((-944) $) 100)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-3703 (($) 96 T CONST)) (-1825 (($ (-944)) 99)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 89)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-1405 (((-658 $)) 102)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-2177 (((-3 (-790) "failed") $ $) 76) (((-790) $) 84)) (-3644 (($ $ (-790)) 94) (($ $) 92)) (-3809 (($) 87)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 90)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63)) (-1517 (((-3 $ "failed") $) 78) (($ $) 91)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-790)) 95) (($ $) 93)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64))) 
+(((-373) (-1311)) (T -373)) 
+((-1517 (*1 *1 *1) (-4 *1 (-373))) (-2288 (*1 *2 *3) (|partial| -12 (-5 *3 (-706 *1)) (-4 *1 (-373)) (-5 *2 (-1280 *1)))) (-1967 (*1 *2) (-12 (-4 *1 (-373)) (-5 *2 (-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))))) (-4217 (*1 *2 *3) (-12 (-4 *1 (-373)) (-5 *3 (-592)) (-5 *2 (-1199 (-944) (-790))))) (-3809 (*1 *1) (-4 *1 (-373))) (-2667 (*1 *1) (-4 *1 (-373))) (-3293 (*1 *2 *1) (-12 (-4 *1 (-373)) (-5 *2 (-141)))) (-2177 (*1 *2 *1) (-12 (-4 *1 (-373)) (-5 *2 (-790)))) (-4346 (*1 *2 *1) (-12 (-4 *1 (-373)) (-5 *2 (-944)))) (-4440 (*1 *2) (-12 (-4 *1 (-373)) (-5 *2 (-3 "prime" "polynomial" "normal" "cyclic"))))) 
+(-13 (-428) (-394) (-1165) (-247) (-10 -8 (-15 -1517 ($ $)) (-15 -2288 ((-3 (-1280 $) "failed") (-706 $))) (-15 -1967 ((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592)))))) (-15 -4217 ((-1199 (-944) (-790)) (-592))) (-15 -3809 ($)) (-15 -2667 ($)) (-15 -3293 ((-141) $)) (-15 -2177 ((-790) $)) (-15 -4346 ((-944) $)) (-15 -4440 ((-3 "prime" "polynomial" "normal" "cyclic"))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-169) . T) ((-632 (-877)) . T) ((-194) . T) ((-247) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-428) . T) ((-394) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) . T) ((-1235) . T)) 
+((-2583 (((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) |#1|) 51)) (-4023 (((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|)))) 49))) 
+(((-374 |#1| |#2| |#3|) (-10 -7 (-15 -4023 ((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))))) (-15 -2583 ((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) |#1|))) (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $)))) (-1255 |#1|) (-435 |#1| |#2|)) (T -374)) 
+((-2583 (*1 *2 *3) (-12 (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-374 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) (-4023 (*1 *2) (-12 (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-374 *3 *4 *5)) (-4 *5 (-435 *3 *4))))) 
+(-10 -7 (-15 -4023 ((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))))) (-15 -2583 ((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 (((-932 |#1|) $) NIL) (($ $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| (-932 |#1|) (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1351 (((-790)) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL (|has| (-932 |#1|) (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-932 |#1|) "failed") $) NIL)) (-2400 (((-932 |#1|) $) NIL)) (-1626 (($ (-1280 (-932 |#1|))) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-932 |#1|) (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-932 |#1|) (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL (|has| (-932 |#1|) (-394)))) (-3293 (((-141) $) NIL (|has| (-932 |#1|) (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394)))) (($ $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| (-932 |#1|) (-394))) (((-855 (-944)) $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) NIL (|has| (-932 |#1|) (-394)))) (-2114 (((-141) $) NIL (|has| (-932 |#1|) (-394)))) (-2793 (((-932 |#1|) $) NIL) (($ $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| (-932 |#1|) (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 (-932 |#1|)) $) NIL) (((-1187 $) $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-3546 (((-944) $) NIL (|has| (-932 |#1|) (-394)))) (-2343 (((-1187 (-932 |#1|)) $) NIL (|has| (-932 |#1|) (-394)))) (-1492 (((-1187 (-932 |#1|)) $) NIL (|has| (-932 |#1|) (-394))) (((-3 (-1187 (-932 |#1|)) "failed") $ $) NIL (|has| (-932 |#1|) (-394)))) (-2252 (($ $ (-1187 (-932 |#1|))) NIL (|has| (-932 |#1|) (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-932 |#1|) (-394)) CONST)) (-1825 (($ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-3575 (((-1280 (-658 (-2 (|:| -2324 (-932 |#1|)) (|:| -1825 (-1137)))))) NIL)) (-2915 (((-706 (-932 |#1|))) NIL)) (-2934 (($) NIL (|has| (-932 |#1|) (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| (-932 |#1|) (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| (-932 |#1|) (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| (-932 |#1|) (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3390 (((-1187 (-932 |#1|))) NIL)) (-3809 (($) NIL (|has| (-932 |#1|) (-394)))) (-3342 (($) NIL (|has| (-932 |#1|) (-394)))) (-2231 (((-1280 (-932 |#1|)) $) NIL) (((-706 (-932 |#1|)) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| (-932 |#1|) (-394)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-932 |#1|)) NIL)) (-1517 (($ $) NIL (|has| (-932 |#1|) (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL) (((-1280 $) (-944)) NIL)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3417 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-1940 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL) (($ $ (-932 |#1|)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ (-932 |#1|)) NIL) (($ (-932 |#1|) $) NIL))) 
+(((-375 |#1| |#2|) (-13 (-349 (-932 |#1|)) (-10 -7 (-15 -3575 ((-1280 (-658 (-2 (|:| -2324 (-932 |#1|)) (|:| -1825 (-1137))))))) (-15 -2915 ((-706 (-932 |#1|)))) (-15 -1351 ((-790))))) (-944) (-944)) (T -375)) 
+((-3575 (*1 *2) (-12 (-5 *2 (-1280 (-658 (-2 (|:| -2324 (-932 *3)) (|:| -1825 (-1137)))))) (-5 *1 (-375 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) (-2915 (*1 *2) (-12 (-5 *2 (-706 (-932 *3))) (-5 *1 (-375 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) (-1351 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-375 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944))))) 
+(-13 (-349 (-932 |#1|)) (-10 -7 (-15 -3575 ((-1280 (-658 (-2 (|:| -2324 (-932 |#1|)) (|:| -1825 (-1137))))))) (-15 -2915 ((-706 (-932 |#1|)))) (-15 -1351 ((-790))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 74)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 ((|#1| $) 92) (($ $ (-944)) 90 (|has| |#1| (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) 148 (|has| |#1| (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1351 (((-790)) 89)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) 162 (|has| |#1| (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 111)) (-2400 ((|#1| $) 91)) (-1626 (($ (-1280 |#1|)) 57)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 187 (|has| |#1| (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) 158 (|has| |#1| (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) 149 (|has| |#1| (-394)))) (-3293 (((-141) $) NIL (|has| |#1| (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394)))) (($ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| |#1| (-394))) (((-855 (-944)) $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) 97 (|has| |#1| (-394)))) (-2114 (((-141) $) 175 (|has| |#1| (-394)))) (-2793 ((|#1| $) 94) (($ $ (-944)) 93 (|has| |#1| (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 |#1|) $) 188) (((-1187 $) $ (-944)) NIL (|has| |#1| (-394)))) (-3546 (((-944) $) 133 (|has| |#1| (-394)))) (-2343 (((-1187 |#1|) $) 73 (|has| |#1| (-394)))) (-1492 (((-1187 |#1|) $) 70 (|has| |#1| (-394))) (((-3 (-1187 |#1|) "failed") $ $) 82 (|has| |#1| (-394)))) (-2252 (($ $ (-1187 |#1|)) 69 (|has| |#1| (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 191)) (-3703 (($) NIL (|has| |#1| (-394)) CONST)) (-1825 (($ (-944)) 136 (|has| |#1| (-394)))) (-2142 (((-141) $) 107)) (-2951 (((-1137) $) NIL)) (-3575 (((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137)))))) 83)) (-2915 (((-706 |#1|)) 87)) (-2934 (($) 96 (|has| |#1| (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 150 (|has| |#1| (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) 151)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| |#1| (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) 62)) (-3390 (((-1187 |#1|)) 152)) (-3809 (($) 132 (|has| |#1| (-394)))) (-3342 (($) NIL (|has| |#1| (-394)))) (-2231 (((-1280 |#1|) $) 105) (((-706 |#1|) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| |#1| (-394)))) (-1683 (((-877) $) 123) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) 56)) (-1517 (($ $) NIL (|has| |#1| (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-4010 (((-790)) 156)) (-2195 (((-1280 $)) 172) (((-1280 $) (-944)) 100)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 30 T CONST)) (-4257 (($) 22 T CONST)) (-3417 (($ $) 106 (|has| |#1| (-394))) (($ $ (-790)) 98 (|has| |#1| (-394)))) (-1940 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-3255 (((-141) $ $) 60)) (-3313 (($ $ $) 103) (($ $ |#1|) 104)) (-3306 (($ $) 177) (($ $ $) 181)) (-3300 (($ $ $) 179)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 137)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 185) (($ $ $) 142) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 102))) 
+(((-376 |#1| |#2|) (-13 (-349 |#1|) (-10 -7 (-15 -3575 ((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (-15 -2915 ((-706 |#1|))) (-15 -1351 ((-790))))) (-373) (-3 (-1187 |#1|) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (T -376)) 
+((-3575 (*1 *2) (-12 (-5 *2 (-1280 (-658 (-2 (|:| -2324 *3) (|:| -1825 (-1137)))))) (-5 *1 (-376 *3 *4)) (-4 *3 (-373)) (-14 *4 (-3 (-1187 *3) *2)))) (-2915 (*1 *2) (-12 (-5 *2 (-706 *3)) (-5 *1 (-376 *3 *4)) (-4 *3 (-373)) (-14 *4 (-3 (-1187 *3) (-1280 (-658 (-2 (|:| -2324 *3) (|:| -1825 (-1137))))))))) (-1351 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-376 *3 *4)) (-4 *3 (-373)) (-14 *4 (-3 (-1187 *3) (-1280 (-658 (-2 (|:| -2324 *3) (|:| -1825 (-1137)))))))))) 
+(-13 (-349 |#1|) (-10 -7 (-15 -3575 ((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (-15 -2915 ((-706 |#1|))) (-15 -1351 ((-790))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| |#1| (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1351 (((-790)) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL (|has| |#1| (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-1626 (($ (-1280 |#1|)) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| |#1| (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL (|has| |#1| (-394)))) (-3293 (((-141) $) NIL (|has| |#1| (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394)))) (($ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| |#1| (-394))) (((-855 (-944)) $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) NIL (|has| |#1| (-394)))) (-2114 (((-141) $) NIL (|has| |#1| (-394)))) (-2793 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 |#1|) $) NIL) (((-1187 $) $ (-944)) NIL (|has| |#1| (-394)))) (-3546 (((-944) $) NIL (|has| |#1| (-394)))) (-2343 (((-1187 |#1|) $) NIL (|has| |#1| (-394)))) (-1492 (((-1187 |#1|) $) NIL (|has| |#1| (-394))) (((-3 (-1187 |#1|) "failed") $ $) NIL (|has| |#1| (-394)))) (-2252 (($ $ (-1187 |#1|)) NIL (|has| |#1| (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| |#1| (-394)) CONST)) (-1825 (($ (-944)) NIL (|has| |#1| (-394)))) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-3575 (((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137)))))) NIL)) (-2915 (((-706 |#1|)) NIL)) (-2934 (($) NIL (|has| |#1| (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| |#1| (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| |#1| (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3390 (((-1187 |#1|)) NIL)) (-3809 (($) NIL (|has| |#1| (-394)))) (-3342 (($) NIL (|has| |#1| (-394)))) (-2231 (((-1280 |#1|) $) NIL) (((-706 |#1|) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| |#1| (-394)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) NIL)) (-1517 (($ $) NIL (|has| |#1| (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL) (((-1280 $) (-944)) NIL)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3417 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-1940 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL) (($ $ |#1|) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-377 |#1| |#2|) (-13 (-349 |#1|) (-10 -7 (-15 -3575 ((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (-15 -2915 ((-706 |#1|))) (-15 -1351 ((-790))))) (-373) (-944)) (T -377)) 
+((-3575 (*1 *2) (-12 (-5 *2 (-1280 (-658 (-2 (|:| -2324 *3) (|:| -1825 (-1137)))))) (-5 *1 (-377 *3 *4)) (-4 *3 (-373)) (-14 *4 (-944)))) (-2915 (*1 *2) (-12 (-5 *2 (-706 *3)) (-5 *1 (-377 *3 *4)) (-4 *3 (-373)) (-14 *4 (-944)))) (-1351 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-377 *3 *4)) (-4 *3 (-373)) (-14 *4 (-944))))) 
+(-13 (-349 |#1|) (-10 -7 (-15 -3575 ((-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))))) (-15 -2915 ((-706 |#1|))) (-15 -1351 ((-790))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 (((-932 |#1|) $) NIL) (($ $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| (-932 |#1|) (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL (|has| (-932 |#1|) (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-932 |#1|) "failed") $) NIL)) (-2400 (((-932 |#1|) $) NIL)) (-1626 (($ (-1280 (-932 |#1|))) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-932 |#1|) (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-932 |#1|) (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL (|has| (-932 |#1|) (-394)))) (-3293 (((-141) $) NIL (|has| (-932 |#1|) (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394)))) (($ $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| (-932 |#1|) (-394))) (((-855 (-944)) $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) NIL (|has| (-932 |#1|) (-394)))) (-2114 (((-141) $) NIL (|has| (-932 |#1|) (-394)))) (-2793 (((-932 |#1|) $) NIL) (($ $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| (-932 |#1|) (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 (-932 |#1|)) $) NIL) (((-1187 $) $ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-3546 (((-944) $) NIL (|has| (-932 |#1|) (-394)))) (-2343 (((-1187 (-932 |#1|)) $) NIL (|has| (-932 |#1|) (-394)))) (-1492 (((-1187 (-932 |#1|)) $) NIL (|has| (-932 |#1|) (-394))) (((-3 (-1187 (-932 |#1|)) "failed") $ $) NIL (|has| (-932 |#1|) (-394)))) (-2252 (($ $ (-1187 (-932 |#1|))) NIL (|has| (-932 |#1|) (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-932 |#1|) (-394)) CONST)) (-1825 (($ (-944)) NIL (|has| (-932 |#1|) (-394)))) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-2934 (($) NIL (|has| (-932 |#1|) (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| (-932 |#1|) (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| (-932 |#1|) (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| (-932 |#1|) (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3390 (((-1187 (-932 |#1|))) NIL)) (-3809 (($) NIL (|has| (-932 |#1|) (-394)))) (-3342 (($) NIL (|has| (-932 |#1|) (-394)))) (-2231 (((-1280 (-932 |#1|)) $) NIL) (((-706 (-932 |#1|)) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| (-932 |#1|) (-394)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-932 |#1|)) NIL)) (-1517 (($ $) NIL (|has| (-932 |#1|) (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| (-932 |#1|) (-169)) (|has| (-932 |#1|) (-394))))) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL) (((-1280 $) (-944)) NIL)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3417 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-1940 (($ $) NIL (|has| (-932 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-932 |#1|) (-394)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL) (($ $ (-932 |#1|)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ (-932 |#1|)) NIL) (($ (-932 |#1|) $) NIL))) 
+(((-378 |#1| |#2|) (-349 (-932 |#1|)) (-944) (-944)) (T -378)) 
+NIL 
+(-349 (-932 |#1|)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) 119 (|has| |#1| (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) 138 (|has| |#1| (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 91)) (-2400 ((|#1| $) 88)) (-1626 (($ (-1280 |#1|)) 83)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 115 (|has| |#1| (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) 80 (|has| |#1| (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) 39 (|has| |#1| (-394)))) (-3293 (((-141) $) NIL (|has| |#1| (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394)))) (($ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| |#1| (-394))) (((-855 (-944)) $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) 120 (|has| |#1| (-394)))) (-2114 (((-141) $) 72 (|has| |#1| (-394)))) (-2793 ((|#1| $) 38) (($ $ (-944)) 40 (|has| |#1| (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 |#1|) $) 62) (((-1187 $) $ (-944)) NIL (|has| |#1| (-394)))) (-3546 (((-944) $) 95 (|has| |#1| (-394)))) (-2343 (((-1187 |#1|) $) NIL (|has| |#1| (-394)))) (-1492 (((-1187 |#1|) $) NIL (|has| |#1| (-394))) (((-3 (-1187 |#1|) "failed") $ $) NIL (|has| |#1| (-394)))) (-2252 (($ $ (-1187 |#1|)) NIL (|has| |#1| (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| |#1| (-394)) CONST)) (-1825 (($ (-944)) 93 (|has| |#1| (-394)))) (-2142 (((-141) $) 140)) (-2951 (((-1137) $) NIL)) (-2934 (($) 35 (|has| |#1| (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 113 (|has| |#1| (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) 137)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| |#1| (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) 56)) (-3390 (((-1187 |#1|)) 86)) (-3809 (($) 125 (|has| |#1| (-394)))) (-3342 (($) NIL (|has| |#1| (-394)))) (-2231 (((-1280 |#1|) $) 50) (((-706 |#1|) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| |#1| (-394)))) (-1683 (((-877) $) 136) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) 85)) (-1517 (($ $) NIL (|has| |#1| (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-4010 (((-790)) 142)) (-2195 (((-1280 $)) 107) (((-1280 $) (-944)) 46)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 109 T CONST)) (-4257 (($) 31 T CONST)) (-3417 (($ $) 65 (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-1940 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-3255 (((-141) $ $) 105)) (-3313 (($ $ $) 97) (($ $ |#1|) 98)) (-3306 (($ $) 78) (($ $ $) 103)) (-3300 (($ $ $) 101)) (** (($ $ (-944)) NIL) (($ $ (-790)) 41) (($ $ (-592)) 128)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 76) (($ $ $) 53) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 74))) 
+(((-379 |#1| |#2|) (-349 |#1|) (-373) (-1187 |#1|)) (T -379)) 
+NIL 
+(-349 |#1|) 
+((-2220 ((|#1| (-1187 |#2|)) 51))) 
+(((-380 |#1| |#2|) (-10 -7 (-15 -2220 (|#1| (-1187 |#2|)))) (-13 (-428) (-10 -7 (-15 -1683 (|#1| |#2|)) (-15 -3546 ((-944) |#1|)) (-15 -2195 ((-1280 |#1|) (-944))) (-15 -3417 (|#1| |#1|)))) (-373)) (T -380)) 
+((-2220 (*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-4 *2 (-13 (-428) (-10 -7 (-15 -1683 (*2 *4)) (-15 -3546 ((-944) *2)) (-15 -2195 ((-1280 *2) (-944))) (-15 -3417 (*2 *2))))) (-5 *1 (-380 *2 *4))))) 
+(-10 -7 (-15 -2220 (|#1| (-1187 |#2|)))) 
+((-1876 (((-986 (-1187 |#1|)) (-1187 |#1|)) 36)) (-4290 (((-1187 |#1|) (-944) (-944)) 109) (((-1187 |#1|) (-944)) 108)) (-3293 (((-141) (-1187 |#1|)) 81)) (-4469 (((-944) (-944)) 71)) (-1678 (((-944) (-944)) 73)) (-3089 (((-944) (-944)) 69)) (-2114 (((-141) (-1187 |#1|)) 85)) (-4124 (((-3 (-1187 |#1|) "failed") (-1187 |#1|)) 97)) (-3249 (((-3 (-1187 |#1|) "failed") (-1187 |#1|)) 100)) (-2772 (((-3 (-1187 |#1|) "failed") (-1187 |#1|)) 99)) (-1439 (((-3 (-1187 |#1|) "failed") (-1187 |#1|)) 98)) (-3244 (((-3 (-1187 |#1|) "failed") (-1187 |#1|)) 94)) (-4202 (((-1187 |#1|) (-1187 |#1|)) 62)) (-4081 (((-1187 |#1|) (-944)) 103)) (-2657 (((-1187 |#1|) (-944)) 106)) (-1662 (((-1187 |#1|) (-944)) 105)) (-2376 (((-1187 |#1|) (-944)) 104)) (-3995 (((-1187 |#1|) (-944)) 101))) 
+(((-381 |#1|) (-10 -7 (-15 -3293 ((-141) (-1187 |#1|))) (-15 -2114 ((-141) (-1187 |#1|))) (-15 -3089 ((-944) (-944))) (-15 -4469 ((-944) (-944))) (-15 -1678 ((-944) (-944))) (-15 -3995 ((-1187 |#1|) (-944))) (-15 -4081 ((-1187 |#1|) (-944))) (-15 -2376 ((-1187 |#1|) (-944))) (-15 -1662 ((-1187 |#1|) (-944))) (-15 -2657 ((-1187 |#1|) (-944))) (-15 -3244 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -4124 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -1439 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -2772 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -3249 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -4290 ((-1187 |#1|) (-944))) (-15 -4290 ((-1187 |#1|) (-944) (-944))) (-15 -4202 ((-1187 |#1|) (-1187 |#1|))) (-15 -1876 ((-986 (-1187 |#1|)) (-1187 |#1|)))) (-373)) (T -381)) 
+((-1876 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-986 (-1187 *4))) (-5 *1 (-381 *4)) (-5 *3 (-1187 *4)))) (-4202 (*1 *2 *2) (-12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3)))) (-4290 (*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) (-4290 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) (-3249 (*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3)))) (-2772 (*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3)))) (-1439 (*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3)))) (-4124 (*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3)))) (-3244 (*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3)))) (-2657 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) (-1662 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) (-2376 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) (-4081 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) (-3995 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) (-1678 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-381 *3)) (-4 *3 (-373)))) (-4469 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-381 *3)) (-4 *3 (-373)))) (-3089 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-381 *3)) (-4 *3 (-373)))) (-2114 (*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-381 *4)))) (-3293 (*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-381 *4))))) 
+(-10 -7 (-15 -3293 ((-141) (-1187 |#1|))) (-15 -2114 ((-141) (-1187 |#1|))) (-15 -3089 ((-944) (-944))) (-15 -4469 ((-944) (-944))) (-15 -1678 ((-944) (-944))) (-15 -3995 ((-1187 |#1|) (-944))) (-15 -4081 ((-1187 |#1|) (-944))) (-15 -2376 ((-1187 |#1|) (-944))) (-15 -1662 ((-1187 |#1|) (-944))) (-15 -2657 ((-1187 |#1|) (-944))) (-15 -3244 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -4124 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -1439 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -2772 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -3249 ((-3 (-1187 |#1|) "failed") (-1187 |#1|))) (-15 -4290 ((-1187 |#1|) (-944))) (-15 -4290 ((-1187 |#1|) (-944) (-944))) (-15 -4202 ((-1187 |#1|) (-1187 |#1|))) (-15 -1876 ((-986 (-1187 |#1|)) (-1187 |#1|)))) 
+((-3524 (((-3 (-658 |#3|) "failed") (-658 |#3|) |#3|) 33))) 
+(((-382 |#1| |#2| |#3|) (-10 -7 (-15 -3524 ((-3 (-658 |#3|) "failed") (-658 |#3|) |#3|))) (-373) (-1255 |#1|) (-1255 |#2|)) (T -382)) 
+((-3524 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-373)) (-5 *1 (-382 *4 *5 *3))))) 
+(-10 -7 (-15 -3524 ((-3 (-658 |#3|) "failed") (-658 |#3|) |#3|))) 
+((-2784 (((-444 |#2|) |#2|) 46)) (-3484 (((-444 |#2|) |#2|) 36))) 
+(((-383 |#1| |#2|) (-10 -7 (-15 -3484 ((-444 |#2|) |#2|)) (-15 -2784 ((-444 |#2|) |#2|))) (-373) (-1255 |#1|)) (T -383)) 
+((-2784 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-383 *4 *3)) (-4 *3 (-1255 *4)))) (-3484 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-383 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -3484 ((-444 |#2|) |#2|)) (-15 -2784 ((-444 |#2|) |#2|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| |#1| (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL (|has| |#1| (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-1626 (($ (-1280 |#1|)) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| |#1| (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL (|has| |#1| (-394)))) (-3293 (((-141) $) NIL (|has| |#1| (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394)))) (($ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| |#1| (-394))) (((-855 (-944)) $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) NIL (|has| |#1| (-394)))) (-2114 (((-141) $) NIL (|has| |#1| (-394)))) (-2793 ((|#1| $) NIL) (($ $ (-944)) NIL (|has| |#1| (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 |#1|) $) NIL) (((-1187 $) $ (-944)) NIL (|has| |#1| (-394)))) (-3546 (((-944) $) NIL (|has| |#1| (-394)))) (-2343 (((-1187 |#1|) $) NIL (|has| |#1| (-394)))) (-1492 (((-1187 |#1|) $) NIL (|has| |#1| (-394))) (((-3 (-1187 |#1|) "failed") $ $) NIL (|has| |#1| (-394)))) (-2252 (($ $ (-1187 |#1|)) NIL (|has| |#1| (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| |#1| (-394)) CONST)) (-1825 (($ (-944)) NIL (|has| |#1| (-394)))) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-2934 (($) NIL (|has| |#1| (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| |#1| (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| |#1| (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3390 (((-1187 |#1|)) NIL)) (-3809 (($) NIL (|has| |#1| (-394)))) (-3342 (($) NIL (|has| |#1| (-394)))) (-2231 (((-1280 |#1|) $) NIL) (((-706 |#1|) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| |#1| (-394)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) NIL)) (-1517 (($ $) NIL (|has| |#1| (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL) (((-1280 $) (-944)) NIL)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3417 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-1940 (($ $) NIL (|has| |#1| (-394))) (($ $ (-790)) NIL (|has| |#1| (-394)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL) (($ $ |#1|) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-384 |#1| |#2|) (-349 |#1|) (-373) (-944)) (T -384)) 
+NIL 
+(-349 |#1|) 
+((-1480 (((-141) (-658 (-980 |#1|))) 31)) (-3903 (((-658 (-980 |#1|)) (-658 (-980 |#1|))) 42)) (-4338 (((-3 (-658 (-980 |#1|)) "failed") (-658 (-980 |#1|))) 38))) 
+(((-385 |#1| |#2|) (-10 -7 (-15 -1480 ((-141) (-658 (-980 |#1|)))) (-15 -4338 ((-3 (-658 (-980 |#1|)) "failed") (-658 (-980 |#1|)))) (-15 -3903 ((-658 (-980 |#1|)) (-658 (-980 |#1|))))) (-477) (-658 (-1191))) (T -385)) 
+((-3903 (*1 *2 *2) (-12 (-5 *2 (-658 (-980 *3))) (-4 *3 (-477)) (-5 *1 (-385 *3 *4)) (-14 *4 (-658 (-1191))))) (-4338 (*1 *2 *2) (|partial| -12 (-5 *2 (-658 (-980 *3))) (-4 *3 (-477)) (-5 *1 (-385 *3 *4)) (-14 *4 (-658 (-1191))))) (-1480 (*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-477)) (-5 *2 (-141)) (-5 *1 (-385 *4 *5)) (-14 *5 (-658 (-1191)))))) 
+(-10 -7 (-15 -1480 ((-141) (-658 (-980 |#1|)))) (-15 -4338 ((-3 (-658 (-980 |#1|)) "failed") (-658 (-980 |#1|)))) (-15 -3903 ((-658 (-980 |#1|)) (-658 (-980 |#1|))))) 
+((-1641 (((-141) $ $) NIL)) (-1403 (((-790) $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) 14)) (-4449 ((|#1| $ (-592)) NIL)) (-3888 (((-592) $ (-592)) NIL)) (-3401 (($ (-1 |#1| |#1|) $) 32)) (-3970 (($ (-1 (-592) (-592)) $) 24)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 26)) (-2951 (((-1137) $) NIL)) (-2033 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-592)))) $) 28)) (-2227 (($ $ $) NIL)) (-2131 (($ $ $) NIL)) (-1683 (((-877) $) 38) (($ |#1|) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-4257 (($) 9 T CONST)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL) (($ |#1| (-592)) 17)) (* (($ $ $) 43) (($ |#1| $) 21) (($ $ |#1|) 19))) 
+(((-386 |#1|) (-13 (-502) (-1065 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-592))) (-15 -1403 ((-790) $)) (-15 -3888 ((-592) $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -3970 ($ (-1 (-592) (-592)) $)) (-15 -3401 ($ (-1 |#1| |#1|) $)) (-15 -2033 ((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-592)))) $)))) (-1119)) (T -386)) 
+((* (*1 *1 *2 *1) (-12 (-5 *1 (-386 *2)) (-4 *2 (-1119)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-386 *2)) (-4 *2 (-1119)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-386 *2)) (-4 *2 (-1119)))) (-1403 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-386 *3)) (-4 *3 (-1119)))) (-3888 (*1 *2 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-386 *3)) (-4 *3 (-1119)))) (-4449 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-386 *2)) (-4 *2 (-1119)))) (-3970 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-592) (-592))) (-5 *1 (-386 *3)) (-4 *3 (-1119)))) (-3401 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-386 *3)))) (-2033 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 (-592))))) (-5 *1 (-386 *3)) (-4 *3 (-1119))))) 
+(-13 (-502) (-1065 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-592))) (-15 -1403 ((-790) $)) (-15 -3888 ((-592) $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -3970 ($ (-1 (-592) (-592)) $)) (-15 -3401 ($ (-1 |#1| |#1|) $)) (-15 -2033 ((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-592)))) $)))) 
+((-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 13)) (-1555 (($ $) 14)) (-3164 (((-444 $) $) 29)) (-2802 (((-141) $) 25)) (-4552 (($ $) 18)) (-3548 (($ $ $) 22) (($ (-658 $)) NIL)) (-4500 (((-444 $) $) 30)) (-3616 (((-3 $ "failed") $ $) 21)) (-2769 (((-790) $) 24)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 34)) (-2537 (((-141) $ $) 15)) (-3313 (($ $ $) 32))) 
+(((-387 |#1|) (-10 -8 (-15 -3313 (|#1| |#1| |#1|)) (-15 -4552 (|#1| |#1|)) (-15 -2802 ((-141) |#1|)) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -4570 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -2769 ((-790) |#1|)) (-15 -3548 (|#1| (-658 |#1|))) (-15 -3548 (|#1| |#1| |#1|)) (-15 -2537 ((-141) |#1| |#1|)) (-15 -1555 (|#1| |#1|)) (-15 -3620 ((-2 (|:| -4509 |#1|) (|:| -4612 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#1|))) (-388)) (T -387)) 
+NIL 
+(-10 -8 (-15 -3313 (|#1| |#1| |#1|)) (-15 -4552 (|#1| |#1|)) (-15 -2802 ((-141) |#1|)) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -4570 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -2769 ((-790) |#1|)) (-15 -3548 (|#1| (-658 |#1|))) (-15 -3548 (|#1| |#1| |#1|)) (-15 -2537 ((-141) |#1| |#1|)) (-15 -1555 (|#1| |#1|)) (-15 -3620 ((-2 (|:| -4509 |#1|) (|:| -4612 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-3001 (($) 16 T CONST)) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2802 (((-141) $) 69)) (-3558 (((-141) $) 30)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64))) 
+(((-388) (-1311)) (T -388)) 
+((-3313 (*1 *1 *1 *1) (-4 *1 (-388)))) 
+(-13 (-323) (-1235) (-260) (-10 -8 (-15 -3313 ($ $ $)) (-6 -4623) (-6 -4617))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T)) 
+((-1641 (((-141) $ $) 7)) (-3388 ((|#2| $ |#2|) 13)) (-2820 (($ $ (-1173)) 18)) (-4393 ((|#2| $) 14)) (-1774 (($ |#1|) 20) (($ |#1| (-1173)) 19)) (-4095 ((|#1| $) 16)) (-2685 (((-1173) $) 9)) (-2690 (((-1173) $) 15)) (-2951 (((-1137) $) 10)) (-4342 (((-1285) $) 12)) (-1683 (((-877) $) 11)) (-2607 (($ $) 17)) (-3255 (((-141) $ $) 6))) 
+(((-389 |#1| |#2|) (-1311) (-1119) (-1119)) (T -389)) 
+((-1774 (*1 *1 *2) (-12 (-4 *1 (-389 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) (-1774 (*1 *1 *2 *3) (-12 (-5 *3 (-1173)) (-4 *1 (-389 *2 *4)) (-4 *2 (-1119)) (-4 *4 (-1119)))) (-2820 (*1 *1 *1 *2) (-12 (-5 *2 (-1173)) (-4 *1 (-389 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-2607 (*1 *1 *1) (-12 (-4 *1 (-389 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) (-4095 (*1 *2 *1) (-12 (-4 *1 (-389 *2 *3)) (-4 *3 (-1119)) (-4 *2 (-1119)))) (-2690 (*1 *2 *1) (-12 (-4 *1 (-389 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-1173)))) (-4393 (*1 *2 *1) (-12 (-4 *1 (-389 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119)))) (-3388 (*1 *2 *1 *2) (-12 (-4 *1 (-389 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119)))) (-4342 (*1 *2 *1) (-12 (-4 *1 (-389 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-1285))))) 
+(-13 (-1119) (-10 -8 (-15 -1774 ($ |t#1|)) (-15 -1774 ($ |t#1| (-1173))) (-15 -2820 ($ $ (-1173))) (-15 -2607 ($ $)) (-15 -4095 (|t#1| $)) (-15 -2690 ((-1173) $)) (-15 -4393 (|t#2| $)) (-15 -3388 (|t#2| $ |t#2|)) (-15 -4342 ((-1285) $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-3388 ((|#1| $ |#1|) 29)) (-2820 (($ $ (-1173)) 22)) (-3463 (((-3 |#1| "failed") $) 28)) (-4393 ((|#1| $) 26)) (-1774 (($ (-414)) 21) (($ (-414) (-1173)) 20)) (-4095 (((-414) $) 24)) (-2685 (((-1173) $) NIL)) (-2690 (((-1173) $) 25)) (-2951 (((-1137) $) NIL)) (-4342 (((-1285) $) 31)) (-1683 (((-877) $) 19)) (-2607 (($ $) 23)) (-3255 (((-141) $ $) 18))) 
+(((-390 |#1|) (-13 (-389 (-414) |#1|) (-10 -8 (-15 -3463 ((-3 |#1| "failed") $)))) (-1119)) (T -390)) 
+((-3463 (*1 *2 *1) (|partial| -12 (-5 *1 (-390 *2)) (-4 *2 (-1119))))) 
+(-13 (-389 (-414) |#1|) (-10 -8 (-15 -3463 ((-3 |#1| "failed") $)))) 
+((-4061 (((-1280 (-706 |#2|)) (-1280 $)) 62)) (-1951 (((-706 |#2|) (-1280 $)) 120)) (-4282 ((|#2| $) 32)) (-2302 (((-706 |#2|) $ (-1280 $)) 124)) (-2503 (((-3 $ "failed") $) 76)) (-1431 ((|#2| $) 35)) (-3916 (((-1187 |#2|) $) 84)) (-1874 ((|#2| (-1280 $)) 107)) (-1582 (((-1187 |#2|) $) 28)) (-4194 (((-141)) 101)) (-1626 (($ (-1280 |#2|) (-1280 $)) 114)) (-3371 (((-3 $ "failed") $) 80)) (-3700 (((-141)) 96)) (-2973 (((-141)) 91)) (-2467 (((-141)) 54)) (-2794 (((-706 |#2|) (-1280 $)) 118)) (-1869 ((|#2| $) 31)) (-1802 (((-706 |#2|) $ (-1280 $)) 123)) (-4158 (((-3 $ "failed") $) 74)) (-3061 ((|#2| $) 34)) (-2013 (((-1187 |#2|) $) 83)) (-3030 ((|#2| (-1280 $)) 105)) (-2397 (((-1187 |#2|) $) 26)) (-3847 (((-141)) 100)) (-4106 (((-141)) 93)) (-2339 (((-141)) 52)) (-2297 (((-141)) 88)) (-2716 (((-141)) 102)) (-2231 (((-1280 |#2|) $ (-1280 $)) NIL) (((-706 |#2|) (-1280 $) (-1280 $)) 112)) (-3545 (((-141)) 98)) (-3664 (((-658 (-1280 |#2|))) 87)) (-1516 (((-141)) 99)) (-3135 (((-141)) 97)) (-2723 (((-141)) 46)) (-2359 (((-141)) 103))) 
+(((-391 |#1| |#2|) (-10 -8 (-15 -3916 ((-1187 |#2|) |#1|)) (-15 -2013 ((-1187 |#2|) |#1|)) (-15 -3664 ((-658 (-1280 |#2|)))) (-15 -2503 ((-3 |#1| "failed") |#1|)) (-15 -4158 ((-3 |#1| "failed") |#1|)) (-15 -3371 ((-3 |#1| "failed") |#1|)) (-15 -2973 ((-141))) (-15 -4106 ((-141))) (-15 -3700 ((-141))) (-15 -2339 ((-141))) (-15 -2467 ((-141))) (-15 -2297 ((-141))) (-15 -2359 ((-141))) (-15 -2716 ((-141))) (-15 -4194 ((-141))) (-15 -3847 ((-141))) (-15 -2723 ((-141))) (-15 -1516 ((-141))) (-15 -3135 ((-141))) (-15 -3545 ((-141))) (-15 -1582 ((-1187 |#2|) |#1|)) (-15 -2397 ((-1187 |#2|) |#1|)) (-15 -1951 ((-706 |#2|) (-1280 |#1|))) (-15 -2794 ((-706 |#2|) (-1280 |#1|))) (-15 -1874 (|#2| (-1280 |#1|))) (-15 -3030 (|#2| (-1280 |#1|))) (-15 -1626 (|#1| (-1280 |#2|) (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -1431 (|#2| |#1|)) (-15 -3061 (|#2| |#1|)) (-15 -4282 (|#2| |#1|)) (-15 -1869 (|#2| |#1|)) (-15 -2302 ((-706 |#2|) |#1| (-1280 |#1|))) (-15 -1802 ((-706 |#2|) |#1| (-1280 |#1|))) (-15 -4061 ((-1280 (-706 |#2|)) (-1280 |#1|)))) (-392 |#2|) (-194)) (T -391)) 
+((-3545 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-3135 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-1516 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-2723 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-3847 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-4194 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-2716 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-2359 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-2297 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-2467 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-2339 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-3700 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-4106 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-2973 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) (-3664 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-658 (-1280 *4))) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4))))) 
+(-10 -8 (-15 -3916 ((-1187 |#2|) |#1|)) (-15 -2013 ((-1187 |#2|) |#1|)) (-15 -3664 ((-658 (-1280 |#2|)))) (-15 -2503 ((-3 |#1| "failed") |#1|)) (-15 -4158 ((-3 |#1| "failed") |#1|)) (-15 -3371 ((-3 |#1| "failed") |#1|)) (-15 -2973 ((-141))) (-15 -4106 ((-141))) (-15 -3700 ((-141))) (-15 -2339 ((-141))) (-15 -2467 ((-141))) (-15 -2297 ((-141))) (-15 -2359 ((-141))) (-15 -2716 ((-141))) (-15 -4194 ((-141))) (-15 -3847 ((-141))) (-15 -2723 ((-141))) (-15 -1516 ((-141))) (-15 -3135 ((-141))) (-15 -3545 ((-141))) (-15 -1582 ((-1187 |#2|) |#1|)) (-15 -2397 ((-1187 |#2|) |#1|)) (-15 -1951 ((-706 |#2|) (-1280 |#1|))) (-15 -2794 ((-706 |#2|) (-1280 |#1|))) (-15 -1874 (|#2| (-1280 |#1|))) (-15 -3030 (|#2| (-1280 |#1|))) (-15 -1626 (|#1| (-1280 |#2|) (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -1431 (|#2| |#1|)) (-15 -3061 (|#2| |#1|)) (-15 -4282 (|#2| |#1|)) (-15 -1869 (|#2| |#1|)) (-15 -2302 ((-706 |#2|) |#1| (-1280 |#1|))) (-15 -1802 ((-706 |#2|) |#1| (-1280 |#1|))) (-15 -4061 ((-1280 (-706 |#2|)) (-1280 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4509 (((-3 $ "failed")) 35 (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) 18)) (-4061 (((-1280 (-706 |#1|)) (-1280 $)) 76)) (-3360 (((-1280 $)) 79)) (-3001 (($) 16 T CONST)) (-2604 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) 38 (|has| |#1| (-582)))) (-2661 (((-3 $ "failed")) 36 (|has| |#1| (-582)))) (-1951 (((-706 |#1|) (-1280 $)) 63)) (-4282 ((|#1| $) 72)) (-2302 (((-706 |#1|) $ (-1280 $)) 74)) (-2503 (((-3 $ "failed") $) 43 (|has| |#1| (-582)))) (-2111 (($ $ (-944)) 27)) (-1431 ((|#1| $) 70)) (-3916 (((-1187 |#1|) $) 40 (|has| |#1| (-582)))) (-1874 ((|#1| (-1280 $)) 65)) (-1582 (((-1187 |#1|) $) 61)) (-4194 (((-141)) 55)) (-1626 (($ (-1280 |#1|) (-1280 $)) 67)) (-3371 (((-3 $ "failed") $) 45 (|has| |#1| (-582)))) (-4175 (((-944)) 78)) (-2169 (((-141)) 52)) (-1833 (($ $ (-944)) 32)) (-3700 (((-141)) 48)) (-2973 (((-141)) 46)) (-2467 (((-141)) 50)) (-1563 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) 39 (|has| |#1| (-582)))) (-3994 (((-3 $ "failed")) 37 (|has| |#1| (-582)))) (-2794 (((-706 |#1|) (-1280 $)) 64)) (-1869 ((|#1| $) 73)) (-1802 (((-706 |#1|) $ (-1280 $)) 75)) (-4158 (((-3 $ "failed") $) 44 (|has| |#1| (-582)))) (-2682 (($ $ (-944)) 28)) (-3061 ((|#1| $) 71)) (-2013 (((-1187 |#1|) $) 41 (|has| |#1| (-582)))) (-3030 ((|#1| (-1280 $)) 66)) (-2397 (((-1187 |#1|) $) 62)) (-3847 (((-141)) 56)) (-2685 (((-1173) $) 9)) (-4106 (((-141)) 47)) (-2339 (((-141)) 49)) (-2297 (((-141)) 51)) (-2951 (((-1137) $) 10)) (-2716 (((-141)) 54)) (-2231 (((-1280 |#1|) $ (-1280 $)) 69) (((-706 |#1|) (-1280 $) (-1280 $)) 68)) (-1473 (((-658 (-980 |#1|)) (-1280 $)) 77)) (-2131 (($ $ $) 24)) (-3545 (((-141)) 60)) (-1683 (((-877) $) 11)) (-3664 (((-658 (-1280 |#1|))) 42 (|has| |#1| (-582)))) (-3667 (($ $ $ $) 25)) (-1516 (((-141)) 58)) (-2844 (($ $ $) 23)) (-3135 (((-141)) 59)) (-2723 (((-141)) 57)) (-2359 (((-141)) 53)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 29)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
+(((-392 |#1|) (-1311) (-194)) (T -392)) 
+((-3360 (*1 *2) (-12 (-4 *3 (-194)) (-5 *2 (-1280 *1)) (-4 *1 (-392 *3)))) (-4175 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-944)))) (-1473 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-658 (-980 *4))))) (-4061 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-1280 (-706 *4))))) (-1802 (*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) (-2302 (*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) (-1869 (*1 *2 *1) (-12 (-4 *1 (-392 *2)) (-4 *2 (-194)))) (-4282 (*1 *2 *1) (-12 (-4 *1 (-392 *2)) (-4 *2 (-194)))) (-3061 (*1 *2 *1) (-12 (-4 *1 (-392 *2)) (-4 *2 (-194)))) (-1431 (*1 *2 *1) (-12 (-4 *1 (-392 *2)) (-4 *2 (-194)))) (-2231 (*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-1280 *4)))) (-2231 (*1 *2 *3 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) (-1626 (*1 *1 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-1280 *1)) (-4 *4 (-194)) (-4 *1 (-392 *4)))) (-3030 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *2)) (-4 *2 (-194)))) (-1874 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *2)) (-4 *2 (-194)))) (-2794 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) (-1951 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) (-2397 (*1 *2 *1) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-1187 *3)))) (-1582 (*1 *2 *1) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-1187 *3)))) (-3545 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-3135 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-1516 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-2723 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-3847 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-4194 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-2716 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-2359 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-2169 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-2297 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-2467 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-2339 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-3700 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-4106 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-2973 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141)))) (-3371 (*1 *1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-194)) (-4 *2 (-582)))) (-4158 (*1 *1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-194)) (-4 *2 (-582)))) (-2503 (*1 *1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-194)) (-4 *2 (-582)))) (-3664 (*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-4 *3 (-582)) (-5 *2 (-658 (-1280 *3))))) (-2013 (*1 *2 *1) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-4 *3 (-582)) (-5 *2 (-1187 *3)))) (-3916 (*1 *2 *1) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-4 *3 (-582)) (-5 *2 (-1187 *3)))) (-1563 (*1 *2) (|partial| -12 (-4 *3 (-582)) (-4 *3 (-194)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2195 (-658 *1)))) (-4 *1 (-392 *3)))) (-2604 (*1 *2) (|partial| -12 (-4 *3 (-582)) (-4 *3 (-194)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2195 (-658 *1)))) (-4 *1 (-392 *3)))) (-3994 (*1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-582)) (-4 *2 (-194)))) (-2661 (*1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-582)) (-4 *2 (-194)))) (-4509 (*1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-582)) (-4 *2 (-194))))) 
+(-13 (-763 |t#1|) (-10 -8 (-15 -3360 ((-1280 $))) (-15 -4175 ((-944))) (-15 -1473 ((-658 (-980 |t#1|)) (-1280 $))) (-15 -4061 ((-1280 (-706 |t#1|)) (-1280 $))) (-15 -1802 ((-706 |t#1|) $ (-1280 $))) (-15 -2302 ((-706 |t#1|) $ (-1280 $))) (-15 -1869 (|t#1| $)) (-15 -4282 (|t#1| $)) (-15 -3061 (|t#1| $)) (-15 -1431 (|t#1| $)) (-15 -2231 ((-1280 |t#1|) $ (-1280 $))) (-15 -2231 ((-706 |t#1|) (-1280 $) (-1280 $))) (-15 -1626 ($ (-1280 |t#1|) (-1280 $))) (-15 -3030 (|t#1| (-1280 $))) (-15 -1874 (|t#1| (-1280 $))) (-15 -2794 ((-706 |t#1|) (-1280 $))) (-15 -1951 ((-706 |t#1|) (-1280 $))) (-15 -2397 ((-1187 |t#1|) $)) (-15 -1582 ((-1187 |t#1|) $)) (-15 -3545 ((-141))) (-15 -3135 ((-141))) (-15 -1516 ((-141))) (-15 -2723 ((-141))) (-15 -3847 ((-141))) (-15 -4194 ((-141))) (-15 -2716 ((-141))) (-15 -2359 ((-141))) (-15 -2169 ((-141))) (-15 -2297 ((-141))) (-15 -2467 ((-141))) (-15 -2339 ((-141))) (-15 -3700 ((-141))) (-15 -4106 ((-141))) (-15 -2973 ((-141))) (IF (|has| |t#1| (-582)) (PROGN (-15 -3371 ((-3 $ "failed") $)) (-15 -4158 ((-3 $ "failed") $)) (-15 -2503 ((-3 $ "failed") $)) (-15 -3664 ((-658 (-1280 |t#1|)))) (-15 -2013 ((-1187 |t#1|) $)) (-15 -3916 ((-1187 |t#1|) $)) (-15 -1563 ((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed"))) (-15 -2604 ((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed"))) (-15 -3994 ((-3 $ "failed"))) (-15 -2661 ((-3 $ "failed"))) (-15 -4509 ((-3 $ "failed"))) (-6 -4622)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-734 |#1|) . T) ((-737) . T) ((-763 |#1|) . T) ((-780) . T) ((-1081 |#1|) . T) ((-1119) . T)) 
+((-4290 (($) 13)) (-1405 (((-658 $)) 15))) 
+(((-393 |#1|) (-10 -8 (-15 -1405 ((-658 |#1|))) (-15 -4290 (|#1|))) (-394)) (T -393)) 
+NIL 
+(-10 -8 (-15 -1405 ((-658 |#1|))) (-15 -4290 (|#1|))) 
+((-1641 (((-141) $ $) 7)) (-1403 (((-790)) 16)) (-4290 (($) 13)) (-3546 (((-944) $) 14)) (-2685 (((-1173) $) 9)) (-1825 (($ (-944)) 15)) (-2951 (((-1137) $) 10)) (-1405 (((-658 $)) 12)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-394) (-1311)) (T -394)) 
+((-1403 (*1 *2) (-12 (-4 *1 (-394)) (-5 *2 (-790)))) (-1825 (*1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-394)))) (-3546 (*1 *2 *1) (-12 (-4 *1 (-394)) (-5 *2 (-944)))) (-4290 (*1 *1) (-4 *1 (-394))) (-1405 (*1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-394))))) 
+(-13 (-1119) (-10 -8 (-15 -1403 ((-790))) (-15 -1825 ($ (-944))) (-15 -3546 ((-944) $)) (-15 -4290 ($)) (-15 -1405 ((-658 $))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1800 (((-706 |#2|) (-1280 $)) 40)) (-1626 (($ (-1280 |#2|) (-1280 $)) 35)) (-4493 (((-706 |#2|) $ (-1280 $)) 43)) (-1482 ((|#2| (-1280 $)) 13)) (-2231 (((-1280 |#2|) $ (-1280 $)) NIL) (((-706 |#2|) (-1280 $) (-1280 $)) 25))) 
+(((-395 |#1| |#2| |#3|) (-10 -8 (-15 -1800 ((-706 |#2|) (-1280 |#1|))) (-15 -1482 (|#2| (-1280 |#1|))) (-15 -1626 (|#1| (-1280 |#2|) (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -4493 ((-706 |#2|) |#1| (-1280 |#1|)))) (-396 |#2| |#3|) (-194) (-1255 |#2|)) (T -395)) 
+NIL 
+(-10 -8 (-15 -1800 ((-706 |#2|) (-1280 |#1|))) (-15 -1482 (|#2| (-1280 |#1|))) (-15 -1626 (|#1| (-1280 |#2|) (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -4493 ((-706 |#2|) |#1| (-1280 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-1800 (((-706 |#1|) (-1280 $)) 44)) (-4529 ((|#1| $) 50)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-1626 (($ (-1280 |#1|) (-1280 $)) 46)) (-4493 (((-706 |#1|) $ (-1280 $)) 51)) (-3371 (((-3 $ "failed") $) 33)) (-4175 (((-944)) 52)) (-3558 (((-141) $) 30)) (-2793 ((|#1| $) 49)) (-3504 ((|#2| $) 42 (|has| |#1| (-388)))) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1482 ((|#1| (-1280 $)) 45)) (-2231 (((-1280 |#1|) $ (-1280 $)) 48) (((-706 |#1|) (-1280 $) (-1280 $)) 47)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 36)) (-1517 (((-3 $ "failed") $) 41 (|has| |#1| (-169)))) (-4198 ((|#2| $) 43)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
+(((-396 |#1| |#2|) (-1311) (-194) (-1255 |t#1|)) (T -396)) 
+((-4175 (*1 *2) (-12 (-4 *1 (-396 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-944)))) (-4493 (*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)))) (-4529 (*1 *2 *1) (-12 (-4 *1 (-396 *2 *3)) (-4 *3 (-1255 *2)) (-4 *2 (-194)))) (-2793 (*1 *2 *1) (-12 (-4 *1 (-396 *2 *3)) (-4 *3 (-1255 *2)) (-4 *2 (-194)))) (-2231 (*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-1280 *4)))) (-2231 (*1 *2 *3 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)))) (-1626 (*1 *1 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-1280 *1)) (-4 *4 (-194)) (-4 *1 (-396 *4 *5)) (-4 *5 (-1255 *4)))) (-1482 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *2 *4)) (-4 *4 (-1255 *2)) (-4 *2 (-194)))) (-1800 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)))) (-4198 (*1 *2 *1) (-12 (-4 *1 (-396 *3 *2)) (-4 *3 (-194)) (-4 *2 (-1255 *3)))) (-3504 (*1 *2 *1) (-12 (-4 *1 (-396 *3 *2)) (-4 *3 (-194)) (-4 *3 (-388)) (-4 *2 (-1255 *3))))) 
+(-13 (-43 |t#1|) (-10 -8 (-15 -4175 ((-944))) (-15 -4493 ((-706 |t#1|) $ (-1280 $))) (-15 -4529 (|t#1| $)) (-15 -2793 (|t#1| $)) (-15 -2231 ((-1280 |t#1|) $ (-1280 $))) (-15 -2231 ((-706 |t#1|) (-1280 $) (-1280 $))) (-15 -1626 ($ (-1280 |t#1|) (-1280 $))) (-15 -1482 (|t#1| (-1280 $))) (-15 -1800 ((-706 |t#1|) (-1280 $))) (-15 -4198 (|t#2| $)) (IF (|has| |t#1| (-388)) (-15 -3504 (|t#2| $)) |noBranch|) (IF (|has| |t#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |t#1| (-169)) (-6 (-169)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-734 |#1|) . T) ((-743) . T) ((-1081 |#1|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1779 ((|#4| (-1 |#3| |#1| |#3|) |#2| |#3|) 23)) (-3657 ((|#3| (-1 |#3| |#1| |#3|) |#2| |#3|) 15)) (-2731 ((|#4| (-1 |#3| |#1|) |#2|) 21))) 
+(((-397 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3657 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1779 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) (-1225) (-399 |#1|) (-1225) (-399 |#3|)) (T -397)) 
+((-1779 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-4 *2 (-399 *5)) (-5 *1 (-397 *6 *4 *5 *2)) (-4 *4 (-399 *6)))) (-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-397 *5 *4 *2 *6)) (-4 *4 (-399 *5)) (-4 *6 (-399 *2)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-4 *2 (-399 *6)) (-5 *1 (-397 *5 *4 *6 *2)) (-4 *4 (-399 *5))))) 
+(-10 -7 (-15 -2731 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3657 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1779 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) 
+((-4076 (((-141) (-1 (-141) |#2| |#2|) $) NIL) (((-141) $) 18)) (-2831 (($ (-1 (-141) |#2| |#2|) $) NIL) (($ $) 28)) (-3960 (($ (-1 (-141) |#2| |#2|) $) 27) (($ $) 22)) (-1373 (($ $) 25)) (-1721 (((-592) (-1 (-141) |#2|) $) NIL) (((-592) |#2| $) 11) (((-592) |#2| $ (-592)) NIL)) (-4491 (($ (-1 (-141) |#2| |#2|) $ $) NIL) (($ $ $) 20))) 
+(((-398 |#1| |#2|) (-10 -8 (-15 -2831 (|#1| |#1|)) (-15 -2831 (|#1| (-1 (-141) |#2| |#2|) |#1|)) (-15 -4076 ((-141) |#1|)) (-15 -3960 (|#1| |#1|)) (-15 -4491 (|#1| |#1| |#1|)) (-15 -1721 ((-592) |#2| |#1| (-592))) (-15 -1721 ((-592) |#2| |#1|)) (-15 -1721 ((-592) (-1 (-141) |#2|) |#1|)) (-15 -4076 ((-141) (-1 (-141) |#2| |#2|) |#1|)) (-15 -3960 (|#1| (-1 (-141) |#2| |#2|) |#1|)) (-15 -1373 (|#1| |#1|)) (-15 -4491 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|))) (-399 |#2|) (-1225)) (T -398)) 
+NIL 
+(-10 -8 (-15 -2831 (|#1| |#1|)) (-15 -2831 (|#1| (-1 (-141) |#2| |#2|) |#1|)) (-15 -4076 ((-141) |#1|)) (-15 -3960 (|#1| |#1|)) (-15 -4491 (|#1| |#1| |#1|)) (-15 -1721 ((-592) |#2| |#1| (-592))) (-15 -1721 ((-592) |#2| |#1|)) (-15 -1721 ((-592) (-1 (-141) |#2|) |#1|)) (-15 -4076 ((-141) (-1 (-141) |#2| |#2|) |#1|)) (-15 -3960 (|#1| (-1 (-141) |#2| |#2|) |#1|)) (-15 -1373 (|#1| |#1|)) (-15 -4491 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) 91) (((-141) $) 85 (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) 82 (|has| $ (-6 -4626))) (($ $) 81 (-12 (|has| |#1| (-869)) (|has| $ (-6 -4626))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#1| $ (-592) |#1|) 49 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 53 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) 70 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-2512 (($ $) 83 (|has| $ (-6 -4626)))) (-1373 (($ $) 93)) (-1360 (($ $) 73 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#1| $) 72 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 69 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) 50 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 48)) (-1721 (((-592) (-1 (-141) |#1|) $) 90) (((-592) |#1| $) 89 (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) 88 (|has| |#1| (-1119)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-3242 (($ (-790) |#1|) 64)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-1837 (($ $ $) 80 (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3319 (($ $ $) 79 (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) 55) (($ $ $ (-592)) 54)) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 39 (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 66)) (-1892 (($ $ |#1|) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 42 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ (-592) |#1|) 47) ((|#1| $ (-592)) 46) (($ $ (-1246 (-592))) 58)) (-3208 (($ $ (-592)) 57) (($ $ (-1246 (-592))) 56)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-2385 (($ $ $ (-592)) 84 (|has| $ (-6 -4626)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 74 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 65)) (-2266 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-658 $)) 60)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) 77 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 76 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-3279 (((-141) $ $) 78 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 75 (|has| |#1| (-869)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-399 |#1|) (-1311) (-1225)) (T -399)) 
+((-4491 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-141) *3 *3)) (-4 *1 (-399 *3)) (-4 *3 (-1225)))) (-1373 (*1 *1 *1) (-12 (-4 *1 (-399 *2)) (-4 *2 (-1225)))) (-3960 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3 *3)) (-4 *1 (-399 *3)) (-4 *3 (-1225)))) (-4076 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *1 (-399 *4)) (-4 *4 (-1225)) (-5 *2 (-141)))) (-1721 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (-4 *1 (-399 *4)) (-4 *4 (-1225)) (-5 *2 (-592)))) (-1721 (*1 *2 *3 *1) (-12 (-4 *1 (-399 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-592)))) (-1721 (*1 *2 *3 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-399 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)))) (-4491 (*1 *1 *1 *1) (-12 (-4 *1 (-399 *2)) (-4 *2 (-1225)) (-4 *2 (-869)))) (-3960 (*1 *1 *1) (-12 (-4 *1 (-399 *2)) (-4 *2 (-1225)) (-4 *2 (-869)))) (-4076 (*1 *2 *1) (-12 (-4 *1 (-399 *3)) (-4 *3 (-1225)) (-4 *3 (-869)) (-5 *2 (-141)))) (-2385 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-592)) (|has| *1 (-6 -4626)) (-4 *1 (-399 *3)) (-4 *3 (-1225)))) (-2512 (*1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-399 *2)) (-4 *2 (-1225)))) (-2831 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3 *3)) (|has| *1 (-6 -4626)) (-4 *1 (-399 *3)) (-4 *3 (-1225)))) (-2831 (*1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-399 *2)) (-4 *2 (-1225)) (-4 *2 (-869))))) 
+(-13 (-664 |t#1|) (-10 -8 (-6 -4625) (-15 -4491 ($ (-1 (-141) |t#1| |t#1|) $ $)) (-15 -1373 ($ $)) (-15 -3960 ($ (-1 (-141) |t#1| |t#1|) $)) (-15 -4076 ((-141) (-1 (-141) |t#1| |t#1|) $)) (-15 -1721 ((-592) (-1 (-141) |t#1|) $)) (IF (|has| |t#1| (-1119)) (PROGN (-15 -1721 ((-592) |t#1| $)) (-15 -1721 ((-592) |t#1| $ (-592)))) |noBranch|) (IF (|has| |t#1| (-869)) (PROGN (-6 (-869)) (-15 -4491 ($ $ $)) (-15 -3960 ($ $)) (-15 -4076 ((-141) $))) |noBranch|) (IF (|has| $ (-6 -4626)) (PROGN (-15 -2385 ($ $ $ (-592))) (-15 -2512 ($ $)) (-15 -2831 ($ (-1 (-141) |t#1| |t#1|) $)) (IF (|has| |t#1| (-869)) (-15 -2831 ($ $)) |noBranch|)) |noBranch|))) 
+(((-39) . T) ((-125) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-632 (-877)) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-664 |#1|) . T) ((-869) |has| |#1| (-869)) ((-1119) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-1225) . T)) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2692 (((-658 |#1|) $) 29)) (-1394 (($ $ (-790)) 30)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3305 (((-1302 |#1| |#2|) (-1302 |#1| |#2|) $) 33)) (-4103 (($ $) 31)) (-2141 (((-1302 |#1| |#2|) (-1302 |#1| |#2|) $) 34)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2806 (($ $ |#1| $) 28) (($ $ (-658 |#1|) (-658 $)) 27)) (-4525 (((-790) $) 35)) (-4466 (($ $ $) 26)) (-1683 (((-877) $) 11) (($ |#1|) 38) (((-1293 |#1| |#2|) $) 37) (((-1302 |#1| |#2|) $) 36)) (-1487 ((|#2| (-1302 |#1| |#2|) $) 39)) (-3514 (($) 17 T CONST)) (-2072 (($ (-688 |#1|)) 32)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#2|) 25 (|has| |#2| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ |#2| $) 22) (($ $ |#2|) 24))) 
+(((-400 |#1| |#2|) (-1311) (-869) (-194)) (T -400)) 
+((-1487 (*1 *2 *3 *1) (-12 (-5 *3 (-1302 *4 *2)) (-4 *1 (-400 *4 *2)) (-4 *4 (-869)) (-4 *2 (-194)))) (-1683 (*1 *1 *2) (-12 (-4 *1 (-400 *2 *3)) (-4 *2 (-869)) (-4 *3 (-194)))) (-1683 (*1 *2 *1) (-12 (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *2 (-1293 *3 *4)))) (-1683 (*1 *2 *1) (-12 (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *2 (-1302 *3 *4)))) (-4525 (*1 *2 *1) (-12 (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *2 (-790)))) (-2141 (*1 *2 *2 *1) (-12 (-5 *2 (-1302 *3 *4)) (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) (-3305 (*1 *2 *2 *1) (-12 (-5 *2 (-1302 *3 *4)) (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) (-2072 (*1 *1 *2) (-12 (-5 *2 (-688 *3)) (-4 *3 (-869)) (-4 *1 (-400 *3 *4)) (-4 *4 (-194)))) (-4103 (*1 *1 *1) (-12 (-4 *1 (-400 *2 *3)) (-4 *2 (-869)) (-4 *3 (-194)))) (-1394 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) (-2692 (*1 *2 *1) (-12 (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *2 (-658 *3)))) (-2806 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-400 *2 *3)) (-4 *2 (-869)) (-4 *3 (-194)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *4)) (-5 *3 (-658 *1)) (-4 *1 (-400 *4 *5)) (-4 *4 (-869)) (-4 *5 (-194))))) 
+(-13 (-649 |t#2|) (-10 -8 (-15 -1487 (|t#2| (-1302 |t#1| |t#2|) $)) (-15 -1683 ($ |t#1|)) (-15 -1683 ((-1293 |t#1| |t#2|) $)) (-15 -1683 ((-1302 |t#1| |t#2|) $)) (-15 -4525 ((-790) $)) (-15 -2141 ((-1302 |t#1| |t#2|) (-1302 |t#1| |t#2|) $)) (-15 -3305 ((-1302 |t#1| |t#2|) (-1302 |t#1| |t#2|) $)) (-15 -2072 ($ (-688 |t#1|))) (-15 -4103 ($ $)) (-15 -1394 ($ $ (-790))) (-15 -2692 ((-658 |t#1|) $)) (-15 -2806 ($ $ |t#1| $)) (-15 -2806 ($ $ (-658 |t#1|) (-658 $))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#2| |#2|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#2|) . T) ((-649 |#2|) . T) ((-734 |#2|) . T) ((-1081 |#2|) . T) ((-1119) . T)) 
+((-2808 ((|#2| (-1 (-141) |#1| |#1|) |#2|) 22)) (-4027 ((|#2| (-1 (-141) |#1| |#1|) |#2|) 12)) (-2265 ((|#2| (-1 (-141) |#1| |#1|) |#2|) 21))) 
+(((-401 |#1| |#2|) (-10 -7 (-15 -4027 (|#2| (-1 (-141) |#1| |#1|) |#2|)) (-15 -2265 (|#2| (-1 (-141) |#1| |#1|) |#2|)) (-15 -2808 (|#2| (-1 (-141) |#1| |#1|) |#2|))) (-1225) (-13 (-399 |#1|) (-10 -7 (-6 -4626)))) (T -401)) 
+((-2808 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-401 *4 *2)) (-4 *2 (-13 (-399 *4) (-10 -7 (-6 -4626)))))) (-2265 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-401 *4 *2)) (-4 *2 (-13 (-399 *4) (-10 -7 (-6 -4626)))))) (-4027 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-401 *4 *2)) (-4 *2 (-13 (-399 *4) (-10 -7 (-6 -4626))))))) 
+(-10 -7 (-15 -4027 (|#2| (-1 (-141) |#1| |#1|) |#2|)) (-15 -2265 (|#2| (-1 (-141) |#1| |#1|) |#2|)) (-15 -2808 (|#2| (-1 (-141) |#1| |#1|) |#2|))) 
+((-3945 (((-706 |#2|) (-706 $)) NIL) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 19) (((-706 (-592)) (-706 $)) 13))) 
+(((-402 |#1| |#2|) (-10 -8 (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 |#2|) (-706 |#1|)))) (-403 |#2|) (-1075)) (T -402)) 
+NIL 
+(-10 -8 (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 |#2|) (-706 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3945 (((-706 |#1|) (-706 $)) 35) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 34) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 38 (|has| |#1| (-654 (-592)))) (((-706 (-592)) (-706 $)) 37 (|has| |#1| (-654 (-592))))) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-403 |#1|) (-1311) (-1075)) (T -403)) 
+NIL 
+(-13 (-654 |t#1|) (-10 -7 (IF (|has| |t#1| (-654 (-592))) (-6 (-654 (-592))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-743) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-2241 (((-658 (-310 (-980 (-191 |#1|)))) (-310 (-433 (-980 (-191 (-592))))) |#1|) 52) (((-658 (-310 (-980 (-191 |#1|)))) (-433 (-980 (-191 (-592)))) |#1|) 51) (((-658 (-658 (-310 (-980 (-191 |#1|))))) (-658 (-310 (-433 (-980 (-191 (-592)))))) |#1|) 47) (((-658 (-658 (-310 (-980 (-191 |#1|))))) (-658 (-433 (-980 (-191 (-592))))) |#1|) 40)) (-1666 (((-658 (-658 (-191 |#1|))) (-658 (-433 (-980 (-191 (-592))))) (-658 (-1191)) |#1|) 28) (((-658 (-191 |#1|)) (-433 (-980 (-191 (-592)))) |#1|) 15))) 
+(((-404 |#1|) (-10 -7 (-15 -2241 ((-658 (-658 (-310 (-980 (-191 |#1|))))) (-658 (-433 (-980 (-191 (-592))))) |#1|)) (-15 -2241 ((-658 (-658 (-310 (-980 (-191 |#1|))))) (-658 (-310 (-433 (-980 (-191 (-592)))))) |#1|)) (-15 -2241 ((-658 (-310 (-980 (-191 |#1|)))) (-433 (-980 (-191 (-592)))) |#1|)) (-15 -2241 ((-658 (-310 (-980 (-191 |#1|)))) (-310 (-433 (-980 (-191 (-592))))) |#1|)) (-15 -1666 ((-658 (-191 |#1|)) (-433 (-980 (-191 (-592)))) |#1|)) (-15 -1666 ((-658 (-658 (-191 |#1|))) (-658 (-433 (-980 (-191 (-592))))) (-658 (-1191)) |#1|))) (-13 (-388) (-867))) (T -404)) 
+((-1666 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-433 (-980 (-191 (-592)))))) (-5 *4 (-658 (-1191))) (-5 *2 (-658 (-658 (-191 *5)))) (-5 *1 (-404 *5)) (-4 *5 (-13 (-388) (-867))))) (-1666 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-191 (-592))))) (-5 *2 (-658 (-191 *4))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867))))) (-2241 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-433 (-980 (-191 (-592)))))) (-5 *2 (-658 (-310 (-980 (-191 *4))))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867))))) (-2241 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-191 (-592))))) (-5 *2 (-658 (-310 (-980 (-191 *4))))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867))))) (-2241 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-310 (-433 (-980 (-191 (-592))))))) (-5 *2 (-658 (-658 (-310 (-980 (-191 *4)))))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867))))) (-2241 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-191 (-592)))))) (-5 *2 (-658 (-658 (-310 (-980 (-191 *4)))))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867)))))) 
+(-10 -7 (-15 -2241 ((-658 (-658 (-310 (-980 (-191 |#1|))))) (-658 (-433 (-980 (-191 (-592))))) |#1|)) (-15 -2241 ((-658 (-658 (-310 (-980 (-191 |#1|))))) (-658 (-310 (-433 (-980 (-191 (-592)))))) |#1|)) (-15 -2241 ((-658 (-310 (-980 (-191 |#1|)))) (-433 (-980 (-191 (-592)))) |#1|)) (-15 -2241 ((-658 (-310 (-980 (-191 |#1|)))) (-310 (-433 (-980 (-191 (-592))))) |#1|)) (-15 -1666 ((-658 (-191 |#1|)) (-433 (-980 (-191 (-592)))) |#1|)) (-15 -1666 ((-658 (-658 (-191 |#1|))) (-658 (-433 (-980 (-191 (-592))))) (-658 (-1191)) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 33)) (-1505 (((-592) $) 55)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2306 (($ $) 109)) (-1588 (($ $) 81)) (-1507 (($ $) 70)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1442 (($ $) 44)) (-3652 (((-141) $ $) NIL)) (-1575 (($ $) 79)) (-1495 (($ $) 68)) (-3940 (((-592) $) 63)) (-3651 (($ $ (-592)) 62)) (-1601 (($ $) NIL)) (-1521 (($ $) NIL)) (-3001 (($) NIL T CONST)) (-1755 (($ $) 111)) (-4368 (((-3 (-592) "failed") $) 187) (((-3 (-433 (-592)) "failed") $) 183)) (-2400 (((-592) $) 185) (((-433 (-592)) $) 181)) (-1586 (($ $ $) NIL)) (-1970 (((-592) $ $) 101)) (-3371 (((-3 $ "failed") $) 113)) (-2753 (((-433 (-592)) $ (-790)) 188) (((-433 (-592)) $ (-790) (-790)) 180)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-4047 (((-944)) 72) (((-944) (-944)) 97 (|has| $ (-6 -4616)))) (-1691 (((-141) $) 105)) (-1435 (($) 40)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL)) (-3354 (((-1285) (-790)) 150)) (-3110 (((-1285)) 155) (((-1285) (-790)) 156)) (-3753 (((-1285)) 157) (((-1285) (-790)) 158)) (-3624 (((-1285)) 153) (((-1285) (-790)) 154)) (-4346 (((-592) $) 58)) (-3558 (((-141) $) 103)) (-4422 (($ $ (-592)) NIL)) (-4398 (($ $) 48)) (-2793 (($ $) NIL)) (-1324 (((-141) $) 35)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL) (($) NIL (-12 (-3252 (|has| $ (-6 -4608))) (-3252 (|has| $ (-6 -4616)))))) (-3319 (($ $ $) NIL) (($) 98 (-12 (-3252 (|has| $ (-6 -4608))) (-3252 (|has| $ (-6 -4616)))))) (-2950 (((-592) $) 17)) (-1998 (($) 86) (($ $) 91)) (-4197 (($) 90) (($ $) 92)) (-4546 (($ $) 82)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 115)) (-1867 (((-944) (-592)) 43 (|has| $ (-6 -4616)))) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) 53)) (-2039 (($ $) 108)) (-4540 (($ (-592) (-592)) 106) (($ (-592) (-592) (-944)) 107)) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3215 (((-592) $) 19)) (-1667 (($) 93)) (-1430 (($ $) 78)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4406 (((-944)) 99) (((-944) (-944)) 100 (|has| $ (-6 -4616)))) (-3644 (($ $ (-790)) NIL) (($ $) 114)) (-1738 (((-944) (-592)) 47 (|has| $ (-6 -4616)))) (-1609 (($ $) NIL)) (-1527 (($ $) NIL)) (-1594 (($ $) NIL)) (-1515 (($ $) NIL)) (-1581 (($ $) 80)) (-1501 (($ $) 69)) (-1778 (((-405) $) 173) (((-237) $) 175) (((-914 (-405)) $) NIL) (((-1173) $) 160) (((-565) $) 171) (($ (-237)) 179)) (-1683 (((-877) $) 162) (($ (-592)) 184) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-592)) 184) (($ (-433 (-592))) NIL) (((-237) $) 176)) (-4010 (((-790)) NIL)) (-2744 (($ $) 110)) (-3671 (((-944)) 54) (((-944) (-944)) 65 (|has| $ (-6 -4616)))) (-4226 (((-944)) 102)) (-1630 (($ $) 85)) (-1546 (($ $) 46) (($ $ $) 52)) (-2537 (((-141) $ $) NIL)) (-1617 (($ $) 83)) (-1533 (($ $) 37)) (-1642 (($ $) NIL)) (-1559 (($ $) NIL)) (-2892 (($ $) NIL)) (-1567 (($ $) NIL)) (-1636 (($ $) NIL)) (-1552 (($ $) NIL)) (-1624 (($ $) 84)) (-1540 (($ $) 49)) (-1392 (($ $) 51)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 34 T CONST)) (-4257 (($) 38 T CONST)) (-1637 (((-1173) $) 27) (((-1173) $ (-141)) 29) (((-1285) (-844) $) 30) (((-1285) (-844) $ (-141)) 31)) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 39)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 42)) (-3313 (($ $ $) 45) (($ $ (-592)) 41)) (-3306 (($ $) 36) (($ $ $) 50)) (-3300 (($ $ $) 61)) (** (($ $ (-944)) 66) (($ $ (-790)) NIL) (($ $ (-592)) 87) (($ $ (-433 (-592))) 124) (($ $ $) 116)) (* (($ (-944) $) 64) (($ (-790) $) NIL) (($ (-592) $) 67) (($ $ $) 60) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL))) 
+(((-405) (-13 (-430) (-247) (-633 (-1173)) (-850) (-632 (-237)) (-1211) (-633 (-565)) (-10 -8 (-15 -3313 ($ $ (-592))) (-15 ** ($ $ $)) (-15 -4398 ($ $)) (-15 -1970 ((-592) $ $)) (-15 -3651 ($ $ (-592))) (-15 -2753 ((-433 (-592)) $ (-790))) (-15 -2753 ((-433 (-592)) $ (-790) (-790))) (-15 -1998 ($)) (-15 -4197 ($)) (-15 -1667 ($)) (-15 -1546 ($ $ $)) (-15 -1998 ($ $)) (-15 -4197 ($ $)) (-15 -1778 ($ (-237))) (-15 -3753 ((-1285))) (-15 -3753 ((-1285) (-790))) (-15 -3624 ((-1285))) (-15 -3624 ((-1285) (-790))) (-15 -3110 ((-1285))) (-15 -3110 ((-1285) (-790))) (-15 -3354 ((-1285) (-790))) (-6 -4616) (-6 -4608)))) (T -405)) 
+((** (*1 *1 *1 *1) (-5 *1 (-405))) (-3313 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-405)))) (-4398 (*1 *1 *1) (-5 *1 (-405))) (-1970 (*1 *2 *1 *1) (-12 (-5 *2 (-592)) (-5 *1 (-405)))) (-3651 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-405)))) (-2753 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-433 (-592))) (-5 *1 (-405)))) (-2753 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-433 (-592))) (-5 *1 (-405)))) (-1998 (*1 *1) (-5 *1 (-405))) (-4197 (*1 *1) (-5 *1 (-405))) (-1667 (*1 *1) (-5 *1 (-405))) (-1546 (*1 *1 *1 *1) (-5 *1 (-405))) (-1998 (*1 *1 *1) (-5 *1 (-405))) (-4197 (*1 *1 *1) (-5 *1 (-405))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-237)) (-5 *1 (-405)))) (-3753 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-405)))) (-3753 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-405)))) (-3624 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-405)))) (-3624 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-405)))) (-3110 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-405)))) (-3110 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-405)))) (-3354 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-405))))) 
+(-13 (-430) (-247) (-633 (-1173)) (-850) (-632 (-237)) (-1211) (-633 (-565)) (-10 -8 (-15 -3313 ($ $ (-592))) (-15 ** ($ $ $)) (-15 -4398 ($ $)) (-15 -1970 ((-592) $ $)) (-15 -3651 ($ $ (-592))) (-15 -2753 ((-433 (-592)) $ (-790))) (-15 -2753 ((-433 (-592)) $ (-790) (-790))) (-15 -1998 ($)) (-15 -4197 ($)) (-15 -1667 ($)) (-15 -1546 ($ $ $)) (-15 -1998 ($ $)) (-15 -4197 ($ $)) (-15 -1778 ($ (-237))) (-15 -3753 ((-1285))) (-15 -3753 ((-1285) (-790))) (-15 -3624 ((-1285))) (-15 -3624 ((-1285) (-790))) (-15 -3110 ((-1285))) (-15 -3110 ((-1285) (-790))) (-15 -3354 ((-1285) (-790))) (-6 -4616) (-6 -4608))) 
+((-4005 (((-658 (-310 (-980 |#1|))) (-310 (-433 (-980 (-592)))) |#1|) 47) (((-658 (-310 (-980 |#1|))) (-433 (-980 (-592))) |#1|) 46) (((-658 (-658 (-310 (-980 |#1|)))) (-658 (-310 (-433 (-980 (-592))))) |#1|) 42) (((-658 (-658 (-310 (-980 |#1|)))) (-658 (-433 (-980 (-592)))) |#1|) 36)) (-3642 (((-658 |#1|) (-433 (-980 (-592))) |#1|) 19) (((-658 (-658 |#1|)) (-658 (-433 (-980 (-592)))) (-658 (-1191)) |#1|) 31))) 
+(((-406 |#1|) (-10 -7 (-15 -4005 ((-658 (-658 (-310 (-980 |#1|)))) (-658 (-433 (-980 (-592)))) |#1|)) (-15 -4005 ((-658 (-658 (-310 (-980 |#1|)))) (-658 (-310 (-433 (-980 (-592))))) |#1|)) (-15 -4005 ((-658 (-310 (-980 |#1|))) (-433 (-980 (-592))) |#1|)) (-15 -4005 ((-658 (-310 (-980 |#1|))) (-310 (-433 (-980 (-592)))) |#1|)) (-15 -3642 ((-658 (-658 |#1|)) (-658 (-433 (-980 (-592)))) (-658 (-1191)) |#1|)) (-15 -3642 ((-658 |#1|) (-433 (-980 (-592))) |#1|))) (-13 (-867) (-388))) (T -406)) 
+((-3642 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-592)))) (-5 *2 (-658 *4)) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388))))) (-3642 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-1191))) (-5 *2 (-658 (-658 *5))) (-5 *1 (-406 *5)) (-4 *5 (-13 (-867) (-388))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-433 (-980 (-592))))) (-5 *2 (-658 (-310 (-980 *4)))) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-592)))) (-5 *2 (-658 (-310 (-980 *4)))) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-310 (-433 (-980 (-592)))))) (-5 *2 (-658 (-658 (-310 (-980 *4))))) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-658 (-310 (-980 *4))))) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388)))))) 
+(-10 -7 (-15 -4005 ((-658 (-658 (-310 (-980 |#1|)))) (-658 (-433 (-980 (-592)))) |#1|)) (-15 -4005 ((-658 (-658 (-310 (-980 |#1|)))) (-658 (-310 (-433 (-980 (-592))))) |#1|)) (-15 -4005 ((-658 (-310 (-980 |#1|))) (-433 (-980 (-592))) |#1|)) (-15 -4005 ((-658 (-310 (-980 |#1|))) (-310 (-433 (-980 (-592)))) |#1|)) (-15 -3642 ((-658 (-658 |#1|)) (-658 (-433 (-980 (-592)))) (-658 (-1191)) |#1|)) (-15 -3642 ((-658 |#1|) (-433 (-980 (-592))) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) 25)) (-2400 ((|#2| $) 27)) (-4593 (($ $) NIL)) (-4036 (((-790) $) 10)) (-3108 (((-658 $) $) 20)) (-2027 (((-141) $) NIL)) (-1493 (($ |#2| |#1|) 18)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3725 (((-658 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 13)) (-2992 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) 14)) (-4573 ((|#2| $) 15)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 43) (($ |#2|) 26)) (-1647 (((-658 |#1|) $) 17)) (-1937 ((|#1| $ |#2|) 45)) (-3514 (($) 28 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ |#1| $) 31) (($ $ |#1|) 32) (($ |#1| |#2|) 33) (($ |#2| |#1|) 34))) 
+(((-407 |#1| |#2|) (-13 (-408 |#1| |#2|) (-10 -8 (-15 * ($ |#2| |#1|)))) (-1075) (-869)) (T -407)) 
+((* (*1 *1 *2 *3) (-12 (-5 *1 (-407 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-869))))) 
+(-13 (-408 |#1| |#2|) (-10 -8 (-15 * ($ |#2| |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#2| "failed") $) 41)) (-2400 ((|#2| $) 40)) (-4593 (($ $) 27)) (-4036 (((-790) $) 31)) (-3108 (((-658 $) $) 32)) (-2027 (((-141) $) 35)) (-1493 (($ |#2| |#1|) 36)) (-2731 (($ (-1 |#1| |#1|) $) 37)) (-3725 (((-658 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 34)) (-2992 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) 28)) (-4573 ((|#2| $) 30)) (-4579 ((|#1| $) 29)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ |#2|) 42)) (-1647 (((-658 |#1|) $) 33)) (-1937 ((|#1| $ |#2|) 38)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24) (($ |#1| |#2|) 39))) 
+(((-408 |#1| |#2|) (-1311) (-1075) (-1119)) (T -408)) 
+((* (*1 *1 *2 *3) (-12 (-4 *1 (-408 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-1119)))) (-1937 (*1 *2 *1 *3) (-12 (-4 *1 (-408 *2 *3)) (-4 *3 (-1119)) (-4 *2 (-1075)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)))) (-1493 (*1 *1 *2 *3) (-12 (-4 *1 (-408 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1119)))) (-2027 (*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-141)))) (-3725 (*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-658 (-2 (|:| |k| *4) (|:| |c| *3)))))) (-1647 (*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-658 *3)))) (-3108 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-658 *1)) (-4 *1 (-408 *3 *4)))) (-4036 (*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-790)))) (-4573 (*1 *2 *1) (-12 (-4 *1 (-408 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1119)))) (-4579 (*1 *2 *1) (-12 (-4 *1 (-408 *2 *3)) (-4 *3 (-1119)) (-4 *2 (-1075)))) (-2992 (*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-2 (|:| |k| *4) (|:| |c| *3))))) (-4593 (*1 *1 *1) (-12 (-4 *1 (-408 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-1119))))) 
+(-13 (-140 |t#1| |t#1|) (-1065 |t#2|) (-10 -8 (-15 * ($ |t#1| |t#2|)) (-15 -1937 (|t#1| $ |t#2|)) (-15 -2731 ($ (-1 |t#1| |t#1|) $)) (-15 -1493 ($ |t#2| |t#1|)) (-15 -2027 ((-141) $)) (-15 -3725 ((-658 (-2 (|:| |k| |t#2|) (|:| |c| |t#1|))) $)) (-15 -1647 ((-658 |t#1|) $)) (-15 -3108 ((-658 $) $)) (-15 -4036 ((-790) $)) (-15 -4573 (|t#2| $)) (-15 -4579 (|t#1| $)) (-15 -2992 ((-2 (|:| |k| |t#2|) (|:| |c| |t#1|)) $)) (-15 -4593 ($ $)) (IF (|has| |t#1| (-194)) (-6 (-734 |t#1|)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-734 |#1|) |has| |#1| (-194)) ((-1065 |#2|) . T) ((-1081 |#1|) . T) ((-1119) . T)) 
+((-3592 (((-1285) $) 7)) (-1683 (((-877) $) 8) (($ (-706 (-715))) 12) (($ (-658 (-350))) 11) (($ (-350)) 10) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 9))) 
+(((-409) (-1311)) (T -409)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-706 (-715))) (-4 *1 (-409)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-409)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-409)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-409))))) 
+(-13 (-421) (-10 -8 (-15 -1683 ($ (-706 (-715)))) (-15 -1683 ($ (-658 (-350)))) (-15 -1683 ($ (-350))) (-15 -1683 ($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350)))))))) 
+(((-632 (-877)) . T) ((-421) . T) ((-1225) . T)) 
+((-4368 (((-3 $ "failed") (-706 (-332 (-405)))) 19) (((-3 $ "failed") (-706 (-332 (-592)))) 17) (((-3 $ "failed") (-706 (-980 (-405)))) 15) (((-3 $ "failed") (-706 (-980 (-592)))) 13) (((-3 $ "failed") (-706 (-433 (-980 (-405))))) 11) (((-3 $ "failed") (-706 (-433 (-980 (-592))))) 9)) (-2400 (($ (-706 (-332 (-405)))) 20) (($ (-706 (-332 (-592)))) 18) (($ (-706 (-980 (-405)))) 16) (($ (-706 (-980 (-592)))) 14) (($ (-706 (-433 (-980 (-405))))) 12) (($ (-706 (-433 (-980 (-592))))) 10)) (-3592 (((-1285) $) 7)) (-1683 (((-877) $) 8) (($ (-658 (-350))) 23) (($ (-350)) 22) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 21))) 
+(((-410) (-1311)) (T -410)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-410)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-410)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-410)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-706 (-332 (-405)))) (-4 *1 (-410)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-332 (-405)))) (-4 *1 (-410)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-706 (-332 (-592)))) (-4 *1 (-410)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-332 (-592)))) (-4 *1 (-410)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-706 (-980 (-405)))) (-4 *1 (-410)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-980 (-405)))) (-4 *1 (-410)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-706 (-980 (-592)))) (-4 *1 (-410)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-980 (-592)))) (-4 *1 (-410)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-706 (-433 (-980 (-405))))) (-4 *1 (-410)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-433 (-980 (-405))))) (-4 *1 (-410)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-706 (-433 (-980 (-592))))) (-4 *1 (-410)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-433 (-980 (-592))))) (-4 *1 (-410))))) 
+(-13 (-421) (-10 -8 (-15 -1683 ($ (-658 (-350)))) (-15 -1683 ($ (-350))) (-15 -1683 ($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350)))))) (-15 -2400 ($ (-706 (-332 (-405))))) (-15 -4368 ((-3 $ "failed") (-706 (-332 (-405))))) (-15 -2400 ($ (-706 (-332 (-592))))) (-15 -4368 ((-3 $ "failed") (-706 (-332 (-592))))) (-15 -2400 ($ (-706 (-980 (-405))))) (-15 -4368 ((-3 $ "failed") (-706 (-980 (-405))))) (-15 -2400 ($ (-706 (-980 (-592))))) (-15 -4368 ((-3 $ "failed") (-706 (-980 (-592))))) (-15 -2400 ($ (-706 (-433 (-980 (-405)))))) (-15 -4368 ((-3 $ "failed") (-706 (-433 (-980 (-405)))))) (-15 -2400 ($ (-706 (-433 (-980 (-592)))))) (-15 -4368 ((-3 $ "failed") (-706 (-433 (-980 (-592)))))))) 
+(((-632 (-877)) . T) ((-421) . T) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-4526 (($ |#1| |#2|) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2183 ((|#2| $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 27)) (-3514 (($) 12 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ |#1| $) 16) (($ $ |#1|) 18))) 
+(((-411 |#1| |#2|) (-13 (-140 |#1| |#1|) (-542 |#1| |#2|) (-10 -7 (IF (|has| |#1| (-194)) (-6 (-734 |#1|)) |noBranch|))) (-1075) (-869)) (T -411)) 
+NIL 
+(-13 (-140 |#1| |#1|) (-542 |#1| |#2|) (-10 -7 (IF (|has| |#1| (-194)) (-6 (-734 |#1|)) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-1403 (((-790) $) 56)) (-3001 (($) NIL T CONST)) (-3305 (((-3 $ "failed") $ $) 58)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3949 (((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) 52)) (-3558 (((-141) $) 14)) (-4449 ((|#1| $ (-592)) NIL)) (-3888 (((-790) $ (-592)) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3401 (($ (-1 |#1| |#1|) $) 37)) (-3970 (($ (-1 (-790) (-790)) $) 34)) (-2141 (((-3 $ "failed") $ $) 49)) (-2685 (((-1173) $) NIL)) (-4403 (($ $ $) 25)) (-4041 (($ $ $) 23)) (-2951 (((-1137) $) NIL)) (-2033 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-790)))) $) 31)) (-4570 (((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $) 55)) (-1683 (((-877) $) 21) (($ |#1|) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-4257 (($) 9 T CONST)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) 41)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) 60 (|has| |#1| (-869)))) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ |#1| (-790)) 40)) (* (($ $ $) 47) (($ |#1| $) 29) (($ $ |#1|) 27))) 
+(((-412 |#1|) (-13 (-743) (-1065 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-790))) (-15 -4041 ($ $ $)) (-15 -4403 ($ $ $)) (-15 -2141 ((-3 $ "failed") $ $)) (-15 -3305 ((-3 $ "failed") $ $)) (-15 -4570 ((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $)) (-15 -3949 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -1403 ((-790) $)) (-15 -2033 ((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-790)))) $)) (-15 -3888 ((-790) $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -3970 ($ (-1 (-790) (-790)) $)) (-15 -3401 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-869)) (-6 (-869)) |noBranch|))) (-1119)) (T -412)) 
+((* (*1 *1 *2 *1) (-12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-5 *1 (-412 *2)) (-4 *2 (-1119)))) (-4041 (*1 *1 *1 *1) (-12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) (-4403 (*1 *1 *1 *1) (-12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) (-2141 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) (-3305 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) (-4570 (*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-412 *3)) (|:| |rm| (-412 *3)))) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) (-3949 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-412 *3)) (|:| |mm| (-412 *3)) (|:| |rm| (-412 *3)))) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) (-1403 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) (-2033 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 (-790))))) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) (-3888 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-790)) (-5 *1 (-412 *4)) (-4 *4 (-1119)))) (-4449 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-412 *2)) (-4 *2 (-1119)))) (-3970 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-790) (-790))) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) (-3401 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-412 *3))))) 
+(-13 (-743) (-1065 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-790))) (-15 -4041 ($ $ $)) (-15 -4403 ($ $ $)) (-15 -2141 ((-3 $ "failed") $ $)) (-15 -3305 ((-3 $ "failed") $ $)) (-15 -4570 ((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $)) (-15 -3949 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -1403 ((-790) $)) (-15 -2033 ((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-790)))) $)) (-15 -3888 ((-790) $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -3970 ($ (-1 (-790) (-790)) $)) (-15 -3401 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-869)) (-6 (-869)) |noBranch|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 46)) (-2400 (((-592) $) 45)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-1837 (($ $ $) 53)) (-3319 (($ $ $) 52)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ $) 41)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-592)) 47)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3286 (((-141) $ $) 50)) (-3273 (((-141) $ $) 49)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 51)) (-3266 (((-141) $ $) 48)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-413) (-1311)) (T -413)) 
+NIL 
+(-13 (-582) (-869) (-1065 (-592))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-582) . T) ((-661 $) . T) ((-734 $) . T) ((-743) . T) ((-869) . T) ((-1065 (-592)) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-1904 (((-141) $) 20)) (-1400 (((-141) $) 19)) (-3242 (($ (-1173) (-1173) (-1173)) 21)) (-4095 (((-1173) $) 16)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3579 (($ (-1173) (-1173) (-1173)) 14)) (-2720 (((-1173) $) 17)) (-1390 (((-141) $) 18)) (-4082 (((-1173) $) 15)) (-1683 (((-877) $) 12) (($ (-1173)) 13) (((-1173) $) 9)) (-3255 (((-141) $ $) 7))) 
+(((-414) (-415)) (T -414)) 
+NIL 
+(-415) 
+((-1641 (((-141) $ $) 7)) (-1904 (((-141) $) 13)) (-1400 (((-141) $) 14)) (-3242 (($ (-1173) (-1173) (-1173)) 12)) (-4095 (((-1173) $) 17)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3579 (($ (-1173) (-1173) (-1173)) 19)) (-2720 (((-1173) $) 16)) (-1390 (((-141) $) 15)) (-4082 (((-1173) $) 18)) (-1683 (((-877) $) 11) (($ (-1173)) 21) (((-1173) $) 20)) (-3255 (((-141) $ $) 6))) 
+(((-415) (-1311)) (T -415)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-4 *1 (-415)))) (-1683 (*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-1173)))) (-3579 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-1173)) (-4 *1 (-415)))) (-4082 (*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-1173)))) (-4095 (*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-1173)))) (-2720 (*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-1173)))) (-1390 (*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-141)))) (-1400 (*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-141)))) (-1904 (*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-141)))) (-3242 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-1173)) (-4 *1 (-415))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-1173))) (-15 -1683 ((-1173) $)) (-15 -3579 ($ (-1173) (-1173) (-1173))) (-15 -4082 ((-1173) $)) (-15 -4095 ((-1173) $)) (-15 -2720 ((-1173) $)) (-15 -1390 ((-141) $)) (-15 -1400 ((-141) $)) (-15 -1904 ((-141) $)) (-15 -3242 ($ (-1173) (-1173) (-1173))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4075 (((-877) $) 50)) (-3001 (($) NIL T CONST)) (-2111 (($ $ (-944)) NIL)) (-1833 (($ $ (-944)) NIL)) (-2682 (($ $ (-944)) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2934 (($ (-790)) 26)) (-1936 (((-790)) 15)) (-2391 (((-877) $) 52)) (-2131 (($ $ $) NIL)) (-1683 (((-877) $) NIL)) (-3667 (($ $ $ $) NIL)) (-2844 (($ $ $) NIL)) (-3514 (($) 20 T CONST)) (-3255 (((-141) $ $) 28)) (-3306 (($ $) 34) (($ $ $) 36)) (-3300 (($ $ $) 37)) (** (($ $ (-944)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 38) (($ $ |#3|) NIL) (($ |#3| $) 33))) 
+(((-416 |#1| |#2| |#3|) (-13 (-763 |#3|) (-10 -8 (-15 -1936 ((-790))) (-15 -2391 ((-877) $)) (-15 -4075 ((-877) $)) (-15 -2934 ($ (-790))))) (-790) (-790) (-194)) (T -416)) 
+((-1936 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-416 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-194)))) (-2391 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-416 *3 *4 *5)) (-14 *3 (-790)) (-14 *4 (-790)) (-4 *5 (-194)))) (-4075 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-416 *3 *4 *5)) (-14 *3 (-790)) (-14 *4 (-790)) (-4 *5 (-194)))) (-2934 (*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-416 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-194))))) 
+(-13 (-763 |#3|) (-10 -8 (-15 -1936 ((-790))) (-15 -2391 ((-877) $)) (-15 -4075 ((-877) $)) (-15 -2934 ($ (-790))))) 
+((-2700 (((-1173)) 10)) (-3127 (((-1161 (-1173))) 28)) (-3572 (((-1285) (-1173)) 25) (((-1285) (-414)) 24)) (-3585 (((-1285)) 26)) (-3982 (((-1161 (-1173))) 27))) 
+(((-417) (-10 -7 (-15 -3982 ((-1161 (-1173)))) (-15 -3127 ((-1161 (-1173)))) (-15 -3585 ((-1285))) (-15 -3572 ((-1285) (-414))) (-15 -3572 ((-1285) (-1173))) (-15 -2700 ((-1173))))) (T -417)) 
+((-2700 (*1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-417)))) (-3572 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-417)))) (-3572 (*1 *2 *3) (-12 (-5 *3 (-414)) (-5 *2 (-1285)) (-5 *1 (-417)))) (-3585 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-417)))) (-3127 (*1 *2) (-12 (-5 *2 (-1161 (-1173))) (-5 *1 (-417)))) (-3982 (*1 *2) (-12 (-5 *2 (-1161 (-1173))) (-5 *1 (-417))))) 
+(-10 -7 (-15 -3982 ((-1161 (-1173)))) (-15 -3127 ((-1161 (-1173)))) (-15 -3585 ((-1285))) (-15 -3572 ((-1285) (-414))) (-15 -3572 ((-1285) (-1173))) (-15 -2700 ((-1173)))) 
+((-4346 (((-790) (-356 |#1| |#2| |#3| |#4|)) 16))) 
+(((-418 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4346 ((-790) (-356 |#1| |#2| |#3| |#4|)))) (-13 (-394) (-388)) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|)) (T -418)) 
+((-4346 (*1 *2 *3) (-12 (-5 *3 (-356 *4 *5 *6 *7)) (-4 *4 (-13 (-394) (-388))) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-4 *7 (-362 *4 *5 *6)) (-5 *2 (-790)) (-5 *1 (-418 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -4346 ((-790) (-356 |#1| |#2| |#3| |#4|)))) 
+((-1683 (((-420) |#1|) 11))) 
+(((-419 |#1|) (-10 -7 (-15 -1683 ((-420) |#1|))) (-1119)) (T -419)) 
+((-1683 (*1 *2 *3) (-12 (-5 *2 (-420)) (-5 *1 (-419 *3)) (-4 *3 (-1119))))) 
+(-10 -7 (-15 -1683 ((-420) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2255 (((-658 (-1173)) $ (-658 (-1173))) 37)) (-4590 (((-658 (-1173)) $ (-658 (-1173))) 38)) (-1458 (((-658 (-1173)) $ (-658 (-1173))) 39)) (-3749 (((-658 (-1173)) $) 34)) (-3242 (($) 23)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1782 (((-658 (-1173)) $) 35)) (-4240 (((-658 (-1173)) $) 36)) (-3536 (((-1285) $ (-592)) 32) (((-1285) $) 33)) (-1778 (($ (-877) (-592)) 29)) (-1683 (((-877) $) 41) (($ (-877)) 25)) (-3255 (((-141) $ $) NIL))) 
+(((-420) (-13 (-1119) (-10 -8 (-15 -1683 ($ (-877))) (-15 -1778 ($ (-877) (-592))) (-15 -3536 ((-1285) $ (-592))) (-15 -3536 ((-1285) $)) (-15 -4240 ((-658 (-1173)) $)) (-15 -1782 ((-658 (-1173)) $)) (-15 -3242 ($)) (-15 -3749 ((-658 (-1173)) $)) (-15 -1458 ((-658 (-1173)) $ (-658 (-1173)))) (-15 -4590 ((-658 (-1173)) $ (-658 (-1173)))) (-15 -2255 ((-658 (-1173)) $ (-658 (-1173))))))) (T -420)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-420)))) (-1778 (*1 *1 *2 *3) (-12 (-5 *2 (-877)) (-5 *3 (-592)) (-5 *1 (-420)))) (-3536 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-420)))) (-3536 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-420)))) (-4240 (*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) (-1782 (*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) (-3242 (*1 *1) (-5 *1 (-420))) (-3749 (*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) (-1458 (*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) (-4590 (*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) (-2255 (*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-877))) (-15 -1778 ($ (-877) (-592))) (-15 -3536 ((-1285) $ (-592))) (-15 -3536 ((-1285) $)) (-15 -4240 ((-658 (-1173)) $)) (-15 -1782 ((-658 (-1173)) $)) (-15 -3242 ($)) (-15 -3749 ((-658 (-1173)) $)) (-15 -1458 ((-658 (-1173)) $ (-658 (-1173)))) (-15 -4590 ((-658 (-1173)) $ (-658 (-1173)))) (-15 -2255 ((-658 (-1173)) $ (-658 (-1173)))))) 
+((-3592 (((-1285) $) 7)) (-1683 (((-877) $) 8))) 
+(((-421) (-1311)) (T -421)) 
+((-3592 (*1 *2 *1) (-12 (-4 *1 (-421)) (-5 *2 (-1285))))) 
+(-13 (-1225) (-632 (-877)) (-10 -8 (-15 -3592 ((-1285) $)))) 
+(((-632 (-877)) . T) ((-1225) . T)) 
+((-4368 (((-3 $ "failed") (-332 (-405))) 19) (((-3 $ "failed") (-332 (-592))) 17) (((-3 $ "failed") (-980 (-405))) 15) (((-3 $ "failed") (-980 (-592))) 13) (((-3 $ "failed") (-433 (-980 (-405)))) 11) (((-3 $ "failed") (-433 (-980 (-592)))) 9)) (-2400 (($ (-332 (-405))) 20) (($ (-332 (-592))) 18) (($ (-980 (-405))) 16) (($ (-980 (-592))) 14) (($ (-433 (-980 (-405)))) 12) (($ (-433 (-980 (-592)))) 10)) (-3592 (((-1285) $) 7)) (-1683 (((-877) $) 8) (($ (-658 (-350))) 23) (($ (-350)) 22) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 21))) 
+(((-422) (-1311)) (T -422)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-422)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-422)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-422)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-332 (-405))) (-4 *1 (-422)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-332 (-405))) (-4 *1 (-422)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-332 (-592))) (-4 *1 (-422)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-332 (-592))) (-4 *1 (-422)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-980 (-405))) (-4 *1 (-422)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-405))) (-4 *1 (-422)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-980 (-592))) (-4 *1 (-422)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-592))) (-4 *1 (-422)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-405)))) (-4 *1 (-422)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-433 (-980 (-405)))) (-4 *1 (-422)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-592)))) (-4 *1 (-422)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-433 (-980 (-592)))) (-4 *1 (-422))))) 
+(-13 (-421) (-10 -8 (-15 -1683 ($ (-658 (-350)))) (-15 -1683 ($ (-350))) (-15 -1683 ($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350)))))) (-15 -2400 ($ (-332 (-405)))) (-15 -4368 ((-3 $ "failed") (-332 (-405)))) (-15 -2400 ($ (-332 (-592)))) (-15 -4368 ((-3 $ "failed") (-332 (-592)))) (-15 -2400 ($ (-980 (-405)))) (-15 -4368 ((-3 $ "failed") (-980 (-405)))) (-15 -2400 ($ (-980 (-592)))) (-15 -4368 ((-3 $ "failed") (-980 (-592)))) (-15 -2400 ($ (-433 (-980 (-405))))) (-15 -4368 ((-3 $ "failed") (-433 (-980 (-405))))) (-15 -2400 ($ (-433 (-980 (-592))))) (-15 -4368 ((-3 $ "failed") (-433 (-980 (-592))))))) 
+(((-632 (-877)) . T) ((-421) . T) ((-1225) . T)) 
+((-1899 (((-658 (-1173)) (-658 (-1173))) 8)) (-3592 (((-1285) (-414)) 27)) (-3385 (((-1123) (-1191) (-658 (-1191)) (-1194) (-658 (-1191))) 59) (((-1123) (-1191) (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191)))) (-658 (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191))))) (-658 (-1191)) (-1191)) 35) (((-1123) (-1191) (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191)))) (-658 (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191))))) (-658 (-1191))) 34))) 
+(((-423) (-10 -7 (-15 -3385 ((-1123) (-1191) (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191)))) (-658 (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191))))) (-658 (-1191)))) (-15 -3385 ((-1123) (-1191) (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191)))) (-658 (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191))))) (-658 (-1191)) (-1191))) (-15 -3385 ((-1123) (-1191) (-658 (-1191)) (-1194) (-658 (-1191)))) (-15 -3592 ((-1285) (-414))) (-15 -1899 ((-658 (-1173)) (-658 (-1173)))))) (T -423)) 
+((-1899 (*1 *2 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-423)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-414)) (-5 *2 (-1285)) (-5 *1 (-423)))) (-3385 (*1 *2 *3 *4 *5 *4) (-12 (-5 *4 (-658 (-1191))) (-5 *5 (-1194)) (-5 *3 (-1191)) (-5 *2 (-1123)) (-5 *1 (-423)))) (-3385 (*1 *2 *3 *4 *5 *6 *3) (-12 (-5 *5 (-658 (-658 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-658 (-3 (|:| |array| (-658 *3)) (|:| |scalar| (-1191))))) (-5 *6 (-658 (-1191))) (-5 *3 (-1191)) (-5 *2 (-1123)) (-5 *1 (-423)))) (-3385 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-658 (-658 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-658 (-3 (|:| |array| (-658 *3)) (|:| |scalar| (-1191))))) (-5 *6 (-658 (-1191))) (-5 *3 (-1191)) (-5 *2 (-1123)) (-5 *1 (-423))))) 
+(-10 -7 (-15 -3385 ((-1123) (-1191) (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191)))) (-658 (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191))))) (-658 (-1191)))) (-15 -3385 ((-1123) (-1191) (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191)))) (-658 (-658 (-3 (|:| |array| (-658 (-1191))) (|:| |scalar| (-1191))))) (-658 (-1191)) (-1191))) (-15 -3385 ((-1123) (-1191) (-658 (-1191)) (-1194) (-658 (-1191)))) (-15 -3592 ((-1285) (-414))) (-15 -1899 ((-658 (-1173)) (-658 (-1173))))) 
+((-3592 (((-1285) $) 37)) (-1683 (((-877) $) 89) (($ (-350)) 92) (($ (-658 (-350))) 91) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 88) (($ (-332 (-717))) 52) (($ (-332 (-715))) 66) (($ (-332 (-710))) 78) (($ (-310 (-332 (-717)))) 62) (($ (-310 (-332 (-715)))) 74) (($ (-310 (-332 (-710)))) 86) (($ (-332 (-592))) 96) (($ (-332 (-405))) 108) (($ (-332 (-191 (-405)))) 120) (($ (-310 (-332 (-592)))) 104) (($ (-310 (-332 (-405)))) 116) (($ (-310 (-332 (-191 (-405))))) 128))) 
+(((-424 |#1| |#2| |#3| |#4|) (-13 (-421) (-10 -8 (-15 -1683 ($ (-350))) (-15 -1683 ($ (-658 (-350)))) (-15 -1683 ($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350)))))) (-15 -1683 ($ (-332 (-717)))) (-15 -1683 ($ (-332 (-715)))) (-15 -1683 ($ (-332 (-710)))) (-15 -1683 ($ (-310 (-332 (-717))))) (-15 -1683 ($ (-310 (-332 (-715))))) (-15 -1683 ($ (-310 (-332 (-710))))) (-15 -1683 ($ (-332 (-592)))) (-15 -1683 ($ (-332 (-405)))) (-15 -1683 ($ (-332 (-191 (-405))))) (-15 -1683 ($ (-310 (-332 (-592))))) (-15 -1683 ($ (-310 (-332 (-405))))) (-15 -1683 ($ (-310 (-332 (-191 (-405)))))))) (-1191) (-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-658 (-1191)) (-1195)) (T -424)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-350)) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-332 (-717))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-332 (-715))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-332 (-710))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-717)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-715)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-710)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-332 (-592))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-332 (-405))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-332 (-191 (-405)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-592)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-405)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-191 (-405))))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195))))) 
+(-13 (-421) (-10 -8 (-15 -1683 ($ (-350))) (-15 -1683 ($ (-658 (-350)))) (-15 -1683 ($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350)))))) (-15 -1683 ($ (-332 (-717)))) (-15 -1683 ($ (-332 (-715)))) (-15 -1683 ($ (-332 (-710)))) (-15 -1683 ($ (-310 (-332 (-717))))) (-15 -1683 ($ (-310 (-332 (-715))))) (-15 -1683 ($ (-310 (-332 (-710))))) (-15 -1683 ($ (-332 (-592)))) (-15 -1683 ($ (-332 (-405)))) (-15 -1683 ($ (-332 (-191 (-405))))) (-15 -1683 ($ (-310 (-332 (-592))))) (-15 -1683 ($ (-310 (-332 (-405))))) (-15 -1683 ($ (-310 (-332 (-191 (-405)))))))) 
+((-1641 (((-141) $ $) NIL)) (-4104 ((|#2| $) 36)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4597 (($ (-433 |#2|)) 84)) (-4134 (((-658 (-2 (|:| -3215 (-790)) (|:| -2838 |#2|) (|:| |num| |#2|))) $) 37)) (-3644 (($ $) 32) (($ $ (-790)) 34)) (-1778 (((-433 |#2|) $) 46)) (-4466 (($ (-658 (-2 (|:| -3215 (-790)) (|:| -2838 |#2|) (|:| |num| |#2|)))) 31)) (-1683 (((-877) $) 120)) (-1940 (($ $) 33) (($ $ (-790)) 35)) (-3255 (((-141) $ $) NIL)) (-3300 (($ |#2| $) 39))) 
+(((-425 |#1| |#2|) (-13 (-1119) (-633 (-433 |#2|)) (-10 -8 (-15 -3300 ($ |#2| $)) (-15 -4597 ($ (-433 |#2|))) (-15 -4104 (|#2| $)) (-15 -4134 ((-658 (-2 (|:| -3215 (-790)) (|:| -2838 |#2|) (|:| |num| |#2|))) $)) (-15 -4466 ($ (-658 (-2 (|:| -3215 (-790)) (|:| -2838 |#2|) (|:| |num| |#2|))))) (-15 -3644 ($ $)) (-15 -1940 ($ $)) (-15 -3644 ($ $ (-790))) (-15 -1940 ($ $ (-790))))) (-13 (-388) (-171)) (-1255 |#1|)) (T -425)) 
+((-3300 (*1 *1 *2 *1) (-12 (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *2)) (-4 *2 (-1255 *3)))) (-4597 (*1 *1 *2) (-12 (-5 *2 (-433 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *4)))) (-4104 (*1 *2 *1) (-12 (-4 *2 (-1255 *3)) (-5 *1 (-425 *3 *2)) (-4 *3 (-13 (-388) (-171))))) (-4134 (*1 *2 *1) (-12 (-4 *3 (-13 (-388) (-171))) (-5 *2 (-658 (-2 (|:| -3215 (-790)) (|:| -2838 *4) (|:| |num| *4)))) (-5 *1 (-425 *3 *4)) (-4 *4 (-1255 *3)))) (-4466 (*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -3215 (-790)) (|:| -2838 *4) (|:| |num| *4)))) (-4 *4 (-1255 *3)) (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *4)))) (-3644 (*1 *1 *1) (-12 (-4 *2 (-13 (-388) (-171))) (-5 *1 (-425 *2 *3)) (-4 *3 (-1255 *2)))) (-1940 (*1 *1 *1) (-12 (-4 *2 (-13 (-388) (-171))) (-5 *1 (-425 *2 *3)) (-4 *3 (-1255 *2)))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *4)) (-4 *4 (-1255 *3)))) (-1940 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *4)) (-4 *4 (-1255 *3))))) 
+(-13 (-1119) (-633 (-433 |#2|)) (-10 -8 (-15 -3300 ($ |#2| $)) (-15 -4597 ($ (-433 |#2|))) (-15 -4104 (|#2| $)) (-15 -4134 ((-658 (-2 (|:| -3215 (-790)) (|:| -2838 |#2|) (|:| |num| |#2|))) $)) (-15 -4466 ($ (-658 (-2 (|:| -3215 (-790)) (|:| -2838 |#2|) (|:| |num| |#2|))))) (-15 -3644 ($ $)) (-15 -1940 ($ $)) (-15 -3644 ($ $ (-790))) (-15 -1940 ($ $ (-790))))) 
+((-1641 (((-141) $ $) 9 (-3836 (|has| |#1| (-908 (-592))) (|has| |#1| (-908 (-405)))))) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 15 (|has| |#1| (-908 (-405)))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 14 (|has| |#1| (-908 (-592))))) (-2685 (((-1173) $) 13 (-3836 (|has| |#1| (-908 (-592))) (|has| |#1| (-908 (-405)))))) (-2951 (((-1137) $) 12 (-3836 (|has| |#1| (-908 (-592))) (|has| |#1| (-908 (-405)))))) (-1683 (((-877) $) 11 (-3836 (|has| |#1| (-908 (-592))) (|has| |#1| (-908 (-405)))))) (-3255 (((-141) $ $) 10 (-3836 (|has| |#1| (-908 (-592))) (|has| |#1| (-908 (-405))))))) 
+(((-426 |#1|) (-1311) (-1225)) (T -426)) 
+NIL 
+(-13 (-1225) (-10 -7 (IF (|has| |t#1| (-908 (-592))) (-6 (-908 (-592))) |noBranch|) (IF (|has| |t#1| (-908 (-405))) (-6 (-908 (-405))) |noBranch|))) 
+(((-125) -3836 (|has| |#1| (-908 (-592))) (|has| |#1| (-908 (-405)))) ((-632 (-877)) -3836 (|has| |#1| (-908 (-592))) (|has| |#1| (-908 (-405)))) ((-908 (-405)) |has| |#1| (-908 (-405))) ((-908 (-592)) |has| |#1| (-908 (-592))) ((-1119) -3836 (|has| |#1| (-908 (-592))) (|has| |#1| (-908 (-405)))) ((-1225) . T)) 
+((-1525 (($ $) 10) (($ $ (-790)) 11))) 
+(((-427 |#1|) (-10 -8 (-15 -1525 (|#1| |#1| (-790))) (-15 -1525 (|#1| |#1|))) (-428)) (T -427)) 
+NIL 
+(-10 -8 (-15 -1525 (|#1| |#1| (-790))) (-15 -1525 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-3001 (($) 16 T CONST)) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-1525 (($ $) 75) (($ $ (-790)) 74)) (-2802 (((-141) $) 69)) (-4346 (((-855 (-944)) $) 77)) (-3558 (((-141) $) 30)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-2177 (((-3 (-790) "failed") $ $) 76)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63)) (-1517 (((-3 $ "failed") $) 78)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64))) 
+(((-428) (-1311)) (T -428)) 
+((-4346 (*1 *2 *1) (-12 (-4 *1 (-428)) (-5 *2 (-855 (-944))))) (-2177 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-428)) (-5 *2 (-790)))) (-1525 (*1 *1 *1) (-4 *1 (-428))) (-1525 (*1 *1 *1 *2) (-12 (-4 *1 (-428)) (-5 *2 (-790))))) 
+(-13 (-388) (-169) (-10 -8 (-15 -4346 ((-855 (-944)) $)) (-15 -2177 ((-3 (-790) "failed") $ $)) (-15 -1525 ($ $)) (-15 -1525 ($ $ (-790))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-169) . T) ((-632 (-877)) . T) ((-194) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T)) 
+((-4540 (($ (-592) (-592)) 11) (($ (-592) (-592) (-944)) NIL)) (-4406 (((-944)) 16) (((-944) (-944)) NIL))) 
+(((-429 |#1|) (-10 -8 (-15 -4406 ((-944) (-944))) (-15 -4406 ((-944))) (-15 -4540 (|#1| (-592) (-592) (-944))) (-15 -4540 (|#1| (-592) (-592)))) (-430)) (T -429)) 
+((-4406 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-429 *3)) (-4 *3 (-430)))) (-4406 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-429 *3)) (-4 *3 (-430))))) 
+(-10 -8 (-15 -4406 ((-944) (-944))) (-15 -4406 ((-944))) (-15 -4540 (|#1| (-592) (-592) (-944))) (-15 -4540 (|#1| (-592) (-592)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-1505 (((-592) $) 85)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2306 (($ $) 83)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-1442 (($ $) 93)) (-3652 (((-141) $ $) 57)) (-3940 (((-592) $) 110)) (-3001 (($) 16 T CONST)) (-1755 (($ $) 82)) (-4368 (((-3 (-592) "failed") $) 98) (((-3 (-433 (-592)) "failed") $) 95)) (-2400 (((-592) $) 97) (((-433 (-592)) $) 94)) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2802 (((-141) $) 69)) (-4047 (((-944)) 119) (((-944) (-944)) 116 (|has| $ (-6 -4616)))) (-1691 (((-141) $) 108)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 89)) (-4346 (((-592) $) 125)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 92)) (-2793 (($ $) 88)) (-1324 (((-141) $) 109)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-1837 (($ $ $) 107) (($) 113 (-12 (-3252 (|has| $ (-6 -4616))) (-3252 (|has| $ (-6 -4608)))))) (-3319 (($ $ $) 106) (($) 112 (-12 (-3252 (|has| $ (-6 -4616))) (-3252 (|has| $ (-6 -4608)))))) (-2950 (((-592) $) 122)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-1867 (((-944) (-592)) 115 (|has| $ (-6 -4616)))) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3856 (($ $) 84)) (-2039 (($ $) 86)) (-4540 (($ (-592) (-592)) 127) (($ (-592) (-592) (-944)) 126)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-3215 (((-592) $) 123)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-4406 (((-944)) 120) (((-944) (-944)) 117 (|has| $ (-6 -4616)))) (-1738 (((-944) (-592)) 114 (|has| $ (-6 -4616)))) (-1778 (((-405) $) 101) (((-237) $) 100) (((-914 (-405)) $) 90)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63) (($ (-592)) 99) (($ (-433 (-592))) 96)) (-4010 (((-790)) 28)) (-2744 (($ $) 87)) (-3671 (((-944)) 121) (((-944) (-944)) 118 (|has| $ (-6 -4616)))) (-4226 (((-944)) 124)) (-2537 (((-141) $ $) 38)) (-1392 (($ $) 111)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3286 (((-141) $ $) 104)) (-3273 (((-141) $ $) 103)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 105)) (-3266 (((-141) $ $) 102)) (-3313 (($ $ $) 62)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66) (($ $ (-433 (-592))) 91)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64))) 
+(((-430) (-1311)) (T -430)) 
+((-4540 (*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-4 *1 (-430)))) (-4540 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-592)) (-5 *3 (-944)) (-4 *1 (-430)))) (-4346 (*1 *2 *1) (-12 (-4 *1 (-430)) (-5 *2 (-592)))) (-4226 (*1 *2) (-12 (-4 *1 (-430)) (-5 *2 (-944)))) (-3215 (*1 *2 *1) (-12 (-4 *1 (-430)) (-5 *2 (-592)))) (-2950 (*1 *2 *1) (-12 (-4 *1 (-430)) (-5 *2 (-592)))) (-3671 (*1 *2) (-12 (-4 *1 (-430)) (-5 *2 (-944)))) (-4406 (*1 *2) (-12 (-4 *1 (-430)) (-5 *2 (-944)))) (-4047 (*1 *2) (-12 (-4 *1 (-430)) (-5 *2 (-944)))) (-3671 (*1 *2 *2) (-12 (-5 *2 (-944)) (|has| *1 (-6 -4616)) (-4 *1 (-430)))) (-4406 (*1 *2 *2) (-12 (-5 *2 (-944)) (|has| *1 (-6 -4616)) (-4 *1 (-430)))) (-4047 (*1 *2 *2) (-12 (-5 *2 (-944)) (|has| *1 (-6 -4616)) (-4 *1 (-430)))) (-1867 (*1 *2 *3) (-12 (-5 *3 (-592)) (|has| *1 (-6 -4616)) (-4 *1 (-430)) (-5 *2 (-944)))) (-1738 (*1 *2 *3) (-12 (-5 *3 (-592)) (|has| *1 (-6 -4616)) (-4 *1 (-430)) (-5 *2 (-944)))) (-1837 (*1 *1) (-12 (-4 *1 (-430)) (-3252 (|has| *1 (-6 -4616))) (-3252 (|has| *1 (-6 -4608))))) (-3319 (*1 *1) (-12 (-4 *1 (-430)) (-3252 (|has| *1 (-6 -4616))) (-3252 (|has| *1 (-6 -4608)))))) 
+(-13 (-1084) (-10 -8 (-6 -2642) (-15 -4540 ($ (-592) (-592))) (-15 -4540 ($ (-592) (-592) (-944))) (-15 -4346 ((-592) $)) (-15 -4226 ((-944))) (-15 -3215 ((-592) $)) (-15 -2950 ((-592) $)) (-15 -3671 ((-944))) (-15 -4406 ((-944))) (-15 -4047 ((-944))) (IF (|has| $ (-6 -4616)) (PROGN (-15 -3671 ((-944) (-944))) (-15 -4406 ((-944) (-944))) (-15 -4047 ((-944) (-944))) (-15 -1867 ((-944) (-592))) (-15 -1738 ((-944) (-592)))) |noBranch|) (IF (|has| $ (-6 -4608)) |noBranch| (IF (|has| $ (-6 -4616)) |noBranch| (PROGN (-15 -1837 ($)) (-15 -3319 ($))))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-171) . T) ((-632 (-877)) . T) ((-194) . T) ((-633 (-237)) . T) ((-633 (-405)) . T) ((-633 (-914 (-405))) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-813) . T) ((-814) . T) ((-816) . T) ((-817) . T) ((-867) . T) ((-869) . T) ((-908 (-405)) . T) ((-943) . T) ((-1030) . T) ((-1049) . T) ((-1084) . T) ((-1065 (-433 (-592))) . T) ((-1065 (-592)) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T)) 
+((-2731 (((-444 |#2|) (-1 |#2| |#1|) (-444 |#1|)) 20))) 
+(((-431 |#1| |#2|) (-10 -7 (-15 -2731 ((-444 |#2|) (-1 |#2| |#1|) (-444 |#1|)))) (-582) (-582)) (T -431)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-444 *5)) (-4 *5 (-582)) (-4 *6 (-582)) (-5 *2 (-444 *6)) (-5 *1 (-431 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-444 |#2|) (-1 |#2| |#1|) (-444 |#1|)))) 
+((-2731 (((-433 |#2|) (-1 |#2| |#1|) (-433 |#1|)) 13))) 
+(((-432 |#1| |#2|) (-10 -7 (-15 -2731 ((-433 |#2|) (-1 |#2| |#1|) (-433 |#1|)))) (-582) (-582)) (T -432)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-433 *5)) (-4 *5 (-582)) (-4 *6 (-582)) (-5 *2 (-433 *6)) (-5 *1 (-432 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-433 |#2|) (-1 |#2| |#1|) (-433 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 13)) (-1505 ((|#1| $) 21 (|has| |#1| (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| |#1| (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 17) (((-3 (-1191) "failed") $) NIL (|has| |#1| (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) 70 (|has| |#1| (-1065 (-592)))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592))))) (-2400 ((|#1| $) 15) (((-1191) $) NIL (|has| |#1| (-1065 (-1191)))) (((-433 (-592)) $) 67 (|has| |#1| (-1065 (-592)))) (((-592) $) NIL (|has| |#1| (-1065 (-592))))) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) 50)) (-4290 (($) NIL (|has| |#1| (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) NIL (|has| |#1| (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| |#1| (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| |#1| (-908 (-405))))) (-3558 (((-141) $) 64)) (-3838 (($ $) NIL)) (-1448 ((|#1| $) 71)) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-1165)))) (-1324 (((-141) $) NIL (|has| |#1| (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| |#1| (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 97)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| |#1| (-323)))) (-2039 ((|#1| $) 28 (|has| |#1| (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) 133 (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) 129 (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) NIL (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) NIL (|has| |#1| (-547 (-1191) |#1|)))) (-2769 (((-790) $) NIL)) (-3927 (($ $ |#1|) NIL (|has| |#1| (-303 |#1| |#1|)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) 63)) (-2782 (($ $) NIL)) (-1456 ((|#1| $) 73)) (-1778 (((-914 (-592)) $) NIL (|has| |#1| (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| |#1| (-633 (-914 (-405))))) (((-565) $) NIL (|has| |#1| (-633 (-565)))) (((-405) $) NIL (|has| |#1| (-1049))) (((-237) $) NIL (|has| |#1| (-1049)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 113 (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) 10) (($ (-1191)) NIL (|has| |#1| (-1065 (-1191))))) (-1517 (((-3 $ "failed") $) 99 (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) 100)) (-2744 ((|#1| $) 26 (|has| |#1| (-574)))) (-2537 (((-141) $ $) NIL)) (-1392 (($ $) NIL (|has| |#1| (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 22 T CONST)) (-4257 (($) 8 T CONST)) (-1637 (((-1173) $) 43 (-12 (|has| |#1| (-574)) (|has| |#1| (-850)))) (((-1173) $ (-141)) 44 (-12 (|has| |#1| (-574)) (|has| |#1| (-850)))) (((-1285) (-844) $) 45 (-12 (|has| |#1| (-574)) (|has| |#1| (-850)))) (((-1285) (-844) $ (-141)) 46 (-12 (|has| |#1| (-574)) (|has| |#1| (-850))))) (-1940 (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) 56)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) 24 (|has| |#1| (-869)))) (-3313 (($ $ $) 124) (($ |#1| |#1|) 52)) (-3306 (($ $) 25) (($ $ $) 55)) (-3300 (($ $ $) 53)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 123)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 60) (($ $ $) 57) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ |#1| $) 61) (($ $ |#1|) 85))) 
+(((-433 |#1|) (-13 (-1021 |#1|) (-10 -7 (IF (|has| |#1| (-574)) (IF (|has| |#1| (-850)) (-6 (-850)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4612)) (IF (|has| |#1| (-477)) (IF (|has| |#1| (-6 -4623)) (-6 -4612) |noBranch|) |noBranch|) |noBranch|))) (-582)) (T -433)) 
+NIL 
+(-13 (-1021 |#1|) (-10 -7 (IF (|has| |#1| (-574)) (IF (|has| |#1| (-850)) (-6 (-850)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4612)) (IF (|has| |#1| (-477)) (IF (|has| |#1| (-6 -4623)) (-6 -4612) |noBranch|) |noBranch|) |noBranch|))) 
+((-1800 (((-706 |#2|) (-1280 $)) NIL) (((-706 |#2|)) 18)) (-1626 (($ (-1280 |#2|) (-1280 $)) NIL) (($ (-1280 |#2|)) 26)) (-4493 (((-706 |#2|) $ (-1280 $)) NIL) (((-706 |#2|) $) 22)) (-3504 ((|#3| $) 59)) (-1482 ((|#2| (-1280 $)) NIL) ((|#2|) 20)) (-2231 (((-1280 |#2|) $ (-1280 $)) NIL) (((-706 |#2|) (-1280 $) (-1280 $)) NIL) (((-1280 |#2|) $) NIL) (((-706 |#2|) (-1280 $)) 24)) (-1778 (((-1280 |#2|) $) 11) (($ (-1280 |#2|)) 13)) (-4198 ((|#3| $) 51))) 
+(((-434 |#1| |#2| |#3|) (-10 -8 (-15 -4493 ((-706 |#2|) |#1|)) (-15 -1482 (|#2|)) (-15 -1800 ((-706 |#2|))) (-15 -1778 (|#1| (-1280 |#2|))) (-15 -1778 ((-1280 |#2|) |#1|)) (-15 -1626 (|#1| (-1280 |#2|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1|)) (-15 -3504 (|#3| |#1|)) (-15 -4198 (|#3| |#1|)) (-15 -1800 ((-706 |#2|) (-1280 |#1|))) (-15 -1482 (|#2| (-1280 |#1|))) (-15 -1626 (|#1| (-1280 |#2|) (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -4493 ((-706 |#2|) |#1| (-1280 |#1|)))) (-435 |#2| |#3|) (-194) (-1255 |#2|)) (T -434)) 
+((-1800 (*1 *2) (-12 (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)) (-5 *1 (-434 *3 *4 *5)) (-4 *3 (-435 *4 *5)))) (-1482 (*1 *2) (-12 (-4 *4 (-1255 *2)) (-4 *2 (-194)) (-5 *1 (-434 *3 *2 *4)) (-4 *3 (-435 *2 *4))))) 
+(-10 -8 (-15 -4493 ((-706 |#2|) |#1|)) (-15 -1482 (|#2|)) (-15 -1800 ((-706 |#2|))) (-15 -1778 (|#1| (-1280 |#2|))) (-15 -1778 ((-1280 |#2|) |#1|)) (-15 -1626 (|#1| (-1280 |#2|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1|)) (-15 -3504 (|#3| |#1|)) (-15 -4198 (|#3| |#1|)) (-15 -1800 ((-706 |#2|) (-1280 |#1|))) (-15 -1482 (|#2| (-1280 |#1|))) (-15 -1626 (|#1| (-1280 |#2|) (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -4493 ((-706 |#2|) |#1| (-1280 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-1800 (((-706 |#1|) (-1280 $)) 44) (((-706 |#1|)) 55)) (-4529 ((|#1| $) 50)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-1626 (($ (-1280 |#1|) (-1280 $)) 46) (($ (-1280 |#1|)) 58)) (-4493 (((-706 |#1|) $ (-1280 $)) 51) (((-706 |#1|) $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-4175 (((-944)) 52)) (-3558 (((-141) $) 30)) (-2793 ((|#1| $) 49)) (-3504 ((|#2| $) 42 (|has| |#1| (-388)))) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1482 ((|#1| (-1280 $)) 45) ((|#1|) 54)) (-2231 (((-1280 |#1|) $ (-1280 $)) 48) (((-706 |#1|) (-1280 $) (-1280 $)) 47) (((-1280 |#1|) $) 60) (((-706 |#1|) (-1280 $)) 59)) (-1778 (((-1280 |#1|) $) 57) (($ (-1280 |#1|)) 56)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 36)) (-1517 (((-3 $ "failed") $) 41 (|has| |#1| (-169)))) (-4198 ((|#2| $) 43)) (-4010 (((-790)) 28)) (-2195 (((-1280 $)) 61)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
+(((-435 |#1| |#2|) (-1311) (-194) (-1255 |t#1|)) (T -435)) 
+((-2195 (*1 *2) (-12 (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-1280 *1)) (-4 *1 (-435 *3 *4)))) (-2231 (*1 *2 *1) (-12 (-4 *1 (-435 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-1280 *3)))) (-2231 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-435 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)))) (-1626 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-194)) (-4 *1 (-435 *3 *4)) (-4 *4 (-1255 *3)))) (-1778 (*1 *2 *1) (-12 (-4 *1 (-435 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-1280 *3)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-194)) (-4 *1 (-435 *3 *4)) (-4 *4 (-1255 *3)))) (-1800 (*1 *2) (-12 (-4 *1 (-435 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-706 *3)))) (-1482 (*1 *2) (-12 (-4 *1 (-435 *2 *3)) (-4 *3 (-1255 *2)) (-4 *2 (-194)))) (-4493 (*1 *2 *1) (-12 (-4 *1 (-435 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-706 *3))))) 
+(-13 (-396 |t#1| |t#2|) (-10 -8 (-15 -2195 ((-1280 $))) (-15 -2231 ((-1280 |t#1|) $)) (-15 -2231 ((-706 |t#1|) (-1280 $))) (-15 -1626 ($ (-1280 |t#1|))) (-15 -1778 ((-1280 |t#1|) $)) (-15 -1778 ($ (-1280 |t#1|))) (-15 -1800 ((-706 |t#1|))) (-15 -1482 (|t#1|)) (-15 -4493 ((-706 |t#1|) $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-396 |#1| |#2|) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-734 |#1|) . T) ((-743) . T) ((-1081 |#1|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) 27) (((-3 (-592) "failed") $) 19)) (-2400 ((|#2| $) NIL) (((-433 (-592)) $) 24) (((-592) $) 14)) (-1683 (($ |#2|) NIL) (($ (-433 (-592))) 22) (($ (-592)) 11))) 
+(((-436 |#1| |#2|) (-10 -8 (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -1683 (|#1| (-592))) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -2400 (|#2| |#1|))) (-437 |#2|) (-1225)) (T -436)) 
+NIL 
+(-10 -8 (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -1683 (|#1| (-592))) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -2400 (|#2| |#1|))) 
+((-4368 (((-3 |#1| "failed") $) 7) (((-3 (-433 (-592)) "failed") $) 15 (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) 12 (|has| |#1| (-1065 (-592))))) (-2400 ((|#1| $) 8) (((-433 (-592)) $) 14 (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) 11 (|has| |#1| (-1065 (-592))))) (-1683 (($ |#1|) 6) (($ (-433 (-592))) 16 (|has| |#1| (-1065 (-433 (-592))))) (($ (-592)) 13 (|has| |#1| (-1065 (-592)))))) 
+(((-437 |#1|) (-1311) (-1225)) (T -437)) 
+NIL 
+(-13 (-1065 |t#1|) (-10 -7 (IF (|has| |t#1| (-1065 (-592))) (-6 (-1065 (-592))) |noBranch|) (IF (|has| |t#1| (-1065 (-433 (-592)))) (-6 (-1065 (-433 (-592)))) |noBranch|))) 
+(((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T)) 
+((-2731 (((-439 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-439 |#1| |#2| |#3| |#4|)) 33))) 
+(((-438 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2731 ((-439 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-439 |#1| |#2| |#3| |#4|)))) (-323) (-1021 |#1|) (-1255 |#2|) (-13 (-435 |#2| |#3|) (-1065 |#2|)) (-323) (-1021 |#5|) (-1255 |#6|) (-13 (-435 |#6| |#7|) (-1065 |#6|))) (T -438)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-439 *5 *6 *7 *8)) (-4 *5 (-323)) (-4 *6 (-1021 *5)) (-4 *7 (-1255 *6)) (-4 *8 (-13 (-435 *6 *7) (-1065 *6))) (-4 *9 (-323)) (-4 *10 (-1021 *9)) (-4 *11 (-1255 *10)) (-5 *2 (-439 *9 *10 *11 *12)) (-5 *1 (-438 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-13 (-435 *10 *11) (-1065 *10)))))) 
+(-10 -7 (-15 -2731 ((-439 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-439 |#1| |#2| |#3| |#4|)))) 
+((-1641 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-2504 ((|#4| (-790) (-1280 |#4|)) 55)) (-3558 (((-141) $) NIL)) (-1448 (((-1280 |#4|) $) 17)) (-2793 ((|#2| $) 53)) (-1847 (($ $) 136)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 98)) (-2312 (($ (-1280 |#4|)) 97)) (-2951 (((-1137) $) NIL)) (-1456 ((|#1| $) 18)) (-2227 (($ $ $) NIL)) (-2131 (($ $ $) NIL)) (-1683 (((-877) $) 131)) (-2195 (((-1280 |#4|) $) 126)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-4257 (($) 11 T CONST)) (-3255 (((-141) $ $) 39)) (-3313 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 119)) (* (($ $ $) 118))) 
+(((-439 |#1| |#2| |#3| |#4|) (-13 (-502) (-10 -8 (-15 -2312 ($ (-1280 |#4|))) (-15 -2195 ((-1280 |#4|) $)) (-15 -2793 (|#2| $)) (-15 -1448 ((-1280 |#4|) $)) (-15 -1456 (|#1| $)) (-15 -1847 ($ $)) (-15 -2504 (|#4| (-790) (-1280 |#4|))))) (-323) (-1021 |#1|) (-1255 |#2|) (-13 (-435 |#2| |#3|) (-1065 |#2|))) (T -439)) 
+((-2312 (*1 *1 *2) (-12 (-5 *2 (-1280 *6)) (-4 *6 (-13 (-435 *4 *5) (-1065 *4))) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-4 *3 (-323)) (-5 *1 (-439 *3 *4 *5 *6)))) (-2195 (*1 *2 *1) (-12 (-4 *3 (-323)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-1280 *6)) (-5 *1 (-439 *3 *4 *5 *6)) (-4 *6 (-13 (-435 *4 *5) (-1065 *4))))) (-2793 (*1 *2 *1) (-12 (-4 *4 (-1255 *2)) (-4 *2 (-1021 *3)) (-5 *1 (-439 *3 *2 *4 *5)) (-4 *3 (-323)) (-4 *5 (-13 (-435 *2 *4) (-1065 *2))))) (-1448 (*1 *2 *1) (-12 (-4 *3 (-323)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-1280 *6)) (-5 *1 (-439 *3 *4 *5 *6)) (-4 *6 (-13 (-435 *4 *5) (-1065 *4))))) (-1456 (*1 *2 *1) (-12 (-4 *3 (-1021 *2)) (-4 *4 (-1255 *3)) (-4 *2 (-323)) (-5 *1 (-439 *2 *3 *4 *5)) (-4 *5 (-13 (-435 *3 *4) (-1065 *3))))) (-1847 (*1 *1 *1) (-12 (-4 *2 (-323)) (-4 *3 (-1021 *2)) (-4 *4 (-1255 *3)) (-5 *1 (-439 *2 *3 *4 *5)) (-4 *5 (-13 (-435 *3 *4) (-1065 *3))))) (-2504 (*1 *2 *3 *4) (-12 (-5 *3 (-790)) (-5 *4 (-1280 *2)) (-4 *5 (-323)) (-4 *6 (-1021 *5)) (-4 *2 (-13 (-435 *6 *7) (-1065 *6))) (-5 *1 (-439 *5 *6 *7 *2)) (-4 *7 (-1255 *6))))) 
+(-13 (-502) (-10 -8 (-15 -2312 ($ (-1280 |#4|))) (-15 -2195 ((-1280 |#4|) $)) (-15 -2793 (|#2| $)) (-15 -1448 ((-1280 |#4|) $)) (-15 -1456 (|#1| $)) (-15 -1847 ($ $)) (-15 -2504 (|#4| (-790) (-1280 |#4|))))) 
+((-1641 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-2793 ((|#2| $) 60)) (-2930 (($ (-1280 |#4|)) 25) (($ (-439 |#1| |#2| |#3| |#4|)) 75 (|has| |#4| (-1065 |#2|)))) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 34)) (-2195 (((-1280 |#4|) $) 26)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-4257 (($) 23 T CONST)) (-3255 (((-141) $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ $ $) 72))) 
+(((-440 |#1| |#2| |#3| |#4| |#5|) (-13 (-743) (-10 -8 (-15 -2195 ((-1280 |#4|) $)) (-15 -2793 (|#2| $)) (-15 -2930 ($ (-1280 |#4|))) (IF (|has| |#4| (-1065 |#2|)) (-15 -2930 ($ (-439 |#1| |#2| |#3| |#4|))) |noBranch|))) (-323) (-1021 |#1|) (-1255 |#2|) (-435 |#2| |#3|) (-1280 |#4|)) (T -440)) 
+((-2195 (*1 *2 *1) (-12 (-4 *3 (-323)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-1280 *6)) (-5 *1 (-440 *3 *4 *5 *6 *7)) (-4 *6 (-435 *4 *5)) (-14 *7 *2))) (-2793 (*1 *2 *1) (-12 (-4 *4 (-1255 *2)) (-4 *2 (-1021 *3)) (-5 *1 (-440 *3 *2 *4 *5 *6)) (-4 *3 (-323)) (-4 *5 (-435 *2 *4)) (-14 *6 (-1280 *5)))) (-2930 (*1 *1 *2) (-12 (-5 *2 (-1280 *6)) (-4 *6 (-435 *4 *5)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-4 *3 (-323)) (-5 *1 (-440 *3 *4 *5 *6 *7)) (-14 *7 *2))) (-2930 (*1 *1 *2) (-12 (-5 *2 (-439 *3 *4 *5 *6)) (-4 *6 (-1065 *4)) (-4 *3 (-323)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-4 *6 (-435 *4 *5)) (-14 *7 (-1280 *6)) (-5 *1 (-440 *3 *4 *5 *6 *7))))) 
+(-13 (-743) (-10 -8 (-15 -2195 ((-1280 |#4|) $)) (-15 -2793 (|#2| $)) (-15 -2930 ($ (-1280 |#4|))) (IF (|has| |#4| (-1065 |#2|)) (-15 -2930 ($ (-439 |#1| |#2| |#3| |#4|))) |noBranch|))) 
+((-2731 ((|#3| (-1 |#4| |#2|) |#1|) 26))) 
+(((-441 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#3| (-1 |#4| |#2|) |#1|))) (-443 |#2|) (-194) (-443 |#4|) (-194)) (T -441)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-194)) (-4 *6 (-194)) (-4 *2 (-443 *6)) (-5 *1 (-441 *4 *5 *2 *6)) (-4 *4 (-443 *5))))) 
+(-10 -7 (-15 -2731 (|#3| (-1 |#4| |#2|) |#1|))) 
+((-4509 (((-3 $ "failed")) 85)) (-4061 (((-1280 (-706 |#2|)) (-1280 $)) NIL) (((-1280 (-706 |#2|))) 90)) (-2604 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) 84)) (-2661 (((-3 $ "failed")) 83)) (-1951 (((-706 |#2|) (-1280 $)) NIL) (((-706 |#2|)) 101)) (-2302 (((-706 |#2|) $ (-1280 $)) NIL) (((-706 |#2|) $) 109)) (-2120 (((-1187 (-980 |#2|))) 54)) (-1874 ((|#2| (-1280 $)) NIL) ((|#2|) 105)) (-1626 (($ (-1280 |#2|) (-1280 $)) NIL) (($ (-1280 |#2|)) 112)) (-1563 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) 82)) (-3994 (((-3 $ "failed")) 74)) (-2794 (((-706 |#2|) (-1280 $)) NIL) (((-706 |#2|)) 99)) (-1802 (((-706 |#2|) $ (-1280 $)) NIL) (((-706 |#2|) $) 107)) (-3004 (((-1187 (-980 |#2|))) 53)) (-3030 ((|#2| (-1280 $)) NIL) ((|#2|) 103)) (-2231 (((-1280 |#2|) $ (-1280 $)) NIL) (((-706 |#2|) (-1280 $) (-1280 $)) NIL) (((-1280 |#2|) $) NIL) (((-706 |#2|) (-1280 $)) 111)) (-1778 (((-1280 |#2|) $) 95) (($ (-1280 |#2|)) 97)) (-1473 (((-658 (-980 |#2|)) (-1280 $)) NIL) (((-658 (-980 |#2|))) 93)) (-4572 (($ (-706 |#2|) $) 89))) 
+(((-442 |#1| |#2|) (-10 -8 (-15 -4572 (|#1| (-706 |#2|) |#1|)) (-15 -2120 ((-1187 (-980 |#2|)))) (-15 -3004 ((-1187 (-980 |#2|)))) (-15 -2302 ((-706 |#2|) |#1|)) (-15 -1802 ((-706 |#2|) |#1|)) (-15 -1951 ((-706 |#2|))) (-15 -2794 ((-706 |#2|))) (-15 -1874 (|#2|)) (-15 -3030 (|#2|)) (-15 -1778 (|#1| (-1280 |#2|))) (-15 -1778 ((-1280 |#2|) |#1|)) (-15 -1626 (|#1| (-1280 |#2|))) (-15 -1473 ((-658 (-980 |#2|)))) (-15 -4061 ((-1280 (-706 |#2|)))) (-15 -2231 ((-706 |#2|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1|)) (-15 -4509 ((-3 |#1| "failed"))) (-15 -2661 ((-3 |#1| "failed"))) (-15 -3994 ((-3 |#1| "failed"))) (-15 -2604 ((-3 (-2 (|:| |particular| |#1|) (|:| -2195 (-658 |#1|))) "failed"))) (-15 -1563 ((-3 (-2 (|:| |particular| |#1|) (|:| -2195 (-658 |#1|))) "failed"))) (-15 -1951 ((-706 |#2|) (-1280 |#1|))) (-15 -2794 ((-706 |#2|) (-1280 |#1|))) (-15 -1874 (|#2| (-1280 |#1|))) (-15 -3030 (|#2| (-1280 |#1|))) (-15 -1626 (|#1| (-1280 |#2|) (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -2302 ((-706 |#2|) |#1| (-1280 |#1|))) (-15 -1802 ((-706 |#2|) |#1| (-1280 |#1|))) (-15 -4061 ((-1280 (-706 |#2|)) (-1280 |#1|))) (-15 -1473 ((-658 (-980 |#2|)) (-1280 |#1|)))) (-443 |#2|) (-194)) (T -442)) 
+((-4061 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-1280 (-706 *4))) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) (-1473 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-658 (-980 *4))) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) (-3030 (*1 *2) (-12 (-4 *2 (-194)) (-5 *1 (-442 *3 *2)) (-4 *3 (-443 *2)))) (-1874 (*1 *2) (-12 (-4 *2 (-194)) (-5 *1 (-442 *3 *2)) (-4 *3 (-443 *2)))) (-2794 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-706 *4)) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) (-1951 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-706 *4)) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) (-3004 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-1187 (-980 *4))) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) (-2120 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-1187 (-980 *4))) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4))))) 
+(-10 -8 (-15 -4572 (|#1| (-706 |#2|) |#1|)) (-15 -2120 ((-1187 (-980 |#2|)))) (-15 -3004 ((-1187 (-980 |#2|)))) (-15 -2302 ((-706 |#2|) |#1|)) (-15 -1802 ((-706 |#2|) |#1|)) (-15 -1951 ((-706 |#2|))) (-15 -2794 ((-706 |#2|))) (-15 -1874 (|#2|)) (-15 -3030 (|#2|)) (-15 -1778 (|#1| (-1280 |#2|))) (-15 -1778 ((-1280 |#2|) |#1|)) (-15 -1626 (|#1| (-1280 |#2|))) (-15 -1473 ((-658 (-980 |#2|)))) (-15 -4061 ((-1280 (-706 |#2|)))) (-15 -2231 ((-706 |#2|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1|)) (-15 -4509 ((-3 |#1| "failed"))) (-15 -2661 ((-3 |#1| "failed"))) (-15 -3994 ((-3 |#1| "failed"))) (-15 -2604 ((-3 (-2 (|:| |particular| |#1|) (|:| -2195 (-658 |#1|))) "failed"))) (-15 -1563 ((-3 (-2 (|:| |particular| |#1|) (|:| -2195 (-658 |#1|))) "failed"))) (-15 -1951 ((-706 |#2|) (-1280 |#1|))) (-15 -2794 ((-706 |#2|) (-1280 |#1|))) (-15 -1874 (|#2| (-1280 |#1|))) (-15 -3030 (|#2| (-1280 |#1|))) (-15 -1626 (|#1| (-1280 |#2|) (-1280 |#1|))) (-15 -2231 ((-706 |#2|) (-1280 |#1|) (-1280 |#1|))) (-15 -2231 ((-1280 |#2|) |#1| (-1280 |#1|))) (-15 -2302 ((-706 |#2|) |#1| (-1280 |#1|))) (-15 -1802 ((-706 |#2|) |#1| (-1280 |#1|))) (-15 -4061 ((-1280 (-706 |#2|)) (-1280 |#1|))) (-15 -1473 ((-658 (-980 |#2|)) (-1280 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4509 (((-3 $ "failed")) 35 (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) 18)) (-4061 (((-1280 (-706 |#1|)) (-1280 $)) 76) (((-1280 (-706 |#1|))) 93)) (-3360 (((-1280 $)) 79)) (-3001 (($) 16 T CONST)) (-2604 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) 38 (|has| |#1| (-582)))) (-2661 (((-3 $ "failed")) 36 (|has| |#1| (-582)))) (-1951 (((-706 |#1|) (-1280 $)) 63) (((-706 |#1|)) 85)) (-4282 ((|#1| $) 72)) (-2302 (((-706 |#1|) $ (-1280 $)) 74) (((-706 |#1|) $) 83)) (-2503 (((-3 $ "failed") $) 43 (|has| |#1| (-582)))) (-2120 (((-1187 (-980 |#1|))) 81 (|has| |#1| (-388)))) (-2111 (($ $ (-944)) 27)) (-1431 ((|#1| $) 70)) (-3916 (((-1187 |#1|) $) 40 (|has| |#1| (-582)))) (-1874 ((|#1| (-1280 $)) 65) ((|#1|) 87)) (-1582 (((-1187 |#1|) $) 61)) (-4194 (((-141)) 55)) (-1626 (($ (-1280 |#1|) (-1280 $)) 67) (($ (-1280 |#1|)) 91)) (-3371 (((-3 $ "failed") $) 45 (|has| |#1| (-582)))) (-4175 (((-944)) 78)) (-2169 (((-141)) 52)) (-1833 (($ $ (-944)) 32)) (-3700 (((-141)) 48)) (-2973 (((-141)) 46)) (-2467 (((-141)) 50)) (-1563 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) 39 (|has| |#1| (-582)))) (-3994 (((-3 $ "failed")) 37 (|has| |#1| (-582)))) (-2794 (((-706 |#1|) (-1280 $)) 64) (((-706 |#1|)) 86)) (-1869 ((|#1| $) 73)) (-1802 (((-706 |#1|) $ (-1280 $)) 75) (((-706 |#1|) $) 84)) (-4158 (((-3 $ "failed") $) 44 (|has| |#1| (-582)))) (-3004 (((-1187 (-980 |#1|))) 82 (|has| |#1| (-388)))) (-2682 (($ $ (-944)) 28)) (-3061 ((|#1| $) 71)) (-2013 (((-1187 |#1|) $) 41 (|has| |#1| (-582)))) (-3030 ((|#1| (-1280 $)) 66) ((|#1|) 88)) (-2397 (((-1187 |#1|) $) 62)) (-3847 (((-141)) 56)) (-2685 (((-1173) $) 9)) (-4106 (((-141)) 47)) (-2339 (((-141)) 49)) (-2297 (((-141)) 51)) (-2951 (((-1137) $) 10)) (-2716 (((-141)) 54)) (-3927 ((|#1| $ (-592)) 94)) (-2231 (((-1280 |#1|) $ (-1280 $)) 69) (((-706 |#1|) (-1280 $) (-1280 $)) 68) (((-1280 |#1|) $) 96) (((-706 |#1|) (-1280 $)) 95)) (-1778 (((-1280 |#1|) $) 90) (($ (-1280 |#1|)) 89)) (-1473 (((-658 (-980 |#1|)) (-1280 $)) 77) (((-658 (-980 |#1|))) 92)) (-2131 (($ $ $) 24)) (-3545 (((-141)) 60)) (-1683 (((-877) $) 11)) (-2195 (((-1280 $)) 97)) (-3664 (((-658 (-1280 |#1|))) 42 (|has| |#1| (-582)))) (-3667 (($ $ $ $) 25)) (-1516 (((-141)) 58)) (-4572 (($ (-706 |#1|) $) 80)) (-2844 (($ $ $) 23)) (-3135 (((-141)) 59)) (-2723 (((-141)) 57)) (-2359 (((-141)) 53)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 29)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
+(((-443 |#1|) (-1311) (-194)) (T -443)) 
+((-2195 (*1 *2) (-12 (-4 *3 (-194)) (-5 *2 (-1280 *1)) (-4 *1 (-443 *3)))) (-2231 (*1 *2 *1) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-1280 *3)))) (-2231 (*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-443 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-443 *2)) (-4 *2 (-194)))) (-4061 (*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-1280 (-706 *3))))) (-1473 (*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-658 (-980 *3))))) (-1626 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-194)) (-4 *1 (-443 *3)))) (-1778 (*1 *2 *1) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-1280 *3)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-194)) (-4 *1 (-443 *3)))) (-3030 (*1 *2) (-12 (-4 *1 (-443 *2)) (-4 *2 (-194)))) (-1874 (*1 *2) (-12 (-4 *1 (-443 *2)) (-4 *2 (-194)))) (-2794 (*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-706 *3)))) (-1951 (*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-706 *3)))) (-1802 (*1 *2 *1) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-706 *3)))) (-2302 (*1 *2 *1) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-706 *3)))) (-3004 (*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-4 *3 (-388)) (-5 *2 (-1187 (-980 *3))))) (-2120 (*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-4 *3 (-388)) (-5 *2 (-1187 (-980 *3))))) (-4572 (*1 *1 *2 *1) (-12 (-5 *2 (-706 *3)) (-4 *1 (-443 *3)) (-4 *3 (-194))))) 
+(-13 (-392 |t#1|) (-10 -8 (-15 -2195 ((-1280 $))) (-15 -2231 ((-1280 |t#1|) $)) (-15 -2231 ((-706 |t#1|) (-1280 $))) (-15 -3927 (|t#1| $ (-592))) (-15 -4061 ((-1280 (-706 |t#1|)))) (-15 -1473 ((-658 (-980 |t#1|)))) (-15 -1626 ($ (-1280 |t#1|))) (-15 -1778 ((-1280 |t#1|) $)) (-15 -1778 ($ (-1280 |t#1|))) (-15 -3030 (|t#1|)) (-15 -1874 (|t#1|)) (-15 -2794 ((-706 |t#1|))) (-15 -1951 ((-706 |t#1|))) (-15 -1802 ((-706 |t#1|) $)) (-15 -2302 ((-706 |t#1|) $)) (IF (|has| |t#1| (-388)) (PROGN (-15 -3004 ((-1187 (-980 |t#1|)))) (-15 -2120 ((-1187 (-980 |t#1|))))) |noBranch|) (-15 -4572 ($ (-706 |t#1|) $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-392 |#1|) . T) ((-661 |#1|) . T) ((-734 |#1|) . T) ((-737) . T) ((-763 |#1|) . T) ((-780) . T) ((-1081 |#1|) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 40)) (-1745 (($ $) 55)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 142)) (-1555 (($ $) NIL)) (-1313 (((-141) $) 34)) (-4509 ((|#1| $) 12)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| |#1| (-1235)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-1235)))) (-2058 (($ |#1| (-592)) 30)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 112)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 53)) (-3371 (((-3 $ "failed") $) 127)) (-4182 (((-3 (-433 (-592)) "failed") $) 61 (|has| |#1| (-574)))) (-2435 (((-141) $) 57 (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) 59 (|has| |#1| (-574)))) (-1919 (($ |#1| (-592)) 32)) (-2802 (((-141) $) 148 (|has| |#1| (-1235)))) (-3558 (((-141) $) 41)) (-3839 (((-790) $) 36)) (-4434 (((-3 "nil" "sqfr" "irred" "prime") $ (-592)) 133)) (-4449 ((|#1| $ (-592)) 132)) (-1972 (((-592) $ (-592)) 131)) (-4427 (($ |#1| (-592)) 29)) (-2731 (($ (-1 |#1| |#1|) $) 139)) (-2788 (($ |#1| (-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-592))))) 56)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-4557 (($ |#1| (-592)) 31)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) 143 (|has| |#1| (-477)))) (-2648 (($ |#1| (-592) (-3 "nil" "sqfr" "irred" "prime")) 28)) (-2033 (((-658 (-2 (|:| -4500 |#1|) (|:| -3215 (-592)))) $) 52)) (-3382 (((-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-592)))) $) 11)) (-4500 (((-444 $) $) NIL (|has| |#1| (-1235)))) (-3616 (((-3 $ "failed") $ $) 134)) (-3215 (((-592) $) 128)) (-3098 ((|#1| $) 54)) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) 76 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) 81 (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) NIL (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) $) NIL (|has| |#1| (-547 (-1191) $))) (($ $ (-658 (-1191)) (-658 $)) 82 (|has| |#1| (-547 (-1191) $))) (($ $ (-658 (-310 $))) 78 (|has| |#1| (-325 $))) (($ $ (-310 $)) NIL (|has| |#1| (-325 $))) (($ $ $ $) NIL (|has| |#1| (-325 $))) (($ $ (-658 $) (-658 $)) NIL (|has| |#1| (-325 $)))) (-3927 (($ $ |#1|) 68 (|has| |#1| (-303 |#1| |#1|))) (($ $ $) 69 (|has| |#1| (-303 $ $)))) (-3644 (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) 138)) (-1778 (((-565) $) 26 (|has| |#1| (-633 (-565)))) (((-405) $) 88 (|has| |#1| (-1049))) (((-237) $) 91 (|has| |#1| (-1049)))) (-1683 (((-877) $) 110) (($ (-592)) 44) (($ $) NIL) (($ |#1|) 43) (($ (-433 (-592))) NIL (|has| |#1| (-1065 (-433 (-592)))))) (-4010 (((-790)) 46)) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 38 T CONST)) (-4257 (($) 37 T CONST)) (-1940 (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3255 (((-141) $ $) 92)) (-3306 (($ $) 124) (($ $ $) NIL)) (-3300 (($ $ $) 136)) (** (($ $ (-944)) NIL) (($ $ (-790)) 98)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 48) (($ $ $) 47) (($ |#1| $) 49) (($ $ |#1|) NIL))) 
+(((-444 |#1|) (-13 (-582) (-245 |#1|) (-43 |#1|) (-358 |#1|) (-437 |#1|) (-10 -8 (-15 -3098 (|#1| $)) (-15 -3215 ((-592) $)) (-15 -2788 ($ |#1| (-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-592)))))) (-15 -3382 ((-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-592)))) $)) (-15 -4427 ($ |#1| (-592))) (-15 -2033 ((-658 (-2 (|:| -4500 |#1|) (|:| -3215 (-592)))) $)) (-15 -4557 ($ |#1| (-592))) (-15 -1972 ((-592) $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -4434 ((-3 "nil" "sqfr" "irred" "prime") $ (-592))) (-15 -3839 ((-790) $)) (-15 -1919 ($ |#1| (-592))) (-15 -2058 ($ |#1| (-592))) (-15 -2648 ($ |#1| (-592) (-3 "nil" "sqfr" "irred" "prime"))) (-15 -4509 (|#1| $)) (-15 -1745 ($ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-477)) (-6 (-477)) |noBranch|) (IF (|has| |#1| (-1049)) (-6 (-1049)) |noBranch|) (IF (|has| |#1| (-1235)) (-6 (-1235)) |noBranch|) (IF (|has| |#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (IF (|has| |#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|) (IF (|has| |#1| (-303 $ $)) (-6 (-303 $ $)) |noBranch|) (IF (|has| |#1| (-325 $)) (-6 (-325 $)) |noBranch|) (IF (|has| |#1| (-547 (-1191) $)) (-6 (-547 (-1191) $)) |noBranch|))) (-582)) (T -444)) 
+((-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-582)) (-5 *1 (-444 *3)))) (-3098 (*1 *2 *1) (-12 (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-3215 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-444 *3)) (-4 *3 (-582)))) (-2788 (*1 *1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (-592))))) (-4 *2 (-582)) (-5 *1 (-444 *2)))) (-3382 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (-592))))) (-5 *1 (-444 *3)) (-4 *3 (-582)))) (-4427 (*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-2033 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| -4500 *3) (|:| -3215 (-592))))) (-5 *1 (-444 *3)) (-4 *3 (-582)))) (-4557 (*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-1972 (*1 *2 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-444 *3)) (-4 *3 (-582)))) (-4449 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-4434 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-444 *4)) (-4 *4 (-582)))) (-3839 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-444 *3)) (-4 *3 (-582)))) (-1919 (*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-2058 (*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-2648 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-592)) (-5 *4 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-4509 (*1 *2 *1) (-12 (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-1745 (*1 *1 *1) (-12 (-5 *1 (-444 *2)) (-4 *2 (-582)))) (-2435 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-444 *3)) (-4 *3 (-574)) (-4 *3 (-582)))) (-2270 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-444 *3)) (-4 *3 (-574)) (-4 *3 (-582)))) (-4182 (*1 *2 *1) (|partial| -12 (-5 *2 (-433 (-592))) (-5 *1 (-444 *3)) (-4 *3 (-574)) (-4 *3 (-582))))) 
+(-13 (-582) (-245 |#1|) (-43 |#1|) (-358 |#1|) (-437 |#1|) (-10 -8 (-15 -3098 (|#1| $)) (-15 -3215 ((-592) $)) (-15 -2788 ($ |#1| (-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-592)))))) (-15 -3382 ((-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-592)))) $)) (-15 -4427 ($ |#1| (-592))) (-15 -2033 ((-658 (-2 (|:| -4500 |#1|) (|:| -3215 (-592)))) $)) (-15 -4557 ($ |#1| (-592))) (-15 -1972 ((-592) $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -4434 ((-3 "nil" "sqfr" "irred" "prime") $ (-592))) (-15 -3839 ((-790) $)) (-15 -1919 ($ |#1| (-592))) (-15 -2058 ($ |#1| (-592))) (-15 -2648 ($ |#1| (-592) (-3 "nil" "sqfr" "irred" "prime"))) (-15 -4509 (|#1| $)) (-15 -1745 ($ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-477)) (-6 (-477)) |noBranch|) (IF (|has| |#1| (-1049)) (-6 (-1049)) |noBranch|) (IF (|has| |#1| (-1235)) (-6 (-1235)) |noBranch|) (IF (|has| |#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (IF (|has| |#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|) (IF (|has| |#1| (-303 $ $)) (-6 (-303 $ $)) |noBranch|) (IF (|has| |#1| (-325 $)) (-6 (-325 $)) |noBranch|) (IF (|has| |#1| (-547 (-1191) $)) (-6 (-547 (-1191) $)) |noBranch|))) 
+((-4028 (((-444 |#1|) (-444 |#1|) (-1 (-444 |#1|) |#1|)) 20)) (-1823 (((-444 |#1|) (-444 |#1|) (-444 |#1|)) 15))) 
+(((-445 |#1|) (-10 -7 (-15 -4028 ((-444 |#1|) (-444 |#1|) (-1 (-444 |#1|) |#1|))) (-15 -1823 ((-444 |#1|) (-444 |#1|) (-444 |#1|)))) (-582)) (T -445)) 
+((-1823 (*1 *2 *2 *2) (-12 (-5 *2 (-444 *3)) (-4 *3 (-582)) (-5 *1 (-445 *3)))) (-4028 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-444 *4) *4)) (-4 *4 (-582)) (-5 *2 (-444 *4)) (-5 *1 (-445 *4))))) 
+(-10 -7 (-15 -4028 ((-444 |#1|) (-444 |#1|) (-1 (-444 |#1|) |#1|))) (-15 -1823 ((-444 |#1|) (-444 |#1|) (-444 |#1|)))) 
+((-4390 ((|#2| |#2|) 160)) (-3786 (((-3 (|:| |%expansion| (-329 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141)) 55))) 
+(((-446 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3786 ((-3 (|:| |%expansion| (-329 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141))) (-15 -4390 (|#2| |#2|))) (-13 (-477) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|)) (-1191) |#2|) (T -446)) 
+((-4390 (*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-446 *3 *2 *4 *5)) (-4 *2 (-13 (-27) (-1211) (-456 *3))) (-14 *4 (-1191)) (-14 *5 *2))) (-3786 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |%expansion| (-329 *5 *3 *6 *7)) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173)))))) (-5 *1 (-446 *5 *3 *6 *7)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-14 *6 (-1191)) (-14 *7 *3)))) 
+(-10 -7 (-15 -3786 ((-3 (|:| |%expansion| (-329 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141))) (-15 -4390 (|#2| |#2|))) 
+((-2731 ((|#4| (-1 |#3| |#1|) |#2|) 11))) 
+(((-447 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#4| (-1 |#3| |#1|) |#2|))) (-13 (-1075) (-869)) (-456 |#1|) (-13 (-1075) (-869)) (-456 |#3|)) (T -447)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-13 (-1075) (-869))) (-4 *6 (-13 (-1075) (-869))) (-4 *2 (-456 *6)) (-5 *1 (-447 *5 *4 *6 *2)) (-4 *4 (-456 *5))))) 
+(-10 -7 (-15 -2731 (|#4| (-1 |#3| |#1|) |#2|))) 
+((-4390 ((|#2| |#2|) 87)) (-4055 (((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141) (-1173)) 46)) (-4002 (((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141) (-1173)) 152))) 
+(((-448 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -4055 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141) (-1173))) (-15 -4002 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141) (-1173))) (-15 -4390 (|#2| |#2|))) (-13 (-477) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|) (-10 -8 (-15 -1683 ($ |#3|)))) (-867) (-13 (-1257 |#2| |#3|) (-388) (-1211) (-10 -8 (-15 -3644 ($ $)) (-15 -3162 ($ $)))) (-1012 |#4|) (-1191)) (T -448)) 
+((-4390 (*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-4 *2 (-13 (-27) (-1211) (-456 *3) (-10 -8 (-15 -1683 ($ *4))))) (-4 *4 (-867)) (-4 *5 (-13 (-1257 *2 *4) (-388) (-1211) (-10 -8 (-15 -3644 ($ $)) (-15 -3162 ($ $))))) (-5 *1 (-448 *3 *2 *4 *5 *6 *7)) (-4 *6 (-1012 *5)) (-14 *7 (-1191)))) (-4002 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-141)) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-4 *3 (-13 (-27) (-1211) (-456 *6) (-10 -8 (-15 -1683 ($ *7))))) (-4 *7 (-867)) (-4 *8 (-13 (-1257 *3 *7) (-388) (-1211) (-10 -8 (-15 -3644 ($ $)) (-15 -3162 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173)))))) (-5 *1 (-448 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1173)) (-4 *9 (-1012 *8)) (-14 *10 (-1191)))) (-4055 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-141)) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-4 *3 (-13 (-27) (-1211) (-456 *6) (-10 -8 (-15 -1683 ($ *7))))) (-4 *7 (-867)) (-4 *8 (-13 (-1257 *3 *7) (-388) (-1211) (-10 -8 (-15 -3644 ($ $)) (-15 -3162 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173)))))) (-5 *1 (-448 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1173)) (-4 *9 (-1012 *8)) (-14 *10 (-1191))))) 
+(-10 -7 (-15 -4055 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141) (-1173))) (-15 -4002 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173))))) |#2| (-141) (-1173))) (-15 -4390 (|#2| |#2|))) 
+((-1779 ((|#4| (-1 |#3| |#1| |#3|) |#2| |#3|) 22)) (-3657 ((|#3| (-1 |#3| |#1| |#3|) |#2| |#3|) 20)) (-2731 ((|#4| (-1 |#3| |#1|) |#2|) 17))) 
+(((-449 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3657 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1779 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) (-1119) (-451 |#1|) (-1119) (-451 |#3|)) (T -449)) 
+((-1779 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1119)) (-4 *5 (-1119)) (-4 *2 (-451 *5)) (-5 *1 (-449 *6 *4 *5 *2)) (-4 *4 (-451 *6)))) (-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1119)) (-4 *2 (-1119)) (-5 *1 (-449 *5 *4 *2 *6)) (-4 *4 (-451 *5)) (-4 *6 (-451 *2)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-451 *6)) (-5 *1 (-449 *5 *4 *6 *2)) (-4 *4 (-451 *5))))) 
+(-10 -7 (-15 -2731 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3657 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1779 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) 
+((-1875 (($) 44)) (-4528 (($ |#2| $) NIL) (($ $ |#2|) NIL) (($ $ $) 40)) (-4471 (($ $ $) 39)) (-2461 (((-141) $ $) 28)) (-1403 (((-790)) 47)) (-2224 (($ (-658 |#2|)) 20) (($) NIL)) (-4290 (($) 53)) (-1837 ((|#2| $) 61)) (-3319 ((|#2| $) 59)) (-3546 (((-944) $) 55)) (-2852 (($ $ $) 35)) (-1825 (($ (-944)) 50)) (-4328 (($ $ |#2|) NIL) (($ $ $) 38)) (-3452 (((-790) (-1 (-141) |#2|) $) NIL) (((-790) |#2| $) 26)) (-4466 (($ (-658 |#2|)) 24)) (-2184 (($ $) 46)) (-1683 (((-877) $) 33)) (-1484 (((-790) $) 21)) (-4586 (($ (-658 |#2|)) 19) (($) NIL)) (-3255 (((-141) $ $) 16)) (-3266 (((-141) $ $) 13))) 
+(((-450 |#1| |#2|) (-10 -8 (-15 -1403 ((-790))) (-15 -1825 (|#1| (-944))) (-15 -3546 ((-944) |#1|)) (-15 -4290 (|#1|)) (-15 -1837 (|#2| |#1|)) (-15 -3319 (|#2| |#1|)) (-15 -1875 (|#1|)) (-15 -2184 (|#1| |#1|)) (-15 -1484 ((-790) |#1|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -4586 (|#1|)) (-15 -4586 (|#1| (-658 |#2|))) (-15 -2224 (|#1|)) (-15 -2224 (|#1| (-658 |#2|))) (-15 -2852 (|#1| |#1| |#1|)) (-15 -4328 (|#1| |#1| |#1|)) (-15 -4328 (|#1| |#1| |#2|)) (-15 -4471 (|#1| |#1| |#1|)) (-15 -2461 ((-141) |#1| |#1|)) (-15 -4528 (|#1| |#1| |#1|)) (-15 -4528 (|#1| |#1| |#2|)) (-15 -4528 (|#1| |#2| |#1|)) (-15 -4466 (|#1| (-658 |#2|))) (-15 -3452 ((-790) |#2| |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|))) (-451 |#2|) (-1119)) (T -450)) 
+((-1403 (*1 *2) (-12 (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-450 *3 *4)) (-4 *3 (-451 *4))))) 
+(-10 -8 (-15 -1403 ((-790))) (-15 -1825 (|#1| (-944))) (-15 -3546 ((-944) |#1|)) (-15 -4290 (|#1|)) (-15 -1837 (|#2| |#1|)) (-15 -3319 (|#2| |#1|)) (-15 -1875 (|#1|)) (-15 -2184 (|#1| |#1|)) (-15 -1484 ((-790) |#1|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -4586 (|#1|)) (-15 -4586 (|#1| (-658 |#2|))) (-15 -2224 (|#1|)) (-15 -2224 (|#1| (-658 |#2|))) (-15 -2852 (|#1| |#1| |#1|)) (-15 -4328 (|#1| |#1| |#1|)) (-15 -4328 (|#1| |#1| |#2|)) (-15 -4471 (|#1| |#1| |#1|)) (-15 -2461 ((-141) |#1| |#1|)) (-15 -4528 (|#1| |#1| |#1|)) (-15 -4528 (|#1| |#1| |#2|)) (-15 -4528 (|#1| |#2| |#1|)) (-15 -4466 (|#1| (-658 |#2|))) (-15 -3452 ((-790) |#2| |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|))) 
+((-1641 (((-141) $ $) 18)) (-1875 (($) 64 (|has| |#1| (-394)))) (-4528 (($ |#1| $) 79) (($ $ |#1|) 78) (($ $ $) 77)) (-4471 (($ $ $) 75)) (-2461 (((-141) $ $) 76)) (-2126 (((-141) $ (-790)) 8)) (-1403 (((-790)) 57 (|has| |#1| (-394)))) (-2224 (($ (-658 |#1|)) 71) (($) 70)) (-4125 (($ (-1 (-141) |#1|) $) 42 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) 52 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1360 (($ $) 55 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ |#1| $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) 43 (|has| $ (-6 -4625)))) (-4459 (($ |#1| $) 54 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 51 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4625)))) (-4290 (($) 60 (|has| |#1| (-394)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-1837 ((|#1| $) 62 (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3319 ((|#1| $) 63 (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-3546 (((-944) $) 59 (|has| |#1| (-394)))) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22)) (-2852 (($ $ $) 72)) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37)) (-1825 (($ (-944)) 58 (|has| |#1| (-394)))) (-2951 (((-1137) $) 21)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 48)) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-1405 (((-658 $)) 61 (|has| |#1| (-394)))) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-4328 (($ $ |#1|) 74) (($ $ $) 73)) (-1653 (($) 46) (($ (-658 |#1|)) 45)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 47)) (-2184 (($ $) 65 (|has| |#1| (-394)))) (-1683 (((-877) $) 20)) (-1484 (((-790) $) 66)) (-4586 (($ (-658 |#1|)) 69) (($) 68)) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19)) (-3266 (((-141) $ $) 67)) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-451 |#1|) (-1311) (-1119)) (T -451)) 
+((-1484 (*1 *2 *1) (-12 (-4 *1 (-451 *3)) (-4 *3 (-1119)) (-5 *2 (-790)))) (-2184 (*1 *1 *1) (-12 (-4 *1 (-451 *2)) (-4 *2 (-1119)) (-4 *2 (-394)))) (-1875 (*1 *1) (-12 (-4 *1 (-451 *2)) (-4 *2 (-394)) (-4 *2 (-1119)))) (-3319 (*1 *2 *1) (-12 (-4 *1 (-451 *2)) (-4 *2 (-1119)) (-4 *2 (-869)))) (-1837 (*1 *2 *1) (-12 (-4 *1 (-451 *2)) (-4 *2 (-1119)) (-4 *2 (-869))))) 
+(-13 (-243 |t#1|) (-1116 |t#1|) (-10 -8 (-6 -4625) (-15 -1484 ((-790) $)) (IF (|has| |t#1| (-394)) (PROGN (-6 (-394)) (-15 -2184 ($ $)) (-15 -1875 ($))) |noBranch|) (IF (|has| |t#1| (-869)) (PROGN (-15 -3319 (|t#1| $)) (-15 -1837 (|t#1| $))) |noBranch|))) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) . T) ((-632 (-877)) . T) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-243 |#1|) . T) ((-249 |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-394) |has| |#1| (-394)) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1116 |#1|) . T) ((-1119) . T) ((-1225) . T)) 
+((-1776 (((-609 |#2|) |#2| (-1191)) 35)) (-2751 (((-609 |#2|) |#2| (-1191)) 19)) (-3586 ((|#2| |#2| (-1191)) 24))) 
+(((-452 |#1| |#2|) (-10 -7 (-15 -2751 ((-609 |#2|) |#2| (-1191))) (-15 -1776 ((-609 |#2|) |#2| (-1191))) (-15 -3586 (|#2| |#2| (-1191)))) (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592))) (-13 (-1211) (-29 |#1|))) (T -452)) 
+((-3586 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-452 *4 *2)) (-4 *2 (-13 (-1211) (-29 *4))))) (-1776 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-452 *5 *3)) (-4 *3 (-13 (-1211) (-29 *5))))) (-2751 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-452 *5 *3)) (-4 *3 (-13 (-1211) (-29 *5)))))) 
+(-10 -7 (-15 -2751 ((-609 |#2|) |#2| (-1191))) (-15 -1776 ((-609 |#2|) |#2| (-1191))) (-15 -3586 (|#2| |#2| (-1191)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-1842 (($ |#2| |#1|) 35)) (-3752 (($ |#2| |#1|) 33)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-351 |#2|)) 25)) (-4010 (((-790)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 10 T CONST)) (-4257 (($) 16 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 34)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 36) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-453 |#1| |#2|) (-13 (-43 |#1|) (-10 -8 (IF (|has| |#2| (-6 -4612)) (IF (|has| |#1| (-6 -4612)) (-6 -4612) |noBranch|) |noBranch|) (-15 -1683 ($ |#1|)) (-15 -1683 ($ (-351 |#2|))) (-15 -1842 ($ |#2| |#1|)) (-15 -3752 ($ |#2| |#1|)))) (-13 (-194) (-43 (-433 (-592)))) (-13 (-869) (-21))) (T -453)) 
+((-1683 (*1 *1 *2) (-12 (-5 *1 (-453 *2 *3)) (-4 *2 (-13 (-194) (-43 (-433 (-592))))) (-4 *3 (-13 (-869) (-21))))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-351 *4)) (-4 *4 (-13 (-869) (-21))) (-5 *1 (-453 *3 *4)) (-4 *3 (-13 (-194) (-43 (-433 (-592))))))) (-1842 (*1 *1 *2 *3) (-12 (-5 *1 (-453 *3 *2)) (-4 *3 (-13 (-194) (-43 (-433 (-592))))) (-4 *2 (-13 (-869) (-21))))) (-3752 (*1 *1 *2 *3) (-12 (-5 *1 (-453 *3 *2)) (-4 *3 (-13 (-194) (-43 (-433 (-592))))) (-4 *2 (-13 (-869) (-21)))))) 
+(-13 (-43 |#1|) (-10 -8 (IF (|has| |#2| (-6 -4612)) (IF (|has| |#1| (-6 -4612)) (-6 -4612) |noBranch|) |noBranch|) (-15 -1683 ($ |#1|)) (-15 -1683 ($ (-351 |#2|))) (-15 -1842 ($ |#2| |#1|)) (-15 -3752 ($ |#2| |#1|)))) 
+((-3162 (((-3 |#2| (-658 |#2|)) |#2| (-1191)) 104))) 
+(((-454 |#1| |#2|) (-10 -7 (-15 -3162 ((-3 |#2| (-658 |#2|)) |#2| (-1191)))) (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592))) (-13 (-1211) (-987) (-29 |#1|))) (T -454)) 
+((-3162 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 *3 (-658 *3))) (-5 *1 (-454 *5 *3)) (-4 *3 (-13 (-1211) (-987) (-29 *5)))))) 
+(-10 -7 (-15 -3162 ((-3 |#2| (-658 |#2|)) |#2| (-1191)))) 
+((-4085 (((-658 (-1191)) $) 72)) (-4492 (((-433 (-1187 $)) $ (-631 $)) 268)) (-3147 (($ $ (-310 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-658 (-631 $)) (-658 $)) 233)) (-4368 (((-3 (-631 $) "failed") $) NIL) (((-3 (-1191) "failed") $) 75) (((-3 (-592) "failed") $) NIL) (((-3 |#2| "failed") $) 229) (((-3 (-433 (-980 |#2|)) "failed") $) 319) (((-3 (-980 |#2|) "failed") $) 231) (((-3 (-433 (-592)) "failed") $) NIL)) (-2400 (((-631 $) $) NIL) (((-1191) $) 30) (((-592) $) NIL) ((|#2| $) 227) (((-433 (-980 |#2|)) $) 300) (((-980 |#2|) $) 228) (((-433 (-592)) $) NIL)) (-2791 (((-143) (-143)) 47)) (-3838 (($ $) 87)) (-4160 (((-3 (-631 $) "failed") $) 224)) (-4486 (((-658 (-631 $)) $) 225)) (-4421 (((-3 (-658 $) "failed") $) 243)) (-2427 (((-3 (-2 (|:| |val| $) (|:| -3215 (-592))) "failed") $) 250)) (-2947 (((-3 (-658 $) "failed") $) 241)) (-1649 (((-3 (-2 (|:| -1487 (-592)) (|:| |var| (-631 $))) "failed") $) 259)) (-2257 (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $) 247) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-143)) 214) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-1191)) 216)) (-4559 (((-141) $) 19)) (-4565 ((|#2| $) 21)) (-2806 (($ $ (-631 $) $) NIL) (($ $ (-658 (-631 $)) (-658 $)) 232) (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) 96) (($ $ (-1191) (-1 $ (-658 $))) NIL) (($ $ (-1191) (-1 $ $)) NIL) (($ $ (-658 (-143)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-143) (-1 $ (-658 $))) NIL) (($ $ (-143) (-1 $ $)) NIL) (($ $ (-1191)) 57) (($ $ (-658 (-1191))) 236) (($ $) 237) (($ $ (-143) $ (-1191)) 60) (($ $ (-658 (-143)) (-658 $) (-1191)) 67) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ $))) 107) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ (-658 $)))) 238) (($ $ (-1191) (-790) (-1 $ (-658 $))) 94) (($ $ (-1191) (-790) (-1 $ $)) 93)) (-3927 (($ (-143) $) NIL) (($ (-143) $ $) NIL) (($ (-143) $ $ $) NIL) (($ (-143) $ $ $ $) NIL) (($ (-143) (-658 $)) 106)) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) 234)) (-2782 (($ $) 279)) (-1778 (((-914 (-592)) $) 253) (((-914 (-405)) $) 256) (($ (-444 $)) 315) (((-565) $) NIL)) (-1683 (((-877) $) 235) (($ (-631 $)) 84) (($ (-1191)) 26) (($ |#2|) NIL) (($ (-1142 |#2| (-631 $))) NIL) (($ (-433 |#2|)) 284) (($ (-980 (-433 |#2|))) 324) (($ (-433 (-980 (-433 |#2|)))) 296) (($ (-433 (-980 |#2|))) 290) (($ $) NIL) (($ (-980 |#2|)) 183) (($ (-433 (-592))) 329) (($ (-592)) NIL)) (-4010 (((-790)) 79)) (-3038 (((-141) (-143)) 41)) (-3270 (($ (-1191) $) 33) (($ (-1191) $ $) 34) (($ (-1191) $ $ $) 35) (($ (-1191) $ $ $ $) 36) (($ (-1191) (-658 $)) 39)) (* (($ (-433 (-592)) $) NIL) (($ $ (-433 (-592))) NIL) (($ |#2| $) 261) (($ $ |#2|) NIL) (($ $ $) NIL) (($ (-592) $) NIL) (($ (-790) $) NIL) (($ (-944) $) NIL))) 
+(((-455 |#1| |#2|) (-10 -8 (-15 * (|#1| (-944) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -4010 ((-790))) (-15 -1683 (|#1| (-592))) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1778 ((-565) |#1|)) (-15 -2400 ((-980 |#2|) |#1|)) (-15 -4368 ((-3 (-980 |#2|) "failed") |#1|)) (-15 -1683 (|#1| (-980 |#2|))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -1683 (|#1| |#1|)) (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 -2400 ((-433 (-980 |#2|)) |#1|)) (-15 -4368 ((-3 (-433 (-980 |#2|)) "failed") |#1|)) (-15 -1683 (|#1| (-433 (-980 |#2|)))) (-15 -4492 ((-433 (-1187 |#1|)) |#1| (-631 |#1|))) (-15 -1683 (|#1| (-433 (-980 (-433 |#2|))))) (-15 -1683 (|#1| (-980 (-433 |#2|)))) (-15 -1683 (|#1| (-433 |#2|))) (-15 -2782 (|#1| |#1|)) (-15 -1778 (|#1| (-444 |#1|))) (-15 -2806 (|#1| |#1| (-1191) (-790) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-1191) (-790) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-790)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-790)) (-658 (-1 |#1| |#1|)))) (-15 -2427 ((-3 (-2 (|:| |val| |#1|) (|:| -3215 (-592))) "failed") |#1|)) (-15 -2257 ((-3 (-2 (|:| |var| (-631 |#1|)) (|:| -3215 (-592))) "failed") |#1| (-1191))) (-15 -2257 ((-3 (-2 (|:| |var| (-631 |#1|)) (|:| -3215 (-592))) "failed") |#1| (-143))) (-15 -3838 (|#1| |#1|)) (-15 -1683 (|#1| (-1142 |#2| (-631 |#1|)))) (-15 -1649 ((-3 (-2 (|:| -1487 (-592)) (|:| |var| (-631 |#1|))) "failed") |#1|)) (-15 -2947 ((-3 (-658 |#1|) "failed") |#1|)) (-15 -2257 ((-3 (-2 (|:| |var| (-631 |#1|)) (|:| -3215 (-592))) "failed") |#1|)) (-15 -4421 ((-3 (-658 |#1|) "failed") |#1|)) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 |#1|) (-1191))) (-15 -2806 (|#1| |#1| (-143) |#1| (-1191))) (-15 -2806 (|#1| |#1|)) (-15 -2806 (|#1| |#1| (-658 (-1191)))) (-15 -2806 (|#1| |#1| (-1191))) (-15 -3270 (|#1| (-1191) (-658 |#1|))) (-15 -3270 (|#1| (-1191) |#1| |#1| |#1| |#1|)) (-15 -3270 (|#1| (-1191) |#1| |#1| |#1|)) (-15 -3270 (|#1| (-1191) |#1| |#1|)) (-15 -3270 (|#1| (-1191) |#1|)) (-15 -4085 ((-658 (-1191)) |#1|)) (-15 -4565 (|#2| |#1|)) (-15 -4559 ((-141) |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -2400 ((-1191) |#1|)) (-15 -4368 ((-3 (-1191) "failed") |#1|)) (-15 -1683 (|#1| (-1191))) (-15 -2806 (|#1| |#1| (-143) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-143) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 (-1 |#1| |#1|)))) (-15 -2806 (|#1| |#1| (-1191) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-1191) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-1 |#1| |#1|)))) (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -4486 ((-658 (-631 |#1|)) |#1|)) (-15 -4160 ((-3 (-631 |#1|) "failed") |#1|)) (-15 -3147 (|#1| |#1| (-658 (-631 |#1|)) (-658 |#1|))) (-15 -3147 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -3147 (|#1| |#1| (-310 |#1|))) (-15 -3927 (|#1| (-143) (-658 |#1|))) (-15 -3927 (|#1| (-143) |#1| |#1| |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1| |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-631 |#1|)) (-658 |#1|))) (-15 -2806 (|#1| |#1| (-631 |#1|) |#1|)) (-15 -2400 ((-631 |#1|) |#1|)) (-15 -4368 ((-3 (-631 |#1|) "failed") |#1|)) (-15 -1683 (|#1| (-631 |#1|))) (-15 -1683 ((-877) |#1|))) (-456 |#2|) (-869)) (T -455)) 
+((-2791 (*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *4 (-869)) (-5 *1 (-455 *3 *4)) (-4 *3 (-456 *4)))) (-3038 (*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-455 *4 *5)) (-4 *4 (-456 *5)))) (-4010 (*1 *2) (-12 (-4 *4 (-869)) (-5 *2 (-790)) (-5 *1 (-455 *3 *4)) (-4 *3 (-456 *4))))) 
+(-10 -8 (-15 * (|#1| (-944) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -4010 ((-790))) (-15 -1683 (|#1| (-592))) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1778 ((-565) |#1|)) (-15 -2400 ((-980 |#2|) |#1|)) (-15 -4368 ((-3 (-980 |#2|) "failed") |#1|)) (-15 -1683 (|#1| (-980 |#2|))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -1683 (|#1| |#1|)) (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 -2400 ((-433 (-980 |#2|)) |#1|)) (-15 -4368 ((-3 (-433 (-980 |#2|)) "failed") |#1|)) (-15 -1683 (|#1| (-433 (-980 |#2|)))) (-15 -4492 ((-433 (-1187 |#1|)) |#1| (-631 |#1|))) (-15 -1683 (|#1| (-433 (-980 (-433 |#2|))))) (-15 -1683 (|#1| (-980 (-433 |#2|)))) (-15 -1683 (|#1| (-433 |#2|))) (-15 -2782 (|#1| |#1|)) (-15 -1778 (|#1| (-444 |#1|))) (-15 -2806 (|#1| |#1| (-1191) (-790) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-1191) (-790) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-790)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-790)) (-658 (-1 |#1| |#1|)))) (-15 -2427 ((-3 (-2 (|:| |val| |#1|) (|:| -3215 (-592))) "failed") |#1|)) (-15 -2257 ((-3 (-2 (|:| |var| (-631 |#1|)) (|:| -3215 (-592))) "failed") |#1| (-1191))) (-15 -2257 ((-3 (-2 (|:| |var| (-631 |#1|)) (|:| -3215 (-592))) "failed") |#1| (-143))) (-15 -3838 (|#1| |#1|)) (-15 -1683 (|#1| (-1142 |#2| (-631 |#1|)))) (-15 -1649 ((-3 (-2 (|:| -1487 (-592)) (|:| |var| (-631 |#1|))) "failed") |#1|)) (-15 -2947 ((-3 (-658 |#1|) "failed") |#1|)) (-15 -2257 ((-3 (-2 (|:| |var| (-631 |#1|)) (|:| -3215 (-592))) "failed") |#1|)) (-15 -4421 ((-3 (-658 |#1|) "failed") |#1|)) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 |#1|) (-1191))) (-15 -2806 (|#1| |#1| (-143) |#1| (-1191))) (-15 -2806 (|#1| |#1|)) (-15 -2806 (|#1| |#1| (-658 (-1191)))) (-15 -2806 (|#1| |#1| (-1191))) (-15 -3270 (|#1| (-1191) (-658 |#1|))) (-15 -3270 (|#1| (-1191) |#1| |#1| |#1| |#1|)) (-15 -3270 (|#1| (-1191) |#1| |#1| |#1|)) (-15 -3270 (|#1| (-1191) |#1| |#1|)) (-15 -3270 (|#1| (-1191) |#1|)) (-15 -4085 ((-658 (-1191)) |#1|)) (-15 -4565 (|#2| |#1|)) (-15 -4559 ((-141) |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -2400 ((-1191) |#1|)) (-15 -4368 ((-3 (-1191) "failed") |#1|)) (-15 -1683 (|#1| (-1191))) (-15 -2806 (|#1| |#1| (-143) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-143) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-143)) (-658 (-1 |#1| |#1|)))) (-15 -2806 (|#1| |#1| (-1191) (-1 |#1| |#1|))) (-15 -2806 (|#1| |#1| (-1191) (-1 |#1| (-658 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-1 |#1| (-658 |#1|))))) (-15 -2806 (|#1| |#1| (-658 (-1191)) (-658 (-1 |#1| |#1|)))) (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -4486 ((-658 (-631 |#1|)) |#1|)) (-15 -4160 ((-3 (-631 |#1|) "failed") |#1|)) (-15 -3147 (|#1| |#1| (-658 (-631 |#1|)) (-658 |#1|))) (-15 -3147 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -3147 (|#1| |#1| (-310 |#1|))) (-15 -3927 (|#1| (-143) (-658 |#1|))) (-15 -3927 (|#1| (-143) |#1| |#1| |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1| |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1| |#1|)) (-15 -3927 (|#1| (-143) |#1|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -2806 (|#1| |#1| (-658 (-631 |#1|)) (-658 |#1|))) (-15 -2806 (|#1| |#1| (-631 |#1|) |#1|)) (-15 -2400 ((-631 |#1|) |#1|)) (-15 -4368 ((-3 (-631 |#1|) "failed") |#1|)) (-15 -1683 (|#1| (-631 |#1|))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 108 (|has| |#1| (-25)))) (-4085 (((-658 (-1191)) $) 195)) (-4492 (((-433 (-1187 $)) $ (-631 $)) 163 (|has| |#1| (-582)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 135 (|has| |#1| (-582)))) (-1555 (($ $) 136 (|has| |#1| (-582)))) (-1313 (((-141) $) 138 (|has| |#1| (-582)))) (-2165 (((-658 (-631 $)) $) 43)) (-2350 (((-3 $ "failed") $ $) 110 (|has| |#1| (-21)))) (-3147 (($ $ (-310 $)) 55) (($ $ (-658 (-310 $))) 54) (($ $ (-658 (-631 $)) (-658 $)) 53)) (-3743 (($ $) 155 (|has| |#1| (-582)))) (-3164 (((-444 $) $) 156 (|has| |#1| (-582)))) (-3652 (((-141) $ $) 146 (|has| |#1| (-582)))) (-3001 (($) 94 (-3836 (|has| |#1| (-1131)) (|has| |#1| (-25))) CONST)) (-4368 (((-3 (-631 $) "failed") $) 68) (((-3 (-1191) "failed") $) 208) (((-3 (-592) "failed") $) 201 (|has| |#1| (-1065 (-592)))) (((-3 |#1| "failed") $) 199) (((-3 (-433 (-980 |#1|)) "failed") $) 161 (|has| |#1| (-582))) (((-3 (-980 |#1|) "failed") $) 115 (|has| |#1| (-1075))) (((-3 (-433 (-592)) "failed") $) 87 (-3836 (-12 (|has| |#1| (-1065 (-592))) (|has| |#1| (-582))) (|has| |#1| (-1065 (-433 (-592))))))) (-2400 (((-631 $) $) 67) (((-1191) $) 207) (((-592) $) 202 (|has| |#1| (-1065 (-592)))) ((|#1| $) 198) (((-433 (-980 |#1|)) $) 160 (|has| |#1| (-582))) (((-980 |#1|) $) 114 (|has| |#1| (-1075))) (((-433 (-592)) $) 86 (-3836 (-12 (|has| |#1| (-1065 (-592))) (|has| |#1| (-582))) (|has| |#1| (-1065 (-433 (-592))))))) (-1586 (($ $ $) 150 (|has| |#1| (-582)))) (-3945 (((-706 (-592)) (-706 $)) 129 (-1732 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 128 (-1732 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 127 (|has| |#1| (-1075))) (((-706 |#1|) (-706 $)) 126 (|has| |#1| (-1075)))) (-3371 (((-3 $ "failed") $) 97 (|has| |#1| (-1131)))) (-1599 (($ $ $) 149 (|has| |#1| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 144 (|has| |#1| (-582)))) (-2802 (((-141) $) 157 (|has| |#1| (-582)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 204 (|has| |#1| (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 203 (|has| |#1| (-908 (-405))))) (-2243 (($ $) 50) (($ (-658 $)) 49)) (-4388 (((-658 (-143)) $) 42)) (-2791 (((-143) (-143)) 41)) (-3558 (((-141) $) 95 (|has| |#1| (-1131)))) (-3372 (((-141) $) 21 (|has| $ (-1065 (-592))))) (-3838 (($ $) 178 (|has| |#1| (-1075)))) (-1448 (((-1142 |#1| (-631 $)) $) 179 (|has| |#1| (-1075)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 153 (|has| |#1| (-582)))) (-2710 (((-1187 $) (-631 $)) 24 (|has| $ (-1075)))) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2731 (($ (-1 $ $) (-631 $)) 35)) (-4160 (((-3 (-631 $) "failed") $) 45)) (-2750 (($ (-658 $)) 142 (|has| |#1| (-582))) (($ $ $) 141 (|has| |#1| (-582)))) (-2685 (((-1173) $) 9)) (-4486 (((-658 (-631 $)) $) 44)) (-1462 (($ (-143) $) 37) (($ (-143) (-658 $)) 36)) (-4421 (((-3 (-658 $) "failed") $) 184 (|has| |#1| (-1131)))) (-2427 (((-3 (-2 (|:| |val| $) (|:| -3215 (-592))) "failed") $) 175 (|has| |#1| (-1075)))) (-2947 (((-3 (-658 $) "failed") $) 182 (|has| |#1| (-25)))) (-1649 (((-3 (-2 (|:| -1487 (-592)) (|:| |var| (-631 $))) "failed") $) 181 (|has| |#1| (-25)))) (-2257 (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $) 183 (|has| |#1| (-1131))) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-143)) 177 (|has| |#1| (-1075))) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-1191)) 176 (|has| |#1| (-1075)))) (-3013 (((-141) $ (-143)) 39) (((-141) $ (-1191)) 38)) (-4552 (($ $) 99 (-3836 (|has| |#1| (-502)) (|has| |#1| (-582))))) (-2535 (((-790) $) 46)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 197)) (-4565 ((|#1| $) 196)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 143 (|has| |#1| (-582)))) (-3548 (($ (-658 $)) 140 (|has| |#1| (-582))) (($ $ $) 139 (|has| |#1| (-582)))) (-1319 (((-141) $ $) 34) (((-141) $ (-1191)) 33)) (-4500 (((-444 $) $) 154 (|has| |#1| (-582)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 152 (|has| |#1| (-582))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 151 (|has| |#1| (-582)))) (-3616 (((-3 $ "failed") $ $) 134 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 145 (|has| |#1| (-582)))) (-3554 (((-141) $) 22 (|has| $ (-1065 (-592))))) (-2806 (($ $ (-631 $) $) 66) (($ $ (-658 (-631 $)) (-658 $)) 65) (($ $ (-658 (-310 $))) 64) (($ $ (-310 $)) 63) (($ $ $ $) 62) (($ $ (-658 $) (-658 $)) 61) (($ $ (-658 (-1191)) (-658 (-1 $ $))) 32) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) 31) (($ $ (-1191) (-1 $ (-658 $))) 30) (($ $ (-1191) (-1 $ $)) 29) (($ $ (-658 (-143)) (-658 (-1 $ $))) 28) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) 27) (($ $ (-143) (-1 $ (-658 $))) 26) (($ $ (-143) (-1 $ $)) 25) (($ $ (-1191)) 189 (|has| |#1| (-633 (-565)))) (($ $ (-658 (-1191))) 188 (|has| |#1| (-633 (-565)))) (($ $) 187 (|has| |#1| (-633 (-565)))) (($ $ (-143) $ (-1191)) 186 (|has| |#1| (-633 (-565)))) (($ $ (-658 (-143)) (-658 $) (-1191)) 185 (|has| |#1| (-633 (-565)))) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ $))) 174 (|has| |#1| (-1075))) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ (-658 $)))) 173 (|has| |#1| (-1075))) (($ $ (-1191) (-790) (-1 $ (-658 $))) 172 (|has| |#1| (-1075))) (($ $ (-1191) (-790) (-1 $ $)) 171 (|has| |#1| (-1075)))) (-2769 (((-790) $) 147 (|has| |#1| (-582)))) (-3927 (($ (-143) $) 60) (($ (-143) $ $) 59) (($ (-143) $ $ $) 58) (($ (-143) $ $ $ $) 57) (($ (-143) (-658 $)) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 148 (|has| |#1| (-582)))) (-2818 (($ $) 48) (($ $ $) 47)) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) 120 (|has| |#1| (-1075))) (($ $ (-1191) (-790)) 119 (|has| |#1| (-1075))) (($ $ (-658 (-1191))) 118 (|has| |#1| (-1075))) (($ $ (-1191)) 117 (|has| |#1| (-1075)))) (-2782 (($ $) 168 (|has| |#1| (-582)))) (-1456 (((-1142 |#1| (-631 $)) $) 169 (|has| |#1| (-582)))) (-3390 (($ $) 23 (|has| $ (-1075)))) (-1778 (((-914 (-592)) $) 206 (|has| |#1| (-633 (-914 (-592))))) (((-914 (-405)) $) 205 (|has| |#1| (-633 (-914 (-405))))) (($ (-444 $)) 170 (|has| |#1| (-582))) (((-565) $) 89 (|has| |#1| (-633 (-565))))) (-2227 (($ $ $) 103 (|has| |#1| (-502)))) (-2131 (($ $ $) 104 (|has| |#1| (-502)))) (-1683 (((-877) $) 11) (($ (-631 $)) 69) (($ (-1191)) 209) (($ |#1|) 200) (($ (-1142 |#1| (-631 $))) 180 (|has| |#1| (-1075))) (($ (-433 |#1|)) 166 (|has| |#1| (-582))) (($ (-980 (-433 |#1|))) 165 (|has| |#1| (-582))) (($ (-433 (-980 (-433 |#1|)))) 164 (|has| |#1| (-582))) (($ (-433 (-980 |#1|))) 162 (|has| |#1| (-582))) (($ $) 133 (|has| |#1| (-582))) (($ (-980 |#1|)) 116 (|has| |#1| (-1075))) (($ (-433 (-592))) 88 (-3836 (|has| |#1| (-582)) (-12 (|has| |#1| (-1065 (-592))) (|has| |#1| (-582))) (|has| |#1| (-1065 (-433 (-592)))))) (($ (-592)) 85 (-3836 (|has| |#1| (-1075)) (|has| |#1| (-1065 (-592)))))) (-1517 (((-3 $ "failed") $) 130 (|has| |#1| (-169)))) (-4010 (((-790)) 125 (|has| |#1| (-1075)))) (-3280 (($ $) 52) (($ (-658 $)) 51)) (-3038 (((-141) (-143)) 40)) (-2537 (((-141) $ $) 137 (|has| |#1| (-582)))) (-3270 (($ (-1191) $) 194) (($ (-1191) $ $) 193) (($ (-1191) $ $ $) 192) (($ (-1191) $ $ $ $) 191) (($ (-1191) (-658 $)) 190)) (-1424 (($ $ (-592)) 102 (-3836 (|has| |#1| (-502)) (|has| |#1| (-582)))) (($ $ (-790)) 96 (|has| |#1| (-1131))) (($ $ (-944)) 92 (|has| |#1| (-1131)))) (-3514 (($) 107 (|has| |#1| (-25)) CONST)) (-4257 (($) 93 (|has| |#1| (-1131)) CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) 124 (|has| |#1| (-1075))) (($ $ (-1191) (-790)) 123 (|has| |#1| (-1075))) (($ $ (-658 (-1191))) 122 (|has| |#1| (-1075))) (($ $ (-1191)) 121 (|has| |#1| (-1075)))) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (-3313 (($ (-1142 |#1| (-631 $)) (-1142 |#1| (-631 $))) 167 (|has| |#1| (-582))) (($ $ $) 100 (-3836 (|has| |#1| (-502)) (|has| |#1| (-582))))) (-3306 (($ $ $) 112 (|has| |#1| (-21))) (($ $) 111 (|has| |#1| (-21)))) (-3300 (($ $ $) 105 (|has| |#1| (-25)))) (** (($ $ (-592)) 101 (-3836 (|has| |#1| (-502)) (|has| |#1| (-582)))) (($ $ (-790)) 98 (|has| |#1| (-1131))) (($ $ (-944)) 91 (|has| |#1| (-1131)))) (* (($ (-433 (-592)) $) 159 (|has| |#1| (-582))) (($ $ (-433 (-592))) 158 (|has| |#1| (-582))) (($ |#1| $) 132 (|has| |#1| (-194))) (($ $ |#1|) 131 (|has| |#1| (-194))) (($ (-592) $) 113 (|has| |#1| (-21))) (($ (-790) $) 109 (|has| |#1| (-25))) (($ (-944) $) 106 (|has| |#1| (-25))) (($ $ $) 90 (|has| |#1| (-1131))))) 
+(((-456 |#1|) (-1311) (-869)) (T -456)) 
+((-4559 (*1 *2 *1) (-12 (-4 *1 (-456 *3)) (-4 *3 (-869)) (-5 *2 (-141)))) (-4565 (*1 *2 *1) (-12 (-4 *1 (-456 *2)) (-4 *2 (-869)))) (-4085 (*1 *2 *1) (-12 (-4 *1 (-456 *3)) (-4 *3 (-869)) (-5 *2 (-658 (-1191))))) (-3270 (*1 *1 *2 *1) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)))) (-3270 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)))) (-3270 (*1 *1 *2 *1 *1 *1) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)))) (-3270 (*1 *1 *2 *1 *1 *1 *1) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)))) (-3270 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-658 *1)) (-4 *1 (-456 *4)) (-4 *4 (-869)))) (-2806 (*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)) (-4 *3 (-633 (-565))))) (-2806 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-1191))) (-4 *1 (-456 *3)) (-4 *3 (-869)) (-4 *3 (-633 (-565))))) (-2806 (*1 *1 *1) (-12 (-4 *1 (-456 *2)) (-4 *2 (-869)) (-4 *2 (-633 (-565))))) (-2806 (*1 *1 *1 *2 *1 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1191)) (-4 *1 (-456 *4)) (-4 *4 (-869)) (-4 *4 (-633 (-565))))) (-2806 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-143))) (-5 *3 (-658 *1)) (-5 *4 (-1191)) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-633 (-565))))) (-4421 (*1 *2 *1) (|partial| -12 (-4 *3 (-1131)) (-4 *3 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-456 *3)))) (-2257 (*1 *2 *1) (|partial| -12 (-4 *3 (-1131)) (-4 *3 (-869)) (-5 *2 (-2 (|:| |var| (-631 *1)) (|:| -3215 (-592)))) (-4 *1 (-456 *3)))) (-2947 (*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-456 *3)))) (-1649 (*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-869)) (-5 *2 (-2 (|:| -1487 (-592)) (|:| |var| (-631 *1)))) (-4 *1 (-456 *3)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1142 *3 (-631 *1))) (-4 *3 (-1075)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) (-1448 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *3 (-869)) (-5 *2 (-1142 *3 (-631 *1))) (-4 *1 (-456 *3)))) (-3838 (*1 *1 *1) (-12 (-4 *1 (-456 *2)) (-4 *2 (-869)) (-4 *2 (-1075)))) (-2257 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-143)) (-4 *4 (-1075)) (-4 *4 (-869)) (-5 *2 (-2 (|:| |var| (-631 *1)) (|:| -3215 (-592)))) (-4 *1 (-456 *4)))) (-2257 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1191)) (-4 *4 (-1075)) (-4 *4 (-869)) (-5 *2 (-2 (|:| |var| (-631 *1)) (|:| -3215 (-592)))) (-4 *1 (-456 *4)))) (-2427 (*1 *2 *1) (|partial| -12 (-4 *3 (-1075)) (-4 *3 (-869)) (-5 *2 (-2 (|:| |val| *1) (|:| -3215 (-592)))) (-4 *1 (-456 *3)))) (-2806 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-658 (-790))) (-5 *4 (-658 (-1 *1 *1))) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-1075)))) (-2806 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-658 (-790))) (-5 *4 (-658 (-1 *1 (-658 *1)))) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-1075)))) (-2806 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-790)) (-5 *4 (-1 *1 (-658 *1))) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-1075)))) (-2806 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-790)) (-5 *4 (-1 *1 *1)) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-1075)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-444 *1)) (-4 *1 (-456 *3)) (-4 *3 (-582)) (-4 *3 (-869)))) (-1456 (*1 *2 *1) (-12 (-4 *3 (-582)) (-4 *3 (-869)) (-5 *2 (-1142 *3 (-631 *1))) (-4 *1 (-456 *3)))) (-2782 (*1 *1 *1) (-12 (-4 *1 (-456 *2)) (-4 *2 (-869)) (-4 *2 (-582)))) (-3313 (*1 *1 *2 *2) (-12 (-5 *2 (-1142 *3 (-631 *1))) (-4 *3 (-582)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-433 *3)) (-4 *3 (-582)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-980 (-433 *3))) (-4 *3 (-582)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-433 *3)))) (-4 *3 (-582)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) (-4492 (*1 *2 *1 *3) (-12 (-5 *3 (-631 *1)) (-4 *1 (-456 *4)) (-4 *4 (-869)) (-4 *4 (-582)) (-5 *2 (-433 (-1187 *1))))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-456 *3)) (-4 *3 (-869)) (-4 *3 (-1131))))) 
+(-13 (-318) (-1065 (-1191)) (-906 |t#1|) (-426 |t#1|) (-437 |t#1|) (-10 -8 (-15 -4559 ((-141) $)) (-15 -4565 (|t#1| $)) (-15 -4085 ((-658 (-1191)) $)) (-15 -3270 ($ (-1191) $)) (-15 -3270 ($ (-1191) $ $)) (-15 -3270 ($ (-1191) $ $ $)) (-15 -3270 ($ (-1191) $ $ $ $)) (-15 -3270 ($ (-1191) (-658 $))) (IF (|has| |t#1| (-633 (-565))) (PROGN (-6 (-633 (-565))) (-15 -2806 ($ $ (-1191))) (-15 -2806 ($ $ (-658 (-1191)))) (-15 -2806 ($ $)) (-15 -2806 ($ $ (-143) $ (-1191))) (-15 -2806 ($ $ (-658 (-143)) (-658 $) (-1191)))) |noBranch|) (IF (|has| |t#1| (-1131)) (PROGN (-6 (-743)) (-15 ** ($ $ (-790))) (-15 -4421 ((-3 (-658 $) "failed") $)) (-15 -2257 ((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $))) |noBranch|) (IF (|has| |t#1| (-502)) (-6 (-502)) |noBranch|) (IF (|has| |t#1| (-25)) (PROGN (-6 (-23)) (-15 -2947 ((-3 (-658 $) "failed") $)) (-15 -1649 ((-3 (-2 (|:| -1487 (-592)) (|:| |var| (-631 $))) "failed") $))) |noBranch|) (IF (|has| |t#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |t#1| (-1075)) (PROGN (-6 (-1075)) (-6 (-1065 (-980 |t#1|))) (-6 (-922 (-1191))) (-6 (-403 |t#1|)) (-15 -1683 ($ (-1142 |t#1| (-631 $)))) (-15 -1448 ((-1142 |t#1| (-631 $)) $)) (-15 -3838 ($ $)) (-15 -2257 ((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-143))) (-15 -2257 ((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-1191))) (-15 -2427 ((-3 (-2 (|:| |val| $) (|:| -3215 (-592))) "failed") $)) (-15 -2806 ($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ $)))) (-15 -2806 ($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ (-658 $))))) (-15 -2806 ($ $ (-1191) (-790) (-1 $ (-658 $)))) (-15 -2806 ($ $ (-1191) (-790) (-1 $ $)))) |noBranch|) (IF (|has| |t#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |t#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |t#1| (-194)) (-6 (-43 |t#1|)) |noBranch|) (IF (|has| |t#1| (-582)) (PROGN (-6 (-388)) (-6 (-1065 (-433 (-980 |t#1|)))) (-15 -1778 ($ (-444 $))) (-15 -1456 ((-1142 |t#1| (-631 $)) $)) (-15 -2782 ($ $)) (-15 -3313 ($ (-1142 |t#1| (-631 $)) (-1142 |t#1| (-631 $)))) (-15 -1683 ($ (-433 |t#1|))) (-15 -1683 ($ (-980 (-433 |t#1|)))) (-15 -1683 ($ (-433 (-980 (-433 |t#1|))))) (-15 -4492 ((-433 (-1187 $)) $ (-631 $))) (IF (|has| |t#1| (-1065 (-592))) (-6 (-1065 (-433 (-592)))) |noBranch|)) |noBranch|))) 
+(((-21) -3836 (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169)) (|has| |#1| (-21))) ((-23) -3836 (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169)) (|has| |#1| (-25)) (|has| |#1| (-21))) ((-25) -3836 (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169)) (|has| |#1| (-25)) (|has| |#1| (-21))) ((-43 (-433 (-592))) |has| |#1| (-582)) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) |has| |#1| (-582)) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-582)) ((-140 |#1| |#1|) |has| |#1| (-194)) ((-140 $ $) |has| |#1| (-582)) ((-158) -3836 (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169)) (|has| |#1| (-21))) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) |has| |#1| (-582)) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-633 (-914 (-405))) |has| |#1| (-633 (-914 (-405)))) ((-633 (-914 (-592))) |has| |#1| (-633 (-914 (-592)))) ((-260) |has| |#1| (-582)) ((-307) |has| |#1| (-582)) ((-323) |has| |#1| (-582)) ((-325 $) . T) ((-318) . T) ((-388) |has| |#1| (-582)) ((-403 |#1|) |has| |#1| (-1075)) ((-426 |#1|) . T) ((-437 |#1|) . T) ((-477) |has| |#1| (-582)) ((-502) |has| |#1| (-502)) ((-547 (-631 $) $) . T) ((-547 $ $) . T) ((-582) |has| |#1| (-582)) ((-661 (-433 (-592))) |has| |#1| (-582)) ((-661 |#1|) |has| |#1| (-194)) ((-661 $) -3836 (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169))) ((-678) |has| |#1| (-582)) ((-654 (-592)) -12 (|has| |#1| (-654 (-592))) (|has| |#1| (-1075))) ((-654 |#1|) |has| |#1| (-1075)) ((-734 (-433 (-592))) |has| |#1| (-582)) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) |has| |#1| (-582)) ((-743) -3836 (|has| |#1| (-1131)) (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-502)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169))) ((-869) . T) ((-922 (-1191)) |has| |#1| (-1075)) ((-908 (-405)) |has| |#1| (-908 (-405))) ((-908 (-592)) |has| |#1| (-908 (-592))) ((-906 |#1|) . T) ((-943) |has| |#1| (-582)) ((-1065 (-433 (-592))) -3836 (|has| |#1| (-1065 (-433 (-592)))) (-12 (|has| |#1| (-582)) (|has| |#1| (-1065 (-592))))) ((-1065 (-433 (-980 |#1|))) |has| |#1| (-582)) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 (-631 $)) . T) ((-1065 (-980 |#1|)) |has| |#1| (-1075)) ((-1065 (-1191)) . T) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) |has| |#1| (-582)) ((-1081 |#1|) |has| |#1| (-194)) ((-1081 $) |has| |#1| (-582)) ((-1075) -3836 (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169))) ((-1082) -3836 (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169))) ((-1131) -3836 (|has| |#1| (-1131)) (|has| |#1| (-1075)) (|has| |#1| (-582)) (|has| |#1| (-502)) (|has| |#1| (-194)) (|has| |#1| (-171)) (|has| |#1| (-169))) ((-1119) . T) ((-1225) . T) ((-1235) |has| |#1| (-582))) 
+((-4018 ((|#2| |#2| |#2|) 33)) (-2791 (((-143) (-143)) 44)) (-3322 ((|#2| (-658 |#2|)) 79)) (-3040 ((|#2| |#2|) 77)) (-3677 ((|#2| |#2|) 68)) (-4511 ((|#2| |#2|) 71)) (-3031 ((|#2| (-658 |#2|)) 75)) (-2677 ((|#2| (-658 |#2|)) 83)) (-1576 ((|#2| (-658 |#2|)) 87)) (-2176 ((|#2| (-658 |#2|)) 81)) (-2487 ((|#2| (-658 |#2|)) 85)) (-3627 ((|#2| |#2|) 91)) (-1631 ((|#2| |#2|) 89)) (-2002 ((|#2| |#2|) 32)) (-2280 ((|#2| |#2| |#2|) 35)) (-2500 ((|#2| |#2| |#2|) 37)) (-3468 ((|#2| |#2| |#2|) 34)) (-2894 ((|#2| |#2| |#2|) 36)) (-3038 (((-141) (-143)) 42)) (-2156 ((|#2| |#2|) 39)) (-3132 ((|#2| |#2|) 38)) (-1392 ((|#2| |#2|) 27)) (-2348 ((|#2| |#2| |#2|) 30) ((|#2| |#2|) 28)) (-2170 ((|#2| |#2| |#2|) 31))) 
+(((-457 |#1| |#2|) (-10 -7 (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -1392 (|#2| |#2|)) (-15 -2348 (|#2| |#2|)) (-15 -2348 (|#2| |#2| |#2|)) (-15 -2170 (|#2| |#2| |#2|)) (-15 -2002 (|#2| |#2|)) (-15 -4018 (|#2| |#2| |#2|)) (-15 -3468 (|#2| |#2| |#2|)) (-15 -2280 (|#2| |#2| |#2|)) (-15 -2894 (|#2| |#2| |#2|)) (-15 -2500 (|#2| |#2| |#2|)) (-15 -3132 (|#2| |#2|)) (-15 -2156 (|#2| |#2|)) (-15 -4511 (|#2| |#2|)) (-15 -3677 (|#2| |#2|)) (-15 -3031 (|#2| (-658 |#2|))) (-15 -3040 (|#2| |#2|)) (-15 -3322 (|#2| (-658 |#2|))) (-15 -2176 (|#2| (-658 |#2|))) (-15 -2677 (|#2| (-658 |#2|))) (-15 -2487 (|#2| (-658 |#2|))) (-15 -1576 (|#2| (-658 |#2|))) (-15 -1631 (|#2| |#2|)) (-15 -3627 (|#2| |#2|))) (-13 (-869) (-582)) (-456 |#1|)) (T -457)) 
+((-3627 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-1631 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-1576 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-2487 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-2677 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-2176 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-3322 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-3040 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-3031 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582))))) (-3677 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-4511 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2156 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-3132 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2500 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2894 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2280 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-3468 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-4018 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2002 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2170 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2348 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2348 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-1392 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) (-2791 (*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *4)) (-4 *4 (-456 *3)))) (-3038 (*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-457 *4 *5)) (-4 *5 (-456 *4))))) 
+(-10 -7 (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -1392 (|#2| |#2|)) (-15 -2348 (|#2| |#2|)) (-15 -2348 (|#2| |#2| |#2|)) (-15 -2170 (|#2| |#2| |#2|)) (-15 -2002 (|#2| |#2|)) (-15 -4018 (|#2| |#2| |#2|)) (-15 -3468 (|#2| |#2| |#2|)) (-15 -2280 (|#2| |#2| |#2|)) (-15 -2894 (|#2| |#2| |#2|)) (-15 -2500 (|#2| |#2| |#2|)) (-15 -3132 (|#2| |#2|)) (-15 -2156 (|#2| |#2|)) (-15 -4511 (|#2| |#2|)) (-15 -3677 (|#2| |#2|)) (-15 -3031 (|#2| (-658 |#2|))) (-15 -3040 (|#2| |#2|)) (-15 -3322 (|#2| (-658 |#2|))) (-15 -2176 (|#2| (-658 |#2|))) (-15 -2677 (|#2| (-658 |#2|))) (-15 -2487 (|#2| (-658 |#2|))) (-15 -1576 (|#2| (-658 |#2|))) (-15 -1631 (|#2| |#2|)) (-15 -3627 (|#2| |#2|))) 
+((-2667 (((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1187 |#2|)) (|:| |pol2| (-1187 |#2|)) (|:| |prim| (-1187 |#2|))) |#2| |#2|) 93 (|has| |#2| (-27))) (((-2 (|:| |primelt| |#2|) (|:| |poly| (-658 (-1187 |#2|))) (|:| |prim| (-1187 |#2|))) (-658 |#2|)) 58))) 
+(((-458 |#1| |#2|) (-10 -7 (-15 -2667 ((-2 (|:| |primelt| |#2|) (|:| |poly| (-658 (-1187 |#2|))) (|:| |prim| (-1187 |#2|))) (-658 |#2|))) (IF (|has| |#2| (-27)) (-15 -2667 ((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1187 |#2|)) (|:| |pol2| (-1187 |#2|)) (|:| |prim| (-1187 |#2|))) |#2| |#2|)) |noBranch|)) (-13 (-582) (-869) (-171)) (-456 |#1|)) (T -458)) 
+((-2667 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-582) (-869) (-171))) (-5 *2 (-2 (|:| |primelt| *3) (|:| |pol1| (-1187 *3)) (|:| |pol2| (-1187 *3)) (|:| |prim| (-1187 *3)))) (-5 *1 (-458 *4 *3)) (-4 *3 (-27)) (-4 *3 (-456 *4)))) (-2667 (*1 *2 *3) (-12 (-5 *3 (-658 *5)) (-4 *5 (-456 *4)) (-4 *4 (-13 (-582) (-869) (-171))) (-5 *2 (-2 (|:| |primelt| *5) (|:| |poly| (-658 (-1187 *5))) (|:| |prim| (-1187 *5)))) (-5 *1 (-458 *4 *5))))) 
+(-10 -7 (-15 -2667 ((-2 (|:| |primelt| |#2|) (|:| |poly| (-658 (-1187 |#2|))) (|:| |prim| (-1187 |#2|))) (-658 |#2|))) (IF (|has| |#2| (-27)) (-15 -2667 ((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1187 |#2|)) (|:| |pol2| (-1187 |#2|)) (|:| |prim| (-1187 |#2|))) |#2| |#2|)) |noBranch|)) 
+((-2931 (((-1285)) 18)) (-2516 (((-1187 (-433 (-592))) |#2| (-631 |#2|)) 40) (((-433 (-592)) |#2|) 23))) 
+(((-459 |#1| |#2|) (-10 -7 (-15 -2516 ((-433 (-592)) |#2|)) (-15 -2516 ((-1187 (-433 (-592))) |#2| (-631 |#2|))) (-15 -2931 ((-1285)))) (-13 (-869) (-582) (-1065 (-592))) (-456 |#1|)) (T -459)) 
+((-2931 (*1 *2) (-12 (-4 *3 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-1285)) (-5 *1 (-459 *3 *4)) (-4 *4 (-456 *3)))) (-2516 (*1 *2 *3 *4) (-12 (-5 *4 (-631 *3)) (-4 *3 (-456 *5)) (-4 *5 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-1187 (-433 (-592)))) (-5 *1 (-459 *5 *3)))) (-2516 (*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-433 (-592))) (-5 *1 (-459 *4 *3)) (-4 *3 (-456 *4))))) 
+(-10 -7 (-15 -2516 ((-433 (-592)) |#2|)) (-15 -2516 ((-1187 (-433 (-592))) |#2| (-631 |#2|))) (-15 -2931 ((-1285)))) 
+((-2952 (((-141) $) 28)) (-3632 (((-141) $) 30)) (-4277 (((-141) $) 31)) (-1438 (((-141) $) 34)) (-3077 (((-141) $) 29)) (-1341 (((-141) $) 33)) (-1683 (((-877) $) 18) (($ (-1173)) 27) (($ (-1191)) 23) (((-1191) $) 22) (((-1123) $) 21)) (-3444 (((-141) $) 32)) (-3255 (((-141) $ $) 15))) 
+(((-460) (-13 (-632 (-877)) (-10 -8 (-15 -1683 ($ (-1173))) (-15 -1683 ($ (-1191))) (-15 -1683 ((-1191) $)) (-15 -1683 ((-1123) $)) (-15 -2952 ((-141) $)) (-15 -3077 ((-141) $)) (-15 -4277 ((-141) $)) (-15 -1341 ((-141) $)) (-15 -1438 ((-141) $)) (-15 -3444 ((-141) $)) (-15 -3632 ((-141) $)) (-15 -3255 ((-141) $ $))))) (T -460)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-460)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-460)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-460)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1123)) (-5 *1 (-460)))) (-2952 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) (-3077 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) (-4277 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) (-1341 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) (-1438 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) (-3444 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) (-3632 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) (-3255 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460))))) 
+(-13 (-632 (-877)) (-10 -8 (-15 -1683 ($ (-1173))) (-15 -1683 ($ (-1191))) (-15 -1683 ((-1191) $)) (-15 -1683 ((-1123) $)) (-15 -2952 ((-141) $)) (-15 -3077 ((-141) $)) (-15 -4277 ((-141) $)) (-15 -1341 ((-141) $)) (-15 -1438 ((-141) $)) (-15 -3444 ((-141) $)) (-15 -3632 ((-141) $)) (-15 -3255 ((-141) $ $)))) 
+((-2963 (((-3 (-444 (-1187 (-433 (-592)))) "failed") |#3|) 68)) (-2024 (((-444 |#3|) |#3|) 33)) (-2730 (((-3 (-444 (-1187 (-53))) "failed") |#3|) 27 (|has| |#2| (-1065 (-53))))) (-2786 (((-3 (|:| |overq| (-1187 (-433 (-592)))) (|:| |overan| (-1187 (-53))) (|:| -3550 (-141))) |#3|) 35))) 
+(((-461 |#1| |#2| |#3|) (-10 -7 (-15 -2024 ((-444 |#3|) |#3|)) (-15 -2963 ((-3 (-444 (-1187 (-433 (-592)))) "failed") |#3|)) (-15 -2786 ((-3 (|:| |overq| (-1187 (-433 (-592)))) (|:| |overan| (-1187 (-53))) (|:| -3550 (-141))) |#3|)) (IF (|has| |#2| (-1065 (-53))) (-15 -2730 ((-3 (-444 (-1187 (-53))) "failed") |#3|)) |noBranch|)) (-13 (-582) (-869) (-1065 (-592))) (-456 |#1|) (-1255 |#2|)) (T -461)) 
+((-2730 (*1 *2 *3) (|partial| -12 (-4 *5 (-1065 (-53))) (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-4 *5 (-456 *4)) (-5 *2 (-444 (-1187 (-53)))) (-5 *1 (-461 *4 *5 *3)) (-4 *3 (-1255 *5)))) (-2786 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-4 *5 (-456 *4)) (-5 *2 (-3 (|:| |overq| (-1187 (-433 (-592)))) (|:| |overan| (-1187 (-53))) (|:| -3550 (-141)))) (-5 *1 (-461 *4 *5 *3)) (-4 *3 (-1255 *5)))) (-2963 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-4 *5 (-456 *4)) (-5 *2 (-444 (-1187 (-433 (-592))))) (-5 *1 (-461 *4 *5 *3)) (-4 *3 (-1255 *5)))) (-2024 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-4 *5 (-456 *4)) (-5 *2 (-444 *3)) (-5 *1 (-461 *4 *5 *3)) (-4 *3 (-1255 *5))))) 
+(-10 -7 (-15 -2024 ((-444 |#3|) |#3|)) (-15 -2963 ((-3 (-444 (-1187 (-433 (-592)))) "failed") |#3|)) (-15 -2786 ((-3 (|:| |overq| (-1187 (-433 (-592)))) (|:| |overan| (-1187 (-53))) (|:| -3550 (-141))) |#3|)) (IF (|has| |#2| (-1065 (-53))) (-15 -2730 ((-3 (-444 (-1187 (-53))) "failed") |#3|)) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-3388 (((-1173) $ (-1173)) NIL)) (-2820 (($ $ (-1173)) NIL)) (-4393 (((-1173) $) NIL)) (-1635 (((-414) (-414) (-414)) 17) (((-414) (-414)) 15)) (-1774 (($ (-414)) NIL) (($ (-414) (-1173)) NIL)) (-4095 (((-414) $) NIL)) (-2685 (((-1173) $) NIL)) (-2690 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1334 (((-1285) (-1173)) 9)) (-3483 (((-1285) (-1173)) 10)) (-1798 (((-1285)) 11)) (-4342 (((-1285) $) NIL)) (-1683 (((-877) $) NIL)) (-2607 (($ $) 34)) (-3255 (((-141) $ $) NIL))) 
+(((-462) (-13 (-389 (-414) (-1173)) (-10 -7 (-15 -1635 ((-414) (-414) (-414))) (-15 -1635 ((-414) (-414))) (-15 -1334 ((-1285) (-1173))) (-15 -3483 ((-1285) (-1173))) (-15 -1798 ((-1285)))))) (T -462)) 
+((-1635 (*1 *2 *2 *2) (-12 (-5 *2 (-414)) (-5 *1 (-462)))) (-1635 (*1 *2 *2) (-12 (-5 *2 (-414)) (-5 *1 (-462)))) (-1334 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-462)))) (-3483 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-462)))) (-1798 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-462))))) 
+(-13 (-389 (-414) (-1173)) (-10 -7 (-15 -1635 ((-414) (-414) (-414))) (-15 -1635 ((-414) (-414))) (-15 -1334 ((-1285) (-1173))) (-15 -3483 ((-1285) (-1173))) (-15 -1798 ((-1285))))) 
+((-1641 (((-141) $ $) NIL)) (-2351 (((-3 (|:| |fst| (-460)) (|:| -4191 "void")) $) 10)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3261 (($) 31)) (-2555 (($) 37)) (-3467 (($) 33)) (-3361 (($) 35)) (-2662 (($) 32)) (-3049 (($) 34)) (-2502 (($) 36)) (-2291 (((-141) $) 8)) (-1407 (((-658 (-980 (-592))) $) 16)) (-4466 (($ (-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-658 (-1191)) (-141)) 25) (($ (-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-658 (-980 (-592))) (-141)) 26)) (-1683 (((-877) $) 21) (($ (-460)) 28)) (-3255 (((-141) $ $) NIL))) 
+(((-463) (-13 (-1119) (-10 -8 (-15 -1683 ((-877) $)) (-15 -1683 ($ (-460))) (-15 -2351 ((-3 (|:| |fst| (-460)) (|:| -4191 "void")) $)) (-15 -1407 ((-658 (-980 (-592))) $)) (-15 -2291 ((-141) $)) (-15 -4466 ($ (-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-658 (-1191)) (-141))) (-15 -4466 ($ (-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-658 (-980 (-592))) (-141))) (-15 -3261 ($)) (-15 -2662 ($)) (-15 -3467 ($)) (-15 -2555 ($)) (-15 -3049 ($)) (-15 -3361 ($)) (-15 -2502 ($))))) (T -463)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-463)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-460)) (-5 *1 (-463)))) (-2351 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *1 (-463)))) (-1407 (*1 *2 *1) (-12 (-5 *2 (-658 (-980 (-592)))) (-5 *1 (-463)))) (-2291 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-463)))) (-4466 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *3 (-658 (-1191))) (-5 *4 (-141)) (-5 *1 (-463)))) (-4466 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-141)) (-5 *1 (-463)))) (-3261 (*1 *1) (-5 *1 (-463))) (-2662 (*1 *1) (-5 *1 (-463))) (-3467 (*1 *1) (-5 *1 (-463))) (-2555 (*1 *1) (-5 *1 (-463))) (-3049 (*1 *1) (-5 *1 (-463))) (-3361 (*1 *1) (-5 *1 (-463))) (-2502 (*1 *1) (-5 *1 (-463)))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ((-877) $)) (-15 -1683 ($ (-460))) (-15 -2351 ((-3 (|:| |fst| (-460)) (|:| -4191 "void")) $)) (-15 -1407 ((-658 (-980 (-592))) $)) (-15 -2291 ((-141) $)) (-15 -4466 ($ (-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-658 (-1191)) (-141))) (-15 -4466 ($ (-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-658 (-980 (-592))) (-141))) (-15 -3261 ($)) (-15 -2662 ($)) (-15 -3467 ($)) (-15 -2555 ($)) (-15 -3049 ($)) (-15 -3361 ($)) (-15 -2502 ($)))) 
+((-1641 (((-141) $ $) NIL)) (-4095 (((-1191) $) 8)) (-2685 (((-1173) $) 16)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 13))) 
+(((-464 |#1|) (-13 (-1119) (-10 -8 (-15 -4095 ((-1191) $)))) (-1191)) (T -464)) 
+((-4095 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-464 *3)) (-14 *3 *2)))) 
+(-13 (-1119) (-10 -8 (-15 -4095 ((-1191) $)))) 
+((-3592 (((-1285) $) 7)) (-1683 (((-877) $) 8) (($ (-1280 (-715))) 12) (($ (-658 (-350))) 11) (($ (-350)) 10) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 9))) 
+(((-465) (-1311)) (T -465)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-715))) (-4 *1 (-465)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-465)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-465)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-465))))) 
+(-13 (-421) (-10 -8 (-15 -1683 ($ (-1280 (-715)))) (-15 -1683 ($ (-658 (-350)))) (-15 -1683 ($ (-350))) (-15 -1683 ($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350)))))))) 
+(((-632 (-877)) . T) ((-421) . T) ((-1225) . T)) 
+((-4368 (((-3 $ "failed") (-1280 (-332 (-405)))) 19) (((-3 $ "failed") (-1280 (-332 (-592)))) 17) (((-3 $ "failed") (-1280 (-980 (-405)))) 15) (((-3 $ "failed") (-1280 (-980 (-592)))) 13) (((-3 $ "failed") (-1280 (-433 (-980 (-405))))) 11) (((-3 $ "failed") (-1280 (-433 (-980 (-592))))) 9)) (-2400 (($ (-1280 (-332 (-405)))) 20) (($ (-1280 (-332 (-592)))) 18) (($ (-1280 (-980 (-405)))) 16) (($ (-1280 (-980 (-592)))) 14) (($ (-1280 (-433 (-980 (-405))))) 12) (($ (-1280 (-433 (-980 (-592))))) 10)) (-3592 (((-1285) $) 7)) (-1683 (((-877) $) 8) (($ (-658 (-350))) 23) (($ (-350)) 22) (($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) 21))) 
+(((-466) (-1311)) (T -466)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-466)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-466)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-466)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-1280 (-332 (-405)))) (-4 *1 (-466)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-332 (-405)))) (-4 *1 (-466)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-1280 (-332 (-592)))) (-4 *1 (-466)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-332 (-592)))) (-4 *1 (-466)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-1280 (-980 (-405)))) (-4 *1 (-466)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-980 (-405)))) (-4 *1 (-466)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-1280 (-980 (-592)))) (-4 *1 (-466)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-980 (-592)))) (-4 *1 (-466)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-1280 (-433 (-980 (-405))))) (-4 *1 (-466)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-433 (-980 (-405))))) (-4 *1 (-466)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-1280 (-433 (-980 (-592))))) (-4 *1 (-466)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-433 (-980 (-592))))) (-4 *1 (-466))))) 
+(-13 (-421) (-10 -8 (-15 -1683 ($ (-658 (-350)))) (-15 -1683 ($ (-350))) (-15 -1683 ($ (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350)))))) (-15 -2400 ($ (-1280 (-332 (-405))))) (-15 -4368 ((-3 $ "failed") (-1280 (-332 (-405))))) (-15 -2400 ($ (-1280 (-332 (-592))))) (-15 -4368 ((-3 $ "failed") (-1280 (-332 (-592))))) (-15 -2400 ($ (-1280 (-980 (-405))))) (-15 -4368 ((-3 $ "failed") (-1280 (-980 (-405))))) (-15 -2400 ($ (-1280 (-980 (-592))))) (-15 -4368 ((-3 $ "failed") (-1280 (-980 (-592))))) (-15 -2400 ($ (-1280 (-433 (-980 (-405)))))) (-15 -4368 ((-3 $ "failed") (-1280 (-433 (-980 (-405)))))) (-15 -2400 ($ (-1280 (-433 (-980 (-592)))))) (-15 -4368 ((-3 $ "failed") (-1280 (-433 (-980 (-592)))))))) 
+(((-632 (-877)) . T) ((-421) . T) ((-1225) . T)) 
+((-4384 (((-141)) 17)) (-2832 (((-141) (-141)) 18)) (-3535 (((-141)) 13)) (-2259 (((-141) (-141)) 14)) (-1789 (((-141)) 15)) (-1786 (((-141) (-141)) 16)) (-4310 (((-944) (-944)) 21) (((-944)) 20)) (-3839 (((-790) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592))))) 41)) (-3414 (((-944) (-944)) 23) (((-944)) 22)) (-4251 (((-2 (|:| -1644 (-592)) (|:| -2033 (-658 |#1|))) |#1|) 61)) (-2788 (((-444 |#1|) (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592))))))) 125)) (-2112 (((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141)) 151)) (-3082 (((-444 |#1|) |#1| (-790) (-790)) 164) (((-444 |#1|) |#1| (-658 (-790)) (-790)) 161) (((-444 |#1|) |#1| (-658 (-790))) 163) (((-444 |#1|) |#1| (-790)) 162) (((-444 |#1|) |#1|) 160)) (-4072 (((-3 |#1| "failed") (-944) |#1| (-658 (-790)) (-790) (-141)) 166) (((-3 |#1| "failed") (-944) |#1| (-658 (-790)) (-790)) 167) (((-3 |#1| "failed") (-944) |#1| (-658 (-790))) 169) (((-3 |#1| "failed") (-944) |#1| (-790)) 168) (((-3 |#1| "failed") (-944) |#1|) 170)) (-4500 (((-444 |#1|) |#1| (-790) (-790)) 159) (((-444 |#1|) |#1| (-658 (-790)) (-790)) 155) (((-444 |#1|) |#1| (-658 (-790))) 157) (((-444 |#1|) |#1| (-790)) 156) (((-444 |#1|) |#1|) 154)) (-1560 (((-141) |#1|) 36)) (-3363 (((-754 (-790)) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592))))) 66)) (-4144 (((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141) (-1121 (-790)) (-790)) 153))) 
+(((-467 |#1|) (-10 -7 (-15 -2788 ((-444 |#1|) (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))))) (-15 -3363 ((-754 (-790)) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))))) (-15 -3414 ((-944))) (-15 -3414 ((-944) (-944))) (-15 -4310 ((-944))) (-15 -4310 ((-944) (-944))) (-15 -3839 ((-790) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))))) (-15 -4251 ((-2 (|:| -1644 (-592)) (|:| -2033 (-658 |#1|))) |#1|)) (-15 -4384 ((-141))) (-15 -2832 ((-141) (-141))) (-15 -3535 ((-141))) (-15 -2259 ((-141) (-141))) (-15 -1560 ((-141) |#1|)) (-15 -1789 ((-141))) (-15 -1786 ((-141) (-141))) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -4500 ((-444 |#1|) |#1| (-790))) (-15 -4500 ((-444 |#1|) |#1| (-658 (-790)))) (-15 -4500 ((-444 |#1|) |#1| (-658 (-790)) (-790))) (-15 -4500 ((-444 |#1|) |#1| (-790) (-790))) (-15 -3082 ((-444 |#1|) |#1|)) (-15 -3082 ((-444 |#1|) |#1| (-790))) (-15 -3082 ((-444 |#1|) |#1| (-658 (-790)))) (-15 -3082 ((-444 |#1|) |#1| (-658 (-790)) (-790))) (-15 -3082 ((-444 |#1|) |#1| (-790) (-790))) (-15 -4072 ((-3 |#1| "failed") (-944) |#1|)) (-15 -4072 ((-3 |#1| "failed") (-944) |#1| (-790))) (-15 -4072 ((-3 |#1| "failed") (-944) |#1| (-658 (-790)))) (-15 -4072 ((-3 |#1| "failed") (-944) |#1| (-658 (-790)) (-790))) (-15 -4072 ((-3 |#1| "failed") (-944) |#1| (-658 (-790)) (-790) (-141))) (-15 -2112 ((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141))) (-15 -4144 ((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141) (-1121 (-790)) (-790)))) (-1255 (-592))) (T -467)) 
+((-4144 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-141)) (-5 *5 (-1121 (-790))) (-5 *6 (-790)) (-5 *2 (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| *3) (|:| -1777 (-592))))))) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-2112 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-5 *2 (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| *3) (|:| -1777 (-592))))))) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4072 (*1 *2 *3 *2 *4 *5 *6) (|partial| -12 (-5 *3 (-944)) (-5 *4 (-658 (-790))) (-5 *5 (-790)) (-5 *6 (-141)) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) (-4072 (*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *3 (-944)) (-5 *4 (-658 (-790))) (-5 *5 (-790)) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) (-4072 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-944)) (-5 *4 (-658 (-790))) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) (-4072 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-944)) (-5 *4 (-790)) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) (-4072 (*1 *2 *3 *2) (|partial| -12 (-5 *3 (-944)) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) (-3082 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3082 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-790))) (-5 *5 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3082 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-790))) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3082 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3082 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4500 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4500 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-790))) (-5 *5 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-790))) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4500 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-1786 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-1789 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-1560 (*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-2259 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3535 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-2832 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4384 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4251 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| -1644 (-592)) (|:| -2033 (-658 *3)))) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3839 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4500 *4) (|:| -4525 (-592))))) (-4 *4 (-1255 (-592))) (-5 *2 (-790)) (-5 *1 (-467 *4)))) (-4310 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-4310 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3414 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3414 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) (-3363 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4500 *4) (|:| -4525 (-592))))) (-4 *4 (-1255 (-592))) (-5 *2 (-754 (-790))) (-5 *1 (-467 *4)))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| *4) (|:| -1777 (-592))))))) (-4 *4 (-1255 (-592))) (-5 *2 (-444 *4)) (-5 *1 (-467 *4))))) 
+(-10 -7 (-15 -2788 ((-444 |#1|) (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))))) (-15 -3363 ((-754 (-790)) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))))) (-15 -3414 ((-944))) (-15 -3414 ((-944) (-944))) (-15 -4310 ((-944))) (-15 -4310 ((-944) (-944))) (-15 -3839 ((-790) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))))) (-15 -4251 ((-2 (|:| -1644 (-592)) (|:| -2033 (-658 |#1|))) |#1|)) (-15 -4384 ((-141))) (-15 -2832 ((-141) (-141))) (-15 -3535 ((-141))) (-15 -2259 ((-141) (-141))) (-15 -1560 ((-141) |#1|)) (-15 -1789 ((-141))) (-15 -1786 ((-141) (-141))) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -4500 ((-444 |#1|) |#1| (-790))) (-15 -4500 ((-444 |#1|) |#1| (-658 (-790)))) (-15 -4500 ((-444 |#1|) |#1| (-658 (-790)) (-790))) (-15 -4500 ((-444 |#1|) |#1| (-790) (-790))) (-15 -3082 ((-444 |#1|) |#1|)) (-15 -3082 ((-444 |#1|) |#1| (-790))) (-15 -3082 ((-444 |#1|) |#1| (-658 (-790)))) (-15 -3082 ((-444 |#1|) |#1| (-658 (-790)) (-790))) (-15 -3082 ((-444 |#1|) |#1| (-790) (-790))) (-15 -4072 ((-3 |#1| "failed") (-944) |#1|)) (-15 -4072 ((-3 |#1| "failed") (-944) |#1| (-790))) (-15 -4072 ((-3 |#1| "failed") (-944) |#1| (-658 (-790)))) (-15 -4072 ((-3 |#1| "failed") (-944) |#1| (-658 (-790)) (-790))) (-15 -4072 ((-3 |#1| "failed") (-944) |#1| (-658 (-790)) (-790) (-141))) (-15 -2112 ((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141))) (-15 -4144 ((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141) (-1121 (-790)) (-790)))) 
+((-2157 (((-592) |#2|) 48) (((-592) |#2| (-790)) 47)) (-3387 (((-592) |#2|) 55)) (-4555 ((|#3| |#2|) 25)) (-2793 ((|#3| |#2| (-944)) 14)) (-4233 ((|#3| |#2|) 15)) (-2086 ((|#3| |#2|) 9)) (-2535 ((|#3| |#2|) 10)) (-3897 ((|#3| |#2| (-944)) 62) ((|#3| |#2|) 30)) (-2338 (((-592) |#2|) 57))) 
+(((-468 |#1| |#2| |#3|) (-10 -7 (-15 -2338 ((-592) |#2|)) (-15 -3897 (|#3| |#2|)) (-15 -3897 (|#3| |#2| (-944))) (-15 -3387 ((-592) |#2|)) (-15 -2157 ((-592) |#2| (-790))) (-15 -2157 ((-592) |#2|)) (-15 -2793 (|#3| |#2| (-944))) (-15 -4555 (|#3| |#2|)) (-15 -2086 (|#3| |#2|)) (-15 -2535 (|#3| |#2|)) (-15 -4233 (|#3| |#2|))) (-1075) (-1255 |#1|) (-13 (-430) (-1065 |#1|) (-388) (-1211) (-301))) (T -468)) 
+((-4233 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4)))) (-2535 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4)))) (-2086 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4)))) (-4555 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4)))) (-2793 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *2 (-13 (-430) (-1065 *5) (-388) (-1211) (-301))) (-5 *1 (-468 *5 *3 *2)) (-4 *3 (-1255 *5)))) (-2157 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-468 *4 *3 *5)) (-4 *3 (-1255 *4)) (-4 *5 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))))) (-2157 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-1075)) (-5 *2 (-592)) (-5 *1 (-468 *5 *3 *6)) (-4 *3 (-1255 *5)) (-4 *6 (-13 (-430) (-1065 *5) (-388) (-1211) (-301))))) (-3387 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-468 *4 *3 *5)) (-4 *3 (-1255 *4)) (-4 *5 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))))) (-3897 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *2 (-13 (-430) (-1065 *5) (-388) (-1211) (-301))) (-5 *1 (-468 *5 *3 *2)) (-4 *3 (-1255 *5)))) (-3897 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4)))) (-2338 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-468 *4 *3 *5)) (-4 *3 (-1255 *4)) (-4 *5 (-13 (-430) (-1065 *4) (-388) (-1211) (-301)))))) 
+(-10 -7 (-15 -2338 ((-592) |#2|)) (-15 -3897 (|#3| |#2|)) (-15 -3897 (|#3| |#2| (-944))) (-15 -3387 ((-592) |#2|)) (-15 -2157 ((-592) |#2| (-790))) (-15 -2157 ((-592) |#2|)) (-15 -2793 (|#3| |#2| (-944))) (-15 -4555 (|#3| |#2|)) (-15 -2086 (|#3| |#2|)) (-15 -2535 (|#3| |#2|)) (-15 -4233 (|#3| |#2|))) 
+((-4011 ((|#2| (-1280 |#1|)) 36)) (-2436 ((|#2| |#2| |#1|) 49)) (-2155 ((|#2| |#2| |#1|) 41)) (-1373 ((|#2| |#2|) 38)) (-1469 (((-141) |#2|) 30)) (-3684 (((-658 |#2|) (-944) (-444 |#2|)) 16)) (-4072 ((|#2| (-944) (-444 |#2|)) 21)) (-3363 (((-754 (-790)) (-444 |#2|)) 25))) 
+(((-469 |#1| |#2|) (-10 -7 (-15 -1469 ((-141) |#2|)) (-15 -4011 (|#2| (-1280 |#1|))) (-15 -1373 (|#2| |#2|)) (-15 -2155 (|#2| |#2| |#1|)) (-15 -2436 (|#2| |#2| |#1|)) (-15 -3363 ((-754 (-790)) (-444 |#2|))) (-15 -4072 (|#2| (-944) (-444 |#2|))) (-15 -3684 ((-658 |#2|) (-944) (-444 |#2|)))) (-1075) (-1255 |#1|)) (T -469)) 
+((-3684 (*1 *2 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-444 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-1075)) (-5 *2 (-658 *6)) (-5 *1 (-469 *5 *6)))) (-4072 (*1 *2 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-444 *2)) (-4 *2 (-1255 *5)) (-5 *1 (-469 *5 *2)) (-4 *5 (-1075)))) (-3363 (*1 *2 *3) (-12 (-5 *3 (-444 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-1075)) (-5 *2 (-754 (-790))) (-5 *1 (-469 *4 *5)))) (-2436 (*1 *2 *2 *3) (-12 (-4 *3 (-1075)) (-5 *1 (-469 *3 *2)) (-4 *2 (-1255 *3)))) (-2155 (*1 *2 *2 *3) (-12 (-4 *3 (-1075)) (-5 *1 (-469 *3 *2)) (-4 *2 (-1255 *3)))) (-1373 (*1 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-469 *3 *2)) (-4 *2 (-1255 *3)))) (-4011 (*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-1075)) (-4 *2 (-1255 *4)) (-5 *1 (-469 *4 *2)))) (-1469 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-141)) (-5 *1 (-469 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -1469 ((-141) |#2|)) (-15 -4011 (|#2| (-1280 |#1|))) (-15 -1373 (|#2| |#2|)) (-15 -2155 (|#2| |#2| |#1|)) (-15 -2436 (|#2| |#2| |#1|)) (-15 -3363 ((-754 (-790)) (-444 |#2|))) (-15 -4072 (|#2| (-944) (-444 |#2|))) (-15 -3684 ((-658 |#2|) (-944) (-444 |#2|)))) 
+((-3956 (((-790)) 41)) (-4228 (((-790)) 23 (|has| |#1| (-430))) (((-790) (-790)) 22 (|has| |#1| (-430)))) (-2649 (((-592) |#1|) 18 (|has| |#1| (-430)))) (-1808 (((-592) |#1|) 20 (|has| |#1| (-430)))) (-2755 (((-790)) 40) (((-790) (-790)) 39)) (-2060 ((|#1| (-790) (-592)) 29)) (-3968 (((-1285)) 43))) 
+(((-470 |#1|) (-10 -7 (-15 -2060 (|#1| (-790) (-592))) (-15 -2755 ((-790) (-790))) (-15 -2755 ((-790))) (-15 -3956 ((-790))) (-15 -3968 ((-1285))) (IF (|has| |#1| (-430)) (PROGN (-15 -1808 ((-592) |#1|)) (-15 -2649 ((-592) |#1|)) (-15 -4228 ((-790) (-790))) (-15 -4228 ((-790)))) |noBranch|)) (-1075)) (T -470)) 
+((-4228 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-430)) (-4 *3 (-1075)))) (-4228 (*1 *2 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-430)) (-4 *3 (-1075)))) (-2649 (*1 *2 *3) (-12 (-5 *2 (-592)) (-5 *1 (-470 *3)) (-4 *3 (-430)) (-4 *3 (-1075)))) (-1808 (*1 *2 *3) (-12 (-5 *2 (-592)) (-5 *1 (-470 *3)) (-4 *3 (-430)) (-4 *3 (-1075)))) (-3968 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-470 *3)) (-4 *3 (-1075)))) (-3956 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-1075)))) (-2755 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-1075)))) (-2755 (*1 *2 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-1075)))) (-2060 (*1 *2 *3 *4) (-12 (-5 *3 (-790)) (-5 *4 (-592)) (-5 *1 (-470 *2)) (-4 *2 (-1075))))) 
+(-10 -7 (-15 -2060 (|#1| (-790) (-592))) (-15 -2755 ((-790) (-790))) (-15 -2755 ((-790))) (-15 -3956 ((-790))) (-15 -3968 ((-1285))) (IF (|has| |#1| (-430)) (PROGN (-15 -1808 ((-592) |#1|)) (-15 -2649 ((-592) |#1|)) (-15 -4228 ((-790) (-790))) (-15 -4228 ((-790)))) |noBranch|)) 
+((-1739 (((-658 (-592)) (-592)) 57)) (-2802 (((-141) (-191 (-592))) 61)) (-4500 (((-444 (-191 (-592))) (-191 (-592))) 56))) 
+(((-471) (-10 -7 (-15 -4500 ((-444 (-191 (-592))) (-191 (-592)))) (-15 -1739 ((-658 (-592)) (-592))) (-15 -2802 ((-141) (-191 (-592)))))) (T -471)) 
+((-2802 (*1 *2 *3) (-12 (-5 *3 (-191 (-592))) (-5 *2 (-141)) (-5 *1 (-471)))) (-1739 (*1 *2 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-471)) (-5 *3 (-592)))) (-4500 (*1 *2 *3) (-12 (-5 *2 (-444 (-191 (-592)))) (-5 *1 (-471)) (-5 *3 (-191 (-592)))))) 
+(-10 -7 (-15 -4500 ((-444 (-191 (-592))) (-191 (-592)))) (-15 -1739 ((-658 (-592)) (-592))) (-15 -2802 ((-141) (-191 (-592))))) 
+((-1946 ((|#4| |#4| (-658 |#4|)) 57)) (-3580 (((-658 |#4|) (-658 |#4|) (-1173) (-1173)) 17) (((-658 |#4|) (-658 |#4|) (-1173)) 16) (((-658 |#4|) (-658 |#4|)) 11))) 
+(((-472 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1946 (|#4| |#4| (-658 |#4|))) (-15 -3580 ((-658 |#4|) (-658 |#4|))) (-15 -3580 ((-658 |#4|) (-658 |#4|) (-1173))) (-15 -3580 ((-658 |#4|) (-658 |#4|) (-1173) (-1173)))) (-323) (-815) (-869) (-977 |#1| |#2| |#3|)) (T -472)) 
+((-3580 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-1173)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-323)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-472 *4 *5 *6 *7)))) (-3580 (*1 *2 *2 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-1173)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-323)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-472 *4 *5 *6 *7)))) (-3580 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-323)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-472 *3 *4 *5 *6)))) (-1946 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *4 *5 *6)) (-4 *4 (-323)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-472 *4 *5 *6 *2))))) 
+(-10 -7 (-15 -1946 (|#4| |#4| (-658 |#4|))) (-15 -3580 ((-658 |#4|) (-658 |#4|))) (-15 -3580 ((-658 |#4|) (-658 |#4|) (-1173))) (-15 -3580 ((-658 |#4|) (-658 |#4|) (-1173) (-1173)))) 
+((-3210 (((-658 (-658 |#4|)) (-658 |#4|) (-141)) 70) (((-658 (-658 |#4|)) (-658 |#4|)) 69) (((-658 (-658 |#4|)) (-658 |#4|) (-658 |#4|) (-141)) 63) (((-658 (-658 |#4|)) (-658 |#4|) (-658 |#4|)) 64)) (-3159 (((-658 (-658 |#4|)) (-658 |#4|) (-141)) 40) (((-658 (-658 |#4|)) (-658 |#4|)) 60))) 
+(((-473 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3159 ((-658 (-658 |#4|)) (-658 |#4|))) (-15 -3159 ((-658 (-658 |#4|)) (-658 |#4|) (-141))) (-15 -3210 ((-658 (-658 |#4|)) (-658 |#4|) (-658 |#4|))) (-15 -3210 ((-658 (-658 |#4|)) (-658 |#4|) (-658 |#4|) (-141))) (-15 -3210 ((-658 (-658 |#4|)) (-658 |#4|))) (-15 -3210 ((-658 (-658 |#4|)) (-658 |#4|) (-141)))) (-13 (-323) (-171)) (-815) (-869) (-977 |#1| |#2| |#3|)) (T -473)) 
+((-3210 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-977 *5 *6 *7)) (-5 *2 (-658 (-658 *8))) (-5 *1 (-473 *5 *6 *7 *8)) (-5 *3 (-658 *8)))) (-3210 (*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-658 (-658 *7))) (-5 *1 (-473 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) (-3210 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-977 *5 *6 *7)) (-5 *2 (-658 (-658 *8))) (-5 *1 (-473 *5 *6 *7 *8)) (-5 *3 (-658 *8)))) (-3210 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-658 (-658 *7))) (-5 *1 (-473 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) (-3159 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-977 *5 *6 *7)) (-5 *2 (-658 (-658 *8))) (-5 *1 (-473 *5 *6 *7 *8)) (-5 *3 (-658 *8)))) (-3159 (*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-658 (-658 *7))) (-5 *1 (-473 *4 *5 *6 *7)) (-5 *3 (-658 *7))))) 
+(-10 -7 (-15 -3159 ((-658 (-658 |#4|)) (-658 |#4|))) (-15 -3159 ((-658 (-658 |#4|)) (-658 |#4|) (-141))) (-15 -3210 ((-658 (-658 |#4|)) (-658 |#4|) (-658 |#4|))) (-15 -3210 ((-658 (-658 |#4|)) (-658 |#4|) (-658 |#4|) (-141))) (-15 -3210 ((-658 (-658 |#4|)) (-658 |#4|))) (-15 -3210 ((-658 (-658 |#4|)) (-658 |#4|) (-141)))) 
+((-3576 (((-790) |#4|) 12)) (-4121 (((-658 (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|))) |#4| (-790) (-658 (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|)))) 31)) (-4066 (((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 37)) (-3510 ((|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 38)) (-2827 ((|#4| |#4| (-658 |#4|)) 39)) (-4154 (((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-658 |#4|)) 68)) (-2962 (((-1285) |#4|) 41)) (-1697 (((-1285) (-658 |#4|)) 50)) (-4423 (((-592) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-592) (-592) (-592)) 47)) (-4285 (((-1285) (-592)) 75)) (-1425 (((-658 |#4|) (-658 |#4|)) 73)) (-2581 (((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|)) |#4| (-790)) 25)) (-4046 (((-592) |#4|) 74)) (-3974 ((|#4| |#4|) 29)) (-1677 (((-658 |#4|) (-658 |#4|) (-592) (-592)) 54)) (-4118 (((-592) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-592) (-592) (-592) (-592)) 85)) (-1740 (((-141) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 16)) (-2342 (((-141) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 57)) (-1452 (((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 56)) (-4242 (((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 35)) (-2096 (((-141) |#2| |#2|) 55)) (-4336 (((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 36)) (-4176 (((-141) |#2| |#2| |#2| |#2|) 58)) (-3965 ((|#4| |#4| (-658 |#4|)) 69))) 
+(((-474 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3965 (|#4| |#4| (-658 |#4|))) (-15 -2827 (|#4| |#4| (-658 |#4|))) (-15 -1677 ((-658 |#4|) (-658 |#4|) (-592) (-592))) (-15 -2342 ((-141) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2096 ((-141) |#2| |#2|)) (-15 -4176 ((-141) |#2| |#2| |#2| |#2|)) (-15 -4336 ((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -4242 ((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -1452 ((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -4154 ((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-658 |#4|))) (-15 -3974 (|#4| |#4|)) (-15 -4121 ((-658 (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|))) |#4| (-790) (-658 (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|))))) (-15 -3510 (|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -4066 ((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -1425 ((-658 |#4|) (-658 |#4|))) (-15 -4046 ((-592) |#4|)) (-15 -2962 ((-1285) |#4|)) (-15 -4423 ((-592) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-592) (-592) (-592))) (-15 -4118 ((-592) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-592) (-592) (-592) (-592))) (-15 -1697 ((-1285) (-658 |#4|))) (-15 -4285 ((-1285) (-592))) (-15 -1740 ((-141) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2581 ((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|)) |#4| (-790))) (-15 -3576 ((-790) |#4|))) (-477) (-815) (-869) (-977 |#1| |#2| |#3|)) (T -474)) 
+((-3576 (*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-790)) (-5 *1 (-474 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6)))) (-2581 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-2 (|:| |totdeg| (-790)) (|:| -3489 *4))) (-5 *5 (-790)) (-4 *4 (-977 *6 *7 *8)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-5 *2 (-2 (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (-5 *1 (-474 *6 *7 *8 *4)))) (-1740 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-790)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-815)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-474 *4 *5 *6 *7)))) (-4285 (*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1285)) (-5 *1 (-474 *4 *5 *6 *7)) (-4 *7 (-977 *4 *5 *6)))) (-1697 (*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1285)) (-5 *1 (-474 *4 *5 *6 *7)))) (-4118 (*1 *2 *3 *4 *4 *2 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-790)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-815)) (-4 *4 (-977 *5 *6 *7)) (-4 *5 (-477)) (-4 *7 (-869)) (-5 *1 (-474 *5 *6 *7 *4)))) (-4423 (*1 *2 *3 *4 *4 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-790)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-815)) (-4 *4 (-977 *5 *6 *7)) (-4 *5 (-477)) (-4 *7 (-869)) (-5 *1 (-474 *5 *6 *7 *4)))) (-2962 (*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1285)) (-5 *1 (-474 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6)))) (-4046 (*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-592)) (-5 *1 (-474 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6)))) (-1425 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-474 *3 *4 *5 *6)))) (-4066 (*1 *2 *2 *2) (-12 (-5 *2 (-658 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-790)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-815)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-477)) (-4 *5 (-869)) (-5 *1 (-474 *3 *4 *5 *6)))) (-3510 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-790)) (|:| |poli| *2) (|:| |polj| *2))) (-4 *5 (-815)) (-4 *2 (-977 *4 *5 *6)) (-5 *1 (-474 *4 *5 *6 *2)) (-4 *4 (-477)) (-4 *6 (-869)))) (-4121 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-658 (-2 (|:| |totdeg| (-790)) (|:| -3489 *3)))) (-5 *4 (-790)) (-4 *3 (-977 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-474 *5 *6 *7 *3)))) (-3974 (*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-474 *3 *4 *5 *2)) (-4 *2 (-977 *3 *4 *5)))) (-4154 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-977 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |poly| *3) (|:| |mult| *5))) (-5 *1 (-474 *5 *6 *7 *3)))) (-1452 (*1 *2 *3 *2) (-12 (-5 *2 (-658 (-2 (|:| |lcmfij| *3) (|:| |totdeg| (-790)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *3 (-815)) (-4 *6 (-977 *4 *3 *5)) (-4 *4 (-477)) (-4 *5 (-869)) (-5 *1 (-474 *4 *3 *5 *6)))) (-4242 (*1 *2 *2) (-12 (-5 *2 (-658 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-790)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-815)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-477)) (-4 *5 (-869)) (-5 *1 (-474 *3 *4 *5 *6)))) (-4336 (*1 *2 *3 *2) (-12 (-5 *2 (-658 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-790)) (|:| |poli| *3) (|:| |polj| *3)))) (-4 *5 (-815)) (-4 *3 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *6 (-869)) (-5 *1 (-474 *4 *5 *6 *3)))) (-4176 (*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-477)) (-4 *3 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-474 *4 *3 *5 *6)) (-4 *6 (-977 *4 *3 *5)))) (-2096 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *3 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-474 *4 *3 *5 *6)) (-4 *6 (-977 *4 *3 *5)))) (-2342 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-790)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-815)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-474 *4 *5 *6 *7)))) (-1677 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-592)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-474 *4 *5 *6 *7)))) (-2827 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-474 *4 *5 *6 *2)))) (-3965 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-474 *4 *5 *6 *2))))) 
+(-10 -7 (-15 -3965 (|#4| |#4| (-658 |#4|))) (-15 -2827 (|#4| |#4| (-658 |#4|))) (-15 -1677 ((-658 |#4|) (-658 |#4|) (-592) (-592))) (-15 -2342 ((-141) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2096 ((-141) |#2| |#2|)) (-15 -4176 ((-141) |#2| |#2| |#2| |#2|)) (-15 -4336 ((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -4242 ((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -1452 ((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -4154 ((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-658 |#4|))) (-15 -3974 (|#4| |#4|)) (-15 -4121 ((-658 (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|))) |#4| (-790) (-658 (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|))))) (-15 -3510 (|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -4066 ((-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-658 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -1425 ((-658 |#4|) (-658 |#4|))) (-15 -4046 ((-592) |#4|)) (-15 -2962 ((-1285) |#4|)) (-15 -4423 ((-592) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-592) (-592) (-592))) (-15 -4118 ((-592) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-592) (-592) (-592) (-592))) (-15 -1697 ((-1285) (-658 |#4|))) (-15 -4285 ((-1285) (-592))) (-15 -1740 ((-141) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2581 ((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-790)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-790)) (|:| -3489 |#4|)) |#4| (-790))) (-15 -3576 ((-790) |#4|))) 
+((-3389 ((|#4| |#4| (-658 |#4|)) 22 (|has| |#1| (-388)))) (-3903 (((-658 |#4|) (-658 |#4|) (-1173) (-1173)) 41) (((-658 |#4|) (-658 |#4|) (-1173)) 40) (((-658 |#4|) (-658 |#4|)) 35))) 
+(((-475 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3903 ((-658 |#4|) (-658 |#4|))) (-15 -3903 ((-658 |#4|) (-658 |#4|) (-1173))) (-15 -3903 ((-658 |#4|) (-658 |#4|) (-1173) (-1173))) (IF (|has| |#1| (-388)) (-15 -3389 (|#4| |#4| (-658 |#4|))) |noBranch|)) (-477) (-815) (-869) (-977 |#1| |#2| |#3|)) (T -475)) 
+((-3389 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *4 *5 *6)) (-4 *4 (-388)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-475 *4 *5 *6 *2)))) (-3903 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-1173)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-475 *4 *5 *6 *7)))) (-3903 (*1 *2 *2 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-1173)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-475 *4 *5 *6 *7)))) (-3903 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-475 *3 *4 *5 *6))))) 
+(-10 -7 (-15 -3903 ((-658 |#4|) (-658 |#4|))) (-15 -3903 ((-658 |#4|) (-658 |#4|) (-1173))) (-15 -3903 ((-658 |#4|) (-658 |#4|) (-1173) (-1173))) (IF (|has| |#1| (-388)) (-15 -3389 (|#4| |#4| (-658 |#4|))) |noBranch|)) 
+((-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 43)) (-2750 (($ $ $) 14) (($ (-658 $)) 21)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 41)) (-3548 (($ $ $) NIL) (($ (-658 $)) 22))) 
+(((-476 |#1|) (-10 -8 (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|))) (-15 -2750 (|#1| (-658 |#1|))) (-15 -2750 (|#1| |#1| |#1|)) (-15 -3548 (|#1| (-658 |#1|))) (-15 -3548 (|#1| |#1| |#1|)) (-15 -1389 ((-2 (|:| |llcmres| |#1|) (|:| |coeff1| |#1|) (|:| |coeff2| |#1|)) |#1| |#1|))) (-477)) (T -476)) 
+NIL 
+(-10 -8 (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|))) (-15 -2750 (|#1| (-658 |#1|))) (-15 -2750 (|#1| |#1| |#1|)) (-15 -3548 (|#1| (-658 |#1|))) (-15 -3548 (|#1| |#1| |#1|)) (-15 -1389 ((-2 (|:| |llcmres| |#1|) (|:| |coeff1| |#1|) (|:| |coeff2| |#1|)) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 48)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3616 (((-3 $ "failed") $ $) 41)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-477) (-1311)) (T -477)) 
+((-3548 (*1 *1 *1 *1) (-4 *1 (-477))) (-3548 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-477)))) (-2750 (*1 *1 *1 *1) (-4 *1 (-477))) (-2750 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-477)))) (-2536 (*1 *2 *2 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-477))))) 
+(-13 (-582) (-678) (-10 -8 (-15 -3548 ($ $ $)) (-15 -3548 ($ (-658 $))) (-15 -2750 ($ $ $)) (-15 -2750 ($ (-658 $))) (-15 -2536 ((-1187 $) (-1187 $) (-1187 $))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-582) . T) ((-661 $) . T) ((-678) . T) ((-734 $) . T) ((-743) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4509 (((-3 $ "failed")) NIL (|has| (-433 (-980 |#1|)) (-582)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4061 (((-1280 (-706 (-433 (-980 |#1|)))) (-1280 $)) NIL) (((-1280 (-706 (-433 (-980 |#1|))))) NIL)) (-3360 (((-1280 $)) NIL)) (-3001 (($) NIL T CONST)) (-2604 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL)) (-2661 (((-3 $ "failed")) NIL (|has| (-433 (-980 |#1|)) (-582)))) (-1951 (((-706 (-433 (-980 |#1|))) (-1280 $)) NIL) (((-706 (-433 (-980 |#1|)))) NIL)) (-4282 (((-433 (-980 |#1|)) $) NIL)) (-2302 (((-706 (-433 (-980 |#1|))) $ (-1280 $)) NIL) (((-706 (-433 (-980 |#1|))) $) NIL)) (-2503 (((-3 $ "failed") $) NIL (|has| (-433 (-980 |#1|)) (-582)))) (-2120 (((-1187 (-980 (-433 (-980 |#1|))))) NIL (|has| (-433 (-980 |#1|)) (-388))) (((-1187 (-433 (-980 |#1|)))) 79 (|has| |#1| (-582)))) (-2111 (($ $ (-944)) NIL)) (-1431 (((-433 (-980 |#1|)) $) NIL)) (-3916 (((-1187 (-433 (-980 |#1|))) $) 77 (|has| (-433 (-980 |#1|)) (-582)))) (-1874 (((-433 (-980 |#1|)) (-1280 $)) NIL) (((-433 (-980 |#1|))) NIL)) (-1582 (((-1187 (-433 (-980 |#1|))) $) NIL)) (-4194 (((-141)) NIL)) (-1626 (($ (-1280 (-433 (-980 |#1|))) (-1280 $)) 97) (($ (-1280 (-433 (-980 |#1|)))) NIL)) (-3371 (((-3 $ "failed") $) NIL (|has| (-433 (-980 |#1|)) (-582)))) (-4175 (((-944)) NIL)) (-2169 (((-141)) NIL)) (-1833 (($ $ (-944)) NIL)) (-3700 (((-141)) NIL)) (-2973 (((-141)) NIL)) (-2467 (((-141)) NIL)) (-1563 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL)) (-3994 (((-3 $ "failed")) NIL (|has| (-433 (-980 |#1|)) (-582)))) (-2794 (((-706 (-433 (-980 |#1|))) (-1280 $)) NIL) (((-706 (-433 (-980 |#1|)))) NIL)) (-1869 (((-433 (-980 |#1|)) $) NIL)) (-1802 (((-706 (-433 (-980 |#1|))) $ (-1280 $)) NIL) (((-706 (-433 (-980 |#1|))) $) NIL)) (-4158 (((-3 $ "failed") $) NIL (|has| (-433 (-980 |#1|)) (-582)))) (-3004 (((-1187 (-980 (-433 (-980 |#1|))))) NIL (|has| (-433 (-980 |#1|)) (-388))) (((-1187 (-433 (-980 |#1|)))) 78 (|has| |#1| (-582)))) (-2682 (($ $ (-944)) NIL)) (-3061 (((-433 (-980 |#1|)) $) NIL)) (-2013 (((-1187 (-433 (-980 |#1|))) $) 72 (|has| (-433 (-980 |#1|)) (-582)))) (-3030 (((-433 (-980 |#1|)) (-1280 $)) NIL) (((-433 (-980 |#1|))) NIL)) (-2397 (((-1187 (-433 (-980 |#1|))) $) NIL)) (-3847 (((-141)) NIL)) (-2685 (((-1173) $) NIL)) (-4106 (((-141)) NIL)) (-2339 (((-141)) NIL)) (-2297 (((-141)) NIL)) (-2951 (((-1137) $) NIL)) (-3107 (((-433 (-980 |#1|)) $ $) 66 (|has| |#1| (-582)))) (-4584 (((-433 (-980 |#1|)) $) 65 (|has| |#1| (-582)))) (-1520 (((-433 (-980 |#1|)) $) 89 (|has| |#1| (-582)))) (-2906 (((-1187 (-433 (-980 |#1|))) $) 83 (|has| |#1| (-582)))) (-2880 (((-433 (-980 |#1|))) 67 (|has| |#1| (-582)))) (-1382 (((-433 (-980 |#1|)) $ $) 54 (|has| |#1| (-582)))) (-3442 (((-433 (-980 |#1|)) $) 53 (|has| |#1| (-582)))) (-3694 (((-433 (-980 |#1|)) $) 88 (|has| |#1| (-582)))) (-2824 (((-1187 (-433 (-980 |#1|))) $) 82 (|has| |#1| (-582)))) (-4190 (((-433 (-980 |#1|))) 64 (|has| |#1| (-582)))) (-3474 (($) 95) (($ (-1191)) 101) (($ (-1280 (-1191))) 100) (($ (-1280 $)) 90) (($ (-1191) (-1280 $)) 99) (($ (-1280 (-1191)) (-1280 $)) 98)) (-2716 (((-141)) NIL)) (-3927 (((-433 (-980 |#1|)) $ (-592)) NIL)) (-2231 (((-1280 (-433 (-980 |#1|))) $ (-1280 $)) 92) (((-706 (-433 (-980 |#1|))) (-1280 $) (-1280 $)) NIL) (((-1280 (-433 (-980 |#1|))) $) 37) (((-706 (-433 (-980 |#1|))) (-1280 $)) NIL)) (-1778 (((-1280 (-433 (-980 |#1|))) $) NIL) (($ (-1280 (-433 (-980 |#1|)))) 34)) (-1473 (((-658 (-980 (-433 (-980 |#1|)))) (-1280 $)) NIL) (((-658 (-980 (-433 (-980 |#1|))))) NIL) (((-658 (-980 |#1|)) (-1280 $)) 93 (|has| |#1| (-582))) (((-658 (-980 |#1|))) 94 (|has| |#1| (-582)))) (-2131 (($ $ $) NIL)) (-3545 (((-141)) NIL)) (-1683 (((-877) $) NIL) (($ (-1280 (-433 (-980 |#1|)))) NIL)) (-2195 (((-1280 $)) 56)) (-3664 (((-658 (-1280 (-433 (-980 |#1|))))) NIL (|has| (-433 (-980 |#1|)) (-582)))) (-3667 (($ $ $ $) NIL)) (-1516 (((-141)) NIL)) (-4572 (($ (-706 (-433 (-980 |#1|))) $) NIL)) (-2844 (($ $ $) NIL)) (-3135 (((-141)) NIL)) (-2723 (((-141)) NIL)) (-2359 (((-141)) NIL)) (-3514 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) 91)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 52) (($ $ (-433 (-980 |#1|))) NIL) (($ (-433 (-980 |#1|)) $) NIL) (($ (-1156 |#2| (-433 (-980 |#1|))) $) NIL))) 
+(((-478 |#1| |#2| |#3| |#4|) (-13 (-443 (-433 (-980 |#1|))) (-661 (-1156 |#2| (-433 (-980 |#1|)))) (-10 -8 (-15 -1683 ($ (-1280 (-433 (-980 |#1|))))) (-15 -1563 ((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed"))) (-15 -2604 ((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed"))) (-15 -3474 ($)) (-15 -3474 ($ (-1191))) (-15 -3474 ($ (-1280 (-1191)))) (-15 -3474 ($ (-1280 $))) (-15 -3474 ($ (-1191) (-1280 $))) (-15 -3474 ($ (-1280 (-1191)) (-1280 $))) (IF (|has| |#1| (-582)) (PROGN (-15 -3004 ((-1187 (-433 (-980 |#1|))))) (-15 -2824 ((-1187 (-433 (-980 |#1|))) $)) (-15 -3442 ((-433 (-980 |#1|)) $)) (-15 -3694 ((-433 (-980 |#1|)) $)) (-15 -2120 ((-1187 (-433 (-980 |#1|))))) (-15 -2906 ((-1187 (-433 (-980 |#1|))) $)) (-15 -4584 ((-433 (-980 |#1|)) $)) (-15 -1520 ((-433 (-980 |#1|)) $)) (-15 -1382 ((-433 (-980 |#1|)) $ $)) (-15 -4190 ((-433 (-980 |#1|)))) (-15 -3107 ((-433 (-980 |#1|)) $ $)) (-15 -2880 ((-433 (-980 |#1|)))) (-15 -1473 ((-658 (-980 |#1|)) (-1280 $))) (-15 -1473 ((-658 (-980 |#1|))))) |noBranch|))) (-194) (-944) (-658 (-1191)) (-1280 (-706 |#1|))) (T -478)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1280 (-433 (-980 *3)))) (-4 *3 (-194)) (-14 *6 (-1280 (-706 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))))) (-1563 (*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-478 *3 *4 *5 *6)) (|:| -2195 (-658 (-478 *3 *4 *5 *6))))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-2604 (*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-478 *3 *4 *5 *6)) (|:| -2195 (-658 (-478 *3 *4 *5 *6))))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-3474 (*1 *1) (-12 (-5 *1 (-478 *2 *3 *4 *5)) (-4 *2 (-194)) (-14 *3 (-944)) (-14 *4 (-658 (-1191))) (-14 *5 (-1280 (-706 *2))))) (-3474 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 *2)) (-14 *6 (-1280 (-706 *3))))) (-3474 (*1 *1 *2) (-12 (-5 *2 (-1280 (-1191))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-3474 (*1 *1 *2) (-12 (-5 *2 (-1280 (-478 *3 *4 *5 *6))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-3474 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-478 *4 *5 *6 *7))) (-5 *1 (-478 *4 *5 *6 *7)) (-4 *4 (-194)) (-14 *5 (-944)) (-14 *6 (-658 *2)) (-14 *7 (-1280 (-706 *4))))) (-3474 (*1 *1 *2 *3) (-12 (-5 *2 (-1280 (-1191))) (-5 *3 (-1280 (-478 *4 *5 *6 *7))) (-5 *1 (-478 *4 *5 *6 *7)) (-4 *4 (-194)) (-14 *5 (-944)) (-14 *6 (-658 (-1191))) (-14 *7 (-1280 (-706 *4))))) (-3004 (*1 *2) (-12 (-5 *2 (-1187 (-433 (-980 *3)))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-2824 (*1 *2 *1) (-12 (-5 *2 (-1187 (-433 (-980 *3)))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-3442 (*1 *2 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-3694 (*1 *2 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-2120 (*1 *2) (-12 (-5 *2 (-1187 (-433 (-980 *3)))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-2906 (*1 *2 *1) (-12 (-5 *2 (-1187 (-433 (-980 *3)))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-4584 (*1 *2 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-1520 (*1 *2 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-1382 (*1 *2 *1 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-4190 (*1 *2) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-3107 (*1 *2 *1 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-2880 (*1 *2) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) (-1473 (*1 *2 *3) (-12 (-5 *3 (-1280 (-478 *4 *5 *6 *7))) (-5 *2 (-658 (-980 *4))) (-5 *1 (-478 *4 *5 *6 *7)) (-4 *4 (-582)) (-4 *4 (-194)) (-14 *5 (-944)) (-14 *6 (-658 (-1191))) (-14 *7 (-1280 (-706 *4))))) (-1473 (*1 *2) (-12 (-5 *2 (-658 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(-13 (-443 (-433 (-980 |#1|))) (-661 (-1156 |#2| (-433 (-980 |#1|)))) (-10 -8 (-15 -1683 ($ (-1280 (-433 (-980 |#1|))))) (-15 -1563 ((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed"))) (-15 -2604 ((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed"))) (-15 -3474 ($)) (-15 -3474 ($ (-1191))) (-15 -3474 ($ (-1280 (-1191)))) (-15 -3474 ($ (-1280 $))) (-15 -3474 ($ (-1191) (-1280 $))) (-15 -3474 ($ (-1280 (-1191)) (-1280 $))) (IF (|has| |#1| (-582)) (PROGN (-15 -3004 ((-1187 (-433 (-980 |#1|))))) (-15 -2824 ((-1187 (-433 (-980 |#1|))) $)) (-15 -3442 ((-433 (-980 |#1|)) $)) (-15 -3694 ((-433 (-980 |#1|)) $)) (-15 -2120 ((-1187 (-433 (-980 |#1|))))) (-15 -2906 ((-1187 (-433 (-980 |#1|))) $)) (-15 -4584 ((-433 (-980 |#1|)) $)) (-15 -1520 ((-433 (-980 |#1|)) $)) (-15 -1382 ((-433 (-980 |#1|)) $ $)) (-15 -4190 ((-433 (-980 |#1|)))) (-15 -3107 ((-433 (-980 |#1|)) $ $)) (-15 -2880 ((-433 (-980 |#1|)))) (-15 -1473 ((-658 (-980 |#1|)) (-1280 $))) (-15 -1473 ((-658 (-980 |#1|))))) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 13)) (-4085 (((-658 (-879 |#1|)) $) 73)) (-4492 (((-1187 $) $ (-879 |#1|)) 46) (((-1187 |#2|) $) 115)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#2| (-582)))) (-1555 (($ $) NIL (|has| |#2| (-582)))) (-1313 (((-141) $) NIL (|has| |#2| (-582)))) (-2189 (((-790) $) 21) (((-790) $ (-658 (-879 |#1|))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3743 (($ $) NIL (|has| |#2| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#2| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) 44) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-879 |#1|) "failed") $) NIL)) (-2400 ((|#2| $) 42) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-879 |#1|) $) NIL)) (-1544 (($ $ $ (-879 |#1|)) NIL (|has| |#2| (-194)))) (-4377 (($ $ (-658 (-592))) 78)) (-4593 (($ $) 67)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#2| (-477))) (($ $ (-879 |#1|)) NIL (|has| |#2| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#2| (-931)))) (-4209 (($ $ |#2| |#3| $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-879 |#1|) (-908 (-405))) (|has| |#2| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-879 |#1|) (-908 (-592))) (|has| |#2| (-908 (-592)))))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) 58)) (-4533 (($ (-1187 |#2|) (-879 |#1|)) 120) (($ (-1187 $) (-879 |#1|)) 52)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) 59)) (-4526 (($ |#2| |#3|) 28) (($ $ (-879 |#1|) (-790)) 30) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-879 |#1|)) NIL)) (-4206 ((|#3| $) NIL) (((-790) $ (-879 |#1|)) 50) (((-658 (-790)) $ (-658 (-879 |#1|))) 57)) (-1837 (($ $ $) NIL (|has| |#2| (-869)))) (-3319 (($ $ $) NIL (|has| |#2| (-869)))) (-2976 (($ (-1 |#3| |#3|) $) NIL)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-3254 (((-3 (-879 |#1|) "failed") $) 39)) (-4573 (($ $) NIL)) (-4579 ((|#2| $) 41)) (-2750 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-2685 (((-1173) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-879 |#1|)) (|:| -3215 (-790))) "failed") $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 40)) (-4565 ((|#2| $) 113)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#2| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) 125 (|has| |#2| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#2| (-931)))) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-879 |#1|) |#2|) 85) (($ $ (-658 (-879 |#1|)) (-658 |#2|)) 88) (($ $ (-879 |#1|) $) 83) (($ $ (-658 (-879 |#1|)) (-658 $)) 104)) (-1482 (($ $ (-879 |#1|)) NIL (|has| |#2| (-194)))) (-3644 (($ $ (-879 |#1|)) 53) (($ $ (-658 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-4525 ((|#3| $) 66) (((-790) $ (-879 |#1|)) 37) (((-658 (-790)) $ (-658 (-879 |#1|))) 56)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-879 |#1|) (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-879 |#1|) (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-879 |#1|) (-633 (-565))) (|has| |#2| (-633 (-565)))))) (-1554 ((|#2| $) 122 (|has| |#2| (-477))) (($ $ (-879 |#1|)) NIL (|has| |#2| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#2| (-931))))) (-1683 (((-877) $) 141) (($ (-592)) NIL) (($ |#2|) 84) (($ (-879 |#1|)) 31) (($ (-433 (-592))) NIL (-3836 (|has| |#2| (-43 (-433 (-592)))) (|has| |#2| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#2| (-582)))) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ |#3|) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#2| (-931))) (|has| |#2| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#2| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#2| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 16 T CONST)) (-4257 (($) 25 T CONST)) (-1940 (($ $ (-879 |#1|)) NIL) (($ $ (-658 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-3286 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3313 (($ $ |#2|) 64 (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 109)) (** (($ $ (-944)) NIL) (($ $ (-790)) 107)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 29) (($ $ (-433 (-592))) NIL (|has| |#2| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#2| (-43 (-433 (-592))))) (($ |#2| $) 63) (($ $ |#2|) NIL))) 
+(((-479 |#1| |#2| |#3|) (-13 (-977 |#2| |#3| (-879 |#1|)) (-10 -8 (-15 -4377 ($ $ (-658 (-592)))))) (-658 (-1191)) (-1075) (-252 (-1699 |#1|) (-790))) (T -479)) 
+((-4377 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-14 *3 (-658 (-1191))) (-5 *1 (-479 *3 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-252 (-1699 *3) (-790)))))) 
+(-13 (-977 |#2| |#3| (-879 |#1|)) (-10 -8 (-15 -4377 ($ $ (-658 (-592)))))) 
+((-3591 (((-1285) (-332 (-405)) (-1111 (-405)) (-1111 (-405)) (-1173)) 49) (((-1285) (-332 (-405)) (-1111 (-405)) (-1111 (-405)) (-1173) (-658 (-278))) 48) (((-1285) (-332 (-405)) (-1111 (-405)) (-1173)) 42) (((-1285) (-332 (-405)) (-1111 (-405)) (-1173) (-658 (-278))) 39))) 
+(((-480) (-10 -7 (-15 -3591 ((-1285) (-332 (-405)) (-1111 (-405)) (-1173) (-658 (-278)))) (-15 -3591 ((-1285) (-332 (-405)) (-1111 (-405)) (-1173))) (-15 -3591 ((-1285) (-332 (-405)) (-1111 (-405)) (-1111 (-405)) (-1173) (-658 (-278)))) (-15 -3591 ((-1285) (-332 (-405)) (-1111 (-405)) (-1111 (-405)) (-1173))))) (T -480)) 
+((-3591 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-405))) (-5 *5 (-1173)) (-5 *2 (-1285)) (-5 *1 (-480)))) (-3591 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-405))) (-5 *5 (-1173)) (-5 *6 (-658 (-278))) (-5 *2 (-1285)) (-5 *1 (-480)))) (-3591 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-405))) (-5 *5 (-1173)) (-5 *2 (-1285)) (-5 *1 (-480)))) (-3591 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-405))) (-5 *5 (-1173)) (-5 *6 (-658 (-278))) (-5 *2 (-1285)) (-5 *1 (-480))))) 
+(-10 -7 (-15 -3591 ((-1285) (-332 (-405)) (-1111 (-405)) (-1173) (-658 (-278)))) (-15 -3591 ((-1285) (-332 (-405)) (-1111 (-405)) (-1173))) (-15 -3591 ((-1285) (-332 (-405)) (-1111 (-405)) (-1111 (-405)) (-1173) (-658 (-278)))) (-15 -3591 ((-1285) (-332 (-405)) (-1111 (-405)) (-1111 (-405)) (-1173)))) 
+((-3875 (((-141) |#1| (-658 |#2|)) 65)) (-1728 (((-3 (-1280 (-658 |#2|)) "failed") (-790) |#1| (-658 |#2|)) 74)) (-2953 (((-3 (-658 |#2|) "failed") |#2| |#1| (-1280 (-658 |#2|))) 76)) (-3674 ((|#2| |#2| |#1|) 28)) (-3787 (((-790) |#2| (-658 |#2|)) 20))) 
+(((-481 |#1| |#2|) (-10 -7 (-15 -3674 (|#2| |#2| |#1|)) (-15 -3787 ((-790) |#2| (-658 |#2|))) (-15 -1728 ((-3 (-1280 (-658 |#2|)) "failed") (-790) |#1| (-658 |#2|))) (-15 -2953 ((-3 (-658 |#2|) "failed") |#2| |#1| (-1280 (-658 |#2|)))) (-15 -3875 ((-141) |#1| (-658 |#2|)))) (-323) (-1255 |#1|)) (T -481)) 
+((-3875 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *5)) (-4 *5 (-1255 *3)) (-4 *3 (-323)) (-5 *2 (-141)) (-5 *1 (-481 *3 *5)))) (-2953 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1280 (-658 *3))) (-4 *4 (-323)) (-5 *2 (-658 *3)) (-5 *1 (-481 *4 *3)) (-4 *3 (-1255 *4)))) (-1728 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-790)) (-4 *4 (-323)) (-4 *6 (-1255 *4)) (-5 *2 (-1280 (-658 *6))) (-5 *1 (-481 *4 *6)) (-5 *5 (-658 *6)))) (-3787 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-323)) (-5 *2 (-790)) (-5 *1 (-481 *5 *3)))) (-3674 (*1 *2 *2 *3) (-12 (-4 *3 (-323)) (-5 *1 (-481 *3 *2)) (-4 *2 (-1255 *3))))) 
+(-10 -7 (-15 -3674 (|#2| |#2| |#1|)) (-15 -3787 ((-790) |#2| (-658 |#2|))) (-15 -1728 ((-3 (-1280 (-658 |#2|)) "failed") (-790) |#1| (-658 |#2|))) (-15 -2953 ((-3 (-658 |#2|) "failed") |#2| |#1| (-1280 (-658 |#2|)))) (-15 -3875 ((-141) |#1| (-658 |#2|)))) 
+((-4500 (((-444 |#5|) |#5|) 24))) 
+(((-482 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4500 ((-444 |#5|) |#5|))) (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191))))) (-815) (-582) (-582) (-977 |#4| |#2| |#1|)) (T -482)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-4 *5 (-815)) (-4 *7 (-582)) (-5 *2 (-444 *3)) (-5 *1 (-482 *4 *5 *6 *7 *3)) (-4 *6 (-582)) (-4 *3 (-977 *7 *5 *4))))) 
+(-10 -7 (-15 -4500 ((-444 |#5|) |#5|))) 
+((-2606 ((|#3|) 36)) (-2536 (((-1187 |#4|) (-1187 |#4|) (-1187 |#4|)) 32))) 
+(((-483 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2536 ((-1187 |#4|) (-1187 |#4|) (-1187 |#4|))) (-15 -2606 (|#3|))) (-815) (-869) (-931) (-977 |#3| |#1| |#2|)) (T -483)) 
+((-2606 (*1 *2) (-12 (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-931)) (-5 *1 (-483 *3 *4 *2 *5)) (-4 *5 (-977 *2 *3 *4)))) (-2536 (*1 *2 *2 *2) (-12 (-5 *2 (-1187 *6)) (-4 *6 (-977 *5 *3 *4)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-931)) (-5 *1 (-483 *3 *4 *5 *6))))) 
+(-10 -7 (-15 -2536 ((-1187 |#4|) (-1187 |#4|) (-1187 |#4|))) (-15 -2606 (|#3|))) 
+((-4500 (((-444 (-1187 |#1|)) (-1187 |#1|)) 41))) 
+(((-484 |#1|) (-10 -7 (-15 -4500 ((-444 (-1187 |#1|)) (-1187 |#1|)))) (-323)) (T -484)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-323)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-484 *4)) (-5 *3 (-1187 *4))))) 
+(-10 -7 (-15 -4500 ((-444 (-1187 |#1|)) (-1187 |#1|)))) 
+((-1986 (((-57) |#2| (-1191) (-310 |#2|) (-1246 (-790))) 42) (((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-790))) 41) (((-57) |#2| (-1191) (-310 |#2|)) 35) (((-57) (-1 |#2| (-592)) (-310 |#2|)) 27)) (-2881 (((-57) |#2| (-1191) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592))) 80) (((-57) (-1 |#2| (-433 (-592))) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592))) 79) (((-57) |#2| (-1191) (-310 |#2|) (-1246 (-592))) 78) (((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-592))) 77) (((-57) |#2| (-1191) (-310 |#2|)) 72) (((-57) (-1 |#2| (-592)) (-310 |#2|)) 71)) (-2001 (((-57) |#2| (-1191) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592))) 66) (((-57) (-1 |#2| (-433 (-592))) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592))) 64)) (-1994 (((-57) |#2| (-1191) (-310 |#2|) (-1246 (-592))) 48) (((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-592))) 47))) 
+(((-485 |#1| |#2|) (-10 -7 (-15 -1986 ((-57) (-1 |#2| (-592)) (-310 |#2|))) (-15 -1986 ((-57) |#2| (-1191) (-310 |#2|))) (-15 -1986 ((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-790)))) (-15 -1986 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-790)))) (-15 -1994 ((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-592)))) (-15 -1994 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-592)))) (-15 -2001 ((-57) (-1 |#2| (-433 (-592))) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592)))) (-15 -2001 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592)))) (-15 -2881 ((-57) (-1 |#2| (-592)) (-310 |#2|))) (-15 -2881 ((-57) |#2| (-1191) (-310 |#2|))) (-15 -2881 ((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-592)))) (-15 -2881 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-592)))) (-15 -2881 ((-57) (-1 |#2| (-433 (-592))) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592)))) (-15 -2881 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592))))) (-13 (-582) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|))) (T -485)) 
+((-2881 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-433 (-592)))) (-5 *7 (-433 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *8))) (-4 *8 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *8 *3)))) (-2881 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-433 (-592)))) (-5 *4 (-310 *8)) (-5 *5 (-1246 (-433 (-592)))) (-5 *6 (-433 (-592))) (-4 *8 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *8)))) (-2881 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *3)))) (-2881 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-592))) (-5 *4 (-310 *7)) (-5 *5 (-1246 (-592))) (-4 *7 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *7)))) (-2881 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *3)))) (-2881 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-592))) (-5 *4 (-310 *6)) (-4 *6 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *5 *6)))) (-2001 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-433 (-592)))) (-5 *7 (-433 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *8))) (-4 *8 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *8 *3)))) (-2001 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-433 (-592)))) (-5 *4 (-310 *8)) (-5 *5 (-1246 (-433 (-592)))) (-5 *6 (-433 (-592))) (-4 *8 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *8)))) (-1994 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *3)))) (-1994 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-592))) (-5 *4 (-310 *7)) (-5 *5 (-1246 (-592))) (-4 *7 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *7)))) (-1986 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-790))) (-4 *3 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *3)))) (-1986 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-592))) (-5 *4 (-310 *7)) (-5 *5 (-1246 (-790))) (-4 *7 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *7)))) (-1986 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *3)))) (-1986 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-592))) (-5 *4 (-310 *6)) (-4 *6 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *5 *6))))) 
+(-10 -7 (-15 -1986 ((-57) (-1 |#2| (-592)) (-310 |#2|))) (-15 -1986 ((-57) |#2| (-1191) (-310 |#2|))) (-15 -1986 ((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-790)))) (-15 -1986 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-790)))) (-15 -1994 ((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-592)))) (-15 -1994 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-592)))) (-15 -2001 ((-57) (-1 |#2| (-433 (-592))) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592)))) (-15 -2001 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592)))) (-15 -2881 ((-57) (-1 |#2| (-592)) (-310 |#2|))) (-15 -2881 ((-57) |#2| (-1191) (-310 |#2|))) (-15 -2881 ((-57) (-1 |#2| (-592)) (-310 |#2|) (-1246 (-592)))) (-15 -2881 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-592)))) (-15 -2881 ((-57) (-1 |#2| (-433 (-592))) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592)))) (-15 -2881 ((-57) |#2| (-1191) (-310 |#2|) (-1246 (-433 (-592))) (-433 (-592))))) 
+((-3674 ((|#2| |#2| |#1|) 15)) (-3673 (((-658 |#2|) |#2| (-658 |#2|) |#1| (-944)) 65)) (-1723 (((-2 (|:| |plist| (-658 |#2|)) (|:| |modulo| |#1|)) |#2| (-658 |#2|) |#1| (-944)) 58))) 
+(((-486 |#1| |#2|) (-10 -7 (-15 -1723 ((-2 (|:| |plist| (-658 |#2|)) (|:| |modulo| |#1|)) |#2| (-658 |#2|) |#1| (-944))) (-15 -3673 ((-658 |#2|) |#2| (-658 |#2|) |#1| (-944))) (-15 -3674 (|#2| |#2| |#1|))) (-323) (-1255 |#1|)) (T -486)) 
+((-3674 (*1 *2 *2 *3) (-12 (-4 *3 (-323)) (-5 *1 (-486 *3 *2)) (-4 *2 (-1255 *3)))) (-3673 (*1 *2 *3 *2 *4 *5) (-12 (-5 *2 (-658 *3)) (-5 *5 (-944)) (-4 *3 (-1255 *4)) (-4 *4 (-323)) (-5 *1 (-486 *4 *3)))) (-1723 (*1 *2 *3 *4 *5 *6) (-12 (-5 *6 (-944)) (-4 *5 (-323)) (-4 *3 (-1255 *5)) (-5 *2 (-2 (|:| |plist| (-658 *3)) (|:| |modulo| *5))) (-5 *1 (-486 *5 *3)) (-5 *4 (-658 *3))))) 
+(-10 -7 (-15 -1723 ((-2 (|:| |plist| (-658 |#2|)) (|:| |modulo| |#1|)) |#2| (-658 |#2|) |#1| (-944))) (-15 -3673 ((-658 |#2|) |#2| (-658 |#2|) |#1| (-944))) (-15 -3674 (|#2| |#2| |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 28)) (-2673 (($ |#3|) 25)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4593 (($ $) 32)) (-2644 (($ |#2| |#4| $) 33)) (-4526 (($ |#2| (-730 |#3| |#4| |#5|)) 24)) (-4573 (((-730 |#3| |#4| |#5|) $) 15)) (-3093 ((|#3| $) 19)) (-3436 ((|#4| $) 17)) (-4579 ((|#2| $) 29)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3180 (($ |#2| |#3| |#4|) 26)) (-3514 (($) 36 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 34)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ |#6| $) 40) (($ $ |#6|) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
+(((-487 |#1| |#2| |#3| |#4| |#5| |#6|) (-13 (-734 |#6|) (-734 |#2|) (-10 -8 (-15 -4579 (|#2| $)) (-15 -4573 ((-730 |#3| |#4| |#5|) $)) (-15 -3436 (|#4| $)) (-15 -3093 (|#3| $)) (-15 -4593 ($ $)) (-15 -4526 ($ |#2| (-730 |#3| |#4| |#5|))) (-15 -2673 ($ |#3|)) (-15 -3180 ($ |#2| |#3| |#4|)) (-15 -2644 ($ |#2| |#4| $)) (-15 * ($ |#6| $)))) (-658 (-1191)) (-194) (-869) (-252 (-1699 |#1|) (-790)) (-1 (-141) (-2 (|:| -1825 |#3|) (|:| -3215 |#4|)) (-2 (|:| -1825 |#3|) (|:| -3215 |#4|))) (-977 |#2| |#4| (-879 |#1|))) (T -487)) 
+((* (*1 *1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-4 *6 (-252 (-1699 *3) (-790))) (-14 *7 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *6)) (-2 (|:| -1825 *5) (|:| -3215 *6)))) (-5 *1 (-487 *3 *4 *5 *6 *7 *2)) (-4 *5 (-869)) (-4 *2 (-977 *4 *6 (-879 *3))))) (-4579 (*1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *5 (-252 (-1699 *3) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *4) (|:| -3215 *5)) (-2 (|:| -1825 *4) (|:| -3215 *5)))) (-4 *2 (-194)) (-5 *1 (-487 *3 *2 *4 *5 *6 *7)) (-4 *4 (-869)) (-4 *7 (-977 *2 *5 (-879 *3))))) (-4573 (*1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-4 *6 (-252 (-1699 *3) (-790))) (-14 *7 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *6)) (-2 (|:| -1825 *5) (|:| -3215 *6)))) (-5 *2 (-730 *5 *6 *7)) (-5 *1 (-487 *3 *4 *5 *6 *7 *8)) (-4 *5 (-869)) (-4 *8 (-977 *4 *6 (-879 *3))))) (-3436 (*1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-14 *6 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *2)) (-2 (|:| -1825 *5) (|:| -3215 *2)))) (-4 *2 (-252 (-1699 *3) (-790))) (-5 *1 (-487 *3 *4 *5 *2 *6 *7)) (-4 *5 (-869)) (-4 *7 (-977 *4 *2 (-879 *3))))) (-3093 (*1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-4 *5 (-252 (-1699 *3) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *2) (|:| -3215 *5)) (-2 (|:| -1825 *2) (|:| -3215 *5)))) (-4 *2 (-869)) (-5 *1 (-487 *3 *4 *2 *5 *6 *7)) (-4 *7 (-977 *4 *5 (-879 *3))))) (-4593 (*1 *1 *1) (-12 (-14 *2 (-658 (-1191))) (-4 *3 (-194)) (-4 *5 (-252 (-1699 *2) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *4) (|:| -3215 *5)) (-2 (|:| -1825 *4) (|:| -3215 *5)))) (-5 *1 (-487 *2 *3 *4 *5 *6 *7)) (-4 *4 (-869)) (-4 *7 (-977 *3 *5 (-879 *2))))) (-4526 (*1 *1 *2 *3) (-12 (-5 *3 (-730 *5 *6 *7)) (-4 *5 (-869)) (-4 *6 (-252 (-1699 *4) (-790))) (-14 *7 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *6)) (-2 (|:| -1825 *5) (|:| -3215 *6)))) (-14 *4 (-658 (-1191))) (-4 *2 (-194)) (-5 *1 (-487 *4 *2 *5 *6 *7 *8)) (-4 *8 (-977 *2 *6 (-879 *4))))) (-2673 (*1 *1 *2) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-4 *5 (-252 (-1699 *3) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *2) (|:| -3215 *5)) (-2 (|:| -1825 *2) (|:| -3215 *5)))) (-5 *1 (-487 *3 *4 *2 *5 *6 *7)) (-4 *2 (-869)) (-4 *7 (-977 *4 *5 (-879 *3))))) (-3180 (*1 *1 *2 *3 *4) (-12 (-14 *5 (-658 (-1191))) (-4 *2 (-194)) (-4 *4 (-252 (-1699 *5) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *3) (|:| -3215 *4)) (-2 (|:| -1825 *3) (|:| -3215 *4)))) (-5 *1 (-487 *5 *2 *3 *4 *6 *7)) (-4 *3 (-869)) (-4 *7 (-977 *2 *4 (-879 *5))))) (-2644 (*1 *1 *2 *3 *1) (-12 (-14 *4 (-658 (-1191))) (-4 *2 (-194)) (-4 *3 (-252 (-1699 *4) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *3)) (-2 (|:| -1825 *5) (|:| -3215 *3)))) (-5 *1 (-487 *4 *2 *5 *3 *6 *7)) (-4 *5 (-869)) (-4 *7 (-977 *2 *3 (-879 *4)))))) 
+(-13 (-734 |#6|) (-734 |#2|) (-10 -8 (-15 -4579 (|#2| $)) (-15 -4573 ((-730 |#3| |#4| |#5|) $)) (-15 -3436 (|#4| $)) (-15 -3093 (|#3| $)) (-15 -4593 ($ $)) (-15 -4526 ($ |#2| (-730 |#3| |#4| |#5|))) (-15 -2673 ($ |#3|)) (-15 -3180 ($ |#2| |#3| |#4|)) (-15 -2644 ($ |#2| |#4| $)) (-15 * ($ |#6| $)))) 
+((-1641 (((-141) $ $) NIL)) (-1863 (((-1191) (-658 (-489))) 48)) (-1746 (((-790) (-658 (-489))) 33)) (-1409 (((-141) (-658 (-489))) 39)) (-2530 (((-3 (-944) "arbitrary") (-658 (-489))) 20)) (-3912 (((-3 (-790) "arbitrary") (-658 (-489))) 18)) (-3130 (((-3 (-944) "arbitrary") (-658 (-489))) 32)) (-3929 (((-790) (-658 (-489))) 25)) (-2458 (((-3 (-790) "arbitrary") (-658 (-489))) 16)) (-3751 (((-3 (-790) "arbitrary") (-658 (-489))) 17)) (-1698 (((-3 (-790) "arbitrary") (-658 (-489))) 21)) (-2685 (((-1173) $) NIL)) (-3275 (((-1191) (-658 (-489))) 50)) (-3155 (((-3 (-944) (-141)) (-658 (-489))) 44)) (-2951 (((-1137) $) NIL)) (-4049 (((-1191) (-658 (-489))) 49)) (-4312 (((-141) (-658 (-489))) 51)) (-4439 (((-141) (-658 (-489))) 40)) (-1683 (((-877) $) NIL)) (-1545 (((-1285) (-658 (-489))) 61)) (-3346 (((-141) (-658 (-489))) 38)) (-3971 (((-3 "skip" "MonteCarlo" "deterministic") (-658 (-489))) 37)) (-3520 (((-141) (-658 (-489))) 29)) (-4221 (((-3 (-944) (-141)) (-658 (-489))) 45)) (-3255 (((-141) $ $) NIL))) 
+(((-488) (-13 (-1119) (-10 -7 (-15 -3751 ((-3 (-790) "arbitrary") (-658 (-489)))) (-15 -3912 ((-3 (-790) "arbitrary") (-658 (-489)))) (-15 -2530 ((-3 (-944) "arbitrary") (-658 (-489)))) (-15 -3130 ((-3 (-944) "arbitrary") (-658 (-489)))) (-15 -3155 ((-3 (-944) (-141)) (-658 (-489)))) (-15 -4221 ((-3 (-944) (-141)) (-658 (-489)))) (-15 -2458 ((-3 (-790) "arbitrary") (-658 (-489)))) (-15 -1698 ((-3 (-790) "arbitrary") (-658 (-489)))) (-15 -3929 ((-790) (-658 (-489)))) (-15 -3520 ((-141) (-658 (-489)))) (-15 -1746 ((-790) (-658 (-489)))) (-15 -3971 ((-3 "skip" "MonteCarlo" "deterministic") (-658 (-489)))) (-15 -3346 ((-141) (-658 (-489)))) (-15 -1409 ((-141) (-658 (-489)))) (-15 -4049 ((-1191) (-658 (-489)))) (-15 -1863 ((-1191) (-658 (-489)))) (-15 -3275 ((-1191) (-658 (-489)))) (-15 -4312 ((-141) (-658 (-489)))) (-15 -4439 ((-141) (-658 (-489)))) (-15 -1545 ((-1285) (-658 (-489))))))) (T -488)) 
+((-3751 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-488)))) (-3912 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-488)))) (-2530 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-944) "arbitrary")) (-5 *1 (-488)))) (-3130 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-944) "arbitrary")) (-5 *1 (-488)))) (-3155 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-944) (-141))) (-5 *1 (-488)))) (-4221 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-944) (-141))) (-5 *1 (-488)))) (-2458 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-488)))) (-1698 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-488)))) (-3929 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-790)) (-5 *1 (-488)))) (-3520 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) (-1746 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-790)) (-5 *1 (-488)))) (-3971 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 "skip" "MonteCarlo" "deterministic")) (-5 *1 (-488)))) (-3346 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) (-1409 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) (-4049 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-1191)) (-5 *1 (-488)))) (-1863 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-1191)) (-5 *1 (-488)))) (-3275 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-1191)) (-5 *1 (-488)))) (-4312 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) (-4439 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) (-1545 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-1285)) (-5 *1 (-488))))) 
+(-13 (-1119) (-10 -7 (-15 -3751 ((-3 (-790) "arbitrary") (-658 (-489)))) (-15 -3912 ((-3 (-790) "arbitrary") (-658 (-489)))) (-15 -2530 ((-3 (-944) "arbitrary") (-658 (-489)))) (-15 -3130 ((-3 (-944) "arbitrary") (-658 (-489)))) (-15 -3155 ((-3 (-944) (-141)) (-658 (-489)))) (-15 -4221 ((-3 (-944) (-141)) (-658 (-489)))) (-15 -2458 ((-3 (-790) "arbitrary") (-658 (-489)))) (-15 -1698 ((-3 (-790) "arbitrary") (-658 (-489)))) (-15 -3929 ((-790) (-658 (-489)))) (-15 -3520 ((-141) (-658 (-489)))) (-15 -1746 ((-790) (-658 (-489)))) (-15 -3971 ((-3 "skip" "MonteCarlo" "deterministic") (-658 (-489)))) (-15 -3346 ((-141) (-658 (-489)))) (-15 -1409 ((-141) (-658 (-489)))) (-15 -4049 ((-1191) (-658 (-489)))) (-15 -1863 ((-1191) (-658 (-489)))) (-15 -3275 ((-1191) (-658 (-489)))) (-15 -4312 ((-141) (-658 (-489)))) (-15 -4439 ((-141) (-658 (-489)))) (-15 -1545 ((-1285) (-658 (-489)))))) 
+((-1641 (((-141) $ $) NIL)) (-1863 (($ (-1191)) 49)) (-1746 (($ (-790)) 28)) (-3199 (((-3 (-57) "failed") (-658 $) (-1191)) 61)) (-1409 (($ (-141)) 40)) (-2530 (($ (-3 (-944) "arbitrary")) 15)) (-3912 (($ (-3 (-790) "arbitrary")) 13)) (-3130 (($ (-3 (-944) "arbitrary")) 27)) (-3929 (($ (-790)) 20)) (-2458 (($ (-3 (-790) "arbitrary")) 11)) (-3751 (($ (-3 (-790) "arbitrary")) 12)) (-1698 (($ (-3 (-790) "arbitrary")) 16)) (-2685 (((-1173) $) NIL)) (-3275 (($ (-1191)) 50)) (-3155 (($ (-3 (-944) (-141))) 32)) (-2951 (((-1137) $) NIL)) (-1866 (($ (-658 (-1191))) 48)) (-4049 (($ (-1191)) 44)) (-4139 (($ (-1191)) 51)) (-4439 (($ (-141)) 34)) (-1683 (((-877) $) 56)) (-3346 (($ (-141)) 39)) (-3971 (($ (-3 "skip" "MonteCarlo" "deterministic")) 38)) (-3520 (($ (-141)) 24)) (-4221 (($ (-3 (-944) (-141))) 33)) (-3255 (((-141) $ $) 58))) 
+(((-489) (-13 (-1119) (-10 -8 (-15 -3751 ($ (-3 (-790) "arbitrary"))) (-15 -3912 ($ (-3 (-790) "arbitrary"))) (-15 -2530 ($ (-3 (-944) "arbitrary"))) (-15 -3130 ($ (-3 (-944) "arbitrary"))) (-15 -3155 ($ (-3 (-944) (-141)))) (-15 -4221 ($ (-3 (-944) (-141)))) (-15 -2458 ($ (-3 (-790) "arbitrary"))) (-15 -1698 ($ (-3 (-790) "arbitrary"))) (-15 -3929 ($ (-790))) (-15 -3520 ($ (-141))) (-15 -1746 ($ (-790))) (-15 -3971 ($ (-3 "skip" "MonteCarlo" "deterministic"))) (-15 -3346 ($ (-141))) (-15 -1409 ($ (-141))) (-15 -4439 ($ (-141))) (-15 -4049 ($ (-1191))) (-15 -1866 ($ (-658 (-1191)))) (-15 -1863 ($ (-1191))) (-15 -3275 ($ (-1191))) (-15 -4139 ($ (-1191))) (-15 -3199 ((-3 (-57) "failed") (-658 $) (-1191)))))) (T -489)) 
+((-3751 (*1 *1 *2) (-12 (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-489)))) (-3912 (*1 *1 *2) (-12 (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-489)))) (-2530 (*1 *1 *2) (-12 (-5 *2 (-3 (-944) "arbitrary")) (-5 *1 (-489)))) (-3130 (*1 *1 *2) (-12 (-5 *2 (-3 (-944) "arbitrary")) (-5 *1 (-489)))) (-3155 (*1 *1 *2) (-12 (-5 *2 (-3 (-944) (-141))) (-5 *1 (-489)))) (-4221 (*1 *1 *2) (-12 (-5 *2 (-3 (-944) (-141))) (-5 *1 (-489)))) (-2458 (*1 *1 *2) (-12 (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-489)))) (-1698 (*1 *1 *2) (-12 (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-489)))) (-3929 (*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-489)))) (-3520 (*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-489)))) (-1746 (*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-489)))) (-3971 (*1 *1 *2) (-12 (-5 *2 (-3 "skip" "MonteCarlo" "deterministic")) (-5 *1 (-489)))) (-3346 (*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-489)))) (-1409 (*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-489)))) (-4439 (*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-489)))) (-4049 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-489)))) (-1866 (*1 *1 *2) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-489)))) (-1863 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-489)))) (-3275 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-489)))) (-4139 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-489)))) (-3199 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-658 (-489))) (-5 *4 (-1191)) (-5 *2 (-57)) (-5 *1 (-489))))) 
+(-13 (-1119) (-10 -8 (-15 -3751 ($ (-3 (-790) "arbitrary"))) (-15 -3912 ($ (-3 (-790) "arbitrary"))) (-15 -2530 ($ (-3 (-944) "arbitrary"))) (-15 -3130 ($ (-3 (-944) "arbitrary"))) (-15 -3155 ($ (-3 (-944) (-141)))) (-15 -4221 ($ (-3 (-944) (-141)))) (-15 -2458 ($ (-3 (-790) "arbitrary"))) (-15 -1698 ($ (-3 (-790) "arbitrary"))) (-15 -3929 ($ (-790))) (-15 -3520 ($ (-141))) (-15 -1746 ($ (-790))) (-15 -3971 ($ (-3 "skip" "MonteCarlo" "deterministic"))) (-15 -3346 ($ (-141))) (-15 -1409 ($ (-141))) (-15 -4439 ($ (-141))) (-15 -4049 ($ (-1191))) (-15 -1866 ($ (-658 (-1191)))) (-15 -1863 ($ (-1191))) (-15 -3275 ($ (-1191))) (-15 -4139 ($ (-1191))) (-15 -3199 ((-3 (-57) "failed") (-658 $) (-1191))))) 
+((-3967 (((-3 |#5| "failed") |#5| |#2| (-1 |#2|)) 35))) 
+(((-490 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3967 ((-3 |#5| "failed") |#5| |#2| (-1 |#2|)))) (-815) (-869) (-582) (-977 |#3| |#1| |#2|) (-13 (-1065 (-433 (-592))) (-388) (-10 -8 (-15 -1683 ($ |#4|)) (-15 -1448 (|#4| $)) (-15 -1456 (|#4| $))))) (T -490)) 
+((-3967 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *4 (-1 *3)) (-4 *3 (-869)) (-4 *5 (-815)) (-4 *6 (-582)) (-4 *7 (-977 *6 *5 *3)) (-5 *1 (-490 *5 *3 *6 *7 *2)) (-4 *2 (-13 (-1065 (-433 (-592))) (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $)))))))) 
+(-10 -7 (-15 -3967 ((-3 |#5| "failed") |#5| |#2| (-1 |#2|)))) 
+((-3427 ((|#3|) 43)) (-2589 (((-658 |#5|)) 47)) (-2671 (((-658 |#5|) (-658 |#5|)) 129)) (-3822 ((|#3| |#3|) 107)) (-3796 (((-1285)) 106)) (-3969 (((-658 |#5|)) 150 (|has| |#1| (-394)))) (-2463 (((-658 |#7|)) 153 (|has| |#1| (-394)))) (-3891 (((-1285) (-658 (-141))) 120)) (-3405 ((|#5| |#7|) 94)) (-2742 (((-658 |#7|) (-944)) 149 (|has| |#1| (-394)))) (-3466 (((-658 |#7|) |#5|) 92)) (-1449 ((|#6| |#3| |#7|) 97)) (-1595 (((-592) (-944)) 194 (|has| |#1| (-394)))) (-4056 (((-592) (-944) (-944)) 193 (|has| |#1| (-394)))) (-4530 (((-592) (-944)) 176 (|has| |#1| (-394)))) (-2353 (((-2 (|:| |num| (-658 |#3|)) (|:| |den| |#3|)) |#8|) 69)) (-1587 ((|#8| |#3|) 50)) (-2225 (((-658 |#3|) |#8| (-658 |#3|)) 136)) (-4507 (((-658 |#3|) |#8| (-790)) 65)) (-3315 ((|#3| |#3| (-592)) 40)) (-3567 (((-592)) 74)) (-3918 (((-790)) 73)) (-4389 (((-2 (|:| -2016 (-592)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-592))) |#8| (-592) (-592)) 114)) (-4474 (((-3 |#1| "failed") (-433 |#3|) |#7|) 144) (((-3 |#1| "failed") |#3| |#3| |#7|) 139) (((-3 |#1| "failed") |#3| |#7|) 104)) (-2806 ((|#1| (-433 |#3|) |#7|) 145) ((|#1| |#3| |#3| |#7|) 140) ((|#1| |#3| |#7|) 105)) (-1488 (((-658 |#10|)) 70)) (-3166 (((-658 |#10|)) 45)) (-2825 (((-592)) 204 (|has| |#1| (-394)))) (-2269 ((|#8|) 54)) (-2665 (((-1275 (-592) -4132) (-944)) 155 (|has| |#1| (-394))) (((-1275 (-592) -4132)) 156 (|has| |#1| (-394)))) (-2821 (((-1187 (-592)) (-944)) 158 (|has| |#1| (-394))) (((-1187 (-592))) 196 (|has| |#1| (-394))))) 
+(((-491 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -3796 ((-1285))) (-15 -3822 (|#3| |#3|)) (-15 -3315 (|#3| |#3| (-592))) (-15 -3891 ((-1285) (-658 (-141)))) (-15 -3427 (|#3|)) (-15 -3918 ((-790))) (-15 -3567 ((-592))) (-15 -3166 ((-658 |#10|))) (-15 -1488 ((-658 |#10|))) (-15 -2671 ((-658 |#5|) (-658 |#5|))) (-15 -2589 ((-658 |#5|))) (-15 -1449 (|#6| |#3| |#7|)) (-15 -2353 ((-2 (|:| |num| (-658 |#3|)) (|:| |den| |#3|)) |#8|)) (-15 -4389 ((-2 (|:| -2016 (-592)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-592))) |#8| (-592) (-592))) (-15 -4507 ((-658 |#3|) |#8| (-790))) (-15 -2225 ((-658 |#3|) |#8| (-658 |#3|))) (-15 -2806 (|#1| |#3| |#7|)) (-15 -2806 (|#1| |#3| |#3| |#7|)) (-15 -2806 (|#1| (-433 |#3|) |#7|)) (-15 -4474 ((-3 |#1| "failed") |#3| |#7|)) (-15 -4474 ((-3 |#1| "failed") |#3| |#3| |#7|)) (-15 -4474 ((-3 |#1| "failed") (-433 |#3|) |#7|)) (-15 -1587 (|#8| |#3|)) (-15 -2269 (|#8|)) (-15 -3466 ((-658 |#7|) |#5|)) (-15 -3405 (|#5| |#7|)) (IF (|has| |#1| (-394)) (PROGN (-15 -2463 ((-658 |#7|))) (-15 -3969 ((-658 |#5|))) (-15 -2821 ((-1187 (-592)))) (-15 -2821 ((-1187 (-592)) (-944))) (-15 -2825 ((-592))) (-15 -2742 ((-658 |#7|) (-944))) (-15 -4530 ((-592) (-944))) (-15 -1595 ((-592) (-944))) (-15 -4056 ((-592) (-944) (-944))) (-15 -2665 ((-1275 (-592) -4132))) (-15 -2665 ((-1275 (-592) -4132) (-944)))) |noBranch|)) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|) (-665 |#1|) (-947 |#1| |#6|) (-257 |#7|) (-560 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-280 |#9|) (-137)) (T -491)) 
+((-2665 (*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) (-2665 (*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-4056 (*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) (-1595 (*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) (-4530 (*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) (-2742 (*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-658 *10)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) (-2825 (*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-2821 (*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-1187 (-592))) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) (-2821 (*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-1187 (-592))) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3969 (*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *7)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-2463 (*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *9)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3405 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-665 *4)) (-4 *3 (-947 *4 *8)) (-4 *9 (-257 *3)) (-4 *10 (-560 *4 *5 *6 *7 *2 *8 *3 *9 *12)) (-4 *12 (-137)) (-4 *2 (-999 *4)) (-5 *1 (-491 *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) (-3466 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *3 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *6 *7 *3 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *9)) (-5 *1 (-491 *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-2269 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-560 *3 *4 *5 *6 *7 *8 *9 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *9)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-280 *10)))) (-1587 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-560 *4 *5 *3 *6 *7 *8 *9 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *9)) (-5 *1 (-491 *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-280 *10)))) (-4474 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 *6)) (-4 *6 (-977 *2 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-14 *5 (-658 (-1191))) (-4 *8 (-999 *2)) (-4 *9 (-665 *2)) (-4 *4 (-947 *2 *9)) (-4 *10 (-257 *4)) (-4 *11 (-560 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-4474 (*1 *2 *3 *3 *4) (|partial| -12 (-14 *5 (-658 (-1191))) (-4 *3 (-977 *2 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *2)) (-4 *8 (-665 *2)) (-4 *4 (-947 *2 *8)) (-4 *9 (-257 *4)) (-4 *10 (-560 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) (-4474 (*1 *2 *3 *4) (|partial| -12 (-14 *5 (-658 (-1191))) (-4 *3 (-977 *2 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *2)) (-4 *8 (-665 *2)) (-4 *4 (-947 *2 *8)) (-4 *9 (-257 *4)) (-4 *10 (-560 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) (-2806 (*1 *2 *3 *4) (-12 (-5 *3 (-433 *6)) (-4 *6 (-977 *2 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-14 *5 (-658 (-1191))) (-4 *8 (-999 *2)) (-4 *9 (-665 *2)) (-4 *4 (-947 *2 *9)) (-4 *10 (-257 *4)) (-4 *11 (-560 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-2806 (*1 *2 *3 *3 *4) (-12 (-14 *5 (-658 (-1191))) (-4 *3 (-977 *2 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *2)) (-4 *8 (-665 *2)) (-4 *4 (-947 *2 *8)) (-4 *9 (-257 *4)) (-4 *10 (-560 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) (-2806 (*1 *2 *3 *4) (-12 (-14 *5 (-658 (-1191))) (-4 *3 (-977 *2 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *2)) (-4 *8 (-665 *2)) (-4 *4 (-947 *2 *8)) (-4 *9 (-257 *4)) (-4 *10 (-560 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) (-2225 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *3 (-257 *10)) (-4 *11 (-560 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-137)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-280 *11)))) (-4507 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) *4)) (-4 *9 (-999 *5)) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-4 *3 (-257 *11)) (-4 *12 (-560 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-137)) (-5 *2 (-658 *7)) (-5 *1 (-491 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-4 *13 (-280 *12)))) (-4389 (*1 *2 *3 *4 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) (-790))) (-4 *9 (-999 *5)) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-4 *3 (-257 *11)) (-4 *12 (-560 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-137)) (-5 *2 (-2 (|:| -2016 (-592)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (-592)))) (-5 *1 (-491 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-5 *4 (-592)) (-4 *13 (-280 *12)))) (-2353 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *3 (-257 *10)) (-4 *11 (-560 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-137)) (-5 *2 (-2 (|:| |num| (-658 *6)) (|:| |den| *6))) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-280 *11)))) (-1449 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *8 (-999 *5)) (-4 *4 (-947 *5 *2)) (-4 *9 (-257 *4)) (-4 *10 (-560 *5 *6 *3 *7 *8 *2 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-665 *5)) (-5 *1 (-491 *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) (-2589 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *7)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-2671 (*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-999 *3)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-1488 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *12)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3166 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *12)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3567 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3918 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-790)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3427 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-252 (-1699 *4) (-790))) (-4 *6 (-999 *3)) (-4 *7 (-665 *3)) (-4 *8 (-947 *3 *7)) (-4 *9 (-257 *8)) (-4 *10 (-560 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-137)) (-4 *2 (-977 *3 *5 (-879 *4))) (-5 *1 (-491 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) (-3891 (*1 *2 *3) (-12 (-5 *3 (-658 (-141))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-1285)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) (-3315 (*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *2 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *2 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *1 (-491 *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) (-3822 (*1 *2 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *2 (-977 *3 *5 (-879 *4))) (-4 *5 (-252 (-1699 *4) (-790))) (-4 *6 (-999 *3)) (-4 *7 (-665 *3)) (-4 *8 (-947 *3 *7)) (-4 *9 (-257 *8)) (-4 *10 (-560 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-137)) (-5 *1 (-491 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) (-3796 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11))))) 
+(-10 -7 (-15 -3796 ((-1285))) (-15 -3822 (|#3| |#3|)) (-15 -3315 (|#3| |#3| (-592))) (-15 -3891 ((-1285) (-658 (-141)))) (-15 -3427 (|#3|)) (-15 -3918 ((-790))) (-15 -3567 ((-592))) (-15 -3166 ((-658 |#10|))) (-15 -1488 ((-658 |#10|))) (-15 -2671 ((-658 |#5|) (-658 |#5|))) (-15 -2589 ((-658 |#5|))) (-15 -1449 (|#6| |#3| |#7|)) (-15 -2353 ((-2 (|:| |num| (-658 |#3|)) (|:| |den| |#3|)) |#8|)) (-15 -4389 ((-2 (|:| -2016 (-592)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-592))) |#8| (-592) (-592))) (-15 -4507 ((-658 |#3|) |#8| (-790))) (-15 -2225 ((-658 |#3|) |#8| (-658 |#3|))) (-15 -2806 (|#1| |#3| |#7|)) (-15 -2806 (|#1| |#3| |#3| |#7|)) (-15 -2806 (|#1| (-433 |#3|) |#7|)) (-15 -4474 ((-3 |#1| "failed") |#3| |#7|)) (-15 -4474 ((-3 |#1| "failed") |#3| |#3| |#7|)) (-15 -4474 ((-3 |#1| "failed") (-433 |#3|) |#7|)) (-15 -1587 (|#8| |#3|)) (-15 -2269 (|#8|)) (-15 -3466 ((-658 |#7|) |#5|)) (-15 -3405 (|#5| |#7|)) (IF (|has| |#1| (-394)) (PROGN (-15 -2463 ((-658 |#7|))) (-15 -3969 ((-658 |#5|))) (-15 -2821 ((-1187 (-592)))) (-15 -2821 ((-1187 (-592)) (-944))) (-15 -2825 ((-592))) (-15 -2742 ((-658 |#7|) (-944))) (-15 -4530 ((-592) (-944))) (-15 -1595 ((-592) (-944))) (-15 -4056 ((-592) (-944) (-944))) (-15 -2665 ((-1275 (-592) -4132))) (-15 -2665 ((-1275 (-592) -4132) (-944)))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-4085 (((-658 |#3|) $) 41)) (-4325 (((-141) $) NIL)) (-2988 (((-141) $) NIL (|has| |#1| (-582)))) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3113 (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-3239 (((-141) $) NIL (|has| |#1| (-582)))) (-3478 (((-141) $ $) NIL (|has| |#1| (-582)))) (-2398 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1529 (((-141) $) NIL (|has| |#1| (-582)))) (-4521 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) 47)) (-2400 (($ (-658 |#4|)) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-4459 (($ |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-582)))) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4625)))) (-4004 (((-658 |#4|) $) 18 (|has| $ (-6 -4625)))) (-3259 ((|#3| $) 45)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#4|) $) 14 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 26 (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-3987 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 21)) (-2290 (((-658 |#3|) $) NIL)) (-2645 (((-141) |#3| $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-582)))) (-2951 (((-1137) $) NIL)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) NIL)) (-3002 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 39)) (-2890 (($) 17)) (-3452 (((-790) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (((-790) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) 16)) (-1778 (((-565) $) NIL (|has| |#4| (-633 (-565)))) (($ (-658 |#4|)) 49)) (-4466 (($ (-658 |#4|)) 13)) (-2613 (($ $ |#3|) NIL)) (-4152 (($ $ |#3|) NIL)) (-2507 (($ $ |#3|) NIL)) (-1683 (((-877) $) 38) (((-658 |#4|) $) 48)) (-3369 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 30)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-492 |#1| |#2| |#3| |#4|) (-13 (-1005 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -1778 ($ (-658 |#4|))) (-6 -4625) (-6 -4626))) (-1075) (-815) (-869) (-1089 |#1| |#2| |#3|)) (T -492)) 
+((-1778 (*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-492 *3 *4 *5 *6))))) 
+(-13 (-1005 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -1778 ($ (-658 |#4|))) (-6 -4625) (-6 -4626))) 
+((-3514 (($) 11)) (-4257 (($) 13)) (* (($ |#2| $) 15) (($ $ |#2|) 16))) 
+(((-493 |#1| |#2| |#3|) (-10 -8 (-15 -4257 (|#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -3514 (|#1|))) (-494 |#2| |#3|) (-194) (-23)) (T -493)) 
+NIL 
+(-10 -8 (-15 -4257 (|#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -3514 (|#1|))) 
+((-1641 (((-141) $ $) 7)) (-4368 (((-3 |#1| "failed") $) 23)) (-2400 ((|#1| $) 22)) (-3679 (($ $ $) 20)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-4525 ((|#2| $) 18)) (-1683 (((-877) $) 11) (($ |#1|) 24)) (-3514 (($) 17 T CONST)) (-4257 (($) 21 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 14) (($ $ $) 12)) (-3300 (($ $ $) 13)) (* (($ |#1| $) 16) (($ $ |#1|) 15))) 
+(((-494 |#1| |#2|) (-1311) (-194) (-23)) (T -494)) 
+((-4257 (*1 *1) (-12 (-4 *1 (-494 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) (-3679 (*1 *1 *1 *1) (-12 (-4 *1 (-494 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23))))) 
+(-13 (-499 |t#1| |t#2|) (-1065 |t#1|) (-10 -8 (-15 (-4257) ($) -4249) (-15 -3679 ($ $ $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-499 |#1| |#2|) . T) ((-1065 |#1|) . T) ((-1119) . T)) 
+((-4117 (((-1280 (-1280 (-592))) (-1280 (-1280 (-592))) (-944)) 18)) (-1891 (((-1280 (-1280 (-592))) (-944)) 16))) 
+(((-495) (-10 -7 (-15 -4117 ((-1280 (-1280 (-592))) (-1280 (-1280 (-592))) (-944))) (-15 -1891 ((-1280 (-1280 (-592))) (-944))))) (T -495)) 
+((-1891 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 (-1280 (-592)))) (-5 *1 (-495)))) (-4117 (*1 *2 *2 *3) (-12 (-5 *2 (-1280 (-1280 (-592)))) (-5 *3 (-944)) (-5 *1 (-495))))) 
+(-10 -7 (-15 -4117 ((-1280 (-1280 (-592))) (-1280 (-1280 (-592))) (-944))) (-15 -1891 ((-1280 (-1280 (-592))) (-944)))) 
+((-1793 (((-592) (-592)) 30) (((-592)) 22)) (-2320 (((-592) (-592)) 26) (((-592)) 18)) (-3866 (((-592) (-592)) 28) (((-592)) 20)) (-2315 (((-141) (-141)) 12) (((-141)) 10)) (-2304 (((-141) (-141)) 11) (((-141)) 9)) (-1804 (((-141) (-141)) 24) (((-141)) 15))) 
+(((-496) (-10 -7 (-15 -2304 ((-141))) (-15 -2315 ((-141))) (-15 -2304 ((-141) (-141))) (-15 -2315 ((-141) (-141))) (-15 -1804 ((-141))) (-15 -3866 ((-592))) (-15 -2320 ((-592))) (-15 -1793 ((-592))) (-15 -1804 ((-141) (-141))) (-15 -3866 ((-592) (-592))) (-15 -2320 ((-592) (-592))) (-15 -1793 ((-592) (-592))))) (T -496)) 
+((-1793 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) (-2320 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) (-3866 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) (-1804 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496)))) (-1793 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) (-2320 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) (-3866 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) (-1804 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496)))) (-2315 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496)))) (-2304 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496)))) (-2315 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496)))) (-2304 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496))))) 
+(-10 -7 (-15 -2304 ((-141))) (-15 -2315 ((-141))) (-15 -2304 ((-141) (-141))) (-15 -2315 ((-141) (-141))) (-15 -1804 ((-141))) (-15 -3866 ((-592))) (-15 -2320 ((-592))) (-15 -1793 ((-592))) (-15 -1804 ((-141) (-141))) (-15 -3866 ((-592) (-592))) (-15 -2320 ((-592) (-592))) (-15 -1793 ((-592) (-592)))) 
+((-1641 (((-141) $ $) NIL)) (-3682 (((-658 (-405)) $) 27) (((-658 (-405)) $ (-658 (-405))) 90)) (-1443 (((-658 (-1113 (-405))) $) 14) (((-658 (-1113 (-405))) $ (-658 (-1113 (-405)))) 87)) (-3072 (((-658 (-658 (-971 (-237)))) (-658 (-658 (-971 (-237)))) (-658 (-896))) 42)) (-2896 (((-658 (-658 (-971 (-237)))) $) 83)) (-1831 (((-1285) $ (-971 (-237)) (-896)) 103)) (-3323 (($ $) 82) (($ (-658 (-658 (-971 (-237))))) 93) (($ (-658 (-658 (-971 (-237)))) (-658 (-896)) (-658 (-896)) (-658 (-944))) 92) (($ (-658 (-658 (-971 (-237)))) (-658 (-896)) (-658 (-896)) (-658 (-944)) (-658 (-278))) 94)) (-2685 (((-1173) $) NIL)) (-1350 (((-592) $) 65)) (-2951 (((-1137) $) NIL)) (-2997 (($) 91)) (-2801 (((-658 (-237)) (-658 (-658 (-971 (-237))))) 52)) (-2181 (((-1285) $ (-658 (-971 (-237))) (-896) (-896) (-944)) 97) (((-1285) $ (-971 (-237))) 99) (((-1285) $ (-971 (-237)) (-896) (-896) (-944)) 98)) (-1683 (((-877) $) 109) (($ (-658 (-658 (-971 (-237))))) 104)) (-3950 (((-1285) $ (-971 (-237))) 102)) (-3255 (((-141) $ $) NIL))) 
+(((-497) (-13 (-1119) (-10 -8 (-15 -2997 ($)) (-15 -3323 ($ $)) (-15 -3323 ($ (-658 (-658 (-971 (-237)))))) (-15 -3323 ($ (-658 (-658 (-971 (-237)))) (-658 (-896)) (-658 (-896)) (-658 (-944)))) (-15 -3323 ($ (-658 (-658 (-971 (-237)))) (-658 (-896)) (-658 (-896)) (-658 (-944)) (-658 (-278)))) (-15 -2896 ((-658 (-658 (-971 (-237)))) $)) (-15 -1350 ((-592) $)) (-15 -1443 ((-658 (-1113 (-405))) $)) (-15 -1443 ((-658 (-1113 (-405))) $ (-658 (-1113 (-405))))) (-15 -3682 ((-658 (-405)) $)) (-15 -3682 ((-658 (-405)) $ (-658 (-405)))) (-15 -2181 ((-1285) $ (-658 (-971 (-237))) (-896) (-896) (-944))) (-15 -2181 ((-1285) $ (-971 (-237)))) (-15 -2181 ((-1285) $ (-971 (-237)) (-896) (-896) (-944))) (-15 -3950 ((-1285) $ (-971 (-237)))) (-15 -1831 ((-1285) $ (-971 (-237)) (-896))) (-15 -1683 ($ (-658 (-658 (-971 (-237)))))) (-15 -1683 ((-877) $)) (-15 -3072 ((-658 (-658 (-971 (-237)))) (-658 (-658 (-971 (-237)))) (-658 (-896)))) (-15 -2801 ((-658 (-237)) (-658 (-658 (-971 (-237))))))))) (T -497)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-497)))) (-2997 (*1 *1) (-5 *1 (-497))) (-3323 (*1 *1 *1) (-5 *1 (-497))) (-3323 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *1 (-497)))) (-3323 (*1 *1 *2 *3 *3 *4) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *3 (-658 (-896))) (-5 *4 (-658 (-944))) (-5 *1 (-497)))) (-3323 (*1 *1 *2 *3 *3 *4 *5) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *3 (-658 (-896))) (-5 *4 (-658 (-944))) (-5 *5 (-658 (-278))) (-5 *1 (-497)))) (-2896 (*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *1 (-497)))) (-1350 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-497)))) (-1443 (*1 *2 *1) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-497)))) (-1443 (*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-497)))) (-3682 (*1 *2 *1) (-12 (-5 *2 (-658 (-405))) (-5 *1 (-497)))) (-3682 (*1 *2 *1 *2) (-12 (-5 *2 (-658 (-405))) (-5 *1 (-497)))) (-2181 (*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-658 (-971 (-237)))) (-5 *4 (-896)) (-5 *5 (-944)) (-5 *2 (-1285)) (-5 *1 (-497)))) (-2181 (*1 *2 *1 *3) (-12 (-5 *3 (-971 (-237))) (-5 *2 (-1285)) (-5 *1 (-497)))) (-2181 (*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-971 (-237))) (-5 *4 (-896)) (-5 *5 (-944)) (-5 *2 (-1285)) (-5 *1 (-497)))) (-3950 (*1 *2 *1 *3) (-12 (-5 *3 (-971 (-237))) (-5 *2 (-1285)) (-5 *1 (-497)))) (-1831 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-971 (-237))) (-5 *4 (-896)) (-5 *2 (-1285)) (-5 *1 (-497)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *1 (-497)))) (-3072 (*1 *2 *2 *3) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *3 (-658 (-896))) (-5 *1 (-497)))) (-2801 (*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *2 (-658 (-237))) (-5 *1 (-497))))) 
+(-13 (-1119) (-10 -8 (-15 -2997 ($)) (-15 -3323 ($ $)) (-15 -3323 ($ (-658 (-658 (-971 (-237)))))) (-15 -3323 ($ (-658 (-658 (-971 (-237)))) (-658 (-896)) (-658 (-896)) (-658 (-944)))) (-15 -3323 ($ (-658 (-658 (-971 (-237)))) (-658 (-896)) (-658 (-896)) (-658 (-944)) (-658 (-278)))) (-15 -2896 ((-658 (-658 (-971 (-237)))) $)) (-15 -1350 ((-592) $)) (-15 -1443 ((-658 (-1113 (-405))) $)) (-15 -1443 ((-658 (-1113 (-405))) $ (-658 (-1113 (-405))))) (-15 -3682 ((-658 (-405)) $)) (-15 -3682 ((-658 (-405)) $ (-658 (-405)))) (-15 -2181 ((-1285) $ (-658 (-971 (-237))) (-896) (-896) (-944))) (-15 -2181 ((-1285) $ (-971 (-237)))) (-15 -2181 ((-1285) $ (-971 (-237)) (-896) (-896) (-944))) (-15 -3950 ((-1285) $ (-971 (-237)))) (-15 -1831 ((-1285) $ (-971 (-237)) (-896))) (-15 -1683 ($ (-658 (-658 (-971 (-237)))))) (-15 -1683 ((-877) $)) (-15 -3072 ((-658 (-658 (-971 (-237)))) (-658 (-658 (-971 (-237)))) (-658 (-896)))) (-15 -2801 ((-658 (-237)) (-658 (-658 (-971 (-237)))))))) 
+((-3306 (($ $) NIL) (($ $ $) 11))) 
+(((-498 |#1| |#2| |#3|) (-10 -8 (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|))) (-499 |#2| |#3|) (-194) (-23)) (T -498)) 
+NIL 
+(-10 -8 (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-4525 ((|#2| $) 18)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 14) (($ $ $) 12)) (-3300 (($ $ $) 13)) (* (($ |#1| $) 16) (($ $ |#1|) 15))) 
+(((-499 |#1| |#2|) (-1311) (-194) (-23)) (T -499)) 
+((-4525 (*1 *2 *1) (-12 (-4 *1 (-499 *3 *2)) (-4 *3 (-194)) (-4 *2 (-23)))) (-3514 (*1 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) (-3306 (*1 *1 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) (-3300 (*1 *1 *1 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) (-3306 (*1 *1 *1 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23))))) 
+(-13 (-1119) (-10 -8 (-15 -4525 (|t#2| $)) (-15 (-3514) ($) -4249) (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|)) (-15 -3306 ($ $)) (-15 -3300 ($ $ $)) (-15 -3306 ($ $ $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1742 (((-3 (-658 (-516 |#1| |#2|)) "failed") (-658 (-516 |#1| |#2|)) (-658 (-879 |#1|))) 88)) (-4428 (((-658 (-658 (-264 |#1| |#2|))) (-658 (-264 |#1| |#2|)) (-658 (-879 |#1|))) 86)) (-3138 (((-2 (|:| |dpolys| (-658 (-264 |#1| |#2|))) (|:| |coords| (-658 (-592)))) (-658 (-264 |#1| |#2|)) (-658 (-879 |#1|))) 58))) 
+(((-500 |#1| |#2| |#3|) (-10 -7 (-15 -4428 ((-658 (-658 (-264 |#1| |#2|))) (-658 (-264 |#1| |#2|)) (-658 (-879 |#1|)))) (-15 -1742 ((-3 (-658 (-516 |#1| |#2|)) "failed") (-658 (-516 |#1| |#2|)) (-658 (-879 |#1|)))) (-15 -3138 ((-2 (|:| |dpolys| (-658 (-264 |#1| |#2|))) (|:| |coords| (-658 (-592)))) (-658 (-264 |#1| |#2|)) (-658 (-879 |#1|))))) (-658 (-1191)) (-477) (-477)) (T -500)) 
+((-3138 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-879 *5))) (-14 *5 (-658 (-1191))) (-4 *6 (-477)) (-5 *2 (-2 (|:| |dpolys| (-658 (-264 *5 *6))) (|:| |coords| (-658 (-592))))) (-5 *1 (-500 *5 *6 *7)) (-5 *3 (-658 (-264 *5 *6))) (-4 *7 (-477)))) (-1742 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-516 *4 *5))) (-5 *3 (-658 (-879 *4))) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *1 (-500 *4 *5 *6)) (-4 *6 (-477)))) (-4428 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-879 *5))) (-14 *5 (-658 (-1191))) (-4 *6 (-477)) (-5 *2 (-658 (-658 (-264 *5 *6)))) (-5 *1 (-500 *5 *6 *7)) (-5 *3 (-658 (-264 *5 *6))) (-4 *7 (-477))))) 
+(-10 -7 (-15 -4428 ((-658 (-658 (-264 |#1| |#2|))) (-658 (-264 |#1| |#2|)) (-658 (-879 |#1|)))) (-15 -1742 ((-3 (-658 (-516 |#1| |#2|)) "failed") (-658 (-516 |#1| |#2|)) (-658 (-879 |#1|)))) (-15 -3138 ((-2 (|:| |dpolys| (-658 (-264 |#1| |#2|))) (|:| |coords| (-658 (-592)))) (-658 (-264 |#1| |#2|)) (-658 (-879 |#1|))))) 
+((-3371 (((-3 $ "failed") $) 11)) (-2227 (($ $ $) 20)) (-2131 (($ $ $) 21)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 14)) (-3313 (($ $ $) 9)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 19))) 
+(((-501 |#1|) (-10 -8 (-15 -2131 (|#1| |#1| |#1|)) (-15 -2227 (|#1| |#1| |#1|)) (-15 -1424 (|#1| |#1| (-592))) (-15 ** (|#1| |#1| (-592))) (-15 -3313 (|#1| |#1| |#1|)) (-15 -3371 ((-3 |#1| "failed") |#1|)) (-15 -1424 (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-790))) (-15 -1424 (|#1| |#1| (-944))) (-15 ** (|#1| |#1| (-944)))) (-502)) (T -501)) 
+NIL 
+(-10 -8 (-15 -2131 (|#1| |#1| |#1|)) (-15 -2227 (|#1| |#1| |#1|)) (-15 -1424 (|#1| |#1| (-592))) (-15 ** (|#1| |#1| (-592))) (-15 -3313 (|#1| |#1| |#1|)) (-15 -3371 ((-3 |#1| "failed") |#1|)) (-15 -1424 (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-790))) (-15 -1424 (|#1| |#1| (-944))) (-15 ** (|#1| |#1| (-944)))) 
+((-1641 (((-141) $ $) 7)) (-3001 (($) 19 T CONST)) (-3371 (((-3 $ "failed") $) 15)) (-3558 (((-141) $) 18)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 26)) (-2951 (((-1137) $) 10)) (-2227 (($ $ $) 22)) (-2131 (($ $ $) 21)) (-1683 (((-877) $) 11)) (-1424 (($ $ (-944)) 12) (($ $ (-790)) 16) (($ $ (-592)) 23)) (-4257 (($) 20 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 25)) (** (($ $ (-944)) 13) (($ $ (-790)) 17) (($ $ (-592)) 24)) (* (($ $ $) 14))) 
+(((-502) (-1311)) (T -502)) 
+((-4552 (*1 *1 *1) (-4 *1 (-502))) (-3313 (*1 *1 *1 *1) (-4 *1 (-502))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-502)) (-5 *2 (-592)))) (-1424 (*1 *1 *1 *2) (-12 (-4 *1 (-502)) (-5 *2 (-592)))) (-2227 (*1 *1 *1 *1) (-4 *1 (-502))) (-2131 (*1 *1 *1 *1) (-4 *1 (-502)))) 
+(-13 (-743) (-10 -8 (-15 -4552 ($ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ (-592))) (-15 -1424 ($ $ (-592))) (-6 -4622) (-15 -2227 ($ $ $)) (-15 -2131 ($ $ $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-743) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 17)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-433 (-592))) NIL) (($ $ (-433 (-592)) (-433 (-592))) NIL)) (-2982 (((-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|))) $) NIL)) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-790) (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|)))) NIL)) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-433 (-592)) $) NIL) (((-433 (-592)) $ (-433 (-592))) NIL)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) NIL) (($ $ (-433 (-592))) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-433 (-592))) NIL) (($ $ (-1103) (-433 (-592))) NIL) (($ $ (-658 (-1103)) (-658 (-433 (-592)))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) 22)) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-3162 (($ $) 26 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 33 (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 |#2|)) 27 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-2807 (($ $ (-433 (-592))) NIL)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ (-433 (-592))) NIL) (($ $ $) NIL (|has| (-433 (-592)) (-1131)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) 25 (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) 13 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $ (-1276 |#2|)) 15)) (-4525 (((-433 (-592)) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL (|has| |#1| (-194))) (($ (-1276 |#2|)) NIL) (($ (-1264 |#1| |#2| |#3|)) 9) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582)))) (-1937 ((|#1| $ (-433 (-592))) NIL)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) 18)) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-433 (-592))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) 24)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 23) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-503 |#1| |#2| |#3|) (-13 (-1260 |#1|) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -1683 ($ (-1264 |#1| |#2| |#3|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) (-1075) (-1191) |#1|) (T -503)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-503 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1264 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3) (-5 *1 (-503 *3 *4 *5)))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-503 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-503 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3)))) 
+(-13 (-1260 |#1|) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -1683 ($ (-1264 |#1| |#2| |#3|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3898 (((-1285) $ |#1| |#1|) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#2| $ |#1| |#2|) 18)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 |#2| "failed") |#1| $) 19)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) 16)) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) NIL)) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 ((|#1| $) NIL (|has| |#1| (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 ((|#1| $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-2840 (((-658 |#1|) $) NIL)) (-2396 (((-141) |#1| $) NIL)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3708 (((-658 |#1|) $) NIL)) (-3780 (((-141) |#1| $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1918 ((|#2| $) NIL (|has| |#1| (-869)))) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ |#1|) 13) ((|#2| $ |#1| |#2|) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-504 |#1| |#2| |#3| |#4|) (-1202 |#1| |#2|) (-1119) (-1119) (-1202 |#1| |#2|) |#2|) (T -504)) 
+NIL 
+(-1202 |#1| |#2|) 
+((-1641 (((-141) $ $) NIL)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) NIL)) (-2248 (((-658 $) (-658 |#4|)) NIL)) (-4085 (((-658 |#3|) $) NIL)) (-4325 (((-141) $) NIL)) (-2988 (((-141) $) NIL (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-2244 ((|#4| |#4| $) NIL)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3113 (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) NIL)) (-3001 (($) NIL T CONST)) (-3239 (((-141) $) 26 (|has| |#1| (-582)))) (-3478 (((-141) $ $) NIL (|has| |#1| (-582)))) (-2398 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1529 (((-141) $) NIL (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-4521 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) NIL)) (-2400 (($ (-658 |#4|)) NIL)) (-1366 (((-3 $ "failed") $) 39)) (-2226 ((|#4| |#4| $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-4459 (($ |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) NIL)) (-3092 ((|#4| |#4| $) NIL)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) NIL)) (-4004 (((-658 |#4|) $) 16 (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#4|) $) 17 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 25 (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-3987 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 21)) (-2290 (((-658 |#3|) $) NIL)) (-2645 (((-141) |#3| $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-4255 (((-3 |#4| "failed") $) 37)) (-1712 (((-658 |#4|) $) NIL)) (-2346 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1751 ((|#4| |#4| $) NIL)) (-3085 (((-141) $ $) NIL)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1803 ((|#4| |#4| $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-3 |#4| "failed") $) 35)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) NIL)) (-2778 (((-3 $ "failed") $ |#4|) 46)) (-2807 (($ $ |#4|) NIL)) (-3002 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 15)) (-2890 (($) 13)) (-4525 (((-790) $) NIL)) (-3452 (((-790) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (((-790) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) 12)) (-1778 (((-565) $) NIL (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 20)) (-2613 (($ $ |#3|) 42)) (-4152 (($ $ |#3|) 43)) (-2965 (($ $) NIL)) (-2507 (($ $ |#3|) NIL)) (-1683 (((-877) $) 31) (((-658 |#4|) $) 40)) (-1857 (((-790) $) NIL (|has| |#3| (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) NIL)) (-3369 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) NIL)) (-3069 (((-141) |#3| $) NIL)) (-3255 (((-141) $ $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-505 |#1| |#2| |#3| |#4|) (-1219 |#1| |#2| |#3| |#4|) (-582) (-815) (-869) (-1089 |#1| |#2| |#3|)) (T -505)) 
+NIL 
+(-1219 |#1| |#2| |#3| |#4|) 
+((-1809 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))) (-1191)) NIL (|has| (-53) (-1065 (-1191)))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))) NIL)) (-3507 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)) NIL (|has| (-53) (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL)) (-2780 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)) NIL (|has| (-53) (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL)) (-4126 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL)) (-4166 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)) NIL (|has| (-53) (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL)) (-1835 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL)) (-4351 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) NIL)) (-1500 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)) NIL (|has| (-53) (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL)) (-3610 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)) NIL (|has| (-53) (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL)) (-1926 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL)) (-2948 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)) NIL (|has| (-53) (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL)) (-3351 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-658 (-1191)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-658 (-1191))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53))) NIL)) (-3090 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))) (-1191)) NIL (|has| (-53) (-1065 (-1191)))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))) NIL))) 
+(((-506) (-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (IF (|has| (-53) (-1065 (-1191))) (IF (|has| (-53) (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (IF (|has| (-53) (-1065 (-1191))) (IF (|has| (-53) (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|))) (T -506)) 
+((-2948 (*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) (-2780 (*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) (-4166 (*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) (-3507 (*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) (-3090 (*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (-5 *1 (-506)))) (-1809 (*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (-5 *1 (-506)))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790))))) (-5 *1 (-506)))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790))))) (-5 *1 (-506)))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-2780 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-4166 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-3507 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-4126 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-4126 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-1835 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-1835 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-1926 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-1926 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-2948 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-2948 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) (-3610 (*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) (-1500 (*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) (-3610 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-1500 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-3351 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-3351 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-3351 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) (-3351 (*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506))))) 
+(-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (IF (|has| (-53) (-1065 (-1191))) (IF (|has| (-53) (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (IF (|has| (-53) (-1065 (-1191))) (IF (|has| (-53) (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|)) 
+((-3803 (((-332 (-592)) |#1|) 11))) 
+(((-507 |#1|) (-10 -7 (-15 -3803 ((-332 (-592)) |#1|))) (-13 (-373) (-633 (-592)))) (T -507)) 
+((-3803 (*1 *2 *3) (-12 (-5 *2 (-332 (-592))) (-5 *1 (-507 *3)) (-4 *3 (-13 (-373) (-633 (-592))))))) 
+(-10 -7 (-15 -3803 ((-332 (-592)) |#1|))) 
+((-1809 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))) (-1191)) NIL (|has| |#1| (-1065 (-1191)))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))) NIL)) (-3507 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) NIL (|has| |#1| (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL)) (-2780 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) NIL (|has| |#1| (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL)) (-4126 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL)) (-4166 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) NIL (|has| |#1| (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL)) (-1835 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL)) (-4351 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489)))) NIL)) (-1500 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) NIL (|has| |#1| (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL)) (-3610 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) NIL (|has| |#1| (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL)) (-1926 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL)) (-2948 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) NIL (|has| |#1| (-1065 (-1191)))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL)) (-3351 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|)) NIL)) (-3090 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))) (-1191)) NIL (|has| |#1| (-1065 (-1191)))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))) NIL))) 
+(((-508 |#1|) (-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (IF (|has| |#1| (-1065 (-1191))) (IF (|has| |#1| (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489)))) (IF (|has| |#1| (-1065 (-1191))) (IF (|has| |#1| (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|)) (-13 (-373) (-633 (-592)))) (T -508)) 
+((-2948 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 *4) (-790)))) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 *4) (-790)))) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 *4) (-790))))) (-5 *1 (-508 *4)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 *4) (-790))))) (-5 *1 (-508 *4)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-2780 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-4166 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-3507 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-4126 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-4126 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-1835 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-1835 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-1926 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-1926 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-2948 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-2948 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 *4) (-790)))) (-658 (-489)))) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) (-3610 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-1500 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) (-3351 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *7) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 *7)) (-4 *7 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *7)))) (-3351 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *6) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 *6)) (-4 *6 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *6)))) (-3351 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) (-3351 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4))))) 
+(-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (IF (|has| |#1| (-1065 (-1191))) (IF (|has| |#1| (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489)))) (IF (|has| |#1| (-1065 (-1191))) (IF (|has| |#1| (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 |#1| (-790) (-790) (-1187 |#1|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 |#1|) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|)) 
+((-1809 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-592)) (-1065 (-1191))) (|has| (-592) (-1065 (-1191))))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))) NIL)) (-3507 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-592)) (-1065 (-1191))) (|has| (-592) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL)) (-2780 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-592)) (-1065 (-1191))) (|has| (-592) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL)) (-4126 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL)) (-4166 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-592)) (-1065 (-1191))) (|has| (-592) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL)) (-1835 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL)) (-4351 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) NIL)) (-1500 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-592)) (-1065 (-1191))) (|has| (-592) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL)) (-3610 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-592)) (-1065 (-1191))) (|has| (-592) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL)) (-1926 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL)) (-2948 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-592)) (-1065 (-1191))) (|has| (-592) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL)) (-3351 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-658 (-1191)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-658 (-1191))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592)))) NIL)) (-3090 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-592)) (-1065 (-1191))) (|has| (-592) (-1065 (-1191))))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))) NIL))) 
+(((-509) (-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (IF (|has| (-433 (-592)) (-1065 (-1191))) (IF (|has| (-592) (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (IF (|has| (-433 (-592)) (-1065 (-1191))) (IF (|has| (-592) (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|))) (T -509)) 
+((-2948 (*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) (-2780 (*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) (-4166 (*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) (-3507 (*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) (-3090 (*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (-5 *1 (-509)))) (-1809 (*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (-5 *1 (-509)))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790))))) (-5 *1 (-509)))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790))))) (-5 *1 (-509)))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-2780 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-4166 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-3507 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-4126 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-4126 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-1835 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-1835 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-1926 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-1926 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-2948 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-2948 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) (-3610 (*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) (-1500 (*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) (-3610 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-1500 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-3351 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-3351 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-3351 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) (-3351 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509))))) 
+(-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (IF (|has| (-433 (-592)) (-1065 (-1191))) (IF (|has| (-592) (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (IF (|has| (-433 (-592)) (-1065 (-1191))) (IF (|has| (-592) (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|)) 
+((-1809 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))) (-1191)) 367 (-12 (|has| |#1| (-1065 (-1191))) (|has| |#2| (-1065 (-1191))))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))) 361)) (-3507 (((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) 484 (-12 (|has| |#1| (-1065 (-1191))) (|has| |#2| (-1065 (-1191))))) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 477) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 478)) (-2780 (((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) 486 (-12 (|has| |#1| (-1065 (-1191))) (|has| |#2| (-1065 (-1191))))) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 483) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 482)) (-4126 (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 475) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 474)) (-4166 (((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) 485 (-12 (|has| |#1| (-1065 (-1191))) (|has| |#2| (-1065 (-1191))))) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 480) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 479)) (-1835 (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 471) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 472)) (-4351 (((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489)))) 463)) (-1500 (((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) 193 (-12 (|has| |#1| (-1065 (-1191))) (|has| |#2| (-1065 (-1191))))) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 191) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 190)) (-3610 (((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) 219 (-12 (|has| |#1| (-1065 (-1191))) (|has| |#2| (-1065 (-1191))))) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 208) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 207)) (-1926 (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 468) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 469)) (-2948 (((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)) 476 (-12 (|has| |#1| (-1065 (-1191))) (|has| |#2| (-1065 (-1191))))) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 464) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 465)) (-3351 (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)) (-658 (-489))) 509) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191))) 514) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) 513) (((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|)) 512)) (-3090 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))) (-1191)) 336 (-12 (|has| |#1| (-1065 (-1191))) (|has| |#2| (-1065 (-1191))))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))) 326))) 
+(((-510 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3351 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1500 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3610 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (IF (|has| |#1| (-1065 (-1191))) (IF (|has| |#2| (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -2948 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1926 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1835 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3507 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3507 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -2780 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489)))) (IF (|has| |#1| (-1065 (-1191))) (IF (|has| |#2| (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|)) (-388) (-477) (-13 (-456 (-592)) (-582) (-1065 |#4|) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $)))) (-13 (-869) (-582)) (-1 |#1| |#4|) (-1 |#3| |#1|)) (T -510)) 
+((-2948 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 *3)) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) *3 *6)) (|:| C (-1 (-658 *5) (-790)))) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 *3)) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) *3 *6)) (|:| C (-1 (-658 *5) (-790)))) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 (-1191))) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) (-1191) *6)) (|:| C (-1 (-658 *5) (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 (-1191))) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) (-1191) *6)) (|:| C (-1 (-658 *5) (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-2780 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-4166 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-3507 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-4126 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-4126 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-1835 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-1835 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-1926 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-1926 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-2948 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-2948 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 (-1191))) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) (-1191) *6)) (|:| C (-1 (-658 *5) (-790)))) (-658 (-489)))) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-14 *9 (-1 *6 *4)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) (-3610 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-1500 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-3351 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 *9) (|:| -4346 (-790)))) (-658 *7) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 *7)) (-4 *7 (-388)) (-14 *12 (-1 *9 *7)) (-4 *10 (-13 (-869) (-582))) (-14 *11 (-1 *7 *10)) (-5 *2 (-658 (-2 (|:| -1325 *9) (|:| -4346 (-790))))) (-5 *1 (-510 *7 *8 *9 *10 *11 *12)) (-4 *8 (-477)) (-4 *9 (-13 (-456 (-592)) (-582) (-1065 *10) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-3351 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 *8) (|:| -4346 (-790)))) (-658 *6) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 *6)) (-4 *6 (-388)) (-14 *11 (-1 *8 *6)) (-4 *9 (-13 (-869) (-582))) (-14 *10 (-1 *6 *9)) (-5 *2 (-658 (-2 (|:| -1325 *8) (|:| -4346 (-790))))) (-5 *1 (-510 *6 *7 *8 *9 *10 *11)) (-4 *7 (-477)) (-4 *8 (-13 (-456 (-592)) (-582) (-1065 *9) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-3351 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) (-3351 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $)))))))) 
+(-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3351 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1500 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3610 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (IF (|has| |#1| (-1065 (-1191))) (IF (|has| |#2| (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -2948 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1926 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -1835 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3507 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3507 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -2780 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489)))) (IF (|has| |#1| (-1065 (-1191))) (IF (|has| |#2| (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 |#1|)) (-1237 |#1|))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 |#1|))) (-1237 (-1187 |#1|)))) (|:| |exprStream| (-1 (-1171 |#3|) |#3| (-1191))) (|:| A (-1 |#2| (-790) (-790) (-1187 |#2|))) (|:| AF (-1 (-1187 |#1|) (-790) (-790) (-1237 (-1187 |#1|)))) (|:| AX (-1 |#3| (-790) (-1191) |#3|)) (|:| C (-1 (-658 |#2|) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 |#3|) (|:| -4346 (-790)))) (-658 |#1|) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|)) 
+((-1809 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-980 (-592))) (-1065 (-1191))) (|has| (-980 (-592)) (-1065 (-1191))))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))) NIL)) (-3507 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-980 (-592))) (-1065 (-1191))) (|has| (-980 (-592)) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL)) (-2780 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-980 (-592))) (-1065 (-1191))) (|has| (-980 (-592)) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL)) (-4126 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL)) (-4166 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-980 (-592))) (-1065 (-1191))) (|has| (-980 (-592)) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL)) (-1835 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL)) (-4351 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) NIL)) (-1500 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-980 (-592))) (-1065 (-1191))) (|has| (-980 (-592)) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL)) (-3610 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-980 (-592))) (-1065 (-1191))) (|has| (-980 (-592)) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL)) (-1926 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL)) (-2948 (((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-980 (-592))) (-1065 (-1191))) (|has| (-980 (-592)) (-1065 (-1191))))) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL)) (-3351 (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-658 (-1191)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-658 (-1191))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592))))) NIL)) (-3090 (((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))) (-1191)) NIL (-12 (|has| (-433 (-980 (-592))) (-1065 (-1191))) (|has| (-980 (-592)) (-1065 (-1191))))) (((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))) NIL))) 
+(((-511) (-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (IF (|has| (-433 (-980 (-592))) (-1065 (-1191))) (IF (|has| (-980 (-592)) (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (IF (|has| (-433 (-980 (-592))) (-1065 (-1191))) (IF (|has| (-980 (-592)) (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|))) (T -511)) 
+((-2948 (*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) (-2780 (*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) (-4166 (*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) (-3507 (*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) (-3090 (*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (-5 *1 (-511)))) (-1809 (*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (-5 *1 (-511)))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790))))) (-5 *1 (-511)))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790))))) (-5 *1 (-511)))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-2780 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-4166 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-3507 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-4126 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-4126 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-1835 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-1835 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-1926 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-1926 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-2948 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-2948 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) (-3610 (*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) (-1500 (*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) (-3610 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-1500 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-3351 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-3351 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-3351 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) (-3351 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511))))) 
+(-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -1500 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3610 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (IF (|has| (-433 (-980 (-592))) (-1065 (-1191))) (IF (|has| (-980 (-592)) (-1065 (-1191))) (PROGN (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -1926 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -1835 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))))) (-15 -3090 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (-15 -1809 ((-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (IF (|has| (-433 (-980 (-592))) (-1065 (-1191))) (IF (|has| (-980 (-592)) (-1065 (-1191))) (PROGN (-15 -1809 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))) (-1191))) (-15 -3090 ((-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))) (-1191)))) |noBranch|) |noBranch|)) 
+((-1809 (((-1 HPSPEC (-658 (-489))) (-1191)) NIL) ((HPSPEC (-658 (-489))) NIL)) (-3507 (((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191)) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL)) (-2780 (((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191)) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL)) (-4126 (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL)) (-4166 (((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191)) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL)) (-1835 (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL)) (-4351 (((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1 HPSPEC (-658 (-489)))) NIL)) (-1500 (((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191)) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL)) (-3610 (((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191)) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL)) (-1926 (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL)) (-2948 (((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191)) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL)) (-3351 (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-658 (-1191)) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-658 (-1191))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) NIL) (((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592))))) NIL)) (-3090 (((-1 HPSPEC (-658 (-489))) (-1191)) NIL) ((HPSPEC (-658 (-489))) NIL))) 
+(((-512 |#1|) (-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3351 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -1500 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3610 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1 HPSPEC (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -1926 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -1835 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -2780 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3090 (HPSPEC (-658 (-489)))) (-15 -1809 (HPSPEC (-658 (-489)))) (-15 -1809 ((-1 HPSPEC (-658 (-489))) (-1191))) (-15 -3090 ((-1 HPSPEC (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191)))) (-1191)) (T -512)) 
+((-2948 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 HPSPEC (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 HPSPEC (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 HPSPEC) (-5 *1 (-512 *4)) (-14 *4 (-1191)))) (-3090 (*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 HPSPEC) (-5 *1 (-512 *4)) (-14 *4 (-1191)))) (-2780 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-2780 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-4166 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-3507 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-3507 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-4126 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-4126 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-1835 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-1835 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-1926 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-1926 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-2948 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-2948 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-1 HPSPEC (-658 (-489)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 (-1191)))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3))) (-3610 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-3610 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-1500 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-1500 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) (-3351 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-760 *7 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *7 (-592)))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 (-433 (-761 *7 (-592))))) (-14 *7 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *7 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *7)))) (-3351 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-760 *6 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *6 (-592)))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 (-433 (-761 *6 (-592))))) (-14 *6 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *6 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *6)))) (-3351 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) (-3351 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4))))) 
+(-10 -7 (-15 -3351 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3351 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-658 (-1191)))) (-15 -3351 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-658 (-1191)) (-658 (-489)))) (-15 -1500 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -1500 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -3610 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3610 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -1500 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -3610 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -4351 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1 HPSPEC (-658 (-489))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -2948 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -1926 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -1926 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -1835 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -1835 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -4126 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3507 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -4166 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -2780 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489)))) (-15 -2780 ((-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))))) (-15 -3090 (HPSPEC (-658 (-489)))) (-15 -1809 (HPSPEC (-658 (-489)))) (-15 -1809 ((-1 HPSPEC (-658 (-489))) (-1191))) (-15 -3090 ((-1 HPSPEC (-658 (-489))) (-1191))) (-15 -3507 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -4166 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -2780 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191))) (-15 -2948 ((-1 (-658 (-2 (|:| -1325 (-760 |#1| (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 |#1| (-592)))) (-658 (-489))) (-1191)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL)) (-2400 (((-592) $) NIL) (((-433 (-592)) $) NIL)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1435 (($) 18)) (-3558 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-1778 (((-405) $) 22) (((-237) $) 25) (((-433 (-1187 (-592))) $) 19) (((-565) $) 52)) (-1683 (((-877) $) 50) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (((-237) $) 24) (((-405) $) 21)) (-4010 (((-790)) NIL)) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 36 T CONST)) (-4257 (($) 11 T CONST)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL))) 
+(((-513) (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))) (-1049) (-632 (-237)) (-632 (-405)) (-633 (-433 (-1187 (-592)))) (-633 (-565)) (-10 -8 (-15 -1435 ($))))) (T -513)) 
+((-1435 (*1 *1) (-5 *1 (-513)))) 
+(-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))) (-1049) (-632 (-237)) (-632 (-405)) (-633 (-433 (-1187 (-592)))) (-633 (-565)) (-10 -8 (-15 -1435 ($)))) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3898 (((-1285) $ |#1| |#1|) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#2| $ |#1| |#2|) 16)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 |#2| "failed") |#1| $) 20)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) 18)) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) NIL)) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 ((|#1| $) NIL (|has| |#1| (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 ((|#1| $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-2840 (((-658 |#1|) $) 13)) (-2396 (((-141) |#1| $) NIL)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3708 (((-658 |#1|) $) NIL)) (-3780 (((-141) |#1| $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1918 ((|#2| $) NIL (|has| |#1| (-869)))) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 19)) (-3927 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 11 (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1699 (((-790) $) 15 (|has| $ (-6 -4625))))) 
+(((-514 |#1| |#2| |#3|) (-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625))) (-1119) (-1119) (-1173)) (T -514)) 
+NIL 
+(-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625))) 
+((-2470 (((-592) (-592) (-592)) 7)) (-2238 (((-141) (-592) (-592) (-592) (-592)) 11)) (-3086 (((-1280 (-658 (-592))) (-790) (-790)) 22))) 
+(((-515) (-10 -7 (-15 -2470 ((-592) (-592) (-592))) (-15 -2238 ((-141) (-592) (-592) (-592) (-592))) (-15 -3086 ((-1280 (-658 (-592))) (-790) (-790))))) (T -515)) 
+((-3086 (*1 *2 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1280 (-658 (-592)))) (-5 *1 (-515)))) (-2238 (*1 *2 *3 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *2 (-141)) (-5 *1 (-515)))) (-2470 (*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-515))))) 
+(-10 -7 (-15 -2470 ((-592) (-592) (-592))) (-15 -2238 ((-141) (-592) (-592) (-592) (-592))) (-15 -3086 ((-1280 (-658 (-592))) (-790) (-790)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-879 |#1|)) $) NIL)) (-4492 (((-1187 $) $ (-879 |#1|)) NIL) (((-1187 |#2|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#2| (-582)))) (-1555 (($ $) NIL (|has| |#2| (-582)))) (-1313 (((-141) $) NIL (|has| |#2| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-879 |#1|))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3743 (($ $) NIL (|has| |#2| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#2| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-879 |#1|) "failed") $) NIL)) (-2400 ((|#2| $) NIL) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-879 |#1|) $) NIL)) (-1544 (($ $ $ (-879 |#1|)) NIL (|has| |#2| (-194)))) (-4377 (($ $ (-658 (-592))) NIL)) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#2| (-477))) (($ $ (-879 |#1|)) NIL (|has| |#2| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#2| (-931)))) (-4209 (($ $ |#2| (-517 (-1699 |#1|) (-790)) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-879 |#1|) (-908 (-405))) (|has| |#2| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-879 |#1|) (-908 (-592))) (|has| |#2| (-908 (-592)))))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-4533 (($ (-1187 |#2|) (-879 |#1|)) NIL) (($ (-1187 $) (-879 |#1|)) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#2| (-517 (-1699 |#1|) (-790))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-879 |#1|)) NIL)) (-4206 (((-517 (-1699 |#1|) (-790)) $) NIL) (((-790) $ (-879 |#1|)) NIL) (((-658 (-790)) $ (-658 (-879 |#1|))) NIL)) (-1837 (($ $ $) NIL (|has| |#2| (-869)))) (-3319 (($ $ $) NIL (|has| |#2| (-869)))) (-2976 (($ (-1 (-517 (-1699 |#1|) (-790)) (-517 (-1699 |#1|) (-790))) $) NIL)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-3254 (((-3 (-879 |#1|) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#2| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-2685 (((-1173) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-879 |#1|)) (|:| -3215 (-790))) "failed") $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#2| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#2| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#2| (-931)))) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-879 |#1|) |#2|) NIL) (($ $ (-658 (-879 |#1|)) (-658 |#2|)) NIL) (($ $ (-879 |#1|) $) NIL) (($ $ (-658 (-879 |#1|)) (-658 $)) NIL)) (-1482 (($ $ (-879 |#1|)) NIL (|has| |#2| (-194)))) (-3644 (($ $ (-879 |#1|)) NIL) (($ $ (-658 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-4525 (((-517 (-1699 |#1|) (-790)) $) NIL) (((-790) $ (-879 |#1|)) NIL) (((-658 (-790)) $ (-658 (-879 |#1|))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-879 |#1|) (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-879 |#1|) (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-879 |#1|) (-633 (-565))) (|has| |#2| (-633 (-565)))))) (-1554 ((|#2| $) NIL (|has| |#2| (-477))) (($ $ (-879 |#1|)) NIL (|has| |#2| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#2| (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) NIL) (($ (-879 |#1|)) NIL) (($ (-433 (-592))) NIL (-3836 (|has| |#2| (-43 (-433 (-592)))) (|has| |#2| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#2| (-582)))) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-517 (-1699 |#1|) (-790))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#2| (-931))) (|has| |#2| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#2| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#2| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-879 |#1|)) NIL) (($ $ (-658 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-3286 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#2| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#2| (-43 (-433 (-592))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-516 |#1| |#2|) (-13 (-977 |#2| (-517 (-1699 |#1|) (-790)) (-879 |#1|)) (-10 -8 (-15 -4377 ($ $ (-658 (-592)))))) (-658 (-1191)) (-1075)) (T -516)) 
+((-4377 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-516 *3 *4)) (-14 *3 (-658 (-1191))) (-4 *4 (-1075))))) 
+(-13 (-977 |#2| (-517 (-1699 |#1|) (-790)) (-879 |#1|)) (-10 -8 (-15 -4377 ($ $ (-658 (-592)))))) 
+((-1641 (((-141) $ $) NIL (|has| |#2| (-1119)))) (-2272 (((-141) $) NIL (|has| |#2| (-158)))) (-2673 (($ (-944)) NIL (|has| |#2| (-1075)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4079 (($ $ $) NIL (|has| |#2| (-815)))) (-2350 (((-3 $ "failed") $ $) NIL (|has| |#2| (-158)))) (-2126 (((-141) $ (-790)) NIL)) (-1403 (((-790)) NIL (|has| |#2| (-394)))) (-3940 (((-592) $) NIL (|has| |#2| (-867)))) (-3932 ((|#2| $ (-592) |#2|) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) (((-3 |#2| "failed") $) NIL (|has| |#2| (-1119)))) (-2400 (((-592) $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119)))) (((-433 (-592)) $) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) ((|#2| $) NIL (|has| |#2| (-1119)))) (-3945 (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL (|has| |#2| (-1075))) (((-706 |#2|) (-706 $)) NIL (|has| |#2| (-1075)))) (-3371 (((-3 $ "failed") $) NIL (|has| |#2| (-743)))) (-4290 (($) NIL (|has| |#2| (-394)))) (-1426 ((|#2| $ (-592) |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ (-592)) 11)) (-1691 (((-141) $) NIL (|has| |#2| (-867)))) (-4004 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3558 (((-141) $) NIL (|has| |#2| (-743)))) (-1324 (((-141) $) NIL (|has| |#2| (-867)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-4467 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3987 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-3546 (((-944) $) NIL (|has| |#2| (-394)))) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#2| (-1119)))) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-1825 (($ (-944)) NIL (|has| |#2| (-394)))) (-2951 (((-1137) $) NIL (|has| |#2| (-1119)))) (-1918 ((|#2| $) NIL (|has| (-592) (-869)))) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1405 (((-658 $)) NIL (|has| |#2| (-394)))) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ (-592) |#2|) NIL) ((|#2| $ (-592)) NIL)) (-1729 ((|#2| $ $) NIL (|has| |#2| (-1075)))) (-4512 (($ (-1280 |#2|)) NIL)) (-1936 (((-160)) NIL (|has| |#2| (-388)))) (-3644 (($ $) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1 |#2| |#2|) (-790)) NIL (|has| |#2| (-1075))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1075)))) (-3452 (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-1280 |#2|) $) NIL) (((-877) $) NIL (|has| |#2| (-1119))) (($ (-592)) NIL (-3836 (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119))) (|has| |#2| (-1075)))) (($ (-433 (-592))) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) (($ |#2|) NIL (|has| |#2| (-1119)))) (-4010 (((-790)) NIL (|has| |#2| (-1075)))) (-3369 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-1392 (($ $) NIL (|has| |#2| (-867)))) (-1424 (($ $ (-790)) NIL (|has| |#2| (-743))) (($ $ (-944)) NIL (|has| |#2| (-743)))) (-3514 (($) NIL (|has| |#2| (-158)) CONST)) (-4257 (($) NIL (|has| |#2| (-743)) CONST)) (-1940 (($ $) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1 |#2| |#2|) (-790)) NIL (|has| |#2| (-1075))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1075)))) (-3286 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3273 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3255 (((-141) $ $) NIL (|has| |#2| (-1119)))) (-3279 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3266 (((-141) $ $) 15 (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $ $) NIL (|has| |#2| (-1075))) (($ $) NIL (|has| |#2| (-1075)))) (-3300 (($ $ $) NIL (|has| |#2| (-25)))) (** (($ $ (-790)) NIL (|has| |#2| (-743))) (($ $ (-944)) NIL (|has| |#2| (-743)))) (* (($ (-592) $) NIL (|has| |#2| (-1075))) (($ $ $) NIL (|has| |#2| (-743))) (($ $ |#2|) NIL (|has| |#2| (-743))) (($ |#2| $) NIL (|has| |#2| (-743))) (($ (-790) $) NIL (|has| |#2| (-158))) (($ (-944) $) NIL (|has| |#2| (-25)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-517 |#1| |#2|) (-252 |#1| |#2|) (-790) (-815)) (T -517)) 
+NIL 
+(-252 |#1| |#2|) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) NIL)) (-3001 (($) NIL T CONST)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2713 (($ $ $) 32)) (-4491 (($ $ $) 31)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3319 ((|#1| $) 26)) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4137 ((|#1| $) 27)) (-2113 (($ |#1| $) 10)) (-4013 (($ (-658 |#1|)) 12)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-2106 ((|#1| $) 23)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 9)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 29)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) 21 (|has| $ (-6 -4625))))) 
+(((-518 |#1|) (-13 (-997 |#1|) (-10 -8 (-15 -4013 ($ (-658 |#1|))) (-15 -4560 ($ (-658 |#1|))) (-15 -4599 ($ $)) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -1724 ((-141) $ $)) (-15 -2106 (|#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (-15 -3319 (|#1| $)) (-15 -4491 ($ $ $)) (-15 -2713 ($ $ $)) (-15 -3001 ($)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) (-869)) (T -518)) 
+((-1724 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) (-4599 (*1 *1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-2890 (*1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-2943 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) (-2554 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-518 *4)) (-4 *4 (-869)))) (-4345 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-518 *4)) (-4 *4 (-869)))) (-2126 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-518 *4)) (-4 *4 (-869)))) (-3001 (*1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-869)) (-5 *1 (-518 *3)))) (-3987 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-869)) (-5 *1 (-518 *3)))) (-3369 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-869)) (-5 *2 (-141)) (-5 *1 (-518 *4)))) (-3002 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-869)) (-5 *2 (-141)) (-5 *1 (-518 *4)))) (-3452 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-869)) (-5 *2 (-790)) (-5 *1 (-518 *4)))) (-4004 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) (-3452 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) (-3133 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) (-2685 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) (-2951 (*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) (-3255 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) (-1641 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) (-4560 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-518 *3)))) (-2106 (*1 *2 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-2113 (*1 *1 *2 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-4137 (*1 *2 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-3319 (*1 *2 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-4491 (*1 *1 *1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-2713 (*1 *1 *1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) (-4013 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-518 *3))))) 
+(-13 (-997 |#1|) (-10 -8 (-15 -4013 ($ (-658 |#1|))) (-15 -4560 ($ (-658 |#1|))) (-15 -4599 ($ $)) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -1724 ((-141) $ $)) (-15 -2106 (|#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (-15 -3319 (|#1| $)) (-15 -4491 ($ $ $)) (-15 -2713 ($ $ $)) (-15 -3001 ($)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3657 (($ $) 69)) (-1663 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-2312 (((-439 |#2| (-433 |#2|) |#3| |#4|) $) 43)) (-2951 (((-1137) $) NIL)) (-2934 (((-3 |#4| "failed") $) 105)) (-4096 (($ (-439 |#2| (-433 |#2|) |#3| |#4|)) 76) (($ |#4|) 32) (($ |#1| |#1|) 113) (($ |#1| |#1| (-592)) NIL) (($ |#4| |#2| |#2| |#2| |#1|) 125)) (-1906 (((-2 (|:| -4547 (-439 |#2| (-433 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 45)) (-1683 (((-877) $) 100)) (-3514 (($) 33 T CONST)) (-3255 (((-141) $ $) 107)) (-3306 (($ $) 72) (($ $ $) NIL)) (-3300 (($ $ $) 70)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 73))) 
+(((-519 |#1| |#2| |#3| |#4|) (-355 |#1| |#2| |#3| |#4|) (-388) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|)) (T -519)) 
+NIL 
+(-355 |#1| |#2| |#3| |#4|) 
+((-1855 (((-592) (-658 (-592))) 28)) (-2981 ((|#1| (-658 |#1|)) 56)) (-3248 (((-658 |#1|) (-658 |#1|)) 57)) (-2764 (((-658 |#1|) (-658 |#1|)) 59)) (-3548 ((|#1| (-658 |#1|)) 58)) (-1554 (((-658 (-592)) (-658 |#1|)) 31))) 
+(((-520 |#1|) (-10 -7 (-15 -3548 (|#1| (-658 |#1|))) (-15 -2981 (|#1| (-658 |#1|))) (-15 -2764 ((-658 |#1|) (-658 |#1|))) (-15 -3248 ((-658 |#1|) (-658 |#1|))) (-15 -1554 ((-658 (-592)) (-658 |#1|))) (-15 -1855 ((-592) (-658 (-592))))) (-1255 (-592))) (T -520)) 
+((-1855 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-592)) (-5 *1 (-520 *4)) (-4 *4 (-1255 *2)))) (-1554 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1255 (-592))) (-5 *2 (-658 (-592))) (-5 *1 (-520 *4)))) (-3248 (*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1255 (-592))) (-5 *1 (-520 *3)))) (-2764 (*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1255 (-592))) (-5 *1 (-520 *3)))) (-2981 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-5 *1 (-520 *2)) (-4 *2 (-1255 (-592))))) (-3548 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-5 *1 (-520 *2)) (-4 *2 (-1255 (-592)))))) 
+(-10 -7 (-15 -3548 (|#1| (-658 |#1|))) (-15 -2981 (|#1| (-658 |#1|))) (-15 -2764 ((-658 |#1|) (-658 |#1|))) (-15 -3248 ((-658 |#1|) (-658 |#1|))) (-15 -1554 ((-658 (-592)) (-658 |#1|))) (-15 -1855 ((-592) (-658 (-592))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 (((-592) $) NIL (|has| (-592) (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| (-592) (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL (|has| (-592) (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-592) (-1065 (-592)))) (((-3 (-592) "failed") $) NIL (|has| (-592) (-1065 (-592))))) (-2400 (((-592) $) NIL) (((-1191) $) NIL (|has| (-592) (-1065 (-1191)))) (((-433 (-592)) $) NIL (|has| (-592) (-1065 (-592)))) (((-592) $) NIL (|has| (-592) (-1065 (-592))))) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-592) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-592) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-706 (-592)) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-592) (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) NIL (|has| (-592) (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| (-592) (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| (-592) (-908 (-405))))) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL)) (-1448 (((-592) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| (-592) (-1165)))) (-1324 (((-141) $) NIL (|has| (-592) (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-592) (-869)))) (-2731 (($ (-1 (-592) (-592)) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-592) (-1165)) CONST)) (-3456 (($ (-433 (-592))) 8)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| (-592) (-323))) (((-433 (-592)) $) NIL)) (-2039 (((-592) $) NIL (|has| (-592) (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 (-592)) (-658 (-592))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-592) (-592)) NIL (|has| (-592) (-325 (-592)))) (($ $ (-310 (-592))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-658 (-310 (-592)))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-658 (-1191)) (-658 (-592))) NIL (|has| (-592) (-547 (-1191) (-592)))) (($ $ (-1191) (-592)) NIL (|has| (-592) (-547 (-1191) (-592))))) (-2769 (((-790) $) NIL)) (-3927 (($ $ (-592)) NIL (|has| (-592) (-303 (-592) (-592))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL (|has| (-592) (-247))) (($ $ (-790)) NIL (|has| (-592) (-247))) (($ $ (-1191)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1 (-592) (-592)) (-790)) NIL) (($ $ (-1 (-592) (-592))) NIL)) (-2782 (($ $) NIL)) (-1456 (((-592) $) NIL)) (-1778 (((-914 (-592)) $) NIL (|has| (-592) (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| (-592) (-633 (-914 (-405))))) (((-565) $) NIL (|has| (-592) (-633 (-565)))) (((-405) $) NIL (|has| (-592) (-1049))) (((-237) $) NIL (|has| (-592) (-1049)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-592) (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) 7) (($ (-592)) NIL) (($ (-1191)) NIL (|has| (-592) (-1065 (-1191)))) (((-433 (-592)) $) NIL) (((-1032 16) $) 9)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-592) (-931))) (|has| (-592) (-169))))) (-4010 (((-790)) NIL)) (-2744 (((-592) $) NIL (|has| (-592) (-574)))) (-2537 (((-141) $ $) NIL)) (-1392 (($ $) NIL (|has| (-592) (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $) NIL (|has| (-592) (-247))) (($ $ (-790)) NIL (|has| (-592) (-247))) (($ $ (-1191)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1 (-592) (-592)) (-790)) NIL) (($ $ (-1 (-592) (-592))) NIL)) (-3286 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3313 (($ $ $) NIL) (($ (-592) (-592)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ (-592) $) NIL) (($ $ (-592)) NIL))) 
+(((-521) (-13 (-1021 (-592)) (-10 -8 (-15 -1683 ((-433 (-592)) $)) (-15 -1683 ((-1032 16) $)) (-15 -3856 ((-433 (-592)) $)) (-15 -3456 ($ (-433 (-592))))))) (T -521)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-521)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1032 16)) (-5 *1 (-521)))) (-3856 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-521)))) (-3456 (*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-521))))) 
+(-13 (-1021 (-592)) (-10 -8 (-15 -1683 ((-433 (-592)) $)) (-15 -1683 ((-1032 16) $)) (-15 -3856 ((-433 (-592)) $)) (-15 -3456 ($ (-433 (-592)))))) 
+((-4467 (((-658 |#2|) $) 22)) (-3133 (((-141) |#2| $) 27)) (-3002 (((-141) (-1 (-141) |#2|) $) 20)) (-2806 (($ $ (-658 (-310 |#2|))) 12) (($ $ (-310 |#2|)) NIL) (($ $ |#2| |#2|) NIL) (($ $ (-658 |#2|) (-658 |#2|)) NIL)) (-3452 (((-790) (-1 (-141) |#2|) $) 21) (((-790) |#2| $) 25)) (-1683 (((-877) $) 36)) (-3369 (((-141) (-1 (-141) |#2|) $) 19)) (-3255 (((-141) $ $) 30)) (-1699 (((-790) $) 16))) 
+(((-522 |#1| |#2|) (-10 -8 (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -2806 (|#1| |#1| (-658 |#2|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#2| |#2|)) (-15 -2806 (|#1| |#1| (-310 |#2|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#2|)))) (-15 -3133 ((-141) |#2| |#1|)) (-15 -3452 ((-790) |#2| |#1|)) (-15 -4467 ((-658 |#2|) |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -1699 ((-790) |#1|))) (-523 |#2|) (-1225)) (T -522)) 
+NIL 
+(-10 -8 (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -2806 (|#1| |#1| (-658 |#2|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#2| |#2|)) (-15 -2806 (|#1| |#1| (-310 |#2|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#2|)))) (-15 -3133 ((-141) |#2| |#1|)) (-15 -3452 ((-790) |#2| |#1|)) (-15 -4467 ((-658 |#2|) |#1|)) (-15 -3452 ((-790) (-1 (-141) |#2|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -1699 ((-790) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-3001 (($) 7 T CONST)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-523 |#1|) (-1311) (-1225)) (T -523)) 
+((-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-523 *3)) (-4 *3 (-1225)))) (-3987 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| *1 (-6 -4626)) (-4 *1 (-523 *3)) (-4 *3 (-1225)))) (-3369 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| *1 (-6 -4625)) (-4 *1 (-523 *4)) (-4 *4 (-1225)) (-5 *2 (-141)))) (-3002 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| *1 (-6 -4625)) (-4 *1 (-523 *4)) (-4 *4 (-1225)) (-5 *2 (-141)))) (-3452 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| *1 (-6 -4625)) (-4 *1 (-523 *4)) (-4 *4 (-1225)) (-5 *2 (-790)))) (-4004 (*1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-523 *3)) (-4 *3 (-1225)) (-5 *2 (-658 *3)))) (-4467 (*1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-523 *3)) (-4 *3 (-1225)) (-5 *2 (-658 *3)))) (-3452 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-523 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-790)))) (-3133 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-523 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-141))))) 
+(-13 (-39) (-10 -8 (IF (|has| |t#1| (-1119)) (-6 (-1119)) |noBranch|) (IF (|has| |t#1| (-1119)) (IF (|has| |t#1| (-325 |t#1|)) (-6 (-325 |t#1|)) |noBranch|) |noBranch|) (-15 -2731 ($ (-1 |t#1| |t#1|) $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |t#1| |t#1|) $)) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3369 ((-141) (-1 (-141) |t#1|) $)) (-15 -3002 ((-141) (-1 (-141) |t#1|) $)) (-15 -3452 ((-790) (-1 (-141) |t#1|) $)) (-15 -4004 ((-658 |t#1|) $)) (-15 -4467 ((-658 |t#1|) $)) (IF (|has| |t#1| (-1119)) (PROGN (-15 -3452 ((-790) |t#1| $)) (-15 -3133 ((-141) |t#1| $))) |noBranch|)) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1805 (((-1173) (-877)) 40)) (-3536 (((-1285) (-1173)) 29)) (-1807 (((-1173) (-877)) 25)) (-2609 (((-1173) (-877)) 26)) (-1683 (((-877) $) NIL) (((-1173) (-877)) 24)) (-3255 (((-141) $ $) NIL))) 
+(((-524) (-13 (-1119) (-10 -7 (-15 -1683 ((-1173) (-877))) (-15 -1807 ((-1173) (-877))) (-15 -2609 ((-1173) (-877))) (-15 -1805 ((-1173) (-877))) (-15 -3536 ((-1285) (-1173)))))) (T -524)) 
+((-1683 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-524)))) (-1807 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-524)))) (-2609 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-524)))) (-1805 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-524)))) (-3536 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-524))))) 
+(-13 (-1119) (-10 -7 (-15 -1683 ((-1173) (-877))) (-15 -1807 ((-1173) (-877))) (-15 -2609 ((-1173) (-877))) (-15 -1805 ((-1173) (-877))) (-15 -3536 ((-1285) (-1173))))) 
+((-1588 (($ $) 15)) (-1575 (($ $) 24)) (-1601 (($ $) 12)) (-1609 (($ $) 10)) (-1594 (($ $) 17)) (-1581 (($ $) 22))) 
+(((-525 |#1|) (-10 -8 (-15 -1581 (|#1| |#1|)) (-15 -1594 (|#1| |#1|)) (-15 -1609 (|#1| |#1|)) (-15 -1601 (|#1| |#1|)) (-15 -1575 (|#1| |#1|)) (-15 -1588 (|#1| |#1|))) (-526)) (T -525)) 
+NIL 
+(-10 -8 (-15 -1581 (|#1| |#1|)) (-15 -1594 (|#1| |#1|)) (-15 -1609 (|#1| |#1|)) (-15 -1601 (|#1| |#1|)) (-15 -1575 (|#1| |#1|)) (-15 -1588 (|#1| |#1|))) 
+((-1588 (($ $) 11)) (-1575 (($ $) 10)) (-1601 (($ $) 9)) (-1609 (($ $) 8)) (-1594 (($ $) 7)) (-1581 (($ $) 6))) 
+(((-526) (-1311)) (T -526)) 
+((-1588 (*1 *1 *1) (-4 *1 (-526))) (-1575 (*1 *1 *1) (-4 *1 (-526))) (-1601 (*1 *1 *1) (-4 *1 (-526))) (-1609 (*1 *1 *1) (-4 *1 (-526))) (-1594 (*1 *1 *1) (-4 *1 (-526))) (-1581 (*1 *1 *1) (-4 *1 (-526)))) 
+(-13 (-10 -8 (-15 -1581 ($ $)) (-15 -1594 ($ $)) (-15 -1609 ($ $)) (-15 -1601 ($ $)) (-15 -1575 ($ $)) (-15 -1588 ($ $)))) 
+((-4500 (((-444 |#4|) |#4| (-1 (-444 |#2|) |#2|)) 42))) 
+(((-527 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4500 ((-444 |#4|) |#4| (-1 (-444 |#2|) |#2|)))) (-388) (-1255 |#1|) (-13 (-388) (-171) (-741 |#1| |#2|)) (-1255 |#3|)) (T -527)) 
+((-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-4 *7 (-13 (-388) (-171) (-741 *5 *6))) (-5 *2 (-444 *3)) (-5 *1 (-527 *5 *6 *7 *3)) (-4 *3 (-1255 *7))))) 
+(-10 -7 (-15 -4500 ((-444 |#4|) |#4| (-1 (-444 |#2|) |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-3863 (((-658 $) (-1187 $) (-1191)) NIL) (((-658 $) (-1187 $)) NIL) (((-658 $) (-980 $)) NIL)) (-3224 (($ (-1187 $) (-1191)) NIL) (($ (-1187 $)) NIL) (($ (-980 $)) NIL)) (-2272 (((-141) $) 36)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-4387 (((-141) $ $) 62)) (-2165 (((-658 (-631 $)) $) 46)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3147 (($ $ (-310 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1442 (($ $) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-1316 (((-658 $) (-1187 $) (-1191)) NIL) (((-658 $) (-1187 $)) NIL) (((-658 $) (-980 $)) NIL)) (-3906 (($ (-1187 $) (-1191)) NIL) (($ (-1187 $)) NIL) (($ (-980 $)) NIL)) (-4368 (((-3 (-631 $) "failed") $) NIL) (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL)) (-2400 (((-631 $) $) NIL) (((-592) $) NIL) (((-433 (-592)) $) 48)) (-1586 (($ $ $) NIL)) (-3945 (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-706 (-592)) (-706 $)) NIL) (((-2 (|:| -3253 (-706 (-433 (-592)))) (|:| |vec| (-1280 (-433 (-592))))) (-706 $) (-1280 $)) NIL) (((-706 (-433 (-592))) (-706 $)) NIL)) (-3657 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-2243 (($ $) NIL) (($ (-658 $)) NIL)) (-4388 (((-658 (-143)) $) NIL)) (-2791 (((-143) (-143)) NIL)) (-3558 (((-141) $) 39)) (-3372 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-1448 (((-1142 (-592) (-631 $)) $) 34)) (-4422 (($ $ (-592)) NIL)) (-2793 (((-1187 $) (-1187 $) (-631 $)) 77) (((-1187 $) (-1187 $) (-658 (-631 $))) 53) (($ $ (-631 $)) 66) (($ $ (-658 (-631 $))) 67)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2710 (((-1187 $) (-631 $)) 64 (|has| $ (-1075)))) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 $ $) (-631 $)) NIL)) (-4160 (((-3 (-631 $) "failed") $) NIL)) (-2750 (($ (-658 $)) NIL) (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-4486 (((-658 (-631 $)) $) NIL)) (-1462 (($ (-143) $) NIL) (($ (-143) (-658 $)) NIL)) (-3013 (((-141) $ (-143)) NIL) (((-141) $ (-1191)) NIL)) (-4552 (($ $) NIL)) (-2535 (((-790) $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ (-658 $)) NIL) (($ $ $) NIL)) (-1319 (((-141) $ $) NIL) (((-141) $ (-1191)) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3554 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-2806 (($ $ (-631 $) $) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-1191) (-1 $ (-658 $))) NIL) (($ $ (-1191) (-1 $ $)) NIL) (($ $ (-658 (-143)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-143) (-1 $ (-658 $))) NIL) (($ $ (-143) (-1 $ $)) NIL)) (-2769 (((-790) $) NIL)) (-3927 (($ (-143) $) NIL) (($ (-143) $ $) NIL) (($ (-143) $ $ $) NIL) (($ (-143) $ $ $ $) NIL) (($ (-143) (-658 $)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2818 (($ $) NIL) (($ $ $) NIL)) (-3644 (($ $ (-790)) NIL) (($ $) 33)) (-1456 (((-1142 (-592) (-631 $)) $) 17)) (-3390 (($ $) NIL (|has| $ (-1075)))) (-1778 (((-405) $) 91) (((-237) $) 99) (((-191 (-405)) $) 107)) (-1683 (((-877) $) NIL) (($ (-631 $)) NIL) (($ (-433 (-592))) NIL) (($ $) NIL) (($ (-592)) NIL) (($ (-1142 (-592) (-631 $))) 18)) (-4010 (((-790)) NIL)) (-3280 (($ $) NIL) (($ (-658 $)) NIL)) (-3038 (((-141) (-143)) 83)) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-592)) NIL) (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (-3514 (($) 9 T CONST)) (-4257 (($) 19 T CONST)) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 21)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3313 (($ $ $) 41)) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-433 (-592))) NIL) (($ $ (-592)) 44) (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (* (($ (-433 (-592)) $) NIL) (($ $ (-433 (-592))) NIL) (($ $ $) 24) (($ (-592) $) NIL) (($ (-790) $) NIL) (($ (-944) $) NIL))) 
+(((-528) (-13 (-318) (-27) (-1065 (-592)) (-1065 (-433 (-592))) (-654 (-592)) (-1049) (-654 (-433 (-592))) (-171) (-633 (-191 (-405))) (-247) (-10 -8 (-15 -1683 ($ (-1142 (-592) (-631 $)))) (-15 -1448 ((-1142 (-592) (-631 $)) $)) (-15 -1456 ((-1142 (-592) (-631 $)) $)) (-15 -3657 ($ $)) (-15 -4387 ((-141) $ $)) (-15 -2793 ((-1187 $) (-1187 $) (-631 $))) (-15 -2793 ((-1187 $) (-1187 $) (-658 (-631 $)))) (-15 -2793 ($ $ (-631 $))) (-15 -2793 ($ $ (-658 (-631 $))))))) (T -528)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1142 (-592) (-631 (-528)))) (-5 *1 (-528)))) (-1448 (*1 *2 *1) (-12 (-5 *2 (-1142 (-592) (-631 (-528)))) (-5 *1 (-528)))) (-1456 (*1 *2 *1) (-12 (-5 *2 (-1142 (-592) (-631 (-528)))) (-5 *1 (-528)))) (-3657 (*1 *1 *1) (-5 *1 (-528))) (-4387 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-528)))) (-2793 (*1 *2 *2 *3) (-12 (-5 *2 (-1187 (-528))) (-5 *3 (-631 (-528))) (-5 *1 (-528)))) (-2793 (*1 *2 *2 *3) (-12 (-5 *2 (-1187 (-528))) (-5 *3 (-658 (-631 (-528)))) (-5 *1 (-528)))) (-2793 (*1 *1 *1 *2) (-12 (-5 *2 (-631 (-528))) (-5 *1 (-528)))) (-2793 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-631 (-528)))) (-5 *1 (-528))))) 
+(-13 (-318) (-27) (-1065 (-592)) (-1065 (-433 (-592))) (-654 (-592)) (-1049) (-654 (-433 (-592))) (-171) (-633 (-191 (-405))) (-247) (-10 -8 (-15 -1683 ($ (-1142 (-592) (-631 $)))) (-15 -1448 ((-1142 (-592) (-631 $)) $)) (-15 -1456 ((-1142 (-592) (-631 $)) $)) (-15 -3657 ($ $)) (-15 -4387 ((-141) $ $)) (-15 -2793 ((-1187 $) (-1187 $) (-631 $))) (-15 -2793 ((-1187 $) (-1187 $) (-658 (-631 $)))) (-15 -2793 ($ $ (-631 $))) (-15 -2793 ($ $ (-658 (-631 $)))))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) NIL) (((-141) $) NIL (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) |#1|) 25 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) 22 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 21)) (-1721 (((-592) (-1 (-141) |#1|) $) NIL) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119)))) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) |#1|) 14)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 12 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) 23 (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 16 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 17) (($ (-1 |#1| |#1| |#1|) $ $) 19)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) NIL (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) 10 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 13)) (-3927 ((|#1| $ (-592) |#1|) NIL) ((|#1| $ (-592)) 24) (($ $ (-1246 (-592))) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-2266 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-1699 (((-790) $) 9 (|has| $ (-6 -4625))))) 
+(((-529 |#1| |#2|) (-19 |#1|) (-1225) (-592)) (T -529)) 
 NIL 
 (-19 |#1|) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) (-572) |#1|) NIL)) (-1823 (($ $ (-572) (-509 |#1| |#3|)) NIL)) (-1695 (($ $ (-572) (-509 |#1| |#2|)) NIL)) (-2211 (($) NIL T CONST)) (-4267 (((-509 |#1| |#3|) $ (-572)) NIL)) (-3037 ((|#1| $ (-572) (-572) |#1|) NIL)) (-4212 ((|#1| $ (-572) (-572)) NIL)) (-2010 (((-638 |#1|) $) NIL)) (-3704 (((-769) $) NIL)) (-1364 (($ (-769) (-769) |#1|) NIL)) (-3712 (((-769) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-2660 (((-572) $) NIL)) (-3092 (((-572) $) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3927 (((-572) $) NIL)) (-3227 (((-572) $) NIL)) (-2435 (($ (-1 |#1| |#1|) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3299 (($ $ |#1|) NIL)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) (-572)) NIL) ((|#1| $ (-572) (-572) |#1|) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-4580 (((-509 |#1| |#2|) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-510 |#1| |#2| |#3|) (-62 |#1| (-509 |#1| |#3|) (-509 |#1| |#2|)) (-1204) (-572) (-572)) (T -510)) 
-NIL 
-(-62 |#1| (-509 |#1| |#3|) (-509 |#1| |#2|)) 
-((-4501 (((-638 (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|)))) (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) (-769) (-769)) 27)) (-3102 (((-638 (-1166 |#1|)) |#1| (-769) (-769) (-769)) 34)) (-4399 (((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) (-638 |#3|) (-638 (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|)))) (-769)) 83))) 
-(((-511 |#1| |#2| |#3|) (-10 -7 (-15 -3102 ((-638 (-1166 |#1|)) |#1| (-769) (-769) (-769))) (-15 -4501 ((-638 (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|)))) (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) (-769) (-769))) (-15 -4399 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) (-638 |#3|) (-638 (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|)))) (-769)))) (-353) (-1234 |#1|) (-1234 |#2|)) (T -511)) 
-((-4399 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 (-2 (|:| -2237 (-685 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-685 *7))))) (-5 *5 (-769)) (-4 *8 (-1234 *7)) (-4 *7 (-1234 *6)) (-4 *6 (-353)) (-5 *2 (-2 (|:| -2237 (-685 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-685 *7)))) (-5 *1 (-511 *6 *7 *8)))) (-4501 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-769)) (-4 *5 (-353)) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-2 (|:| -2237 (-685 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-685 *6))))) (-5 *1 (-511 *5 *6 *7)) (-5 *3 (-2 (|:| -2237 (-685 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-685 *6)))) (-4 *7 (-1234 *6)))) (-3102 (*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-769)) (-4 *3 (-353)) (-4 *5 (-1234 *3)) (-5 *2 (-638 (-1166 *3))) (-5 *1 (-511 *3 *5 *6)) (-4 *6 (-1234 *5))))) 
-(-10 -7 (-15 -3102 ((-638 (-1166 |#1|)) |#1| (-769) (-769) (-769))) (-15 -4501 ((-638 (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|)))) (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) (-769) (-769))) (-15 -4399 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) (-638 |#3|) (-638 (-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|)))) (-769)))) 
-((-3625 (((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) (-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) (-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|)))) 60)) (-3125 ((|#1| (-685 |#1|) |#1| (-769)) 25)) (-2974 (((-769) (-769) (-769)) 30)) (-1654 (((-685 |#1|) (-685 |#1|) (-685 |#1|)) 42)) (-2801 (((-685 |#1|) (-685 |#1|) (-685 |#1|) |#1|) 50) (((-685 |#1|) (-685 |#1|) (-685 |#1|)) 47)) (-2440 ((|#1| (-685 |#1|) (-685 |#1|) |#1| (-572)) 29)) (-3807 ((|#1| (-685 |#1|)) 18))) 
-(((-512 |#1| |#2| |#3|) (-10 -7 (-15 -3807 (|#1| (-685 |#1|))) (-15 -3125 (|#1| (-685 |#1|) |#1| (-769))) (-15 -2440 (|#1| (-685 |#1|) (-685 |#1|) |#1| (-572))) (-15 -2974 ((-769) (-769) (-769))) (-15 -2801 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -2801 ((-685 |#1|) (-685 |#1|) (-685 |#1|) |#1|)) (-15 -1654 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -3625 ((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) (-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) (-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|)))))) (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $)))) (-1234 |#1|) (-415 |#1| |#2|)) (T -512)) 
-((-3625 (*1 *2 *2 *2) (-12 (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) (-1654 (*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) (-2801 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) (-2801 (*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) (-2974 (*1 *2 *2 *2) (-12 (-5 *2 (-769)) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) (-2440 (*1 *2 *3 *3 *2 *4) (-12 (-5 *3 (-685 *2)) (-5 *4 (-572)) (-4 *2 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *5 (-1234 *2)) (-5 *1 (-512 *2 *5 *6)) (-4 *6 (-415 *2 *5)))) (-3125 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-685 *2)) (-5 *4 (-769)) (-4 *2 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *5 (-1234 *2)) (-5 *1 (-512 *2 *5 *6)) (-4 *6 (-415 *2 *5)))) (-3807 (*1 *2 *3) (-12 (-5 *3 (-685 *2)) (-4 *4 (-1234 *2)) (-4 *2 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-5 *1 (-512 *2 *4 *5)) (-4 *5 (-415 *2 *4))))) 
-(-10 -7 (-15 -3807 (|#1| (-685 |#1|))) (-15 -3125 (|#1| (-685 |#1|) |#1| (-769))) (-15 -2440 (|#1| (-685 |#1|) (-685 |#1|) |#1| (-572))) (-15 -2974 ((-769) (-769) (-769))) (-15 -2801 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -2801 ((-685 |#1|) (-685 |#1|) (-685 |#1|) |#1|)) (-15 -1654 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -3625 ((-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) (-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|))) (-2 (|:| -2237 (-685 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-685 |#1|)))))) 
-((-2262 (((-121) $ $) NIL)) (-2004 (($ $) NIL)) (-2992 (($ $ $) 35)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) $) NIL (|has| (-121) (-848))) (((-121) (-1 (-121) (-121) (-121)) $) NIL)) (-4131 (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-121) (-848)))) (($ (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4603)))) (-3008 (($ $) NIL (|has| (-121) (-848))) (($ (-1 (-121) (-121) (-121)) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-121) $ (-1225 (-572)) (-121)) NIL (|has| $ (-6 -4603))) (((-121) $ (-572) (-121)) 36 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-3445 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602))) (($ (-121) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-3116 (((-121) (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-3037 (((-121) $ (-572) (-121)) NIL (|has| $ (-6 -4603)))) (-4212 (((-121) $ (-572)) NIL)) (-4014 (((-572) (-121) $ (-572)) NIL (|has| (-121) (-1098))) (((-572) (-121) $) NIL (|has| (-121) (-1098))) (((-572) (-1 (-121) (-121)) $) NIL)) (-2010 (((-638 (-121)) $) NIL (|has| $ (-6 -4602)))) (-2468 (($ $ $) 33)) (-2959 (($ $) NIL)) (-2117 (($ $ $) NIL)) (-1364 (($ (-769) (-121)) 23)) (-2084 (($ $ $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 8 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL)) (-4475 (($ $ $) NIL (|has| (-121) (-848))) (($ (-1 (-121) (-121) (-121)) $ $) NIL)) (-4467 (((-638 (-121)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL)) (-2435 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-121) (-121) (-121)) $ $) 30) (($ (-1 (-121) (-121)) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2603 (($ $ $ (-572)) NIL) (($ (-121) $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-121) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-121) "failed") (-1 (-121) (-121)) $) NIL)) (-3299 (($ $ (-121)) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-121)) (-638 (-121))) NIL (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-121) (-121)) NIL (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-290 (-121))) NIL (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098)))) (($ $ (-638 (-290 (-121)))) NIL (-12 (|has| (-121) (-305 (-121))) (|has| (-121) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098))))) (-2957 (((-638 (-121)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 24)) (-3277 (($ $ (-1225 (-572))) NIL) (((-121) $ (-572)) 18) (((-121) $ (-572) (-121)) NIL)) (-1940 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-1571 (((-769) (-121) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-121) (-1098)))) (((-769) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602)))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) 25)) (-4081 (((-545) $) NIL (|has| (-121) (-613 (-545))))) (-3921 (($ (-638 (-121))) NIL)) (-4500 (($ (-638 $)) NIL) (($ $ $) NIL) (($ (-121) $) NIL) (($ $ (-121)) NIL)) (-3972 (((-856) $) 22)) (-3501 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4602)))) (-4028 (($ $ $) 31)) (-4174 (($ $) NIL)) (-2235 (($ $ $) NIL)) (-3091 (($ $ $) 39)) (-3076 (($ $) 37)) (-2914 (($ $ $) 38)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 26)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 27)) (-2226 (($ $ $) NIL)) (-4032 (((-769) $) 10 (|has| $ (-6 -4602))))) 
-(((-513 |#1|) (-13 (-133) (-10 -8 (-15 -3076 ($ $)) (-15 -3091 ($ $ $)) (-15 -2914 ($ $ $)))) (-572)) (T -513)) 
-((-3076 (*1 *1 *1) (-12 (-5 *1 (-513 *2)) (-14 *2 (-572)))) (-3091 (*1 *1 *1 *1) (-12 (-5 *1 (-513 *2)) (-14 *2 (-572)))) (-2914 (*1 *1 *1 *1) (-12 (-5 *1 (-513 *2)) (-14 *2 (-572))))) 
-(-13 (-133) (-10 -8 (-15 -3076 ($ $)) (-15 -3091 ($ $ $)) (-15 -2914 ($ $ $)))) 
-((-2538 (((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1166 |#4|)) 34)) (-1725 (((-1166 |#4|) (-1 |#4| |#1|) |#2|) 30) ((|#2| (-1 |#1| |#4|) (-1166 |#4|)) 21)) (-3239 (((-3 (-685 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-685 (-1166 |#4|))) 45)) (-2072 (((-1166 (-1166 |#4|)) (-1 |#4| |#1|) |#3|) 54))) 
-(((-514 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1725 (|#2| (-1 |#1| |#4|) (-1166 |#4|))) (-15 -1725 ((-1166 |#4|) (-1 |#4| |#1|) |#2|)) (-15 -2538 ((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1166 |#4|))) (-15 -3239 ((-3 (-685 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-685 (-1166 |#4|)))) (-15 -2072 ((-1166 (-1166 |#4|)) (-1 |#4| |#1|) |#3|))) (-1054) (-1234 |#1|) (-1234 |#2|) (-1054)) (T -514)) 
-((-2072 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1054)) (-4 *7 (-1054)) (-4 *6 (-1234 *5)) (-5 *2 (-1166 (-1166 *7))) (-5 *1 (-514 *5 *6 *4 *7)) (-4 *4 (-1234 *6)))) (-3239 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *8)) (-5 *4 (-685 (-1166 *8))) (-4 *5 (-1054)) (-4 *8 (-1054)) (-4 *6 (-1234 *5)) (-5 *2 (-685 *6)) (-5 *1 (-514 *5 *6 *7 *8)) (-4 *7 (-1234 *6)))) (-2538 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *7)) (-5 *4 (-1166 *7)) (-4 *5 (-1054)) (-4 *7 (-1054)) (-4 *2 (-1234 *5)) (-5 *1 (-514 *5 *2 *6 *7)) (-4 *6 (-1234 *2)))) (-1725 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1054)) (-4 *7 (-1054)) (-4 *4 (-1234 *5)) (-5 *2 (-1166 *7)) (-5 *1 (-514 *5 *4 *6 *7)) (-4 *6 (-1234 *4)))) (-1725 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *7)) (-5 *4 (-1166 *7)) (-4 *5 (-1054)) (-4 *7 (-1054)) (-4 *2 (-1234 *5)) (-5 *1 (-514 *5 *2 *6 *7)) (-4 *6 (-1234 *2))))) 
-(-10 -7 (-15 -1725 (|#2| (-1 |#1| |#4|) (-1166 |#4|))) (-15 -1725 ((-1166 |#4|) (-1 |#4| |#1|) |#2|)) (-15 -2538 ((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1166 |#4|))) (-15 -3239 ((-3 (-685 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-685 (-1166 |#4|)))) (-15 -2072 ((-1166 (-1166 |#4|)) (-1 |#4| |#1|) |#3|))) 
-((-2262 (((-121) $ $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3735 (((-1264) $) 18)) (-3277 (((-1152) $ (-1170)) 22)) (-2415 (((-1264) $) 14)) (-3972 (((-856) $) 20) (($ (-1152)) 19)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 8)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 7))) 
-(((-515) (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $)) (-15 -3972 ($ (-1152)))))) (T -515)) 
-((-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1152)) (-5 *1 (-515)))) (-2415 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-515)))) (-3735 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-515)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-515))))) 
-(-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $)) (-15 -3972 ($ (-1152))))) 
-((-1518 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|) 19)) (-3559 ((|#1| |#4|) 10)) (-1443 ((|#3| |#4|) 17))) 
-(((-516 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3559 (|#1| |#4|)) (-15 -1443 (|#3| |#4|)) (-15 -1518 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|))) (-562) (-1000 |#1|) (-379 |#1|) (-379 |#2|)) (T -516)) 
-((-1518 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-1000 *4)) (-5 *2 (-2 (|:| |num| *6) (|:| |den| *4))) (-5 *1 (-516 *4 *5 *6 *3)) (-4 *6 (-379 *4)) (-4 *3 (-379 *5)))) (-1443 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-1000 *4)) (-4 *2 (-379 *4)) (-5 *1 (-516 *4 *5 *2 *3)) (-4 *3 (-379 *5)))) (-3559 (*1 *2 *3) (-12 (-4 *4 (-1000 *2)) (-4 *2 (-562)) (-5 *1 (-516 *2 *4 *5 *3)) (-4 *5 (-379 *2)) (-4 *3 (-379 *4))))) 
-(-10 -7 (-15 -3559 (|#1| |#4|)) (-15 -1443 (|#3| |#4|)) (-15 -1518 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|))) 
-((-2262 (((-121) $ $) NIL)) (-2360 (((-1170) $) NIL)) (-4036 (((-769) $) NIL)) (-4562 (((-1170) $ (-1170)) NIL)) (-1981 (((-769) $ (-769)) NIL)) (-2744 (((-973 |#1|) $ (-973 |#1|)) NIL)) (-3935 (((-769) $ (-769)) NIL)) (-2847 (((-33 |#1|) $ (-33 |#1|)) NIL)) (-4558 (((-638 (-780 |#1|)) $ (-638 (-780 |#1|))) NIL)) (-3114 (((-238 (-927 |#1|)) $ (-238 (-927 |#1|))) NIL)) (-2621 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) $ (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|)) NIL)) (-2807 ((|#3| $ |#3|) NIL)) (-2404 (((-973 |#1|) $) NIL)) (-3784 (((-769) $) NIL)) (-2573 (((-33 |#1|) $) NIL)) (-2075 (((-638 (-780 |#1|)) $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1647 (((-121) (-121)) NIL) (((-121)) NIL)) (-1702 (((-856) $) NIL)) (-1670 (((-238 (-927 |#1|)) $) NIL)) (-4316 (((-923) $) NIL)) (-4343 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) $) NIL)) (-2652 (($ (-973 |#1|) (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-33 |#1|) (-769) |#3| (-769) (-238 (-927 |#1|)) |#1| (-1170)) NIL) (($ (-973 |#1|) (-244 |#2| |#1|)) NIL)) (-3972 (((-856) $) NIL)) (-4560 ((|#3| $) NIL)) (-2449 ((|#1| $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-517 |#1| |#2| |#3|) (-13 (-540 |#1| |#2| (-244 |#2| |#1|) (-234 (-4032 |#2|) (-769)) (-973 |#1|) (-780 |#1|) (-927 |#1|) (-238 (-927 |#1|)) |#3|) (-10 -8 (-15 -1702 ((-856) $)) (-15 -1647 ((-121) (-121))) (-15 -1647 ((-121))))) (-368) (-638 (-1170)) (-117)) (T -517)) 
-((-1702 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-517 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1647 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-517 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1647 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-517 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(-13 (-540 |#1| |#2| (-244 |#2| |#1|) (-234 (-4032 |#2|) (-769)) (-973 |#1|) (-780 |#1|) (-927 |#1|) (-238 (-927 |#1|)) |#3|) (-10 -8 (-15 -1702 ((-856) $)) (-15 -1647 ((-121) (-121))) (-15 -1647 ((-121))))) 
-((-2262 (((-121) $ $) NIL)) (-2868 (((-121) $ (-638 |#3|)) 101) (((-121) $) 102)) (-1342 (((-121) $) 144)) (-1584 (($ $ |#4|) 93) (($ $ |#4| (-638 |#3|)) 97)) (-3753 (((-1159 (-638 (-959 |#1|)) (-638 (-290 (-959 |#1|)))) (-638 |#4|)) 137 (|has| |#3| (-613 (-1170))))) (-3043 (($ $ $) 87) (($ $ |#4|) 85)) (-3893 (((-121) $) 143)) (-1834 (($ $) 105)) (-1658 (((-1152) $) NIL)) (-1931 (($ $ $) 79) (($ (-638 $)) 81)) (-2766 (((-121) |#4| $) 104)) (-3679 (((-121) $ $) 68)) (-1730 (($ (-638 |#4|)) 86)) (-2607 (((-1116) $) NIL)) (-2166 (($ (-638 |#4|)) 141)) (-2780 (((-121) $) 142)) (-3604 (($ $) 70)) (-1758 (((-638 |#4|) $) 55)) (-1358 (((-2 (|:| |mval| (-685 |#1|)) (|:| |invmval| (-685 |#1|)) (|:| |genIdeal| $)) $ (-638 |#3|)) NIL)) (-1363 (((-121) |#4| $) 73)) (-2502 (((-572) $ (-638 |#3|)) 106) (((-572) $) 107)) (-3972 (((-856) $) 140) (($ (-638 |#4|)) 82)) (-2230 (($ (-2 (|:| |mval| (-685 |#1|)) (|:| |invmval| (-685 |#1|)) (|:| |genIdeal| $))) NIL)) (-1324 (((-121) $ $) 69)) (-1367 (($ $ $) 89)) (** (($ $ (-769)) 92)) (* (($ $ $) 91))) 
-(((-518 |#1| |#2| |#3| |#4|) (-13 (-1098) (-10 -7 (-15 * ($ $ $)) (-15 ** ($ $ (-769))) (-15 -1367 ($ $ $)) (-15 -3893 ((-121) $)) (-15 -1342 ((-121) $)) (-15 -1363 ((-121) |#4| $)) (-15 -3679 ((-121) $ $)) (-15 -2766 ((-121) |#4| $)) (-15 -2868 ((-121) $ (-638 |#3|))) (-15 -2868 ((-121) $)) (-15 -1931 ($ $ $)) (-15 -1931 ($ (-638 $))) (-15 -3043 ($ $ $)) (-15 -3043 ($ $ |#4|)) (-15 -3604 ($ $)) (-15 -1358 ((-2 (|:| |mval| (-685 |#1|)) (|:| |invmval| (-685 |#1|)) (|:| |genIdeal| $)) $ (-638 |#3|))) (-15 -2230 ($ (-2 (|:| |mval| (-685 |#1|)) (|:| |invmval| (-685 |#1|)) (|:| |genIdeal| $)))) (-15 -2502 ((-572) $ (-638 |#3|))) (-15 -2502 ((-572) $)) (-15 -1834 ($ $)) (-15 -1730 ($ (-638 |#4|))) (-15 -2166 ($ (-638 |#4|))) (-15 -2780 ((-121) $)) (-15 -1758 ((-638 |#4|) $)) (-15 -3972 ($ (-638 |#4|))) (-15 -1584 ($ $ |#4|)) (-15 -1584 ($ $ |#4| (-638 |#3|))) (IF (|has| |#3| (-613 (-1170))) (-15 -3753 ((-1159 (-638 (-959 |#1|)) (-638 (-290 (-959 |#1|)))) (-638 |#4|))) |noBranch|))) (-368) (-794) (-848) (-956 |#1| |#2| |#3|)) (T -518)) 
-((* (*1 *1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-1367 (*1 *1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) (-3893 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-1342 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-1363 (*1 *2 *3 *1) (-12 (-4 *4 (-368)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6)))) (-3679 (*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-2766 (*1 *2 *3 *1) (-12 (-4 *4 (-368)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6)))) (-2868 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-848)) (-4 *4 (-368)) (-4 *5 (-794)) (-5 *2 (-121)) (-5 *1 (-518 *4 *5 *6 *7)) (-4 *7 (-956 *4 *5 *6)))) (-2868 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-1931 (*1 *1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) (-1931 (*1 *1 *2) (-12 (-5 *2 (-638 (-518 *3 *4 *5 *6))) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-3043 (*1 *1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) (-3043 (*1 *1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *2)) (-4 *2 (-956 *3 *4 *5)))) (-3604 (*1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) (-1358 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-848)) (-4 *4 (-368)) (-4 *5 (-794)) (-5 *2 (-2 (|:| |mval| (-685 *4)) (|:| |invmval| (-685 *4)) (|:| |genIdeal| (-518 *4 *5 *6 *7)))) (-5 *1 (-518 *4 *5 *6 *7)) (-4 *7 (-956 *4 *5 *6)))) (-2230 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |mval| (-685 *3)) (|:| |invmval| (-685 *3)) (|:| |genIdeal| (-518 *3 *4 *5 *6)))) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-2502 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-848)) (-4 *4 (-368)) (-4 *5 (-794)) (-5 *2 (-572)) (-5 *1 (-518 *4 *5 *6 *7)) (-4 *7 (-956 *4 *5 *6)))) (-2502 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-572)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-1834 (*1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) (-1730 (*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)))) (-2166 (*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)))) (-2780 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-1758 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *6)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)))) (-1584 (*1 *1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *2)) (-4 *2 (-956 *3 *4 *5)))) (-1584 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-848)) (-4 *4 (-368)) (-4 *5 (-794)) (-5 *1 (-518 *4 *5 *6 *2)) (-4 *2 (-956 *4 *5 *6)))) (-3753 (*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *5 *6)) (-4 *6 (-613 (-1170))) (-4 *4 (-368)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1159 (-638 (-959 *4)) (-638 (-290 (-959 *4))))) (-5 *1 (-518 *4 *5 *6 *7))))) 
-(-13 (-1098) (-10 -7 (-15 * ($ $ $)) (-15 ** ($ $ (-769))) (-15 -1367 ($ $ $)) (-15 -3893 ((-121) $)) (-15 -1342 ((-121) $)) (-15 -1363 ((-121) |#4| $)) (-15 -3679 ((-121) $ $)) (-15 -2766 ((-121) |#4| $)) (-15 -2868 ((-121) $ (-638 |#3|))) (-15 -2868 ((-121) $)) (-15 -1931 ($ $ $)) (-15 -1931 ($ (-638 $))) (-15 -3043 ($ $ $)) (-15 -3043 ($ $ |#4|)) (-15 -3604 ($ $)) (-15 -1358 ((-2 (|:| |mval| (-685 |#1|)) (|:| |invmval| (-685 |#1|)) (|:| |genIdeal| $)) $ (-638 |#3|))) (-15 -2230 ($ (-2 (|:| |mval| (-685 |#1|)) (|:| |invmval| (-685 |#1|)) (|:| |genIdeal| $)))) (-15 -2502 ((-572) $ (-638 |#3|))) (-15 -2502 ((-572) $)) (-15 -1834 ($ $)) (-15 -1730 ($ (-638 |#4|))) (-15 -2166 ($ (-638 |#4|))) (-15 -2780 ((-121) $)) (-15 -1758 ((-638 |#4|) $)) (-15 -3972 ($ (-638 |#4|))) (-15 -1584 ($ $ |#4|)) (-15 -1584 ($ $ |#4| (-638 |#3|))) (IF (|has| |#3| (-613 (-1170))) (-15 -3753 ((-1159 (-638 (-959 |#1|)) (-638 (-290 (-959 |#1|)))) (-638 |#4|))) |noBranch|))) 
-((-4144 (((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572))))) 144)) (-1617 (((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572))))) 145)) (-1748 (((-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572))))) 103)) (-1526 (((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572))))) NIL)) (-1529 (((-638 (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572))))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572))))) 147)) (-1437 (((-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-638 (-858 |#1|))) 159))) 
-(((-519 |#1| |#2|) (-10 -7 (-15 -4144 ((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1617 ((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1526 ((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1748 ((-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1529 ((-638 (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572))))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1437 ((-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-638 (-858 |#1|))))) (-638 (-1170)) (-769)) (T -519)) 
-((-1437 (*1 *2 *2 *3) (-12 (-5 *2 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))) (-5 *3 (-638 (-858 *4))) (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *1 (-519 *4 *5)))) (-1529 (*1 *2 *3) (-12 (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *2 (-638 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572)))))) (-5 *1 (-519 *4 *5)) (-5 *3 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))))) (-1748 (*1 *2 *2) (-12 (-5 *2 (-518 (-413 (-572)) (-234 *4 (-769)) (-858 *3) (-244 *3 (-413 (-572))))) (-14 *3 (-638 (-1170))) (-14 *4 (-769)) (-5 *1 (-519 *3 *4)))) (-1526 (*1 *2 *3) (-12 (-5 *3 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))) (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *2 (-121)) (-5 *1 (-519 *4 *5)))) (-1617 (*1 *2 *3) (-12 (-5 *3 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))) (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *2 (-121)) (-5 *1 (-519 *4 *5)))) (-4144 (*1 *2 *3) (-12 (-5 *3 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))) (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *2 (-121)) (-5 *1 (-519 *4 *5))))) 
-(-10 -7 (-15 -4144 ((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1617 ((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1526 ((-121) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1748 ((-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1529 ((-638 (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572))))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))))) (-15 -1437 ((-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-518 (-413 (-572)) (-234 |#2| (-769)) (-858 |#1|) (-244 |#1| (-413 (-572)))) (-638 (-858 |#1|))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-4328 (($ |#1| |#2|) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-1692 ((|#2| $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-2378 (($) 12 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) 11) (($ $ $) 23)) (-1367 (($ $ $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 18))) 
-(((-520 |#1| |#2|) (-13 (-21) (-522 |#1| |#2|)) (-21) (-848)) (T -520)) 
-NIL 
-(-13 (-21) (-522 |#1| |#2|)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 12)) (-2211 (($) NIL T CONST)) (-4383 (($ $) 26)) (-4328 (($ |#1| |#2|) 23)) (-3828 (($ (-1 |#1| |#1|) $) 25)) (-1692 ((|#2| $) NIL)) (-4373 ((|#1| $) 27)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-2378 (($) 10 T CONST)) (-1324 (((-121) $ $) NIL)) (-1367 (($ $ $) 17)) (* (($ (-923) $) NIL) (($ (-769) $) 22))) 
-(((-521 |#1| |#2|) (-13 (-23) (-522 |#1| |#2|)) (-23) (-848)) (T -521)) 
-NIL 
-(-13 (-23) (-522 |#1| |#2|)) 
-((-2262 (((-121) $ $) 7)) (-4383 (($ $) 12)) (-4328 (($ |#1| |#2|) 15)) (-3828 (($ (-1 |#1| |#1|) $) 16)) (-1692 ((|#2| $) 13)) (-4373 ((|#1| $) 14)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-522 |#1| |#2|) (-1290) (-1098) (-848)) (T -522)) 
-((-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-522 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-848)))) (-4328 (*1 *1 *2 *3) (-12 (-4 *1 (-522 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-848)))) (-4373 (*1 *2 *1) (-12 (-4 *1 (-522 *2 *3)) (-4 *3 (-848)) (-4 *2 (-1098)))) (-1692 (*1 *2 *1) (-12 (-4 *1 (-522 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-848)))) (-4383 (*1 *1 *1) (-12 (-4 *1 (-522 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-848))))) 
-(-13 (-1098) (-10 -8 (-15 -3828 ($ (-1 |t#1| |t#1|) $)) (-15 -4328 ($ |t#1| |t#2|)) (-15 -4373 (|t#1| $)) (-15 -1692 (|t#2| $)) (-15 -4383 ($ $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-4328 (($ |#1| |#2|) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-1692 ((|#2| $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-2378 (($) NIL T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 13)) (-1367 (($ $ $) NIL)) (* (($ (-769) $) NIL) (($ (-923) $) NIL))) 
-(((-523 |#1| |#2|) (-13 (-793) (-522 |#1| |#2|)) (-793) (-848)) (T -523)) 
-NIL 
-(-13 (-793) (-522 |#1| |#2|)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1614 (($ $ $) 16)) (-1572 (((-3 $ "failed") $ $) 13)) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-4328 (($ |#1| |#2|) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-1692 ((|#2| $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL)) (-2378 (($) NIL T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1367 (($ $ $) NIL)) (* (($ (-769) $) NIL) (($ (-923) $) NIL))) 
-(((-524 |#1| |#2|) (-13 (-794) (-522 |#1| |#2|)) (-794) (-848)) (T -524)) 
-NIL 
-(-13 (-794) (-522 |#1| |#2|)) 
-((-2262 (((-121) $ $) NIL)) (-4383 (($ $) 24)) (-4328 (($ |#1| |#2|) 21)) (-3828 (($ (-1 |#1| |#1|) $) 23)) (-1692 ((|#2| $) 26)) (-4373 ((|#1| $) 25)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 20)) (-1324 (((-121) $ $) 13))) 
-(((-525 |#1| |#2|) (-522 |#1| |#2|) (-1098) (-848)) (T -525)) 
-NIL 
-(-522 |#1| |#2|) 
-((-4485 (($ $ (-638 |#2|) (-638 |#3|)) NIL) (($ $ |#2| |#3|) 12))) 
-(((-526 |#1| |#2| |#3|) (-10 -8 (-15 -4485 (|#1| |#1| |#2| |#3|)) (-15 -4485 (|#1| |#1| (-638 |#2|) (-638 |#3|)))) (-527 |#2| |#3|) (-1098) (-1204)) (T -526)) 
-NIL 
-(-10 -8 (-15 -4485 (|#1| |#1| |#2| |#3|)) (-15 -4485 (|#1| |#1| (-638 |#2|) (-638 |#3|)))) 
-((-4485 (($ $ (-638 |#1|) (-638 |#2|)) 7) (($ $ |#1| |#2|) 6))) 
-(((-527 |#1| |#2|) (-1290) (-1098) (-1204)) (T -527)) 
-((-4485 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *4)) (-5 *3 (-638 *5)) (-4 *1 (-527 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1204)))) (-4485 (*1 *1 *1 *2 *3) (-12 (-4 *1 (-527 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1204))))) 
-(-13 (-10 -8 (-15 -4485 ($ $ |t#1| |t#2|)) (-15 -4485 ($ $ (-638 |t#1|) (-638 |t#2|))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 16)) (-2640 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 |#2|))) $) 18)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1685 (((-769) $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-4351 ((|#1| $ (-572)) 23)) (-1333 ((|#2| $ (-572)) 21)) (-3629 (($ (-1 |#1| |#1|) $) 46)) (-2966 (($ (-1 |#2| |#2|) $) 43)) (-1658 (((-1152) $) NIL)) (-3696 (($ $ $) 53 (|has| |#2| (-793)))) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 42) (($ |#1|) NIL)) (-1958 ((|#2| |#1| $) 49)) (-2378 (($) 11 T CONST)) (-1324 (((-121) $ $) 29)) (-1367 (($ $ $) 27) (($ |#1| $) 25)) (* (($ (-923) $) NIL) (($ (-769) $) 36) (($ |#2| |#1|) 31))) 
-(((-528 |#1| |#2| |#3|) (-322 |#1| |#2|) (-1098) (-138) |#2|) (T -528)) 
-NIL 
-(-322 |#1| |#2|) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-4538 (((-121) (-121)) 24)) (-3283 ((|#1| $ (-572) |#1|) 27 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603)))) (-1550 (($ (-1 (-121) |#1|) $) 51)) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-3259 (($ $) 54 (|has| |#1| (-1098)))) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1544 (($ |#1| $) NIL (|has| |#1| (-1098))) (($ (-1 (-121) |#1|) $) 43)) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-4014 (((-572) (-1 (-121) |#1|) $) NIL) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098)))) (-3558 (($ $ (-572)) 13)) (-1570 (((-769) $) 11)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) |#1|) 22)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 20 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-3279 (($ $ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) 34)) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) 35) (($ $ $) NIL (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) 19 (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-1335 (($ $ $ (-572)) 50) (($ |#1| $ (-572)) 36)) (-2603 (($ |#1| $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2742 (($ (-638 |#1|)) 28)) (-1837 ((|#1| $) NIL (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) 18 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 39)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 14)) (-3277 ((|#1| $ (-572) |#1|) NIL) ((|#1| $ (-572)) 32) (($ $ (-1225 (-572))) NIL)) (-2145 (($ $ (-1225 (-572))) 49) (($ $ (-572)) 44)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) 40 (|has| $ (-6 -4603)))) (-1607 (($ $) 31)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-2977 (($ $ $) 41) (($ $ |#1|) 38)) (-4500 (($ $ |#1|) NIL) (($ |#1| $) 37) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-4032 (((-769) $) 15 (|has| $ (-6 -4602))))) 
-(((-529 |#1| |#2|) (-13 (-19 |#1|) (-279 |#1|) (-10 -8 (-15 -2742 ($ (-638 |#1|))) (-15 -1570 ((-769) $)) (-15 -3558 ($ $ (-572))) (-15 -4538 ((-121) (-121))))) (-1204) (-572)) (T -529)) 
-((-2742 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-529 *3 *4)) (-14 *4 (-572)))) (-1570 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-529 *3 *4)) (-4 *3 (-1204)) (-14 *4 (-572)))) (-3558 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-529 *3 *4)) (-4 *3 (-1204)) (-14 *4 *2))) (-4538 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-529 *3 *4)) (-4 *3 (-1204)) (-14 *4 (-572))))) 
-(-13 (-19 |#1|) (-279 |#1|) (-10 -8 (-15 -2742 ($ (-638 |#1|))) (-15 -1570 ((-769) $)) (-15 -3558 ($ $ (-572))) (-15 -4538 ((-121) (-121))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 (((-585 |#1|) $) NIL) (($ $ (-923)) NIL (|has| (-585 |#1|) (-374)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| (-585 |#1|) (-374)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL (|has| (-585 |#1|) (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-585 |#1|) "failed") $) NIL)) (-1318 (((-585 |#1|) $) NIL)) (-4337 (($ (-1259 (-585 |#1|))) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-585 |#1|) (-374)))) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-585 |#1|) (-374)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL (|has| (-585 |#1|) (-374)))) (-1297 (((-121) $) NIL (|has| (-585 |#1|) (-374)))) (-4486 (($ $ (-769)) NIL (-1841 (|has| (-585 |#1|) (-149)) (|has| (-585 |#1|) (-374)))) (($ $) NIL (-1841 (|has| (-585 |#1|) (-149)) (|has| (-585 |#1|) (-374))))) (-1526 (((-121) $) NIL)) (-3377 (((-923) $) NIL (|has| (-585 |#1|) (-374))) (((-834 (-923)) $) NIL (-1841 (|has| (-585 |#1|) (-149)) (|has| (-585 |#1|) (-374))))) (-3893 (((-121) $) NIL)) (-1664 (($) NIL (|has| (-585 |#1|) (-374)))) (-3880 (((-121) $) NIL (|has| (-585 |#1|) (-374)))) (-4429 (((-585 |#1|) $) NIL) (($ $ (-923)) NIL (|has| (-585 |#1|) (-374)))) (-3961 (((-3 $ "failed") $) NIL (|has| (-585 |#1|) (-374)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 (-585 |#1|)) $) NIL) (((-1166 $) $ (-923)) NIL (|has| (-585 |#1|) (-374)))) (-3633 (((-923) $) NIL (|has| (-585 |#1|) (-374)))) (-4064 (((-1166 (-585 |#1|)) $) NIL (|has| (-585 |#1|) (-374)))) (-4484 (((-1166 (-585 |#1|)) $) NIL (|has| (-585 |#1|) (-374))) (((-3 (-1166 (-585 |#1|)) "failed") $ $) NIL (|has| (-585 |#1|) (-374)))) (-2359 (($ $ (-1166 (-585 |#1|))) NIL (|has| (-585 |#1|) (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-585 |#1|) (-374)) CONST)) (-1763 (($ (-923)) NIL (|has| (-585 |#1|) (-374)))) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-2307 (($) NIL (|has| (-585 |#1|) (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| (-585 |#1|) (-374)))) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL) (((-923)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL (|has| (-585 |#1|) (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-769) $) NIL (|has| (-585 |#1|) (-374))) (((-3 (-769) "failed") $ $) NIL (-1841 (|has| (-585 |#1|) (-149)) (|has| (-585 |#1|) (-374))))) (-2502 (((-140)) NIL)) (-3139 (($ $) NIL (|has| (-585 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-585 |#1|) (-374)))) (-4316 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-2830 (((-1166 (-585 |#1|))) NIL)) (-2278 (($) NIL (|has| (-585 |#1|) (-374)))) (-3627 (($) NIL (|has| (-585 |#1|) (-374)))) (-3160 (((-1259 (-585 |#1|)) $) NIL) (((-685 (-585 |#1|)) (-1259 $)) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| (-585 |#1|) (-374)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-585 |#1|)) NIL)) (-2779 (($ $) NIL (|has| (-585 |#1|) (-374))) (((-3 $ "failed") $) NIL (-1841 (|has| (-585 |#1|) (-149)) (|has| (-585 |#1|) (-374))))) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL) (((-1259 $) (-923)) NIL)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-2611 (($ $) NIL (|has| (-585 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-585 |#1|) (-374)))) (-1557 (($ $) NIL (|has| (-585 |#1|) (-374))) (($ $ (-769)) NIL (|has| (-585 |#1|) (-374)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL) (($ $ (-585 |#1|)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ $ (-585 |#1|)) NIL) (($ (-585 |#1|) $) NIL))) 
-(((-530 |#1| |#2|) (-329 (-585 |#1|)) (-923) (-923)) (T -530)) 
-NIL 
-(-329 (-585 |#1|)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) (-572) |#1|) 33)) (-1823 (($ $ (-572) |#4|) NIL)) (-1695 (($ $ (-572) |#5|) NIL)) (-2211 (($) NIL T CONST)) (-4267 ((|#4| $ (-572)) NIL)) (-3037 ((|#1| $ (-572) (-572) |#1|) 32)) (-4212 ((|#1| $ (-572) (-572)) 30)) (-2010 (((-638 |#1|) $) NIL)) (-3704 (((-769) $) 26)) (-1364 (($ (-769) (-769) |#1|) 23)) (-3712 (((-769) $) 28)) (-2157 (((-121) $ (-769)) NIL)) (-2660 (((-572) $) 24)) (-3092 (((-572) $) 25)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3927 (((-572) $) 27)) (-3227 (((-572) $) 29)) (-2435 (($ (-1 |#1| |#1|) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) 36 (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3299 (($ $ |#1|) NIL)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 14)) (-1665 (($) 15)) (-3277 ((|#1| $ (-572) (-572)) 31) ((|#1| $ (-572) (-572) |#1|) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-4580 ((|#5| $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-531 |#1| |#2| |#3| |#4| |#5|) (-62 |#1| |#4| |#5|) (-1204) (-572) (-572) (-379 |#1|) (-379 |#1|)) (T -531)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) (-592) |#1|) NIL)) (-2547 (($ $ (-592) (-529 |#1| |#3|)) NIL)) (-2242 (($ $ (-592) (-529 |#1| |#2|)) NIL)) (-3001 (($) NIL T CONST)) (-2747 (((-529 |#1| |#3|) $ (-592)) NIL)) (-1426 ((|#1| $ (-592) (-592) |#1|) NIL)) (-3959 ((|#1| $ (-592) (-592)) NIL)) (-4004 (((-658 |#1|) $) NIL)) (-4292 (((-790) $) NIL)) (-3242 (($ (-790) (-790) |#1|) NIL)) (-4298 (((-790) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-4577 (((-592) $) NIL)) (-4280 (((-592) $) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1898 (((-592) $) NIL)) (-3005 (((-592) $) NIL)) (-3987 (($ (-1 |#1| |#1|) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1892 (($ $ |#1|) NIL)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) (-592)) NIL) ((|#1| $ (-592) (-592) |#1|) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-2000 (((-529 |#1| |#2|) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-530 |#1| |#2| |#3|) (-62 |#1| (-529 |#1| |#3|) (-529 |#1| |#2|)) (-1225) (-592) (-592)) (T -530)) 
+NIL 
+(-62 |#1| (-529 |#1| |#3|) (-529 |#1| |#2|)) 
+((-3344 (((-658 (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|)))) (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) (-790) (-790)) 27)) (-3382 (((-658 (-1187 |#1|)) |#1| (-790) (-790) (-790)) 34)) (-3219 (((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) (-658 |#3|) (-658 (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|)))) (-790)) 83))) 
+(((-531 |#1| |#2| |#3|) (-10 -7 (-15 -3382 ((-658 (-1187 |#1|)) |#1| (-790) (-790) (-790))) (-15 -3344 ((-658 (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|)))) (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) (-790) (-790))) (-15 -3219 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) (-658 |#3|) (-658 (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|)))) (-790)))) (-373) (-1255 |#1|) (-1255 |#2|)) (T -531)) 
+((-3219 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 (-2 (|:| -2195 (-706 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-706 *7))))) (-5 *5 (-790)) (-4 *8 (-1255 *7)) (-4 *7 (-1255 *6)) (-4 *6 (-373)) (-5 *2 (-2 (|:| -2195 (-706 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-706 *7)))) (-5 *1 (-531 *6 *7 *8)))) (-3344 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-790)) (-4 *5 (-373)) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-2 (|:| -2195 (-706 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-706 *6))))) (-5 *1 (-531 *5 *6 *7)) (-5 *3 (-2 (|:| -2195 (-706 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-706 *6)))) (-4 *7 (-1255 *6)))) (-3382 (*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-790)) (-4 *3 (-373)) (-4 *5 (-1255 *3)) (-5 *2 (-658 (-1187 *3))) (-5 *1 (-531 *3 *5 *6)) (-4 *6 (-1255 *5))))) 
+(-10 -7 (-15 -3382 ((-658 (-1187 |#1|)) |#1| (-790) (-790) (-790))) (-15 -3344 ((-658 (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|)))) (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) (-790) (-790))) (-15 -3219 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) (-658 |#3|) (-658 (-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|)))) (-790)))) 
+((-3277 (((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) (-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) (-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|)))) 60)) (-2664 ((|#1| (-706 |#1|) |#1| (-790)) 25)) (-3506 (((-790) (-790) (-790)) 30)) (-2600 (((-706 |#1|) (-706 |#1|) (-706 |#1|)) 42)) (-4029 (((-706 |#1|) (-706 |#1|) (-706 |#1|) |#1|) 50) (((-706 |#1|) (-706 |#1|) (-706 |#1|)) 47)) (-4155 ((|#1| (-706 |#1|) (-706 |#1|) |#1| (-592)) 29)) (-2236 ((|#1| (-706 |#1|)) 18))) 
+(((-532 |#1| |#2| |#3|) (-10 -7 (-15 -2236 (|#1| (-706 |#1|))) (-15 -2664 (|#1| (-706 |#1|) |#1| (-790))) (-15 -4155 (|#1| (-706 |#1|) (-706 |#1|) |#1| (-592))) (-15 -3506 ((-790) (-790) (-790))) (-15 -4029 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -4029 ((-706 |#1|) (-706 |#1|) (-706 |#1|) |#1|)) (-15 -2600 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -3277 ((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) (-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) (-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|)))))) (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $)))) (-1255 |#1|) (-435 |#1| |#2|)) (T -532)) 
+((-3277 (*1 *2 *2 *2) (-12 (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) (-2600 (*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) (-4029 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) (-4029 (*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) (-3506 (*1 *2 *2 *2) (-12 (-5 *2 (-790)) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) (-4155 (*1 *2 *3 *3 *2 *4) (-12 (-5 *3 (-706 *2)) (-5 *4 (-592)) (-4 *2 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *5 (-1255 *2)) (-5 *1 (-532 *2 *5 *6)) (-4 *6 (-435 *2 *5)))) (-2664 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-706 *2)) (-5 *4 (-790)) (-4 *2 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *5 (-1255 *2)) (-5 *1 (-532 *2 *5 *6)) (-4 *6 (-435 *2 *5)))) (-2236 (*1 *2 *3) (-12 (-5 *3 (-706 *2)) (-4 *4 (-1255 *2)) (-4 *2 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-5 *1 (-532 *2 *4 *5)) (-4 *5 (-435 *2 *4))))) 
+(-10 -7 (-15 -2236 (|#1| (-706 |#1|))) (-15 -2664 (|#1| (-706 |#1|) |#1| (-790))) (-15 -4155 (|#1| (-706 |#1|) (-706 |#1|) |#1| (-592))) (-15 -3506 ((-790) (-790) (-790))) (-15 -4029 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -4029 ((-706 |#1|) (-706 |#1|) (-706 |#1|) |#1|)) (-15 -2600 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -3277 ((-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) (-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|))) (-2 (|:| -2195 (-706 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-706 |#1|)))))) 
+((-1641 (((-141) $ $) NIL)) (-3163 (($ $) NIL)) (-2773 (($ $ $) 35)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) $) NIL (|has| (-141) (-869))) (((-141) (-1 (-141) (-141) (-141)) $) NIL)) (-2831 (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-141) (-869)))) (($ (-1 (-141) (-141) (-141)) $) NIL (|has| $ (-6 -4626)))) (-3960 (($ $) NIL (|has| (-141) (-869))) (($ (-1 (-141) (-141) (-141)) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-141) $ (-1246 (-592)) (-141)) NIL (|has| $ (-6 -4626))) (((-141) $ (-592) (-141)) 36 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-4459 (($ (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625))) (($ (-141) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-3657 (((-141) (-1 (-141) (-141) (-141)) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-141) (-141)) $ (-141)) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-141) (-141)) $ (-141) (-141)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-1426 (((-141) $ (-592) (-141)) NIL (|has| $ (-6 -4626)))) (-3959 (((-141) $ (-592)) NIL)) (-1721 (((-592) (-141) $ (-592)) NIL (|has| (-141) (-1119))) (((-592) (-141) $) NIL (|has| (-141) (-1119))) (((-592) (-1 (-141) (-141)) $) NIL)) (-4004 (((-658 (-141)) $) NIL (|has| $ (-6 -4625)))) (-3573 (($ $ $) 33)) (-3252 (($ $) NIL)) (-1419 (($ $ $) NIL)) (-3242 (($ (-790) (-141)) 23)) (-3782 (($ $ $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 8 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL)) (-4491 (($ $ $) NIL (|has| (-141) (-869))) (($ (-1 (-141) (-141) (-141)) $ $) NIL)) (-4467 (((-658 (-141)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-141) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL)) (-3987 (($ (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-141) (-141) (-141)) $ $) 30) (($ (-1 (-141) (-141)) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-3666 (($ $ $ (-592)) NIL) (($ (-141) $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-141) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-141) "failed") (-1 (-141) (-141)) $) NIL)) (-1892 (($ $ (-141)) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-141)) (-658 (-141))) NIL (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-141) (-141)) NIL (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-310 (-141))) NIL (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119)))) (($ $ (-658 (-310 (-141)))) NIL (-12 (|has| (-141) (-325 (-141))) (|has| (-141) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-141) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119))))) (-4210 (((-658 (-141)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 24)) (-3927 (($ $ (-1246 (-592))) NIL) (((-141) $ (-592)) 18) (((-141) $ (-592) (-141)) NIL)) (-3208 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-3452 (((-790) (-141) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-141) (-1119)))) (((-790) (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625)))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) 25)) (-1778 (((-565) $) NIL (|has| (-141) (-633 (-565))))) (-4466 (($ (-658 (-141))) NIL)) (-2266 (($ (-658 $)) NIL) (($ $ $) NIL) (($ (-141) $) NIL) (($ $ (-141)) NIL)) (-1683 (((-877) $) 22)) (-3369 (((-141) (-1 (-141) (-141)) $) NIL (|has| $ (-6 -4625)))) (-1732 (($ $ $) 31)) (-1424 (($ $) NIL)) (-1623 (($ $ $) NIL)) (-1447 (($ $ $) 39)) (-1422 (($ $) 37)) (-3214 (($ $ $) 38)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 26)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 27)) (-1616 (($ $ $) NIL)) (-1699 (((-790) $) 10 (|has| $ (-6 -4625))))) 
+(((-533 |#1|) (-13 (-153) (-10 -8 (-15 -1422 ($ $)) (-15 -1447 ($ $ $)) (-15 -3214 ($ $ $)))) (-592)) (T -533)) 
+((-1422 (*1 *1 *1) (-12 (-5 *1 (-533 *2)) (-14 *2 (-592)))) (-1447 (*1 *1 *1 *1) (-12 (-5 *1 (-533 *2)) (-14 *2 (-592)))) (-3214 (*1 *1 *1 *1) (-12 (-5 *1 (-533 *2)) (-14 *2 (-592))))) 
+(-13 (-153) (-10 -8 (-15 -1422 ($ $)) (-15 -1447 ($ $ $)) (-15 -3214 ($ $ $)))) 
+((-2509 (((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1187 |#4|)) 34)) (-2214 (((-1187 |#4|) (-1 |#4| |#1|) |#2|) 30) ((|#2| (-1 |#1| |#4|) (-1187 |#4|)) 21)) (-2108 (((-3 (-706 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-706 (-1187 |#4|))) 45)) (-3522 (((-1187 (-1187 |#4|)) (-1 |#4| |#1|) |#3|) 54))) 
+(((-534 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2214 (|#2| (-1 |#1| |#4|) (-1187 |#4|))) (-15 -2214 ((-1187 |#4|) (-1 |#4| |#1|) |#2|)) (-15 -2509 ((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1187 |#4|))) (-15 -2108 ((-3 (-706 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-706 (-1187 |#4|)))) (-15 -3522 ((-1187 (-1187 |#4|)) (-1 |#4| |#1|) |#3|))) (-1075) (-1255 |#1|) (-1255 |#2|) (-1075)) (T -534)) 
+((-3522 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1075)) (-4 *7 (-1075)) (-4 *6 (-1255 *5)) (-5 *2 (-1187 (-1187 *7))) (-5 *1 (-534 *5 *6 *4 *7)) (-4 *4 (-1255 *6)))) (-2108 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *8)) (-5 *4 (-706 (-1187 *8))) (-4 *5 (-1075)) (-4 *8 (-1075)) (-4 *6 (-1255 *5)) (-5 *2 (-706 *6)) (-5 *1 (-534 *5 *6 *7 *8)) (-4 *7 (-1255 *6)))) (-2509 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *7)) (-5 *4 (-1187 *7)) (-4 *5 (-1075)) (-4 *7 (-1075)) (-4 *2 (-1255 *5)) (-5 *1 (-534 *5 *2 *6 *7)) (-4 *6 (-1255 *2)))) (-2214 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1075)) (-4 *7 (-1075)) (-4 *4 (-1255 *5)) (-5 *2 (-1187 *7)) (-5 *1 (-534 *5 *4 *6 *7)) (-4 *6 (-1255 *4)))) (-2214 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *7)) (-5 *4 (-1187 *7)) (-4 *5 (-1075)) (-4 *7 (-1075)) (-4 *2 (-1255 *5)) (-5 *1 (-534 *5 *2 *6 *7)) (-4 *6 (-1255 *2))))) 
+(-10 -7 (-15 -2214 (|#2| (-1 |#1| |#4|) (-1187 |#4|))) (-15 -2214 ((-1187 |#4|) (-1 |#4| |#1|) |#2|)) (-15 -2509 ((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1187 |#4|))) (-15 -2108 ((-3 (-706 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-706 (-1187 |#4|)))) (-15 -3522 ((-1187 (-1187 |#4|)) (-1 |#4| |#1|) |#3|))) 
+((-1641 (((-141) $ $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3948 (((-1285) $) 18)) (-3927 (((-1173) $ (-1191)) 22)) (-3536 (((-1285) $) 14)) (-1683 (((-877) $) 20) (($ (-1173)) 19)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 8)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 7))) 
+(((-535) (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $)) (-15 -1683 ($ (-1173)))))) (T -535)) 
+((-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1173)) (-5 *1 (-535)))) (-3536 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-535)))) (-3948 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-535)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-535))))) 
+(-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $)) (-15 -1683 ($ (-1173))))) 
+((-3626 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|) 19)) (-2088 ((|#1| |#4|) 10)) (-2219 ((|#3| |#4|) 17))) 
+(((-536 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2088 (|#1| |#4|)) (-15 -2219 (|#3| |#4|)) (-15 -3626 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|))) (-582) (-1021 |#1|) (-399 |#1|) (-399 |#2|)) (T -536)) 
+((-3626 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-1021 *4)) (-5 *2 (-2 (|:| |num| *6) (|:| |den| *4))) (-5 *1 (-536 *4 *5 *6 *3)) (-4 *6 (-399 *4)) (-4 *3 (-399 *5)))) (-2219 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-1021 *4)) (-4 *2 (-399 *4)) (-5 *1 (-536 *4 *5 *2 *3)) (-4 *3 (-399 *5)))) (-2088 (*1 *2 *3) (-12 (-4 *4 (-1021 *2)) (-4 *2 (-582)) (-5 *1 (-536 *2 *4 *5 *3)) (-4 *5 (-399 *2)) (-4 *3 (-399 *4))))) 
+(-10 -7 (-15 -2088 (|#1| |#4|)) (-15 -2219 (|#3| |#4|)) (-15 -3626 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|))) 
+((-1641 (((-141) $ $) NIL)) (-2294 (((-1191) $) NIL)) (-2913 (((-790) $) NIL)) (-2725 (((-1191) $ (-1191)) NIL)) (-2969 (((-790) $ (-790)) NIL)) (-3807 (((-994 |#1|) $ (-994 |#1|)) NIL)) (-2138 (((-790) $ (-790)) NIL)) (-2483 (((-33 |#1|) $ (-33 |#1|)) NIL)) (-2598 (((-658 (-801 |#1|)) $ (-658 (-801 |#1|))) NIL)) (-3710 (((-258 (-948 |#1|)) $ (-258 (-948 |#1|))) NIL)) (-2450 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) $ (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|)) NIL)) (-4153 ((|#3| $ |#3|) NIL)) (-4501 (((-994 |#1|) $) NIL)) (-2903 (((-790) $) NIL)) (-4399 (((-33 |#1|) $) NIL)) (-3607 (((-658 (-801 |#1|)) $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3767 (((-141) (-141)) NIL) (((-141)) NIL)) (-1736 (((-877) $) NIL)) (-3011 (((-258 (-948 |#1|)) $) NIL)) (-4525 (((-944) $) NIL)) (-1761 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) $) NIL)) (-2443 (($ (-994 |#1|) (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-33 |#1|) (-790) |#3| (-790) (-258 (-948 |#1|)) |#1| (-1191)) NIL) (($ (-994 |#1|) (-264 |#2| |#1|)) NIL)) (-1683 (((-877) $) NIL)) (-2663 ((|#3| $) NIL)) (-3204 ((|#1| $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-537 |#1| |#2| |#3|) (-13 (-560 |#1| |#2| (-264 |#2| |#1|) (-254 (-1699 |#2|) (-790)) (-994 |#1|) (-801 |#1|) (-948 |#1|) (-258 (-948 |#1|)) |#3|) (-10 -8 (-15 -1736 ((-877) $)) (-15 -3767 ((-141) (-141))) (-15 -3767 ((-141))))) (-388) (-658 (-1191)) (-137)) (T -537)) 
+((-1736 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3767 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3767 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(-13 (-560 |#1| |#2| (-264 |#2| |#1|) (-254 (-1699 |#2|) (-790)) (-994 |#1|) (-801 |#1|) (-948 |#1|) (-258 (-948 |#1|)) |#3|) (-10 -8 (-15 -1736 ((-877) $)) (-15 -3767 ((-141) (-141))) (-15 -3767 ((-141))))) 
+((-1641 (((-141) $ $) NIL)) (-2979 (((-141) $ (-658 |#3|)) 101) (((-141) $) 102)) (-2272 (((-141) $) 144)) (-1329 (($ $ |#4|) 93) (($ $ |#4| (-658 |#3|)) 97)) (-3278 (((-1180 (-658 (-980 |#1|)) (-658 (-310 (-980 |#1|)))) (-658 |#4|)) 137 (|has| |#3| (-633 (-1191))))) (-2230 (($ $ $) 87) (($ $ |#4|) 85)) (-3558 (((-141) $) 143)) (-2882 (($ $) 105)) (-2685 (((-1173) $) NIL)) (-2852 (($ $ $) 79) (($ (-658 $)) 81)) (-3010 (((-141) |#4| $) 104)) (-4430 (((-141) $ $) 68)) (-2312 (($ (-658 |#4|)) 86)) (-2951 (((-1137) $) NIL)) (-3338 (($ (-658 |#4|)) 141)) (-1548 (((-141) $) 142)) (-3903 (($ $) 70)) (-1551 (((-658 |#4|) $) 55)) (-4172 (((-2 (|:| |mval| (-706 |#1|)) (|:| |invmval| (-706 |#1|)) (|:| |genIdeal| $)) $ (-658 |#3|)) NIL)) (-4332 (((-141) |#4| $) 73)) (-1936 (((-592) $ (-658 |#3|)) 106) (((-592) $) 107)) (-1683 (((-877) $) 140) (($ (-658 |#4|)) 82)) (-2050 (($ (-2 (|:| |mval| (-706 |#1|)) (|:| |invmval| (-706 |#1|)) (|:| |genIdeal| $))) NIL)) (-3255 (((-141) $ $) 69)) (-3300 (($ $ $) 89)) (** (($ $ (-790)) 92)) (* (($ $ $) 91))) 
+(((-538 |#1| |#2| |#3| |#4|) (-13 (-1119) (-10 -7 (-15 * ($ $ $)) (-15 ** ($ $ (-790))) (-15 -3300 ($ $ $)) (-15 -3558 ((-141) $)) (-15 -2272 ((-141) $)) (-15 -4332 ((-141) |#4| $)) (-15 -4430 ((-141) $ $)) (-15 -3010 ((-141) |#4| $)) (-15 -2979 ((-141) $ (-658 |#3|))) (-15 -2979 ((-141) $)) (-15 -2852 ($ $ $)) (-15 -2852 ($ (-658 $))) (-15 -2230 ($ $ $)) (-15 -2230 ($ $ |#4|)) (-15 -3903 ($ $)) (-15 -4172 ((-2 (|:| |mval| (-706 |#1|)) (|:| |invmval| (-706 |#1|)) (|:| |genIdeal| $)) $ (-658 |#3|))) (-15 -2050 ($ (-2 (|:| |mval| (-706 |#1|)) (|:| |invmval| (-706 |#1|)) (|:| |genIdeal| $)))) (-15 -1936 ((-592) $ (-658 |#3|))) (-15 -1936 ((-592) $)) (-15 -2882 ($ $)) (-15 -2312 ($ (-658 |#4|))) (-15 -3338 ($ (-658 |#4|))) (-15 -1548 ((-141) $)) (-15 -1551 ((-658 |#4|) $)) (-15 -1683 ($ (-658 |#4|))) (-15 -1329 ($ $ |#4|)) (-15 -1329 ($ $ |#4| (-658 |#3|))) (IF (|has| |#3| (-633 (-1191))) (-15 -3278 ((-1180 (-658 (-980 |#1|)) (-658 (-310 (-980 |#1|)))) (-658 |#4|))) |noBranch|))) (-388) (-815) (-869) (-977 |#1| |#2| |#3|)) (T -538)) 
+((* (*1 *1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-3300 (*1 *1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) (-3558 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-2272 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-4332 (*1 *2 *3 *1) (-12 (-4 *4 (-388)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6)))) (-4430 (*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-3010 (*1 *2 *3 *1) (-12 (-4 *4 (-388)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6)))) (-2979 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-869)) (-4 *4 (-388)) (-4 *5 (-815)) (-5 *2 (-141)) (-5 *1 (-538 *4 *5 *6 *7)) (-4 *7 (-977 *4 *5 *6)))) (-2979 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-2852 (*1 *1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) (-2852 (*1 *1 *2) (-12 (-5 *2 (-658 (-538 *3 *4 *5 *6))) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-2230 (*1 *1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) (-2230 (*1 *1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *2)) (-4 *2 (-977 *3 *4 *5)))) (-3903 (*1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) (-4172 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-869)) (-4 *4 (-388)) (-4 *5 (-815)) (-5 *2 (-2 (|:| |mval| (-706 *4)) (|:| |invmval| (-706 *4)) (|:| |genIdeal| (-538 *4 *5 *6 *7)))) (-5 *1 (-538 *4 *5 *6 *7)) (-4 *7 (-977 *4 *5 *6)))) (-2050 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |mval| (-706 *3)) (|:| |invmval| (-706 *3)) (|:| |genIdeal| (-538 *3 *4 *5 *6)))) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-1936 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-869)) (-4 *4 (-388)) (-4 *5 (-815)) (-5 *2 (-592)) (-5 *1 (-538 *4 *5 *6 *7)) (-4 *7 (-977 *4 *5 *6)))) (-1936 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-592)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-2882 (*1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) (-2312 (*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)))) (-3338 (*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)))) (-1548 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-1551 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *6)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)))) (-1329 (*1 *1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *2)) (-4 *2 (-977 *3 *4 *5)))) (-1329 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-869)) (-4 *4 (-388)) (-4 *5 (-815)) (-5 *1 (-538 *4 *5 *6 *2)) (-4 *2 (-977 *4 *5 *6)))) (-3278 (*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *5 *6)) (-4 *6 (-633 (-1191))) (-4 *4 (-388)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1180 (-658 (-980 *4)) (-658 (-310 (-980 *4))))) (-5 *1 (-538 *4 *5 *6 *7))))) 
+(-13 (-1119) (-10 -7 (-15 * ($ $ $)) (-15 ** ($ $ (-790))) (-15 -3300 ($ $ $)) (-15 -3558 ((-141) $)) (-15 -2272 ((-141) $)) (-15 -4332 ((-141) |#4| $)) (-15 -4430 ((-141) $ $)) (-15 -3010 ((-141) |#4| $)) (-15 -2979 ((-141) $ (-658 |#3|))) (-15 -2979 ((-141) $)) (-15 -2852 ($ $ $)) (-15 -2852 ($ (-658 $))) (-15 -2230 ($ $ $)) (-15 -2230 ($ $ |#4|)) (-15 -3903 ($ $)) (-15 -4172 ((-2 (|:| |mval| (-706 |#1|)) (|:| |invmval| (-706 |#1|)) (|:| |genIdeal| $)) $ (-658 |#3|))) (-15 -2050 ($ (-2 (|:| |mval| (-706 |#1|)) (|:| |invmval| (-706 |#1|)) (|:| |genIdeal| $)))) (-15 -1936 ((-592) $ (-658 |#3|))) (-15 -1936 ((-592) $)) (-15 -2882 ($ $)) (-15 -2312 ($ (-658 |#4|))) (-15 -3338 ($ (-658 |#4|))) (-15 -1548 ((-141) $)) (-15 -1551 ((-658 |#4|) $)) (-15 -1683 ($ (-658 |#4|))) (-15 -1329 ($ $ |#4|)) (-15 -1329 ($ $ |#4| (-658 |#3|))) (IF (|has| |#3| (-633 (-1191))) (-15 -3278 ((-1180 (-658 (-980 |#1|)) (-658 (-310 (-980 |#1|)))) (-658 |#4|))) |noBranch|))) 
+((-3171 (((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592))))) 144)) (-4148 (((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592))))) 145)) (-1810 (((-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592))))) 103)) (-2802 (((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592))))) NIL)) (-2935 (((-658 (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592))))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592))))) 147)) (-1764 (((-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-658 (-879 |#1|))) 159))) 
+(((-539 |#1| |#2|) (-10 -7 (-15 -3171 ((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -4148 ((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -2802 ((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -1810 ((-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -2935 ((-658 (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592))))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -1764 ((-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-658 (-879 |#1|))))) (-658 (-1191)) (-790)) (T -539)) 
+((-1764 (*1 *2 *2 *3) (-12 (-5 *2 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))) (-5 *3 (-658 (-879 *4))) (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *1 (-539 *4 *5)))) (-2935 (*1 *2 *3) (-12 (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *2 (-658 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592)))))) (-5 *1 (-539 *4 *5)) (-5 *3 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))))) (-1810 (*1 *2 *2) (-12 (-5 *2 (-538 (-433 (-592)) (-254 *4 (-790)) (-879 *3) (-264 *3 (-433 (-592))))) (-14 *3 (-658 (-1191))) (-14 *4 (-790)) (-5 *1 (-539 *3 *4)))) (-2802 (*1 *2 *3) (-12 (-5 *3 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))) (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *2 (-141)) (-5 *1 (-539 *4 *5)))) (-4148 (*1 *2 *3) (-12 (-5 *3 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))) (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *2 (-141)) (-5 *1 (-539 *4 *5)))) (-3171 (*1 *2 *3) (-12 (-5 *3 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))) (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *2 (-141)) (-5 *1 (-539 *4 *5))))) 
+(-10 -7 (-15 -3171 ((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -4148 ((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -2802 ((-141) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -1810 ((-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -2935 ((-658 (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592))))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))))) (-15 -1764 ((-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-538 (-433 (-592)) (-254 |#2| (-790)) (-879 |#1|) (-264 |#1| (-433 (-592)))) (-658 (-879 |#1|))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-4526 (($ |#1| |#2|) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2183 ((|#2| $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3514 (($) 12 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) 11) (($ $ $) 23)) (-3300 (($ $ $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 18))) 
+(((-540 |#1| |#2|) (-13 (-21) (-542 |#1| |#2|)) (-21) (-869)) (T -540)) 
+NIL 
+(-13 (-21) (-542 |#1| |#2|)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 12)) (-3001 (($) NIL T CONST)) (-4593 (($ $) 26)) (-4526 (($ |#1| |#2|) 23)) (-2731 (($ (-1 |#1| |#1|) $) 25)) (-2183 ((|#2| $) NIL)) (-4579 ((|#1| $) 27)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3514 (($) 10 T CONST)) (-3255 (((-141) $ $) NIL)) (-3300 (($ $ $) 17)) (* (($ (-944) $) NIL) (($ (-790) $) 22))) 
+(((-541 |#1| |#2|) (-13 (-23) (-542 |#1| |#2|)) (-23) (-869)) (T -541)) 
+NIL 
+(-13 (-23) (-542 |#1| |#2|)) 
+((-1641 (((-141) $ $) 7)) (-4593 (($ $) 12)) (-4526 (($ |#1| |#2|) 15)) (-2731 (($ (-1 |#1| |#1|) $) 16)) (-2183 ((|#2| $) 13)) (-4579 ((|#1| $) 14)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-542 |#1| |#2|) (-1311) (-1119) (-869)) (T -542)) 
+((-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-542 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-869)))) (-4526 (*1 *1 *2 *3) (-12 (-4 *1 (-542 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-869)))) (-4579 (*1 *2 *1) (-12 (-4 *1 (-542 *2 *3)) (-4 *3 (-869)) (-4 *2 (-1119)))) (-2183 (*1 *2 *1) (-12 (-4 *1 (-542 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-869)))) (-4593 (*1 *1 *1) (-12 (-4 *1 (-542 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-869))))) 
+(-13 (-1119) (-10 -8 (-15 -2731 ($ (-1 |t#1| |t#1|) $)) (-15 -4526 ($ |t#1| |t#2|)) (-15 -4579 (|t#1| $)) (-15 -2183 (|t#2| $)) (-15 -4593 ($ $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-4526 (($ |#1| |#2|) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2183 ((|#2| $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3514 (($) NIL T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 13)) (-3300 (($ $ $) NIL)) (* (($ (-790) $) NIL) (($ (-944) $) NIL))) 
+(((-543 |#1| |#2|) (-13 (-814) (-542 |#1| |#2|)) (-814) (-869)) (T -543)) 
+NIL 
+(-13 (-814) (-542 |#1| |#2|)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4079 (($ $ $) 16)) (-2350 (((-3 $ "failed") $ $) 13)) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-4526 (($ |#1| |#2|) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2183 ((|#2| $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL)) (-3514 (($) NIL T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3300 (($ $ $) NIL)) (* (($ (-790) $) NIL) (($ (-944) $) NIL))) 
+(((-544 |#1| |#2|) (-13 (-815) (-542 |#1| |#2|)) (-815) (-869)) (T -544)) 
+NIL 
+(-13 (-815) (-542 |#1| |#2|)) 
+((-1641 (((-141) $ $) NIL)) (-4593 (($ $) 24)) (-4526 (($ |#1| |#2|) 21)) (-2731 (($ (-1 |#1| |#1|) $) 23)) (-2183 ((|#2| $) 26)) (-4579 ((|#1| $) 25)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 20)) (-3255 (((-141) $ $) 13))) 
+(((-545 |#1| |#2|) (-542 |#1| |#2|) (-1119) (-869)) (T -545)) 
+NIL 
+(-542 |#1| |#2|) 
+((-2806 (($ $ (-658 |#2|) (-658 |#3|)) NIL) (($ $ |#2| |#3|) 12))) 
+(((-546 |#1| |#2| |#3|) (-10 -8 (-15 -2806 (|#1| |#1| |#2| |#3|)) (-15 -2806 (|#1| |#1| (-658 |#2|) (-658 |#3|)))) (-547 |#2| |#3|) (-1119) (-1225)) (T -546)) 
+NIL 
+(-10 -8 (-15 -2806 (|#1| |#1| |#2| |#3|)) (-15 -2806 (|#1| |#1| (-658 |#2|) (-658 |#3|)))) 
+((-2806 (($ $ (-658 |#1|) (-658 |#2|)) 7) (($ $ |#1| |#2|) 6))) 
+(((-547 |#1| |#2|) (-1311) (-1119) (-1225)) (T -547)) 
+((-2806 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *4)) (-5 *3 (-658 *5)) (-4 *1 (-547 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1225)))) (-2806 (*1 *1 *1 *2 *3) (-12 (-4 *1 (-547 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1225))))) 
+(-13 (-10 -8 (-15 -2806 ($ $ |t#1| |t#2|)) (-15 -2806 ($ $ (-658 |t#1|) (-658 |t#2|))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 16)) (-2982 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 |#2|))) $) 18)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1403 (((-790) $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-4449 ((|#1| $ (-592)) 23)) (-2077 ((|#2| $ (-592)) 21)) (-3401 (($ (-1 |#1| |#1|) $) 46)) (-3271 (($ (-1 |#2| |#2|) $) 43)) (-2685 (((-1173) $) NIL)) (-1619 (($ $ $) 53 (|has| |#2| (-814)))) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 42) (($ |#1|) NIL)) (-1937 ((|#2| |#1| $) 49)) (-3514 (($) 11 T CONST)) (-3255 (((-141) $ $) 29)) (-3300 (($ $ $) 27) (($ |#1| $) 25)) (* (($ (-944) $) NIL) (($ (-790) $) 36) (($ |#2| |#1|) 31))) 
+(((-548 |#1| |#2| |#3|) (-342 |#1| |#2|) (-1119) (-158) |#2|) (T -548)) 
+NIL 
+(-342 |#1| |#2|) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) NIL) (((-141) $) NIL (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3071 (((-141) (-141)) 24)) (-3932 ((|#1| $ (-592) |#1|) 27 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626)))) (-4125 (($ (-1 (-141) |#1|) $) 51)) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1461 (($ $) 54 (|has| |#1| (-1119)))) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4065 (($ |#1| $) NIL (|has| |#1| (-1119))) (($ (-1 (-141) |#1|) $) 43)) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-1721 (((-592) (-1 (-141) |#1|) $) NIL) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119)))) (-2056 (($ $ (-592)) 13)) (-2329 (((-790) $) 11)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) |#1|) 22)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 20 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-2713 (($ $ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) 34)) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) 35) (($ $ $) NIL (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) 19 (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2113 (($ $ $ (-592)) 50) (($ |#1| $ (-592)) 36)) (-3666 (($ |#1| $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3769 (($ (-658 |#1|)) 28)) (-1918 ((|#1| $) NIL (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) 18 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 39)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 14)) (-3927 ((|#1| $ (-592) |#1|) NIL) ((|#1| $ (-592)) 32) (($ $ (-1246 (-592))) NIL)) (-4113 (($ $ (-1246 (-592))) 49) (($ $ (-592)) 44)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) 40 (|has| $ (-6 -4626)))) (-4599 (($ $) 31)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-3619 (($ $ $) 41) (($ $ |#1|) 38)) (-2266 (($ $ |#1|) NIL) (($ |#1| $) 37) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-1699 (((-790) $) 15 (|has| $ (-6 -4625))))) 
+(((-549 |#1| |#2|) (-13 (-19 |#1|) (-299 |#1|) (-10 -8 (-15 -3769 ($ (-658 |#1|))) (-15 -2329 ((-790) $)) (-15 -2056 ($ $ (-592))) (-15 -3071 ((-141) (-141))))) (-1225) (-592)) (T -549)) 
+((-3769 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-549 *3 *4)) (-14 *4 (-592)))) (-2329 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-549 *3 *4)) (-4 *3 (-1225)) (-14 *4 (-592)))) (-2056 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-549 *3 *4)) (-4 *3 (-1225)) (-14 *4 *2))) (-3071 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-549 *3 *4)) (-4 *3 (-1225)) (-14 *4 (-592))))) 
+(-13 (-19 |#1|) (-299 |#1|) (-10 -8 (-15 -3769 ($ (-658 |#1|))) (-15 -2329 ((-790) $)) (-15 -2056 ($ $ (-592))) (-15 -3071 ((-141) (-141))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 (((-605 |#1|) $) NIL) (($ $ (-944)) NIL (|has| (-605 |#1|) (-394)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| (-605 |#1|) (-394)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL (|has| (-605 |#1|) (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-605 |#1|) "failed") $) NIL)) (-2400 (((-605 |#1|) $) NIL)) (-1626 (($ (-1280 (-605 |#1|))) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-605 |#1|) (-394)))) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-605 |#1|) (-394)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL (|has| (-605 |#1|) (-394)))) (-3293 (((-141) $) NIL (|has| (-605 |#1|) (-394)))) (-1525 (($ $ (-790)) NIL (-3836 (|has| (-605 |#1|) (-169)) (|has| (-605 |#1|) (-394)))) (($ $) NIL (-3836 (|has| (-605 |#1|) (-169)) (|has| (-605 |#1|) (-394))))) (-2802 (((-141) $) NIL)) (-4346 (((-944) $) NIL (|has| (-605 |#1|) (-394))) (((-855 (-944)) $) NIL (-3836 (|has| (-605 |#1|) (-169)) (|has| (-605 |#1|) (-394))))) (-3558 (((-141) $) NIL)) (-2834 (($) NIL (|has| (-605 |#1|) (-394)))) (-2114 (((-141) $) NIL (|has| (-605 |#1|) (-394)))) (-2793 (((-605 |#1|) $) NIL) (($ $ (-944)) NIL (|has| (-605 |#1|) (-394)))) (-3921 (((-3 $ "failed") $) NIL (|has| (-605 |#1|) (-394)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 (-605 |#1|)) $) NIL) (((-1187 $) $ (-944)) NIL (|has| (-605 |#1|) (-394)))) (-3546 (((-944) $) NIL (|has| (-605 |#1|) (-394)))) (-2343 (((-1187 (-605 |#1|)) $) NIL (|has| (-605 |#1|) (-394)))) (-1492 (((-1187 (-605 |#1|)) $) NIL (|has| (-605 |#1|) (-394))) (((-3 (-1187 (-605 |#1|)) "failed") $ $) NIL (|has| (-605 |#1|) (-394)))) (-2252 (($ $ (-1187 (-605 |#1|))) NIL (|has| (-605 |#1|) (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-605 |#1|) (-394)) CONST)) (-1825 (($ (-944)) NIL (|has| (-605 |#1|) (-394)))) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-2934 (($) NIL (|has| (-605 |#1|) (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| (-605 |#1|) (-394)))) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL) (((-944)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL (|has| (-605 |#1|) (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-790) $) NIL (|has| (-605 |#1|) (-394))) (((-3 (-790) "failed") $ $) NIL (-3836 (|has| (-605 |#1|) (-169)) (|has| (-605 |#1|) (-394))))) (-1936 (((-160)) NIL)) (-3644 (($ $) NIL (|has| (-605 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-605 |#1|) (-394)))) (-4525 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3390 (((-1187 (-605 |#1|))) NIL)) (-3809 (($) NIL (|has| (-605 |#1|) (-394)))) (-3342 (($) NIL (|has| (-605 |#1|) (-394)))) (-2231 (((-1280 (-605 |#1|)) $) NIL) (((-706 (-605 |#1|)) (-1280 $)) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| (-605 |#1|) (-394)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-605 |#1|)) NIL)) (-1517 (($ $) NIL (|has| (-605 |#1|) (-394))) (((-3 $ "failed") $) NIL (-3836 (|has| (-605 |#1|) (-169)) (|has| (-605 |#1|) (-394))))) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL) (((-1280 $) (-944)) NIL)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3417 (($ $) NIL (|has| (-605 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-605 |#1|) (-394)))) (-1940 (($ $) NIL (|has| (-605 |#1|) (-394))) (($ $ (-790)) NIL (|has| (-605 |#1|) (-394)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL) (($ $ (-605 |#1|)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ $ (-605 |#1|)) NIL) (($ (-605 |#1|) $) NIL))) 
+(((-550 |#1| |#2|) (-349 (-605 |#1|)) (-944) (-944)) (T -550)) 
+NIL 
+(-349 (-605 |#1|)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) (-592) |#1|) 33)) (-2547 (($ $ (-592) |#4|) NIL)) (-2242 (($ $ (-592) |#5|) NIL)) (-3001 (($) NIL T CONST)) (-2747 ((|#4| $ (-592)) NIL)) (-1426 ((|#1| $ (-592) (-592) |#1|) 32)) (-3959 ((|#1| $ (-592) (-592)) 30)) (-4004 (((-658 |#1|) $) NIL)) (-4292 (((-790) $) 26)) (-3242 (($ (-790) (-790) |#1|) 23)) (-4298 (((-790) $) 28)) (-4345 (((-141) $ (-790)) NIL)) (-4577 (((-592) $) 24)) (-4280 (((-592) $) 25)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1898 (((-592) $) 27)) (-3005 (((-592) $) 29)) (-3987 (($ (-1 |#1| |#1|) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) 36 (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1892 (($ $ |#1|) NIL)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 14)) (-2890 (($) 15)) (-3927 ((|#1| $ (-592) (-592)) 31) ((|#1| $ (-592) (-592) |#1|) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-2000 ((|#5| $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-551 |#1| |#2| |#3| |#4| |#5|) (-62 |#1| |#4| |#5|) (-1225) (-592) (-592) (-399 |#1|) (-399 |#1|)) (T -551)) 
 NIL 
 (-62 |#1| |#4| |#5|) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) NIL)) (-4230 ((|#1| $) NIL)) (-4232 (($ $) NIL)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) 57 (|has| $ (-6 -4603)))) (-2041 (((-121) $) NIL (|has| |#1| (-848))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-4131 (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848)))) (($ (-1 (-121) |#1| |#1|) $) 55 (|has| $ (-6 -4603)))) (-3008 (($ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-3749 (($ $ $) 23 (|has| $ (-6 -4603)))) (-2656 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-4055 ((|#1| $ |#1|) 21 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ "first" |#1|) 22 (|has| $ (-6 -4603))) (($ $ "rest" $) 24 (|has| $ (-6 -4603))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-1550 (($ (-1 (-121) |#1|) $) NIL)) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4066 ((|#1| $) NIL)) (-2211 (($) NIL T CONST)) (-2985 (($ $) 28 (|has| $ (-6 -4603)))) (-1656 (($ $) 29)) (-1651 (($ $) 18) (($ $ (-769)) 32)) (-3259 (($ $) 53 (|has| |#1| (-1098)))) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1544 (($ |#1| $) NIL (|has| |#1| (-1098))) (($ (-1 (-121) |#1|) $) NIL)) (-3445 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-2429 (((-121) $) NIL)) (-4014 (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098))) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) (-1 (-121) |#1|) $) NIL)) (-2010 (((-638 |#1|) $) 27 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1364 (($ (-769) |#1|) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 31 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-3279 (($ $ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) 56)) (-4475 (($ $ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 51 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1624 (($ |#1|) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) 50 (|has| |#1| (-1098)))) (-3253 ((|#1| $) NIL) (($ $ (-769)) NIL)) (-1335 (($ $ $ (-572)) NIL) (($ |#1| $ (-572)) NIL)) (-2603 (($ $ $ (-572)) NIL) (($ |#1| $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) 13) (($ $ (-769)) NIL)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-3540 (((-121) $) NIL)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 12)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) 17)) (-1665 (($) 16)) (-3277 ((|#1| $ "value") NIL) ((|#1| $ "first") 15) (($ $ "rest") 20) ((|#1| $ "last") NIL) (($ $ (-1225 (-572))) NIL) ((|#1| $ (-572)) NIL) ((|#1| $ (-572) |#1|) NIL)) (-3537 (((-572) $ $) NIL)) (-2145 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-1940 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-1791 (((-121) $) 33)) (-2619 (($ $) NIL)) (-3316 (($ $) NIL (|has| $ (-6 -4603)))) (-1471 (((-769) $) NIL)) (-3622 (($ $) 35)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) 34)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 26)) (-2977 (($ $ $) 52) (($ $ |#1|) NIL)) (-4500 (($ $ $) NIL) (($ |#1| $) 10) (($ (-638 $)) NIL) (($ $ |#1|) NIL)) (-3972 (((-856) $) 45 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) 47 (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-4032 (((-769) $) 9 (|has| $ (-6 -4602))))) 
-(((-532 |#1| |#2|) (-662 |#1|) (-1204) (-572)) (T -532)) 
-NIL 
-(-662 |#1|) 
-((-3292 ((|#4| |#4|) 26)) (-2667 (((-769) |#4|) 31)) (-3095 (((-769) |#4|) 32)) (-1301 (((-638 |#3|) |#4|) 37 (|has| |#3| (-6 -4603)))) (-3750 (((-3 |#4| "failed") |#4|) 47)) (-4040 ((|#4| |#4|) 40)) (-2271 ((|#1| |#4|) 39))) 
-(((-533 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3292 (|#4| |#4|)) (-15 -2667 ((-769) |#4|)) (-15 -3095 ((-769) |#4|)) (IF (|has| |#3| (-6 -4603)) (-15 -1301 ((-638 |#3|) |#4|)) |noBranch|) (-15 -2271 (|#1| |#4|)) (-15 -4040 (|#4| |#4|)) (-15 -3750 ((-3 |#4| "failed") |#4|))) (-368) (-379 |#1|) (-379 |#1|) (-683 |#1| |#2| |#3|)) (T -533)) 
-((-3750 (*1 *2 *2) (|partial| -12 (-4 *3 (-368)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-533 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-4040 (*1 *2 *2) (-12 (-4 *3 (-368)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-533 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-2271 (*1 *2 *3) (-12 (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-368)) (-5 *1 (-533 *2 *4 *5 *3)) (-4 *3 (-683 *2 *4 *5)))) (-1301 (*1 *2 *3) (-12 (|has| *6 (-6 -4603)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-638 *6)) (-5 *1 (-533 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-3095 (*1 *2 *3) (-12 (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-769)) (-5 *1 (-533 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-2667 (*1 *2 *3) (-12 (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-769)) (-5 *1 (-533 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-3292 (*1 *2 *2) (-12 (-4 *3 (-368)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-533 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(-10 -7 (-15 -3292 (|#4| |#4|)) (-15 -2667 ((-769) |#4|)) (-15 -3095 ((-769) |#4|)) (IF (|has| |#3| (-6 -4603)) (-15 -1301 ((-638 |#3|) |#4|)) |noBranch|) (-15 -2271 (|#1| |#4|)) (-15 -4040 (|#4| |#4|)) (-15 -3750 ((-3 |#4| "failed") |#4|))) 
-((-3292 ((|#8| |#4|) 20)) (-1301 (((-638 |#3|) |#4|) 29 (|has| |#7| (-6 -4603)))) (-3750 (((-3 |#8| "failed") |#4|) 23))) 
-(((-534 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -3292 (|#8| |#4|)) (-15 -3750 ((-3 |#8| "failed") |#4|)) (IF (|has| |#7| (-6 -4603)) (-15 -1301 ((-638 |#3|) |#4|)) |noBranch|)) (-562) (-379 |#1|) (-379 |#1|) (-683 |#1| |#2| |#3|) (-1000 |#1|) (-379 |#5|) (-379 |#5|) (-683 |#5| |#6| |#7|)) (T -534)) 
-((-1301 (*1 *2 *3) (-12 (|has| *9 (-6 -4603)) (-4 *4 (-562)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-4 *7 (-1000 *4)) (-4 *8 (-379 *7)) (-4 *9 (-379 *7)) (-5 *2 (-638 *6)) (-5 *1 (-534 *4 *5 *6 *3 *7 *8 *9 *10)) (-4 *3 (-683 *4 *5 *6)) (-4 *10 (-683 *7 *8 *9)))) (-3750 (*1 *2 *3) (|partial| -12 (-4 *4 (-562)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-4 *7 (-1000 *4)) (-4 *2 (-683 *7 *8 *9)) (-5 *1 (-534 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-683 *4 *5 *6)) (-4 *8 (-379 *7)) (-4 *9 (-379 *7)))) (-3292 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-4 *7 (-1000 *4)) (-4 *2 (-683 *7 *8 *9)) (-5 *1 (-534 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-683 *4 *5 *6)) (-4 *8 (-379 *7)) (-4 *9 (-379 *7))))) 
-(-10 -7 (-15 -3292 (|#8| |#4|)) (-15 -3750 ((-3 |#8| "failed") |#4|)) (IF (|has| |#7| (-6 -4603)) (-15 -1301 ((-638 |#3|) |#4|)) |noBranch|)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4169 (($ (-769) (-769)) NIL)) (-2113 (($ $ $) NIL)) (-1444 (($ (-603 |#1| |#3|)) NIL) (($ $) NIL)) (-3083 (((-121) $) NIL)) (-3861 (($ $ (-572) (-572)) 12)) (-3595 (($ $ (-572) (-572)) NIL)) (-4152 (($ $ (-572) (-572) (-572) (-572)) NIL)) (-4369 (($ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2569 (($ $ (-572) (-572) $) NIL)) (-3283 ((|#1| $ (-572) (-572) |#1|) NIL) (($ $ (-638 (-572)) (-638 (-572)) $) NIL)) (-1823 (($ $ (-572) (-603 |#1| |#3|)) NIL)) (-1695 (($ $ (-572) (-603 |#1| |#2|)) NIL)) (-1468 (($ (-769) |#1|) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) 19 (|has| |#1| (-303)))) (-4267 (((-603 |#1| |#3|) $ (-572)) NIL)) (-2667 (((-769) $) 22 (|has| |#1| (-562)))) (-3037 ((|#1| $ (-572) (-572) |#1|) NIL)) (-4212 ((|#1| $ (-572) (-572)) NIL)) (-4439 ((|#1| $) NIL (|has| |#1| (-174)))) (-2010 (((-638 |#1|) $) NIL)) (-3095 (((-769) $) 24 (|has| |#1| (-562)))) (-1301 (((-638 (-603 |#1| |#2|)) $) 27 (|has| |#1| (-562)))) (-3704 (((-769) $) NIL)) (-1364 (($ (-769) (-769) |#1|) NIL)) (-3712 (((-769) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-1522 ((|#1| $) 17 (|has| |#1| (-6 (-4604 "*"))))) (-2660 (((-572) $) 10)) (-3092 (((-572) $) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3927 (((-572) $) 11)) (-3227 (((-572) $) NIL)) (-3597 (($ (-638 (-638 |#1|))) NIL) (($ (-769) (-769) (-1 |#1| (-572) (-572))) NIL)) (-2435 (($ (-1 |#1| |#1|) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2259 (((-638 (-638 |#1|)) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-3750 (((-3 $ "failed") $) 31 (|has| |#1| (-368)))) (-1865 (($ $ $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3299 (($ $ |#1|) NIL)) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) (-572)) NIL) ((|#1| $ (-572) (-572) |#1|) NIL) (($ $ (-638 (-572)) (-638 (-572))) NIL)) (-3132 (($ (-638 |#1|)) NIL) (($ (-638 $)) NIL)) (-3785 (((-121) $) NIL)) (-2271 ((|#1| $) 15 (|has| |#1| (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-1802 (((-638 (-603 |#1| |#2|)) $) NIL (|has| |#1| (-303)))) (-4580 (((-603 |#1| |#2|) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098))) (($ (-603 |#1| |#2|)) NIL)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-572) $) NIL) (((-603 |#1| |#2|) $ (-603 |#1| |#2|)) NIL) (((-603 |#1| |#3|) (-603 |#1| |#3|) $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-535 |#1| |#2| |#3|) (-683 |#1| (-603 |#1| |#3|) (-603 |#1| |#2|)) (-1054) (-572) (-572)) (T -535)) 
-NIL 
-(-683 |#1| (-603 |#1| |#3|) (-603 |#1| |#2|)) 
-((-3030 (((-1166 |#1|) (-769)) 74)) (-3520 (((-1259 |#1|) (-1259 |#1|) (-923)) 67)) (-2853 (((-1264) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) |#1|) 82)) (-3865 (((-1259 |#1|) (-1259 |#1|) (-769)) 36)) (-3286 (((-1259 |#1|) (-923)) 69)) (-3161 (((-1259 |#1|) (-1259 |#1|) (-572)) 24)) (-1805 (((-1166 |#1|) (-1259 |#1|)) 75)) (-1664 (((-1259 |#1|) (-923)) 93)) (-3880 (((-121) (-1259 |#1|)) 78)) (-4429 (((-1259 |#1|) (-1259 |#1|) (-923)) 59)) (-3251 (((-1166 |#1|) (-1259 |#1|)) 87)) (-3633 (((-923) (-1259 |#1|)) 56)) (-4350 (((-1259 |#1|) (-1259 |#1|)) 30)) (-1763 (((-1259 |#1|) (-923) (-923)) 95)) (-4508 (((-1259 |#1|) (-1259 |#1|) (-1116) (-1116)) 23)) (-4514 (((-1259 |#1|) (-1259 |#1|) (-769) (-1116)) 37)) (-2237 (((-1259 (-1259 |#1|)) (-923)) 92)) (-1379 (((-1259 |#1|) (-1259 |#1|) (-1259 |#1|)) 79)) (** (((-1259 |#1|) (-1259 |#1|) (-572)) 43)) (* (((-1259 |#1|) (-1259 |#1|) (-1259 |#1|)) 25))) 
-(((-536 |#1|) (-10 -7 (-15 -2853 ((-1264) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) |#1|)) (-15 -3286 ((-1259 |#1|) (-923))) (-15 -1763 ((-1259 |#1|) (-923) (-923))) (-15 -1805 ((-1166 |#1|) (-1259 |#1|))) (-15 -3030 ((-1166 |#1|) (-769))) (-15 -4514 ((-1259 |#1|) (-1259 |#1|) (-769) (-1116))) (-15 -3865 ((-1259 |#1|) (-1259 |#1|) (-769))) (-15 -4508 ((-1259 |#1|) (-1259 |#1|) (-1116) (-1116))) (-15 -3161 ((-1259 |#1|) (-1259 |#1|) (-572))) (-15 ** ((-1259 |#1|) (-1259 |#1|) (-572))) (-15 * ((-1259 |#1|) (-1259 |#1|) (-1259 |#1|))) (-15 -1379 ((-1259 |#1|) (-1259 |#1|) (-1259 |#1|))) (-15 -4429 ((-1259 |#1|) (-1259 |#1|) (-923))) (-15 -3520 ((-1259 |#1|) (-1259 |#1|) (-923))) (-15 -4350 ((-1259 |#1|) (-1259 |#1|))) (-15 -3633 ((-923) (-1259 |#1|))) (-15 -3880 ((-121) (-1259 |#1|))) (-15 -2237 ((-1259 (-1259 |#1|)) (-923))) (-15 -1664 ((-1259 |#1|) (-923))) (-15 -3251 ((-1166 |#1|) (-1259 |#1|)))) (-353)) (T -536)) 
-((-3251 (*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-353)) (-5 *2 (-1166 *4)) (-5 *1 (-536 *4)))) (-1664 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 *4)) (-5 *1 (-536 *4)) (-4 *4 (-353)))) (-2237 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 (-1259 *4))) (-5 *1 (-536 *4)) (-4 *4 (-353)))) (-3880 (*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-536 *4)))) (-3633 (*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-353)) (-5 *2 (-923)) (-5 *1 (-536 *4)))) (-4350 (*1 *2 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-353)) (-5 *1 (-536 *3)))) (-3520 (*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-923)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) (-4429 (*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-923)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) (-1379 (*1 *2 *2 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-353)) (-5 *1 (-536 *3)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-353)) (-5 *1 (-536 *3)))) (** (*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-572)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) (-3161 (*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-572)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) (-4508 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-1116)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) (-3865 (*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-769)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) (-4514 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-1259 *5)) (-5 *3 (-769)) (-5 *4 (-1116)) (-4 *5 (-353)) (-5 *1 (-536 *5)))) (-3030 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1166 *4)) (-5 *1 (-536 *4)) (-4 *4 (-353)))) (-1805 (*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-353)) (-5 *2 (-1166 *4)) (-5 *1 (-536 *4)))) (-1763 (*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 *4)) (-5 *1 (-536 *4)) (-4 *4 (-353)))) (-3286 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 *4)) (-5 *1 (-536 *4)) (-4 *4 (-353)))) (-2853 (*1 *2 *3 *4) (-12 (-5 *3 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-4 *4 (-353)) (-5 *2 (-1264)) (-5 *1 (-536 *4))))) 
-(-10 -7 (-15 -2853 ((-1264) (-1259 (-638 (-2 (|:| -2148 |#1|) (|:| -1763 (-1116))))) |#1|)) (-15 -3286 ((-1259 |#1|) (-923))) (-15 -1763 ((-1259 |#1|) (-923) (-923))) (-15 -1805 ((-1166 |#1|) (-1259 |#1|))) (-15 -3030 ((-1166 |#1|) (-769))) (-15 -4514 ((-1259 |#1|) (-1259 |#1|) (-769) (-1116))) (-15 -3865 ((-1259 |#1|) (-1259 |#1|) (-769))) (-15 -4508 ((-1259 |#1|) (-1259 |#1|) (-1116) (-1116))) (-15 -3161 ((-1259 |#1|) (-1259 |#1|) (-572))) (-15 ** ((-1259 |#1|) (-1259 |#1|) (-572))) (-15 * ((-1259 |#1|) (-1259 |#1|) (-1259 |#1|))) (-15 -1379 ((-1259 |#1|) (-1259 |#1|) (-1259 |#1|))) (-15 -4429 ((-1259 |#1|) (-1259 |#1|) (-923))) (-15 -3520 ((-1259 |#1|) (-1259 |#1|) (-923))) (-15 -4350 ((-1259 |#1|) (-1259 |#1|))) (-15 -3633 ((-923) (-1259 |#1|))) (-15 -3880 ((-121) (-1259 |#1|))) (-15 -2237 ((-1259 (-1259 |#1|)) (-923))) (-15 -1664 ((-1259 |#1|) (-923))) (-15 -3251 ((-1166 |#1|) (-1259 |#1|)))) 
-((-2509 (((-1 |#1| |#1|) |#1|) 11)) (-2281 (((-1 |#1| |#1|)) 10))) 
-(((-537 |#1|) (-10 -7 (-15 -2281 ((-1 |#1| |#1|))) (-15 -2509 ((-1 |#1| |#1|) |#1|))) (-13 (-722) (-25))) (T -537)) 
-((-2509 (*1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-537 *3)) (-4 *3 (-13 (-722) (-25))))) (-2281 (*1 *2) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-537 *3)) (-4 *3 (-13 (-722) (-25)))))) 
-(-10 -7 (-15 -2281 ((-1 |#1| |#1|))) (-15 -2509 ((-1 |#1| |#1|) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1614 (($ $ $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-4328 (($ (-769) |#1|) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 (-769) (-769)) $) NIL)) (-1692 ((|#1| $) NIL)) (-4373 (((-769) $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 20)) (-2378 (($) NIL T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1367 (($ $ $) NIL)) (* (($ (-769) $) NIL) (($ (-923) $) NIL))) 
-(((-538 |#1|) (-13 (-794) (-522 (-769) |#1|)) (-848)) (T -538)) 
-NIL 
-(-13 (-794) (-522 (-769) |#1|)) 
-((-2572 (((-638 |#2|) (-1166 |#1|) |#3|) 83)) (-4573 (((-638 (-2 (|:| |outval| |#2|) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 |#2|))))) (-685 |#1|) |#3| (-1 (-424 (-1166 |#1|)) (-1166 |#1|))) 99)) (-3568 (((-1166 |#1|) (-685 |#1|)) 95))) 
-(((-539 |#1| |#2| |#3|) (-10 -7 (-15 -3568 ((-1166 |#1|) (-685 |#1|))) (-15 -2572 ((-638 |#2|) (-1166 |#1|) |#3|)) (-15 -4573 ((-638 (-2 (|:| |outval| |#2|) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 |#2|))))) (-685 |#1|) |#3| (-1 (-424 (-1166 |#1|)) (-1166 |#1|))))) (-368) (-368) (-13 (-368) (-846))) (T -539)) 
-((-4573 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *6)) (-5 *5 (-1 (-424 (-1166 *6)) (-1166 *6))) (-4 *6 (-368)) (-5 *2 (-638 (-2 (|:| |outval| *7) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 *7)))))) (-5 *1 (-539 *6 *7 *4)) (-4 *7 (-368)) (-4 *4 (-13 (-368) (-846))))) (-2572 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 *5)) (-4 *5 (-368)) (-5 *2 (-638 *6)) (-5 *1 (-539 *5 *6 *4)) (-4 *6 (-368)) (-4 *4 (-13 (-368) (-846))))) (-3568 (*1 *2 *3) (-12 (-5 *3 (-685 *4)) (-4 *4 (-368)) (-5 *2 (-1166 *4)) (-5 *1 (-539 *4 *5 *6)) (-4 *5 (-368)) (-4 *6 (-13 (-368) (-846)))))) 
-(-10 -7 (-15 -3568 ((-1166 |#1|) (-685 |#1|))) (-15 -2572 ((-638 |#2|) (-1166 |#1|) |#3|)) (-15 -4573 ((-638 (-2 (|:| |outval| |#2|) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 |#2|))))) (-685 |#1|) |#3| (-1 (-424 (-1166 |#1|)) (-1166 |#1|))))) 
-((-2262 (((-121) $ $) 7)) (-2360 (((-1170) $) 20)) (-4036 (((-769) $) 22)) (-4562 (((-1170) $ (-1170)) 23)) (-1981 (((-769) $ (-769)) 28)) (-2744 ((|#5| $ |#5|) 31)) (-3935 (((-769) $ (-769)) 27)) (-2847 (((-33 |#1|) $ (-33 |#1|)) 29)) (-4558 (((-638 |#6|) $ (-638 |#6|)) 24)) (-3114 ((|#8| $ |#8|) 25)) (-2621 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) $ (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|)) 30)) (-2807 ((|#9| $ |#9|) 26)) (-2404 ((|#5| $) 19)) (-3784 (((-769) $) 16)) (-2573 (((-33 |#1|) $) 17)) (-2075 (((-638 |#6|) $) 21)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1670 ((|#8| $) 14)) (-4316 (((-923) $) 12)) (-4343 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) $) 18)) (-2652 (($ |#5| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-33 |#1|) (-769) |#9| (-769) |#8| |#1| (-1170)) 33) (($ |#5| |#3|) 32)) (-3972 (((-856) $) 11)) (-4560 ((|#9| $) 15)) (-2449 ((|#1| $) 13)) (-1324 (((-121) $ $) 6))) 
-(((-540 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-1290) (-368) (-638 (-1170)) (-956 |t#1| |t#4| (-858 |t#2|)) (-232 (-4032 |t#2|) (-769)) (-978 |t#1|) (-645 |t#1|) (-926 |t#1| |t#6|) (-237 |t#7|) (-117)) (T -540)) 
-((-2652 (*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (-12 (-5 *3 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *8)) (-5 *4 (-33 *8)) (-5 *9 (-1170)) (-4 *8 (-368)) (-5 *5 (-769)) (-4 *12 (-232 (-4032 *10) *5)) (-4 *13 (-645 *8)) (-4 *14 (-926 *8 *13)) (-4 *1 (-540 *8 *10 *11 *12 *2 *13 *14 *7 *6)) (-4 *11 (-956 *8 *12 (-858 *10))) (-4 *2 (-978 *8)) (-4 *7 (-237 *14)) (-4 *6 (-117)))) (-2652 (*1 *1 *2 *3) (-12 (-4 *4 (-368)) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-645 *4)) (-4 *8 (-926 *4 *7)) (-4 *1 (-540 *4 *5 *3 *6 *2 *7 *8 *9 *10)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *2 (-978 *4)) (-4 *9 (-237 *8)) (-4 *10 (-117)))) (-2744 (*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *2 (-978 *3)) (-4 *7 (-645 *3)) (-4 *8 (-926 *3 *7)) (-4 *9 (-237 *8)) (-4 *10 (-117)))) (-2621 (*1 *2 *1 *2) (-12 (-5 *2 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *3)) (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)))) (-2847 (*1 *2 *1 *2) (-12 (-5 *2 (-33 *3)) (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)))) (-1981 (*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-769)))) (-3935 (*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-769)))) (-2807 (*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *2 (-117)))) (-3114 (*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *2 (-237 *9)) (-4 *10 (-117)))) (-4558 (*1 *2 *1 *2) (-12 (-5 *2 (-638 *8)) (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)))) (-4562 (*1 *2 *1 *2) (-12 (-5 *2 (-1170)) (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)))) (-4036 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-769)))) (-2075 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-638 *8)))) (-2360 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-1170)))) (-2404 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-645 *3)) (-4 *8 (-926 *3 *7)) (-4 *9 (-237 *8)) (-4 *10 (-117)) (-4 *2 (-978 *3)))) (-4343 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *3)))) (-2573 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-33 *3)))) (-3784 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-769)))) (-4560 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *2 (-117)))) (-1670 (*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-117)) (-4 *2 (-237 *9)))) (-2449 (*1 *2 *1) (-12 (-4 *1 (-540 *2 *3 *4 *5 *6 *7 *8 *9 *10)) (-4 *4 (-956 *2 *5 (-858 *3))) (-4 *5 (-232 (-4032 *3) (-769))) (-4 *6 (-978 *2)) (-4 *7 (-645 *2)) (-4 *8 (-926 *2 *7)) (-4 *9 (-237 *8)) (-4 *10 (-117)) (-4 *2 (-368))))) 
-(-13 (-1096) (-10 -8 (-15 -2652 ($ |t#5| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |t#1|) (-33 |t#1|) (-769) |t#9| (-769) |t#8| |t#1| (-1170))) (-15 -2652 ($ |t#5| |t#3|)) (-15 -2744 (|t#5| $ |t#5|)) (-15 -2621 ((-244 (-3921 (QUOTE X) (QUOTE -2301)) |t#1|) $ (-244 (-3921 (QUOTE X) (QUOTE -2301)) |t#1|))) (-15 -2847 ((-33 |t#1|) $ (-33 |t#1|))) (-15 -1981 ((-769) $ (-769))) (-15 -3935 ((-769) $ (-769))) (-15 -2807 (|t#9| $ |t#9|)) (-15 -3114 (|t#8| $ |t#8|)) (-15 -4558 ((-638 |t#6|) $ (-638 |t#6|))) (-15 -4562 ((-1170) $ (-1170))) (-15 -4036 ((-769) $)) (-15 -2075 ((-638 |t#6|) $)) (-15 -2360 ((-1170) $)) (-15 -2404 (|t#5| $)) (-15 -4343 ((-244 (-3921 (QUOTE X) (QUOTE -2301)) |t#1|) $)) (-15 -2573 ((-33 |t#1|) $)) (-15 -3784 ((-769) $)) (-15 -4560 (|t#9| $)) (-15 -1670 (|t#8| $)) (-15 -2449 (|t#1| $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T) ((-1096) . T)) 
-((-2262 (((-121) $ $) NIL)) (-2360 (((-1170) $) NIL)) (-4036 (((-769) $) NIL)) (-4562 (((-1170) $ (-1170)) NIL)) (-1981 (((-769) $ (-769)) NIL)) (-2744 (((-974 |#1|) $ (-974 |#1|)) NIL)) (-3935 (((-769) $ (-769)) NIL)) (-2847 (((-33 (-863 |#1|)) $ (-33 (-863 |#1|))) NIL)) (-4558 (((-638 (-780 (-863 |#1|))) $ (-638 (-780 (-863 |#1|)))) NIL)) (-3114 (((-238 (-928 |#1|)) $ (-238 (-928 |#1|))) NIL)) (-2621 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) (-863 |#1|)) $ (-244 (-3921 (QUOTE X) (QUOTE -2301)) (-863 |#1|))) NIL)) (-2807 ((|#3| $ |#3|) NIL)) (-2404 (((-974 |#1|) $) NIL)) (-3784 (((-769) $) NIL)) (-2573 (((-33 (-863 |#1|)) $) NIL)) (-2075 (((-638 (-780 (-863 |#1|))) $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1647 (((-121) (-121)) NIL) (((-121)) NIL)) (-1702 (((-856) $) NIL)) (-1670 (((-238 (-928 |#1|)) $) NIL)) (-4316 (((-923) $) NIL)) (-4343 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) (-863 |#1|)) $) NIL)) (-2652 (($ (-974 |#1|) (-244 (-3921 (QUOTE X) (QUOTE -2301)) (-863 |#1|)) (-33 (-863 |#1|)) (-769) |#3| (-769) (-238 (-928 |#1|)) (-863 |#1|) (-1170)) NIL) (($ (-974 |#1|) (-244 |#2| (-863 |#1|))) NIL)) (-3972 (((-856) $) NIL)) (-4560 ((|#3| $) NIL)) (-2449 (((-863 |#1|) $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-541 |#1| |#2| |#3|) (-13 (-540 (-863 |#1|) |#2| (-244 |#2| (-863 |#1|)) (-234 (-4032 |#2|) (-769)) (-974 |#1|) (-780 (-863 |#1|)) (-928 |#1|) (-238 (-928 |#1|)) |#3|) (-10 -8 (-15 -1702 ((-856) $)) (-15 -1647 ((-121) (-121))) (-15 -1647 ((-121))))) (-353) (-638 (-1170)) (-117)) (T -541)) 
-((-1702 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-541 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1647 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-541 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1647 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-541 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(-13 (-540 (-863 |#1|) |#2| (-244 |#2| (-863 |#1|)) (-234 (-4032 |#2|) (-769)) (-974 |#1|) (-780 (-863 |#1|)) (-928 |#1|) (-238 (-928 |#1|)) |#3|) (-10 -8 (-15 -1702 ((-856) $)) (-15 -1647 ((-121) (-121))) (-15 -1647 ((-121))))) 
-((-2262 (((-121) $ $) NIL)) (-2360 (((-1170) $) 42)) (-4036 (((-769) $) 48)) (-4562 (((-1170) $ (-1170)) 81)) (-1981 (((-769) $ (-769)) 71)) (-2744 ((|#5| $ |#5|) 74)) (-3935 (((-769) $ (-769)) 77)) (-2847 (((-33 |#1|) $ (-33 |#1|)) 76)) (-4558 (((-638 |#6|) $ (-638 |#6|)) 79)) (-3114 ((|#8| $ |#8|) 80)) (-2621 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) $ (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|)) 75)) (-2807 ((|#9| $ |#9|) 78)) (-2404 ((|#5| $) 40)) (-3784 (((-769) $) 43)) (-2573 (((-33 |#1|) $) 45)) (-2075 (((-638 |#6|) $) 73)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1647 (((-121) (-121)) 52) (((-121)) 53)) (-1702 (((-856) $) 50)) (-1670 ((|#8| $) 47)) (-4316 (((-923) $) 58)) (-4343 (((-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) $) 44)) (-2652 (($ |#5| (-244 (-3921 (QUOTE X) (QUOTE -2301)) |#1|) (-33 |#1|) (-769) |#9| (-769) |#8| |#1| (-1170)) 59) (($ |#5| |#3|) 70)) (-3972 (((-856) $) 54)) (-4560 ((|#9| $) 46)) (-2449 ((|#1| $) 55)) (-1324 (((-121) $ $) NIL))) 
-(((-542 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-13 (-540 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-10 -8 (-15 -1702 ((-856) $)) (-15 -1647 ((-121) (-121))) (-15 -1647 ((-121))))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|) (-645 |#1|) (-926 |#1| |#6|) (-237 |#7|) (-117)) (T -542)) 
-((-1702 (*1 *2 *1) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-5 *2 (-856)) (-5 *1 (-542 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *10 (-237 *9)) (-4 *11 (-117)))) (-1647 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-5 *1 (-542 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *10 (-237 *9)) (-4 *11 (-117)))) (-1647 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-5 *2 (-121)) (-5 *1 (-542 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *10 (-237 *9)) (-4 *11 (-117))))) 
-(-13 (-540 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-10 -8 (-15 -1702 ((-856) $)) (-15 -1647 ((-121) (-121))) (-15 -1647 ((-121))))) 
-((-3355 (((-841 (-572))) 11)) (-3350 (((-841 (-572))) 13)) (-1757 (((-834 (-572))) 8))) 
-(((-543) (-10 -7 (-15 -1757 ((-834 (-572)))) (-15 -3355 ((-841 (-572)))) (-15 -3350 ((-841 (-572)))))) (T -543)) 
-((-3350 (*1 *2) (-12 (-5 *2 (-841 (-572))) (-5 *1 (-543)))) (-3355 (*1 *2) (-12 (-5 *2 (-841 (-572))) (-5 *1 (-543)))) (-1757 (*1 *2) (-12 (-5 *2 (-834 (-572))) (-5 *1 (-543))))) 
-(-10 -7 (-15 -1757 ((-834 (-572)))) (-15 -3355 ((-841 (-572)))) (-15 -3350 ((-841 (-572))))) 
-((-2891 (((-545) (-1170)) 15)) (-1930 ((|#1| (-545)) 20))) 
-(((-544 |#1|) (-10 -7 (-15 -2891 ((-545) (-1170))) (-15 -1930 (|#1| (-545)))) (-1204)) (T -544)) 
-((-1930 (*1 *2 *3) (-12 (-5 *3 (-545)) (-5 *1 (-544 *2)) (-4 *2 (-1204)))) (-2891 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-545)) (-5 *1 (-544 *4)) (-4 *4 (-1204))))) 
-(-10 -7 (-15 -2891 ((-545) (-1170))) (-15 -1930 (|#1| (-545)))) 
-((-2262 (((-121) $ $) NIL)) (-3855 (((-1152) $) 46)) (-2150 (((-121) $) 43)) (-4154 (((-1170) $) 44)) (-3032 (((-121) $) 41)) (-4035 (((-1152) $) 42)) (-3888 (($ (-1152)) 47)) (-3330 (((-121) $) NIL)) (-4270 (((-121) $) NIL)) (-3664 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-1874 (($ $ (-638 (-1170))) 20)) (-1930 (((-57) $) 22)) (-2814 (((-121) $) NIL)) (-4012 (((-572) $) NIL)) (-2607 (((-1116) $) NIL)) (-3616 (($ $ (-638 (-1170)) (-1170)) 59)) (-2661 (((-121) $) NIL)) (-3997 (((-217) $) NIL)) (-4086 (($ $) 38)) (-1793 (((-856) $) NIL)) (-2352 (((-121) $ $) NIL)) (-3277 (($ $ (-572)) NIL) (($ $ (-638 (-572))) NIL)) (-4323 (((-638 $) $) 28)) (-1847 (((-1170) (-638 $)) 48)) (-4081 (($ (-638 $)) 52) (($ (-1152)) NIL) (($ (-1170)) 18) (($ (-572)) 8) (($ (-217)) 25) (($ (-856)) NIL) (((-1102) $) 11) (($ (-1102)) 12)) (-3254 (((-1170) (-1170) (-638 $)) 51)) (-3972 (((-856) $) NIL)) (-3856 (($ $) 50)) (-3849 (($ $) 49)) (-4555 (($ $ (-638 $)) 56)) (-2332 (((-121) $) 27)) (-2378 (($) 9 T CONST)) (-3255 (($) 10 T CONST)) (-1324 (((-121) $ $) 60)) (-1379 (($ $ $) 65)) (-1367 (($ $ $) 61)) (** (($ $ (-769)) 64) (($ $ (-572)) 63)) (* (($ $ $) 62)) (-4032 (((-572) $) NIL))) 
-(((-545) (-13 (-1101 (-1152) (-1170) (-572) (-217) (-856)) (-613 (-1102)) (-10 -8 (-15 -1930 ((-57) $)) (-15 -4081 ($ (-1102))) (-15 -4555 ($ $ (-638 $))) (-15 -3616 ($ $ (-638 (-1170)) (-1170))) (-15 -1874 ($ $ (-638 (-1170)))) (-15 -1367 ($ $ $)) (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ (-769))) (-15 ** ($ $ (-572))) (-15 0 ($) -3211) (-15 1 ($) -3211) (-15 -4086 ($ $)) (-15 -3855 ((-1152) $)) (-15 -3888 ($ (-1152))) (-15 -1847 ((-1170) (-638 $))) (-15 -3254 ((-1170) (-1170) (-638 $)))))) (T -545)) 
-((-1930 (*1 *2 *1) (-12 (-5 *2 (-57)) (-5 *1 (-545)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-1102)) (-5 *1 (-545)))) (-4555 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-545))) (-5 *1 (-545)))) (-3616 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-1170)) (-5 *1 (-545)))) (-1874 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-545)))) (-1367 (*1 *1 *1 *1) (-5 *1 (-545))) (* (*1 *1 *1 *1) (-5 *1 (-545))) (-1379 (*1 *1 *1 *1) (-5 *1 (-545))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-545)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-545)))) (-2378 (*1 *1) (-5 *1 (-545))) (-3255 (*1 *1) (-5 *1 (-545))) (-4086 (*1 *1 *1) (-5 *1 (-545))) (-3855 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-545)))) (-3888 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-545)))) (-1847 (*1 *2 *3) (-12 (-5 *3 (-638 (-545))) (-5 *2 (-1170)) (-5 *1 (-545)))) (-3254 (*1 *2 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-545))) (-5 *1 (-545))))) 
-(-13 (-1101 (-1152) (-1170) (-572) (-217) (-856)) (-613 (-1102)) (-10 -8 (-15 -1930 ((-57) $)) (-15 -4081 ($ (-1102))) (-15 -4555 ($ $ (-638 $))) (-15 -3616 ($ $ (-638 (-1170)) (-1170))) (-15 -1874 ($ $ (-638 (-1170)))) (-15 -1367 ($ $ $)) (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ (-769))) (-15 ** ($ $ (-572))) (-15 (-2378) ($) -3211) (-15 (-3255) ($) -3211) (-15 -4086 ($ $)) (-15 -3855 ((-1152) $)) (-15 -3888 ($ (-1152))) (-15 -1847 ((-1170) (-638 $))) (-15 -3254 ((-1170) (-1170) (-638 $))))) 
-((-2590 ((|#2| |#2|) 17)) (-2663 ((|#2| |#2|) 13)) (-3577 ((|#2| |#2| (-572) (-572)) 20)) (-2322 ((|#2| |#2|) 15))) 
-(((-546 |#1| |#2|) (-10 -7 (-15 -2663 (|#2| |#2|)) (-15 -2322 (|#2| |#2|)) (-15 -2590 (|#2| |#2|)) (-15 -3577 (|#2| |#2| (-572) (-572)))) (-13 (-562) (-151)) (-1249 |#1|)) (T -546)) 
-((-3577 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-572)) (-4 *4 (-13 (-562) (-151))) (-5 *1 (-546 *4 *2)) (-4 *2 (-1249 *4)))) (-2590 (*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-151))) (-5 *1 (-546 *3 *2)) (-4 *2 (-1249 *3)))) (-2322 (*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-151))) (-5 *1 (-546 *3 *2)) (-4 *2 (-1249 *3)))) (-2663 (*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-151))) (-5 *1 (-546 *3 *2)) (-4 *2 (-1249 *3))))) 
-(-10 -7 (-15 -2663 (|#2| |#2|)) (-15 -2322 (|#2| |#2|)) (-15 -2590 (|#2| |#2|)) (-15 -3577 (|#2| |#2| (-572) (-572)))) 
-((-2334 (((-638 (-290 (-959 |#2|))) (-638 |#2|) (-638 (-1170))) 32)) (-3370 (((-638 |#2|) (-959 |#1|) |#3|) 53) (((-638 |#2|) (-1166 |#1|) |#3|) 52)) (-3899 (((-638 (-638 |#2|)) (-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170)) |#3|) 87))) 
-(((-547 |#1| |#2| |#3|) (-10 -7 (-15 -3370 ((-638 |#2|) (-1166 |#1|) |#3|)) (-15 -3370 ((-638 |#2|) (-959 |#1|) |#3|)) (-15 -3899 ((-638 (-638 |#2|)) (-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170)) |#3|)) (-15 -2334 ((-638 (-290 (-959 |#2|))) (-638 |#2|) (-638 (-1170))))) (-457) (-368) (-13 (-368) (-846))) (T -547)) 
-((-2334 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-638 (-1170))) (-4 *6 (-368)) (-5 *2 (-638 (-290 (-959 *6)))) (-5 *1 (-547 *5 *6 *7)) (-4 *5 (-457)) (-4 *7 (-13 (-368) (-846))))) (-3899 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-638 (-959 *6))) (-5 *4 (-638 (-1170))) (-4 *6 (-457)) (-5 *2 (-638 (-638 *7))) (-5 *1 (-547 *6 *7 *5)) (-4 *7 (-368)) (-4 *5 (-13 (-368) (-846))))) (-3370 (*1 *2 *3 *4) (-12 (-5 *3 (-959 *5)) (-4 *5 (-457)) (-5 *2 (-638 *6)) (-5 *1 (-547 *5 *6 *4)) (-4 *6 (-368)) (-4 *4 (-13 (-368) (-846))))) (-3370 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 *5)) (-4 *5 (-457)) (-5 *2 (-638 *6)) (-5 *1 (-547 *5 *6 *4)) (-4 *6 (-368)) (-4 *4 (-13 (-368) (-846)))))) 
-(-10 -7 (-15 -3370 ((-638 |#2|) (-1166 |#1|) |#3|)) (-15 -3370 ((-638 |#2|) (-959 |#1|) |#3|)) (-15 -3899 ((-638 (-638 |#2|)) (-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170)) |#3|)) (-15 -2334 ((-638 (-290 (-959 |#2|))) (-638 |#2|) (-638 (-1170))))) 
-((-4007 ((|#2| |#2| |#1|) 17)) (-3549 ((|#2| (-638 |#2|)) 26)) (-2141 ((|#2| (-638 |#2|)) 45))) 
-(((-548 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3549 (|#2| (-638 |#2|))) (-15 -2141 (|#2| (-638 |#2|))) (-15 -4007 (|#2| |#2| |#1|))) (-303) (-1234 |#1|) |#1| (-1 |#1| |#1| (-769))) (T -548)) 
-((-4007 (*1 *2 *2 *3) (-12 (-4 *3 (-303)) (-14 *4 *3) (-14 *5 (-1 *3 *3 (-769))) (-5 *1 (-548 *3 *2 *4 *5)) (-4 *2 (-1234 *3)))) (-2141 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-548 *4 *2 *5 *6)) (-4 *4 (-303)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-769))))) (-3549 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-548 *4 *2 *5 *6)) (-4 *4 (-303)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-769)))))) 
-(-10 -7 (-15 -3549 (|#2| (-638 |#2|))) (-15 -2141 (|#2| (-638 |#2|))) (-15 -4007 (|#2| |#2| |#1|))) 
-((-4304 (((-424 (-1166 |#4|)) (-1166 |#4|) (-1 (-424 (-1166 |#3|)) (-1166 |#3|))) 79) (((-424 |#4|) |#4| (-1 (-424 (-1166 |#3|)) (-1166 |#3|))) 164))) 
-(((-549 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4304 ((-424 |#4|) |#4| (-1 (-424 (-1166 |#3|)) (-1166 |#3|)))) (-15 -4304 ((-424 (-1166 |#4|)) (-1166 |#4|) (-1 (-424 (-1166 |#3|)) (-1166 |#3|))))) (-848) (-794) (-13 (-303) (-151)) (-956 |#3| |#2| |#1|)) (T -549)) 
-((-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-424 (-1166 *7)) (-1166 *7))) (-4 *7 (-13 (-303) (-151))) (-4 *5 (-848)) (-4 *6 (-794)) (-4 *8 (-956 *7 *6 *5)) (-5 *2 (-424 (-1166 *8))) (-5 *1 (-549 *5 *6 *7 *8)) (-5 *3 (-1166 *8)))) (-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-424 (-1166 *7)) (-1166 *7))) (-4 *7 (-13 (-303) (-151))) (-4 *5 (-848)) (-4 *6 (-794)) (-5 *2 (-424 *3)) (-5 *1 (-549 *5 *6 *7 *3)) (-4 *3 (-956 *7 *6 *5))))) 
-(-10 -7 (-15 -4304 ((-424 |#4|) |#4| (-1 (-424 (-1166 |#3|)) (-1166 |#3|)))) (-15 -4304 ((-424 (-1166 |#4|)) (-1166 |#4|) (-1 (-424 (-1166 |#3|)) (-1166 |#3|))))) 
-((-2590 ((|#4| |#4|) 73)) (-2663 ((|#4| |#4|) 69)) (-3577 ((|#4| |#4| (-572) (-572)) 75)) (-2322 ((|#4| |#4|) 71))) 
-(((-550 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2663 (|#4| |#4|)) (-15 -2322 (|#4| |#4|)) (-15 -2590 (|#4| |#4|)) (-15 -3577 (|#4| |#4| (-572) (-572)))) (-13 (-368) (-374) (-613 (-572))) (-1234 |#1|) (-720 |#1| |#2|) (-1249 |#3|)) (T -550)) 
-((-3577 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-572)) (-4 *4 (-13 (-368) (-374) (-613 *3))) (-4 *5 (-1234 *4)) (-4 *6 (-720 *4 *5)) (-5 *1 (-550 *4 *5 *6 *2)) (-4 *2 (-1249 *6)))) (-2590 (*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-4 *4 (-1234 *3)) (-4 *5 (-720 *3 *4)) (-5 *1 (-550 *3 *4 *5 *2)) (-4 *2 (-1249 *5)))) (-2322 (*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-4 *4 (-1234 *3)) (-4 *5 (-720 *3 *4)) (-5 *1 (-550 *3 *4 *5 *2)) (-4 *2 (-1249 *5)))) (-2663 (*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-4 *4 (-1234 *3)) (-4 *5 (-720 *3 *4)) (-5 *1 (-550 *3 *4 *5 *2)) (-4 *2 (-1249 *5))))) 
-(-10 -7 (-15 -2663 (|#4| |#4|)) (-15 -2322 (|#4| |#4|)) (-15 -2590 (|#4| |#4|)) (-15 -3577 (|#4| |#4| (-572) (-572)))) 
-((-2590 ((|#2| |#2|) 27)) (-2663 ((|#2| |#2|) 23)) (-3577 ((|#2| |#2| (-572) (-572)) 29)) (-2322 ((|#2| |#2|) 25))) 
-(((-551 |#1| |#2|) (-10 -7 (-15 -2663 (|#2| |#2|)) (-15 -2322 (|#2| |#2|)) (-15 -2590 (|#2| |#2|)) (-15 -3577 (|#2| |#2| (-572) (-572)))) (-13 (-368) (-374) (-613 (-572))) (-1249 |#1|)) (T -551)) 
-((-3577 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-572)) (-4 *4 (-13 (-368) (-374) (-613 *3))) (-5 *1 (-551 *4 *2)) (-4 *2 (-1249 *4)))) (-2590 (*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-5 *1 (-551 *3 *2)) (-4 *2 (-1249 *3)))) (-2322 (*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-5 *1 (-551 *3 *2)) (-4 *2 (-1249 *3)))) (-2663 (*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-5 *1 (-551 *3 *2)) (-4 *2 (-1249 *3))))) 
-(-10 -7 (-15 -2663 (|#2| |#2|)) (-15 -2322 (|#2| |#2|)) (-15 -2590 (|#2| |#2|)) (-15 -3577 (|#2| |#2| (-572) (-572)))) 
-((-2381 (((-3 (-572) "failed") |#2| |#1| (-1 (-3 (-572) "failed") |#1|)) 14) (((-3 (-572) "failed") |#2| |#1| (-572) (-1 (-3 (-572) "failed") |#1|)) 13) (((-3 (-572) "failed") |#2| (-572) (-1 (-3 (-572) "failed") |#1|)) 26))) 
-(((-552 |#1| |#2|) (-10 -7 (-15 -2381 ((-3 (-572) "failed") |#2| (-572) (-1 (-3 (-572) "failed") |#1|))) (-15 -2381 ((-3 (-572) "failed") |#2| |#1| (-572) (-1 (-3 (-572) "failed") |#1|))) (-15 -2381 ((-3 (-572) "failed") |#2| |#1| (-1 (-3 (-572) "failed") |#1|)))) (-1054) (-1234 |#1|)) (T -552)) 
-((-2381 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-572) "failed") *4)) (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-552 *4 *3)) (-4 *3 (-1234 *4)))) (-2381 (*1 *2 *3 *4 *2 *5) (|partial| -12 (-5 *5 (-1 (-3 (-572) "failed") *4)) (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-552 *4 *3)) (-4 *3 (-1234 *4)))) (-2381 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *4 (-1 (-3 (-572) "failed") *5)) (-4 *5 (-1054)) (-5 *2 (-572)) (-5 *1 (-552 *5 *3)) (-4 *3 (-1234 *5))))) 
-(-10 -7 (-15 -2381 ((-3 (-572) "failed") |#2| (-572) (-1 (-3 (-572) "failed") |#1|))) (-15 -2381 ((-3 (-572) "failed") |#2| |#1| (-572) (-1 (-3 (-572) "failed") |#1|))) (-15 -2381 ((-3 (-572) "failed") |#2| |#1| (-1 (-3 (-572) "failed") |#1|)))) 
-((-1481 (($ $ $) 78)) (-1466 (((-424 $) $) 46)) (-3376 (((-3 (-572) "failed") $) 58)) (-1318 (((-572) $) 36)) (-2956 (((-3 (-413 (-572)) "failed") $) 73)) (-3175 (((-121) $) 23)) (-4299 (((-413 (-572)) $) 71)) (-1526 (((-121) $) 49)) (-1968 (($ $ $ $) 85)) (-1908 (((-121) $) 15)) (-2133 (($ $ $) 56)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 68)) (-3961 (((-3 $ "failed") $) 63)) (-1582 (($ $) 22)) (-2144 (($ $ $) 83)) (-1773 (($) 59)) (-2900 (($ $) 52)) (-4304 (((-424 $) $) 44)) (-4247 (((-121) $) 13)) (-4029 (((-769) $) 27)) (-3139 (($ $ (-769)) NIL) (($ $) 10)) (-1607 (($ $) 16)) (-4081 (((-572) $) NIL) (((-545) $) 35) (((-893 (-572)) $) 39) (((-385) $) 30) (((-217) $) 32)) (-2140 (((-769)) 8)) (-1348 (((-121) $ $) 19)) (-3610 (($ $ $) 54))) 
-(((-553 |#1|) (-10 -8 (-15 -2144 (|#1| |#1| |#1|)) (-15 -1968 (|#1| |#1| |#1| |#1|)) (-15 -1582 (|#1| |#1|)) (-15 -1607 (|#1| |#1|)) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -1481 (|#1| |#1| |#1|)) (-15 -1348 ((-121) |#1| |#1|)) (-15 -4247 ((-121) |#1|)) (-15 -1773 (|#1|)) (-15 -3961 ((-3 |#1| "failed") |#1|)) (-15 -4081 ((-217) |#1|)) (-15 -4081 ((-385) |#1|)) (-15 -2133 (|#1| |#1| |#1|)) (-15 -2900 (|#1| |#1|)) (-15 -3610 (|#1| |#1| |#1|)) (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|))) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -4081 ((-572) |#1|)) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -1908 ((-121) |#1|)) (-15 -4029 ((-769) |#1|)) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -1526 ((-121) |#1|)) (-15 -2140 ((-769)))) (-554)) (T -553)) 
-((-2140 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-553 *3)) (-4 *3 (-554))))) 
-(-10 -8 (-15 -2144 (|#1| |#1| |#1|)) (-15 -1968 (|#1| |#1| |#1| |#1|)) (-15 -1582 (|#1| |#1|)) (-15 -1607 (|#1| |#1|)) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -1481 (|#1| |#1| |#1|)) (-15 -1348 ((-121) |#1| |#1|)) (-15 -4247 ((-121) |#1|)) (-15 -1773 (|#1|)) (-15 -3961 ((-3 |#1| "failed") |#1|)) (-15 -4081 ((-217) |#1|)) (-15 -4081 ((-385) |#1|)) (-15 -2133 (|#1| |#1| |#1|)) (-15 -2900 (|#1| |#1|)) (-15 -3610 (|#1| |#1| |#1|)) (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|))) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -4081 ((-572) |#1|)) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -1908 ((-121) |#1|)) (-15 -4029 ((-769) |#1|)) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -1526 ((-121) |#1|)) (-15 -2140 ((-769)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1481 (($ $ $) 82)) (-1572 (((-3 $ "failed") $ $) 18)) (-2934 (($ $ $ $) 70)) (-2844 (($ $) 49)) (-1466 (((-424 $) $) 50)) (-3112 (((-121) $ $) 122)) (-2433 (((-572) $) 111)) (-3351 (($ $ $) 85)) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 103)) (-1318 (((-572) $) 102)) (-2190 (($ $ $) 126)) (-2284 (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 101) (((-685 (-572)) (-685 $)) 100)) (-1799 (((-3 $ "failed") $) 33)) (-2956 (((-3 (-413 (-572)) "failed") $) 79)) (-3175 (((-121) $) 81)) (-4299 (((-413 (-572)) $) 80)) (-3286 (($) 78) (($ $) 77)) (-2208 (($ $ $) 125)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 120)) (-1526 (((-121) $) 51)) (-1968 (($ $ $ $) 68)) (-4489 (($ $ $) 83)) (-1908 (((-121) $) 113)) (-2133 (($ $ $) 94)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 97)) (-3893 (((-121) $) 30)) (-4240 (((-121) $) 89)) (-3961 (((-3 $ "failed") $) 91)) (-4472 (((-121) $) 112)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 129)) (-1628 (($ $ $ $) 69)) (-1771 (($ $ $) 114)) (-4238 (($ $ $) 115)) (-1582 (($ $) 72)) (-3200 (($ $) 86)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-2144 (($ $ $) 67)) (-1773 (($) 90 T CONST)) (-3088 (($ $) 74)) (-2607 (((-1116) $) 10) (($ $) 76)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-2900 (($ $) 95)) (-4304 (((-424 $) $) 48)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 128) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 127)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 121)) (-4247 (((-121) $) 88)) (-4029 (((-769) $) 123)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 124)) (-3139 (($ $ (-769)) 108) (($ $) 106)) (-4340 (($ $) 73)) (-1607 (($ $) 75)) (-4081 (((-572) $) 105) (((-545) $) 99) (((-893 (-572)) $) 98) (((-385) $) 93) (((-217) $) 92)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-572)) 104)) (-2140 (((-769)) 28)) (-1348 (((-121) $ $) 84)) (-3610 (($ $ $) 96)) (-4393 (($) 87)) (-3774 (((-121) $ $) 38)) (-1498 (($ $ $ $) 71)) (-2264 (($ $) 110)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-769)) 109) (($ $) 107)) (-1349 (((-121) $ $) 117)) (-1338 (((-121) $ $) 118)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 116)) (-1334 (((-121) $ $) 119)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-554) (-1290)) (T -554)) 
-((-4240 (*1 *2 *1) (-12 (-4 *1 (-554)) (-5 *2 (-121)))) (-4247 (*1 *2 *1) (-12 (-4 *1 (-554)) (-5 *2 (-121)))) (-4393 (*1 *1) (-4 *1 (-554))) (-3200 (*1 *1 *1) (-4 *1 (-554))) (-3351 (*1 *1 *1 *1) (-4 *1 (-554))) (-1348 (*1 *2 *1 *1) (-12 (-4 *1 (-554)) (-5 *2 (-121)))) (-4489 (*1 *1 *1 *1) (-4 *1 (-554))) (-1481 (*1 *1 *1 *1) (-4 *1 (-554))) (-3175 (*1 *2 *1) (-12 (-4 *1 (-554)) (-5 *2 (-121)))) (-4299 (*1 *2 *1) (-12 (-4 *1 (-554)) (-5 *2 (-413 (-572))))) (-2956 (*1 *2 *1) (|partial| -12 (-4 *1 (-554)) (-5 *2 (-413 (-572))))) (-3286 (*1 *1) (-4 *1 (-554))) (-3286 (*1 *1 *1) (-4 *1 (-554))) (-2607 (*1 *1 *1) (-4 *1 (-554))) (-1607 (*1 *1 *1) (-4 *1 (-554))) (-3088 (*1 *1 *1) (-4 *1 (-554))) (-4340 (*1 *1 *1) (-4 *1 (-554))) (-1582 (*1 *1 *1) (-4 *1 (-554))) (-1498 (*1 *1 *1 *1 *1) (-4 *1 (-554))) (-2934 (*1 *1 *1 *1 *1) (-4 *1 (-554))) (-1628 (*1 *1 *1 *1 *1) (-4 *1 (-554))) (-1968 (*1 *1 *1 *1 *1) (-4 *1 (-554))) (-2144 (*1 *1 *1 *1) (-4 *1 (-554)))) 
-(-13 (-1214) (-303) (-821) (-227) (-613 (-572)) (-1044 (-572)) (-634 (-572)) (-613 (-545)) (-613 (-893 (-572))) (-887 (-572)) (-147) (-1028) (-151) (-1144) (-10 -8 (-15 -4240 ((-121) $)) (-15 -4247 ((-121) $)) (-6 -4601) (-15 -4393 ($)) (-15 -3200 ($ $)) (-15 -3351 ($ $ $)) (-15 -1348 ((-121) $ $)) (-15 -4489 ($ $ $)) (-15 -1481 ($ $ $)) (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $)) (-15 -3286 ($)) (-15 -3286 ($ $)) (-15 -2607 ($ $)) (-15 -1607 ($ $)) (-15 -3088 ($ $)) (-15 -4340 ($ $)) (-15 -1582 ($ $)) (-15 -1498 ($ $ $ $)) (-15 -2934 ($ $ $ $)) (-15 -1628 ($ $ $ $)) (-15 -1968 ($ $ $ $)) (-15 -2144 ($ $ $)) (-6 -4600))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-151) . T) ((-612 (-856)) . T) ((-147) . T) ((-174) . T) ((-613 (-217)) . T) ((-613 (-385)) . T) ((-613 (-545)) . T) ((-613 (-572)) . T) ((-613 (-893 (-572))) . T) ((-227) . T) ((-287) . T) ((-303) . T) ((-457) . T) ((-562) . T) ((-641 $) . T) ((-634 (-572)) . T) ((-713 $) . T) ((-722) . T) ((-792) . T) ((-793) . T) ((-795) . T) ((-796) . T) ((-821) . T) ((-846) . T) ((-848) . T) ((-887 (-572)) . T) ((-922) . T) ((-1028) . T) ((-1044 (-572)) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) . T) ((-1214) . T)) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2430 (((-1264) $ |#1| |#1|) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#2| $ |#1| |#2|) NIL)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 |#2| "failed") |#1| $) NIL)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) NIL)) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) NIL)) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 ((|#1| $) NIL (|has| |#1| (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 ((|#1| $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2760 (((-638 |#1|) $) NIL)) (-2365 (((-121) |#1| $) NIL)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2739 (((-638 |#1|) $) NIL)) (-1601 (((-121) |#1| $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-1837 ((|#2| $) NIL (|has| |#1| (-848)))) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-555 |#1| |#2| |#3|) (-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602))) (-1098) (-1098) (-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602)))) (T -555)) 
-NIL 
-(-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602))) 
-((-2849 (((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) (-1 (-1166 |#2|) (-1166 |#2|))) 49))) 
-(((-556 |#1| |#2|) (-10 -7 (-15 -2849 ((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) (-1 (-1166 |#2|) (-1166 |#2|))))) (-13 (-848) (-562)) (-13 (-27) (-436 |#1|))) (T -556)) 
-((-2849 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-611 *3)) (-5 *5 (-1 (-1166 *3) (-1166 *3))) (-4 *3 (-13 (-27) (-436 *6))) (-4 *6 (-13 (-848) (-562))) (-5 *2 (-589 *3)) (-5 *1 (-556 *6 *3))))) 
-(-10 -7 (-15 -2849 ((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) (-1 (-1166 |#2|) (-1166 |#2|))))) 
-((-2860 (((-589 |#5|) |#5| (-1 |#3| |#3|)) 195)) (-3337 (((-3 |#5| "failed") |#5| (-1 |#3| |#3|)) 191)) (-3121 (((-589 |#5|) |#5| (-1 |#3| |#3|)) 198))) 
-(((-557 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3121 ((-589 |#5|) |#5| (-1 |#3| |#3|))) (-15 -2860 ((-589 |#5|) |#5| (-1 |#3| |#3|))) (-15 -3337 ((-3 |#5| "failed") |#5| (-1 |#3| |#3|)))) (-13 (-848) (-562) (-1044 (-572))) (-13 (-27) (-436 |#1|)) (-1234 |#2|) (-1234 (-413 |#3|)) (-342 |#2| |#3| |#4|)) (T -557)) 
-((-3337 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-27) (-436 *4))) (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-4 *7 (-1234 (-413 *6))) (-5 *1 (-557 *4 *5 *6 *7 *2)) (-4 *2 (-342 *5 *6 *7)))) (-2860 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1234 *6)) (-4 *6 (-13 (-27) (-436 *5))) (-4 *5 (-13 (-848) (-562) (-1044 (-572)))) (-4 *8 (-1234 (-413 *7))) (-5 *2 (-589 *3)) (-5 *1 (-557 *5 *6 *7 *8 *3)) (-4 *3 (-342 *6 *7 *8)))) (-3121 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1234 *6)) (-4 *6 (-13 (-27) (-436 *5))) (-4 *5 (-13 (-848) (-562) (-1044 (-572)))) (-4 *8 (-1234 (-413 *7))) (-5 *2 (-589 *3)) (-5 *1 (-557 *5 *6 *7 *8 *3)) (-4 *3 (-342 *6 *7 *8))))) 
-(-10 -7 (-15 -3121 ((-589 |#5|) |#5| (-1 |#3| |#3|))) (-15 -2860 ((-589 |#5|) |#5| (-1 |#3| |#3|))) (-15 -3337 ((-3 |#5| "failed") |#5| (-1 |#3| |#3|)))) 
-((-1789 (((-121) (-572) (-572)) 10)) (-3042 (((-572) (-572)) 7)) (-3141 (((-572) (-572) (-572)) 8))) 
-(((-558) (-10 -7 (-15 -3042 ((-572) (-572))) (-15 -3141 ((-572) (-572) (-572))) (-15 -1789 ((-121) (-572) (-572))))) (T -558)) 
-((-1789 (*1 *2 *3 *3) (-12 (-5 *3 (-572)) (-5 *2 (-121)) (-5 *1 (-558)))) (-3141 (*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-558)))) (-3042 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-558))))) 
-(-10 -7 (-15 -3042 ((-572) (-572))) (-15 -3141 ((-572) (-572) (-572))) (-15 -1789 ((-121) (-572) (-572)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3632 ((|#1| $) 59)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-4284 (($ $) 89)) (-4224 (($ $) 72)) (-1614 ((|#1| $) 60)) (-1572 (((-3 $ "failed") $ $) 18)) (-4190 (($ $) 71)) (-4273 (($ $) 88)) (-4217 (($ $) 73)) (-4295 (($ $) 87)) (-4233 (($ $) 74)) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 67)) (-1318 (((-572) $) 66)) (-1799 (((-3 $ "failed") $) 33)) (-3963 (($ |#1| |#1|) 64)) (-1908 (((-121) $) 58)) (-4184 (($) 99)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 70)) (-4472 (((-121) $) 57)) (-1771 (($ $ $) 105)) (-4238 (($ $ $) 104)) (-3539 (($ $) 96)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-2121 (($ |#1| |#1|) 65) (($ |#1|) 63) (($ (-413 (-572))) 62)) (-2685 ((|#1| $) 61)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-1803 (((-3 $ "failed") $ $) 41)) (-4179 (($ $) 97)) (-4302 (($ $) 86)) (-4237 (($ $) 75)) (-4289 (($ $) 85)) (-4228 (($ $) 76)) (-4278 (($ $) 84)) (-4220 (($ $) 77)) (-3470 (((-121) $ |#1|) 56)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-572)) 68)) (-2140 (((-769)) 28)) (-4321 (($ $) 95)) (-4251 (($ $) 83)) (-3774 (((-121) $ $) 38)) (-4308 (($ $) 94)) (-4241 (($ $) 82)) (-4333 (($ $) 93)) (-4263 (($ $) 81)) (-2104 (($ $) 92)) (-4268 (($ $) 80)) (-4327 (($ $) 91)) (-4257 (($ $) 79)) (-4314 (($ $) 90)) (-4246 (($ $) 78)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1349 (((-121) $ $) 102)) (-1338 (((-121) $ $) 101)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 103)) (-1334 (((-121) $ $) 100)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ $) 98) (($ $ (-413 (-572))) 69)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-559 |#1|) (-1290) (-13 (-410) (-1190))) (T -559)) 
-((-2121 (*1 *1 *2 *2) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) (-3963 (*1 *1 *2 *2) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) (-2121 (*1 *1 *2) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) (-2121 (*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-4 *1 (-559 *3)) (-4 *3 (-13 (-410) (-1190))))) (-2685 (*1 *2 *1) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) (-1614 (*1 *2 *1) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) (-3632 (*1 *2 *1) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) (-1908 (*1 *2 *1) (-12 (-4 *1 (-559 *3)) (-4 *3 (-13 (-410) (-1190))) (-5 *2 (-121)))) (-4472 (*1 *2 *1) (-12 (-4 *1 (-559 *3)) (-4 *3 (-13 (-410) (-1190))) (-5 *2 (-121)))) (-3470 (*1 *2 *1 *3) (-12 (-4 *1 (-559 *3)) (-4 *3 (-13 (-410) (-1190))) (-5 *2 (-121))))) 
-(-13 (-457) (-848) (-1190) (-1009) (-1044 (-572)) (-10 -8 (-6 -3410) (-15 -2121 ($ |t#1| |t#1|)) (-15 -3963 ($ |t#1| |t#1|)) (-15 -2121 ($ |t#1|)) (-15 -2121 ($ (-413 (-572)))) (-15 -2685 (|t#1| $)) (-15 -1614 (|t#1| $)) (-15 -3632 (|t#1| $)) (-15 -1908 ((-121) $)) (-15 -4472 ((-121) $)) (-15 -3470 ((-121) $ |t#1|)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-40) . T) ((-98) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-281) . T) ((-287) . T) ((-457) . T) ((-506) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-848) . T) ((-1009) . T) ((-1044 (-572)) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1190) . T) ((-1193) . T)) 
-((-2201 (((-1264) (-923) |#3| (-638 |#5|)) 55)) (-2420 ((|#8| |#3| |#3| (-638 |#10|) (-638 |#5|)) 52))) 
-(((-560 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -2420 (|#8| |#3| |#3| (-638 |#10|) (-638 |#5|))) (-15 -2201 ((-1264) (-923) |#3| (-638 |#5|)))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|) (-645 |#1|) (-926 |#1| |#6|) (-237 |#7|) (-540 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-260 |#9|) (-117)) (T -560)) 
-((-2201 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-923)) (-5 *5 (-638 *9)) (-4 *9 (-978 *6)) (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *4 (-956 *6 *8 (-858 *7))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *10 (-645 *6)) (-4 *11 (-926 *6 *10)) (-4 *12 (-237 *11)) (-4 *13 (-540 *6 *7 *4 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-5 *2 (-1264)) (-5 *1 (-560 *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (-4 *14 (-260 *13)))) (-2420 (*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-638 *13)) (-5 *5 (-638 *9)) (-4 *9 (-978 *6)) (-4 *13 (-260 *12)) (-4 *6 (-368)) (-4 *12 (-540 *6 *7 *3 *8 *9 *10 *11 *2 *14)) (-4 *14 (-117)) (-14 *7 (-638 (-1170))) (-4 *3 (-956 *6 *8 (-858 *7))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *10 (-645 *6)) (-4 *11 (-926 *6 *10)) (-4 *2 (-237 *11)) (-5 *1 (-560 *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14))))) 
-(-10 -7 (-15 -2420 (|#8| |#3| |#3| (-638 |#10|) (-638 |#5|))) (-15 -2201 ((-1264) (-923) |#3| (-638 |#5|)))) 
-((-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 9)) (-3946 (($ $) 11)) (-3686 (((-121) $) 18)) (-1799 (((-3 $ "failed") $) 16)) (-3774 (((-121) $ $) 20))) 
-(((-561 |#1|) (-10 -8 (-15 -3686 ((-121) |#1|)) (-15 -3774 ((-121) |#1| |#1|)) (-15 -3946 (|#1| |#1|)) (-15 -4109 ((-2 (|:| -3029 |#1|) (|:| -4589 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -1799 ((-3 |#1| "failed") |#1|))) (-562)) (T -561)) 
-NIL 
-(-10 -8 (-15 -3686 ((-121) |#1|)) (-15 -3774 ((-121) |#1| |#1|)) (-15 -3946 (|#1| |#1|)) (-15 -4109 ((-2 (|:| -3029 |#1|) (|:| -4589 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -1799 ((-3 |#1| "failed") |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ $) 41)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-562) (-1290)) (T -562)) 
-((-1803 (*1 *1 *1 *1) (|partial| -4 *1 (-562))) (-4109 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -3029 *1) (|:| -4589 *1) (|:| |associate| *1))) (-4 *1 (-562)))) (-3946 (*1 *1 *1) (-4 *1 (-562))) (-3774 (*1 *2 *1 *1) (-12 (-4 *1 (-562)) (-5 *2 (-121)))) (-3686 (*1 *2 *1) (-12 (-4 *1 (-562)) (-5 *2 (-121))))) 
-(-13 (-174) (-43 $) (-287) (-10 -8 (-15 -1803 ((-3 $ "failed") $ $)) (-15 -4109 ((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $)) (-15 -3946 ($ $)) (-15 -3774 ((-121) $ $)) (-15 -3686 ((-121) $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-1559 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1170) (-638 |#2|)) 35)) (-1311 (((-589 |#2|) |#2| (-1170)) 58)) (-3644 (((-3 |#2| "failed") |#2| (-1170)) 147)) (-1573 (((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1170) (-611 |#2|) (-638 (-611 |#2|))) 149)) (-3692 (((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1170) |#2|) 38))) 
-(((-563 |#1| |#2|) (-10 -7 (-15 -3692 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1170) |#2|)) (-15 -1559 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1170) (-638 |#2|))) (-15 -3644 ((-3 |#2| "failed") |#2| (-1170))) (-15 -1311 ((-589 |#2|) |#2| (-1170))) (-15 -1573 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1170) (-611 |#2|) (-638 (-611 |#2|))))) (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|))) (T -563)) 
-((-1573 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1170)) (-5 *6 (-638 (-611 *3))) (-5 *5 (-611 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-563 *7 *3)))) (-1311 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-563 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-3644 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-563 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))))) (-1559 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-638 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-563 *6 *3)))) (-3692 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1170)) (-4 *5 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-563 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5)))))) 
-(-10 -7 (-15 -3692 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1170) |#2|)) (-15 -1559 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1170) (-638 |#2|))) (-15 -3644 ((-3 |#2| "failed") |#2| (-1170))) (-15 -1311 ((-589 |#2|) |#2| (-1170))) (-15 -1573 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1170) (-611 |#2|) (-638 (-611 |#2|))))) 
-((-3604 (((-638 |#5|) (-638 |#5|)) 41))) 
-(((-564 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3604 ((-638 |#5|) (-638 |#5|)))) (-368) (-638 (-1170)) (-794) (-848) (-956 |#1| |#3| |#4|)) (T -564)) 
-((-3604 (*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-956 *3 *5 *6)) (-4 *3 (-368)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-564 *3 *4 *5 *6 *7)) (-14 *4 (-638 (-1170)))))) 
-(-10 -7 (-15 -3604 ((-638 |#5|) (-638 |#5|)))) 
-((-1466 (((-424 |#1|) |#1|) 18)) (-4304 (((-424 |#1|) |#1|) 32)) (-4491 (((-3 |#1| "failed") |#1|) 43)) (-4348 (((-424 |#1|) |#1|) 49))) 
-(((-565 |#1|) (-10 -7 (-15 -4304 ((-424 |#1|) |#1|)) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -4348 ((-424 |#1|) |#1|)) (-15 -4491 ((-3 |#1| "failed") |#1|))) (-554)) (T -565)) 
-((-4491 (*1 *2 *2) (|partial| -12 (-5 *1 (-565 *2)) (-4 *2 (-554)))) (-4348 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-565 *3)) (-4 *3 (-554)))) (-1466 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-565 *3)) (-4 *3 (-554)))) (-4304 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-565 *3)) (-4 *3 (-554))))) 
-(-10 -7 (-15 -4304 ((-424 |#1|) |#1|)) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -4348 ((-424 |#1|) |#1|)) (-15 -4491 ((-3 |#1| "failed") |#1|))) 
-((-2390 (((-638 |#3|) |#8| (-638 |#3|)) 45)) (-3711 (((-638 |#3|) |#8| (-769) |#3| (-638 |#3|)) 44)) (-3765 (((-638 (-1259 |#1|)) |#8| (-638 |#3|)) 26)) (-3668 (((-638 (-1259 |#1|)) |#8| (-638 |#3|)) 27))) 
-(((-566 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -3668 ((-638 (-1259 |#1|)) |#8| (-638 |#3|))) (-15 -3765 ((-638 (-1259 |#1|)) |#8| (-638 |#3|))) (-15 -2390 ((-638 |#3|) |#8| (-638 |#3|))) (-15 -3711 ((-638 |#3|) |#8| (-769) |#3| (-638 |#3|)))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|) (-645 |#1|) (-926 |#1| |#6|) (-237 |#7|)) (T -566)) 
-((-3711 (*1 *2 *3 *4 *5 *2) (-12 (-5 *2 (-638 *5)) (-4 *5 (-956 *6 *8 (-858 *7))) (-4 *8 (-232 (-4032 *7) *4)) (-5 *4 (-769)) (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *10 (-645 *6)) (-4 *11 (-926 *6 *10)) (-5 *1 (-566 *6 *7 *5 *8 *9 *10 *11 *3)) (-4 *9 (-978 *6)) (-4 *3 (-237 *11)))) (-2390 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-5 *1 (-566 *4 *5 *6 *7 *8 *9 *10 *3)) (-4 *8 (-978 *4)) (-4 *3 (-237 *10)))) (-3765 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *7)) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) (-769))) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-5 *2 (-638 (-1259 *5))) (-5 *1 (-566 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-978 *5)) (-4 *3 (-237 *11)))) (-3668 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *7)) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) (-769))) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-5 *2 (-638 (-1259 *5))) (-5 *1 (-566 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-978 *5)) (-4 *3 (-237 *11))))) 
-(-10 -7 (-15 -3668 ((-638 (-1259 |#1|)) |#8| (-638 |#3|))) (-15 -3765 ((-638 (-1259 |#1|)) |#8| (-638 |#3|))) (-15 -2390 ((-638 |#3|) |#8| (-638 |#3|))) (-15 -3711 ((-638 |#3|) |#8| (-769) |#3| (-638 |#3|)))) 
-((-4201 (($) 9)) (-3247 (((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 29)) (-2760 (((-638 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) $) 26)) (-1335 (($ (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) 23)) (-2207 (($ (-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) 21)) (-4320 (((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 33)) (-2957 (((-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $) 31)) (-2513 (((-1264)) 12))) 
-(((-567) (-10 -8 (-15 -4201 ($)) (-15 -2513 ((-1264))) (-15 -2760 ((-638 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) $)) (-15 -2207 ($ (-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))))) (-15 -1335 ($ (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-15 -3247 ((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2957 ((-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $)) (-15 -4320 ((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) (T -567)) 
-((-4320 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-567)))) (-2957 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-567)))) (-3247 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-567)))) (-1335 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (-5 *1 (-567)))) (-2207 (*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-567)))) (-2760 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-5 *1 (-567)))) (-2513 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-567)))) (-4201 (*1 *1) (-5 *1 (-567)))) 
-(-10 -8 (-15 -4201 ($)) (-15 -2513 ((-1264))) (-15 -2760 ((-638 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) $)) (-15 -2207 ($ (-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))))) (-15 -1335 ($ (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-15 -3247 ((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2957 ((-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $)) (-15 -4320 ((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) 
-((-4297 (((-1166 (-413 (-1166 |#2|))) |#2| (-611 |#2|) (-611 |#2|) (-1166 |#2|)) 28)) (-2221 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|))) 96) (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|) |#2| (-1166 |#2|)) 106)) (-3107 (((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|))) 78) (((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) |#2| (-1166 |#2|)) 50)) (-2564 (((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2| (-611 |#2|) |#2| (-413 (-1166 |#2|))) 85) (((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2| |#2| (-1166 |#2|)) 105)) (-4370 (((-3 |#2| "failed") |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170)) (-611 |#2|) |#2| (-413 (-1166 |#2|))) 101) (((-3 |#2| "failed") |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170)) |#2| (-1166 |#2|)) 107)) (-4517 (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|))) 124 (|has| |#3| (-650 |#2|))) (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) |#2| (-1166 |#2|)) 123 (|has| |#3| (-650 |#2|)))) (-4335 ((|#2| (-1166 (-413 (-1166 |#2|))) (-611 |#2|) |#2|) 48)) (-3111 (((-1166 (-413 (-1166 |#2|))) (-1166 |#2|) (-611 |#2|)) 27))) 
-(((-568 |#1| |#2| |#3|) (-10 -7 (-15 -3107 ((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) |#2| (-1166 |#2|))) (-15 -3107 ((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|)))) (-15 -2564 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2| |#2| (-1166 |#2|))) (-15 -2564 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2| (-611 |#2|) |#2| (-413 (-1166 |#2|)))) (-15 -2221 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|) |#2| (-1166 |#2|))) (-15 -2221 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|)))) (-15 -4370 ((-3 |#2| "failed") |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170)) |#2| (-1166 |#2|))) (-15 -4370 ((-3 |#2| "failed") |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170)) (-611 |#2|) |#2| (-413 (-1166 |#2|)))) (-15 -4297 ((-1166 (-413 (-1166 |#2|))) |#2| (-611 |#2|) (-611 |#2|) (-1166 |#2|))) (-15 -4335 (|#2| (-1166 (-413 (-1166 |#2|))) (-611 |#2|) |#2|)) (-15 -3111 ((-1166 (-413 (-1166 |#2|))) (-1166 |#2|) (-611 |#2|))) (IF (|has| |#3| (-650 |#2|)) (PROGN (-15 -4517 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) |#2| (-1166 |#2|))) (-15 -4517 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|))))) |noBranch|)) (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572))) (-13 (-436 |#1|) (-27) (-1190)) (-1098)) (T -568)) 
-((-4517 (*1 *2 *3 *4 *5 *5 *5 *4 *6) (-12 (-5 *5 (-611 *4)) (-5 *6 (-413 (-1166 *4))) (-4 *4 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-568 *7 *4 *3)) (-4 *3 (-650 *4)) (-4 *3 (-1098)))) (-4517 (*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *5 (-611 *4)) (-5 *6 (-1166 *4)) (-4 *4 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-568 *7 *4 *3)) (-4 *3 (-650 *4)) (-4 *3 (-1098)))) (-3111 (*1 *2 *3 *4) (-12 (-5 *4 (-611 *6)) (-4 *6 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-1166 (-413 (-1166 *6)))) (-5 *1 (-568 *5 *6 *7)) (-5 *3 (-1166 *6)) (-4 *7 (-1098)))) (-4335 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1166 (-413 (-1166 *2)))) (-5 *4 (-611 *2)) (-4 *2 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *1 (-568 *5 *2 *6)) (-4 *6 (-1098)))) (-4297 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-611 *3)) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-1166 (-413 (-1166 *3)))) (-5 *1 (-568 *6 *3 *7)) (-5 *5 (-1166 *3)) (-4 *7 (-1098)))) (-4370 (*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| -12 (-5 *3 (-611 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1170))) (-5 *5 (-413 (-1166 *2))) (-4 *2 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *1 (-568 *6 *2 *7)) (-4 *7 (-1098)))) (-4370 (*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| -12 (-5 *3 (-611 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1170))) (-5 *5 (-1166 *2)) (-4 *2 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *1 (-568 *6 *2 *7)) (-4 *7 (-1098)))) (-2221 (*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-638 *3)) (-5 *6 (-413 (-1166 *3))) (-4 *3 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-568 *7 *3 *8)) (-4 *8 (-1098)))) (-2221 (*1 *2 *3 *4 *4 *5 *3 *6) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-638 *3)) (-5 *6 (-1166 *3)) (-4 *3 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-568 *7 *3 *8)) (-4 *8 (-1098)))) (-2564 (*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-413 (-1166 *3))) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-568 *6 *3 *7)) (-4 *7 (-1098)))) (-2564 (*1 *2 *3 *4 *4 *3 *3 *5) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-1166 *3)) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-568 *6 *3 *7)) (-4 *7 (-1098)))) (-3107 (*1 *2 *3 *4 *4 *4 *3 *5) (-12 (-5 *4 (-611 *3)) (-5 *5 (-413 (-1166 *3))) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-568 *6 *3 *7)) (-4 *7 (-1098)))) (-3107 (*1 *2 *3 *4 *4 *3 *5) (-12 (-5 *4 (-611 *3)) (-5 *5 (-1166 *3)) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-568 *6 *3 *7)) (-4 *7 (-1098))))) 
-(-10 -7 (-15 -3107 ((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) |#2| (-1166 |#2|))) (-15 -3107 ((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|)))) (-15 -2564 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2| |#2| (-1166 |#2|))) (-15 -2564 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2| (-611 |#2|) |#2| (-413 (-1166 |#2|)))) (-15 -2221 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|) |#2| (-1166 |#2|))) (-15 -2221 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|)))) (-15 -4370 ((-3 |#2| "failed") |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170)) |#2| (-1166 |#2|))) (-15 -4370 ((-3 |#2| "failed") |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170)) (-611 |#2|) |#2| (-413 (-1166 |#2|)))) (-15 -4297 ((-1166 (-413 (-1166 |#2|))) |#2| (-611 |#2|) (-611 |#2|) (-1166 |#2|))) (-15 -4335 (|#2| (-1166 (-413 (-1166 |#2|))) (-611 |#2|) |#2|)) (-15 -3111 ((-1166 (-413 (-1166 |#2|))) (-1166 |#2|) (-611 |#2|))) (IF (|has| |#3| (-650 |#2|)) (PROGN (-15 -4517 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) |#2| (-1166 |#2|))) (-15 -4517 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) (-611 |#2|) |#2| (-413 (-1166 |#2|))))) |noBranch|)) 
-((-4204 (((-572) (-572) (-769)) 65)) (-3958 (((-572) (-572)) 64)) (-1430 (((-572) (-572)) 63)) (-4417 (((-572) (-572)) 68)) (-1943 (((-572) (-572) (-572)) 48)) (-3947 (((-572) (-572) (-572)) 45)) (-2873 (((-413 (-572)) (-572)) 20)) (-3871 (((-572) (-572)) 21)) (-3854 (((-572) (-572)) 57)) (-3730 (((-572) (-572)) 32)) (-1766 (((-638 (-572)) (-572)) 62)) (-4399 (((-572) (-572) (-572) (-572) (-572)) 43)) (-2038 (((-413 (-572)) (-572)) 41))) 
-(((-569) (-10 -7 (-15 -2038 ((-413 (-572)) (-572))) (-15 -4399 ((-572) (-572) (-572) (-572) (-572))) (-15 -1766 ((-638 (-572)) (-572))) (-15 -3730 ((-572) (-572))) (-15 -3854 ((-572) (-572))) (-15 -3871 ((-572) (-572))) (-15 -2873 ((-413 (-572)) (-572))) (-15 -3947 ((-572) (-572) (-572))) (-15 -1943 ((-572) (-572) (-572))) (-15 -4417 ((-572) (-572))) (-15 -1430 ((-572) (-572))) (-15 -3958 ((-572) (-572))) (-15 -4204 ((-572) (-572) (-769))))) (T -569)) 
-((-4204 (*1 *2 *2 *3) (-12 (-5 *2 (-572)) (-5 *3 (-769)) (-5 *1 (-569)))) (-3958 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-1430 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-4417 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-1943 (*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-3947 (*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-2873 (*1 *2 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-569)) (-5 *3 (-572)))) (-3871 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-3854 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-3730 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-1766 (*1 *2 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-569)) (-5 *3 (-572)))) (-4399 (*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) (-2038 (*1 *2 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-569)) (-5 *3 (-572))))) 
-(-10 -7 (-15 -2038 ((-413 (-572)) (-572))) (-15 -4399 ((-572) (-572) (-572) (-572) (-572))) (-15 -1766 ((-638 (-572)) (-572))) (-15 -3730 ((-572) (-572))) (-15 -3854 ((-572) (-572))) (-15 -3871 ((-572) (-572))) (-15 -2873 ((-413 (-572)) (-572))) (-15 -3947 ((-572) (-572) (-572))) (-15 -1943 ((-572) (-572) (-572))) (-15 -4417 ((-572) (-572))) (-15 -1430 ((-572) (-572))) (-15 -3958 ((-572) (-572))) (-15 -4204 ((-572) (-572) (-769)))) 
-((-4069 (((-2 (|:| |answer| |#4|) (|:| -4223 |#4|)) |#4| (-1 |#2| |#2|)) 52))) 
-(((-570 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4069 ((-2 (|:| |answer| |#4|) (|:| -4223 |#4|)) |#4| (-1 |#2| |#2|)))) (-368) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|)) (T -570)) 
-((-4069 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-4 *7 (-1234 (-413 *6))) (-5 *2 (-2 (|:| |answer| *3) (|:| -4223 *3))) (-5 *1 (-570 *5 *6 *7 *3)) (-4 *3 (-342 *5 *6 *7))))) 
-(-10 -7 (-15 -4069 ((-2 (|:| |answer| |#4|) (|:| -4223 |#4|)) |#4| (-1 |#2| |#2|)))) 
-((-4069 (((-2 (|:| |answer| (-413 |#2|)) (|:| -4223 (-413 |#2|)) (|:| |specpart| (-413 |#2|)) (|:| |polypart| |#2|)) (-413 |#2|) (-1 |#2| |#2|)) 18))) 
-(((-571 |#1| |#2|) (-10 -7 (-15 -4069 ((-2 (|:| |answer| (-413 |#2|)) (|:| -4223 (-413 |#2|)) (|:| |specpart| (-413 |#2|)) (|:| |polypart| |#2|)) (-413 |#2|) (-1 |#2| |#2|)))) (-368) (-1234 |#1|)) (T -571)) 
-((-4069 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |answer| (-413 *6)) (|:| -4223 (-413 *6)) (|:| |specpart| (-413 *6)) (|:| |polypart| *6))) (-5 *1 (-571 *5 *6)) (-5 *3 (-413 *6))))) 
-(-10 -7 (-15 -4069 ((-2 (|:| |answer| (-413 |#2|)) (|:| -4223 (-413 |#2|)) (|:| |specpart| (-413 |#2|)) (|:| |polypart| |#2|)) (-413 |#2|) (-1 |#2| |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 25)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 86)) (-3946 (($ $) 87)) (-3686 (((-121) $) NIL)) (-1481 (($ $ $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2934 (($ $ $ $) 42)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL)) (-3351 (($ $ $) 80)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL)) (-1318 (((-572) $) NIL)) (-2190 (($ $ $) 79)) (-2284 (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 60) (((-685 (-572)) (-685 $)) 57)) (-1799 (((-3 $ "failed") $) 83)) (-2956 (((-3 (-413 (-572)) "failed") $) NIL)) (-3175 (((-121) $) NIL)) (-4299 (((-413 (-572)) $) NIL)) (-3286 (($) 62) (($ $) 63)) (-2208 (($ $ $) 78)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1968 (($ $ $ $) NIL)) (-4489 (($ $ $) 54)) (-1908 (((-121) $) NIL)) (-2133 (($ $ $) NIL)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL)) (-3893 (((-121) $) 26)) (-4240 (((-121) $) 73)) (-3961 (((-3 $ "failed") $) NIL)) (-4472 (((-121) $) 34)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1628 (($ $ $ $) 43)) (-1771 (($ $ $) 75)) (-4238 (($ $ $) 74)) (-1582 (($ $) NIL)) (-3200 (($ $) 40)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) 53)) (-2144 (($ $ $) NIL)) (-1773 (($) NIL T CONST)) (-3088 (($ $) 31)) (-2607 (((-1116) $) NIL) (($ $) 33)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 117)) (-3069 (($ $ $) 84) (($ (-638 $)) NIL)) (-2900 (($ $) NIL)) (-4304 (((-424 $) $) 103)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL)) (-1803 (((-3 $ "failed") $ $) 82)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4247 (((-121) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 77)) (-3139 (($ $ (-769)) NIL) (($ $) NIL)) (-4340 (($ $) 32)) (-1607 (($ $) 30)) (-4081 (((-572) $) 39) (((-545) $) 51) (((-893 (-572)) $) NIL) (((-385) $) 46) (((-217) $) 48) (((-1152) $) 52)) (-3972 (((-856) $) 37) (($ (-572)) 38) (($ $) NIL) (($ (-572)) 38)) (-2140 (((-769)) NIL)) (-1348 (((-121) $ $) NIL)) (-3610 (($ $ $) NIL)) (-4393 (($) 29)) (-3774 (((-121) $ $) NIL)) (-1498 (($ $ $ $) 41)) (-2264 (($ $) 61)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 27 T CONST)) (-3255 (($) 28 T CONST)) (-3594 (((-1152) $) 20) (((-1152) $ (-121)) 22) (((-1264) (-823) $) 23) (((-1264) (-823) $ (-121)) 24)) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 64)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 65)) (-1373 (($ $) 66) (($ $ $) 68)) (-1367 (($ $ $) 67)) (** (($ $ (-923)) NIL) (($ $ (-769)) 72)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 70) (($ $ $) 69))) 
-(((-572) (-13 (-554) (-613 (-1152)) (-829) (-10 -8 (-15 -3286 ($ $)) (-6 -4589) (-6 -4594) (-6 -4590) (-6 -4584)))) (T -572)) 
-((-3286 (*1 *1 *1) (-5 *1 (-572)))) 
-(-13 (-554) (-613 (-1152)) (-829) (-10 -8 (-15 -3286 ($ $)) (-6 -4589) (-6 -4594) (-6 -4590) (-6 -4584))) 
-((-1540 (((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042))) (-767) (-1066)) 103) (((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042))) (-767)) 105)) (-2774 (((-3 (-1042) "failed") (-312 (-385)) (-1090 (-841 (-385))) (-1170)) 168) (((-3 (-1042) "failed") (-312 (-385)) (-1090 (-841 (-385))) (-1152)) 167) (((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385) (-385) (-1066)) 173) (((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385) (-385)) 174) (((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385)) 175) (((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385))))) 176) (((-1042) (-312 (-385)) (-1092 (-841 (-385)))) 163) (((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385)) 162) (((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385) (-385)) 158) (((-1042) (-767)) 150) (((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385) (-385) (-1066)) 157))) 
-(((-573) (-10 -7 (-15 -2774 ((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385) (-385) (-1066))) (-15 -2774 ((-1042) (-767))) (-15 -2774 ((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385) (-385))) (-15 -2774 ((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385))) (-15 -2774 ((-1042) (-312 (-385)) (-1092 (-841 (-385))))) (-15 -2774 ((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))))) (-15 -2774 ((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385))) (-15 -2774 ((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385) (-385))) (-15 -2774 ((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385) (-385) (-1066))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042))) (-767))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042))) (-767) (-1066))) (-15 -2774 ((-3 (-1042) "failed") (-312 (-385)) (-1090 (-841 (-385))) (-1152))) (-15 -2774 ((-3 (-1042) "failed") (-312 (-385)) (-1090 (-841 (-385))) (-1170))))) (T -573)) 
-((-2774 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-841 (-385)))) (-5 *5 (-1170)) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-841 (-385)))) (-5 *5 (-1152)) (-5 *2 (-1042)) (-5 *1 (-573)))) (-1540 (*1 *2 *3 *4) (-12 (-5 *3 (-767)) (-5 *4 (-1066)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042)))) (-5 *1 (-573)))) (-1540 (*1 *2 *3) (-12 (-5 *3 (-767)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042)))) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-1092 (-841 (-385))))) (-5 *5 (-385)) (-5 *6 (-1066)) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-1092 (-841 (-385))))) (-5 *5 (-385)) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-1092 (-841 (-385))))) (-5 *5 (-385)) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-1092 (-841 (-385))))) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1092 (-841 (-385)))) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1092 (-841 (-385)))) (-5 *5 (-385)) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1092 (-841 (-385)))) (-5 *5 (-385)) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3) (-12 (-5 *3 (-767)) (-5 *2 (-1042)) (-5 *1 (-573)))) (-2774 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1092 (-841 (-385)))) (-5 *5 (-385)) (-5 *6 (-1066)) (-5 *2 (-1042)) (-5 *1 (-573))))) 
-(-10 -7 (-15 -2774 ((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385) (-385) (-1066))) (-15 -2774 ((-1042) (-767))) (-15 -2774 ((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385) (-385))) (-15 -2774 ((-1042) (-312 (-385)) (-1092 (-841 (-385))) (-385))) (-15 -2774 ((-1042) (-312 (-385)) (-1092 (-841 (-385))))) (-15 -2774 ((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))))) (-15 -2774 ((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385))) (-15 -2774 ((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385) (-385))) (-15 -2774 ((-1042) (-312 (-385)) (-638 (-1092 (-841 (-385)))) (-385) (-385) (-1066))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042))) (-767))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042))) (-767) (-1066))) (-15 -2774 ((-3 (-1042) "failed") (-312 (-385)) (-1090 (-841 (-385))) (-1152))) (-15 -2774 ((-3 (-1042) "failed") (-312 (-385)) (-1090 (-841 (-385))) (-1170)))) 
-((-3743 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|)) 179)) (-4022 (((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|)) 97)) (-2783 (((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2|) 175)) (-2554 (((-3 |#2| "failed") |#2| |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170))) 184)) (-3698 (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) (-1170)) 192 (|has| |#3| (-650 |#2|))))) 
-(((-574 |#1| |#2| |#3|) (-10 -7 (-15 -4022 ((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|))) (-15 -2783 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2|)) (-15 -3743 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|))) (-15 -2554 ((-3 |#2| "failed") |#2| |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170)))) (IF (|has| |#3| (-650 |#2|)) (-15 -3698 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) (-1170))) |noBranch|)) (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572))) (-13 (-436 |#1|) (-27) (-1190)) (-1098)) (T -574)) 
-((-3698 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *5 (-611 *4)) (-5 *6 (-1170)) (-4 *4 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-574 *7 *4 *3)) (-4 *3 (-650 *4)) (-4 *3 (-1098)))) (-2554 (*1 *2 *2 *2 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-611 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1170))) (-4 *2 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *1 (-574 *5 *2 *6)) (-4 *6 (-1098)))) (-3743 (*1 *2 *3 *4 *4 *5) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-638 *3)) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-574 *6 *3 *7)) (-4 *7 (-1098)))) (-2783 (*1 *2 *3 *4 *4 *3) (|partial| -12 (-5 *4 (-611 *3)) (-4 *3 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-574 *5 *3 *6)) (-4 *6 (-1098)))) (-4022 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-611 *3)) (-4 *3 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-574 *5 *3 *6)) (-4 *6 (-1098))))) 
-(-10 -7 (-15 -4022 ((-589 |#2|) |#2| (-611 |#2|) (-611 |#2|))) (-15 -2783 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-611 |#2|) (-611 |#2|) |#2|)) (-15 -3743 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-611 |#2|) (-611 |#2|) (-638 |#2|))) (-15 -2554 ((-3 |#2| "failed") |#2| |#2| |#2| (-611 |#2|) (-611 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1170)))) (IF (|has| |#3| (-650 |#2|)) (-15 -3698 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2237 (-638 |#2|))) |#3| |#2| (-611 |#2|) (-611 |#2|) (-1170))) |noBranch|)) 
-((-4207 (((-2 (|:| -3631 |#2|) (|:| |nconst| |#2|)) |#2| (-1170)) 62)) (-3775 (((-3 |#2| "failed") |#2| (-1170) (-841 |#2|) (-841 |#2|)) 159 (-12 (|has| |#2| (-1132)) (|has| |#1| (-613 (-893 (-572)))) (|has| |#1| (-887 (-572))))) (((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170)) 133 (-12 (|has| |#2| (-624)) (|has| |#1| (-613 (-893 (-572)))) (|has| |#1| (-887 (-572)))))) (-2555 (((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170)) 142 (-12 (|has| |#2| (-624)) (|has| |#1| (-613 (-893 (-572)))) (|has| |#1| (-887 (-572))))))) 
-(((-575 |#1| |#2|) (-10 -7 (-15 -4207 ((-2 (|:| -3631 |#2|) (|:| |nconst| |#2|)) |#2| (-1170))) (IF (|has| |#1| (-613 (-893 (-572)))) (IF (|has| |#1| (-887 (-572))) (PROGN (IF (|has| |#2| (-624)) (PROGN (-15 -2555 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170))) (-15 -3775 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170)))) |noBranch|) (IF (|has| |#2| (-1132)) (-15 -3775 ((-3 |#2| "failed") |#2| (-1170) (-841 |#2|) (-841 |#2|))) |noBranch|)) |noBranch|) |noBranch|)) (-13 (-848) (-1044 (-572)) (-457) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|))) (T -575)) 
-((-3775 (*1 *2 *2 *3 *4 *4) (|partial| -12 (-5 *3 (-1170)) (-5 *4 (-841 *2)) (-4 *2 (-1132)) (-4 *2 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-613 (-893 (-572)))) (-4 *5 (-887 (-572))) (-4 *5 (-13 (-848) (-1044 (-572)) (-457) (-634 (-572)))) (-5 *1 (-575 *5 *2)))) (-3775 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1170)) (-4 *5 (-613 (-893 (-572)))) (-4 *5 (-887 (-572))) (-4 *5 (-13 (-848) (-1044 (-572)) (-457) (-634 (-572)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-575 *5 *3)) (-4 *3 (-624)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-2555 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1170)) (-4 *5 (-613 (-893 (-572)))) (-4 *5 (-887 (-572))) (-4 *5 (-13 (-848) (-1044 (-572)) (-457) (-634 (-572)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-575 *5 *3)) (-4 *3 (-624)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-4207 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-1044 (-572)) (-457) (-634 (-572)))) (-5 *2 (-2 (|:| -3631 *3) (|:| |nconst| *3))) (-5 *1 (-575 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5)))))) 
-(-10 -7 (-15 -4207 ((-2 (|:| -3631 |#2|) (|:| |nconst| |#2|)) |#2| (-1170))) (IF (|has| |#1| (-613 (-893 (-572)))) (IF (|has| |#1| (-887 (-572))) (PROGN (IF (|has| |#2| (-624)) (PROGN (-15 -2555 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170))) (-15 -3775 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170)))) |noBranch|) (IF (|has| |#2| (-1132)) (-15 -3775 ((-3 |#2| "failed") |#2| (-1170) (-841 |#2|) (-841 |#2|))) |noBranch|)) |noBranch|) |noBranch|)) 
-((-3498 (((-3 (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|)))))) "failed") (-413 |#2|) (-638 (-413 |#2|))) 39)) (-2774 (((-589 (-413 |#2|)) (-413 |#2|)) 27)) (-2519 (((-3 (-413 |#2|) "failed") (-413 |#2|)) 16)) (-4206 (((-3 (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-413 |#2|)) 46))) 
-(((-576 |#1| |#2|) (-10 -7 (-15 -2774 ((-589 (-413 |#2|)) (-413 |#2|))) (-15 -2519 ((-3 (-413 |#2|) "failed") (-413 |#2|))) (-15 -4206 ((-3 (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-413 |#2|))) (-15 -3498 ((-3 (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|)))))) "failed") (-413 |#2|) (-638 (-413 |#2|))))) (-13 (-368) (-151) (-1044 (-572))) (-1234 |#1|)) (T -576)) 
-((-3498 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-638 (-413 *6))) (-5 *3 (-413 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-576 *5 *6)))) (-4206 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-13 (-368) (-151) (-1044 (-572)))) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -3444 (-413 *5)) (|:| |coeff| (-413 *5)))) (-5 *1 (-576 *4 *5)) (-5 *3 (-413 *5)))) (-2519 (*1 *2 *2) (|partial| -12 (-5 *2 (-413 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-13 (-368) (-151) (-1044 (-572)))) (-5 *1 (-576 *3 *4)))) (-2774 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-572)))) (-4 *5 (-1234 *4)) (-5 *2 (-589 (-413 *5))) (-5 *1 (-576 *4 *5)) (-5 *3 (-413 *5))))) 
-(-10 -7 (-15 -2774 ((-589 (-413 |#2|)) (-413 |#2|))) (-15 -2519 ((-3 (-413 |#2|) "failed") (-413 |#2|))) (-15 -4206 ((-3 (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-413 |#2|))) (-15 -3498 ((-3 (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|)))))) "failed") (-413 |#2|) (-638 (-413 |#2|))))) 
-((-1448 (((-3 (-572) "failed") |#1|) 14)) (-2814 (((-121) |#1|) 13)) (-4012 (((-572) |#1|) 9))) 
-(((-577 |#1|) (-10 -7 (-15 -4012 ((-572) |#1|)) (-15 -2814 ((-121) |#1|)) (-15 -1448 ((-3 (-572) "failed") |#1|))) (-1044 (-572))) (T -577)) 
-((-1448 (*1 *2 *3) (|partial| -12 (-5 *2 (-572)) (-5 *1 (-577 *3)) (-4 *3 (-1044 *2)))) (-2814 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-577 *3)) (-4 *3 (-1044 (-572))))) (-4012 (*1 *2 *3) (-12 (-5 *2 (-572)) (-5 *1 (-577 *3)) (-4 *3 (-1044 *2))))) 
-(-10 -7 (-15 -4012 ((-572) |#1|)) (-15 -2814 ((-121) |#1|)) (-15 -1448 ((-3 (-572) "failed") |#1|))) 
-((-1675 (((-3 (-2 (|:| |mainpart| (-413 (-959 |#1|))) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 (-959 |#1|))) (|:| |logand| (-413 (-959 |#1|))))))) "failed") (-413 (-959 |#1|)) (-1170) (-638 (-413 (-959 |#1|)))) 43)) (-3280 (((-589 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-1170)) 25)) (-3951 (((-3 (-413 (-959 |#1|)) "failed") (-413 (-959 |#1|)) (-1170)) 20)) (-4480 (((-3 (-2 (|:| -3444 (-413 (-959 |#1|))) (|:| |coeff| (-413 (-959 |#1|)))) "failed") (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|))) 32))) 
-(((-578 |#1|) (-10 -7 (-15 -3280 ((-589 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-1170))) (-15 -3951 ((-3 (-413 (-959 |#1|)) "failed") (-413 (-959 |#1|)) (-1170))) (-15 -1675 ((-3 (-2 (|:| |mainpart| (-413 (-959 |#1|))) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 (-959 |#1|))) (|:| |logand| (-413 (-959 |#1|))))))) "failed") (-413 (-959 |#1|)) (-1170) (-638 (-413 (-959 |#1|))))) (-15 -4480 ((-3 (-2 (|:| -3444 (-413 (-959 |#1|))) (|:| |coeff| (-413 (-959 |#1|)))) "failed") (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|))))) (-13 (-562) (-1044 (-572)) (-151))) (T -578)) 
-((-4480 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-1044 (-572)) (-151))) (-5 *2 (-2 (|:| -3444 (-413 (-959 *5))) (|:| |coeff| (-413 (-959 *5))))) (-5 *1 (-578 *5)) (-5 *3 (-413 (-959 *5))))) (-1675 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-638 (-413 (-959 *6)))) (-5 *3 (-413 (-959 *6))) (-4 *6 (-13 (-562) (-1044 (-572)) (-151))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-578 *6)))) (-3951 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-413 (-959 *4))) (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-1044 (-572)) (-151))) (-5 *1 (-578 *4)))) (-3280 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-1044 (-572)) (-151))) (-5 *2 (-589 (-413 (-959 *5)))) (-5 *1 (-578 *5)) (-5 *3 (-413 (-959 *5)))))) 
-(-10 -7 (-15 -3280 ((-589 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-1170))) (-15 -3951 ((-3 (-413 (-959 |#1|)) "failed") (-413 (-959 |#1|)) (-1170))) (-15 -1675 ((-3 (-2 (|:| |mainpart| (-413 (-959 |#1|))) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 (-959 |#1|))) (|:| |logand| (-413 (-959 |#1|))))))) "failed") (-413 (-959 |#1|)) (-1170) (-638 (-413 (-959 |#1|))))) (-15 -4480 ((-3 (-2 (|:| -3444 (-413 (-959 |#1|))) (|:| |coeff| (-413 (-959 |#1|)))) "failed") (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|))))) 
-((-2262 (((-121) $ $) 59)) (-1342 (((-121) $) 36)) (-3632 ((|#1| $) 30)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) 63)) (-4284 (($ $) 123)) (-4224 (($ $) 103)) (-1614 ((|#1| $) 28)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $) NIL)) (-4273 (($ $) 125)) (-4217 (($ $) 99)) (-4295 (($ $) 127)) (-4233 (($ $) 107)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) 78)) (-1318 (((-572) $) 80)) (-1799 (((-3 $ "failed") $) 62)) (-3963 (($ |#1| |#1|) 26)) (-1908 (((-121) $) 33)) (-4184 (($) 89)) (-3893 (((-121) $) 43)) (-1451 (($ $ (-572)) NIL)) (-4472 (((-121) $) 34)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3539 (($ $) 91)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-2121 (($ |#1| |#1|) 20) (($ |#1|) 25) (($ (-413 (-572))) 77)) (-2685 ((|#1| $) 27)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) 65) (($ (-638 $)) NIL)) (-1803 (((-3 $ "failed") $ $) 64)) (-4179 (($ $) 93)) (-4302 (($ $) 131)) (-4237 (($ $) 105)) (-4289 (($ $) 133)) (-4228 (($ $) 109)) (-4278 (($ $) 129)) (-4220 (($ $) 101)) (-3470 (((-121) $ |#1|) 31)) (-3972 (((-856) $) 85) (($ (-572)) 67) (($ $) NIL) (($ (-572)) 67)) (-2140 (((-769)) 87)) (-4321 (($ $) 145)) (-4251 (($ $) 115)) (-3774 (((-121) $ $) NIL)) (-4308 (($ $) 143)) (-4241 (($ $) 111)) (-4333 (($ $) 141)) (-4263 (($ $) 121)) (-2104 (($ $) 139)) (-4268 (($ $) 119)) (-4327 (($ $) 137)) (-4257 (($ $) 117)) (-4314 (($ $) 135)) (-4246 (($ $) 113)) (-4174 (($ $ (-923)) 55) (($ $ (-769)) NIL)) (-2378 (($) 21 T CONST)) (-3255 (($) 10 T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 37)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 35)) (-1373 (($ $) 41) (($ $ $) 42)) (-1367 (($ $ $) 40)) (** (($ $ (-923)) 54) (($ $ (-769)) NIL) (($ $ $) 95) (($ $ (-413 (-572))) 147)) (* (($ (-923) $) 51) (($ (-769) $) NIL) (($ (-572) $) 50) (($ $ $) 48))) 
-(((-579 |#1|) (-559 |#1|) (-13 (-410) (-1190))) (T -579)) 
-NIL 
-(-559 |#1|) 
-((-2462 (((-3 (-638 (-1166 (-572))) "failed") (-638 (-1166 (-572))) (-1166 (-572))) 24))) 
-(((-580) (-10 -7 (-15 -2462 ((-3 (-638 (-1166 (-572))) "failed") (-638 (-1166 (-572))) (-1166 (-572)))))) (T -580)) 
-((-2462 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 (-572)))) (-5 *3 (-1166 (-572))) (-5 *1 (-580))))) 
-(-10 -7 (-15 -2462 ((-3 (-638 (-1166 (-572))) "failed") (-638 (-1166 (-572))) (-1166 (-572))))) 
-((-3931 (((-638 (-611 |#2|)) (-638 (-611 |#2|)) (-1170)) 18)) (-1360 (((-638 (-611 |#2|)) (-638 |#2|) (-1170)) 23)) (-3518 (((-638 (-611 |#2|)) (-638 (-611 |#2|)) (-638 (-611 |#2|))) 10)) (-3494 ((|#2| |#2| (-1170)) 51 (|has| |#1| (-562)))) (-4231 ((|#2| |#2| (-1170)) 76 (-12 (|has| |#2| (-281)) (|has| |#1| (-457))))) (-3079 (((-611 |#2|) (-611 |#2|) (-638 (-611 |#2|)) (-1170)) 25)) (-2304 (((-611 |#2|) (-638 (-611 |#2|))) 24)) (-3310 (((-589 |#2|) |#2| (-1170) (-1 (-589 |#2|) |#2| (-1170)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170))) 100 (-12 (|has| |#2| (-281)) (|has| |#2| (-624)) (|has| |#2| (-1044 (-1170))) (|has| |#1| (-613 (-893 (-572)))) (|has| |#1| (-457)) (|has| |#1| (-887 (-572))))))) 
-(((-581 |#1| |#2|) (-10 -7 (-15 -3931 ((-638 (-611 |#2|)) (-638 (-611 |#2|)) (-1170))) (-15 -2304 ((-611 |#2|) (-638 (-611 |#2|)))) (-15 -3079 ((-611 |#2|) (-611 |#2|) (-638 (-611 |#2|)) (-1170))) (-15 -3518 ((-638 (-611 |#2|)) (-638 (-611 |#2|)) (-638 (-611 |#2|)))) (-15 -1360 ((-638 (-611 |#2|)) (-638 |#2|) (-1170))) (IF (|has| |#1| (-562)) (-15 -3494 (|#2| |#2| (-1170))) |noBranch|) (IF (|has| |#1| (-457)) (IF (|has| |#2| (-281)) (PROGN (-15 -4231 (|#2| |#2| (-1170))) (IF (|has| |#1| (-613 (-893 (-572)))) (IF (|has| |#1| (-887 (-572))) (IF (|has| |#2| (-624)) (IF (|has| |#2| (-1044 (-1170))) (-15 -3310 ((-589 |#2|) |#2| (-1170) (-1 (-589 |#2|) |#2| (-1170)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) |noBranch|) |noBranch|)) (-848) (-436 |#1|)) (T -581)) 
-((-3310 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-1 (-589 *3) *3 (-1170))) (-5 *6 (-1 (-3 (-2 (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (-1170))) (-4 *3 (-281)) (-4 *3 (-624)) (-4 *3 (-1044 *4)) (-4 *3 (-436 *7)) (-5 *4 (-1170)) (-4 *7 (-613 (-893 (-572)))) (-4 *7 (-457)) (-4 *7 (-887 (-572))) (-4 *7 (-848)) (-5 *2 (-589 *3)) (-5 *1 (-581 *7 *3)))) (-4231 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-457)) (-4 *4 (-848)) (-5 *1 (-581 *4 *2)) (-4 *2 (-281)) (-4 *2 (-436 *4)))) (-3494 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-562)) (-4 *4 (-848)) (-5 *1 (-581 *4 *2)) (-4 *2 (-436 *4)))) (-1360 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-1170)) (-4 *6 (-436 *5)) (-4 *5 (-848)) (-5 *2 (-638 (-611 *6))) (-5 *1 (-581 *5 *6)))) (-3518 (*1 *2 *2 *2) (-12 (-5 *2 (-638 (-611 *4))) (-4 *4 (-436 *3)) (-4 *3 (-848)) (-5 *1 (-581 *3 *4)))) (-3079 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-638 (-611 *6))) (-5 *4 (-1170)) (-5 *2 (-611 *6)) (-4 *6 (-436 *5)) (-4 *5 (-848)) (-5 *1 (-581 *5 *6)))) (-2304 (*1 *2 *3) (-12 (-5 *3 (-638 (-611 *5))) (-4 *4 (-848)) (-5 *2 (-611 *5)) (-5 *1 (-581 *4 *5)) (-4 *5 (-436 *4)))) (-3931 (*1 *2 *2 *3) (-12 (-5 *2 (-638 (-611 *5))) (-5 *3 (-1170)) (-4 *5 (-436 *4)) (-4 *4 (-848)) (-5 *1 (-581 *4 *5))))) 
-(-10 -7 (-15 -3931 ((-638 (-611 |#2|)) (-638 (-611 |#2|)) (-1170))) (-15 -2304 ((-611 |#2|) (-638 (-611 |#2|)))) (-15 -3079 ((-611 |#2|) (-611 |#2|) (-638 (-611 |#2|)) (-1170))) (-15 -3518 ((-638 (-611 |#2|)) (-638 (-611 |#2|)) (-638 (-611 |#2|)))) (-15 -1360 ((-638 (-611 |#2|)) (-638 |#2|) (-1170))) (IF (|has| |#1| (-562)) (-15 -3494 (|#2| |#2| (-1170))) |noBranch|) (IF (|has| |#1| (-457)) (IF (|has| |#2| (-281)) (PROGN (-15 -4231 (|#2| |#2| (-1170))) (IF (|has| |#1| (-613 (-893 (-572)))) (IF (|has| |#1| (-887 (-572))) (IF (|has| |#2| (-624)) (IF (|has| |#2| (-1044 (-1170))) (-15 -3310 ((-589 |#2|) |#2| (-1170) (-1 (-589 |#2|) |#2| (-1170)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1170)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) |noBranch|) |noBranch|)) 
-((-3996 (((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-638 |#1|) "failed") (-572) |#1| |#1|)) 167)) (-3813 (((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|))))))) (|:| |a0| |#1|)) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-638 (-413 |#2|))) 143)) (-1426 (((-3 (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|)))))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-638 (-413 |#2|))) 140)) (-4458 (((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|) 129)) (-1404 (((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|)) 153)) (-4301 (((-3 (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-413 |#2|)) 170)) (-3714 (((-3 (-2 (|:| |answer| (-413 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-413 |#2|)) 173)) (-3446 (((-2 (|:| |ir| (-589 (-413 |#2|))) (|:| |specpart| (-413 |#2|)) (|:| |polypart| |#2|)) (-413 |#2|) (-1 |#2| |#2|)) 81)) (-4504 (((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)) 88)) (-3100 (((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|))))))) (|:| |a0| |#1|)) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|) (-638 (-413 |#2|))) 147)) (-4185 (((-3 (-619 |#1| |#2|) "failed") (-619 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|)) 133)) (-4306 (((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|)) 157)) (-3663 (((-3 (-2 (|:| |answer| (-413 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|) (-413 |#2|)) 178))) 
-(((-582 |#1| |#2|) (-10 -7 (-15 -1404 ((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|))) (-15 -4306 ((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|))) (-15 -3996 ((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-638 |#1|) "failed") (-572) |#1| |#1|))) (-15 -3714 ((-3 (-2 (|:| |answer| (-413 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-413 |#2|))) (-15 -3663 ((-3 (-2 (|:| |answer| (-413 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|) (-413 |#2|))) (-15 -3813 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|))))))) (|:| |a0| |#1|)) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-638 (-413 |#2|)))) (-15 -3100 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|))))))) (|:| |a0| |#1|)) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|) (-638 (-413 |#2|)))) (-15 -4301 ((-3 (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-413 |#2|))) (-15 -1426 ((-3 (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|)))))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-638 (-413 |#2|)))) (-15 -4458 ((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|)) (-15 -4185 ((-3 (-619 |#1| |#2|) "failed") (-619 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|))) (-15 -3446 ((-2 (|:| |ir| (-589 (-413 |#2|))) (|:| |specpart| (-413 |#2|)) (|:| |polypart| |#2|)) (-413 |#2|) (-1 |#2| |#2|))) (-15 -4504 ((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)))) (-368) (-1234 |#1|)) (T -582)) 
-((-4504 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |answer| *3) (|:| |polypart| *3))) (-5 *1 (-582 *5 *3)))) (-3446 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |ir| (-589 (-413 *6))) (|:| |specpart| (-413 *6)) (|:| |polypart| *6))) (-5 *1 (-582 *5 *6)) (-5 *3 (-413 *6)))) (-4185 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-619 *4 *5)) (-5 *3 (-1 (-2 (|:| |ans| *4) (|:| -1862 *4) (|:| |sol?| (-121))) (-572) *4)) (-4 *4 (-368)) (-4 *5 (-1234 *4)) (-5 *1 (-582 *4 *5)))) (-4458 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 (-2 (|:| -3444 *4) (|:| |coeff| *4)) "failed") *4)) (-4 *4 (-368)) (-5 *1 (-582 *4 *2)) (-4 *2 (-1234 *4)))) (-1426 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 *7 *7)) (-5 *5 (-638 (-413 *7))) (-4 *7 (-1234 *6)) (-5 *3 (-413 *7)) (-4 *6 (-368)) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-582 *6 *7)))) (-4301 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| -3444 (-413 *6)) (|:| |coeff| (-413 *6)))) (-5 *1 (-582 *5 *6)) (-5 *3 (-413 *6)))) (-3100 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-2 (|:| |ans| *7) (|:| -1862 *7) (|:| |sol?| (-121))) (-572) *7)) (-5 *6 (-638 (-413 *8))) (-4 *7 (-368)) (-4 *8 (-1234 *7)) (-5 *3 (-413 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-582 *7 *8)))) (-3813 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-3 (-2 (|:| -3444 *7) (|:| |coeff| *7)) "failed") *7)) (-5 *6 (-638 (-413 *8))) (-4 *7 (-368)) (-4 *8 (-1234 *7)) (-5 *3 (-413 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-582 *7 *8)))) (-3663 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -1862 *6) (|:| |sol?| (-121))) (-572) *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-413 *7)) (|:| |a0| *6)) (-2 (|:| -3444 (-413 *7)) (|:| |coeff| (-413 *7))) "failed")) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7)))) (-3714 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -3444 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-413 *7)) (|:| |a0| *6)) (-2 (|:| -3444 (-413 *7)) (|:| |coeff| (-413 *7))) "failed")) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7)))) (-3996 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-638 *6) "failed") (-572) *6 *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-2 (|:| |answer| (-589 (-413 *7))) (|:| |a0| *6))) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7)))) (-4306 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -1862 *6) (|:| |sol?| (-121))) (-572) *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-2 (|:| |answer| (-589 (-413 *7))) (|:| |a0| *6))) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7)))) (-1404 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -3444 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-2 (|:| |answer| (-589 (-413 *7))) (|:| |a0| *6))) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7))))) 
-(-10 -7 (-15 -1404 ((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|))) (-15 -4306 ((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|))) (-15 -3996 ((-2 (|:| |answer| (-589 (-413 |#2|))) (|:| |a0| |#1|)) (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-638 |#1|) "failed") (-572) |#1| |#1|))) (-15 -3714 ((-3 (-2 (|:| |answer| (-413 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-413 |#2|))) (-15 -3663 ((-3 (-2 (|:| |answer| (-413 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|) (-413 |#2|))) (-15 -3813 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|))))))) (|:| |a0| |#1|)) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-638 (-413 |#2|)))) (-15 -3100 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|))))))) (|:| |a0| |#1|)) "failed") (-413 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|) (-638 (-413 |#2|)))) (-15 -4301 ((-3 (-2 (|:| -3444 (-413 |#2|)) (|:| |coeff| (-413 |#2|))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-413 |#2|))) (-15 -1426 ((-3 (-2 (|:| |mainpart| (-413 |#2|)) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| (-413 |#2|)) (|:| |logand| (-413 |#2|)))))) "failed") (-413 |#2|) (-1 |#2| |#2|) (-638 (-413 |#2|)))) (-15 -4458 ((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|)) (-15 -4185 ((-3 (-619 |#1| |#2|) "failed") (-619 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1862 |#1|) (|:| |sol?| (-121))) (-572) |#1|))) (-15 -3446 ((-2 (|:| |ir| (-589 (-413 |#2|))) (|:| |specpart| (-413 |#2|)) (|:| |polypart| |#2|)) (-413 |#2|) (-1 |#2| |#2|))) (-15 -4504 ((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)))) 
-((-2188 (((-3 |#2| "failed") |#2| (-1170) (-1170)) 10))) 
-(((-583 |#1| |#2|) (-10 -7 (-15 -2188 ((-3 |#2| "failed") |#2| (-1170) (-1170)))) (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572))) (-13 (-1190) (-966) (-1132) (-29 |#1|))) (T -583)) 
-((-2188 (*1 *2 *2 *3 *3) (|partial| -12 (-5 *3 (-1170)) (-4 *4 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-583 *4 *2)) (-4 *2 (-13 (-1190) (-966) (-1132) (-29 *4)))))) 
-(-10 -7 (-15 -2188 ((-3 |#2| "failed") |#2| (-1170) (-1170)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $ (-572)) 65)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-1431 (($ (-1166 (-572)) (-572)) 71)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) 57)) (-4070 (($ $) 33)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-3377 (((-769) $) 15)) (-3893 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3195 (((-572)) 27)) (-2671 (((-572) $) 31)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1977 (($ $ (-572)) 21)) (-1803 (((-3 $ "failed") $ $) 58)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) 16)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 60)) (-4465 (((-1150 (-572)) $) 18)) (-2424 (($ $) 23)) (-3972 (((-856) $) 85) (($ (-572)) 51) (($ $) NIL)) (-2140 (((-769)) 14)) (-3774 (((-121) $ $) NIL)) (-3410 (((-572) $ (-572)) 35)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 34 T CONST)) (-3255 (($) 19 T CONST)) (-1324 (((-121) $ $) 38)) (-1373 (($ $) 50) (($ $ $) 36)) (-1367 (($ $ $) 49)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 53) (($ $ $) 54))) 
-(((-584 |#1| |#2|) (-869 |#1|) (-572) (-121)) (T -584)) 
-NIL 
-(-869 |#1|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 18)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 (($ $ (-923)) NIL (|has| $ (-374))) (($ $) NIL)) (-3617 (((-1178 (-923) (-769)) (-572)) 47)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 $ "failed") $) 75)) (-1318 (($ $) 74)) (-4337 (($ (-1259 $)) 73)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 42)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) 30)) (-3286 (($) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) 49)) (-1297 (((-121) $) NIL)) (-4486 (($ $) NIL) (($ $ (-769)) NIL)) (-1526 (((-121) $) NIL)) (-3377 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-3893 (((-121) $) NIL)) (-1664 (($) 35 (|has| $ (-374)))) (-3880 (((-121) $) NIL (|has| $ (-374)))) (-4429 (($ $ (-923)) NIL (|has| $ (-374))) (($ $) NIL)) (-3961 (((-3 $ "failed") $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 $) $ (-923)) NIL (|has| $ (-374))) (((-1166 $) $) 83)) (-3633 (((-923) $) 55)) (-4064 (((-1166 $) $) NIL (|has| $ (-374)))) (-4484 (((-3 (-1166 $) "failed") $ $) NIL (|has| $ (-374))) (((-1166 $) $) NIL (|has| $ (-374)))) (-2359 (($ $ (-1166 $)) NIL (|has| $ (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL T CONST)) (-1763 (($ (-923)) 48)) (-1336 (((-121) $) 67)) (-2607 (((-1116) $) NIL)) (-2307 (($) 16 (|has| $ (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 40)) (-4304 (((-424 $) $) NIL)) (-2728 (((-923)) 66) (((-834 (-923))) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-3 (-769) "failed") $ $) NIL) (((-769) $) NIL)) (-2502 (((-140)) NIL)) (-3139 (($ $ (-769)) NIL) (($ $) NIL)) (-4316 (((-923) $) 65) (((-834 (-923)) $) NIL)) (-2830 (((-1166 $)) 82)) (-2278 (($) 54)) (-3627 (($) 36 (|has| $ (-374)))) (-3160 (((-685 $) (-1259 $)) NIL) (((-1259 $) $) 71)) (-4081 (((-572) $) 26)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) 28) (($ $) NIL) (($ (-413 (-572))) NIL)) (-2779 (((-3 $ "failed") $) NIL) (($ $) 84)) (-2140 (((-769)) 37)) (-2237 (((-1259 $) (-923)) 77) (((-1259 $)) 76)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 19 T CONST)) (-3255 (($) 15 T CONST)) (-2611 (($ $ (-769)) NIL (|has| $ (-374))) (($ $) NIL (|has| $ (-374)))) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 24)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 61) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL))) 
-(((-585 |#1|) (-13 (-353) (-329 $) (-613 (-572))) (-923)) (T -585)) 
-NIL 
-(-13 (-353) (-329 $) (-613 (-572))) 
-((-3215 (((-1264) (-1152)) 10))) 
-(((-586) (-10 -7 (-15 -3215 ((-1264) (-1152))))) (T -586)) 
-((-3215 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-586))))) 
-(-10 -7 (-15 -3215 ((-1264) (-1152)))) 
-((-1585 (((-589 |#2|) (-589 |#2|)) 37)) (-2534 (((-638 |#2|) (-589 |#2|)) 39)) (-4150 ((|#2| (-589 |#2|)) 46))) 
-(((-587 |#1| |#2|) (-10 -7 (-15 -1585 ((-589 |#2|) (-589 |#2|))) (-15 -2534 ((-638 |#2|) (-589 |#2|))) (-15 -4150 (|#2| (-589 |#2|)))) (-13 (-457) (-1044 (-572)) (-848) (-634 (-572))) (-13 (-29 |#1|) (-1190))) (T -587)) 
-((-4150 (*1 *2 *3) (-12 (-5 *3 (-589 *2)) (-4 *2 (-13 (-29 *4) (-1190))) (-5 *1 (-587 *4 *2)) (-4 *4 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))))) (-2534 (*1 *2 *3) (-12 (-5 *3 (-589 *5)) (-4 *5 (-13 (-29 *4) (-1190))) (-4 *4 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-638 *5)) (-5 *1 (-587 *4 *5)))) (-1585 (*1 *2 *2) (-12 (-5 *2 (-589 *4)) (-4 *4 (-13 (-29 *3) (-1190))) (-4 *3 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *1 (-587 *3 *4))))) 
-(-10 -7 (-15 -1585 ((-589 |#2|) (-589 |#2|))) (-15 -2534 ((-638 |#2|) (-589 |#2|))) (-15 -4150 (|#2| (-589 |#2|)))) 
-((-3828 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")) 38) (((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed")) 11) (((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed")) 31) (((-589 |#2|) (-1 |#2| |#1|) (-589 |#1|)) 26))) 
-(((-588 |#1| |#2|) (-10 -7 (-15 -3828 ((-589 |#2|) (-1 |#2| |#1|) (-589 |#1|))) (-15 -3828 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed"))) (-15 -3828 ((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed"))) (-15 -3828 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")))) (-368) (-368)) (T -588)) 
-((-3828 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| |mainpart| *5) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (-4 *5 (-368)) (-4 *6 (-368)) (-5 *2 (-2 (|:| |mainpart| *6) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *6) (|:| |logand| *6)))))) (-5 *1 (-588 *5 *6)))) (-3828 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *2 *5)) (-5 *4 (-3 *5 "failed")) (-4 *5 (-368)) (-4 *2 (-368)) (-5 *1 (-588 *5 *2)))) (-3828 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| -3444 *5) (|:| |coeff| *5)) "failed")) (-4 *5 (-368)) (-4 *6 (-368)) (-5 *2 (-2 (|:| -3444 *6) (|:| |coeff| *6))) (-5 *1 (-588 *5 *6)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-589 *5)) (-4 *5 (-368)) (-4 *6 (-368)) (-5 *2 (-589 *6)) (-5 *1 (-588 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-589 |#2|) (-1 |#2| |#1|) (-589 |#1|))) (-15 -3828 ((-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -3444 |#1|) (|:| |coeff| |#1|)) "failed"))) (-15 -3828 ((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed"))) (-15 -3828 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 68)) (-1318 ((|#1| $) NIL)) (-3444 ((|#1| $) 24)) (-1630 (((-638 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $) 26)) (-3034 (($ |#1| (-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 |#1|)) (|:| |logand| (-1166 |#1|)))) (-638 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|)))) 22)) (-4223 (((-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 |#1|)) (|:| |logand| (-1166 |#1|)))) $) 25)) (-1658 (((-1152) $) NIL)) (-4282 (($ |#1| |#1|) 32) (($ |#1| (-1170)) 43 (|has| |#1| (-1044 (-1170))))) (-2607 (((-1116) $) NIL)) (-1316 (((-121) $) 28)) (-3139 ((|#1| $ (-1 |#1| |#1|)) 80) ((|#1| $ (-1170)) 81 (|has| |#1| (-901 (-1170))))) (-3972 (((-856) $) 95) (($ |#1|) 23)) (-2378 (($) 16 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) 15) (($ $ $) NIL)) (-1367 (($ $ $) 77)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 14) (($ (-413 (-572)) $) 35) (($ $ (-413 (-572))) NIL))) 
-(((-589 |#1|) (-13 (-713 (-413 (-572))) (-1044 |#1|) (-10 -8 (-15 -3034 ($ |#1| (-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 |#1|)) (|:| |logand| (-1166 |#1|)))) (-638 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))))) (-15 -3444 (|#1| $)) (-15 -4223 ((-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 |#1|)) (|:| |logand| (-1166 |#1|)))) $)) (-15 -1630 ((-638 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $)) (-15 -1316 ((-121) $)) (-15 -4282 ($ |#1| |#1|)) (-15 -3139 (|#1| $ (-1 |#1| |#1|))) (IF (|has| |#1| (-901 (-1170))) (-15 -3139 (|#1| $ (-1170))) |noBranch|) (IF (|has| |#1| (-1044 (-1170))) (-15 -4282 ($ |#1| (-1170))) |noBranch|))) (-368)) (T -589)) 
-((-3034 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 *2)) (|:| |logand| (-1166 *2))))) (-5 *4 (-638 (-2 (|:| |integrand| *2) (|:| |intvar| *2)))) (-4 *2 (-368)) (-5 *1 (-589 *2)))) (-3444 (*1 *2 *1) (-12 (-5 *1 (-589 *2)) (-4 *2 (-368)))) (-4223 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 *3)) (|:| |logand| (-1166 *3))))) (-5 *1 (-589 *3)) (-4 *3 (-368)))) (-1630 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |integrand| *3) (|:| |intvar| *3)))) (-5 *1 (-589 *3)) (-4 *3 (-368)))) (-1316 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-589 *3)) (-4 *3 (-368)))) (-4282 (*1 *1 *2 *2) (-12 (-5 *1 (-589 *2)) (-4 *2 (-368)))) (-3139 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-589 *2)) (-4 *2 (-368)))) (-3139 (*1 *2 *1 *3) (-12 (-4 *2 (-368)) (-4 *2 (-901 *3)) (-5 *1 (-589 *2)) (-5 *3 (-1170)))) (-4282 (*1 *1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *1 (-589 *2)) (-4 *2 (-1044 *3)) (-4 *2 (-368))))) 
-(-13 (-713 (-413 (-572))) (-1044 |#1|) (-10 -8 (-15 -3034 ($ |#1| (-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 |#1|)) (|:| |logand| (-1166 |#1|)))) (-638 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))))) (-15 -3444 (|#1| $)) (-15 -4223 ((-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 |#1|)) (|:| |logand| (-1166 |#1|)))) $)) (-15 -1630 ((-638 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $)) (-15 -1316 ((-121) $)) (-15 -4282 ($ |#1| |#1|)) (-15 -3139 (|#1| $ (-1 |#1| |#1|))) (IF (|has| |#1| (-901 (-1170))) (-15 -3139 (|#1| $ (-1170))) |noBranch|) (IF (|has| |#1| (-1044 (-1170))) (-15 -4282 ($ |#1| (-1170))) |noBranch|))) 
-((-1461 (((-121) |#1|) 16)) (-2540 (((-3 |#1| "failed") |#1|) 14)) (-3718 (((-2 (|:| -4393 |#1|) (|:| -3751 (-769))) |#1|) 30) (((-3 |#1| "failed") |#1| (-769)) 18)) (-3163 (((-121) |#1| (-769)) 19)) (-3364 ((|#1| |#1|) 31)) (-1524 ((|#1| |#1| (-769)) 33))) 
-(((-590 |#1|) (-10 -7 (-15 -3163 ((-121) |#1| (-769))) (-15 -3718 ((-3 |#1| "failed") |#1| (-769))) (-15 -3718 ((-2 (|:| -4393 |#1|) (|:| -3751 (-769))) |#1|)) (-15 -1524 (|#1| |#1| (-769))) (-15 -1461 ((-121) |#1|)) (-15 -2540 ((-3 |#1| "failed") |#1|)) (-15 -3364 (|#1| |#1|))) (-554)) (T -590)) 
-((-3364 (*1 *2 *2) (-12 (-5 *1 (-590 *2)) (-4 *2 (-554)))) (-2540 (*1 *2 *2) (|partial| -12 (-5 *1 (-590 *2)) (-4 *2 (-554)))) (-1461 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-590 *3)) (-4 *3 (-554)))) (-1524 (*1 *2 *2 *3) (-12 (-5 *3 (-769)) (-5 *1 (-590 *2)) (-4 *2 (-554)))) (-3718 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| -4393 *3) (|:| -3751 (-769)))) (-5 *1 (-590 *3)) (-4 *3 (-554)))) (-3718 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-769)) (-5 *1 (-590 *2)) (-4 *2 (-554)))) (-3163 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-5 *2 (-121)) (-5 *1 (-590 *3)) (-4 *3 (-554))))) 
-(-10 -7 (-15 -3163 ((-121) |#1| (-769))) (-15 -3718 ((-3 |#1| "failed") |#1| (-769))) (-15 -3718 ((-2 (|:| -4393 |#1|) (|:| -3751 (-769))) |#1|)) (-15 -1524 (|#1| |#1| (-769))) (-15 -1461 ((-121) |#1|)) (-15 -2540 ((-3 |#1| "failed") |#1|)) (-15 -3364 (|#1| |#1|))) 
-((-3408 (((-1166 |#1|) (-923)) 26))) 
-(((-591 |#1|) (-10 -7 (-15 -3408 ((-1166 |#1|) (-923)))) (-353)) (T -591)) 
-((-3408 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-591 *4)) (-4 *4 (-353))))) 
-(-10 -7 (-15 -3408 ((-1166 |#1|) (-923)))) 
-((-1585 (((-589 (-413 (-959 |#1|))) (-589 (-413 (-959 |#1|)))) 26)) (-2774 (((-3 (-312 |#1|) (-638 (-312 |#1|))) (-413 (-959 |#1|)) (-1170)) 32 (|has| |#1| (-151)))) (-2534 (((-638 (-312 |#1|)) (-589 (-413 (-959 |#1|)))) 18)) (-2464 (((-312 |#1|) (-413 (-959 |#1|)) (-1170)) 30 (|has| |#1| (-151)))) (-4150 (((-312 |#1|) (-589 (-413 (-959 |#1|)))) 20))) 
-(((-592 |#1|) (-10 -7 (-15 -1585 ((-589 (-413 (-959 |#1|))) (-589 (-413 (-959 |#1|))))) (-15 -2534 ((-638 (-312 |#1|)) (-589 (-413 (-959 |#1|))))) (-15 -4150 ((-312 |#1|) (-589 (-413 (-959 |#1|))))) (IF (|has| |#1| (-151)) (PROGN (-15 -2774 ((-3 (-312 |#1|) (-638 (-312 |#1|))) (-413 (-959 |#1|)) (-1170))) (-15 -2464 ((-312 |#1|) (-413 (-959 |#1|)) (-1170)))) |noBranch|)) (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (T -592)) 
-((-2464 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-151)) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-312 *5)) (-5 *1 (-592 *5)))) (-2774 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-151)) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-3 (-312 *5) (-638 (-312 *5)))) (-5 *1 (-592 *5)))) (-4150 (*1 *2 *3) (-12 (-5 *3 (-589 (-413 (-959 *4)))) (-4 *4 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-312 *4)) (-5 *1 (-592 *4)))) (-2534 (*1 *2 *3) (-12 (-5 *3 (-589 (-413 (-959 *4)))) (-4 *4 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-638 (-312 *4))) (-5 *1 (-592 *4)))) (-1585 (*1 *2 *2) (-12 (-5 *2 (-589 (-413 (-959 *3)))) (-4 *3 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *1 (-592 *3))))) 
-(-10 -7 (-15 -1585 ((-589 (-413 (-959 |#1|))) (-589 (-413 (-959 |#1|))))) (-15 -2534 ((-638 (-312 |#1|)) (-589 (-413 (-959 |#1|))))) (-15 -4150 ((-312 |#1|) (-589 (-413 (-959 |#1|))))) (IF (|has| |#1| (-151)) (PROGN (-15 -2774 ((-3 (-312 |#1|) (-638 (-312 |#1|))) (-413 (-959 |#1|)) (-1170))) (-15 -2464 ((-312 |#1|) (-413 (-959 |#1|)) (-1170)))) |noBranch|)) 
-((-1621 (((-638 (-685 (-572))) (-638 (-572)) (-638 (-906 (-572)))) 45) (((-638 (-685 (-572))) (-638 (-572))) 46) (((-685 (-572)) (-638 (-572)) (-906 (-572))) 41)) (-3764 (((-769) (-638 (-572))) 39))) 
-(((-593) (-10 -7 (-15 -3764 ((-769) (-638 (-572)))) (-15 -1621 ((-685 (-572)) (-638 (-572)) (-906 (-572)))) (-15 -1621 ((-638 (-685 (-572))) (-638 (-572)))) (-15 -1621 ((-638 (-685 (-572))) (-638 (-572)) (-638 (-906 (-572))))))) (T -593)) 
-((-1621 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-572))) (-5 *4 (-638 (-906 (-572)))) (-5 *2 (-638 (-685 (-572)))) (-5 *1 (-593)))) (-1621 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-638 (-685 (-572)))) (-5 *1 (-593)))) (-1621 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-572))) (-5 *4 (-906 (-572))) (-5 *2 (-685 (-572))) (-5 *1 (-593)))) (-3764 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-769)) (-5 *1 (-593))))) 
-(-10 -7 (-15 -3764 ((-769) (-638 (-572)))) (-15 -1621 ((-685 (-572)) (-638 (-572)) (-906 (-572)))) (-15 -1621 ((-638 (-685 (-572))) (-638 (-572)))) (-15 -1621 ((-638 (-685 (-572))) (-638 (-572)) (-638 (-906 (-572)))))) 
-((-4052 (((-638 |#5|) |#5| (-121)) 72)) (-2735 (((-121) |#5| (-638 |#5|)) 30))) 
-(((-594 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4052 ((-638 |#5|) |#5| (-121))) (-15 -2735 ((-121) |#5| (-638 |#5|)))) (-13 (-303) (-151)) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1107 |#1| |#2| |#3| |#4|)) (T -594)) 
-((-2735 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1107 *5 *6 *7 *8)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-594 *5 *6 *7 *8 *3)))) (-4052 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-638 *3)) (-5 *1 (-594 *5 *6 *7 *8 *3)) (-4 *3 (-1107 *5 *6 *7 *8))))) 
-(-10 -7 (-15 -4052 ((-638 |#5|) |#5| (-121))) (-15 -2735 ((-121) |#5| (-638 |#5|)))) 
-((-2262 (((-121) $ $) NIL (|has| (-148) (-1098)))) (-4092 (($ $) 34)) (-4013 (($ $) NIL)) (-3867 (($ $ (-148)) NIL) (($ $ (-143)) NIL)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2066 (((-121) $ $) 51)) (-2013 (((-121) $ $ (-572)) 46)) (-1585 (((-638 $) $ (-148)) 59) (((-638 $) $ (-143)) 60)) (-2041 (((-121) (-1 (-121) (-148) (-148)) $) NIL) (((-121) $) NIL (|has| (-148) (-848)))) (-4131 (($ (-1 (-121) (-148) (-148)) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-148) (-848))))) (-3008 (($ (-1 (-121) (-148) (-148)) $) NIL) (($ $) NIL (|has| (-148) (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-148) $ (-572) (-148)) 45 (|has| $ (-6 -4603))) (((-148) $ (-1225 (-572)) (-148)) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-3429 (($ $ (-148)) 63) (($ $ (-143)) 64)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-3808 (($ $ (-1225 (-572)) $) 44)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-3445 (($ (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098)))) (($ (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-148) (-1 (-148) (-148) (-148)) $ (-148) (-148)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098)))) (((-148) (-1 (-148) (-148) (-148)) $ (-148)) NIL (|has| $ (-6 -4602))) (((-148) (-1 (-148) (-148) (-148)) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-148) $ (-572) (-148)) NIL (|has| $ (-6 -4603)))) (-4212 (((-148) $ (-572)) NIL)) (-2174 (((-121) $ $) 70)) (-4014 (((-572) (-1 (-121) (-148)) $) NIL) (((-572) (-148) $) NIL (|has| (-148) (-1098))) (((-572) (-148) $ (-572)) 48 (|has| (-148) (-1098))) (((-572) $ $ (-572)) 47) (((-572) (-143) $ (-572)) 50)) (-2010 (((-638 (-148)) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) (-148)) 9)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 28 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| (-148) (-848)))) (-4475 (($ (-1 (-121) (-148) (-148)) $ $) NIL) (($ $ $) NIL (|has| (-148) (-848)))) (-4467 (((-638 (-148)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-2026 (((-572) $) 42 (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-148) (-848)))) (-2524 (((-121) $ $ (-148)) 71)) (-3724 (((-769) $ $ (-148)) 69)) (-2435 (($ (-1 (-148) (-148)) $) 33 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-148) (-148)) $) NIL) (($ (-1 (-148) (-148) (-148)) $ $) NIL)) (-2895 (($ $) 37)) (-2676 (($ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1796 (($ $ (-148)) 61) (($ $ (-143)) 62)) (-1658 (((-1152) $) 38 (|has| (-148) (-1098)))) (-2603 (($ (-148) $ (-572)) NIL) (($ $ $ (-572)) 23)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-572) $) 68) (((-1116) $) NIL (|has| (-148) (-1098)))) (-1837 (((-148) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-148) "failed") (-1 (-121) (-148)) $) NIL)) (-3299 (($ $ (-148)) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-148)))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-290 (-148))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-148) (-148)) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-638 (-148)) (-638 (-148))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-2957 (((-638 (-148)) $) NIL)) (-4037 (((-121) $) 12)) (-1665 (($) 10)) (-3277 (((-148) $ (-572) (-148)) NIL) (((-148) $ (-572)) 52) (($ $ (-1225 (-572))) 21) (($ $ $) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602))) (((-769) (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-2907 (($ $ $ (-572)) 65 (|has| $ (-6 -4603)))) (-1607 (($ $) 17)) (-4081 (((-545) $) NIL (|has| (-148) (-613 (-545))))) (-3921 (($ (-638 (-148))) NIL)) (-4500 (($ $ (-148)) NIL) (($ (-148) $) NIL) (($ $ $) 16) (($ (-638 $)) 66)) (-3972 (($ (-148)) NIL) (((-856) $) 27 (|has| (-148) (-1098)))) (-3501 (((-121) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| (-148) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-148) (-848)))) (-1324 (((-121) $ $) 14 (|has| (-148) (-1098)))) (-1343 (((-121) $ $) NIL (|has| (-148) (-848)))) (-1334 (((-121) $ $) 15 (|has| (-148) (-848)))) (-4032 (((-769) $) 13 (|has| $ (-6 -4602))))) 
-(((-595 |#1|) (-13 (-1137) (-10 -8 (-15 -2607 ((-572) $)))) (-572)) (T -595)) 
-((-2607 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-595 *3)) (-14 *3 *2)))) 
-(-13 (-1137) (-10 -8 (-15 -2607 ((-572) $)))) 
-((-4360 (((-2 (|:| |num| |#4|) (|:| |den| (-572))) |#4| |#2|) 23) (((-2 (|:| |num| |#4|) (|:| |den| (-572))) |#4| |#2| (-1092 |#4|)) 32))) 
-(((-596 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4360 ((-2 (|:| |num| |#4|) (|:| |den| (-572))) |#4| |#2| (-1092 |#4|))) (-15 -4360 ((-2 (|:| |num| |#4|) (|:| |den| (-572))) |#4| |#2|))) (-794) (-848) (-562) (-956 |#3| |#1| |#2|)) (T -596)) 
-((-4360 (*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-562)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-572)))) (-5 *1 (-596 *5 *4 *6 *3)) (-4 *3 (-956 *6 *5 *4)))) (-4360 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-1092 *3)) (-4 *3 (-956 *7 *6 *4)) (-4 *6 (-794)) (-4 *4 (-848)) (-4 *7 (-562)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-572)))) (-5 *1 (-596 *6 *4 *7 *3))))) 
-(-10 -7 (-15 -4360 ((-2 (|:| |num| |#4|) (|:| |den| (-572))) |#4| |#2| (-1092 |#4|))) (-15 -4360 ((-2 (|:| |num| |#4|) (|:| |den| (-572))) |#4| |#2|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 63)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-572)) 54) (($ $ (-572) (-572)) 55)) (-2640 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) 60)) (-2704 (($ $) 99)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2480 (((-856) (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) (-1033 (-841 (-572))) (-1170) |#1| (-413 (-572))) 214)) (-4521 (($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) 34)) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-1347 (((-121) $) NIL)) (-3377 (((-572) $) 58) (((-572) $ (-572)) 59)) (-3893 (((-121) $) NIL)) (-3965 (($ $ (-923)) 76)) (-4324 (($ (-1 |#1| (-572)) $) 73)) (-4581 (((-121) $) 25)) (-4328 (($ |#1| (-572)) 22) (($ $ (-1082) (-572)) NIL) (($ $ (-638 (-1082)) (-638 (-572))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) 67)) (-4011 (($ (-1033 (-841 (-572))) (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) 11)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2774 (($ $) 111 (|has| |#1| (-43 (-413 (-572)))))) (-4116 (((-3 $ "failed") $ $ (-121)) 98)) (-3117 (($ $ $) 107)) (-2607 (((-1116) $) NIL)) (-4572 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) 13)) (-4401 (((-1033 (-841 (-572))) $) 12)) (-1977 (($ $ (-572)) 45)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-572)))))) (-3277 ((|#1| $ (-572)) 57) (($ $ $) NIL (|has| (-572) (-1110)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $) 70 (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (-4316 (((-572) $) NIL)) (-2424 (($ $) 46)) (-3972 (((-856) $) NIL) (($ (-572)) 28) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562))) (($ |#1|) 27 (|has| |#1| (-174)))) (-1958 ((|#1| $ (-572)) 56)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) 37)) (-1694 ((|#1| $) NIL)) (-3067 (($ $) 179 (|has| |#1| (-43 (-413 (-572)))))) (-2994 (($ $) 155 (|has| |#1| (-43 (-413 (-572)))))) (-3645 (($ $) 176 (|has| |#1| (-43 (-413 (-572)))))) (-3396 (($ $) 152 (|has| |#1| (-43 (-413 (-572)))))) (-3877 (($ $) 181 (|has| |#1| (-43 (-413 (-572)))))) (-3315 (($ $) 158 (|has| |#1| (-43 (-413 (-572)))))) (-1299 (($ $ (-413 (-572))) 145 (|has| |#1| (-43 (-413 (-572)))))) (-4392 (($ $ |#1|) 120 (|has| |#1| (-43 (-413 (-572)))))) (-2520 (($ $) 149 (|has| |#1| (-43 (-413 (-572)))))) (-3284 (($ $) 147 (|has| |#1| (-43 (-413 (-572)))))) (-4274 (($ $) 182 (|has| |#1| (-43 (-413 (-572)))))) (-2421 (($ $) 159 (|has| |#1| (-43 (-413 (-572)))))) (-1520 (($ $) 180 (|has| |#1| (-43 (-413 (-572)))))) (-4403 (($ $) 157 (|has| |#1| (-43 (-413 (-572)))))) (-4490 (($ $) 177 (|has| |#1| (-43 (-413 (-572)))))) (-3053 (($ $) 153 (|has| |#1| (-43 (-413 (-572)))))) (-2185 (($ $) 187 (|has| |#1| (-43 (-413 (-572)))))) (-2063 (($ $) 167 (|has| |#1| (-43 (-413 (-572)))))) (-4569 (($ $) 184 (|has| |#1| (-43 (-413 (-572)))))) (-3128 (($ $) 162 (|has| |#1| (-43 (-413 (-572)))))) (-3331 (($ $) 191 (|has| |#1| (-43 (-413 (-572)))))) (-4015 (($ $) 171 (|has| |#1| (-43 (-413 (-572)))))) (-1556 (($ $) 193 (|has| |#1| (-43 (-413 (-572)))))) (-3885 (($ $) 173 (|has| |#1| (-43 (-413 (-572)))))) (-1816 (($ $) 189 (|has| |#1| (-43 (-413 (-572)))))) (-3583 (($ $) 169 (|has| |#1| (-43 (-413 (-572)))))) (-3012 (($ $) 186 (|has| |#1| (-43 (-413 (-572)))))) (-2514 (($ $) 165 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-3410 ((|#1| $ (-572)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-572)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 29 T CONST)) (-3255 (($) 38 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (-1324 (((-121) $ $) 65)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) 84) (($ $ $) 64)) (-1367 (($ $ $) 81)) (** (($ $ (-923)) NIL) (($ $ (-769)) 102)) (* (($ (-923) $) 89) (($ (-769) $) 87) (($ (-572) $) 85) (($ $ $) 95) (($ $ |#1|) NIL) (($ |#1| $) 114) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-597 |#1|) (-13 (-1236 |#1| (-572)) (-10 -8 (-15 -4011 ($ (-1033 (-841 (-572))) (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))))) (-15 -4401 ((-1033 (-841 (-572))) $)) (-15 -4572 ((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $)) (-15 -4521 ($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))))) (-15 -4581 ((-121) $)) (-15 -4324 ($ (-1 |#1| (-572)) $)) (-15 -4116 ((-3 $ "failed") $ $ (-121))) (-15 -2704 ($ $)) (-15 -3117 ($ $ $)) (-15 -2480 ((-856) (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) (-1033 (-841 (-572))) (-1170) |#1| (-413 (-572)))) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $)) (-15 -4392 ($ $ |#1|)) (-15 -1299 ($ $ (-413 (-572)))) (-15 -3284 ($ $)) (-15 -2520 ($ $)) (-15 -3396 ($ $)) (-15 -3053 ($ $)) (-15 -2994 ($ $)) (-15 -4403 ($ $)) (-15 -3315 ($ $)) (-15 -2421 ($ $)) (-15 -3128 ($ $)) (-15 -2514 ($ $)) (-15 -2063 ($ $)) (-15 -3583 ($ $)) (-15 -4015 ($ $)) (-15 -3885 ($ $)) (-15 -3645 ($ $)) (-15 -4490 ($ $)) (-15 -3067 ($ $)) (-15 -1520 ($ $)) (-15 -3877 ($ $)) (-15 -4274 ($ $)) (-15 -4569 ($ $)) (-15 -3012 ($ $)) (-15 -2185 ($ $)) (-15 -1816 ($ $)) (-15 -3331 ($ $)) (-15 -1556 ($ $))) |noBranch|))) (-1054)) (T -597)) 
-((-4581 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-597 *3)) (-4 *3 (-1054)))) (-4011 (*1 *1 *2 *3) (-12 (-5 *2 (-1033 (-841 (-572)))) (-5 *3 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *4)))) (-4 *4 (-1054)) (-5 *1 (-597 *4)))) (-4401 (*1 *2 *1) (-12 (-5 *2 (-1033 (-841 (-572)))) (-5 *1 (-597 *3)) (-4 *3 (-1054)))) (-4572 (*1 *2 *1) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))) (-5 *1 (-597 *3)) (-4 *3 (-1054)))) (-4521 (*1 *1 *2) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))) (-4 *3 (-1054)) (-5 *1 (-597 *3)))) (-4324 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-572))) (-4 *3 (-1054)) (-5 *1 (-597 *3)))) (-4116 (*1 *1 *1 *1 *2) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-597 *3)) (-4 *3 (-1054)))) (-2704 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-1054)))) (-3117 (*1 *1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-1054)))) (-2480 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *6)))) (-5 *4 (-1033 (-841 (-572)))) (-5 *5 (-1170)) (-5 *7 (-413 (-572))) (-4 *6 (-1054)) (-5 *2 (-856)) (-5 *1 (-597 *6)))) (-2774 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-4392 (*1 *1 *1 *2) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-1299 (*1 *1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-597 *3)) (-4 *3 (-43 *2)) (-4 *3 (-1054)))) (-3284 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-2520 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3396 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3053 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-2994 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-4403 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3315 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-2421 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3128 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-2514 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-2063 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3583 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-4015 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3885 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3645 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-4490 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3067 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-1520 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3877 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-4274 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-4569 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3012 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-2185 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-1816 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-3331 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) (-1556 (*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(-13 (-1236 |#1| (-572)) (-10 -8 (-15 -4011 ($ (-1033 (-841 (-572))) (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))))) (-15 -4401 ((-1033 (-841 (-572))) $)) (-15 -4572 ((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $)) (-15 -4521 ($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))))) (-15 -4581 ((-121) $)) (-15 -4324 ($ (-1 |#1| (-572)) $)) (-15 -4116 ((-3 $ "failed") $ $ (-121))) (-15 -2704 ($ $)) (-15 -3117 ($ $ $)) (-15 -2480 ((-856) (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) (-1033 (-841 (-572))) (-1170) |#1| (-413 (-572)))) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $)) (-15 -4392 ($ $ |#1|)) (-15 -1299 ($ $ (-413 (-572)))) (-15 -3284 ($ $)) (-15 -2520 ($ $)) (-15 -3396 ($ $)) (-15 -3053 ($ $)) (-15 -2994 ($ $)) (-15 -4403 ($ $)) (-15 -3315 ($ $)) (-15 -2421 ($ $)) (-15 -3128 ($ $)) (-15 -2514 ($ $)) (-15 -2063 ($ $)) (-15 -3583 ($ $)) (-15 -4015 ($ $)) (-15 -3885 ($ $)) (-15 -3645 ($ $)) (-15 -4490 ($ $)) (-15 -3067 ($ $)) (-15 -1520 ($ $)) (-15 -3877 ($ $)) (-15 -4274 ($ $)) (-15 -4569 ($ $)) (-15 -3012 ($ $)) (-15 -2185 ($ $)) (-15 -1816 ($ $)) (-15 -3331 ($ $)) (-15 -1556 ($ $))) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4521 (($ (-1150 |#1|)) 9)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) 42)) (-1347 (((-121) $) 52)) (-3377 (((-769) $) 55) (((-769) $ (-769)) 54)) (-3893 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ $) 44 (|has| |#1| (-562)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-1150 |#1|) $) 23)) (-2140 (((-769)) 51)) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 10 T CONST)) (-3255 (($) 14 T CONST)) (-1324 (((-121) $ $) 22)) (-1373 (($ $) 30) (($ $ $) 16)) (-1367 (($ $ $) 25)) (** (($ $ (-923)) NIL) (($ $ (-769)) 49)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 34) (($ $ $) 28) (($ |#1| $) 37) (($ $ |#1|) 38) (($ $ (-572)) 36))) 
-(((-598 |#1|) (-13 (-1054) (-10 -8 (-15 -3193 ((-1150 |#1|) $)) (-15 -4521 ($ (-1150 |#1|))) (-15 -1347 ((-121) $)) (-15 -3377 ((-769) $)) (-15 -3377 ((-769) $ (-769))) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 * ($ $ (-572))) (IF (|has| |#1| (-562)) (-6 (-562)) |noBranch|))) (-1054)) (T -598)) 
-((-3193 (*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) (-4521 (*1 *1 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-598 *3)))) (-1347 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) (-3377 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) (-3377 (*1 *2 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) (* (*1 *1 *2 *1) (-12 (-5 *1 (-598 *2)) (-4 *2 (-1054)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-598 *2)) (-4 *2 (-1054)))) (* (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-598 *3)) (-4 *3 (-1054))))) 
-(-13 (-1054) (-10 -8 (-15 -3193 ((-1150 |#1|) $)) (-15 -4521 ($ (-1150 |#1|))) (-15 -1347 ((-121) $)) (-15 -3377 ((-769) $)) (-15 -3377 ((-769) $ (-769))) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 * ($ $ (-572))) (IF (|has| |#1| (-562)) (-6 (-562)) |noBranch|))) 
-((-3828 (((-602 |#2|) (-1 |#2| |#1|) (-602 |#1|)) 15))) 
-(((-599 |#1| |#2|) (-10 -7 (-15 -3828 ((-602 |#2|) (-1 |#2| |#1|) (-602 |#1|)))) (-1204) (-1204)) (T -599)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-602 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-602 *6)) (-5 *1 (-599 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-602 |#2|) (-1 |#2| |#1|) (-602 |#1|)))) 
-((-3828 (((-1150 |#3|) (-1 |#3| |#1| |#2|) (-602 |#1|) (-1150 |#2|)) 20) (((-1150 |#3|) (-1 |#3| |#1| |#2|) (-1150 |#1|) (-602 |#2|)) 19) (((-602 |#3|) (-1 |#3| |#1| |#2|) (-602 |#1|) (-602 |#2|)) 18))) 
-(((-600 |#1| |#2| |#3|) (-10 -7 (-15 -3828 ((-602 |#3|) (-1 |#3| |#1| |#2|) (-602 |#1|) (-602 |#2|))) (-15 -3828 ((-1150 |#3|) (-1 |#3| |#1| |#2|) (-1150 |#1|) (-602 |#2|))) (-15 -3828 ((-1150 |#3|) (-1 |#3| |#1| |#2|) (-602 |#1|) (-1150 |#2|)))) (-1204) (-1204) (-1204)) (T -600)) 
-((-3828 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-602 *6)) (-5 *5 (-1150 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-1150 *8)) (-5 *1 (-600 *6 *7 *8)))) (-3828 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1150 *6)) (-5 *5 (-602 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-1150 *8)) (-5 *1 (-600 *6 *7 *8)))) (-3828 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-602 *6)) (-5 *5 (-602 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-602 *8)) (-5 *1 (-600 *6 *7 *8))))) 
-(-10 -7 (-15 -3828 ((-602 |#3|) (-1 |#3| |#1| |#2|) (-602 |#1|) (-602 |#2|))) (-15 -3828 ((-1150 |#3|) (-1 |#3| |#1| |#2|) (-1150 |#1|) (-602 |#2|))) (-15 -3828 ((-1150 |#3|) (-1 |#3| |#1| |#2|) (-602 |#1|) (-1150 |#2|)))) 
-((-4293 ((|#3| |#3| (-638 (-611 |#3|)) (-638 (-1170))) 55)) (-4379 (((-171 |#2|) |#3|) 116)) (-3165 ((|#3| (-171 |#2|)) 43)) (-2802 ((|#2| |#3|) 19)) (-1868 ((|#3| |#2|) 32))) 
-(((-601 |#1| |#2| |#3|) (-10 -7 (-15 -3165 (|#3| (-171 |#2|))) (-15 -2802 (|#2| |#3|)) (-15 -1868 (|#3| |#2|)) (-15 -4379 ((-171 |#2|) |#3|)) (-15 -4293 (|#3| |#3| (-638 (-611 |#3|)) (-638 (-1170))))) (-13 (-562) (-848)) (-13 (-436 |#1|) (-1009) (-1190)) (-13 (-436 (-171 |#1|)) (-1009) (-1190))) (T -601)) 
-((-4293 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-638 (-611 *2))) (-5 *4 (-638 (-1170))) (-4 *2 (-13 (-436 (-171 *5)) (-1009) (-1190))) (-4 *5 (-13 (-562) (-848))) (-5 *1 (-601 *5 *6 *2)) (-4 *6 (-13 (-436 *5) (-1009) (-1190))))) (-4379 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848))) (-5 *2 (-171 *5)) (-5 *1 (-601 *4 *5 *3)) (-4 *5 (-13 (-436 *4) (-1009) (-1190))) (-4 *3 (-13 (-436 (-171 *4)) (-1009) (-1190))))) (-1868 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848))) (-4 *2 (-13 (-436 (-171 *4)) (-1009) (-1190))) (-5 *1 (-601 *4 *3 *2)) (-4 *3 (-13 (-436 *4) (-1009) (-1190))))) (-2802 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848))) (-4 *2 (-13 (-436 *4) (-1009) (-1190))) (-5 *1 (-601 *4 *2 *3)) (-4 *3 (-13 (-436 (-171 *4)) (-1009) (-1190))))) (-3165 (*1 *2 *3) (-12 (-5 *3 (-171 *5)) (-4 *5 (-13 (-436 *4) (-1009) (-1190))) (-4 *4 (-13 (-562) (-848))) (-4 *2 (-13 (-436 (-171 *4)) (-1009) (-1190))) (-5 *1 (-601 *4 *5 *2))))) 
-(-10 -7 (-15 -3165 (|#3| (-171 |#2|))) (-15 -2802 (|#2| |#3|)) (-15 -1868 (|#3| |#2|)) (-15 -4379 ((-171 |#2|) |#3|)) (-15 -4293 (|#3| |#3| (-638 (-611 |#3|)) (-638 (-1170))))) 
-((-2561 (($ (-1 (-121) |#1|) $) 16)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-2516 (($ (-1 |#1| |#1|) |#1|) 9)) (-2543 (($ (-1 (-121) |#1|) $) 12)) (-2552 (($ (-1 (-121) |#1|) $) 14)) (-3921 (((-1150 |#1|) $) 17)) (-3972 (((-856) $) NIL))) 
-(((-602 |#1|) (-13 (-612 (-856)) (-10 -8 (-15 -3828 ($ (-1 |#1| |#1|) $)) (-15 -2543 ($ (-1 (-121) |#1|) $)) (-15 -2552 ($ (-1 (-121) |#1|) $)) (-15 -2561 ($ (-1 (-121) |#1|) $)) (-15 -2516 ($ (-1 |#1| |#1|) |#1|)) (-15 -3921 ((-1150 |#1|) $)))) (-1204)) (T -602)) 
-((-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) (-2543 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) (-2552 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) (-2561 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) (-2516 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) (-3921 (*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-602 *3)) (-4 *3 (-1204))))) 
-(-13 (-612 (-856)) (-10 -8 (-15 -3828 ($ (-1 |#1| |#1|) $)) (-15 -2543 ($ (-1 (-121) |#1|) $)) (-15 -2552 ($ (-1 (-121) |#1|) $)) (-15 -2561 ($ (-1 (-121) |#1|) $)) (-15 -2516 ($ (-1 |#1| |#1|) |#1|)) (-15 -3921 ((-1150 |#1|) $)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4169 (($ (-769)) NIL (|has| |#1| (-23)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-4014 (((-572) (-1 (-121) |#1|) $) NIL) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098)))) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3349 (((-685 |#1|) $ $) NIL (|has| |#1| (-1054)))) (-1364 (($ (-769) |#1|) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3169 ((|#1| $) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1054))))) (-3524 (((-121) $ (-769)) NIL)) (-3200 ((|#1| $) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1054))))) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) NIL (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) |#1|) NIL) ((|#1| $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1436 ((|#1| $ $) NIL (|has| |#1| (-1054)))) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-3780 (($ $ $) NIL (|has| |#1| (-1054)))) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-4500 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1373 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1367 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-572) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-722))) (($ $ |#1|) NIL (|has| |#1| (-722)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-603 |#1| |#2|) (-1257 |#1|) (-1204) (-572)) (T -603)) 
-NIL 
-(-1257 |#1|) 
-((-2430 (((-1264) $ |#2| |#2|) 36)) (-3940 ((|#2| $) 23)) (-2026 ((|#2| $) 21)) (-2435 (($ (-1 |#3| |#3|) $) 32)) (-3828 (($ (-1 |#3| |#3|) $) 30)) (-1837 ((|#3| $) 26)) (-3299 (($ $ |#3|) 33)) (-3167 (((-121) |#3| $) 17)) (-2957 (((-638 |#3|) $) 15)) (-3277 ((|#3| $ |#2| |#3|) 12) ((|#3| $ |#2|) NIL))) 
-(((-604 |#1| |#2| |#3|) (-10 -8 (-15 -2430 ((-1264) |#1| |#2| |#2|)) (-15 -3299 (|#1| |#1| |#3|)) (-15 -1837 (|#3| |#1|)) (-15 -3940 (|#2| |#1|)) (-15 -2026 (|#2| |#1|)) (-15 -3167 ((-121) |#3| |#1|)) (-15 -2957 ((-638 |#3|) |#1|)) (-15 -3277 (|#3| |#1| |#2|)) (-15 -3277 (|#3| |#1| |#2| |#3|)) (-15 -2435 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3828 (|#1| (-1 |#3| |#3|) |#1|))) (-605 |#2| |#3|) (-1098) (-1204)) (T -604)) 
-NIL 
-(-10 -8 (-15 -2430 ((-1264) |#1| |#2| |#2|)) (-15 -3299 (|#1| |#1| |#3|)) (-15 -1837 (|#3| |#1|)) (-15 -3940 (|#2| |#1|)) (-15 -2026 (|#2| |#1|)) (-15 -3167 ((-121) |#3| |#1|)) (-15 -2957 ((-638 |#3|) |#1|)) (-15 -3277 (|#3| |#1| |#2|)) (-15 -3277 (|#3| |#1| |#2| |#3|)) (-15 -2435 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3828 (|#1| (-1 |#3| |#3|) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#2| (-1098)))) (-2430 (((-1264) $ |#1| |#1|) 37 (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#2| $ |#1| |#2|) 49 (|has| $ (-6 -4603)))) (-2211 (($) 7 T CONST)) (-3037 ((|#2| $ |#1| |#2|) 50 (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) 48)) (-2010 (((-638 |#2|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-3940 ((|#1| $) 40 (|has| |#1| (-848)))) (-4467 (((-638 |#2|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#2| $) 27 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602))))) (-2026 ((|#1| $) 41 (|has| |#1| (-848)))) (-2435 (($ (-1 |#2| |#2|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#2| |#2|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#2| (-1098)))) (-2739 (((-638 |#1|) $) 43)) (-1601 (((-121) |#1| $) 44)) (-2607 (((-1116) $) 21 (|has| |#2| (-1098)))) (-1837 ((|#2| $) 39 (|has| |#1| (-848)))) (-3299 (($ $ |#2|) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#2|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#2|))) 26 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) 25 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) 24 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) 23 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#2| $) 42 (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#2| $ |#1| |#2|) 47) ((|#2| $ |#1|) 46)) (-1571 (((-769) (-1 (-121) |#2|) $) 31 (|has| $ (-6 -4602))) (((-769) |#2| $) 28 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#2| (-1098)))) (-3501 (((-121) (-1 (-121) |#2|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#2| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-605 |#1| |#2|) (-1290) (-1098) (-1204)) (T -605)) 
-((-2957 (*1 *2 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1204)) (-5 *2 (-638 *4)))) (-1601 (*1 *2 *3 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1204)) (-5 *2 (-121)))) (-2739 (*1 *2 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1204)) (-5 *2 (-638 *3)))) (-3167 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-605 *4 *3)) (-4 *4 (-1098)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-121)))) (-2026 (*1 *2 *1) (-12 (-4 *1 (-605 *2 *3)) (-4 *3 (-1204)) (-4 *2 (-1098)) (-4 *2 (-848)))) (-3940 (*1 *2 *1) (-12 (-4 *1 (-605 *2 *3)) (-4 *3 (-1204)) (-4 *2 (-1098)) (-4 *2 (-848)))) (-1837 (*1 *2 *1) (-12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1098)) (-4 *3 (-848)) (-4 *2 (-1204)))) (-3299 (*1 *1 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-605 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204)))) (-2430 (*1 *2 *1 *3 *3) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-605 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1204)) (-5 *2 (-1264))))) 
-(-13 (-503 |t#2|) (-285 |t#1| |t#2|) (-10 -8 (-15 -2957 ((-638 |t#2|) $)) (-15 -1601 ((-121) |t#1| $)) (-15 -2739 ((-638 |t#1|) $)) (IF (|has| |t#2| (-1098)) (IF (|has| $ (-6 -4602)) (-15 -3167 ((-121) |t#2| $)) |noBranch|) |noBranch|) (IF (|has| |t#1| (-848)) (PROGN (-15 -2026 (|t#1| $)) (-15 -3940 (|t#1| $)) (-15 -1837 (|t#2| $))) |noBranch|) (IF (|has| $ (-6 -4603)) (PROGN (-15 -3299 ($ $ |t#2|)) (-15 -2430 ((-1264) $ |t#1| |t#1|))) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#2| (-1098)) ((-612 (-856)) |has| |#2| (-1098)) ((-283 |#1| |#2|) . T) ((-285 |#1| |#2|) . T) ((-305 |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-503 |#2|) . T) ((-527 |#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-1098) |has| |#2| (-1098)) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3029 (((-3 $ "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-1354 (((-1259 (-685 |#1|))) NIL (|has| |#2| (-423 |#1|))) (((-1259 (-685 |#1|)) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-2167 (((-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-2211 (($) NIL T CONST)) (-4511 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2095 (((-3 $ "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2882 (((-685 |#1|)) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-3487 ((|#1| $) NIL (|has| |#2| (-372 |#1|)))) (-3700 (((-685 |#1|) $) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) $ (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-2848 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-4535 (((-1166 (-959 |#1|))) NIL (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-368))))) (-3014 (($ $ (-923)) NIL)) (-3588 ((|#1| $) NIL (|has| |#2| (-372 |#1|)))) (-2135 (((-1166 |#1|) $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-4146 ((|#1|) NIL (|has| |#2| (-423 |#1|))) ((|#1| (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-1593 (((-1166 |#1|) $) NIL (|has| |#2| (-372 |#1|)))) (-2048 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-4337 (($ (-1259 |#1|)) NIL (|has| |#2| (-423 |#1|))) (($ (-1259 |#1|) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-1799 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2667 (((-923)) NIL (|has| |#2| (-372 |#1|)))) (-4160 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2027 (($ $ (-923)) NIL)) (-1814 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2209 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1648 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1903 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2036 (((-3 $ "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-1663 (((-685 |#1|)) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-3550 ((|#1| $) NIL (|has| |#2| (-372 |#1|)))) (-3343 (((-685 |#1|) $) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) $ (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-2046 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2339 (((-1166 (-959 |#1|))) NIL (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-368))))) (-3276 (($ $ (-923)) NIL)) (-2340 ((|#1| $) NIL (|has| |#2| (-372 |#1|)))) (-3665 (((-1166 |#1|) $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2110 ((|#1|) NIL (|has| |#2| (-423 |#1|))) ((|#1| (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-1989 (((-1166 |#1|) $) NIL (|has| |#2| (-372 |#1|)))) (-3602 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1658 (((-1152) $) NIL)) (-4219 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2395 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-3046 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2607 (((-1116) $) NIL)) (-4128 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-3277 ((|#1| $ (-572)) NIL (|has| |#2| (-423 |#1|)))) (-3160 (((-685 |#1|) (-1259 $)) NIL (|has| |#2| (-423 |#1|))) (((-1259 |#1|) $) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) (-1259 $) (-1259 $)) NIL (|has| |#2| (-372 |#1|))) (((-1259 |#1|) $ (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-4081 (($ (-1259 |#1|)) NIL (|has| |#2| (-423 |#1|))) (((-1259 |#1|) $) NIL (|has| |#2| (-423 |#1|)))) (-3188 (((-638 (-959 |#1|))) NIL (|has| |#2| (-423 |#1|))) (((-638 (-959 |#1|)) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-4056 (($ $ $) NIL)) (-2073 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-3972 (((-856) $) NIL) ((|#2| $) 21) (($ |#2|) 22)) (-2237 (((-1259 $)) NIL (|has| |#2| (-423 |#1|)))) (-4414 (((-638 (-1259 |#1|))) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-4250 (($ $ $ $) NIL)) (-2928 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1591 (($ (-685 |#1|) $) NIL (|has| |#2| (-423 |#1|)))) (-1397 (($ $ $) NIL)) (-2773 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2756 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1447 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2378 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) 24)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 20) (($ $ |#1|) 19) (($ |#1| $) NIL))) 
-(((-606 |#1| |#2|) (-13 (-742 |#1|) (-612 |#2|) (-10 -8 (-15 -3972 ($ |#2|)) (IF (|has| |#2| (-423 |#1|)) (-6 (-423 |#1|)) |noBranch|) (IF (|has| |#2| (-372 |#1|)) (-6 (-372 |#1|)) |noBranch|))) (-174) (-742 |#1|)) (T -606)) 
-((-3972 (*1 *1 *2) (-12 (-4 *3 (-174)) (-5 *1 (-606 *3 *2)) (-4 *2 (-742 *3))))) 
-(-13 (-742 |#1|) (-612 |#2|) (-10 -8 (-15 -3972 ($ |#2|)) (IF (|has| |#2| (-423 |#1|)) (-6 (-423 |#1|)) |noBranch|) (IF (|has| |#2| (-372 |#1|)) (-6 (-372 |#1|)) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-3757 (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) 33)) (-2982 (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL) (($) NIL)) (-2430 (((-1264) $ (-1152) (-1152)) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-1152) |#1|) 43)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 |#1| "failed") (-1152) $) 46)) (-2211 (($) NIL T CONST)) (-2582 (($ $ (-1152)) 25)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098))))) (-1544 (((-3 |#1| "failed") (-1152) $) 47) (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (($ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL (|has| $ (-6 -4602)))) (-3445 (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (($ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098))))) (-3116 (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098))))) (-2159 (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) 32)) (-3037 ((|#1| $ (-1152) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-1152)) NIL)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602))) (((-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-1652 (($ $) 48)) (-1428 (($ (-394)) 23) (($ (-394) (-1152)) 22)) (-3201 (((-394) $) 34)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-1152) $) NIL (|has| (-1152) (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602))) (((-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (((-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098))))) (-2026 (((-1152) $) NIL (|has| (-1152) (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2760 (((-638 (-1152)) $) 39)) (-2365 (((-121) (-1152) $) NIL)) (-1828 (((-1152) $) 35)) (-4221 (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL)) (-2739 (((-638 (-1152)) $) NIL)) (-1601 (((-121) (-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1734 (((-1264) $) NIL)) (-1837 ((|#1| $) NIL (|has| (-1152) (-848)))) (-3361 (((-3 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) "failed") (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (($ $ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (($ $ (-638 (-290 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 37)) (-3277 ((|#1| $ (-1152) |#1|) NIL) ((|#1| $ (-1152)) 42)) (-1535 (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL) (($) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (((-769) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (((-769) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL)) (-3972 (((-856) $) 21)) (-1391 (($ $) 26)) (-3058 (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 20)) (-4032 (((-769) $) 41 (|has| $ (-6 -4602))))) 
-(((-607 |#1|) (-13 (-369 (-394) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) (-1181 (-1152) |#1|) (-10 -8 (-6 -4602) (-15 -1652 ($ $)))) (-1098)) (T -607)) 
-((-1652 (*1 *1 *1) (-12 (-5 *1 (-607 *2)) (-4 *2 (-1098))))) 
-(-13 (-369 (-394) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) (-1181 (-1152) |#1|) (-10 -8 (-6 -4602) (-15 -1652 ($ $)))) 
-((-3002 (((-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) $) 15)) (-2760 (((-638 |#2|) $) 19)) (-2365 (((-121) |#2| $) 12))) 
-(((-608 |#1| |#2| |#3|) (-10 -8 (-15 -2760 ((-638 |#2|) |#1|)) (-15 -2365 ((-121) |#2| |#1|)) (-15 -3002 ((-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|))) (-609 |#2| |#3|) (-1098) (-1098)) (T -608)) 
-NIL 
-(-10 -8 (-15 -2760 ((-638 |#2|) |#1|)) (-15 -2365 ((-121) |#2| |#1|)) (-15 -3002 ((-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 42 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 52 (|has| $ (-6 -4602)))) (-1750 (((-3 |#2| "failed") |#1| $) 57)) (-2211 (($) 7 T CONST)) (-1643 (($ $) 55 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 43 (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) 58)) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 54 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 51 (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 53 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 50 (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 49 (|has| $ (-6 -4602)))) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 27 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-2760 (((-638 |#1|) $) 59)) (-2365 (((-121) |#1| $) 60)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 36)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 37)) (-2607 (((-1116) $) 21 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 48)) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 38)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 26 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 25 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 24 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 23 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1535 (($) 46) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 45)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 31 (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 28 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 47)) (-3972 (((-856) $) 20 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 39)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-609 |#1| |#2|) (-1290) (-1098) (-1098)) (T -609)) 
-((-2365 (*1 *2 *3 *1) (-12 (-4 *1 (-609 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-121)))) (-2760 (*1 *2 *1) (-12 (-4 *1 (-609 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-638 *3)))) (-1544 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-609 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098)))) (-1750 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-609 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098))))) 
-(-13 (-223 (-2 (|:| -4111 |t#1|) (|:| -4320 |t#2|))) (-10 -8 (-15 -2365 ((-121) |t#1| $)) (-15 -2760 ((-638 |t#1|) $)) (-15 -1544 ((-3 |t#2| "failed") |t#1| $)) (-15 -1750 ((-3 |t#2| "failed") |t#1| $)))) 
-(((-39) . T) ((-111 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-105) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) ((-612 (-856)) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) ((-155 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-613 (-545)) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))) ((-223 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-229 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) -12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-503 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-527 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) -12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-1098) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) ((-1204) . T)) 
-((-2020 (((-611 |#2|) |#1|) 15)) (-2296 (((-3 |#1| "failed") (-611 |#2|)) 19))) 
-(((-610 |#1| |#2|) (-10 -7 (-15 -2020 ((-611 |#2|) |#1|)) (-15 -2296 ((-3 |#1| "failed") (-611 |#2|)))) (-848) (-848)) (T -610)) 
-((-2296 (*1 *2 *3) (|partial| -12 (-5 *3 (-611 *4)) (-4 *4 (-848)) (-4 *2 (-848)) (-5 *1 (-610 *2 *4)))) (-2020 (*1 *2 *3) (-12 (-5 *2 (-611 *4)) (-5 *1 (-610 *3 *4)) (-4 *3 (-848)) (-4 *4 (-848))))) 
-(-10 -7 (-15 -2020 ((-611 |#2|) |#1|)) (-15 -2296 ((-3 |#1| "failed") (-611 |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-1790 (((-3 (-1170) "failed") $) 36)) (-2124 (((-1264) $ (-769)) 26)) (-4014 (((-769) $) 25)) (-4564 (((-123) $) 12)) (-3201 (((-1170) $) 20)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-4496 (($ (-123) (-638 |#1|) (-769)) 30) (($ (-1170)) 31)) (-3291 (((-121) $ (-123)) 18) (((-121) $ (-1170)) 16)) (-1455 (((-769) $) 22)) (-2607 (((-1116) $) NIL)) (-4081 (((-893 (-572)) $) 69 (|has| |#1| (-613 (-893 (-572))))) (((-893 (-385)) $) 75 (|has| |#1| (-613 (-893 (-385))))) (((-545) $) 62 (|has| |#1| (-613 (-545))))) (-3972 (((-856) $) 51)) (-2917 (((-638 |#1|) $) 24)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 39)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 40))) 
-(((-611 |#1|) (-13 (-139) (-885 |#1|) (-10 -8 (-15 -3201 ((-1170) $)) (-15 -4564 ((-123) $)) (-15 -2917 ((-638 |#1|) $)) (-15 -1455 ((-769) $)) (-15 -4496 ($ (-123) (-638 |#1|) (-769))) (-15 -4496 ($ (-1170))) (-15 -1790 ((-3 (-1170) "failed") $)) (-15 -3291 ((-121) $ (-123))) (-15 -3291 ((-121) $ (-1170))) (IF (|has| |#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|))) (-848)) (T -611)) 
-((-3201 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) (-4564 (*1 *2 *1) (-12 (-5 *2 (-123)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) (-2917 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) (-1455 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) (-4496 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-123)) (-5 *3 (-638 *5)) (-5 *4 (-769)) (-4 *5 (-848)) (-5 *1 (-611 *5)))) (-4496 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) (-1790 (*1 *2 *1) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) (-3291 (*1 *2 *1 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-611 *4)) (-4 *4 (-848)))) (-3291 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-121)) (-5 *1 (-611 *4)) (-4 *4 (-848))))) 
-(-13 (-139) (-885 |#1|) (-10 -8 (-15 -3201 ((-1170) $)) (-15 -4564 ((-123) $)) (-15 -2917 ((-638 |#1|) $)) (-15 -1455 ((-769) $)) (-15 -4496 ($ (-123) (-638 |#1|) (-769))) (-15 -4496 ($ (-1170))) (-15 -1790 ((-3 (-1170) "failed") $)) (-15 -3291 ((-121) $ (-123))) (-15 -3291 ((-121) $ (-1170))) (IF (|has| |#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|))) 
-((-3972 ((|#1| $) 6))) 
-(((-612 |#1|) (-1290) (-1204)) (T -612)) 
-((-3972 (*1 *2 *1) (-12 (-4 *1 (-612 *2)) (-4 *2 (-1204))))) 
-(-13 (-10 -8 (-15 -3972 (|t#1| $)))) 
-((-4081 ((|#1| $) 6))) 
-(((-613 |#1|) (-1290) (-1204)) (T -613)) 
-((-4081 (*1 *2 *1) (-12 (-4 *1 (-613 *2)) (-4 *2 (-1204))))) 
-(-13 (-10 -8 (-15 -4081 (|t#1| $)))) 
-((-4296 (((-3 (-1166 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|) (-1 (-424 |#2|) |#2|)) 13) (((-3 (-1166 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|)) 14))) 
-(((-614 |#1| |#2|) (-10 -7 (-15 -4296 ((-3 (-1166 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|))) (-15 -4296 ((-3 (-1166 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|) (-1 (-424 |#2|) |#2|)))) (-13 (-151) (-27) (-1044 (-572)) (-1044 (-413 (-572)))) (-1234 |#1|)) (T -614)) 
-((-4296 (*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-151) (-27) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-1166 (-413 *6))) (-5 *1 (-614 *5 *6)) (-5 *3 (-413 *6)))) (-4296 (*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-151) (-27) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-1166 (-413 *5))) (-5 *1 (-614 *4 *5)) (-5 *3 (-413 *5))))) 
-(-10 -7 (-15 -4296 ((-3 (-1166 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|))) (-15 -4296 ((-3 (-1166 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|) (-1 (-424 |#2|) |#2|)))) 
-((-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) 10))) 
-(((-615 |#1| |#2|) (-10 -8 (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) (-616 |#2|) (-1054)) (T -615)) 
-NIL 
-(-10 -8 (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 35)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ |#1| $) 36))) 
-(((-616 |#1|) (-1290) (-1054)) (T -616)) 
-((-3972 (*1 *1 *2) (-12 (-4 *1 (-616 *2)) (-4 *2 (-1054))))) 
-(-13 (-1054) (-641 |t#1|) (-10 -8 (-15 -3972 ($ |t#1|)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-722) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2433 (((-572) $) NIL (|has| |#1| (-846)))) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-1908 (((-121) $) NIL (|has| |#1| (-846)))) (-3893 (((-121) $) NIL)) (-4487 ((|#1| $) 13)) (-4472 (((-121) $) NIL (|has| |#1| (-846)))) (-1771 (($ $ $) NIL (|has| |#1| (-846)))) (-4238 (($ $ $) NIL (|has| |#1| (-846)))) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4492 ((|#3| $) 15)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) NIL)) (-2140 (((-769)) 20)) (-2264 (($ $) NIL (|has| |#1| (-846)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) 12 T CONST)) (-1349 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1379 (($ $ |#3|) NIL) (($ |#1| |#3|) 11)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 17) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
-(((-617 |#1| |#2| |#3|) (-13 (-43 |#2|) (-10 -8 (IF (|has| |#1| (-846)) (-6 (-846)) |noBranch|) (-15 -1379 ($ $ |#3|)) (-15 -1379 ($ |#1| |#3|)) (-15 -4487 (|#1| $)) (-15 -4492 (|#3| $)))) (-43 |#2|) (-174) (|SubsetCategory| (-722) |#2|)) (T -617)) 
-((-1379 (*1 *1 *1 *2) (-12 (-4 *4 (-174)) (-5 *1 (-617 *3 *4 *2)) (-4 *3 (-43 *4)) (-4 *2 (|SubsetCategory| (-722) *4)))) (-1379 (*1 *1 *2 *3) (-12 (-4 *4 (-174)) (-5 *1 (-617 *2 *4 *3)) (-4 *2 (-43 *4)) (-4 *3 (|SubsetCategory| (-722) *4)))) (-4487 (*1 *2 *1) (-12 (-4 *3 (-174)) (-4 *2 (-43 *3)) (-5 *1 (-617 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-722) *3)))) (-4492 (*1 *2 *1) (-12 (-4 *4 (-174)) (-4 *2 (|SubsetCategory| (-722) *4)) (-5 *1 (-617 *3 *4 *2)) (-4 *3 (-43 *4))))) 
-(-13 (-43 |#2|) (-10 -8 (IF (|has| |#1| (-846)) (-6 (-846)) |noBranch|) (-15 -1379 ($ $ |#3|)) (-15 -1379 ($ |#1| |#3|)) (-15 -4487 (|#1| $)) (-15 -4492 (|#3| $)))) 
-((-3347 ((|#2| |#2| (-1170) (-1170)) 18))) 
-(((-618 |#1| |#2|) (-10 -7 (-15 -3347 (|#2| |#2| (-1170) (-1170)))) (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572))) (-13 (-1190) (-966) (-29 |#1|))) (T -618)) 
-((-3347 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-618 *4 *2)) (-4 *2 (-13 (-1190) (-966) (-29 *4)))))) 
-(-10 -7 (-15 -3347 (|#2| |#2| (-1170) (-1170)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 52)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-3226 ((|#1| $) 49)) (-1572 (((-3 $ "failed") $ $) NIL)) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-2012 (((-2 (|:| -2701 $) (|:| -2146 (-413 |#2|))) (-413 |#2|)) 95 (|has| |#1| (-368)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 83) (((-3 |#2| "failed") $) 80)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL) ((|#2| $) NIL)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) 24)) (-1799 (((-3 $ "failed") $) 74)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-3377 (((-572) $) 19)) (-3893 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) 36)) (-4328 (($ |#1| (-572)) 21)) (-4373 ((|#1| $) 51)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) 85 (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 98 (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1803 (((-3 $ "failed") $ $) 78)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4029 (((-769) $) 97 (|has| |#1| (-368)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 96 (|has| |#1| (-368)))) (-3139 (($ $ (-1 |#2| |#2|)) 65) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-769)) NIL (|has| |#2| (-227))) (($ $) NIL (|has| |#2| (-227)))) (-4316 (((-572) $) 34)) (-4081 (((-413 |#2|) $) 42)) (-3972 (((-856) $) 61) (($ (-572)) 32) (($ $) NIL) (($ (-413 (-572))) NIL (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) 31) (($ |#2|) 22)) (-1958 ((|#1| $ (-572)) 62)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) 29)) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 9 T CONST)) (-3255 (($) 12 T CONST)) (-1557 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-769)) NIL (|has| |#2| (-227))) (($ $) NIL (|has| |#2| (-227)))) (-1324 (((-121) $ $) 17)) (-1373 (($ $) 46) (($ $ $) NIL)) (-1367 (($ $ $) 75)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 26) (($ $ $) 44))) 
-(((-619 |#1| |#2|) (-13 (-225 |#2|) (-562) (-613 (-413 |#2|)) (-417 |#1|) (-1044 |#2|) (-10 -8 (-15 -4581 ((-121) $)) (-15 -4316 ((-572) $)) (-15 -3377 ((-572) $)) (-15 -4383 ($ $)) (-15 -4373 (|#1| $)) (-15 -3226 (|#1| $)) (-15 -1958 (|#1| $ (-572))) (-15 -4328 ($ |#1| (-572))) (IF (|has| |#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-6 (-303)) (-15 -2012 ((-2 (|:| -2701 $) (|:| -2146 (-413 |#2|))) (-413 |#2|)))) |noBranch|))) (-562) (-1234 |#1|)) (T -619)) 
-((-4581 (*1 *2 *1) (-12 (-4 *3 (-562)) (-5 *2 (-121)) (-5 *1 (-619 *3 *4)) (-4 *4 (-1234 *3)))) (-4316 (*1 *2 *1) (-12 (-4 *3 (-562)) (-5 *2 (-572)) (-5 *1 (-619 *3 *4)) (-4 *4 (-1234 *3)))) (-3377 (*1 *2 *1) (-12 (-4 *3 (-562)) (-5 *2 (-572)) (-5 *1 (-619 *3 *4)) (-4 *4 (-1234 *3)))) (-4383 (*1 *1 *1) (-12 (-4 *2 (-562)) (-5 *1 (-619 *2 *3)) (-4 *3 (-1234 *2)))) (-4373 (*1 *2 *1) (-12 (-4 *2 (-562)) (-5 *1 (-619 *2 *3)) (-4 *3 (-1234 *2)))) (-3226 (*1 *2 *1) (-12 (-4 *2 (-562)) (-5 *1 (-619 *2 *3)) (-4 *3 (-1234 *2)))) (-1958 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *2 (-562)) (-5 *1 (-619 *2 *4)) (-4 *4 (-1234 *2)))) (-4328 (*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-4 *2 (-562)) (-5 *1 (-619 *2 *4)) (-4 *4 (-1234 *2)))) (-2012 (*1 *2 *3) (-12 (-4 *4 (-368)) (-4 *4 (-562)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -2701 (-619 *4 *5)) (|:| -2146 (-413 *5)))) (-5 *1 (-619 *4 *5)) (-5 *3 (-413 *5))))) 
-(-13 (-225 |#2|) (-562) (-613 (-413 |#2|)) (-417 |#1|) (-1044 |#2|) (-10 -8 (-15 -4581 ((-121) $)) (-15 -4316 ((-572) $)) (-15 -3377 ((-572) $)) (-15 -4383 ($ $)) (-15 -4373 (|#1| $)) (-15 -3226 (|#1| $)) (-15 -1958 (|#1| $ (-572))) (-15 -4328 ($ |#1| (-572))) (IF (|has| |#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-6 (-303)) (-15 -2012 ((-2 (|:| -2701 $) (|:| -2146 (-413 |#2|))) (-413 |#2|)))) |noBranch|))) 
-((-4165 (((-638 |#6|) (-638 |#4|) (-121)) 46)) (-2968 ((|#6| |#6|) 39))) 
-(((-620 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2968 (|#6| |#6|)) (-15 -4165 ((-638 |#6|) (-638 |#4|) (-121)))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1073 |#1| |#2| |#3| |#4|) (-1107 |#1| |#2| |#3| |#4|)) (T -620)) 
-((-4165 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 *10)) (-5 *1 (-620 *5 *6 *7 *8 *9 *10)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *10 (-1107 *5 *6 *7 *8)))) (-2968 (*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-620 *3 *4 *5 *6 *7 *2)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *2 (-1107 *3 *4 *5 *6))))) 
-(-10 -7 (-15 -2968 (|#6| |#6|)) (-15 -4165 ((-638 |#6|) (-638 |#4|) (-121)))) 
-((-1375 (((-121) |#3| (-769) (-638 |#3|)) 22)) (-3505 (((-3 (-2 (|:| |polfac| (-638 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-638 (-1166 |#3|)))) "failed") |#3| (-638 (-1166 |#3|)) (-2 (|:| |contp| |#3|) (|:| -4547 (-638 (-2 (|:| |irr| |#4|) (|:| -3341 (-572)))))) (-638 |#3|) (-638 |#1|) (-638 |#3|)) 51))) 
-(((-621 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1375 ((-121) |#3| (-769) (-638 |#3|))) (-15 -3505 ((-3 (-2 (|:| |polfac| (-638 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-638 (-1166 |#3|)))) "failed") |#3| (-638 (-1166 |#3|)) (-2 (|:| |contp| |#3|) (|:| -4547 (-638 (-2 (|:| |irr| |#4|) (|:| -3341 (-572)))))) (-638 |#3|) (-638 |#1|) (-638 |#3|)))) (-848) (-794) (-303) (-956 |#3| |#2| |#1|)) (T -621)) 
-((-3505 (*1 *2 *3 *4 *5 *6 *7 *6) (|partial| -12 (-5 *5 (-2 (|:| |contp| *3) (|:| -4547 (-638 (-2 (|:| |irr| *10) (|:| -3341 (-572))))))) (-5 *6 (-638 *3)) (-5 *7 (-638 *8)) (-4 *8 (-848)) (-4 *3 (-303)) (-4 *10 (-956 *3 *9 *8)) (-4 *9 (-794)) (-5 *2 (-2 (|:| |polfac| (-638 *10)) (|:| |correct| *3) (|:| |corrfact| (-638 (-1166 *3))))) (-5 *1 (-621 *8 *9 *3 *10)) (-5 *4 (-638 (-1166 *3))))) (-1375 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-769)) (-5 *5 (-638 *3)) (-4 *3 (-303)) (-4 *6 (-848)) (-4 *7 (-794)) (-5 *2 (-121)) (-5 *1 (-621 *6 *7 *3 *8)) (-4 *8 (-956 *3 *7 *6))))) 
-(-10 -7 (-15 -1375 ((-121) |#3| (-769) (-638 |#3|))) (-15 -3505 ((-3 (-2 (|:| |polfac| (-638 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-638 (-1166 |#3|)))) "failed") |#3| (-638 (-1166 |#3|)) (-2 (|:| |contp| |#3|) (|:| -4547 (-638 (-2 (|:| |irr| |#4|) (|:| -3341 (-572)))))) (-638 |#3|) (-638 |#1|) (-638 |#3|)))) 
-((-2262 (((-121) $ $) NIL)) (-2199 (((-638 |#1|) $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-4076 (($ $) 67)) (-3539 (((-660 |#1| |#2|) $) 52)) (-2081 (((-638 (-2 (|:| |k| (-894 |#1|)) (|:| |c| |#2|))) $) 36)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 70)) (-3159 (((-638 (-290 |#2|)) $ $) 33)) (-2607 (((-1116) $) NIL)) (-4179 (($ (-660 |#1| |#2|)) 48)) (-3018 (($ $ $) NIL)) (-4056 (($ $ $) NIL)) (-3972 (((-856) $) 58) (((-1272 |#1| |#2|) $) NIL) (((-1277 |#1| |#2|) $) 66)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-3255 (($) 53 T CONST)) (-2137 (((-638 (-2 (|:| |k| (-667 |#1|)) (|:| |c| |#2|))) $) 31)) (-2305 (((-638 (-660 |#1| |#2|)) (-638 |#1|)) 65)) (-1324 (((-121) $ $) 54)) (-1379 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ $ $) 44))) 
-(((-622 |#1| |#2| |#3|) (-13 (-482) (-10 -8 (-15 -4179 ($ (-660 |#1| |#2|))) (-15 -3539 ((-660 |#1| |#2|) $)) (-15 -2081 ((-638 (-2 (|:| |k| (-894 |#1|)) (|:| |c| |#2|))) $)) (-15 -3972 ((-1272 |#1| |#2|) $)) (-15 -3972 ((-1277 |#1| |#2|) $)) (-15 -4076 ($ $)) (-15 -2199 ((-638 |#1|) $)) (-15 -2305 ((-638 (-660 |#1| |#2|)) (-638 |#1|))) (-15 -2137 ((-638 (-2 (|:| |k| (-667 |#1|)) (|:| |c| |#2|))) $)) (-15 -3159 ((-638 (-290 |#2|)) $ $)))) (-848) (-13 (-174) (-713 (-413 (-572)))) (-923)) (T -622)) 
-((-4179 (*1 *1 *2) (-12 (-5 *2 (-660 *3 *4)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-5 *1 (-622 *3 *4 *5)) (-14 *5 (-923)))) (-3539 (*1 *2 *1) (-12 (-5 *2 (-660 *3 *4)) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) (-2081 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |k| (-894 *3)) (|:| |c| *4)))) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1272 *3 *4)) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1277 *3 *4)) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) (-4076 (*1 *1 *1) (-12 (-5 *1 (-622 *2 *3 *4)) (-4 *2 (-848)) (-4 *3 (-13 (-174) (-713 (-413 (-572))))) (-14 *4 (-923)))) (-2199 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) (-2305 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-848)) (-5 *2 (-638 (-660 *4 *5))) (-5 *1 (-622 *4 *5 *6)) (-4 *5 (-13 (-174) (-713 (-413 (-572))))) (-14 *6 (-923)))) (-2137 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |k| (-667 *3)) (|:| |c| *4)))) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) (-3159 (*1 *2 *1 *1) (-12 (-5 *2 (-638 (-290 *4))) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923))))) 
-(-13 (-482) (-10 -8 (-15 -4179 ($ (-660 |#1| |#2|))) (-15 -3539 ((-660 |#1| |#2|) $)) (-15 -2081 ((-638 (-2 (|:| |k| (-894 |#1|)) (|:| |c| |#2|))) $)) (-15 -3972 ((-1272 |#1| |#2|) $)) (-15 -3972 ((-1277 |#1| |#2|) $)) (-15 -4076 ($ $)) (-15 -2199 ((-638 |#1|) $)) (-15 -2305 ((-638 (-660 |#1| |#2|)) (-638 |#1|))) (-15 -2137 ((-638 (-2 (|:| |k| (-667 |#1|)) (|:| |c| |#2|))) $)) (-15 -3159 ((-638 (-290 |#2|)) $ $)))) 
-((-4165 (((-638 (-1139 |#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|)))) (-638 (-781 |#1| (-858 |#2|))) (-121)) 70) (((-638 (-1051 |#1| |#2|)) (-638 (-781 |#1| (-858 |#2|))) (-121)) 56)) (-2414 (((-121) (-638 (-781 |#1| (-858 |#2|)))) 22)) (-3416 (((-638 (-1139 |#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|)))) (-638 (-781 |#1| (-858 |#2|))) (-121)) 69)) (-4356 (((-638 (-1051 |#1| |#2|)) (-638 (-781 |#1| (-858 |#2|))) (-121)) 55)) (-3604 (((-638 (-781 |#1| (-858 |#2|))) (-638 (-781 |#1| (-858 |#2|)))) 26)) (-1623 (((-3 (-638 (-781 |#1| (-858 |#2|))) "failed") (-638 (-781 |#1| (-858 |#2|)))) 25))) 
-(((-623 |#1| |#2|) (-10 -7 (-15 -2414 ((-121) (-638 (-781 |#1| (-858 |#2|))))) (-15 -1623 ((-3 (-638 (-781 |#1| (-858 |#2|))) "failed") (-638 (-781 |#1| (-858 |#2|))))) (-15 -3604 ((-638 (-781 |#1| (-858 |#2|))) (-638 (-781 |#1| (-858 |#2|))))) (-15 -4356 ((-638 (-1051 |#1| |#2|)) (-638 (-781 |#1| (-858 |#2|))) (-121))) (-15 -3416 ((-638 (-1139 |#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|)))) (-638 (-781 |#1| (-858 |#2|))) (-121))) (-15 -4165 ((-638 (-1051 |#1| |#2|)) (-638 (-781 |#1| (-858 |#2|))) (-121))) (-15 -4165 ((-638 (-1139 |#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|)))) (-638 (-781 |#1| (-858 |#2|))) (-121)))) (-457) (-638 (-1170))) (T -623)) 
-((-4165 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1139 *5 (-538 (-858 *6)) (-858 *6) (-781 *5 (-858 *6))))) (-5 *1 (-623 *5 *6)))) (-4165 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-623 *5 *6)))) (-3416 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1139 *5 (-538 (-858 *6)) (-858 *6) (-781 *5 (-858 *6))))) (-5 *1 (-623 *5 *6)))) (-4356 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-623 *5 *6)))) (-3604 (*1 *2 *2) (-12 (-5 *2 (-638 (-781 *3 (-858 *4)))) (-4 *3 (-457)) (-14 *4 (-638 (-1170))) (-5 *1 (-623 *3 *4)))) (-1623 (*1 *2 *2) (|partial| -12 (-5 *2 (-638 (-781 *3 (-858 *4)))) (-4 *3 (-457)) (-14 *4 (-638 (-1170))) (-5 *1 (-623 *3 *4)))) (-2414 (*1 *2 *3) (-12 (-5 *3 (-638 (-781 *4 (-858 *5)))) (-4 *4 (-457)) (-14 *5 (-638 (-1170))) (-5 *2 (-121)) (-5 *1 (-623 *4 *5))))) 
-(-10 -7 (-15 -2414 ((-121) (-638 (-781 |#1| (-858 |#2|))))) (-15 -1623 ((-3 (-638 (-781 |#1| (-858 |#2|))) "failed") (-638 (-781 |#1| (-858 |#2|))))) (-15 -3604 ((-638 (-781 |#1| (-858 |#2|))) (-638 (-781 |#1| (-858 |#2|))))) (-15 -4356 ((-638 (-1051 |#1| |#2|)) (-638 (-781 |#1| (-858 |#2|))) (-121))) (-15 -3416 ((-638 (-1139 |#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|)))) (-638 (-781 |#1| (-858 |#2|))) (-121))) (-15 -4165 ((-638 (-1051 |#1| |#2|)) (-638 (-781 |#1| (-858 |#2|))) (-121))) (-15 -4165 ((-638 (-1139 |#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|)))) (-638 (-781 |#1| (-858 |#2|))) (-121)))) 
-((-4284 (($ $) 38)) (-4224 (($ $) 21)) (-4273 (($ $) 37)) (-4217 (($ $) 22)) (-4295 (($ $) 36)) (-4233 (($ $) 23)) (-4184 (($) 48)) (-3539 (($ $) 45)) (-4198 (($ $) 17)) (-4282 (($ $ (-1090 $)) 7) (($ $ (-1170)) 6)) (-2650 (($ $) 14)) (-1327 (($ $) 13)) (-4179 (($ $) 46)) (-4203 (($ $) 15)) (-4213 (($ $) 16)) (-4302 (($ $) 35)) (-4237 (($ $) 24)) (-4289 (($ $) 34)) (-4228 (($ $) 25)) (-4278 (($ $) 33)) (-4220 (($ $) 26)) (-4321 (($ $) 44)) (-4251 (($ $) 32)) (-4308 (($ $) 43)) (-4241 (($ $) 31)) (-4333 (($ $) 42)) (-4263 (($ $) 30)) (-2104 (($ $) 41)) (-4268 (($ $) 29)) (-4327 (($ $) 40)) (-4257 (($ $) 28)) (-4314 (($ $) 39)) (-4246 (($ $) 27)) (-2856 (($ $) 19)) (-1622 (($ $) 20)) (-3481 (($ $) 18)) (** (($ $ $) 47))) 
-(((-624) (-1290)) (T -624)) 
-((-1622 (*1 *1 *1) (-4 *1 (-624))) (-2856 (*1 *1 *1) (-4 *1 (-624))) (-3481 (*1 *1 *1) (-4 *1 (-624))) (-4198 (*1 *1 *1) (-4 *1 (-624))) (-4213 (*1 *1 *1) (-4 *1 (-624))) (-4203 (*1 *1 *1) (-4 *1 (-624))) (-2650 (*1 *1 *1) (-4 *1 (-624))) (-1327 (*1 *1 *1) (-4 *1 (-624)))) 
-(-13 (-966) (-1190) (-10 -8 (-15 -1622 ($ $)) (-15 -2856 ($ $)) (-15 -3481 ($ $)) (-15 -4198 ($ $)) (-15 -4213 ($ $)) (-15 -4203 ($ $)) (-15 -2650 ($ $)) (-15 -1327 ($ $)))) 
-(((-40) . T) ((-98) . T) ((-281) . T) ((-506) . T) ((-966) . T) ((-1190) . T) ((-1193) . T)) 
-((-4564 (((-123) (-123)) 87)) (-4198 ((|#2| |#2|) 32)) (-4282 ((|#2| |#2| (-1090 |#2|)) 83) ((|#2| |#2| (-1170)) 56)) (-2650 ((|#2| |#2|) 34)) (-1327 ((|#2| |#2|) 35)) (-4203 ((|#2| |#2|) 31)) (-4213 ((|#2| |#2|) 33)) (-3228 (((-121) (-123)) 38)) (-2856 ((|#2| |#2|) 28)) (-1622 ((|#2| |#2|) 30)) (-3481 ((|#2| |#2|) 29))) 
-(((-625 |#1| |#2|) (-10 -7 (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -1622 (|#2| |#2|)) (-15 -2856 (|#2| |#2|)) (-15 -3481 (|#2| |#2|)) (-15 -4198 (|#2| |#2|)) (-15 -4203 (|#2| |#2|)) (-15 -4213 (|#2| |#2|)) (-15 -2650 (|#2| |#2|)) (-15 -1327 (|#2| |#2|)) (-15 -4282 (|#2| |#2| (-1170))) (-15 -4282 (|#2| |#2| (-1090 |#2|)))) (-13 (-848) (-562)) (-13 (-436 |#1|) (-1009) (-1190))) (T -625)) 
-((-4282 (*1 *2 *2 *3) (-12 (-5 *3 (-1090 *2)) (-4 *2 (-13 (-436 *4) (-1009) (-1190))) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-625 *4 *2)))) (-4282 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-625 *4 *2)) (-4 *2 (-13 (-436 *4) (-1009) (-1190))))) (-1327 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190))))) (-2650 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190))))) (-4213 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190))))) (-4203 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190))))) (-4198 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190))))) (-3481 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190))))) (-2856 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190))))) (-1622 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190))))) (-4564 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *4)) (-4 *4 (-13 (-436 *3) (-1009) (-1190))))) (-3228 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-625 *4 *5)) (-4 *5 (-13 (-436 *4) (-1009) (-1190)))))) 
-(-10 -7 (-15 -3228 ((-121) (-123))) (-15 -4564 ((-123) (-123))) (-15 -1622 (|#2| |#2|)) (-15 -2856 (|#2| |#2|)) (-15 -3481 (|#2| |#2|)) (-15 -4198 (|#2| |#2|)) (-15 -4203 (|#2| |#2|)) (-15 -4213 (|#2| |#2|)) (-15 -2650 (|#2| |#2|)) (-15 -1327 (|#2| |#2|)) (-15 -4282 (|#2| |#2| (-1170))) (-15 -4282 (|#2| |#2| (-1090 |#2|)))) 
-((-1341 (((-496 |#1| |#2|) (-244 |#1| |#2|)) 52)) (-1609 (((-638 (-244 |#1| |#2|)) (-638 (-496 |#1| |#2|))) 67)) (-3960 (((-496 |#1| |#2|) (-638 (-496 |#1| |#2|)) (-858 |#1|)) 69) (((-496 |#1| |#2|) (-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|)) (-858 |#1|)) 68)) (-4288 (((-2 (|:| |gblist| (-638 (-244 |#1| |#2|))) (|:| |gvlist| (-638 (-572)))) (-638 (-496 |#1| |#2|))) 105)) (-1462 (((-638 (-496 |#1| |#2|)) (-858 |#1|) (-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|))) 82)) (-3208 (((-2 (|:| |glbase| (-638 (-244 |#1| |#2|))) (|:| |glval| (-638 (-572)))) (-638 (-244 |#1| |#2|))) 116)) (-2720 (((-1259 |#2|) (-496 |#1| |#2|) (-638 (-496 |#1| |#2|))) 57)) (-2317 (((-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|))) 39)) (-1553 (((-244 |#1| |#2|) (-244 |#1| |#2|) (-638 (-244 |#1| |#2|))) 49)) (-1975 (((-244 |#1| |#2|) (-638 |#2|) (-244 |#1| |#2|) (-638 (-244 |#1| |#2|))) 89))) 
-(((-626 |#1| |#2|) (-10 -7 (-15 -4288 ((-2 (|:| |gblist| (-638 (-244 |#1| |#2|))) (|:| |gvlist| (-638 (-572)))) (-638 (-496 |#1| |#2|)))) (-15 -3208 ((-2 (|:| |glbase| (-638 (-244 |#1| |#2|))) (|:| |glval| (-638 (-572)))) (-638 (-244 |#1| |#2|)))) (-15 -1609 ((-638 (-244 |#1| |#2|)) (-638 (-496 |#1| |#2|)))) (-15 -3960 ((-496 |#1| |#2|) (-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|)) (-858 |#1|))) (-15 -3960 ((-496 |#1| |#2|) (-638 (-496 |#1| |#2|)) (-858 |#1|))) (-15 -2317 ((-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|)))) (-15 -2720 ((-1259 |#2|) (-496 |#1| |#2|) (-638 (-496 |#1| |#2|)))) (-15 -1975 ((-244 |#1| |#2|) (-638 |#2|) (-244 |#1| |#2|) (-638 (-244 |#1| |#2|)))) (-15 -1462 ((-638 (-496 |#1| |#2|)) (-858 |#1|) (-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|)))) (-15 -1553 ((-244 |#1| |#2|) (-244 |#1| |#2|) (-638 (-244 |#1| |#2|)))) (-15 -1341 ((-496 |#1| |#2|) (-244 |#1| |#2|)))) (-638 (-1170)) (-457)) (T -626)) 
-((-1341 (*1 *2 *3) (-12 (-5 *3 (-244 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *2 (-496 *4 *5)) (-5 *1 (-626 *4 *5)))) (-1553 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-244 *4 *5))) (-5 *2 (-244 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *1 (-626 *4 *5)))) (-1462 (*1 *2 *3 *2 *2) (-12 (-5 *2 (-638 (-496 *4 *5))) (-5 *3 (-858 *4)) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *1 (-626 *4 *5)))) (-1975 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-638 (-244 *5 *6))) (-4 *6 (-457)) (-5 *2 (-244 *5 *6)) (-14 *5 (-638 (-1170))) (-5 *1 (-626 *5 *6)))) (-2720 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-496 *5 *6))) (-5 *3 (-496 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-457)) (-5 *2 (-1259 *6)) (-5 *1 (-626 *5 *6)))) (-2317 (*1 *2 *2) (-12 (-5 *2 (-638 (-496 *3 *4))) (-14 *3 (-638 (-1170))) (-4 *4 (-457)) (-5 *1 (-626 *3 *4)))) (-3960 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-496 *5 *6))) (-5 *4 (-858 *5)) (-14 *5 (-638 (-1170))) (-5 *2 (-496 *5 *6)) (-5 *1 (-626 *5 *6)) (-4 *6 (-457)))) (-3960 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 (-496 *5 *6))) (-5 *4 (-858 *5)) (-14 *5 (-638 (-1170))) (-5 *2 (-496 *5 *6)) (-5 *1 (-626 *5 *6)) (-4 *6 (-457)))) (-1609 (*1 *2 *3) (-12 (-5 *3 (-638 (-496 *4 *5))) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *2 (-638 (-244 *4 *5))) (-5 *1 (-626 *4 *5)))) (-3208 (*1 *2 *3) (-12 (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *2 (-2 (|:| |glbase| (-638 (-244 *4 *5))) (|:| |glval| (-638 (-572))))) (-5 *1 (-626 *4 *5)) (-5 *3 (-638 (-244 *4 *5))))) (-4288 (*1 *2 *3) (-12 (-5 *3 (-638 (-496 *4 *5))) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *2 (-2 (|:| |gblist| (-638 (-244 *4 *5))) (|:| |gvlist| (-638 (-572))))) (-5 *1 (-626 *4 *5))))) 
-(-10 -7 (-15 -4288 ((-2 (|:| |gblist| (-638 (-244 |#1| |#2|))) (|:| |gvlist| (-638 (-572)))) (-638 (-496 |#1| |#2|)))) (-15 -3208 ((-2 (|:| |glbase| (-638 (-244 |#1| |#2|))) (|:| |glval| (-638 (-572)))) (-638 (-244 |#1| |#2|)))) (-15 -1609 ((-638 (-244 |#1| |#2|)) (-638 (-496 |#1| |#2|)))) (-15 -3960 ((-496 |#1| |#2|) (-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|)) (-858 |#1|))) (-15 -3960 ((-496 |#1| |#2|) (-638 (-496 |#1| |#2|)) (-858 |#1|))) (-15 -2317 ((-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|)))) (-15 -2720 ((-1259 |#2|) (-496 |#1| |#2|) (-638 (-496 |#1| |#2|)))) (-15 -1975 ((-244 |#1| |#2|) (-638 |#2|) (-244 |#1| |#2|) (-638 (-244 |#1| |#2|)))) (-15 -1462 ((-638 (-496 |#1| |#2|)) (-858 |#1|) (-638 (-496 |#1| |#2|)) (-638 (-496 |#1| |#2|)))) (-15 -1553 ((-244 |#1| |#2|) (-244 |#1| |#2|) (-638 (-244 |#1| |#2|)))) (-15 -1341 ((-496 |#1| |#2|) (-244 |#1| |#2|)))) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) NIL)) (-2430 (((-1264) $ (-1152) (-1152)) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-57) $ (-1152) (-57)) 16) (((-57) $ (-1170) (-57)) 17)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 (-57) "failed") (-1152) $) NIL)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098))))) (-1544 (($ (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-3 (-57) "failed") (-1152) $) NIL)) (-3445 (($ (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $ (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098)))) (((-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $ (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-57) $ (-1152) (-57)) NIL (|has| $ (-6 -4603)))) (-4212 (((-57) $ (-1152)) NIL)) (-2010 (((-638 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-638 (-57)) $) NIL (|has| $ (-6 -4602)))) (-1652 (($ $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-1152) $) NIL (|has| (-1152) (-848)))) (-4467 (((-638 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-638 (-57)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098))))) (-2026 (((-1152) $) NIL (|has| (-1152) (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4603))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-4159 (($ (-394)) 9)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098))))) (-2760 (((-638 (-1152)) $) NIL)) (-2365 (((-121) (-1152) $) NIL)) (-4221 (((-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) $) NIL)) (-1335 (($ (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) $) NIL)) (-2739 (((-638 (-1152)) $) NIL)) (-1601 (((-121) (-1152) $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098))))) (-1837 (((-57) $) NIL (|has| (-1152) (-848)))) (-3361 (((-3 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) "failed") (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL)) (-3299 (($ $ (-57)) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098)))) (($ $ (-290 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098)))) (($ $ (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098)))) (($ $ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098)))) (($ $ (-638 (-57)) (-638 (-57))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-290 (-57))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-638 (-290 (-57)))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098))))) (-2957 (((-638 (-57)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 (((-57) $ (-1152)) 14) (((-57) $ (-1152) (-57)) NIL) (((-57) $ (-1170)) 15)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098)))) (((-769) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098)))) (((-769) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098))))) (-1391 (($ $) NIL)) (-3058 (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 (-57))) (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-627) (-13 (-1181 (-1152) (-57)) (-10 -8 (-15 -4159 ($ (-394))) (-15 -1652 ($ $)) (-15 -3277 ((-57) $ (-1170))) (-15 -3283 ((-57) $ (-1170) (-57))) (-15 -1391 ($ $))))) (T -627)) 
-((-4159 (*1 *1 *2) (-12 (-5 *2 (-394)) (-5 *1 (-627)))) (-1652 (*1 *1 *1) (-5 *1 (-627))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-57)) (-5 *1 (-627)))) (-3283 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-57)) (-5 *3 (-1170)) (-5 *1 (-627)))) (-1391 (*1 *1 *1) (-5 *1 (-627)))) 
-(-13 (-1181 (-1152) (-57)) (-10 -8 (-15 -4159 ($ (-394))) (-15 -1652 ($ $)) (-15 -3277 ((-57) $ (-1170))) (-15 -3283 ((-57) $ (-1170) (-57))) (-15 -1391 ($ $)))) 
-((-1379 (($ $ |#2|) 10))) 
-(((-628 |#1| |#2|) (-10 -8 (-15 -1379 (|#1| |#1| |#2|))) (-629 |#2|) (-174)) (T -628)) 
-NIL 
-(-10 -8 (-15 -1379 (|#1| |#1| |#2|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3921 (($ $ $) 26)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 25 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
-(((-629 |#1|) (-1290) (-174)) (T -629)) 
-((-3921 (*1 *1 *1 *1) (-12 (-4 *1 (-629 *2)) (-4 *2 (-174)))) (-1379 (*1 *1 *1 *2) (-12 (-4 *1 (-629 *2)) (-4 *2 (-174)) (-4 *2 (-368))))) 
-(-13 (-713 |t#1|) (-10 -8 (-15 -3921 ($ $ $)) (-6 |NullSquare|) (-6 |JacobiIdentity|) (IF (|has| |t#1| (-368)) (-15 -1379 ($ $ |t#1|)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-713 |#1|) . T) ((-1060 |#1|) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3029 (((-3 $ "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-1354 (((-1259 (-685 |#1|))) NIL (|has| |#2| (-423 |#1|))) (((-1259 (-685 |#1|)) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-2167 (((-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-2211 (($) NIL T CONST)) (-4511 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2095 (((-3 $ "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2882 (((-685 |#1|)) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-3487 ((|#1| $) NIL (|has| |#2| (-372 |#1|)))) (-3700 (((-685 |#1|) $) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) $ (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-2848 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-4535 (((-1166 (-959 |#1|))) NIL (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-368))))) (-3014 (($ $ (-923)) NIL)) (-3588 ((|#1| $) NIL (|has| |#2| (-372 |#1|)))) (-2135 (((-1166 |#1|) $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-4146 ((|#1|) NIL (|has| |#2| (-423 |#1|))) ((|#1| (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-1593 (((-1166 |#1|) $) NIL (|has| |#2| (-372 |#1|)))) (-2048 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-4337 (($ (-1259 |#1|)) NIL (|has| |#2| (-423 |#1|))) (($ (-1259 |#1|) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-1799 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2667 (((-923)) NIL (|has| |#2| (-372 |#1|)))) (-4160 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2027 (($ $ (-923)) NIL)) (-1814 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2209 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1648 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1903 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2036 (((-3 $ "failed")) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-1663 (((-685 |#1|)) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-3550 ((|#1| $) NIL (|has| |#2| (-372 |#1|)))) (-3343 (((-685 |#1|) $) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) $ (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-2046 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2339 (((-1166 (-959 |#1|))) NIL (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-368))))) (-3276 (($ $ (-923)) NIL)) (-2340 ((|#1| $) NIL (|has| |#2| (-372 |#1|)))) (-3665 (((-1166 |#1|) $) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-2110 ((|#1|) NIL (|has| |#2| (-423 |#1|))) ((|#1| (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-1989 (((-1166 |#1|) $) NIL (|has| |#2| (-372 |#1|)))) (-3602 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1658 (((-1152) $) NIL)) (-4219 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2395 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-3046 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2607 (((-1116) $) NIL)) (-4128 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-3277 ((|#1| $ (-572)) NIL (|has| |#2| (-423 |#1|)))) (-3160 (((-685 |#1|) (-1259 $)) NIL (|has| |#2| (-423 |#1|))) (((-1259 |#1|) $) NIL (|has| |#2| (-423 |#1|))) (((-685 |#1|) (-1259 $) (-1259 $)) NIL (|has| |#2| (-372 |#1|))) (((-1259 |#1|) $ (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-4081 (($ (-1259 |#1|)) NIL (|has| |#2| (-423 |#1|))) (((-1259 |#1|) $) NIL (|has| |#2| (-423 |#1|)))) (-3188 (((-638 (-959 |#1|))) NIL (|has| |#2| (-423 |#1|))) (((-638 (-959 |#1|)) (-1259 $)) NIL (|has| |#2| (-372 |#1|)))) (-4056 (($ $ $) NIL)) (-2073 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-3972 (((-856) $) NIL) ((|#2| $) 12) (($ |#2|) 13)) (-2237 (((-1259 $)) NIL (|has| |#2| (-423 |#1|)))) (-4414 (((-638 (-1259 |#1|))) NIL (-1841 (-12 (|has| |#2| (-372 |#1|)) (|has| |#1| (-562))) (-12 (|has| |#2| (-423 |#1|)) (|has| |#1| (-562)))))) (-4250 (($ $ $ $) NIL)) (-2928 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1591 (($ (-685 |#1|) $) NIL (|has| |#2| (-423 |#1|)))) (-1397 (($ $ $) NIL)) (-2773 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2756 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-1447 (((-121)) NIL (|has| |#2| (-372 |#1|)))) (-2378 (($) 15 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) 17)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 11) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-630 |#1| |#2|) (-13 (-742 |#1|) (-612 |#2|) (-10 -8 (-15 -3972 ($ |#2|)) (IF (|has| |#2| (-423 |#1|)) (-6 (-423 |#1|)) |noBranch|) (IF (|has| |#2| (-372 |#1|)) (-6 (-372 |#1|)) |noBranch|))) (-174) (-742 |#1|)) (T -630)) 
-((-3972 (*1 *1 *2) (-12 (-4 *3 (-174)) (-5 *1 (-630 *3 *2)) (-4 *2 (-742 *3))))) 
-(-13 (-742 |#1|) (-612 |#2|) (-10 -8 (-15 -3972 ($ |#2|)) (IF (|has| |#2| (-423 |#1|)) (-6 (-423 |#1|)) |noBranch|) (IF (|has| |#2| (-372 |#1|)) (-6 (-372 |#1|)) |noBranch|))) 
-((-2506 (((-3 (-841 |#2|) "failed") |#2| (-290 |#2|) (-1152)) 78) (((-3 (-841 |#2|) (-2 (|:| |leftHandLimit| (-3 (-841 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-841 |#2|) "failed"))) "failed") |#2| (-290 (-841 |#2|))) 100)) (-2439 (((-3 (-834 |#2|) "failed") |#2| (-290 (-834 |#2|))) 105))) 
-(((-631 |#1| |#2|) (-10 -7 (-15 -2506 ((-3 (-841 |#2|) (-2 (|:| |leftHandLimit| (-3 (-841 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-841 |#2|) "failed"))) "failed") |#2| (-290 (-841 |#2|)))) (-15 -2439 ((-3 (-834 |#2|) "failed") |#2| (-290 (-834 |#2|)))) (-15 -2506 ((-3 (-841 |#2|) "failed") |#2| (-290 |#2|) (-1152)))) (-13 (-457) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|))) (T -631)) 
-((-2506 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-290 *3)) (-5 *5 (-1152)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-841 *3)) (-5 *1 (-631 *6 *3)))) (-2439 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-290 (-834 *3))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-834 *3)) (-5 *1 (-631 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) (-2506 (*1 *2 *3 *4) (-12 (-5 *4 (-290 (-841 *3))) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (-841 *3) (-2 (|:| |leftHandLimit| (-3 (-841 *3) "failed")) (|:| |rightHandLimit| (-3 (-841 *3) "failed"))) "failed")) (-5 *1 (-631 *5 *3))))) 
-(-10 -7 (-15 -2506 ((-3 (-841 |#2|) (-2 (|:| |leftHandLimit| (-3 (-841 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-841 |#2|) "failed"))) "failed") |#2| (-290 (-841 |#2|)))) (-15 -2439 ((-3 (-834 |#2|) "failed") |#2| (-290 (-834 |#2|)))) (-15 -2506 ((-3 (-841 |#2|) "failed") |#2| (-290 |#2|) (-1152)))) 
-((-2506 (((-3 (-841 (-413 (-959 |#1|))) "failed") (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))) (-1152)) 79) (((-3 (-841 (-413 (-959 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed"))) "failed") (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|)))) 18) (((-3 (-841 (-413 (-959 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed"))) "failed") (-413 (-959 |#1|)) (-290 (-841 (-959 |#1|)))) 34)) (-2439 (((-834 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|)))) 21) (((-834 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-290 (-834 (-959 |#1|)))) 42))) 
-(((-632 |#1|) (-10 -7 (-15 -2506 ((-3 (-841 (-413 (-959 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed"))) "failed") (-413 (-959 |#1|)) (-290 (-841 (-959 |#1|))))) (-15 -2506 ((-3 (-841 (-413 (-959 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed"))) "failed") (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))))) (-15 -2439 ((-834 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-290 (-834 (-959 |#1|))))) (-15 -2439 ((-834 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))))) (-15 -2506 ((-3 (-841 (-413 (-959 |#1|))) "failed") (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))) (-1152)))) (-457)) (T -632)) 
-((-2506 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-290 (-413 (-959 *6)))) (-5 *5 (-1152)) (-5 *3 (-413 (-959 *6))) (-4 *6 (-457)) (-5 *2 (-841 *3)) (-5 *1 (-632 *6)))) (-2439 (*1 *2 *3 *4) (-12 (-5 *4 (-290 (-413 (-959 *5)))) (-5 *3 (-413 (-959 *5))) (-4 *5 (-457)) (-5 *2 (-834 *3)) (-5 *1 (-632 *5)))) (-2439 (*1 *2 *3 *4) (-12 (-5 *4 (-290 (-834 (-959 *5)))) (-4 *5 (-457)) (-5 *2 (-834 (-413 (-959 *5)))) (-5 *1 (-632 *5)) (-5 *3 (-413 (-959 *5))))) (-2506 (*1 *2 *3 *4) (-12 (-5 *4 (-290 (-413 (-959 *5)))) (-5 *3 (-413 (-959 *5))) (-4 *5 (-457)) (-5 *2 (-3 (-841 *3) (-2 (|:| |leftHandLimit| (-3 (-841 *3) "failed")) (|:| |rightHandLimit| (-3 (-841 *3) "failed"))) "failed")) (-5 *1 (-632 *5)))) (-2506 (*1 *2 *3 *4) (-12 (-5 *4 (-290 (-841 (-959 *5)))) (-4 *5 (-457)) (-5 *2 (-3 (-841 (-413 (-959 *5))) (-2 (|:| |leftHandLimit| (-3 (-841 (-413 (-959 *5))) "failed")) (|:| |rightHandLimit| (-3 (-841 (-413 (-959 *5))) "failed"))) "failed")) (-5 *1 (-632 *5)) (-5 *3 (-413 (-959 *5)))))) 
-(-10 -7 (-15 -2506 ((-3 (-841 (-413 (-959 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed"))) "failed") (-413 (-959 |#1|)) (-290 (-841 (-959 |#1|))))) (-15 -2506 ((-3 (-841 (-413 (-959 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-841 (-413 (-959 |#1|))) "failed"))) "failed") (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))))) (-15 -2439 ((-834 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-290 (-834 (-959 |#1|))))) (-15 -2439 ((-834 (-413 (-959 |#1|))) (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))))) (-15 -2506 ((-3 (-841 (-413 (-959 |#1|))) "failed") (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))) (-1152)))) 
-((-2101 (((-3 (-1259 (-413 |#1|)) "failed") (-1259 |#2|) |#2|) 57 (-2959 (|has| |#1| (-368)))) (((-3 (-1259 |#1|) "failed") (-1259 |#2|) |#2|) 42 (|has| |#1| (-368)))) (-3677 (((-121) (-1259 |#2|)) 30)) (-2726 (((-3 (-1259 |#1|) "failed") (-1259 |#2|)) 33))) 
-(((-633 |#1| |#2|) (-10 -7 (-15 -3677 ((-121) (-1259 |#2|))) (-15 -2726 ((-3 (-1259 |#1|) "failed") (-1259 |#2|))) (IF (|has| |#1| (-368)) (-15 -2101 ((-3 (-1259 |#1|) "failed") (-1259 |#2|) |#2|)) (-15 -2101 ((-3 (-1259 (-413 |#1|)) "failed") (-1259 |#2|) |#2|)))) (-562) (-634 |#1|)) (T -633)) 
-((-2101 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1259 *4)) (-4 *4 (-634 *5)) (-2959 (-4 *5 (-368))) (-4 *5 (-562)) (-5 *2 (-1259 (-413 *5))) (-5 *1 (-633 *5 *4)))) (-2101 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1259 *4)) (-4 *4 (-634 *5)) (-4 *5 (-368)) (-4 *5 (-562)) (-5 *2 (-1259 *5)) (-5 *1 (-633 *5 *4)))) (-2726 (*1 *2 *3) (|partial| -12 (-5 *3 (-1259 *5)) (-4 *5 (-634 *4)) (-4 *4 (-562)) (-5 *2 (-1259 *4)) (-5 *1 (-633 *4 *5)))) (-3677 (*1 *2 *3) (-12 (-5 *3 (-1259 *5)) (-4 *5 (-634 *4)) (-4 *4 (-562)) (-5 *2 (-121)) (-5 *1 (-633 *4 *5))))) 
-(-10 -7 (-15 -3677 ((-121) (-1259 |#2|))) (-15 -2726 ((-3 (-1259 |#1|) "failed") (-1259 |#2|))) (IF (|has| |#1| (-368)) (-15 -2101 ((-3 (-1259 |#1|) "failed") (-1259 |#2|) |#2|)) (-15 -2101 ((-3 (-1259 (-413 |#1|)) "failed") (-1259 |#2|) |#2|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-2284 (((-685 |#1|) (-685 $)) 35) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 34)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-634 |#1|) (-1290) (-1054)) (T -634)) 
-((-2284 (*1 *2 *3) (-12 (-5 *3 (-685 *1)) (-4 *1 (-634 *4)) (-4 *4 (-1054)) (-5 *2 (-685 *4)))) (-2284 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *1)) (-5 *4 (-1259 *1)) (-4 *1 (-634 *5)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -1369 (-685 *5)) (|:| |vec| (-1259 *5))))))) 
-(-13 (-1054) (-10 -8 (-15 -2284 ((-685 |t#1|) (-685 $))) (-15 -2284 ((-2 (|:| -1369 (-685 |t#1|)) (|:| |vec| (-1259 |t#1|))) (-685 $) (-1259 $))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3724 ((|#2| (-638 |#1|) (-638 |#2|) |#1| (-1 |#2| |#1|)) 18) (((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|) (-1 |#2| |#1|)) 19) ((|#2| (-638 |#1|) (-638 |#2|) |#1| |#2|) 16) (((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|) |#2|) 17) ((|#2| (-638 |#1|) (-638 |#2|) |#1|) 10) (((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|)) 12))) 
-(((-635 |#1| |#2|) (-10 -7 (-15 -3724 ((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|))) (-15 -3724 (|#2| (-638 |#1|) (-638 |#2|) |#1|)) (-15 -3724 ((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|) |#2|)) (-15 -3724 (|#2| (-638 |#1|) (-638 |#2|) |#1| |#2|)) (-15 -3724 ((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|) (-1 |#2| |#1|))) (-15 -3724 (|#2| (-638 |#1|) (-638 |#2|) |#1| (-1 |#2| |#1|)))) (-1098) (-1204)) (T -635)) 
-((-3724 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 *2)) (-5 *6 (-1 *2 *5)) (-4 *5 (-1098)) (-4 *2 (-1204)) (-5 *1 (-635 *5 *2)))) (-3724 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-1 *6 *5)) (-5 *3 (-638 *5)) (-5 *4 (-638 *6)) (-4 *5 (-1098)) (-4 *6 (-1204)) (-5 *1 (-635 *5 *6)))) (-3724 (*1 *2 *3 *4 *5 *2) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 *2)) (-4 *5 (-1098)) (-4 *2 (-1204)) (-5 *1 (-635 *5 *2)))) (-3724 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *6)) (-5 *4 (-638 *5)) (-4 *6 (-1098)) (-4 *5 (-1204)) (-5 *2 (-1 *5 *6)) (-5 *1 (-635 *6 *5)))) (-3724 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 *2)) (-4 *5 (-1098)) (-4 *2 (-1204)) (-5 *1 (-635 *5 *2)))) (-3724 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 *6)) (-4 *5 (-1098)) (-4 *6 (-1204)) (-5 *2 (-1 *6 *5)) (-5 *1 (-635 *5 *6))))) 
-(-10 -7 (-15 -3724 ((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|))) (-15 -3724 (|#2| (-638 |#1|) (-638 |#2|) |#1|)) (-15 -3724 ((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|) |#2|)) (-15 -3724 (|#2| (-638 |#1|) (-638 |#2|) |#1| |#2|)) (-15 -3724 ((-1 |#2| |#1|) (-638 |#1|) (-638 |#2|) (-1 |#2| |#1|))) (-15 -3724 (|#2| (-638 |#1|) (-638 |#2|) |#1| (-1 |#2| |#1|)))) 
-((-1911 (((-638 |#2|) (-1 |#2| |#1| |#2|) (-638 |#1|) |#2|) 16)) (-3116 ((|#2| (-1 |#2| |#1| |#2|) (-638 |#1|) |#2|) 18)) (-3828 (((-638 |#2|) (-1 |#2| |#1|) (-638 |#1|)) 13))) 
-(((-636 |#1| |#2|) (-10 -7 (-15 -1911 ((-638 |#2|) (-1 |#2| |#1| |#2|) (-638 |#1|) |#2|)) (-15 -3116 (|#2| (-1 |#2| |#1| |#2|) (-638 |#1|) |#2|)) (-15 -3828 ((-638 |#2|) (-1 |#2| |#1|) (-638 |#1|)))) (-1204) (-1204)) (T -636)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-638 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-638 *6)) (-5 *1 (-636 *5 *6)))) (-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-638 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-636 *5 *2)))) (-1911 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-638 *6)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-5 *2 (-638 *5)) (-5 *1 (-636 *6 *5))))) 
-(-10 -7 (-15 -1911 ((-638 |#2|) (-1 |#2| |#1| |#2|) (-638 |#1|) |#2|)) (-15 -3116 (|#2| (-1 |#2| |#1| |#2|) (-638 |#1|) |#2|)) (-15 -3828 ((-638 |#2|) (-1 |#2| |#1|) (-638 |#1|)))) 
-((-3828 (((-638 |#3|) (-1 |#3| |#1| |#2|) (-638 |#1|) (-638 |#2|)) 13))) 
-(((-637 |#1| |#2| |#3|) (-10 -7 (-15 -3828 ((-638 |#3|) (-1 |#3| |#1| |#2|) (-638 |#1|) (-638 |#2|)))) (-1204) (-1204) (-1204)) (T -637)) 
-((-3828 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-638 *6)) (-5 *5 (-638 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-638 *8)) (-5 *1 (-637 *6 *7 *8))))) 
-(-10 -7 (-15 -3828 ((-638 |#3|) (-1 |#3| |#1| |#2|) (-638 |#1|) (-638 |#2|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) NIL)) (-4230 ((|#1| $) NIL)) (-4232 (($ $) NIL)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) $) NIL (|has| |#1| (-848))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-4131 (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848)))) (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3008 (($ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-3749 (($ $ $) NIL (|has| $ (-6 -4603)))) (-2656 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-4055 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ "first" |#1|) NIL (|has| $ (-6 -4603))) (($ $ "rest" $) NIL (|has| $ (-6 -4603))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-1676 (($ $ $) 31 (|has| |#1| (-1098)))) (-1666 (($ $ $) 33 (|has| |#1| (-1098)))) (-1661 (($ $ $) 36 (|has| |#1| (-1098)))) (-1550 (($ (-1 (-121) |#1|) $) NIL)) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4066 ((|#1| $) NIL)) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1651 (($ $) NIL) (($ $ (-769)) NIL)) (-3259 (($ $) NIL (|has| |#1| (-1098)))) (-1643 (($ $) 30 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1544 (($ |#1| $) NIL (|has| |#1| (-1098))) (($ (-1 (-121) |#1|) $) NIL)) (-3445 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-2429 (((-121) $) NIL)) (-4014 (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098))) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) (-1 (-121) |#1|) $) NIL)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2995 (((-121) $) 9)) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3389 (($) 7)) (-1364 (($ (-769) |#1|) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-3279 (($ $ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4475 (($ $ $) NIL (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 32 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1624 (($ |#1|) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-3253 ((|#1| $) NIL) (($ $ (-769)) NIL)) (-1335 (($ $ $ (-572)) NIL) (($ |#1| $ (-572)) NIL)) (-2603 (($ $ $ (-572)) NIL) (($ |#1| $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) NIL) (($ $ (-769)) NIL)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-3540 (((-121) $) NIL)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1225 (-572))) NIL) ((|#1| $ (-572)) 35) ((|#1| $ (-572) |#1|) NIL)) (-3537 (((-572) $ $) NIL)) (-2145 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-1940 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-1791 (((-121) $) NIL)) (-2619 (($ $) NIL)) (-3316 (($ $) NIL (|has| $ (-6 -4603)))) (-1471 (((-769) $) NIL)) (-3622 (($ $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) 44 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-1603 (($ |#1| $) 10)) (-2977 (($ $ $) NIL) (($ $ |#1|) NIL)) (-4500 (($ $ $) 29) (($ |#1| $) NIL) (($ (-638 $)) NIL) (($ $ |#1|) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3607 (($ $ $) 11)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3594 (((-1152) $) 25 (|has| |#1| (-829))) (((-1152) $ (-121)) 26 (|has| |#1| (-829))) (((-1264) (-823) $) 27 (|has| |#1| (-829))) (((-1264) (-823) $ (-121)) 28 (|has| |#1| (-829)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-638 |#1|) (-13 (-662 |#1|) (-10 -8 (-15 -3389 ($)) (-15 -2995 ((-121) $)) (-15 -1603 ($ |#1| $)) (-15 -3607 ($ $ $)) (IF (|has| |#1| (-1098)) (PROGN (-15 -1676 ($ $ $)) (-15 -1666 ($ $ $)) (-15 -1661 ($ $ $))) |noBranch|) (IF (|has| |#1| (-829)) (-6 (-829)) |noBranch|))) (-1204)) (T -638)) 
-((-3389 (*1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1204)))) (-2995 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-638 *3)) (-4 *3 (-1204)))) (-1603 (*1 *1 *2 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1204)))) (-3607 (*1 *1 *1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1204)))) (-1676 (*1 *1 *1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1098)) (-4 *2 (-1204)))) (-1666 (*1 *1 *1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1098)) (-4 *2 (-1204)))) (-1661 (*1 *1 *1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1098)) (-4 *2 (-1204))))) 
-(-13 (-662 |#1|) (-10 -8 (-15 -3389 ($)) (-15 -2995 ((-121) $)) (-15 -1603 ($ |#1| $)) (-15 -3607 ($ $ $)) (IF (|has| |#1| (-1098)) (PROGN (-15 -1676 ($ $ $)) (-15 -1666 ($ $ $)) (-15 -1661 ($ $ $))) |noBranch|) (IF (|has| |#1| (-829)) (-6 (-829)) |noBranch|))) 
-((-1933 (((-638 |#1|) |#2| (-572)) 21)) (-3541 (((-685 |#1|) (-638 |#2|) (-572)) 30)) (-3847 (((-685 |#1|) (-638 |#2|) (-572)) 28))) 
-(((-639 |#1| |#2|) (-10 -7 (-15 -3541 ((-685 |#1|) (-638 |#2|) (-572))) (-15 -3847 ((-685 |#1|) (-638 |#2|) (-572))) (-15 -1933 ((-638 |#1|) |#2| (-572)))) (-368) (-645 |#1|)) (T -639)) 
-((-1933 (*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-368)) (-5 *2 (-638 *5)) (-5 *1 (-639 *5 *3)) (-4 *3 (-645 *5)))) (-3847 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-572)) (-4 *6 (-645 *5)) (-4 *5 (-368)) (-5 *2 (-685 *5)) (-5 *1 (-639 *5 *6)))) (-3541 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-572)) (-4 *6 (-645 *5)) (-4 *5 (-368)) (-5 *2 (-685 *5)) (-5 *1 (-639 *5 *6))))) 
-(-10 -7 (-15 -3541 ((-685 |#1|) (-638 |#2|) (-572))) (-15 -3847 ((-685 |#1|) (-638 |#2|) (-572))) (-15 -1933 ((-638 |#1|) |#2| (-572)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1689 (($ |#1| |#1| $) 43)) (-1946 (((-121) $ (-769)) NIL)) (-1550 (($ (-1 (-121) |#1|) $) 56 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-3259 (($ $) 45)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1544 (($ |#1| $) 51 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) 53 (|has| $ (-6 -4602)))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-2010 (((-638 |#1|) $) 9 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) 39 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 37)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-4221 ((|#1| $) 46)) (-1335 (($ |#1| $) 26) (($ |#1| $ (-769)) 42)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2232 ((|#1| $) 48)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 21)) (-1665 (($) 25)) (-3168 (((-121) $) 49)) (-4153 (((-638 (-2 (|:| -4320 |#1|) (|:| -1571 (-769)))) $) 60)) (-1535 (($) 23) (($ (-638 |#1|)) 18)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) 57 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) 19)) (-4081 (((-545) $) 34 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-3972 (((-856) $) 14 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 22)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 62 (|has| |#1| (-1098)))) (-4032 (((-769) $) 16 (|has| $ (-6 -4602))))) 
-(((-640 |#1|) (-13 (-690 |#1|) (-10 -8 (-6 -4602) (-15 -3168 ((-121) $)) (-15 -1689 ($ |#1| |#1| $)))) (-1098)) (T -640)) 
-((-3168 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-640 *3)) (-4 *3 (-1098)))) (-1689 (*1 *1 *2 *2 *1) (-12 (-5 *1 (-640 *2)) (-4 *2 (-1098))))) 
-(-13 (-690 |#1|) (-10 -8 (-6 -4602) (-15 -3168 ((-121) $)) (-15 -1689 ($ |#1| |#1| $)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ |#1| $) 22))) 
-(((-641 |#1|) (-1290) (-1061)) (T -641)) 
-((* (*1 *1 *2 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-1061))))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) NIL)) (-1915 ((|#1| $) NIL)) (-3188 (($ $) NIL)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) 57 (|has| $ (-6 -4626)))) (-4076 (((-141) $) NIL (|has| |#1| (-869))) (((-141) (-1 (-141) |#1| |#1|) $) NIL)) (-2831 (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869)))) (($ (-1 (-141) |#1| |#1|) $) 55 (|has| $ (-6 -4626)))) (-3960 (($ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-3153 (($ $ $) 23 (|has| $ (-6 -4626)))) (-4496 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-2101 ((|#1| $ |#1|) 21 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ "first" |#1|) 22 (|has| $ (-6 -4626))) (($ $ "rest" $) 24 (|has| $ (-6 -4626))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-4125 (($ (-1 (-141) |#1|) $) NIL)) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-1765 ((|#1| $) NIL)) (-3001 (($) NIL T CONST)) (-2512 (($ $) 28 (|has| $ (-6 -4626)))) (-1373 (($ $) 29)) (-1366 (($ $) 18) (($ $ (-790)) 32)) (-1461 (($ $) 53 (|has| |#1| (-1119)))) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4065 (($ |#1| $) NIL (|has| |#1| (-1119))) (($ (-1 (-141) |#1|) $) NIL)) (-4459 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-3868 (((-141) $) NIL)) (-1721 (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119))) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) (-1 (-141) |#1|) $) NIL)) (-4004 (((-658 |#1|) $) 27 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3242 (($ (-790) |#1|) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 31 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-2713 (($ $ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) 56)) (-4491 (($ $ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 51 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1333 (($ |#1|) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) 50 (|has| |#1| (-1119)))) (-4255 ((|#1| $) NIL) (($ $ (-790)) NIL)) (-2113 (($ $ $ (-592)) NIL) (($ |#1| $ (-592)) NIL)) (-3666 (($ $ $ (-592)) NIL) (($ |#1| $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) 13) (($ $ (-790)) NIL)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-2955 (((-141) $) NIL)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 12)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) 17)) (-2890 (($) 16)) (-3927 ((|#1| $ "value") NIL) ((|#1| $ "first") 15) (($ $ "rest") 20) ((|#1| $ "last") NIL) (($ $ (-1246 (-592))) NIL) ((|#1| $ (-592)) NIL) ((|#1| $ (-592) |#1|) NIL)) (-2920 (((-592) $ $) NIL)) (-4113 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-3208 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-3228 (((-141) $) 33)) (-2399 (($ $) NIL)) (-1337 (($ $) NIL (|has| $ (-6 -4626)))) (-3318 (((-790) $) NIL)) (-3184 (($ $) 35)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) 34)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 26)) (-3619 (($ $ $) 52) (($ $ |#1|) NIL)) (-2266 (($ $ $) NIL) (($ |#1| $) 10) (($ (-658 $)) NIL) (($ $ |#1|) NIL)) (-1683 (((-877) $) 45 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) 47 (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-1699 (((-790) $) 9 (|has| $ (-6 -4625))))) 
+(((-552 |#1| |#2|) (-683 |#1|) (-1225) (-592)) (T -552)) 
+NIL 
+(-683 |#1|) 
+((-3052 ((|#4| |#4|) 26)) (-4175 (((-790) |#4|) 31)) (-3178 (((-790) |#4|) 32)) (-3555 (((-658 |#3|) |#4|) 37 (|has| |#3| (-6 -4626)))) (-3183 (((-3 |#4| "failed") |#4|) 47)) (-3023 ((|#4| |#4|) 40)) (-1625 ((|#1| |#4|) 39))) 
+(((-553 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3052 (|#4| |#4|)) (-15 -4175 ((-790) |#4|)) (-15 -3178 ((-790) |#4|)) (IF (|has| |#3| (-6 -4626)) (-15 -3555 ((-658 |#3|) |#4|)) |noBranch|) (-15 -1625 (|#1| |#4|)) (-15 -3023 (|#4| |#4|)) (-15 -3183 ((-3 |#4| "failed") |#4|))) (-388) (-399 |#1|) (-399 |#1|) (-704 |#1| |#2| |#3|)) (T -553)) 
+((-3183 (*1 *2 *2) (|partial| -12 (-4 *3 (-388)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-553 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-3023 (*1 *2 *2) (-12 (-4 *3 (-388)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-553 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-1625 (*1 *2 *3) (-12 (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-388)) (-5 *1 (-553 *2 *4 *5 *3)) (-4 *3 (-704 *2 *4 *5)))) (-3555 (*1 *2 *3) (-12 (|has| *6 (-6 -4626)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-658 *6)) (-5 *1 (-553 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-3178 (*1 *2 *3) (-12 (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-790)) (-5 *1 (-553 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-4175 (*1 *2 *3) (-12 (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-790)) (-5 *1 (-553 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-3052 (*1 *2 *2) (-12 (-4 *3 (-388)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-553 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(-10 -7 (-15 -3052 (|#4| |#4|)) (-15 -4175 ((-790) |#4|)) (-15 -3178 ((-790) |#4|)) (IF (|has| |#3| (-6 -4626)) (-15 -3555 ((-658 |#3|) |#4|)) |noBranch|) (-15 -1625 (|#1| |#4|)) (-15 -3023 (|#4| |#4|)) (-15 -3183 ((-3 |#4| "failed") |#4|))) 
+((-3052 ((|#8| |#4|) 20)) (-3555 (((-658 |#3|) |#4|) 29 (|has| |#7| (-6 -4626)))) (-3183 (((-3 |#8| "failed") |#4|) 23))) 
+(((-554 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -3052 (|#8| |#4|)) (-15 -3183 ((-3 |#8| "failed") |#4|)) (IF (|has| |#7| (-6 -4626)) (-15 -3555 ((-658 |#3|) |#4|)) |noBranch|)) (-582) (-399 |#1|) (-399 |#1|) (-704 |#1| |#2| |#3|) (-1021 |#1|) (-399 |#5|) (-399 |#5|) (-704 |#5| |#6| |#7|)) (T -554)) 
+((-3555 (*1 *2 *3) (-12 (|has| *9 (-6 -4626)) (-4 *4 (-582)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-4 *7 (-1021 *4)) (-4 *8 (-399 *7)) (-4 *9 (-399 *7)) (-5 *2 (-658 *6)) (-5 *1 (-554 *4 *5 *6 *3 *7 *8 *9 *10)) (-4 *3 (-704 *4 *5 *6)) (-4 *10 (-704 *7 *8 *9)))) (-3183 (*1 *2 *3) (|partial| -12 (-4 *4 (-582)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-4 *7 (-1021 *4)) (-4 *2 (-704 *7 *8 *9)) (-5 *1 (-554 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-704 *4 *5 *6)) (-4 *8 (-399 *7)) (-4 *9 (-399 *7)))) (-3052 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-4 *7 (-1021 *4)) (-4 *2 (-704 *7 *8 *9)) (-5 *1 (-554 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-704 *4 *5 *6)) (-4 *8 (-399 *7)) (-4 *9 (-399 *7))))) 
+(-10 -7 (-15 -3052 (|#8| |#4|)) (-15 -3183 ((-3 |#8| "failed") |#4|)) (IF (|has| |#7| (-6 -4626)) (-15 -3555 ((-658 |#3|) |#4|)) |noBranch|)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1417 (($ (-790) (-790)) NIL)) (-4596 (($ $ $) NIL)) (-2245 (($ (-623 |#1| |#3|)) NIL) (($ $) NIL)) (-4034 (((-141) $) NIL)) (-2668 (($ $ (-592) (-592)) 12)) (-1664 (($ $ (-592) (-592)) NIL)) (-2019 (($ $ (-592) (-592) (-592) (-592)) NIL)) (-1574 (($ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-2854 (($ $ (-592) (-592) $) NIL)) (-3932 ((|#1| $ (-592) (-592) |#1|) NIL) (($ $ (-658 (-592)) (-658 (-592)) $) NIL)) (-2547 (($ $ (-592) (-623 |#1| |#3|)) NIL)) (-2242 (($ $ (-592) (-623 |#1| |#2|)) NIL)) (-3223 (($ (-790) |#1|) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) 19 (|has| |#1| (-323)))) (-2747 (((-623 |#1| |#3|) $ (-592)) NIL)) (-4175 (((-790) $) 22 (|has| |#1| (-582)))) (-1426 ((|#1| $ (-592) (-592) |#1|) NIL)) (-3959 ((|#1| $ (-592) (-592)) NIL)) (-1794 ((|#1| $) NIL (|has| |#1| (-194)))) (-4004 (((-658 |#1|) $) NIL)) (-3178 (((-790) $) 24 (|has| |#1| (-582)))) (-3555 (((-658 (-623 |#1| |#2|)) $) 27 (|has| |#1| (-582)))) (-4292 (((-790) $) NIL)) (-3242 (($ (-790) (-790) |#1|) NIL)) (-4298 (((-790) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-3781 ((|#1| $) 17 (|has| |#1| (-6 (-4627 "*"))))) (-4577 (((-592) $) 10)) (-4280 (((-592) $) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1898 (((-592) $) 11)) (-3005 (((-592) $) NIL)) (-4186 (($ (-658 (-658 |#1|))) NIL) (($ (-790) (-790) (-1 |#1| (-592) (-592))) NIL)) (-3987 (($ (-1 |#1| |#1|) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-4601 (((-658 (-658 |#1|)) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3183 (((-3 $ "failed") $) 31 (|has| |#1| (-388)))) (-2083 (($ $ $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1892 (($ $ |#1|) NIL)) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) (-592)) NIL) ((|#1| $ (-592) (-592) |#1|) NIL) (($ $ (-658 (-592)) (-658 (-592))) NIL)) (-2933 (($ (-658 |#1|)) NIL) (($ (-658 $)) NIL)) (-2940 (((-141) $) NIL)) (-1625 ((|#1| $) 15 (|has| |#1| (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-3430 (((-658 (-623 |#1| |#2|)) $) NIL (|has| |#1| (-323)))) (-2000 (((-623 |#1| |#2|) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119))) (($ (-623 |#1| |#2|)) NIL)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-592) $) NIL) (((-623 |#1| |#2|) $ (-623 |#1| |#2|)) NIL) (((-623 |#1| |#3|) (-623 |#1| |#3|) $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-555 |#1| |#2| |#3|) (-704 |#1| (-623 |#1| |#3|) (-623 |#1| |#2|)) (-1075) (-592) (-592)) (T -555)) 
+NIL 
+(-704 |#1| (-623 |#1| |#3|) (-623 |#1| |#2|)) 
+((-4542 (((-1187 |#1|) (-790)) 74)) (-4529 (((-1280 |#1|) (-1280 |#1|) (-944)) 67)) (-2595 (((-1285) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) |#1|) 82)) (-2799 (((-1280 |#1|) (-1280 |#1|) (-790)) 36)) (-4290 (((-1280 |#1|) (-944)) 69)) (-2256 (((-1280 |#1|) (-1280 |#1|) (-592)) 24)) (-3489 (((-1187 |#1|) (-1280 |#1|)) 75)) (-2834 (((-1280 |#1|) (-944)) 93)) (-2114 (((-141) (-1280 |#1|)) 78)) (-2793 (((-1280 |#1|) (-1280 |#1|) (-944)) 59)) (-3504 (((-1187 |#1|) (-1280 |#1|)) 87)) (-3546 (((-944) (-1280 |#1|)) 56)) (-4552 (((-1280 |#1|) (-1280 |#1|)) 30)) (-1825 (((-1280 |#1|) (-944) (-944)) 95)) (-4361 (((-1280 |#1|) (-1280 |#1|) (-1137) (-1137)) 23)) (-2674 (((-1280 |#1|) (-1280 |#1|) (-790) (-1137)) 37)) (-2195 (((-1280 (-1280 |#1|)) (-944)) 92)) (-3313 (((-1280 |#1|) (-1280 |#1|) (-1280 |#1|)) 79)) (** (((-1280 |#1|) (-1280 |#1|) (-592)) 43)) (* (((-1280 |#1|) (-1280 |#1|) (-1280 |#1|)) 25))) 
+(((-556 |#1|) (-10 -7 (-15 -2595 ((-1285) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) |#1|)) (-15 -4290 ((-1280 |#1|) (-944))) (-15 -1825 ((-1280 |#1|) (-944) (-944))) (-15 -3489 ((-1187 |#1|) (-1280 |#1|))) (-15 -4542 ((-1187 |#1|) (-790))) (-15 -2674 ((-1280 |#1|) (-1280 |#1|) (-790) (-1137))) (-15 -2799 ((-1280 |#1|) (-1280 |#1|) (-790))) (-15 -4361 ((-1280 |#1|) (-1280 |#1|) (-1137) (-1137))) (-15 -2256 ((-1280 |#1|) (-1280 |#1|) (-592))) (-15 ** ((-1280 |#1|) (-1280 |#1|) (-592))) (-15 * ((-1280 |#1|) (-1280 |#1|) (-1280 |#1|))) (-15 -3313 ((-1280 |#1|) (-1280 |#1|) (-1280 |#1|))) (-15 -2793 ((-1280 |#1|) (-1280 |#1|) (-944))) (-15 -4529 ((-1280 |#1|) (-1280 |#1|) (-944))) (-15 -4552 ((-1280 |#1|) (-1280 |#1|))) (-15 -3546 ((-944) (-1280 |#1|))) (-15 -2114 ((-141) (-1280 |#1|))) (-15 -2195 ((-1280 (-1280 |#1|)) (-944))) (-15 -2834 ((-1280 |#1|) (-944))) (-15 -3504 ((-1187 |#1|) (-1280 |#1|)))) (-373)) (T -556)) 
+((-3504 (*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-373)) (-5 *2 (-1187 *4)) (-5 *1 (-556 *4)))) (-2834 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 *4)) (-5 *1 (-556 *4)) (-4 *4 (-373)))) (-2195 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 (-1280 *4))) (-5 *1 (-556 *4)) (-4 *4 (-373)))) (-2114 (*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-556 *4)))) (-3546 (*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-373)) (-5 *2 (-944)) (-5 *1 (-556 *4)))) (-4552 (*1 *2 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-373)) (-5 *1 (-556 *3)))) (-4529 (*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-944)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) (-2793 (*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-944)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) (-3313 (*1 *2 *2 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-373)) (-5 *1 (-556 *3)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-373)) (-5 *1 (-556 *3)))) (** (*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-592)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) (-2256 (*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-592)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) (-4361 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-1137)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) (-2799 (*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-790)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) (-2674 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-1280 *5)) (-5 *3 (-790)) (-5 *4 (-1137)) (-4 *5 (-373)) (-5 *1 (-556 *5)))) (-4542 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1187 *4)) (-5 *1 (-556 *4)) (-4 *4 (-373)))) (-3489 (*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-373)) (-5 *2 (-1187 *4)) (-5 *1 (-556 *4)))) (-1825 (*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 *4)) (-5 *1 (-556 *4)) (-4 *4 (-373)))) (-4290 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 *4)) (-5 *1 (-556 *4)) (-4 *4 (-373)))) (-2595 (*1 *2 *3 *4) (-12 (-5 *3 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-4 *4 (-373)) (-5 *2 (-1285)) (-5 *1 (-556 *4))))) 
+(-10 -7 (-15 -2595 ((-1285) (-1280 (-658 (-2 (|:| -2324 |#1|) (|:| -1825 (-1137))))) |#1|)) (-15 -4290 ((-1280 |#1|) (-944))) (-15 -1825 ((-1280 |#1|) (-944) (-944))) (-15 -3489 ((-1187 |#1|) (-1280 |#1|))) (-15 -4542 ((-1187 |#1|) (-790))) (-15 -2674 ((-1280 |#1|) (-1280 |#1|) (-790) (-1137))) (-15 -2799 ((-1280 |#1|) (-1280 |#1|) (-790))) (-15 -4361 ((-1280 |#1|) (-1280 |#1|) (-1137) (-1137))) (-15 -2256 ((-1280 |#1|) (-1280 |#1|) (-592))) (-15 ** ((-1280 |#1|) (-1280 |#1|) (-592))) (-15 * ((-1280 |#1|) (-1280 |#1|) (-1280 |#1|))) (-15 -3313 ((-1280 |#1|) (-1280 |#1|) (-1280 |#1|))) (-15 -2793 ((-1280 |#1|) (-1280 |#1|) (-944))) (-15 -4529 ((-1280 |#1|) (-1280 |#1|) (-944))) (-15 -4552 ((-1280 |#1|) (-1280 |#1|))) (-15 -3546 ((-944) (-1280 |#1|))) (-15 -2114 ((-141) (-1280 |#1|))) (-15 -2195 ((-1280 (-1280 |#1|)) (-944))) (-15 -2834 ((-1280 |#1|) (-944))) (-15 -3504 ((-1187 |#1|) (-1280 |#1|)))) 
+((-3091 (((-1 |#1| |#1|) |#1|) 11)) (-3895 (((-1 |#1| |#1|)) 10))) 
+(((-557 |#1|) (-10 -7 (-15 -3895 ((-1 |#1| |#1|))) (-15 -3091 ((-1 |#1| |#1|) |#1|))) (-13 (-743) (-25))) (T -557)) 
+((-3091 (*1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-557 *3)) (-4 *3 (-13 (-743) (-25))))) (-3895 (*1 *2) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-557 *3)) (-4 *3 (-13 (-743) (-25)))))) 
+(-10 -7 (-15 -3895 ((-1 |#1| |#1|))) (-15 -3091 ((-1 |#1| |#1|) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4079 (($ $ $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-4526 (($ (-790) |#1|) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 (-790) (-790)) $) NIL)) (-2183 ((|#1| $) NIL)) (-4579 (((-790) $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 20)) (-3514 (($) NIL T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3300 (($ $ $) NIL)) (* (($ (-790) $) NIL) (($ (-944) $) NIL))) 
+(((-558 |#1|) (-13 (-815) (-542 (-790) |#1|)) (-869)) (T -558)) 
+NIL 
+(-13 (-815) (-542 (-790) |#1|)) 
+((-4375 (((-658 |#2|) (-1187 |#1|) |#3|) 83)) (-1799 (((-658 (-2 (|:| |outval| |#2|) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 |#2|))))) (-706 |#1|) |#3| (-1 (-444 (-1187 |#1|)) (-1187 |#1|))) 99)) (-2264 (((-1187 |#1|) (-706 |#1|)) 95))) 
+(((-559 |#1| |#2| |#3|) (-10 -7 (-15 -2264 ((-1187 |#1|) (-706 |#1|))) (-15 -4375 ((-658 |#2|) (-1187 |#1|) |#3|)) (-15 -1799 ((-658 (-2 (|:| |outval| |#2|) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 |#2|))))) (-706 |#1|) |#3| (-1 (-444 (-1187 |#1|)) (-1187 |#1|))))) (-388) (-388) (-13 (-388) (-867))) (T -559)) 
+((-1799 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *6)) (-5 *5 (-1 (-444 (-1187 *6)) (-1187 *6))) (-4 *6 (-388)) (-5 *2 (-658 (-2 (|:| |outval| *7) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 *7)))))) (-5 *1 (-559 *6 *7 *4)) (-4 *7 (-388)) (-4 *4 (-13 (-388) (-867))))) (-4375 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 *5)) (-4 *5 (-388)) (-5 *2 (-658 *6)) (-5 *1 (-559 *5 *6 *4)) (-4 *6 (-388)) (-4 *4 (-13 (-388) (-867))))) (-2264 (*1 *2 *3) (-12 (-5 *3 (-706 *4)) (-4 *4 (-388)) (-5 *2 (-1187 *4)) (-5 *1 (-559 *4 *5 *6)) (-4 *5 (-388)) (-4 *6 (-13 (-388) (-867)))))) 
+(-10 -7 (-15 -2264 ((-1187 |#1|) (-706 |#1|))) (-15 -4375 ((-658 |#2|) (-1187 |#1|) |#3|)) (-15 -1799 ((-658 (-2 (|:| |outval| |#2|) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 |#2|))))) (-706 |#1|) |#3| (-1 (-444 (-1187 |#1|)) (-1187 |#1|))))) 
+((-1641 (((-141) $ $) 7)) (-2294 (((-1191) $) 20)) (-2913 (((-790) $) 22)) (-2725 (((-1191) $ (-1191)) 23)) (-2969 (((-790) $ (-790)) 28)) (-3807 ((|#5| $ |#5|) 31)) (-2138 (((-790) $ (-790)) 27)) (-2483 (((-33 |#1|) $ (-33 |#1|)) 29)) (-2598 (((-658 |#6|) $ (-658 |#6|)) 24)) (-3710 ((|#8| $ |#8|) 25)) (-2450 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) $ (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|)) 30)) (-4153 ((|#9| $ |#9|) 26)) (-4501 ((|#5| $) 19)) (-2903 (((-790) $) 16)) (-4399 (((-33 |#1|) $) 17)) (-3607 (((-658 |#6|) $) 21)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3011 ((|#8| $) 14)) (-4525 (((-944) $) 12)) (-1761 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) $) 18)) (-2443 (($ |#5| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-33 |#1|) (-790) |#9| (-790) |#8| |#1| (-1191)) 33) (($ |#5| |#3|) 32)) (-1683 (((-877) $) 11)) (-2663 ((|#9| $) 15)) (-3204 ((|#1| $) 13)) (-3255 (((-141) $ $) 6))) 
+(((-560 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-1311) (-388) (-658 (-1191)) (-977 |t#1| |t#4| (-879 |t#2|)) (-252 (-1699 |t#2|) (-790)) (-999 |t#1|) (-665 |t#1|) (-947 |t#1| |t#6|) (-257 |t#7|) (-137)) (T -560)) 
+((-2443 (*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (-12 (-5 *3 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *8)) (-5 *4 (-33 *8)) (-5 *9 (-1191)) (-4 *8 (-388)) (-5 *5 (-790)) (-4 *12 (-252 (-1699 *10) *5)) (-4 *13 (-665 *8)) (-4 *14 (-947 *8 *13)) (-4 *1 (-560 *8 *10 *11 *12 *2 *13 *14 *7 *6)) (-4 *11 (-977 *8 *12 (-879 *10))) (-4 *2 (-999 *8)) (-4 *7 (-257 *14)) (-4 *6 (-137)))) (-2443 (*1 *1 *2 *3) (-12 (-4 *4 (-388)) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-665 *4)) (-4 *8 (-947 *4 *7)) (-4 *1 (-560 *4 *5 *3 *6 *2 *7 *8 *9 *10)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *2 (-999 *4)) (-4 *9 (-257 *8)) (-4 *10 (-137)))) (-3807 (*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *2 (-999 *3)) (-4 *7 (-665 *3)) (-4 *8 (-947 *3 *7)) (-4 *9 (-257 *8)) (-4 *10 (-137)))) (-2450 (*1 *2 *1 *2) (-12 (-5 *2 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *3)) (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)))) (-2483 (*1 *2 *1 *2) (-12 (-5 *2 (-33 *3)) (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)))) (-2969 (*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-790)))) (-2138 (*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-790)))) (-4153 (*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *2 (-137)))) (-3710 (*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *2 (-257 *9)) (-4 *10 (-137)))) (-2598 (*1 *2 *1 *2) (-12 (-5 *2 (-658 *8)) (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)))) (-2725 (*1 *2 *1 *2) (-12 (-5 *2 (-1191)) (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)))) (-2913 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-790)))) (-3607 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-658 *8)))) (-2294 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-1191)))) (-4501 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-665 *3)) (-4 *8 (-947 *3 *7)) (-4 *9 (-257 *8)) (-4 *10 (-137)) (-4 *2 (-999 *3)))) (-1761 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *3)))) (-4399 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-33 *3)))) (-2903 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-790)))) (-2663 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *2 (-137)))) (-3011 (*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-137)) (-4 *2 (-257 *9)))) (-3204 (*1 *2 *1) (-12 (-4 *1 (-560 *2 *3 *4 *5 *6 *7 *8 *9 *10)) (-4 *4 (-977 *2 *5 (-879 *3))) (-4 *5 (-252 (-1699 *3) (-790))) (-4 *6 (-999 *2)) (-4 *7 (-665 *2)) (-4 *8 (-947 *2 *7)) (-4 *9 (-257 *8)) (-4 *10 (-137)) (-4 *2 (-388))))) 
+(-13 (-1117) (-10 -8 (-15 -2443 ($ |t#5| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |t#1|) (-33 |t#1|) (-790) |t#9| (-790) |t#8| |t#1| (-1191))) (-15 -2443 ($ |t#5| |t#3|)) (-15 -3807 (|t#5| $ |t#5|)) (-15 -2450 ((-264 (-4466 (QUOTE X) (QUOTE -3820)) |t#1|) $ (-264 (-4466 (QUOTE X) (QUOTE -3820)) |t#1|))) (-15 -2483 ((-33 |t#1|) $ (-33 |t#1|))) (-15 -2969 ((-790) $ (-790))) (-15 -2138 ((-790) $ (-790))) (-15 -4153 (|t#9| $ |t#9|)) (-15 -3710 (|t#8| $ |t#8|)) (-15 -2598 ((-658 |t#6|) $ (-658 |t#6|))) (-15 -2725 ((-1191) $ (-1191))) (-15 -2913 ((-790) $)) (-15 -3607 ((-658 |t#6|) $)) (-15 -2294 ((-1191) $)) (-15 -4501 (|t#5| $)) (-15 -1761 ((-264 (-4466 (QUOTE X) (QUOTE -3820)) |t#1|) $)) (-15 -4399 ((-33 |t#1|) $)) (-15 -2903 ((-790) $)) (-15 -2663 (|t#9| $)) (-15 -3011 (|t#8| $)) (-15 -3204 (|t#1| $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T) ((-1117) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2294 (((-1191) $) NIL)) (-2913 (((-790) $) NIL)) (-2725 (((-1191) $ (-1191)) NIL)) (-2969 (((-790) $ (-790)) NIL)) (-3807 (((-995 |#1|) $ (-995 |#1|)) NIL)) (-2138 (((-790) $ (-790)) NIL)) (-2483 (((-33 (-884 |#1|)) $ (-33 (-884 |#1|))) NIL)) (-2598 (((-658 (-801 (-884 |#1|))) $ (-658 (-801 (-884 |#1|)))) NIL)) (-3710 (((-258 (-949 |#1|)) $ (-258 (-949 |#1|))) NIL)) (-2450 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) (-884 |#1|)) $ (-264 (-4466 (QUOTE X) (QUOTE -3820)) (-884 |#1|))) NIL)) (-4153 ((|#3| $ |#3|) NIL)) (-4501 (((-995 |#1|) $) NIL)) (-2903 (((-790) $) NIL)) (-4399 (((-33 (-884 |#1|)) $) NIL)) (-3607 (((-658 (-801 (-884 |#1|))) $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3767 (((-141) (-141)) NIL) (((-141)) NIL)) (-1736 (((-877) $) NIL)) (-3011 (((-258 (-949 |#1|)) $) NIL)) (-4525 (((-944) $) NIL)) (-1761 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) (-884 |#1|)) $) NIL)) (-2443 (($ (-995 |#1|) (-264 (-4466 (QUOTE X) (QUOTE -3820)) (-884 |#1|)) (-33 (-884 |#1|)) (-790) |#3| (-790) (-258 (-949 |#1|)) (-884 |#1|) (-1191)) NIL) (($ (-995 |#1|) (-264 |#2| (-884 |#1|))) NIL)) (-1683 (((-877) $) NIL)) (-2663 ((|#3| $) NIL)) (-3204 (((-884 |#1|) $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-561 |#1| |#2| |#3|) (-13 (-560 (-884 |#1|) |#2| (-264 |#2| (-884 |#1|)) (-254 (-1699 |#2|) (-790)) (-995 |#1|) (-801 (-884 |#1|)) (-949 |#1|) (-258 (-949 |#1|)) |#3|) (-10 -8 (-15 -1736 ((-877) $)) (-15 -3767 ((-141) (-141))) (-15 -3767 ((-141))))) (-373) (-658 (-1191)) (-137)) (T -561)) 
+((-1736 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-561 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3767 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-561 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3767 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-561 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(-13 (-560 (-884 |#1|) |#2| (-264 |#2| (-884 |#1|)) (-254 (-1699 |#2|) (-790)) (-995 |#1|) (-801 (-884 |#1|)) (-949 |#1|) (-258 (-949 |#1|)) |#3|) (-10 -8 (-15 -1736 ((-877) $)) (-15 -3767 ((-141) (-141))) (-15 -3767 ((-141))))) 
+((-1641 (((-141) $ $) NIL)) (-2294 (((-1191) $) 42)) (-2913 (((-790) $) 48)) (-2725 (((-1191) $ (-1191)) 81)) (-2969 (((-790) $ (-790)) 71)) (-3807 ((|#5| $ |#5|) 74)) (-2138 (((-790) $ (-790)) 77)) (-2483 (((-33 |#1|) $ (-33 |#1|)) 76)) (-2598 (((-658 |#6|) $ (-658 |#6|)) 79)) (-3710 ((|#8| $ |#8|) 80)) (-2450 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) $ (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|)) 75)) (-4153 ((|#9| $ |#9|) 78)) (-4501 ((|#5| $) 40)) (-2903 (((-790) $) 43)) (-4399 (((-33 |#1|) $) 45)) (-3607 (((-658 |#6|) $) 73)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3767 (((-141) (-141)) 52) (((-141)) 53)) (-1736 (((-877) $) 50)) (-3011 ((|#8| $) 47)) (-4525 (((-944) $) 58)) (-1761 (((-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) $) 44)) (-2443 (($ |#5| (-264 (-4466 (QUOTE X) (QUOTE -3820)) |#1|) (-33 |#1|) (-790) |#9| (-790) |#8| |#1| (-1191)) 59) (($ |#5| |#3|) 70)) (-1683 (((-877) $) 54)) (-2663 ((|#9| $) 46)) (-3204 ((|#1| $) 55)) (-3255 (((-141) $ $) NIL))) 
+(((-562 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-13 (-560 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-10 -8 (-15 -1736 ((-877) $)) (-15 -3767 ((-141) (-141))) (-15 -3767 ((-141))))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|) (-665 |#1|) (-947 |#1| |#6|) (-257 |#7|) (-137)) (T -562)) 
+((-1736 (*1 *2 *1) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-5 *2 (-877)) (-5 *1 (-562 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *10 (-257 *9)) (-4 *11 (-137)))) (-3767 (*1 *2 *2) (-12 (-5 *2 (-141)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-5 *1 (-562 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *10 (-257 *9)) (-4 *11 (-137)))) (-3767 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-5 *2 (-141)) (-5 *1 (-562 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *10 (-257 *9)) (-4 *11 (-137))))) 
+(-13 (-560 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-10 -8 (-15 -1736 ((-877) $)) (-15 -3767 ((-141) (-141))) (-15 -3767 ((-141))))) 
+((-4374 (((-862 (-592))) 11)) (-4366 (((-862 (-592))) 13)) (-4109 (((-855 (-592))) 8))) 
+(((-563) (-10 -7 (-15 -4109 ((-855 (-592)))) (-15 -4374 ((-862 (-592)))) (-15 -4366 ((-862 (-592)))))) (T -563)) 
+((-4366 (*1 *2) (-12 (-5 *2 (-862 (-592))) (-5 *1 (-563)))) (-4374 (*1 *2) (-12 (-5 *2 (-862 (-592))) (-5 *1 (-563)))) (-4109 (*1 *2) (-12 (-5 *2 (-855 (-592))) (-5 *1 (-563))))) 
+(-10 -7 (-15 -4109 ((-855 (-592)))) (-15 -4374 ((-862 (-592)))) (-15 -4366 ((-862 (-592))))) 
+((-2136 (((-565) (-1191)) 15)) (-3193 ((|#1| (-565)) 20))) 
+(((-564 |#1|) (-10 -7 (-15 -2136 ((-565) (-1191))) (-15 -3193 (|#1| (-565)))) (-1225)) (T -564)) 
+((-3193 (*1 *2 *3) (-12 (-5 *3 (-565)) (-5 *1 (-564 *2)) (-4 *2 (-1225)))) (-2136 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-565)) (-5 *1 (-564 *4)) (-4 *4 (-1225))))) 
+(-10 -7 (-15 -2136 ((-565) (-1191))) (-15 -3193 (|#1| (-565)))) 
+((-1641 (((-141) $ $) NIL)) (-4354 (((-1173) $) 46)) (-4188 (((-141) $) 43)) (-1398 (((-1191) $) 44)) (-4602 (((-141) $) 41)) (-4574 (((-1173) $) 42)) (-3168 (($ (-1173)) 47)) (-1549 (((-141) $) NIL)) (-2830 (((-141) $) NIL)) (-1968 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-2071 (($ $ (-658 (-1191))) 20)) (-3193 (((-57) $) 22)) (-4277 (((-141) $) NIL)) (-4553 (((-592) $) NIL)) (-2951 (((-1137) $) NIL)) (-1325 (($ $ (-658 (-1191)) (-1191)) 59)) (-4603 (((-141) $) NIL)) (-4540 (((-237) $) NIL)) (-1783 (($ $) 38)) (-1564 (((-877) $) NIL)) (-2042 (((-141) $ $) NIL)) (-3927 (($ $ (-592)) NIL) (($ $ (-658 (-592))) NIL)) (-4518 (((-658 $) $) 28)) (-3064 (((-1191) (-658 $)) 48)) (-1778 (($ (-658 $)) 52) (($ (-1173)) NIL) (($ (-1191)) 18) (($ (-592)) 8) (($ (-237)) 25) (($ (-877)) NIL) (((-1123) $) 11) (($ (-1123)) 12)) (-4258 (((-1191) (-1191) (-658 $)) 51)) (-1683 (((-877) $) NIL)) (-1565 (($ $) 50)) (-1558 (($ $) 49)) (-2514 (($ $ (-658 $)) 56)) (-2767 (((-141) $) 27)) (-3514 (($) 9 T CONST)) (-4257 (($) 10 T CONST)) (-3255 (((-141) $ $) 60)) (-3313 (($ $ $) 65)) (-3300 (($ $ $) 61)) (** (($ $ (-790)) 64) (($ $ (-592)) 63)) (* (($ $ $) 62)) (-1699 (((-592) $) NIL))) 
+(((-565) (-13 (-1122 (-1173) (-1191) (-592) (-237) (-877)) (-633 (-1123)) (-10 -8 (-15 -3193 ((-57) $)) (-15 -1778 ($ (-1123))) (-15 -2514 ($ $ (-658 $))) (-15 -1325 ($ $ (-658 (-1191)) (-1191))) (-15 -2071 ($ $ (-658 (-1191)))) (-15 -3300 ($ $ $)) (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ (-790))) (-15 ** ($ $ (-592))) (-15 0 ($) -4249) (-15 1 ($) -4249) (-15 -1783 ($ $)) (-15 -4354 ((-1173) $)) (-15 -3168 ($ (-1173))) (-15 -3064 ((-1191) (-658 $))) (-15 -4258 ((-1191) (-1191) (-658 $)))))) (T -565)) 
+((-3193 (*1 *2 *1) (-12 (-5 *2 (-57)) (-5 *1 (-565)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-1123)) (-5 *1 (-565)))) (-2514 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-565))) (-5 *1 (-565)))) (-1325 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-1191)) (-5 *1 (-565)))) (-2071 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-565)))) (-3300 (*1 *1 *1 *1) (-5 *1 (-565))) (* (*1 *1 *1 *1) (-5 *1 (-565))) (-3313 (*1 *1 *1 *1) (-5 *1 (-565))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-565)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-565)))) (-3514 (*1 *1) (-5 *1 (-565))) (-4257 (*1 *1) (-5 *1 (-565))) (-1783 (*1 *1 *1) (-5 *1 (-565))) (-4354 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-565)))) (-3168 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-565)))) (-3064 (*1 *2 *3) (-12 (-5 *3 (-658 (-565))) (-5 *2 (-1191)) (-5 *1 (-565)))) (-4258 (*1 *2 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-565))) (-5 *1 (-565))))) 
+(-13 (-1122 (-1173) (-1191) (-592) (-237) (-877)) (-633 (-1123)) (-10 -8 (-15 -3193 ((-57) $)) (-15 -1778 ($ (-1123))) (-15 -2514 ($ $ (-658 $))) (-15 -1325 ($ $ (-658 (-1191)) (-1191))) (-15 -2071 ($ $ (-658 (-1191)))) (-15 -3300 ($ $ $)) (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ (-790))) (-15 ** ($ $ (-592))) (-15 (-3514) ($) -4249) (-15 (-4257) ($) -4249) (-15 -1783 ($ $)) (-15 -4354 ((-1173) $)) (-15 -3168 ($ (-1173))) (-15 -3064 ((-1191) (-658 $))) (-15 -4258 ((-1191) (-1191) (-658 $))))) 
+((-3066 ((|#2| |#2|) 17)) (-1353 ((|#2| |#2|) 13)) (-2448 ((|#2| |#2| (-592) (-592)) 20)) (-2447 ((|#2| |#2|) 15))) 
+(((-566 |#1| |#2|) (-10 -7 (-15 -1353 (|#2| |#2|)) (-15 -2447 (|#2| |#2|)) (-15 -3066 (|#2| |#2|)) (-15 -2448 (|#2| |#2| (-592) (-592)))) (-13 (-582) (-171)) (-1270 |#1|)) (T -566)) 
+((-2448 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-592)) (-4 *4 (-13 (-582) (-171))) (-5 *1 (-566 *4 *2)) (-4 *2 (-1270 *4)))) (-3066 (*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-171))) (-5 *1 (-566 *3 *2)) (-4 *2 (-1270 *3)))) (-2447 (*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-171))) (-5 *1 (-566 *3 *2)) (-4 *2 (-1270 *3)))) (-1353 (*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-171))) (-5 *1 (-566 *3 *2)) (-4 *2 (-1270 *3))))) 
+(-10 -7 (-15 -1353 (|#2| |#2|)) (-15 -2447 (|#2| |#2|)) (-15 -3066 (|#2| |#2|)) (-15 -2448 (|#2| |#2| (-592) (-592)))) 
+((-2853 (((-658 (-310 (-980 |#2|))) (-658 |#2|) (-658 (-1191))) 32)) (-4204 (((-658 |#2|) (-980 |#1|) |#3|) 53) (((-658 |#2|) (-1187 |#1|) |#3|) 52)) (-2411 (((-658 (-658 |#2|)) (-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191)) |#3|) 87))) 
+(((-567 |#1| |#2| |#3|) (-10 -7 (-15 -4204 ((-658 |#2|) (-1187 |#1|) |#3|)) (-15 -4204 ((-658 |#2|) (-980 |#1|) |#3|)) (-15 -2411 ((-658 (-658 |#2|)) (-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191)) |#3|)) (-15 -2853 ((-658 (-310 (-980 |#2|))) (-658 |#2|) (-658 (-1191))))) (-477) (-388) (-13 (-388) (-867))) (T -567)) 
+((-2853 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-658 (-1191))) (-4 *6 (-388)) (-5 *2 (-658 (-310 (-980 *6)))) (-5 *1 (-567 *5 *6 *7)) (-4 *5 (-477)) (-4 *7 (-13 (-388) (-867))))) (-2411 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-658 (-980 *6))) (-5 *4 (-658 (-1191))) (-4 *6 (-477)) (-5 *2 (-658 (-658 *7))) (-5 *1 (-567 *6 *7 *5)) (-4 *7 (-388)) (-4 *5 (-13 (-388) (-867))))) (-4204 (*1 *2 *3 *4) (-12 (-5 *3 (-980 *5)) (-4 *5 (-477)) (-5 *2 (-658 *6)) (-5 *1 (-567 *5 *6 *4)) (-4 *6 (-388)) (-4 *4 (-13 (-388) (-867))))) (-4204 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 *5)) (-4 *5 (-477)) (-5 *2 (-658 *6)) (-5 *1 (-567 *5 *6 *4)) (-4 *6 (-388)) (-4 *4 (-13 (-388) (-867)))))) 
+(-10 -7 (-15 -4204 ((-658 |#2|) (-1187 |#1|) |#3|)) (-15 -4204 ((-658 |#2|) (-980 |#1|) |#3|)) (-15 -2411 ((-658 (-658 |#2|)) (-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191)) |#3|)) (-15 -2853 ((-658 (-310 (-980 |#2|))) (-658 |#2|) (-658 (-1191))))) 
+((-3674 ((|#2| |#2| |#1|) 17)) (-1846 ((|#2| (-658 |#2|)) 26)) (-4025 ((|#2| (-658 |#2|)) 45))) 
+(((-568 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1846 (|#2| (-658 |#2|))) (-15 -4025 (|#2| (-658 |#2|))) (-15 -3674 (|#2| |#2| |#1|))) (-323) (-1255 |#1|) |#1| (-1 |#1| |#1| (-790))) (T -568)) 
+((-3674 (*1 *2 *2 *3) (-12 (-4 *3 (-323)) (-14 *4 *3) (-14 *5 (-1 *3 *3 (-790))) (-5 *1 (-568 *3 *2 *4 *5)) (-4 *2 (-1255 *3)))) (-4025 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-1255 *4)) (-5 *1 (-568 *4 *2 *5 *6)) (-4 *4 (-323)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-790))))) (-1846 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-1255 *4)) (-5 *1 (-568 *4 *2 *5 *6)) (-4 *4 (-323)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-790)))))) 
+(-10 -7 (-15 -1846 (|#2| (-658 |#2|))) (-15 -4025 (|#2| (-658 |#2|))) (-15 -3674 (|#2| |#2| |#1|))) 
+((-4500 (((-444 (-1187 |#4|)) (-1187 |#4|) (-1 (-444 (-1187 |#3|)) (-1187 |#3|))) 79) (((-444 |#4|) |#4| (-1 (-444 (-1187 |#3|)) (-1187 |#3|))) 164))) 
+(((-569 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4500 ((-444 |#4|) |#4| (-1 (-444 (-1187 |#3|)) (-1187 |#3|)))) (-15 -4500 ((-444 (-1187 |#4|)) (-1187 |#4|) (-1 (-444 (-1187 |#3|)) (-1187 |#3|))))) (-869) (-815) (-13 (-323) (-171)) (-977 |#3| |#2| |#1|)) (T -569)) 
+((-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-444 (-1187 *7)) (-1187 *7))) (-4 *7 (-13 (-323) (-171))) (-4 *5 (-869)) (-4 *6 (-815)) (-4 *8 (-977 *7 *6 *5)) (-5 *2 (-444 (-1187 *8))) (-5 *1 (-569 *5 *6 *7 *8)) (-5 *3 (-1187 *8)))) (-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-444 (-1187 *7)) (-1187 *7))) (-4 *7 (-13 (-323) (-171))) (-4 *5 (-869)) (-4 *6 (-815)) (-5 *2 (-444 *3)) (-5 *1 (-569 *5 *6 *7 *3)) (-4 *3 (-977 *7 *6 *5))))) 
+(-10 -7 (-15 -4500 ((-444 |#4|) |#4| (-1 (-444 (-1187 |#3|)) (-1187 |#3|)))) (-15 -4500 ((-444 (-1187 |#4|)) (-1187 |#4|) (-1 (-444 (-1187 |#3|)) (-1187 |#3|))))) 
+((-3066 ((|#4| |#4|) 73)) (-1353 ((|#4| |#4|) 69)) (-2448 ((|#4| |#4| (-592) (-592)) 75)) (-2447 ((|#4| |#4|) 71))) 
+(((-570 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1353 (|#4| |#4|)) (-15 -2447 (|#4| |#4|)) (-15 -3066 (|#4| |#4|)) (-15 -2448 (|#4| |#4| (-592) (-592)))) (-13 (-388) (-394) (-633 (-592))) (-1255 |#1|) (-741 |#1| |#2|) (-1270 |#3|)) (T -570)) 
+((-2448 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-592)) (-4 *4 (-13 (-388) (-394) (-633 *3))) (-4 *5 (-1255 *4)) (-4 *6 (-741 *4 *5)) (-5 *1 (-570 *4 *5 *6 *2)) (-4 *2 (-1270 *6)))) (-3066 (*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-4 *4 (-1255 *3)) (-4 *5 (-741 *3 *4)) (-5 *1 (-570 *3 *4 *5 *2)) (-4 *2 (-1270 *5)))) (-2447 (*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-4 *4 (-1255 *3)) (-4 *5 (-741 *3 *4)) (-5 *1 (-570 *3 *4 *5 *2)) (-4 *2 (-1270 *5)))) (-1353 (*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-4 *4 (-1255 *3)) (-4 *5 (-741 *3 *4)) (-5 *1 (-570 *3 *4 *5 *2)) (-4 *2 (-1270 *5))))) 
+(-10 -7 (-15 -1353 (|#4| |#4|)) (-15 -2447 (|#4| |#4|)) (-15 -3066 (|#4| |#4|)) (-15 -2448 (|#4| |#4| (-592) (-592)))) 
+((-3066 ((|#2| |#2|) 27)) (-1353 ((|#2| |#2|) 23)) (-2448 ((|#2| |#2| (-592) (-592)) 29)) (-2447 ((|#2| |#2|) 25))) 
+(((-571 |#1| |#2|) (-10 -7 (-15 -1353 (|#2| |#2|)) (-15 -2447 (|#2| |#2|)) (-15 -3066 (|#2| |#2|)) (-15 -2448 (|#2| |#2| (-592) (-592)))) (-13 (-388) (-394) (-633 (-592))) (-1270 |#1|)) (T -571)) 
+((-2448 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-592)) (-4 *4 (-13 (-388) (-394) (-633 *3))) (-5 *1 (-571 *4 *2)) (-4 *2 (-1270 *4)))) (-3066 (*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-5 *1 (-571 *3 *2)) (-4 *2 (-1270 *3)))) (-2447 (*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-5 *1 (-571 *3 *2)) (-4 *2 (-1270 *3)))) (-1353 (*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-5 *1 (-571 *3 *2)) (-4 *2 (-1270 *3))))) 
+(-10 -7 (-15 -1353 (|#2| |#2|)) (-15 -2447 (|#2| |#2|)) (-15 -3066 (|#2| |#2|)) (-15 -2448 (|#2| |#2| (-592) (-592)))) 
+((-2045 (((-3 (-592) "failed") |#2| |#1| (-1 (-3 (-592) "failed") |#1|)) 14) (((-3 (-592) "failed") |#2| |#1| (-592) (-1 (-3 (-592) "failed") |#1|)) 13) (((-3 (-592) "failed") |#2| (-592) (-1 (-3 (-592) "failed") |#1|)) 26))) 
+(((-572 |#1| |#2|) (-10 -7 (-15 -2045 ((-3 (-592) "failed") |#2| (-592) (-1 (-3 (-592) "failed") |#1|))) (-15 -2045 ((-3 (-592) "failed") |#2| |#1| (-592) (-1 (-3 (-592) "failed") |#1|))) (-15 -2045 ((-3 (-592) "failed") |#2| |#1| (-1 (-3 (-592) "failed") |#1|)))) (-1075) (-1255 |#1|)) (T -572)) 
+((-2045 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-592) "failed") *4)) (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-572 *4 *3)) (-4 *3 (-1255 *4)))) (-2045 (*1 *2 *3 *4 *2 *5) (|partial| -12 (-5 *5 (-1 (-3 (-592) "failed") *4)) (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-572 *4 *3)) (-4 *3 (-1255 *4)))) (-2045 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *4 (-1 (-3 (-592) "failed") *5)) (-4 *5 (-1075)) (-5 *2 (-592)) (-5 *1 (-572 *5 *3)) (-4 *3 (-1255 *5))))) 
+(-10 -7 (-15 -2045 ((-3 (-592) "failed") |#2| (-592) (-1 (-3 (-592) "failed") |#1|))) (-15 -2045 ((-3 (-592) "failed") |#2| |#1| (-592) (-1 (-3 (-592) "failed") |#1|))) (-15 -2045 ((-3 (-592) "failed") |#2| |#1| (-1 (-3 (-592) "failed") |#1|)))) 
+((-2204 (($ $ $) 78)) (-3164 (((-444 $) $) 46)) (-4368 (((-3 (-592) "failed") $) 58)) (-2400 (((-592) $) 36)) (-4182 (((-3 (-433 (-592)) "failed") $) 73)) (-2435 (((-141) $) 23)) (-2270 (((-433 (-592)) $) 71)) (-2802 (((-141) $) 49)) (-2520 (($ $ $ $) 85)) (-1691 (((-141) $) 15)) (-3870 (($ $ $) 56)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 68)) (-3921 (((-3 $ "failed") $) 63)) (-4561 (($ $) 22)) (-4092 (($ $ $) 83)) (-3703 (($) 59)) (-2283 (($ $) 52)) (-4500 (((-444 $) $) 44)) (-3554 (((-141) $) 13)) (-2769 (((-790) $) 27)) (-3644 (($ $ (-790)) NIL) (($ $) 10)) (-4599 (($ $) 16)) (-1778 (((-592) $) NIL) (((-565) $) 35) (((-914 (-592)) $) 39) (((-405) $) 30) (((-237) $) 32)) (-4010 (((-790)) 8)) (-3911 (((-141) $ $) 19)) (-4042 (($ $ $) 54))) 
+(((-573 |#1|) (-10 -8 (-15 -4092 (|#1| |#1| |#1|)) (-15 -2520 (|#1| |#1| |#1| |#1|)) (-15 -4561 (|#1| |#1|)) (-15 -4599 (|#1| |#1|)) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -2204 (|#1| |#1| |#1|)) (-15 -3911 ((-141) |#1| |#1|)) (-15 -3554 ((-141) |#1|)) (-15 -3703 (|#1|)) (-15 -3921 ((-3 |#1| "failed") |#1|)) (-15 -1778 ((-237) |#1|)) (-15 -1778 ((-405) |#1|)) (-15 -3870 (|#1| |#1| |#1|)) (-15 -2283 (|#1| |#1|)) (-15 -4042 (|#1| |#1| |#1|)) (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|))) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -1778 ((-592) |#1|)) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -1691 ((-141) |#1|)) (-15 -2769 ((-790) |#1|)) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -2802 ((-141) |#1|)) (-15 -4010 ((-790)))) (-574)) (T -573)) 
+((-4010 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-573 *3)) (-4 *3 (-574))))) 
+(-10 -8 (-15 -4092 (|#1| |#1| |#1|)) (-15 -2520 (|#1| |#1| |#1| |#1|)) (-15 -4561 (|#1| |#1|)) (-15 -4599 (|#1| |#1|)) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -2204 (|#1| |#1| |#1|)) (-15 -3911 ((-141) |#1| |#1|)) (-15 -3554 ((-141) |#1|)) (-15 -3703 (|#1|)) (-15 -3921 ((-3 |#1| "failed") |#1|)) (-15 -1778 ((-237) |#1|)) (-15 -1778 ((-405) |#1|)) (-15 -3870 (|#1| |#1| |#1|)) (-15 -2283 (|#1| |#1|)) (-15 -4042 (|#1| |#1| |#1|)) (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|))) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -1778 ((-592) |#1|)) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -1691 ((-141) |#1|)) (-15 -2769 ((-790) |#1|)) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -2802 ((-141) |#1|)) (-15 -4010 ((-790)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2204 (($ $ $) 83)) (-2350 (((-3 $ "failed") $ $) 18)) (-1686 (($ $ $ $) 71)) (-3743 (($ $) 50)) (-3164 (((-444 $) $) 51)) (-3652 (((-141) $ $) 123)) (-3940 (((-592) $) 112)) (-3651 (($ $ $) 86)) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 104)) (-2400 (((-592) $) 103)) (-1586 (($ $ $) 127)) (-3945 (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 102) (((-706 (-592)) (-706 $)) 101)) (-3371 (((-3 $ "failed") $) 33)) (-4182 (((-3 (-433 (-592)) "failed") $) 80)) (-2435 (((-141) $) 82)) (-2270 (((-433 (-592)) $) 81)) (-4290 (($) 79) (($ $) 78)) (-1599 (($ $ $) 126)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 121)) (-2802 (((-141) $) 52)) (-2520 (($ $ $ $) 69)) (-1592 (($ $ $) 84)) (-1691 (((-141) $) 114)) (-3870 (($ $ $) 95)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 98)) (-3558 (((-141) $) 30)) (-3372 (((-141) $) 90)) (-3921 (((-3 $ "failed") $) 92)) (-1324 (((-141) $) 113)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 130)) (-3260 (($ $ $ $) 70)) (-1837 (($ $ $) 115)) (-3319 (($ $ $) 116)) (-4561 (($ $) 73)) (-4233 (($ $) 87)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 48)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4092 (($ $ $) 68)) (-3703 (($) 91 T CONST)) (-4185 (($ $) 75)) (-2951 (((-1137) $) 10) (($ $) 77)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-2283 (($ $) 96)) (-4500 (((-444 $) $) 49)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 129) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 128)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 122)) (-3554 (((-141) $) 89)) (-2769 (((-790) $) 124)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 125)) (-3644 (($ $ (-790)) 109) (($ $) 107)) (-1676 (($ $) 74)) (-4599 (($ $) 76)) (-1778 (((-592) $) 106) (((-565) $) 100) (((-914 (-592)) $) 99) (((-405) $) 94) (((-237) $) 93)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-592)) 105)) (-4010 (((-790)) 28)) (-3911 (((-141) $ $) 85)) (-4042 (($ $ $) 97)) (-4226 (($) 88)) (-2537 (((-141) $ $) 38)) (-1475 (($ $ $ $) 72)) (-1392 (($ $) 111)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-790)) 110) (($ $) 108)) (-3286 (((-141) $ $) 118)) (-3273 (((-141) $ $) 119)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 117)) (-3266 (((-141) $ $) 120)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-574) (-1311)) (T -574)) 
+((-3372 (*1 *2 *1) (-12 (-4 *1 (-574)) (-5 *2 (-141)))) (-3554 (*1 *2 *1) (-12 (-4 *1 (-574)) (-5 *2 (-141)))) (-4226 (*1 *1) (-4 *1 (-574))) (-4233 (*1 *1 *1) (-4 *1 (-574))) (-3651 (*1 *1 *1 *1) (-4 *1 (-574))) (-3911 (*1 *2 *1 *1) (-12 (-4 *1 (-574)) (-5 *2 (-141)))) (-1592 (*1 *1 *1 *1) (-4 *1 (-574))) (-2204 (*1 *1 *1 *1) (-4 *1 (-574))) (-2435 (*1 *2 *1) (-12 (-4 *1 (-574)) (-5 *2 (-141)))) (-2270 (*1 *2 *1) (-12 (-4 *1 (-574)) (-5 *2 (-433 (-592))))) (-4182 (*1 *2 *1) (|partial| -12 (-4 *1 (-574)) (-5 *2 (-433 (-592))))) (-4290 (*1 *1) (-4 *1 (-574))) (-4290 (*1 *1 *1) (-4 *1 (-574))) (-2951 (*1 *1 *1) (-4 *1 (-574))) (-4599 (*1 *1 *1) (-4 *1 (-574))) (-4185 (*1 *1 *1) (-4 *1 (-574))) (-1676 (*1 *1 *1) (-4 *1 (-574))) (-4561 (*1 *1 *1) (-4 *1 (-574))) (-1475 (*1 *1 *1 *1 *1) (-4 *1 (-574))) (-1686 (*1 *1 *1 *1 *1) (-4 *1 (-574))) (-3260 (*1 *1 *1 *1 *1) (-4 *1 (-574))) (-2520 (*1 *1 *1 *1 *1) (-4 *1 (-574))) (-4092 (*1 *1 *1 *1) (-4 *1 (-574)))) 
+(-13 (-1235) (-323) (-842) (-247) (-633 (-592)) (-1065 (-592)) (-654 (-592)) (-633 (-565)) (-633 (-914 (-592))) (-908 (-592)) (-167) (-1049) (-171) (-1165) (-10 -8 (-15 -3372 ((-141) $)) (-15 -3554 ((-141) $)) (-6 -4624) (-15 -4226 ($)) (-15 -4233 ($ $)) (-15 -3651 ($ $ $)) (-15 -3911 ((-141) $ $)) (-15 -1592 ($ $ $)) (-15 -2204 ($ $ $)) (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $)) (-15 -4290 ($)) (-15 -4290 ($ $)) (-15 -2951 ($ $)) (-15 -4599 ($ $)) (-15 -4185 ($ $)) (-15 -1676 ($ $)) (-15 -4561 ($ $)) (-15 -1475 ($ $ $ $)) (-15 -1686 ($ $ $ $)) (-15 -3260 ($ $ $ $)) (-15 -2520 ($ $ $ $)) (-15 -4092 ($ $ $)) (-6 -4623))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-171) . T) ((-632 (-877)) . T) ((-167) . T) ((-194) . T) ((-633 (-237)) . T) ((-633 (-405)) . T) ((-633 (-565)) . T) ((-633 (-592)) . T) ((-633 (-914 (-592))) . T) ((-247) . T) ((-307) . T) ((-323) . T) ((-477) . T) ((-582) . T) ((-661 $) . T) ((-678) . T) ((-654 (-592)) . T) ((-734 $) . T) ((-743) . T) ((-813) . T) ((-814) . T) ((-816) . T) ((-817) . T) ((-842) . T) ((-867) . T) ((-869) . T) ((-908 (-592)) . T) ((-943) . T) ((-1049) . T) ((-1065 (-592)) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) . T) ((-1235) . T)) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3898 (((-1285) $ |#1| |#1|) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#2| $ |#1| |#2|) NIL)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 |#2| "failed") |#1| $) NIL)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) NIL)) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) NIL)) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 ((|#1| $) NIL (|has| |#1| (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 ((|#1| $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-2840 (((-658 |#1|) $) NIL)) (-2396 (((-141) |#1| $) NIL)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3708 (((-658 |#1|) $) NIL)) (-3780 (((-141) |#1| $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1918 ((|#2| $) NIL (|has| |#1| (-869)))) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-575 |#1| |#2| |#3|) (-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625))) (-1119) (-1119) (-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625)))) (T -575)) 
+NIL 
+(-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625))) 
+((-2523 (((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) (-1 (-1187 |#2|) (-1187 |#2|))) 49))) 
+(((-576 |#1| |#2|) (-10 -7 (-15 -2523 ((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) (-1 (-1187 |#2|) (-1187 |#2|))))) (-13 (-869) (-582)) (-13 (-27) (-456 |#1|))) (T -576)) 
+((-2523 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-631 *3)) (-5 *5 (-1 (-1187 *3) (-1187 *3))) (-4 *3 (-13 (-27) (-456 *6))) (-4 *6 (-13 (-869) (-582))) (-5 *2 (-609 *3)) (-5 *1 (-576 *6 *3))))) 
+(-10 -7 (-15 -2523 ((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) (-1 (-1187 |#2|) (-1187 |#2|))))) 
+((-2748 (((-609 |#5|) |#5| (-1 |#3| |#3|)) 195)) (-1709 (((-3 |#5| "failed") |#5| (-1 |#3| |#3|)) 191)) (-2532 (((-609 |#5|) |#5| (-1 |#3| |#3|)) 198))) 
+(((-577 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2532 ((-609 |#5|) |#5| (-1 |#3| |#3|))) (-15 -2748 ((-609 |#5|) |#5| (-1 |#3| |#3|))) (-15 -1709 ((-3 |#5| "failed") |#5| (-1 |#3| |#3|)))) (-13 (-869) (-582) (-1065 (-592))) (-13 (-27) (-456 |#1|)) (-1255 |#2|) (-1255 (-433 |#3|)) (-362 |#2| |#3| |#4|)) (T -577)) 
+((-1709 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-27) (-456 *4))) (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-4 *7 (-1255 (-433 *6))) (-5 *1 (-577 *4 *5 *6 *7 *2)) (-4 *2 (-362 *5 *6 *7)))) (-2748 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1255 *6)) (-4 *6 (-13 (-27) (-456 *5))) (-4 *5 (-13 (-869) (-582) (-1065 (-592)))) (-4 *8 (-1255 (-433 *7))) (-5 *2 (-609 *3)) (-5 *1 (-577 *5 *6 *7 *8 *3)) (-4 *3 (-362 *6 *7 *8)))) (-2532 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1255 *6)) (-4 *6 (-13 (-27) (-456 *5))) (-4 *5 (-13 (-869) (-582) (-1065 (-592)))) (-4 *8 (-1255 (-433 *7))) (-5 *2 (-609 *3)) (-5 *1 (-577 *5 *6 *7 *8 *3)) (-4 *3 (-362 *6 *7 *8))))) 
+(-10 -7 (-15 -2532 ((-609 |#5|) |#5| (-1 |#3| |#3|))) (-15 -2748 ((-609 |#5|) |#5| (-1 |#3| |#3|))) (-15 -1709 ((-3 |#5| "failed") |#5| (-1 |#3| |#3|)))) 
+((-3169 (((-141) (-592) (-592)) 10)) (-2202 (((-592) (-592)) 7)) (-1811 (((-592) (-592) (-592)) 8))) 
+(((-578) (-10 -7 (-15 -2202 ((-592) (-592))) (-15 -1811 ((-592) (-592) (-592))) (-15 -3169 ((-141) (-592) (-592))))) (T -578)) 
+((-3169 (*1 *2 *3 *3) (-12 (-5 *3 (-592)) (-5 *2 (-141)) (-5 *1 (-578)))) (-1811 (*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-578)))) (-2202 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-578))))) 
+(-10 -7 (-15 -2202 ((-592) (-592))) (-15 -1811 ((-592) (-592) (-592))) (-15 -3169 ((-141) (-592) (-592)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3515 ((|#1| $) 59)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-1588 (($ $) 89)) (-1507 (($ $) 72)) (-4079 ((|#1| $) 60)) (-2350 (((-3 $ "failed") $ $) 18)) (-1442 (($ $) 71)) (-1575 (($ $) 88)) (-1495 (($ $) 73)) (-1601 (($ $) 87)) (-1521 (($ $) 74)) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 67)) (-2400 (((-592) $) 66)) (-3371 (((-3 $ "failed") $) 33)) (-3955 (($ |#1| |#1|) 64)) (-1691 (((-141) $) 58)) (-1435 (($) 99)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 70)) (-1324 (((-141) $) 57)) (-1837 (($ $ $) 105)) (-3319 (($ $ $) 104)) (-4546 (($ $) 96)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-1542 (($ |#1| |#1|) 65) (($ |#1|) 63) (($ (-433 (-592))) 62)) (-1817 ((|#1| $) 61)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3616 (((-3 $ "failed") $ $) 41)) (-1430 (($ $) 97)) (-1609 (($ $) 86)) (-1527 (($ $) 75)) (-1594 (($ $) 85)) (-1515 (($ $) 76)) (-1581 (($ $) 84)) (-1501 (($ $) 77)) (-3942 (((-141) $ |#1|) 56)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-592)) 68)) (-4010 (((-790)) 28)) (-1630 (($ $) 95)) (-1546 (($ $) 83)) (-2537 (((-141) $ $) 38)) (-1617 (($ $) 94)) (-1533 (($ $) 82)) (-1642 (($ $) 93)) (-1559 (($ $) 81)) (-2892 (($ $) 92)) (-1567 (($ $) 80)) (-1636 (($ $) 91)) (-1552 (($ $) 79)) (-1624 (($ $) 90)) (-1540 (($ $) 78)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3286 (((-141) $ $) 102)) (-3273 (((-141) $ $) 101)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 103)) (-3266 (((-141) $ $) 100)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ $) 98) (($ $ (-433 (-592))) 69)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-579 |#1|) (-1311) (-13 (-430) (-1211))) (T -579)) 
+((-1542 (*1 *1 *2 *2) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) (-3955 (*1 *1 *2 *2) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) (-1542 (*1 *1 *2) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) (-1542 (*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-4 *1 (-579 *3)) (-4 *3 (-13 (-430) (-1211))))) (-1817 (*1 *2 *1) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) (-4079 (*1 *2 *1) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) (-3515 (*1 *2 *1) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) (-1691 (*1 *2 *1) (-12 (-4 *1 (-579 *3)) (-4 *3 (-13 (-430) (-1211))) (-5 *2 (-141)))) (-1324 (*1 *2 *1) (-12 (-4 *1 (-579 *3)) (-4 *3 (-13 (-430) (-1211))) (-5 *2 (-141)))) (-3942 (*1 *2 *1 *3) (-12 (-4 *1 (-579 *3)) (-4 *3 (-13 (-430) (-1211))) (-5 *2 (-141))))) 
+(-13 (-477) (-869) (-1211) (-1030) (-1065 (-592)) (-10 -8 (-6 -2642) (-15 -1542 ($ |t#1| |t#1|)) (-15 -3955 ($ |t#1| |t#1|)) (-15 -1542 ($ |t#1|)) (-15 -1542 ($ (-433 (-592)))) (-15 -1817 (|t#1| $)) (-15 -4079 (|t#1| $)) (-15 -3515 (|t#1| $)) (-15 -1691 ((-141) $)) (-15 -1324 ((-141) $)) (-15 -3942 ((-141) $ |t#1|)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-40) . T) ((-116) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-301) . T) ((-307) . T) ((-477) . T) ((-526) . T) ((-582) . T) ((-661 $) . T) ((-678) . T) ((-734 $) . T) ((-743) . T) ((-869) . T) ((-1030) . T) ((-1065 (-592)) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1211) . T) ((-1214) . T)) 
+((-2742 (((-1285) (-944) |#3| (-658 |#5|)) 55)) (-1587 ((|#8| |#3| |#3| (-658 |#10|) (-658 |#5|)) 52))) 
+(((-580 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -1587 (|#8| |#3| |#3| (-658 |#10|) (-658 |#5|))) (-15 -2742 ((-1285) (-944) |#3| (-658 |#5|)))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|) (-665 |#1|) (-947 |#1| |#6|) (-257 |#7|) (-560 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-280 |#9|) (-137)) (T -580)) 
+((-2742 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-944)) (-5 *5 (-658 *9)) (-4 *9 (-999 *6)) (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *4 (-977 *6 *8 (-879 *7))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *10 (-665 *6)) (-4 *11 (-947 *6 *10)) (-4 *12 (-257 *11)) (-4 *13 (-560 *6 *7 *4 *8 *9 *10 *11 *12 *15)) (-4 *15 (-137)) (-5 *2 (-1285)) (-5 *1 (-580 *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (-4 *14 (-280 *13)))) (-1587 (*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-658 *13)) (-5 *5 (-658 *9)) (-4 *9 (-999 *6)) (-4 *13 (-280 *12)) (-4 *6 (-388)) (-4 *12 (-560 *6 *7 *3 *8 *9 *10 *11 *2 *14)) (-4 *14 (-137)) (-14 *7 (-658 (-1191))) (-4 *3 (-977 *6 *8 (-879 *7))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *10 (-665 *6)) (-4 *11 (-947 *6 *10)) (-4 *2 (-257 *11)) (-5 *1 (-580 *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14))))) 
+(-10 -7 (-15 -1587 (|#8| |#3| |#3| (-658 |#10|) (-658 |#5|))) (-15 -2742 ((-1285) (-944) |#3| (-658 |#5|)))) 
+((-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 9)) (-1555 (($ $) 11)) (-1313 (((-141) $) 18)) (-3371 (((-3 $ "failed") $) 16)) (-2537 (((-141) $ $) 20))) 
+(((-581 |#1|) (-10 -8 (-15 -1313 ((-141) |#1|)) (-15 -2537 ((-141) |#1| |#1|)) (-15 -1555 (|#1| |#1|)) (-15 -3620 ((-2 (|:| -4509 |#1|) (|:| -4612 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -3371 ((-3 |#1| "failed") |#1|))) (-582)) (T -581)) 
+NIL 
+(-10 -8 (-15 -1313 ((-141) |#1|)) (-15 -2537 ((-141) |#1| |#1|)) (-15 -1555 (|#1| |#1|)) (-15 -3620 ((-2 (|:| -4509 |#1|) (|:| -4612 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -3371 ((-3 |#1| "failed") |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ $) 41)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-582) (-1311)) (T -582)) 
+((-3616 (*1 *1 *1 *1) (|partial| -4 *1 (-582))) (-3620 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -4509 *1) (|:| -4612 *1) (|:| |associate| *1))) (-4 *1 (-582)))) (-1555 (*1 *1 *1) (-4 *1 (-582))) (-2537 (*1 *2 *1 *1) (-12 (-4 *1 (-582)) (-5 *2 (-141)))) (-1313 (*1 *2 *1) (-12 (-4 *1 (-582)) (-5 *2 (-141))))) 
+(-13 (-194) (-43 $) (-307) (-10 -8 (-15 -3616 ((-3 $ "failed") $ $)) (-15 -3620 ((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $)) (-15 -1555 ($ $)) (-15 -2537 ((-141) $ $)) (-15 -1313 ((-141) $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-661 $) . T) ((-734 $) . T) ((-743) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-2054 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1191) (-658 |#2|)) 35)) (-3357 (((-609 |#2|) |#2| (-1191)) 58)) (-2543 (((-3 |#2| "failed") |#2| (-1191)) 147)) (-2375 (((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1191) (-631 |#2|) (-658 (-631 |#2|))) 149)) (-1490 (((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1191) |#2|) 38))) 
+(((-583 |#1| |#2|) (-10 -7 (-15 -1490 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1191) |#2|)) (-15 -2054 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1191) (-658 |#2|))) (-15 -2543 ((-3 |#2| "failed") |#2| (-1191))) (-15 -3357 ((-609 |#2|) |#2| (-1191))) (-15 -2375 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1191) (-631 |#2|) (-658 (-631 |#2|))))) (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|))) (T -583)) 
+((-2375 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1191)) (-5 *6 (-658 (-631 *3))) (-5 *5 (-631 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-583 *7 *3)))) (-3357 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-583 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-2543 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-583 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))))) (-2054 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-658 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-583 *6 *3)))) (-1490 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1191)) (-4 *5 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-583 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5)))))) 
+(-10 -7 (-15 -1490 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1191) |#2|)) (-15 -2054 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1191) (-658 |#2|))) (-15 -2543 ((-3 |#2| "failed") |#2| (-1191))) (-15 -3357 ((-609 |#2|) |#2| (-1191))) (-15 -2375 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1191) (-631 |#2|) (-658 (-631 |#2|))))) 
+((-3903 (((-658 |#5|) (-658 |#5|)) 41))) 
+(((-584 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3903 ((-658 |#5|) (-658 |#5|)))) (-388) (-658 (-1191)) (-815) (-869) (-977 |#1| |#3| |#4|)) (T -584)) 
+((-3903 (*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-977 *3 *5 *6)) (-4 *3 (-388)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-584 *3 *4 *5 *6 *7)) (-14 *4 (-658 (-1191)))))) 
+(-10 -7 (-15 -3903 ((-658 |#5|) (-658 |#5|)))) 
+((-3164 (((-444 |#1|) |#1|) 18)) (-4500 (((-444 |#1|) |#1|) 32)) (-1657 (((-3 |#1| "failed") |#1|) 43)) (-3865 (((-444 |#1|) |#1|) 49))) 
+(((-585 |#1|) (-10 -7 (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -3865 ((-444 |#1|) |#1|)) (-15 -1657 ((-3 |#1| "failed") |#1|))) (-574)) (T -585)) 
+((-1657 (*1 *2 *2) (|partial| -12 (-5 *1 (-585 *2)) (-4 *2 (-574)))) (-3865 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-585 *3)) (-4 *3 (-574)))) (-3164 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-585 *3)) (-4 *3 (-574)))) (-4500 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-585 *3)) (-4 *3 (-574))))) 
+(-10 -7 (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -3865 ((-444 |#1|) |#1|)) (-15 -1657 ((-3 |#1| "failed") |#1|))) 
+((-2225 (((-658 |#3|) |#8| (-658 |#3|)) 45)) (-4507 (((-658 |#3|) |#8| (-790) |#3| (-658 |#3|)) 44)) (-3629 (((-658 (-1280 |#1|)) |#8| (-658 |#3|)) 26)) (-2129 (((-658 (-1280 |#1|)) |#8| (-658 |#3|)) 27))) 
+(((-586 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2129 ((-658 (-1280 |#1|)) |#8| (-658 |#3|))) (-15 -3629 ((-658 (-1280 |#1|)) |#8| (-658 |#3|))) (-15 -2225 ((-658 |#3|) |#8| (-658 |#3|))) (-15 -4507 ((-658 |#3|) |#8| (-790) |#3| (-658 |#3|)))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|) (-665 |#1|) (-947 |#1| |#6|) (-257 |#7|)) (T -586)) 
+((-4507 (*1 *2 *3 *4 *5 *2) (-12 (-5 *2 (-658 *5)) (-4 *5 (-977 *6 *8 (-879 *7))) (-4 *8 (-252 (-1699 *7) *4)) (-5 *4 (-790)) (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *10 (-665 *6)) (-4 *11 (-947 *6 *10)) (-5 *1 (-586 *6 *7 *5 *8 *9 *10 *11 *3)) (-4 *9 (-999 *6)) (-4 *3 (-257 *11)))) (-2225 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-5 *1 (-586 *4 *5 *6 *7 *8 *9 *10 *3)) (-4 *8 (-999 *4)) (-4 *3 (-257 *10)))) (-3629 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *7)) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) (-790))) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-5 *2 (-658 (-1280 *5))) (-5 *1 (-586 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-999 *5)) (-4 *3 (-257 *11)))) (-2129 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *7)) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) (-790))) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-5 *2 (-658 (-1280 *5))) (-5 *1 (-586 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-999 *5)) (-4 *3 (-257 *11))))) 
+(-10 -7 (-15 -2129 ((-658 (-1280 |#1|)) |#8| (-658 |#3|))) (-15 -3629 ((-658 (-1280 |#1|)) |#8| (-658 |#3|))) (-15 -2225 ((-658 |#3|) |#8| (-658 |#3|))) (-15 -4507 ((-658 |#3|) |#8| (-790) |#3| (-658 |#3|)))) 
+((-1670 (($) 9)) (-4246 (((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 29)) (-2840 (((-658 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) $) 26)) (-2113 (($ (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) 23)) (-2942 (($ (-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) 21)) (-3552 (((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 33)) (-4210 (((-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $) 31)) (-2057 (((-1285)) 12))) 
+(((-587) (-10 -8 (-15 -1670 ($)) (-15 -2057 ((-1285))) (-15 -2840 ((-658 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) $)) (-15 -2942 ($ (-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))))) (-15 -2113 ($ (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-15 -4246 ((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -4210 ((-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $)) (-15 -3552 ((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) (T -587)) 
+((-3552 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-587)))) (-4210 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-587)))) (-4246 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-587)))) (-2113 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (-5 *1 (-587)))) (-2942 (*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-587)))) (-2840 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-5 *1 (-587)))) (-2057 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-587)))) (-1670 (*1 *1) (-5 *1 (-587)))) 
+(-10 -8 (-15 -1670 ($)) (-15 -2057 ((-1285))) (-15 -2840 ((-658 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) $)) (-15 -2942 ($ (-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))))) (-15 -2113 ($ (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-15 -4246 ((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -4210 ((-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $)) (-15 -3552 ((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) 
+((-4492 (((-1187 (-433 (-1187 |#2|))) |#2| (-631 |#2|) (-631 |#2|) (-1187 |#2|)) 28)) (-1879 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|))) 96) (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|) |#2| (-1187 |#2|)) 106)) (-3529 (((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|))) 78) (((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) |#2| (-1187 |#2|)) 50)) (-3876 (((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2| (-631 |#2|) |#2| (-433 (-1187 |#2|))) 85) (((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2| |#2| (-1187 |#2|)) 105)) (-1606 (((-3 |#2| "failed") |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191)) (-631 |#2|) |#2| (-433 (-1187 |#2|))) 101) (((-3 |#2| "failed") |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191)) |#2| (-1187 |#2|)) 107)) (-2770 (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|))) 124 (|has| |#3| (-670 |#2|))) (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) |#2| (-1187 |#2|)) 123 (|has| |#3| (-670 |#2|)))) (-4533 ((|#2| (-1187 (-433 (-1187 |#2|))) (-631 |#2|) |#2|) 48)) (-3650 (((-1187 (-433 (-1187 |#2|))) (-1187 |#2|) (-631 |#2|)) 27))) 
+(((-588 |#1| |#2| |#3|) (-10 -7 (-15 -3529 ((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) |#2| (-1187 |#2|))) (-15 -3529 ((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|)))) (-15 -3876 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2| |#2| (-1187 |#2|))) (-15 -3876 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2| (-631 |#2|) |#2| (-433 (-1187 |#2|)))) (-15 -1879 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|) |#2| (-1187 |#2|))) (-15 -1879 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|)))) (-15 -1606 ((-3 |#2| "failed") |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191)) |#2| (-1187 |#2|))) (-15 -1606 ((-3 |#2| "failed") |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191)) (-631 |#2|) |#2| (-433 (-1187 |#2|)))) (-15 -4492 ((-1187 (-433 (-1187 |#2|))) |#2| (-631 |#2|) (-631 |#2|) (-1187 |#2|))) (-15 -4533 (|#2| (-1187 (-433 (-1187 |#2|))) (-631 |#2|) |#2|)) (-15 -3650 ((-1187 (-433 (-1187 |#2|))) (-1187 |#2|) (-631 |#2|))) (IF (|has| |#3| (-670 |#2|)) (PROGN (-15 -2770 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) |#2| (-1187 |#2|))) (-15 -2770 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|))))) |noBranch|)) (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592))) (-13 (-456 |#1|) (-27) (-1211)) (-1119)) (T -588)) 
+((-2770 (*1 *2 *3 *4 *5 *5 *5 *4 *6) (-12 (-5 *5 (-631 *4)) (-5 *6 (-433 (-1187 *4))) (-4 *4 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-588 *7 *4 *3)) (-4 *3 (-670 *4)) (-4 *3 (-1119)))) (-2770 (*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *5 (-631 *4)) (-5 *6 (-1187 *4)) (-4 *4 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-588 *7 *4 *3)) (-4 *3 (-670 *4)) (-4 *3 (-1119)))) (-3650 (*1 *2 *3 *4) (-12 (-5 *4 (-631 *6)) (-4 *6 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-1187 (-433 (-1187 *6)))) (-5 *1 (-588 *5 *6 *7)) (-5 *3 (-1187 *6)) (-4 *7 (-1119)))) (-4533 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1187 (-433 (-1187 *2)))) (-5 *4 (-631 *2)) (-4 *2 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *1 (-588 *5 *2 *6)) (-4 *6 (-1119)))) (-4492 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-631 *3)) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-1187 (-433 (-1187 *3)))) (-5 *1 (-588 *6 *3 *7)) (-5 *5 (-1187 *3)) (-4 *7 (-1119)))) (-1606 (*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| -12 (-5 *3 (-631 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1191))) (-5 *5 (-433 (-1187 *2))) (-4 *2 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *1 (-588 *6 *2 *7)) (-4 *7 (-1119)))) (-1606 (*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| -12 (-5 *3 (-631 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1191))) (-5 *5 (-1187 *2)) (-4 *2 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *1 (-588 *6 *2 *7)) (-4 *7 (-1119)))) (-1879 (*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-658 *3)) (-5 *6 (-433 (-1187 *3))) (-4 *3 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-588 *7 *3 *8)) (-4 *8 (-1119)))) (-1879 (*1 *2 *3 *4 *4 *5 *3 *6) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-658 *3)) (-5 *6 (-1187 *3)) (-4 *3 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-588 *7 *3 *8)) (-4 *8 (-1119)))) (-3876 (*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-433 (-1187 *3))) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-588 *6 *3 *7)) (-4 *7 (-1119)))) (-3876 (*1 *2 *3 *4 *4 *3 *3 *5) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-1187 *3)) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-588 *6 *3 *7)) (-4 *7 (-1119)))) (-3529 (*1 *2 *3 *4 *4 *4 *3 *5) (-12 (-5 *4 (-631 *3)) (-5 *5 (-433 (-1187 *3))) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-588 *6 *3 *7)) (-4 *7 (-1119)))) (-3529 (*1 *2 *3 *4 *4 *3 *5) (-12 (-5 *4 (-631 *3)) (-5 *5 (-1187 *3)) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-588 *6 *3 *7)) (-4 *7 (-1119))))) 
+(-10 -7 (-15 -3529 ((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) |#2| (-1187 |#2|))) (-15 -3529 ((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|)))) (-15 -3876 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2| |#2| (-1187 |#2|))) (-15 -3876 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2| (-631 |#2|) |#2| (-433 (-1187 |#2|)))) (-15 -1879 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|) |#2| (-1187 |#2|))) (-15 -1879 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|)))) (-15 -1606 ((-3 |#2| "failed") |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191)) |#2| (-1187 |#2|))) (-15 -1606 ((-3 |#2| "failed") |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191)) (-631 |#2|) |#2| (-433 (-1187 |#2|)))) (-15 -4492 ((-1187 (-433 (-1187 |#2|))) |#2| (-631 |#2|) (-631 |#2|) (-1187 |#2|))) (-15 -4533 (|#2| (-1187 (-433 (-1187 |#2|))) (-631 |#2|) |#2|)) (-15 -3650 ((-1187 (-433 (-1187 |#2|))) (-1187 |#2|) (-631 |#2|))) (IF (|has| |#3| (-670 |#2|)) (PROGN (-15 -2770 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) |#2| (-1187 |#2|))) (-15 -2770 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) (-631 |#2|) |#2| (-433 (-1187 |#2|))))) |noBranch|)) 
+((-1731 (((-592) (-592) (-790)) 65)) (-3861 (((-592) (-592)) 64)) (-2394 (((-592) (-592)) 63)) (-2417 (((-592) (-592)) 68)) (-1880 (((-592) (-592) (-592)) 48)) (-1584 (((-592) (-592) (-592)) 45)) (-3119 (((-433 (-592)) (-592)) 20)) (-3012 (((-592) (-592)) 21)) (-4324 (((-592) (-592)) 57)) (-3824 (((-592) (-592)) 32)) (-3779 (((-658 (-592)) (-592)) 62)) (-3219 (((-592) (-592) (-592) (-592) (-592)) 43)) (-4017 (((-433 (-592)) (-592)) 41))) 
+(((-589) (-10 -7 (-15 -4017 ((-433 (-592)) (-592))) (-15 -3219 ((-592) (-592) (-592) (-592) (-592))) (-15 -3779 ((-658 (-592)) (-592))) (-15 -3824 ((-592) (-592))) (-15 -4324 ((-592) (-592))) (-15 -3012 ((-592) (-592))) (-15 -3119 ((-433 (-592)) (-592))) (-15 -1584 ((-592) (-592) (-592))) (-15 -1880 ((-592) (-592) (-592))) (-15 -2417 ((-592) (-592))) (-15 -2394 ((-592) (-592))) (-15 -3861 ((-592) (-592))) (-15 -1731 ((-592) (-592) (-790))))) (T -589)) 
+((-1731 (*1 *2 *2 *3) (-12 (-5 *2 (-592)) (-5 *3 (-790)) (-5 *1 (-589)))) (-3861 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-2394 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-2417 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-1880 (*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-1584 (*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-3119 (*1 *2 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-589)) (-5 *3 (-592)))) (-3012 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-4324 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-3824 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-3779 (*1 *2 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-589)) (-5 *3 (-592)))) (-3219 (*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) (-4017 (*1 *2 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-589)) (-5 *3 (-592))))) 
+(-10 -7 (-15 -4017 ((-433 (-592)) (-592))) (-15 -3219 ((-592) (-592) (-592) (-592) (-592))) (-15 -3779 ((-658 (-592)) (-592))) (-15 -3824 ((-592) (-592))) (-15 -4324 ((-592) (-592))) (-15 -3012 ((-592) (-592))) (-15 -3119 ((-433 (-592)) (-592))) (-15 -1584 ((-592) (-592) (-592))) (-15 -1880 ((-592) (-592) (-592))) (-15 -2417 ((-592) (-592))) (-15 -2394 ((-592) (-592))) (-15 -3861 ((-592) (-592))) (-15 -1731 ((-592) (-592) (-790)))) 
+((-3957 (((-2 (|:| |answer| |#4|) (|:| -4192 |#4|)) |#4| (-1 |#2| |#2|)) 52))) 
+(((-590 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3957 ((-2 (|:| |answer| |#4|) (|:| -4192 |#4|)) |#4| (-1 |#2| |#2|)))) (-388) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|)) (T -590)) 
+((-3957 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-4 *7 (-1255 (-433 *6))) (-5 *2 (-2 (|:| |answer| *3) (|:| -4192 *3))) (-5 *1 (-590 *5 *6 *7 *3)) (-4 *3 (-362 *5 *6 *7))))) 
+(-10 -7 (-15 -3957 ((-2 (|:| |answer| |#4|) (|:| -4192 |#4|)) |#4| (-1 |#2| |#2|)))) 
+((-3957 (((-2 (|:| |answer| (-433 |#2|)) (|:| -4192 (-433 |#2|)) (|:| |specpart| (-433 |#2|)) (|:| |polypart| |#2|)) (-433 |#2|) (-1 |#2| |#2|)) 18))) 
+(((-591 |#1| |#2|) (-10 -7 (-15 -3957 ((-2 (|:| |answer| (-433 |#2|)) (|:| -4192 (-433 |#2|)) (|:| |specpart| (-433 |#2|)) (|:| |polypart| |#2|)) (-433 |#2|) (-1 |#2| |#2|)))) (-388) (-1255 |#1|)) (T -591)) 
+((-3957 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |answer| (-433 *6)) (|:| -4192 (-433 *6)) (|:| |specpart| (-433 *6)) (|:| |polypart| *6))) (-5 *1 (-591 *5 *6)) (-5 *3 (-433 *6))))) 
+(-10 -7 (-15 -3957 ((-2 (|:| |answer| (-433 |#2|)) (|:| -4192 (-433 |#2|)) (|:| |specpart| (-433 |#2|)) (|:| |polypart| |#2|)) (-433 |#2|) (-1 |#2| |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 25)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 86)) (-1555 (($ $) 87)) (-1313 (((-141) $) NIL)) (-2204 (($ $ $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1686 (($ $ $ $) 42)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL)) (-3651 (($ $ $) 80)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL)) (-2400 (((-592) $) NIL)) (-1586 (($ $ $) 79)) (-3945 (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 60) (((-706 (-592)) (-706 $)) 57)) (-3371 (((-3 $ "failed") $) 83)) (-4182 (((-3 (-433 (-592)) "failed") $) NIL)) (-2435 (((-141) $) NIL)) (-2270 (((-433 (-592)) $) NIL)) (-4290 (($) 62) (($ $) 63)) (-1599 (($ $ $) 78)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-2520 (($ $ $ $) NIL)) (-1592 (($ $ $) 54)) (-1691 (((-141) $) NIL)) (-3870 (($ $ $) NIL)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL)) (-3558 (((-141) $) 26)) (-3372 (((-141) $) 73)) (-3921 (((-3 $ "failed") $) NIL)) (-1324 (((-141) $) 34)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3260 (($ $ $ $) 43)) (-1837 (($ $ $) 75)) (-3319 (($ $ $) 74)) (-4561 (($ $) NIL)) (-4233 (($ $) 40)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) 53)) (-4092 (($ $ $) NIL)) (-3703 (($) NIL T CONST)) (-4185 (($ $) 31)) (-2951 (((-1137) $) NIL) (($ $) 33)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 117)) (-3548 (($ $ $) 84) (($ (-658 $)) NIL)) (-2283 (($ $) NIL)) (-4500 (((-444 $) $) 103)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL)) (-3616 (((-3 $ "failed") $ $) 82)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3554 (((-141) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 77)) (-3644 (($ $ (-790)) NIL) (($ $) NIL)) (-1676 (($ $) 32)) (-4599 (($ $) 30)) (-1778 (((-592) $) 39) (((-565) $) 51) (((-914 (-592)) $) NIL) (((-405) $) 46) (((-237) $) 48) (((-1173) $) 52)) (-1683 (((-877) $) 37) (($ (-592)) 38) (($ $) NIL) (($ (-592)) 38)) (-4010 (((-790)) NIL)) (-3911 (((-141) $ $) NIL)) (-4042 (($ $ $) NIL)) (-4226 (($) 29)) (-2537 (((-141) $ $) NIL)) (-1475 (($ $ $ $) 41)) (-1392 (($ $) 61)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 27 T CONST)) (-4257 (($) 28 T CONST)) (-1637 (((-1173) $) 20) (((-1173) $ (-141)) 22) (((-1285) (-844) $) 23) (((-1285) (-844) $ (-141)) 24)) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 64)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 65)) (-3306 (($ $) 66) (($ $ $) 68)) (-3300 (($ $ $) 67)) (** (($ $ (-944)) NIL) (($ $ (-790)) 72)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 70) (($ $ $) 69))) 
+(((-592) (-13 (-574) (-633 (-1173)) (-850) (-10 -8 (-15 -4290 ($ $)) (-6 -4612) (-6 -4617) (-6 -4613) (-6 -4607)))) (T -592)) 
+((-4290 (*1 *1 *1) (-5 *1 (-592)))) 
+(-13 (-574) (-633 (-1173)) (-850) (-10 -8 (-15 -4290 ($ $)) (-6 -4612) (-6 -4617) (-6 -4613) (-6 -4607))) 
+((-2617 (((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063))) (-788) (-1087)) 103) (((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063))) (-788)) 105)) (-3162 (((-3 (-1063) "failed") (-332 (-405)) (-1111 (-862 (-405))) (-1191)) 168) (((-3 (-1063) "failed") (-332 (-405)) (-1111 (-862 (-405))) (-1173)) 167) (((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405) (-405) (-1087)) 173) (((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405) (-405)) 174) (((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405)) 175) (((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405))))) 176) (((-1063) (-332 (-405)) (-1113 (-862 (-405)))) 163) (((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405)) 162) (((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405) (-405)) 158) (((-1063) (-788)) 150) (((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405) (-405) (-1087)) 157))) 
+(((-593) (-10 -7 (-15 -3162 ((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405) (-405) (-1087))) (-15 -3162 ((-1063) (-788))) (-15 -3162 ((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405) (-405))) (-15 -3162 ((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405))) (-15 -3162 ((-1063) (-332 (-405)) (-1113 (-862 (-405))))) (-15 -3162 ((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))))) (-15 -3162 ((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405))) (-15 -3162 ((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405) (-405))) (-15 -3162 ((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405) (-405) (-1087))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063))) (-788))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063))) (-788) (-1087))) (-15 -3162 ((-3 (-1063) "failed") (-332 (-405)) (-1111 (-862 (-405))) (-1173))) (-15 -3162 ((-3 (-1063) "failed") (-332 (-405)) (-1111 (-862 (-405))) (-1191))))) (T -593)) 
+((-3162 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-862 (-405)))) (-5 *5 (-1191)) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-862 (-405)))) (-5 *5 (-1173)) (-5 *2 (-1063)) (-5 *1 (-593)))) (-2617 (*1 *2 *3 *4) (-12 (-5 *3 (-788)) (-5 *4 (-1087)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063)))) (-5 *1 (-593)))) (-2617 (*1 *2 *3) (-12 (-5 *3 (-788)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063)))) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-1113 (-862 (-405))))) (-5 *5 (-405)) (-5 *6 (-1087)) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-1113 (-862 (-405))))) (-5 *5 (-405)) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-1113 (-862 (-405))))) (-5 *5 (-405)) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-1113 (-862 (-405))))) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1113 (-862 (-405)))) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1113 (-862 (-405)))) (-5 *5 (-405)) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1113 (-862 (-405)))) (-5 *5 (-405)) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3) (-12 (-5 *3 (-788)) (-5 *2 (-1063)) (-5 *1 (-593)))) (-3162 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1113 (-862 (-405)))) (-5 *5 (-405)) (-5 *6 (-1087)) (-5 *2 (-1063)) (-5 *1 (-593))))) 
+(-10 -7 (-15 -3162 ((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405) (-405) (-1087))) (-15 -3162 ((-1063) (-788))) (-15 -3162 ((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405) (-405))) (-15 -3162 ((-1063) (-332 (-405)) (-1113 (-862 (-405))) (-405))) (-15 -3162 ((-1063) (-332 (-405)) (-1113 (-862 (-405))))) (-15 -3162 ((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))))) (-15 -3162 ((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405))) (-15 -3162 ((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405) (-405))) (-15 -3162 ((-1063) (-332 (-405)) (-658 (-1113 (-862 (-405)))) (-405) (-405) (-1087))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063))) (-788))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063))) (-788) (-1087))) (-15 -3162 ((-3 (-1063) "failed") (-332 (-405)) (-1111 (-862 (-405))) (-1173))) (-15 -3162 ((-3 (-1063) "failed") (-332 (-405)) (-1111 (-862 (-405))) (-1191)))) 
+((-4163 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|)) 179)) (-2596 (((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|)) 97)) (-1638 (((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2|) 175)) (-1572 (((-3 |#2| "failed") |#2| |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191))) 184)) (-1671 (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) (-1191)) 192 (|has| |#3| (-670 |#2|))))) 
+(((-594 |#1| |#2| |#3|) (-10 -7 (-15 -2596 ((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|))) (-15 -1638 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2|)) (-15 -4163 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|))) (-15 -1572 ((-3 |#2| "failed") |#2| |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191)))) (IF (|has| |#3| (-670 |#2|)) (-15 -1671 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) (-1191))) |noBranch|)) (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592))) (-13 (-456 |#1|) (-27) (-1211)) (-1119)) (T -594)) 
+((-1671 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *5 (-631 *4)) (-5 *6 (-1191)) (-4 *4 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-594 *7 *4 *3)) (-4 *3 (-670 *4)) (-4 *3 (-1119)))) (-1572 (*1 *2 *2 *2 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-631 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1191))) (-4 *2 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *1 (-594 *5 *2 *6)) (-4 *6 (-1119)))) (-4163 (*1 *2 *3 *4 *4 *5) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-658 *3)) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-594 *6 *3 *7)) (-4 *7 (-1119)))) (-1638 (*1 *2 *3 *4 *4 *3) (|partial| -12 (-5 *4 (-631 *3)) (-4 *3 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-594 *5 *3 *6)) (-4 *6 (-1119)))) (-2596 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-631 *3)) (-4 *3 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-594 *5 *3 *6)) (-4 *6 (-1119))))) 
+(-10 -7 (-15 -2596 ((-609 |#2|) |#2| (-631 |#2|) (-631 |#2|))) (-15 -1638 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-631 |#2|) (-631 |#2|) |#2|)) (-15 -4163 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-631 |#2|) (-631 |#2|) (-658 |#2|))) (-15 -1572 ((-3 |#2| "failed") |#2| |#2| |#2| (-631 |#2|) (-631 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1191)))) (IF (|has| |#3| (-670 |#2|)) (-15 -1671 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2195 (-658 |#2|))) |#3| |#2| (-631 |#2|) (-631 |#2|) (-1191))) |noBranch|)) 
+((-3825 (((-2 (|:| -3479 |#2|) (|:| |nconst| |#2|)) |#2| (-1191)) 62)) (-2564 (((-3 |#2| "failed") |#2| (-1191) (-862 |#2|) (-862 |#2|)) 159 (-12 (|has| |#2| (-1153)) (|has| |#1| (-633 (-914 (-592)))) (|has| |#1| (-908 (-592))))) (((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191)) 133 (-12 (|has| |#2| (-644)) (|has| |#1| (-633 (-914 (-592)))) (|has| |#1| (-908 (-592)))))) (-1605 (((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191)) 142 (-12 (|has| |#2| (-644)) (|has| |#1| (-633 (-914 (-592)))) (|has| |#1| (-908 (-592))))))) 
+(((-595 |#1| |#2|) (-10 -7 (-15 -3825 ((-2 (|:| -3479 |#2|) (|:| |nconst| |#2|)) |#2| (-1191))) (IF (|has| |#1| (-633 (-914 (-592)))) (IF (|has| |#1| (-908 (-592))) (PROGN (IF (|has| |#2| (-644)) (PROGN (-15 -1605 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191))) (-15 -2564 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191)))) |noBranch|) (IF (|has| |#2| (-1153)) (-15 -2564 ((-3 |#2| "failed") |#2| (-1191) (-862 |#2|) (-862 |#2|))) |noBranch|)) |noBranch|) |noBranch|)) (-13 (-869) (-1065 (-592)) (-477) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|))) (T -595)) 
+((-2564 (*1 *2 *2 *3 *4 *4) (|partial| -12 (-5 *3 (-1191)) (-5 *4 (-862 *2)) (-4 *2 (-1153)) (-4 *2 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-633 (-914 (-592)))) (-4 *5 (-908 (-592))) (-4 *5 (-13 (-869) (-1065 (-592)) (-477) (-654 (-592)))) (-5 *1 (-595 *5 *2)))) (-2564 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1191)) (-4 *5 (-633 (-914 (-592)))) (-4 *5 (-908 (-592))) (-4 *5 (-13 (-869) (-1065 (-592)) (-477) (-654 (-592)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-595 *5 *3)) (-4 *3 (-644)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-1605 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1191)) (-4 *5 (-633 (-914 (-592)))) (-4 *5 (-908 (-592))) (-4 *5 (-13 (-869) (-1065 (-592)) (-477) (-654 (-592)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-595 *5 *3)) (-4 *3 (-644)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-3825 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-1065 (-592)) (-477) (-654 (-592)))) (-5 *2 (-2 (|:| -3479 *3) (|:| |nconst| *3))) (-5 *1 (-595 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5)))))) 
+(-10 -7 (-15 -3825 ((-2 (|:| -3479 |#2|) (|:| |nconst| |#2|)) |#2| (-1191))) (IF (|has| |#1| (-633 (-914 (-592)))) (IF (|has| |#1| (-908 (-592))) (PROGN (IF (|has| |#2| (-644)) (PROGN (-15 -1605 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191))) (-15 -2564 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191)))) |noBranch|) (IF (|has| |#2| (-1153)) (-15 -2564 ((-3 |#2| "failed") |#2| (-1191) (-862 |#2|) (-862 |#2|))) |noBranch|)) |noBranch|) |noBranch|)) 
+((-3301 (((-3 (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|)))))) "failed") (-433 |#2|) (-658 (-433 |#2|))) 39)) (-3162 (((-609 (-433 |#2|)) (-433 |#2|)) 27)) (-2175 (((-3 (-433 |#2|) "failed") (-433 |#2|)) 16)) (-3799 (((-3 (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-433 |#2|)) 46))) 
+(((-596 |#1| |#2|) (-10 -7 (-15 -3162 ((-609 (-433 |#2|)) (-433 |#2|))) (-15 -2175 ((-3 (-433 |#2|) "failed") (-433 |#2|))) (-15 -3799 ((-3 (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-433 |#2|))) (-15 -3301 ((-3 (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|)))))) "failed") (-433 |#2|) (-658 (-433 |#2|))))) (-13 (-388) (-171) (-1065 (-592))) (-1255 |#1|)) (T -596)) 
+((-3301 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-658 (-433 *6))) (-5 *3 (-433 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-596 *5 *6)))) (-3799 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-13 (-388) (-171) (-1065 (-592)))) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -3191 (-433 *5)) (|:| |coeff| (-433 *5)))) (-5 *1 (-596 *4 *5)) (-5 *3 (-433 *5)))) (-2175 (*1 *2 *2) (|partial| -12 (-5 *2 (-433 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-13 (-388) (-171) (-1065 (-592)))) (-5 *1 (-596 *3 *4)))) (-3162 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-592)))) (-4 *5 (-1255 *4)) (-5 *2 (-609 (-433 *5))) (-5 *1 (-596 *4 *5)) (-5 *3 (-433 *5))))) 
+(-10 -7 (-15 -3162 ((-609 (-433 |#2|)) (-433 |#2|))) (-15 -2175 ((-3 (-433 |#2|) "failed") (-433 |#2|))) (-15 -3799 ((-3 (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-433 |#2|))) (-15 -3301 ((-3 (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|)))))) "failed") (-433 |#2|) (-658 (-433 |#2|))))) 
+((-4337 (((-3 (-592) "failed") |#1|) 14)) (-4277 (((-141) |#1|) 13)) (-4553 (((-592) |#1|) 9))) 
+(((-597 |#1|) (-10 -7 (-15 -4553 ((-592) |#1|)) (-15 -4277 ((-141) |#1|)) (-15 -4337 ((-3 (-592) "failed") |#1|))) (-1065 (-592))) (T -597)) 
+((-4337 (*1 *2 *3) (|partial| -12 (-5 *2 (-592)) (-5 *1 (-597 *3)) (-4 *3 (-1065 *2)))) (-4277 (*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-597 *3)) (-4 *3 (-1065 (-592))))) (-4553 (*1 *2 *3) (-12 (-5 *2 (-592)) (-5 *1 (-597 *3)) (-4 *3 (-1065 *2))))) 
+(-10 -7 (-15 -4553 ((-592) |#1|)) (-15 -4277 ((-141) |#1|)) (-15 -4337 ((-3 (-592) "failed") |#1|))) 
+((-1812 (((-3 (-2 (|:| |mainpart| (-433 (-980 |#1|))) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 (-980 |#1|))) (|:| |logand| (-433 (-980 |#1|))))))) "failed") (-433 (-980 |#1|)) (-1191) (-658 (-433 (-980 |#1|)))) 43)) (-2751 (((-609 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-1191)) 25)) (-1690 (((-3 (-433 (-980 |#1|)) "failed") (-433 (-980 |#1|)) (-1191)) 20)) (-1359 (((-3 (-2 (|:| -3191 (-433 (-980 |#1|))) (|:| |coeff| (-433 (-980 |#1|)))) "failed") (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|))) 32))) 
+(((-598 |#1|) (-10 -7 (-15 -2751 ((-609 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-1191))) (-15 -1690 ((-3 (-433 (-980 |#1|)) "failed") (-433 (-980 |#1|)) (-1191))) (-15 -1812 ((-3 (-2 (|:| |mainpart| (-433 (-980 |#1|))) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 (-980 |#1|))) (|:| |logand| (-433 (-980 |#1|))))))) "failed") (-433 (-980 |#1|)) (-1191) (-658 (-433 (-980 |#1|))))) (-15 -1359 ((-3 (-2 (|:| -3191 (-433 (-980 |#1|))) (|:| |coeff| (-433 (-980 |#1|)))) "failed") (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|))))) (-13 (-582) (-1065 (-592)) (-171))) (T -598)) 
+((-1359 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-1065 (-592)) (-171))) (-5 *2 (-2 (|:| -3191 (-433 (-980 *5))) (|:| |coeff| (-433 (-980 *5))))) (-5 *1 (-598 *5)) (-5 *3 (-433 (-980 *5))))) (-1812 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-658 (-433 (-980 *6)))) (-5 *3 (-433 (-980 *6))) (-4 *6 (-13 (-582) (-1065 (-592)) (-171))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-598 *6)))) (-1690 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-433 (-980 *4))) (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-1065 (-592)) (-171))) (-5 *1 (-598 *4)))) (-2751 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-1065 (-592)) (-171))) (-5 *2 (-609 (-433 (-980 *5)))) (-5 *1 (-598 *5)) (-5 *3 (-433 (-980 *5)))))) 
+(-10 -7 (-15 -2751 ((-609 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-1191))) (-15 -1690 ((-3 (-433 (-980 |#1|)) "failed") (-433 (-980 |#1|)) (-1191))) (-15 -1812 ((-3 (-2 (|:| |mainpart| (-433 (-980 |#1|))) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 (-980 |#1|))) (|:| |logand| (-433 (-980 |#1|))))))) "failed") (-433 (-980 |#1|)) (-1191) (-658 (-433 (-980 |#1|))))) (-15 -1359 ((-3 (-2 (|:| -3191 (-433 (-980 |#1|))) (|:| |coeff| (-433 (-980 |#1|)))) "failed") (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|))))) 
+((-1641 (((-141) $ $) 59)) (-2272 (((-141) $) 36)) (-3515 ((|#1| $) 30)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) 63)) (-1588 (($ $) 123)) (-1507 (($ $) 103)) (-4079 ((|#1| $) 28)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $) NIL)) (-1575 (($ $) 125)) (-1495 (($ $) 99)) (-1601 (($ $) 127)) (-1521 (($ $) 107)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) 78)) (-2400 (((-592) $) 80)) (-3371 (((-3 $ "failed") $) 62)) (-3955 (($ |#1| |#1|) 26)) (-1691 (((-141) $) 33)) (-1435 (($) 89)) (-3558 (((-141) $) 43)) (-4422 (($ $ (-592)) NIL)) (-1324 (((-141) $) 34)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-4546 (($ $) 91)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-1542 (($ |#1| |#1|) 20) (($ |#1|) 25) (($ (-433 (-592))) 77)) (-1817 ((|#1| $) 27)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) 65) (($ (-658 $)) NIL)) (-3616 (((-3 $ "failed") $ $) 64)) (-1430 (($ $) 93)) (-1609 (($ $) 131)) (-1527 (($ $) 105)) (-1594 (($ $) 133)) (-1515 (($ $) 109)) (-1581 (($ $) 129)) (-1501 (($ $) 101)) (-3942 (((-141) $ |#1|) 31)) (-1683 (((-877) $) 85) (($ (-592)) 67) (($ $) NIL) (($ (-592)) 67)) (-4010 (((-790)) 87)) (-1630 (($ $) 145)) (-1546 (($ $) 115)) (-2537 (((-141) $ $) NIL)) (-1617 (($ $) 143)) (-1533 (($ $) 111)) (-1642 (($ $) 141)) (-1559 (($ $) 121)) (-2892 (($ $) 139)) (-1567 (($ $) 119)) (-1636 (($ $) 137)) (-1552 (($ $) 117)) (-1624 (($ $) 135)) (-1540 (($ $) 113)) (-1424 (($ $ (-944)) 55) (($ $ (-790)) NIL)) (-3514 (($) 21 T CONST)) (-4257 (($) 10 T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 37)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 35)) (-3306 (($ $) 41) (($ $ $) 42)) (-3300 (($ $ $) 40)) (** (($ $ (-944)) 54) (($ $ (-790)) NIL) (($ $ $) 95) (($ $ (-433 (-592))) 147)) (* (($ (-944) $) 51) (($ (-790) $) NIL) (($ (-592) $) 50) (($ $ $) 48))) 
+(((-599 |#1|) (-579 |#1|) (-13 (-430) (-1211))) (T -599)) 
+NIL 
+(-579 |#1|) 
+((-3524 (((-3 (-658 (-1187 (-592))) "failed") (-658 (-1187 (-592))) (-1187 (-592))) 24))) 
+(((-600) (-10 -7 (-15 -3524 ((-3 (-658 (-1187 (-592))) "failed") (-658 (-1187 (-592))) (-1187 (-592)))))) (T -600)) 
+((-3524 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 (-592)))) (-5 *3 (-1187 (-592))) (-5 *1 (-600))))) 
+(-10 -7 (-15 -3524 ((-3 (-658 (-1187 (-592))) "failed") (-658 (-1187 (-592))) (-1187 (-592))))) 
+((-2022 (((-658 (-631 |#2|)) (-658 (-631 |#2|)) (-1191)) 18)) (-4227 (((-658 (-631 |#2|)) (-658 |#2|) (-1191)) 23)) (-4528 (((-658 (-631 |#2|)) (-658 (-631 |#2|)) (-658 (-631 |#2|))) 10)) (-3217 ((|#2| |#2| (-1191)) 51 (|has| |#1| (-582)))) (-3160 ((|#2| |#2| (-1191)) 76 (-12 (|has| |#2| (-301)) (|has| |#1| (-477))))) (-3926 (((-631 |#2|) (-631 |#2|) (-658 (-631 |#2|)) (-1191)) 25)) (-3264 (((-631 |#2|) (-658 (-631 |#2|))) 24)) (-4522 (((-609 |#2|) |#2| (-1191) (-1 (-609 |#2|) |#2| (-1191)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191))) 100 (-12 (|has| |#2| (-301)) (|has| |#2| (-644)) (|has| |#2| (-1065 (-1191))) (|has| |#1| (-633 (-914 (-592)))) (|has| |#1| (-477)) (|has| |#1| (-908 (-592))))))) 
+(((-601 |#1| |#2|) (-10 -7 (-15 -2022 ((-658 (-631 |#2|)) (-658 (-631 |#2|)) (-1191))) (-15 -3264 ((-631 |#2|) (-658 (-631 |#2|)))) (-15 -3926 ((-631 |#2|) (-631 |#2|) (-658 (-631 |#2|)) (-1191))) (-15 -4528 ((-658 (-631 |#2|)) (-658 (-631 |#2|)) (-658 (-631 |#2|)))) (-15 -4227 ((-658 (-631 |#2|)) (-658 |#2|) (-1191))) (IF (|has| |#1| (-582)) (-15 -3217 (|#2| |#2| (-1191))) |noBranch|) (IF (|has| |#1| (-477)) (IF (|has| |#2| (-301)) (PROGN (-15 -3160 (|#2| |#2| (-1191))) (IF (|has| |#1| (-633 (-914 (-592)))) (IF (|has| |#1| (-908 (-592))) (IF (|has| |#2| (-644)) (IF (|has| |#2| (-1065 (-1191))) (-15 -4522 ((-609 |#2|) |#2| (-1191) (-1 (-609 |#2|) |#2| (-1191)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) |noBranch|) |noBranch|)) (-869) (-456 |#1|)) (T -601)) 
+((-4522 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-1 (-609 *3) *3 (-1191))) (-5 *6 (-1 (-3 (-2 (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (-1191))) (-4 *3 (-301)) (-4 *3 (-644)) (-4 *3 (-1065 *4)) (-4 *3 (-456 *7)) (-5 *4 (-1191)) (-4 *7 (-633 (-914 (-592)))) (-4 *7 (-477)) (-4 *7 (-908 (-592))) (-4 *7 (-869)) (-5 *2 (-609 *3)) (-5 *1 (-601 *7 *3)))) (-3160 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-477)) (-4 *4 (-869)) (-5 *1 (-601 *4 *2)) (-4 *2 (-301)) (-4 *2 (-456 *4)))) (-3217 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-582)) (-4 *4 (-869)) (-5 *1 (-601 *4 *2)) (-4 *2 (-456 *4)))) (-4227 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-1191)) (-4 *6 (-456 *5)) (-4 *5 (-869)) (-5 *2 (-658 (-631 *6))) (-5 *1 (-601 *5 *6)))) (-4528 (*1 *2 *2 *2) (-12 (-5 *2 (-658 (-631 *4))) (-4 *4 (-456 *3)) (-4 *3 (-869)) (-5 *1 (-601 *3 *4)))) (-3926 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-658 (-631 *6))) (-5 *4 (-1191)) (-5 *2 (-631 *6)) (-4 *6 (-456 *5)) (-4 *5 (-869)) (-5 *1 (-601 *5 *6)))) (-3264 (*1 *2 *3) (-12 (-5 *3 (-658 (-631 *5))) (-4 *4 (-869)) (-5 *2 (-631 *5)) (-5 *1 (-601 *4 *5)) (-4 *5 (-456 *4)))) (-2022 (*1 *2 *2 *3) (-12 (-5 *2 (-658 (-631 *5))) (-5 *3 (-1191)) (-4 *5 (-456 *4)) (-4 *4 (-869)) (-5 *1 (-601 *4 *5))))) 
+(-10 -7 (-15 -2022 ((-658 (-631 |#2|)) (-658 (-631 |#2|)) (-1191))) (-15 -3264 ((-631 |#2|) (-658 (-631 |#2|)))) (-15 -3926 ((-631 |#2|) (-631 |#2|) (-658 (-631 |#2|)) (-1191))) (-15 -4528 ((-658 (-631 |#2|)) (-658 (-631 |#2|)) (-658 (-631 |#2|)))) (-15 -4227 ((-658 (-631 |#2|)) (-658 |#2|) (-1191))) (IF (|has| |#1| (-582)) (-15 -3217 (|#2| |#2| (-1191))) |noBranch|) (IF (|has| |#1| (-477)) (IF (|has| |#2| (-301)) (PROGN (-15 -3160 (|#2| |#2| (-1191))) (IF (|has| |#1| (-633 (-914 (-592)))) (IF (|has| |#1| (-908 (-592))) (IF (|has| |#2| (-644)) (IF (|has| |#2| (-1065 (-1191))) (-15 -4522 ((-609 |#2|) |#2| (-1191) (-1 (-609 |#2|) |#2| (-1191)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1191)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) |noBranch|) |noBranch|)) 
+((-3431 (((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-658 |#1|) "failed") (-592) |#1| |#1|)) 167)) (-2390 (((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|))))))) (|:| |a0| |#1|)) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-658 (-433 |#2|))) 143)) (-3602 (((-3 (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|)))))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-658 (-433 |#2|))) 140)) (-2298 (((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|) 129)) (-3118 (((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|)) 153)) (-2309 (((-3 (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-433 |#2|)) 170)) (-4566 (((-3 (-2 (|:| |answer| (-433 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-433 |#2|)) 173)) (-3218 (((-2 (|:| |ir| (-609 (-433 |#2|))) (|:| |specpart| (-433 |#2|)) (|:| |polypart| |#2|)) (-433 |#2|) (-1 |#2| |#2|)) 81)) (-4059 (((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)) 88)) (-3332 (((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|))))))) (|:| |a0| |#1|)) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|) (-658 (-433 |#2|))) 147)) (-4563 (((-3 (-639 |#1| |#2|) "failed") (-639 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|)) 133)) (-2407 (((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|)) 157)) (-1930 (((-3 (-2 (|:| |answer| (-433 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|) (-433 |#2|)) 178))) 
+(((-602 |#1| |#2|) (-10 -7 (-15 -3118 ((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|))) (-15 -2407 ((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|))) (-15 -3431 ((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-658 |#1|) "failed") (-592) |#1| |#1|))) (-15 -4566 ((-3 (-2 (|:| |answer| (-433 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-433 |#2|))) (-15 -1930 ((-3 (-2 (|:| |answer| (-433 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|) (-433 |#2|))) (-15 -2390 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|))))))) (|:| |a0| |#1|)) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-658 (-433 |#2|)))) (-15 -3332 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|))))))) (|:| |a0| |#1|)) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|) (-658 (-433 |#2|)))) (-15 -2309 ((-3 (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-433 |#2|))) (-15 -3602 ((-3 (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|)))))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-658 (-433 |#2|)))) (-15 -2298 ((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|)) (-15 -4563 ((-3 (-639 |#1| |#2|) "failed") (-639 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|))) (-15 -3218 ((-2 (|:| |ir| (-609 (-433 |#2|))) (|:| |specpart| (-433 |#2|)) (|:| |polypart| |#2|)) (-433 |#2|) (-1 |#2| |#2|))) (-15 -4059 ((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)))) (-388) (-1255 |#1|)) (T -602)) 
+((-4059 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |answer| *3) (|:| |polypart| *3))) (-5 *1 (-602 *5 *3)))) (-3218 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |ir| (-609 (-433 *6))) (|:| |specpart| (-433 *6)) (|:| |polypart| *6))) (-5 *1 (-602 *5 *6)) (-5 *3 (-433 *6)))) (-4563 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-639 *4 *5)) (-5 *3 (-1 (-2 (|:| |ans| *4) (|:| -1954 *4) (|:| |sol?| (-141))) (-592) *4)) (-4 *4 (-388)) (-4 *5 (-1255 *4)) (-5 *1 (-602 *4 *5)))) (-2298 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 (-2 (|:| -3191 *4) (|:| |coeff| *4)) "failed") *4)) (-4 *4 (-388)) (-5 *1 (-602 *4 *2)) (-4 *2 (-1255 *4)))) (-3602 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 *7 *7)) (-5 *5 (-658 (-433 *7))) (-4 *7 (-1255 *6)) (-5 *3 (-433 *7)) (-4 *6 (-388)) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-602 *6 *7)))) (-2309 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| -3191 (-433 *6)) (|:| |coeff| (-433 *6)))) (-5 *1 (-602 *5 *6)) (-5 *3 (-433 *6)))) (-3332 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-2 (|:| |ans| *7) (|:| -1954 *7) (|:| |sol?| (-141))) (-592) *7)) (-5 *6 (-658 (-433 *8))) (-4 *7 (-388)) (-4 *8 (-1255 *7)) (-5 *3 (-433 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-602 *7 *8)))) (-2390 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-3 (-2 (|:| -3191 *7) (|:| |coeff| *7)) "failed") *7)) (-5 *6 (-658 (-433 *8))) (-4 *7 (-388)) (-4 *8 (-1255 *7)) (-5 *3 (-433 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-602 *7 *8)))) (-1930 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -1954 *6) (|:| |sol?| (-141))) (-592) *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-433 *7)) (|:| |a0| *6)) (-2 (|:| -3191 (-433 *7)) (|:| |coeff| (-433 *7))) "failed")) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7)))) (-4566 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -3191 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-433 *7)) (|:| |a0| *6)) (-2 (|:| -3191 (-433 *7)) (|:| |coeff| (-433 *7))) "failed")) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7)))) (-3431 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-658 *6) "failed") (-592) *6 *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-2 (|:| |answer| (-609 (-433 *7))) (|:| |a0| *6))) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7)))) (-2407 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -1954 *6) (|:| |sol?| (-141))) (-592) *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-2 (|:| |answer| (-609 (-433 *7))) (|:| |a0| *6))) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7)))) (-3118 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -3191 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-2 (|:| |answer| (-609 (-433 *7))) (|:| |a0| *6))) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7))))) 
+(-10 -7 (-15 -3118 ((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|))) (-15 -2407 ((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|))) (-15 -3431 ((-2 (|:| |answer| (-609 (-433 |#2|))) (|:| |a0| |#1|)) (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-658 |#1|) "failed") (-592) |#1| |#1|))) (-15 -4566 ((-3 (-2 (|:| |answer| (-433 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-433 |#2|))) (-15 -1930 ((-3 (-2 (|:| |answer| (-433 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|) (-433 |#2|))) (-15 -2390 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|))))))) (|:| |a0| |#1|)) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-658 (-433 |#2|)))) (-15 -3332 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|))))))) (|:| |a0| |#1|)) "failed") (-433 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|) (-658 (-433 |#2|)))) (-15 -2309 ((-3 (-2 (|:| -3191 (-433 |#2|)) (|:| |coeff| (-433 |#2|))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-433 |#2|))) (-15 -3602 ((-3 (-2 (|:| |mainpart| (-433 |#2|)) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| (-433 |#2|)) (|:| |logand| (-433 |#2|)))))) "failed") (-433 |#2|) (-1 |#2| |#2|) (-658 (-433 |#2|)))) (-15 -2298 ((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|)) (-15 -4563 ((-3 (-639 |#1| |#2|) "failed") (-639 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -1954 |#1|) (|:| |sol?| (-141))) (-592) |#1|))) (-15 -3218 ((-2 (|:| |ir| (-609 (-433 |#2|))) (|:| |specpart| (-433 |#2|)) (|:| |polypart| |#2|)) (-433 |#2|) (-1 |#2| |#2|))) (-15 -4059 ((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)))) 
+((-2498 (((-3 |#2| "failed") |#2| (-1191) (-1191)) 10))) 
+(((-603 |#1| |#2|) (-10 -7 (-15 -2498 ((-3 |#2| "failed") |#2| (-1191) (-1191)))) (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592))) (-13 (-1211) (-987) (-1153) (-29 |#1|))) (T -603)) 
+((-2498 (*1 *2 *2 *3 *3) (|partial| -12 (-5 *3 (-1191)) (-4 *4 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-603 *4 *2)) (-4 *2 (-13 (-1211) (-987) (-1153) (-29 *4)))))) 
+(-10 -7 (-15 -2498 ((-3 |#2| "failed") |#2| (-1191) (-1191)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $ (-592)) 65)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-2749 (($ (-1187 (-592)) (-592)) 71)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) 57)) (-3980 (($ $) 33)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-4346 (((-790) $) 15)) (-3558 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1704 (((-592)) 27)) (-1518 (((-592) $) 31)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2807 (($ $ (-592)) 21)) (-3616 (((-3 $ "failed") $ $) 58)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) 16)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 60)) (-4406 (((-1171 (-592)) $) 18)) (-1700 (($ $) 23)) (-1683 (((-877) $) 85) (($ (-592)) 51) (($ $) NIL)) (-4010 (((-790)) 14)) (-2537 (((-141) $ $) NIL)) (-2642 (((-592) $ (-592)) 35)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 34 T CONST)) (-4257 (($) 19 T CONST)) (-3255 (((-141) $ $) 38)) (-3306 (($ $) 50) (($ $ $) 36)) (-3300 (($ $ $) 49)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 53) (($ $ $) 54))) 
+(((-604 |#1| |#2|) (-890 |#1|) (-592) (-141)) (T -604)) 
+NIL 
+(-890 |#1|) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 18)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 (($ $ (-944)) NIL (|has| $ (-394))) (($ $) NIL)) (-4217 (((-1199 (-944) (-790)) (-592)) 47)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 $ "failed") $) 75)) (-2400 (($ $) 74)) (-1626 (($ (-1280 $)) 73)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 42)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) 30)) (-4290 (($) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) 49)) (-3293 (((-141) $) NIL)) (-1525 (($ $) NIL) (($ $ (-790)) NIL)) (-2802 (((-141) $) NIL)) (-4346 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3558 (((-141) $) NIL)) (-2834 (($) 35 (|has| $ (-394)))) (-2114 (((-141) $) NIL (|has| $ (-394)))) (-2793 (($ $ (-944)) NIL (|has| $ (-394))) (($ $) NIL)) (-3921 (((-3 $ "failed") $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 $) $ (-944)) NIL (|has| $ (-394))) (((-1187 $) $) 83)) (-3546 (((-944) $) 55)) (-2343 (((-1187 $) $) NIL (|has| $ (-394)))) (-1492 (((-3 (-1187 $) "failed") $ $) NIL (|has| $ (-394))) (((-1187 $) $) NIL (|has| $ (-394)))) (-2252 (($ $ (-1187 $)) NIL (|has| $ (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL T CONST)) (-1825 (($ (-944)) 48)) (-2142 (((-141) $) 67)) (-2951 (((-1137) $) NIL)) (-2934 (($) 16 (|has| $ (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 40)) (-4500 (((-444 $) $) NIL)) (-3470 (((-944)) 66) (((-855 (-944))) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-3 (-790) "failed") $ $) NIL) (((-790) $) NIL)) (-1936 (((-160)) NIL)) (-3644 (($ $ (-790)) NIL) (($ $) NIL)) (-4525 (((-944) $) 65) (((-855 (-944)) $) NIL)) (-3390 (((-1187 $)) 82)) (-3809 (($) 54)) (-3342 (($) 36 (|has| $ (-394)))) (-2231 (((-706 $) (-1280 $)) NIL) (((-1280 $) $) 71)) (-1778 (((-592) $) 26)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) 28) (($ $) NIL) (($ (-433 (-592))) NIL)) (-1517 (((-3 $ "failed") $) NIL) (($ $) 84)) (-4010 (((-790)) 37)) (-2195 (((-1280 $) (-944)) 77) (((-1280 $)) 76)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 19 T CONST)) (-4257 (($) 15 T CONST)) (-3417 (($ $ (-790)) NIL (|has| $ (-394))) (($ $) NIL (|has| $ (-394)))) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 24)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 61) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL))) 
+(((-605 |#1|) (-13 (-373) (-349 $) (-633 (-592))) (-944)) (T -605)) 
+NIL 
+(-13 (-373) (-349 $) (-633 (-592))) 
+((-2625 (((-1285) (-1173)) 10))) 
+(((-606) (-10 -7 (-15 -2625 ((-1285) (-1173))))) (T -606)) 
+((-2625 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-606))))) 
+(-10 -7 (-15 -2625 ((-1285) (-1173)))) 
+((-1356 (((-609 |#2|) (-609 |#2|)) 37)) (-3098 (((-658 |#2|) (-609 |#2|)) 39)) (-1957 ((|#2| (-609 |#2|)) 46))) 
+(((-607 |#1| |#2|) (-10 -7 (-15 -1356 ((-609 |#2|) (-609 |#2|))) (-15 -3098 ((-658 |#2|) (-609 |#2|))) (-15 -1957 (|#2| (-609 |#2|)))) (-13 (-477) (-1065 (-592)) (-869) (-654 (-592))) (-13 (-29 |#1|) (-1211))) (T -607)) 
+((-1957 (*1 *2 *3) (-12 (-5 *3 (-609 *2)) (-4 *2 (-13 (-29 *4) (-1211))) (-5 *1 (-607 *4 *2)) (-4 *4 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))))) (-3098 (*1 *2 *3) (-12 (-5 *3 (-609 *5)) (-4 *5 (-13 (-29 *4) (-1211))) (-4 *4 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-658 *5)) (-5 *1 (-607 *4 *5)))) (-1356 (*1 *2 *2) (-12 (-5 *2 (-609 *4)) (-4 *4 (-13 (-29 *3) (-1211))) (-4 *3 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *1 (-607 *3 *4))))) 
+(-10 -7 (-15 -1356 ((-609 |#2|) (-609 |#2|))) (-15 -3098 ((-658 |#2|) (-609 |#2|))) (-15 -1957 (|#2| (-609 |#2|)))) 
+((-2731 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")) 38) (((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed")) 11) (((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed")) 31) (((-609 |#2|) (-1 |#2| |#1|) (-609 |#1|)) 26))) 
+(((-608 |#1| |#2|) (-10 -7 (-15 -2731 ((-609 |#2|) (-1 |#2| |#1|) (-609 |#1|))) (-15 -2731 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed"))) (-15 -2731 ((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed"))) (-15 -2731 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")))) (-388) (-388)) (T -608)) 
+((-2731 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| |mainpart| *5) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (-4 *5 (-388)) (-4 *6 (-388)) (-5 *2 (-2 (|:| |mainpart| *6) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *6) (|:| |logand| *6)))))) (-5 *1 (-608 *5 *6)))) (-2731 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *2 *5)) (-5 *4 (-3 *5 "failed")) (-4 *5 (-388)) (-4 *2 (-388)) (-5 *1 (-608 *5 *2)))) (-2731 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| -3191 *5) (|:| |coeff| *5)) "failed")) (-4 *5 (-388)) (-4 *6 (-388)) (-5 *2 (-2 (|:| -3191 *6) (|:| |coeff| *6))) (-5 *1 (-608 *5 *6)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-609 *5)) (-4 *5 (-388)) (-4 *6 (-388)) (-5 *2 (-609 *6)) (-5 *1 (-608 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-609 |#2|) (-1 |#2| |#1|) (-609 |#1|))) (-15 -2731 ((-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -3191 |#1|) (|:| |coeff| |#1|)) "failed"))) (-15 -2731 ((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed"))) (-15 -2731 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 68)) (-2400 ((|#1| $) NIL)) (-3191 ((|#1| $) 24)) (-3291 (((-658 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $) 26)) (-1336 (($ |#1| (-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 |#1|)) (|:| |logand| (-1187 |#1|)))) (-658 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|)))) 22)) (-4192 (((-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 |#1|)) (|:| |logand| (-1187 |#1|)))) $) 25)) (-2685 (((-1173) $) NIL)) (-1868 (($ |#1| |#1|) 32) (($ |#1| (-1191)) 43 (|has| |#1| (-1065 (-1191))))) (-2951 (((-1137) $) NIL)) (-2031 (((-141) $) 28)) (-3644 ((|#1| $ (-1 |#1| |#1|)) 80) ((|#1| $ (-1191)) 81 (|has| |#1| (-922 (-1191))))) (-1683 (((-877) $) 95) (($ |#1|) 23)) (-3514 (($) 16 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) 15) (($ $ $) NIL)) (-3300 (($ $ $) 77)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 14) (($ (-433 (-592)) $) 35) (($ $ (-433 (-592))) NIL))) 
+(((-609 |#1|) (-13 (-734 (-433 (-592))) (-1065 |#1|) (-10 -8 (-15 -1336 ($ |#1| (-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 |#1|)) (|:| |logand| (-1187 |#1|)))) (-658 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))))) (-15 -3191 (|#1| $)) (-15 -4192 ((-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 |#1|)) (|:| |logand| (-1187 |#1|)))) $)) (-15 -3291 ((-658 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $)) (-15 -2031 ((-141) $)) (-15 -1868 ($ |#1| |#1|)) (-15 -3644 (|#1| $ (-1 |#1| |#1|))) (IF (|has| |#1| (-922 (-1191))) (-15 -3644 (|#1| $ (-1191))) |noBranch|) (IF (|has| |#1| (-1065 (-1191))) (-15 -1868 ($ |#1| (-1191))) |noBranch|))) (-388)) (T -609)) 
+((-1336 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 *2)) (|:| |logand| (-1187 *2))))) (-5 *4 (-658 (-2 (|:| |integrand| *2) (|:| |intvar| *2)))) (-4 *2 (-388)) (-5 *1 (-609 *2)))) (-3191 (*1 *2 *1) (-12 (-5 *1 (-609 *2)) (-4 *2 (-388)))) (-4192 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 *3)) (|:| |logand| (-1187 *3))))) (-5 *1 (-609 *3)) (-4 *3 (-388)))) (-3291 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |integrand| *3) (|:| |intvar| *3)))) (-5 *1 (-609 *3)) (-4 *3 (-388)))) (-2031 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-609 *3)) (-4 *3 (-388)))) (-1868 (*1 *1 *2 *2) (-12 (-5 *1 (-609 *2)) (-4 *2 (-388)))) (-3644 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-609 *2)) (-4 *2 (-388)))) (-3644 (*1 *2 *1 *3) (-12 (-4 *2 (-388)) (-4 *2 (-922 *3)) (-5 *1 (-609 *2)) (-5 *3 (-1191)))) (-1868 (*1 *1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *1 (-609 *2)) (-4 *2 (-1065 *3)) (-4 *2 (-388))))) 
+(-13 (-734 (-433 (-592))) (-1065 |#1|) (-10 -8 (-15 -1336 ($ |#1| (-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 |#1|)) (|:| |logand| (-1187 |#1|)))) (-658 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))))) (-15 -3191 (|#1| $)) (-15 -4192 ((-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 |#1|)) (|:| |logand| (-1187 |#1|)))) $)) (-15 -3291 ((-658 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $)) (-15 -2031 ((-141) $)) (-15 -1868 ($ |#1| |#1|)) (-15 -3644 (|#1| $ (-1 |#1| |#1|))) (IF (|has| |#1| (-922 (-1191))) (-15 -3644 (|#1| $ (-1191))) |noBranch|) (IF (|has| |#1| (-1065 (-1191))) (-15 -1868 ($ |#1| (-1191))) |noBranch|))) 
+((-4078 (((-141) |#1|) 16)) (-4538 (((-3 |#1| "failed") |#1|) 14)) (-1411 (((-2 (|:| -4226 |#1|) (|:| -3215 (-790))) |#1|) 30) (((-3 |#1| "failed") |#1| (-790)) 18)) (-2313 (((-141) |#1| (-790)) 19)) (-4088 ((|#1| |#1|) 31)) (-2539 ((|#1| |#1| (-790)) 33))) 
+(((-610 |#1|) (-10 -7 (-15 -2313 ((-141) |#1| (-790))) (-15 -1411 ((-3 |#1| "failed") |#1| (-790))) (-15 -1411 ((-2 (|:| -4226 |#1|) (|:| -3215 (-790))) |#1|)) (-15 -2539 (|#1| |#1| (-790))) (-15 -4078 ((-141) |#1|)) (-15 -4538 ((-3 |#1| "failed") |#1|)) (-15 -4088 (|#1| |#1|))) (-574)) (T -610)) 
+((-4088 (*1 *2 *2) (-12 (-5 *1 (-610 *2)) (-4 *2 (-574)))) (-4538 (*1 *2 *2) (|partial| -12 (-5 *1 (-610 *2)) (-4 *2 (-574)))) (-4078 (*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-610 *3)) (-4 *3 (-574)))) (-2539 (*1 *2 *2 *3) (-12 (-5 *3 (-790)) (-5 *1 (-610 *2)) (-4 *2 (-574)))) (-1411 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| -4226 *3) (|:| -3215 (-790)))) (-5 *1 (-610 *3)) (-4 *3 (-574)))) (-1411 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-790)) (-5 *1 (-610 *2)) (-4 *2 (-574)))) (-2313 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-5 *2 (-141)) (-5 *1 (-610 *3)) (-4 *3 (-574))))) 
+(-10 -7 (-15 -2313 ((-141) |#1| (-790))) (-15 -1411 ((-3 |#1| "failed") |#1| (-790))) (-15 -1411 ((-2 (|:| -4226 |#1|) (|:| -3215 (-790))) |#1|)) (-15 -2539 (|#1| |#1| (-790))) (-15 -4078 ((-141) |#1|)) (-15 -4538 ((-3 |#1| "failed") |#1|)) (-15 -4088 (|#1| |#1|))) 
+((-3774 (((-1187 |#1|) (-944)) 26))) 
+(((-611 |#1|) (-10 -7 (-15 -3774 ((-1187 |#1|) (-944)))) (-373)) (T -611)) 
+((-3774 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-611 *4)) (-4 *4 (-373))))) 
+(-10 -7 (-15 -3774 ((-1187 |#1|) (-944)))) 
+((-1356 (((-609 (-433 (-980 |#1|))) (-609 (-433 (-980 |#1|)))) 26)) (-3162 (((-3 (-332 |#1|) (-658 (-332 |#1|))) (-433 (-980 |#1|)) (-1191)) 32 (|has| |#1| (-171)))) (-3098 (((-658 (-332 |#1|)) (-609 (-433 (-980 |#1|)))) 18)) (-3586 (((-332 |#1|) (-433 (-980 |#1|)) (-1191)) 30 (|has| |#1| (-171)))) (-1957 (((-332 |#1|) (-609 (-433 (-980 |#1|)))) 20))) 
+(((-612 |#1|) (-10 -7 (-15 -1356 ((-609 (-433 (-980 |#1|))) (-609 (-433 (-980 |#1|))))) (-15 -3098 ((-658 (-332 |#1|)) (-609 (-433 (-980 |#1|))))) (-15 -1957 ((-332 |#1|) (-609 (-433 (-980 |#1|))))) (IF (|has| |#1| (-171)) (PROGN (-15 -3162 ((-3 (-332 |#1|) (-658 (-332 |#1|))) (-433 (-980 |#1|)) (-1191))) (-15 -3586 ((-332 |#1|) (-433 (-980 |#1|)) (-1191)))) |noBranch|)) (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (T -612)) 
+((-3586 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-171)) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-332 *5)) (-5 *1 (-612 *5)))) (-3162 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-171)) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-3 (-332 *5) (-658 (-332 *5)))) (-5 *1 (-612 *5)))) (-1957 (*1 *2 *3) (-12 (-5 *3 (-609 (-433 (-980 *4)))) (-4 *4 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-332 *4)) (-5 *1 (-612 *4)))) (-3098 (*1 *2 *3) (-12 (-5 *3 (-609 (-433 (-980 *4)))) (-4 *4 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-658 (-332 *4))) (-5 *1 (-612 *4)))) (-1356 (*1 *2 *2) (-12 (-5 *2 (-609 (-433 (-980 *3)))) (-4 *3 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *1 (-612 *3))))) 
+(-10 -7 (-15 -1356 ((-609 (-433 (-980 |#1|))) (-609 (-433 (-980 |#1|))))) (-15 -3098 ((-658 (-332 |#1|)) (-609 (-433 (-980 |#1|))))) (-15 -1957 ((-332 |#1|) (-609 (-433 (-980 |#1|))))) (IF (|has| |#1| (-171)) (PROGN (-15 -3162 ((-3 (-332 |#1|) (-658 (-332 |#1|))) (-433 (-980 |#1|)) (-1191))) (-15 -3586 ((-332 |#1|) (-433 (-980 |#1|)) (-1191)))) |noBranch|)) 
+((-4269 (((-658 (-706 (-592))) (-658 (-592)) (-658 (-927 (-592)))) 45) (((-658 (-706 (-592))) (-658 (-592))) 46) (((-706 (-592)) (-658 (-592)) (-927 (-592))) 41)) (-3599 (((-790) (-658 (-592))) 39))) 
+(((-613) (-10 -7 (-15 -3599 ((-790) (-658 (-592)))) (-15 -4269 ((-706 (-592)) (-658 (-592)) (-927 (-592)))) (-15 -4269 ((-658 (-706 (-592))) (-658 (-592)))) (-15 -4269 ((-658 (-706 (-592))) (-658 (-592)) (-658 (-927 (-592))))))) (T -613)) 
+((-4269 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-592))) (-5 *4 (-658 (-927 (-592)))) (-5 *2 (-658 (-706 (-592)))) (-5 *1 (-613)))) (-4269 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-658 (-706 (-592)))) (-5 *1 (-613)))) (-4269 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-592))) (-5 *4 (-927 (-592))) (-5 *2 (-706 (-592))) (-5 *1 (-613)))) (-3599 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-790)) (-5 *1 (-613))))) 
+(-10 -7 (-15 -3599 ((-790) (-658 (-592)))) (-15 -4269 ((-706 (-592)) (-658 (-592)) (-927 (-592)))) (-15 -4269 ((-658 (-706 (-592))) (-658 (-592)))) (-15 -4269 ((-658 (-706 (-592))) (-658 (-592)) (-658 (-927 (-592)))))) 
+((-2004 (((-658 |#5|) |#5| (-141)) 72)) (-3637 (((-141) |#5| (-658 |#5|)) 30))) 
+(((-614 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2004 ((-658 |#5|) |#5| (-141))) (-15 -3637 ((-141) |#5| (-658 |#5|)))) (-13 (-323) (-171)) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1128 |#1| |#2| |#3| |#4|)) (T -614)) 
+((-3637 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1128 *5 *6 *7 *8)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-614 *5 *6 *7 *8 *3)))) (-2004 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-658 *3)) (-5 *1 (-614 *5 *6 *7 *8 *3)) (-4 *3 (-1128 *5 *6 *7 *8))))) 
+(-10 -7 (-15 -2004 ((-658 |#5|) |#5| (-141))) (-15 -3637 ((-141) |#5| (-658 |#5|)))) 
+((-1641 (((-141) $ $) NIL (|has| (-168) (-1119)))) (-3202 (($ $) 34)) (-3777 (($ $) NIL)) (-2874 (($ $ (-168)) NIL) (($ $ (-163)) NIL)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-3326 (((-141) $ $) 51)) (-3288 (((-141) $ $ (-592)) 46)) (-1356 (((-658 $) $ (-168)) 59) (((-658 $) $ (-163)) 60)) (-4076 (((-141) (-1 (-141) (-168) (-168)) $) NIL) (((-141) $) NIL (|has| (-168) (-869)))) (-2831 (($ (-1 (-141) (-168) (-168)) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-168) (-869))))) (-3960 (($ (-1 (-141) (-168) (-168)) $) NIL) (($ $) NIL (|has| (-168) (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-168) $ (-592) (-168)) 45 (|has| $ (-6 -4626))) (((-168) $ (-1246 (-592)) (-168)) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-4447 (($ $ (-168)) 63) (($ $ (-163)) 64)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-2262 (($ $ (-1246 (-592)) $) 44)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-4459 (($ (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119)))) (($ (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-168) (-1 (-168) (-168) (-168)) $ (-168) (-168)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119)))) (((-168) (-1 (-168) (-168) (-168)) $ (-168)) NIL (|has| $ (-6 -4625))) (((-168) (-1 (-168) (-168) (-168)) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-168) $ (-592) (-168)) NIL (|has| $ (-6 -4626)))) (-3959 (((-168) $ (-592)) NIL)) (-3379 (((-141) $ $) 70)) (-1721 (((-592) (-1 (-141) (-168)) $) NIL) (((-592) (-168) $) NIL (|has| (-168) (-1119))) (((-592) (-168) $ (-592)) 48 (|has| (-168) (-1119))) (((-592) $ $ (-592)) 47) (((-592) (-163) $ (-592)) 50)) (-4004 (((-658 (-168)) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) (-168)) 9)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 28 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| (-168) (-869)))) (-4491 (($ (-1 (-141) (-168) (-168)) $ $) NIL) (($ $ $) NIL (|has| (-168) (-869)))) (-4467 (((-658 (-168)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-1813 (((-592) $) 42 (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-168) (-869)))) (-3614 (((-141) $ $ (-168)) 71)) (-1600 (((-790) $ $ (-168)) 69)) (-3987 (($ (-1 (-168) (-168)) $) 33 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-168) (-168)) $) NIL) (($ (-1 (-168) (-168) (-168)) $ $) NIL)) (-2200 (($ $) 37)) (-1633 (($ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2999 (($ $ (-168)) 61) (($ $ (-163)) 62)) (-2685 (((-1173) $) 38 (|has| (-168) (-1119)))) (-3666 (($ (-168) $ (-592)) NIL) (($ $ $ (-592)) 23)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-592) $) 68) (((-1137) $) NIL (|has| (-168) (-1119)))) (-1918 (((-168) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-168) "failed") (-1 (-141) (-168)) $) NIL)) (-1892 (($ $ (-168)) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-168)))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-310 (-168))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-168) (-168)) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-658 (-168)) (-658 (-168))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-4210 (((-658 (-168)) $) NIL)) (-2943 (((-141) $) 12)) (-2890 (($) 10)) (-3927 (((-168) $ (-592) (-168)) NIL) (((-168) $ (-592)) 52) (($ $ (-1246 (-592))) 21) (($ $ $) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625))) (((-790) (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-2385 (($ $ $ (-592)) 65 (|has| $ (-6 -4626)))) (-4599 (($ $) 17)) (-1778 (((-565) $) NIL (|has| (-168) (-633 (-565))))) (-4466 (($ (-658 (-168))) NIL)) (-2266 (($ $ (-168)) NIL) (($ (-168) $) NIL) (($ $ $) 16) (($ (-658 $)) 66)) (-1683 (($ (-168)) NIL) (((-877) $) 27 (|has| (-168) (-1119)))) (-3369 (((-141) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| (-168) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-168) (-869)))) (-3255 (((-141) $ $) 14 (|has| (-168) (-1119)))) (-3279 (((-141) $ $) NIL (|has| (-168) (-869)))) (-3266 (((-141) $ $) 15 (|has| (-168) (-869)))) (-1699 (((-790) $) 13 (|has| $ (-6 -4625))))) 
+(((-615 |#1|) (-13 (-1158) (-10 -8 (-15 -2951 ((-592) $)))) (-592)) (T -615)) 
+((-2951 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-615 *3)) (-14 *3 *2)))) 
+(-13 (-1158) (-10 -8 (-15 -2951 ((-592) $)))) 
+((-2090 (((-2 (|:| |num| |#4|) (|:| |den| (-592))) |#4| |#2|) 23) (((-2 (|:| |num| |#4|) (|:| |den| (-592))) |#4| |#2| (-1113 |#4|)) 32))) 
+(((-616 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2090 ((-2 (|:| |num| |#4|) (|:| |den| (-592))) |#4| |#2| (-1113 |#4|))) (-15 -2090 ((-2 (|:| |num| |#4|) (|:| |den| (-592))) |#4| |#2|))) (-815) (-869) (-582) (-977 |#3| |#1| |#2|)) (T -616)) 
+((-2090 (*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-582)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-592)))) (-5 *1 (-616 *5 *4 *6 *3)) (-4 *3 (-977 *6 *5 *4)))) (-2090 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-1113 *3)) (-4 *3 (-977 *7 *6 *4)) (-4 *6 (-815)) (-4 *4 (-869)) (-4 *7 (-582)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-592)))) (-5 *1 (-616 *6 *4 *7 *3))))) 
+(-10 -7 (-15 -2090 ((-2 (|:| |num| |#4|) (|:| |den| (-592))) |#4| |#2| (-1113 |#4|))) (-15 -2090 ((-2 (|:| |num| |#4|) (|:| |den| (-592))) |#4| |#2|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 63)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-592)) 54) (($ $ (-592) (-592)) 55)) (-2982 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) 60)) (-4162 (($ $) 99)) (-2350 (((-3 $ "failed") $ $) NIL)) (-2658 (((-877) (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) (-1054 (-862 (-592))) (-1191) |#1| (-433 (-592))) 214)) (-2881 (($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) 34)) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-2273 (((-141) $) NIL)) (-4346 (((-592) $) 58) (((-592) $ (-592)) 59)) (-3558 (((-141) $) NIL)) (-3990 (($ $ (-944)) 76)) (-1376 (($ (-1 |#1| (-592)) $) 73)) (-2027 (((-141) $) 25)) (-4526 (($ |#1| (-592)) 22) (($ $ (-1103) (-592)) NIL) (($ $ (-658 (-1103)) (-658 (-592))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) 67)) (-3759 (($ (-1054 (-862 (-592))) (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) 11)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-3162 (($ $) 111 (|has| |#1| (-43 (-433 (-592)))))) (-3776 (((-3 $ "failed") $ $ (-141)) 98)) (-2432 (($ $ $) 107)) (-2951 (((-1137) $) NIL)) (-1759 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) 13)) (-3283 (((-1054 (-862 (-592))) $) 12)) (-2807 (($ $ (-592)) 45)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-592)))))) (-3927 ((|#1| $ (-592)) 57) (($ $ $) NIL (|has| (-592) (-1131)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $) 70 (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (-4525 (((-592) $) NIL)) (-1700 (($ $) 46)) (-1683 (((-877) $) NIL) (($ (-592)) 28) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582))) (($ |#1|) 27 (|has| |#1| (-194)))) (-1937 ((|#1| $ (-592)) 56)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) 37)) (-2838 ((|#1| $) NIL)) (-1593 (($ $) 179 (|has| |#1| (-43 (-433 (-592)))))) (-2861 (($ $) 155 (|has| |#1| (-43 (-433 (-592)))))) (-2588 (($ $) 176 (|has| |#1| (-43 (-433 (-592)))))) (-3562 (($ $) 152 (|has| |#1| (-43 (-433 (-592)))))) (-1860 (($ $) 181 (|has| |#1| (-43 (-433 (-592)))))) (-1314 (($ $) 158 (|has| |#1| (-43 (-433 (-592)))))) (-4598 (($ $ (-433 (-592))) 145 (|has| |#1| (-43 (-433 (-592)))))) (-4195 (($ $ |#1|) 120 (|has| |#1| (-43 (-433 (-592)))))) (-2196 (($ $) 149 (|has| |#1| (-43 (-433 (-592)))))) (-2858 (($ $) 147 (|has| |#1| (-43 (-433 (-592)))))) (-2960 (($ $) 182 (|has| |#1| (-43 (-433 (-592)))))) (-1629 (($ $) 159 (|has| |#1| (-43 (-433 (-592)))))) (-3685 (($ $) 180 (|has| |#1| (-43 (-433 (-592)))))) (-3341 (($ $) 157 (|has| |#1| (-43 (-433 (-592)))))) (-1628 (($ $) 177 (|has| |#1| (-43 (-433 (-592)))))) (-4409 (($ $) 153 (|has| |#1| (-43 (-433 (-592)))))) (-3763 (($ $) 187 (|has| |#1| (-43 (-433 (-592)))))) (-3348 (($ $) 167 (|has| |#1| (-43 (-433 (-592)))))) (-2998 (($ $) 184 (|has| |#1| (-43 (-433 (-592)))))) (-2779 (($ $) 162 (|has| |#1| (-43 (-433 (-592)))))) (-1578 (($ $) 191 (|has| |#1| (-43 (-433 (-592)))))) (-3794 (($ $) 171 (|has| |#1| (-43 (-433 (-592)))))) (-1991 (($ $) 193 (|has| |#1| (-43 (-433 (-592)))))) (-3095 (($ $) 173 (|has| |#1| (-43 (-433 (-592)))))) (-2422 (($ $) 189 (|has| |#1| (-43 (-433 (-592)))))) (-4581 (($ $) 169 (|has| |#1| (-43 (-433 (-592)))))) (-2075 (($ $) 186 (|has| |#1| (-43 (-433 (-592)))))) (-2089 (($ $) 165 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-2642 ((|#1| $ (-592)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-592)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 29 T CONST)) (-4257 (($) 38 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (-3255 (((-141) $ $) 65)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) 84) (($ $ $) 64)) (-3300 (($ $ $) 81)) (** (($ $ (-944)) NIL) (($ $ (-790)) 102)) (* (($ (-944) $) 89) (($ (-790) $) 87) (($ (-592) $) 85) (($ $ $) 95) (($ $ |#1|) NIL) (($ |#1| $) 114) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-617 |#1|) (-13 (-1257 |#1| (-592)) (-10 -8 (-15 -3759 ($ (-1054 (-862 (-592))) (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))))) (-15 -3283 ((-1054 (-862 (-592))) $)) (-15 -1759 ((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $)) (-15 -2881 ($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))))) (-15 -2027 ((-141) $)) (-15 -1376 ($ (-1 |#1| (-592)) $)) (-15 -3776 ((-3 $ "failed") $ $ (-141))) (-15 -4162 ($ $)) (-15 -2432 ($ $ $)) (-15 -2658 ((-877) (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) (-1054 (-862 (-592))) (-1191) |#1| (-433 (-592)))) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $)) (-15 -4195 ($ $ |#1|)) (-15 -4598 ($ $ (-433 (-592)))) (-15 -2858 ($ $)) (-15 -2196 ($ $)) (-15 -3562 ($ $)) (-15 -4409 ($ $)) (-15 -2861 ($ $)) (-15 -3341 ($ $)) (-15 -1314 ($ $)) (-15 -1629 ($ $)) (-15 -2779 ($ $)) (-15 -2089 ($ $)) (-15 -3348 ($ $)) (-15 -4581 ($ $)) (-15 -3794 ($ $)) (-15 -3095 ($ $)) (-15 -2588 ($ $)) (-15 -1628 ($ $)) (-15 -1593 ($ $)) (-15 -3685 ($ $)) (-15 -1860 ($ $)) (-15 -2960 ($ $)) (-15 -2998 ($ $)) (-15 -2075 ($ $)) (-15 -3763 ($ $)) (-15 -2422 ($ $)) (-15 -1578 ($ $)) (-15 -1991 ($ $))) |noBranch|))) (-1075)) (T -617)) 
+((-2027 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-617 *3)) (-4 *3 (-1075)))) (-3759 (*1 *1 *2 *3) (-12 (-5 *2 (-1054 (-862 (-592)))) (-5 *3 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *4)))) (-4 *4 (-1075)) (-5 *1 (-617 *4)))) (-3283 (*1 *2 *1) (-12 (-5 *2 (-1054 (-862 (-592)))) (-5 *1 (-617 *3)) (-4 *3 (-1075)))) (-1759 (*1 *2 *1) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))) (-5 *1 (-617 *3)) (-4 *3 (-1075)))) (-2881 (*1 *1 *2) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))) (-4 *3 (-1075)) (-5 *1 (-617 *3)))) (-1376 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-592))) (-4 *3 (-1075)) (-5 *1 (-617 *3)))) (-3776 (*1 *1 *1 *1 *2) (|partial| -12 (-5 *2 (-141)) (-5 *1 (-617 *3)) (-4 *3 (-1075)))) (-4162 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-1075)))) (-2432 (*1 *1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-1075)))) (-2658 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *6)))) (-5 *4 (-1054 (-862 (-592)))) (-5 *5 (-1191)) (-5 *7 (-433 (-592))) (-4 *6 (-1075)) (-5 *2 (-877)) (-5 *1 (-617 *6)))) (-3162 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-4195 (*1 *1 *1 *2) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-4598 (*1 *1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-617 *3)) (-4 *3 (-43 *2)) (-4 *3 (-1075)))) (-2858 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2196 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-3562 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-4409 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2861 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-3341 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-1314 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-1629 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2779 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2089 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-3348 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-4581 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-3794 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-3095 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2588 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-1628 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-1593 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-3685 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-1860 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2960 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2998 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2075 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-3763 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-2422 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-1578 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) (-1991 (*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(-13 (-1257 |#1| (-592)) (-10 -8 (-15 -3759 ($ (-1054 (-862 (-592))) (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))))) (-15 -3283 ((-1054 (-862 (-592))) $)) (-15 -1759 ((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $)) (-15 -2881 ($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))))) (-15 -2027 ((-141) $)) (-15 -1376 ($ (-1 |#1| (-592)) $)) (-15 -3776 ((-3 $ "failed") $ $ (-141))) (-15 -4162 ($ $)) (-15 -2432 ($ $ $)) (-15 -2658 ((-877) (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) (-1054 (-862 (-592))) (-1191) |#1| (-433 (-592)))) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $)) (-15 -4195 ($ $ |#1|)) (-15 -4598 ($ $ (-433 (-592)))) (-15 -2858 ($ $)) (-15 -2196 ($ $)) (-15 -3562 ($ $)) (-15 -4409 ($ $)) (-15 -2861 ($ $)) (-15 -3341 ($ $)) (-15 -1314 ($ $)) (-15 -1629 ($ $)) (-15 -2779 ($ $)) (-15 -2089 ($ $)) (-15 -3348 ($ $)) (-15 -4581 ($ $)) (-15 -3794 ($ $)) (-15 -3095 ($ $)) (-15 -2588 ($ $)) (-15 -1628 ($ $)) (-15 -1593 ($ $)) (-15 -3685 ($ $)) (-15 -1860 ($ $)) (-15 -2960 ($ $)) (-15 -2998 ($ $)) (-15 -2075 ($ $)) (-15 -3763 ($ $)) (-15 -2422 ($ $)) (-15 -1578 ($ $)) (-15 -1991 ($ $))) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-2881 (($ (-1171 |#1|)) 9)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) 42)) (-2273 (((-141) $) 52)) (-4346 (((-790) $) 55) (((-790) $ (-790)) 54)) (-3558 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ $) 44 (|has| |#1| (-582)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-1171 |#1|) $) 23)) (-4010 (((-790)) 51)) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 10 T CONST)) (-4257 (($) 14 T CONST)) (-3255 (((-141) $ $) 22)) (-3306 (($ $) 30) (($ $ $) 16)) (-3300 (($ $ $) 25)) (** (($ $ (-944)) NIL) (($ $ (-790)) 49)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 34) (($ $ $) 28) (($ |#1| $) 37) (($ $ |#1|) 38) (($ $ (-592)) 36))) 
+(((-618 |#1|) (-13 (-1075) (-10 -8 (-15 -1647 ((-1171 |#1|) $)) (-15 -2881 ($ (-1171 |#1|))) (-15 -2273 ((-141) $)) (-15 -4346 ((-790) $)) (-15 -4346 ((-790) $ (-790))) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 * ($ $ (-592))) (IF (|has| |#1| (-582)) (-6 (-582)) |noBranch|))) (-1075)) (T -618)) 
+((-1647 (*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) (-2881 (*1 *1 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-618 *3)))) (-2273 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) (-4346 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) (-4346 (*1 *2 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) (* (*1 *1 *2 *1) (-12 (-5 *1 (-618 *2)) (-4 *2 (-1075)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-618 *2)) (-4 *2 (-1075)))) (* (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-618 *3)) (-4 *3 (-1075))))) 
+(-13 (-1075) (-10 -8 (-15 -1647 ((-1171 |#1|) $)) (-15 -2881 ($ (-1171 |#1|))) (-15 -2273 ((-141) $)) (-15 -4346 ((-790) $)) (-15 -4346 ((-790) $ (-790))) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 * ($ $ (-592))) (IF (|has| |#1| (-582)) (-6 (-582)) |noBranch|))) 
+((-2731 (((-622 |#2|) (-1 |#2| |#1|) (-622 |#1|)) 15))) 
+(((-619 |#1| |#2|) (-10 -7 (-15 -2731 ((-622 |#2|) (-1 |#2| |#1|) (-622 |#1|)))) (-1225) (-1225)) (T -619)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-622 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-622 *6)) (-5 *1 (-619 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-622 |#2|) (-1 |#2| |#1|) (-622 |#1|)))) 
+((-2731 (((-1171 |#3|) (-1 |#3| |#1| |#2|) (-622 |#1|) (-1171 |#2|)) 20) (((-1171 |#3|) (-1 |#3| |#1| |#2|) (-1171 |#1|) (-622 |#2|)) 19) (((-622 |#3|) (-1 |#3| |#1| |#2|) (-622 |#1|) (-622 |#2|)) 18))) 
+(((-620 |#1| |#2| |#3|) (-10 -7 (-15 -2731 ((-622 |#3|) (-1 |#3| |#1| |#2|) (-622 |#1|) (-622 |#2|))) (-15 -2731 ((-1171 |#3|) (-1 |#3| |#1| |#2|) (-1171 |#1|) (-622 |#2|))) (-15 -2731 ((-1171 |#3|) (-1 |#3| |#1| |#2|) (-622 |#1|) (-1171 |#2|)))) (-1225) (-1225) (-1225)) (T -620)) 
+((-2731 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-622 *6)) (-5 *5 (-1171 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-1171 *8)) (-5 *1 (-620 *6 *7 *8)))) (-2731 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1171 *6)) (-5 *5 (-622 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-1171 *8)) (-5 *1 (-620 *6 *7 *8)))) (-2731 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-622 *6)) (-5 *5 (-622 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-622 *8)) (-5 *1 (-620 *6 *7 *8))))) 
+(-10 -7 (-15 -2731 ((-622 |#3|) (-1 |#3| |#1| |#2|) (-622 |#1|) (-622 |#2|))) (-15 -2731 ((-1171 |#3|) (-1 |#3| |#1| |#2|) (-1171 |#1|) (-622 |#2|))) (-15 -2731 ((-1171 |#3|) (-1 |#3| |#1| |#2|) (-622 |#1|) (-1171 |#2|)))) 
+((-2135 ((|#3| |#3| (-658 (-631 |#3|)) (-658 (-1191))) 55)) (-3858 (((-191 |#2|) |#3|) 116)) (-2229 ((|#3| (-191 |#2|)) 43)) (-4053 ((|#2| |#3|) 19)) (-2137 ((|#3| |#2|) 32))) 
+(((-621 |#1| |#2| |#3|) (-10 -7 (-15 -2229 (|#3| (-191 |#2|))) (-15 -4053 (|#2| |#3|)) (-15 -2137 (|#3| |#2|)) (-15 -3858 ((-191 |#2|) |#3|)) (-15 -2135 (|#3| |#3| (-658 (-631 |#3|)) (-658 (-1191))))) (-13 (-582) (-869)) (-13 (-456 |#1|) (-1030) (-1211)) (-13 (-456 (-191 |#1|)) (-1030) (-1211))) (T -621)) 
+((-2135 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-658 (-631 *2))) (-5 *4 (-658 (-1191))) (-4 *2 (-13 (-456 (-191 *5)) (-1030) (-1211))) (-4 *5 (-13 (-582) (-869))) (-5 *1 (-621 *5 *6 *2)) (-4 *6 (-13 (-456 *5) (-1030) (-1211))))) (-3858 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869))) (-5 *2 (-191 *5)) (-5 *1 (-621 *4 *5 *3)) (-4 *5 (-13 (-456 *4) (-1030) (-1211))) (-4 *3 (-13 (-456 (-191 *4)) (-1030) (-1211))))) (-2137 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869))) (-4 *2 (-13 (-456 (-191 *4)) (-1030) (-1211))) (-5 *1 (-621 *4 *3 *2)) (-4 *3 (-13 (-456 *4) (-1030) (-1211))))) (-4053 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869))) (-4 *2 (-13 (-456 *4) (-1030) (-1211))) (-5 *1 (-621 *4 *2 *3)) (-4 *3 (-13 (-456 (-191 *4)) (-1030) (-1211))))) (-2229 (*1 *2 *3) (-12 (-5 *3 (-191 *5)) (-4 *5 (-13 (-456 *4) (-1030) (-1211))) (-4 *4 (-13 (-582) (-869))) (-4 *2 (-13 (-456 (-191 *4)) (-1030) (-1211))) (-5 *1 (-621 *4 *5 *2))))) 
+(-10 -7 (-15 -2229 (|#3| (-191 |#2|))) (-15 -4053 (|#2| |#3|)) (-15 -2137 (|#3| |#2|)) (-15 -3858 ((-191 |#2|) |#3|)) (-15 -2135 (|#3| |#3| (-658 (-631 |#3|)) (-658 (-1191))))) 
+((-3113 (($ (-1 (-141) |#1|) $) 16)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3086 (($ (-1 |#1| |#1|) |#1|) 9)) (-3103 (($ (-1 (-141) |#1|) $) 12)) (-3109 (($ (-1 (-141) |#1|) $) 14)) (-4466 (((-1171 |#1|) $) 17)) (-1683 (((-877) $) NIL))) 
+(((-622 |#1|) (-13 (-632 (-877)) (-10 -8 (-15 -2731 ($ (-1 |#1| |#1|) $)) (-15 -3103 ($ (-1 (-141) |#1|) $)) (-15 -3109 ($ (-1 (-141) |#1|) $)) (-15 -3113 ($ (-1 (-141) |#1|) $)) (-15 -3086 ($ (-1 |#1| |#1|) |#1|)) (-15 -4466 ((-1171 |#1|) $)))) (-1225)) (T -622)) 
+((-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) (-3103 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) (-3109 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) (-3113 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) (-3086 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) (-4466 (*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-622 *3)) (-4 *3 (-1225))))) 
+(-13 (-632 (-877)) (-10 -8 (-15 -2731 ($ (-1 |#1| |#1|) $)) (-15 -3103 ($ (-1 (-141) |#1|) $)) (-15 -3109 ($ (-1 (-141) |#1|) $)) (-15 -3113 ($ (-1 (-141) |#1|) $)) (-15 -3086 ($ (-1 |#1| |#1|) |#1|)) (-15 -4466 ((-1171 |#1|) $)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1417 (($ (-790)) NIL (|has| |#1| (-23)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) NIL) (((-141) $) NIL (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-1721 (((-592) (-1 (-141) |#1|) $) NIL) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119)))) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-4363 (((-706 |#1|) $ $) NIL (|has| |#1| (-1075)))) (-3242 (($ (-790) |#1|) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2311 ((|#1| $) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1075))))) (-2554 (((-141) $ (-790)) NIL)) (-4233 ((|#1| $) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1075))))) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) NIL (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) |#1|) NIL) ((|#1| $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-1729 ((|#1| $ $) NIL (|has| |#1| (-1075)))) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-2746 (($ $ $) NIL (|has| |#1| (-1075)))) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-2266 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3306 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-3300 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-592) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-743))) (($ $ |#1|) NIL (|has| |#1| (-743)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-623 |#1| |#2|) (-1278 |#1|) (-1225) (-592)) (T -623)) 
+NIL 
+(-1278 |#1|) 
+((-3898 (((-1285) $ |#2| |#2|) 36)) (-2261 ((|#2| $) 23)) (-1813 ((|#2| $) 21)) (-3987 (($ (-1 |#3| |#3|) $) 32)) (-2731 (($ (-1 |#3| |#3|) $) 30)) (-1918 ((|#3| $) 26)) (-1892 (($ $ |#3|) 33)) (-2254 (((-141) |#3| $) 17)) (-4210 (((-658 |#3|) $) 15)) (-3927 ((|#3| $ |#2| |#3|) 12) ((|#3| $ |#2|) NIL))) 
+(((-624 |#1| |#2| |#3|) (-10 -8 (-15 -3898 ((-1285) |#1| |#2| |#2|)) (-15 -1892 (|#1| |#1| |#3|)) (-15 -1918 (|#3| |#1|)) (-15 -2261 (|#2| |#1|)) (-15 -1813 (|#2| |#1|)) (-15 -2254 ((-141) |#3| |#1|)) (-15 -4210 ((-658 |#3|) |#1|)) (-15 -3927 (|#3| |#1| |#2|)) (-15 -3927 (|#3| |#1| |#2| |#3|)) (-15 -3987 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2731 (|#1| (-1 |#3| |#3|) |#1|))) (-625 |#2| |#3|) (-1119) (-1225)) (T -624)) 
+NIL 
+(-10 -8 (-15 -3898 ((-1285) |#1| |#2| |#2|)) (-15 -1892 (|#1| |#1| |#3|)) (-15 -1918 (|#3| |#1|)) (-15 -2261 (|#2| |#1|)) (-15 -1813 (|#2| |#1|)) (-15 -2254 ((-141) |#3| |#1|)) (-15 -4210 ((-658 |#3|) |#1|)) (-15 -3927 (|#3| |#1| |#2|)) (-15 -3927 (|#3| |#1| |#2| |#3|)) (-15 -3987 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2731 (|#1| (-1 |#3| |#3|) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#2| (-1119)))) (-3898 (((-1285) $ |#1| |#1|) 37 (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#2| $ |#1| |#2|) 49 (|has| $ (-6 -4626)))) (-3001 (($) 7 T CONST)) (-1426 ((|#2| $ |#1| |#2|) 50 (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) 48)) (-4004 (((-658 |#2|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-2261 ((|#1| $) 40 (|has| |#1| (-869)))) (-4467 (((-658 |#2|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#2| $) 27 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625))))) (-1813 ((|#1| $) 41 (|has| |#1| (-869)))) (-3987 (($ (-1 |#2| |#2|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#2| |#2|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#2| (-1119)))) (-3708 (((-658 |#1|) $) 43)) (-3780 (((-141) |#1| $) 44)) (-2951 (((-1137) $) 21 (|has| |#2| (-1119)))) (-1918 ((|#2| $) 39 (|has| |#1| (-869)))) (-1892 (($ $ |#2|) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#2|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#2|))) 26 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) 25 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) 24 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) 23 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#2| $) 42 (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#2| $ |#1| |#2|) 47) ((|#2| $ |#1|) 46)) (-3452 (((-790) (-1 (-141) |#2|) $) 31 (|has| $ (-6 -4625))) (((-790) |#2| $) 28 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#2| (-1119)))) (-3369 (((-141) (-1 (-141) |#2|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#2| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-625 |#1| |#2|) (-1311) (-1119) (-1225)) (T -625)) 
+((-4210 (*1 *2 *1) (-12 (-4 *1 (-625 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1225)) (-5 *2 (-658 *4)))) (-3780 (*1 *2 *3 *1) (-12 (-4 *1 (-625 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1225)) (-5 *2 (-141)))) (-3708 (*1 *2 *1) (-12 (-4 *1 (-625 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1225)) (-5 *2 (-658 *3)))) (-2254 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-625 *4 *3)) (-4 *4 (-1119)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-141)))) (-1813 (*1 *2 *1) (-12 (-4 *1 (-625 *2 *3)) (-4 *3 (-1225)) (-4 *2 (-1119)) (-4 *2 (-869)))) (-2261 (*1 *2 *1) (-12 (-4 *1 (-625 *2 *3)) (-4 *3 (-1225)) (-4 *2 (-1119)) (-4 *2 (-869)))) (-1918 (*1 *2 *1) (-12 (-4 *1 (-625 *3 *2)) (-4 *3 (-1119)) (-4 *3 (-869)) (-4 *2 (-1225)))) (-1892 (*1 *1 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-625 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225)))) (-3898 (*1 *2 *1 *3 *3) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-625 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1225)) (-5 *2 (-1285))))) 
+(-13 (-523 |t#2|) (-305 |t#1| |t#2|) (-10 -8 (-15 -4210 ((-658 |t#2|) $)) (-15 -3780 ((-141) |t#1| $)) (-15 -3708 ((-658 |t#1|) $)) (IF (|has| |t#2| (-1119)) (IF (|has| $ (-6 -4625)) (-15 -2254 ((-141) |t#2| $)) |noBranch|) |noBranch|) (IF (|has| |t#1| (-869)) (PROGN (-15 -1813 (|t#1| $)) (-15 -2261 (|t#1| $)) (-15 -1918 (|t#2| $))) |noBranch|) (IF (|has| $ (-6 -4626)) (PROGN (-15 -1892 ($ $ |t#2|)) (-15 -3898 ((-1285) $ |t#1| |t#1|))) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#2| (-1119)) ((-632 (-877)) |has| |#2| (-1119)) ((-303 |#1| |#2|) . T) ((-305 |#1| |#2|) . T) ((-325 |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-523 |#2|) . T) ((-547 |#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-1119) |has| |#2| (-1119)) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4509 (((-3 $ "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4061 (((-1280 (-706 |#1|))) NIL (|has| |#2| (-443 |#1|))) (((-1280 (-706 |#1|)) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-3360 (((-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-3001 (($) NIL T CONST)) (-2604 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-2661 (((-3 $ "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-1951 (((-706 |#1|)) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-4282 ((|#1| $) NIL (|has| |#2| (-392 |#1|)))) (-2302 (((-706 |#1|) $) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) $ (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-2503 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-2120 (((-1187 (-980 |#1|))) NIL (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-388))))) (-2111 (($ $ (-944)) NIL)) (-1431 ((|#1| $) NIL (|has| |#2| (-392 |#1|)))) (-3916 (((-1187 |#1|) $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-1874 ((|#1|) NIL (|has| |#2| (-443 |#1|))) ((|#1| (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-1582 (((-1187 |#1|) $) NIL (|has| |#2| (-392 |#1|)))) (-4194 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-1626 (($ (-1280 |#1|)) NIL (|has| |#2| (-443 |#1|))) (($ (-1280 |#1|) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-3371 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-4175 (((-944)) NIL (|has| |#2| (-392 |#1|)))) (-2169 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-1833 (($ $ (-944)) NIL)) (-3700 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2973 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2467 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-1563 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-3994 (((-3 $ "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-2794 (((-706 |#1|)) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-1869 ((|#1| $) NIL (|has| |#2| (-392 |#1|)))) (-1802 (((-706 |#1|) $) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) $ (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-4158 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-3004 (((-1187 (-980 |#1|))) NIL (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-388))))) (-2682 (($ $ (-944)) NIL)) (-3061 ((|#1| $) NIL (|has| |#2| (-392 |#1|)))) (-2013 (((-1187 |#1|) $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-3030 ((|#1|) NIL (|has| |#2| (-443 |#1|))) ((|#1| (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-2397 (((-1187 |#1|) $) NIL (|has| |#2| (-392 |#1|)))) (-3847 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2685 (((-1173) $) NIL)) (-4106 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2339 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2297 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2951 (((-1137) $) NIL)) (-2716 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-3927 ((|#1| $ (-592)) NIL (|has| |#2| (-443 |#1|)))) (-2231 (((-706 |#1|) (-1280 $)) NIL (|has| |#2| (-443 |#1|))) (((-1280 |#1|) $) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) (-1280 $) (-1280 $)) NIL (|has| |#2| (-392 |#1|))) (((-1280 |#1|) $ (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-1778 (($ (-1280 |#1|)) NIL (|has| |#2| (-443 |#1|))) (((-1280 |#1|) $) NIL (|has| |#2| (-443 |#1|)))) (-1473 (((-658 (-980 |#1|))) NIL (|has| |#2| (-443 |#1|))) (((-658 (-980 |#1|)) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-2131 (($ $ $) NIL)) (-3545 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-1683 (((-877) $) NIL) ((|#2| $) 21) (($ |#2|) 22)) (-2195 (((-1280 $)) NIL (|has| |#2| (-443 |#1|)))) (-3664 (((-658 (-1280 |#1|))) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-3667 (($ $ $ $) NIL)) (-1516 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-4572 (($ (-706 |#1|) $) NIL (|has| |#2| (-443 |#1|)))) (-2844 (($ $ $) NIL)) (-3135 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2723 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2359 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-3514 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) 24)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 20) (($ $ |#1|) 19) (($ |#1| $) NIL))) 
+(((-626 |#1| |#2|) (-13 (-763 |#1|) (-632 |#2|) (-10 -8 (-15 -1683 ($ |#2|)) (IF (|has| |#2| (-443 |#1|)) (-6 (-443 |#1|)) |noBranch|) (IF (|has| |#2| (-392 |#1|)) (-6 (-392 |#1|)) |noBranch|))) (-194) (-763 |#1|)) (T -626)) 
+((-1683 (*1 *1 *2) (-12 (-4 *3 (-194)) (-5 *1 (-626 *3 *2)) (-4 *2 (-763 *3))))) 
+(-13 (-763 |#1|) (-632 |#2|) (-10 -8 (-15 -1683 ($ |#2|)) (IF (|has| |#2| (-443 |#1|)) (-6 (-443 |#1|)) |noBranch|) (IF (|has| |#2| (-392 |#1|)) (-6 (-392 |#1|)) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-3388 (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) 33)) (-4016 (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL) (($) NIL)) (-3898 (((-1285) $ (-1173) (-1173)) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-1173) |#1|) 43)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 |#1| "failed") (-1173) $) 46)) (-3001 (($) NIL T CONST)) (-2820 (($ $ (-1173)) 25)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119))))) (-4065 (((-3 |#1| "failed") (-1173) $) 47) (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (($ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL (|has| $ (-6 -4625)))) (-4459 (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (($ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119))))) (-3657 (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119))))) (-4393 (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) 32)) (-1426 ((|#1| $ (-1173) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-1173)) NIL)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625))) (((-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-2538 (($ $) 48)) (-1774 (($ (-414)) 23) (($ (-414) (-1173)) 22)) (-4095 (((-414) $) 34)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-1173) $) NIL (|has| (-1173) (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625))) (((-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (((-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119))))) (-1813 (((-1173) $) NIL (|has| (-1173) (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-2840 (((-658 (-1173)) $) 39)) (-2396 (((-141) (-1173) $) NIL)) (-2690 (((-1173) $) 35)) (-4137 (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL)) (-3708 (((-658 (-1173)) $) NIL)) (-3780 (((-141) (-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4342 (((-1285) $) NIL)) (-1918 ((|#1| $) NIL (|has| (-1173) (-869)))) (-4050 (((-3 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) "failed") (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (($ $ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (($ $ (-658 (-310 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 37)) (-3927 ((|#1| $ (-1173) |#1|) NIL) ((|#1| $ (-1173)) 42)) (-1653 (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL) (($) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (((-790) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (((-790) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL)) (-1683 (((-877) $) 21)) (-2607 (($ $) 26)) (-4560 (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 20)) (-1699 (((-790) $) 41 (|has| $ (-6 -4625))))) 
+(((-627 |#1|) (-13 (-389 (-414) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) (-1202 (-1173) |#1|) (-10 -8 (-6 -4625) (-15 -2538 ($ $)))) (-1119)) (T -627)) 
+((-2538 (*1 *1 *1) (-12 (-5 *1 (-627 *2)) (-4 *2 (-1119))))) 
+(-13 (-389 (-414) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) (-1202 (-1173) |#1|) (-10 -8 (-6 -4625) (-15 -2538 ($ $)))) 
+((-3133 (((-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) $) 15)) (-2840 (((-658 |#2|) $) 19)) (-2396 (((-141) |#2| $) 12))) 
+(((-628 |#1| |#2| |#3|) (-10 -8 (-15 -2840 ((-658 |#2|) |#1|)) (-15 -2396 ((-141) |#2| |#1|)) (-15 -3133 ((-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|))) (-629 |#2| |#3|) (-1119) (-1119)) (T -628)) 
+NIL 
+(-10 -8 (-15 -2840 ((-658 |#2|) |#1|)) (-15 -2396 ((-141) |#2| |#1|)) (-15 -3133 ((-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 42 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 52 (|has| $ (-6 -4625)))) (-2916 (((-3 |#2| "failed") |#1| $) 57)) (-3001 (($) 7 T CONST)) (-1360 (($ $) 55 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 43 (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) 58)) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 54 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 51 (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 53 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 50 (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 49 (|has| $ (-6 -4625)))) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 27 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-2840 (((-658 |#1|) $) 59)) (-2396 (((-141) |#1| $) 60)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 36)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 37)) (-2951 (((-1137) $) 21 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 48)) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 38)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 26 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 25 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 24 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 23 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-1653 (($) 46) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 45)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 31 (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 28 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 47)) (-1683 (((-877) $) 20 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 39)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-629 |#1| |#2|) (-1311) (-1119) (-1119)) (T -629)) 
+((-2396 (*1 *2 *3 *1) (-12 (-4 *1 (-629 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-141)))) (-2840 (*1 *2 *1) (-12 (-4 *1 (-629 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-658 *3)))) (-4065 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-629 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119)))) (-2916 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-629 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119))))) 
+(-13 (-243 (-2 (|:| -1350 |t#1|) (|:| -3552 |t#2|))) (-10 -8 (-15 -2396 ((-141) |t#1| $)) (-15 -2840 ((-658 |t#1|) $)) (-15 -4065 ((-3 |t#2| "failed") |t#1| $)) (-15 -2916 ((-3 |t#2| "failed") |t#1| $)))) 
+(((-39) . T) ((-131 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-125) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) ((-632 (-877)) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) ((-175 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-633 (-565)) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))) ((-243 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-249 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) -12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-523 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-547 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) -12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-1119) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) ((-1225) . T)) 
+((-1672 (((-631 |#2|) |#1|) 15)) (-4281 (((-3 |#1| "failed") (-631 |#2|)) 19))) 
+(((-630 |#1| |#2|) (-10 -7 (-15 -1672 ((-631 |#2|) |#1|)) (-15 -4281 ((-3 |#1| "failed") (-631 |#2|)))) (-869) (-869)) (T -630)) 
+((-4281 (*1 *2 *3) (|partial| -12 (-5 *3 (-631 *4)) (-4 *4 (-869)) (-4 *2 (-869)) (-5 *1 (-630 *2 *4)))) (-1672 (*1 *2 *3) (-12 (-5 *2 (-631 *4)) (-5 *1 (-630 *3 *4)) (-4 *3 (-869)) (-4 *4 (-869))))) 
+(-10 -7 (-15 -1672 ((-631 |#2|) |#1|)) (-15 -4281 ((-3 |#1| "failed") (-631 |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-3200 (((-3 (-1191) "failed") $) 36)) (-1632 (((-1285) $ (-790)) 26)) (-1721 (((-790) $) 25)) (-2791 (((-143) $) 12)) (-4095 (((-1191) $) 20)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-1462 (($ (-143) (-658 |#1|) (-790)) 30) (($ (-1191)) 31)) (-3013 (((-141) $ (-143)) 18) (((-141) $ (-1191)) 16)) (-2535 (((-790) $) 22)) (-2951 (((-1137) $) NIL)) (-1778 (((-914 (-592)) $) 69 (|has| |#1| (-633 (-914 (-592))))) (((-914 (-405)) $) 75 (|has| |#1| (-633 (-914 (-405))))) (((-565) $) 62 (|has| |#1| (-633 (-565))))) (-1683 (((-877) $) 51)) (-4575 (((-658 |#1|) $) 24)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 39)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 40))) 
+(((-631 |#1|) (-13 (-159) (-906 |#1|) (-10 -8 (-15 -4095 ((-1191) $)) (-15 -2791 ((-143) $)) (-15 -4575 ((-658 |#1|) $)) (-15 -2535 ((-790) $)) (-15 -1462 ($ (-143) (-658 |#1|) (-790))) (-15 -1462 ($ (-1191))) (-15 -3200 ((-3 (-1191) "failed") $)) (-15 -3013 ((-141) $ (-143))) (-15 -3013 ((-141) $ (-1191))) (IF (|has| |#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|))) (-869)) (T -631)) 
+((-4095 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) (-2791 (*1 *2 *1) (-12 (-5 *2 (-143)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) (-4575 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) (-2535 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) (-1462 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-143)) (-5 *3 (-658 *5)) (-5 *4 (-790)) (-4 *5 (-869)) (-5 *1 (-631 *5)))) (-1462 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) (-3200 (*1 *2 *1) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) (-3013 (*1 *2 *1 *3) (-12 (-5 *3 (-143)) (-5 *2 (-141)) (-5 *1 (-631 *4)) (-4 *4 (-869)))) (-3013 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-141)) (-5 *1 (-631 *4)) (-4 *4 (-869))))) 
+(-13 (-159) (-906 |#1|) (-10 -8 (-15 -4095 ((-1191) $)) (-15 -2791 ((-143) $)) (-15 -4575 ((-658 |#1|) $)) (-15 -2535 ((-790) $)) (-15 -1462 ($ (-143) (-658 |#1|) (-790))) (-15 -1462 ($ (-1191))) (-15 -3200 ((-3 (-1191) "failed") $)) (-15 -3013 ((-141) $ (-143))) (-15 -3013 ((-141) $ (-1191))) (IF (|has| |#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|))) 
+((-1683 ((|#1| $) 6))) 
+(((-632 |#1|) (-1311) (-1225)) (T -632)) 
+((-1683 (*1 *2 *1) (-12 (-4 *1 (-632 *2)) (-4 *2 (-1225))))) 
+(-13 (-10 -8 (-15 -1683 (|t#1| $)))) 
+((-1778 ((|#1| $) 6))) 
+(((-633 |#1|) (-1311) (-1225)) (T -633)) 
+((-1778 (*1 *2 *1) (-12 (-4 *1 (-633 *2)) (-4 *2 (-1225))))) 
+(-13 (-10 -8 (-15 -1778 (|t#1| $)))) 
+((-2199 (((-3 (-1187 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|) (-1 (-444 |#2|) |#2|)) 13) (((-3 (-1187 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|)) 14))) 
+(((-634 |#1| |#2|) (-10 -7 (-15 -2199 ((-3 (-1187 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|))) (-15 -2199 ((-3 (-1187 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|) (-1 (-444 |#2|) |#2|)))) (-13 (-171) (-27) (-1065 (-592)) (-1065 (-433 (-592)))) (-1255 |#1|)) (T -634)) 
+((-2199 (*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-171) (-27) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-1187 (-433 *6))) (-5 *1 (-634 *5 *6)) (-5 *3 (-433 *6)))) (-2199 (*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-171) (-27) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-1187 (-433 *5))) (-5 *1 (-634 *4 *5)) (-5 *3 (-433 *5))))) 
+(-10 -7 (-15 -2199 ((-3 (-1187 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|))) (-15 -2199 ((-3 (-1187 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|) (-1 (-444 |#2|) |#2|)))) 
+((-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) 10))) 
+(((-635 |#1| |#2|) (-10 -8 (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) (-636 |#2|) (-1075)) (T -635)) 
+NIL 
+(-10 -8 (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 35)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ |#1| $) 36))) 
+(((-636 |#1|) (-1311) (-1075)) (T -636)) 
+((-1683 (*1 *1 *2) (-12 (-4 *1 (-636 *2)) (-4 *2 (-1075))))) 
+(-13 (-1075) (-661 |t#1|) (-10 -8 (-15 -1683 ($ |t#1|)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-743) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3940 (((-592) $) NIL (|has| |#1| (-867)))) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-1691 (((-141) $) NIL (|has| |#1| (-867)))) (-3558 (((-141) $) NIL)) (-1448 ((|#1| $) 13)) (-1324 (((-141) $) NIL (|has| |#1| (-867)))) (-1837 (($ $ $) NIL (|has| |#1| (-867)))) (-3319 (($ $ $) NIL (|has| |#1| (-867)))) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1456 ((|#3| $) 15)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) NIL)) (-4010 (((-790)) 20)) (-1392 (($ $) NIL (|has| |#1| (-867)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) 12 T CONST)) (-3286 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3313 (($ $ |#3|) NIL) (($ |#1| |#3|) 11)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 17) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
+(((-637 |#1| |#2| |#3|) (-13 (-43 |#2|) (-10 -8 (IF (|has| |#1| (-867)) (-6 (-867)) |noBranch|) (-15 -3313 ($ $ |#3|)) (-15 -3313 ($ |#1| |#3|)) (-15 -1448 (|#1| $)) (-15 -1456 (|#3| $)))) (-43 |#2|) (-194) (|SubsetCategory| (-743) |#2|)) (T -637)) 
+((-3313 (*1 *1 *1 *2) (-12 (-4 *4 (-194)) (-5 *1 (-637 *3 *4 *2)) (-4 *3 (-43 *4)) (-4 *2 (|SubsetCategory| (-743) *4)))) (-3313 (*1 *1 *2 *3) (-12 (-4 *4 (-194)) (-5 *1 (-637 *2 *4 *3)) (-4 *2 (-43 *4)) (-4 *3 (|SubsetCategory| (-743) *4)))) (-1448 (*1 *2 *1) (-12 (-4 *3 (-194)) (-4 *2 (-43 *3)) (-5 *1 (-637 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-743) *3)))) (-1456 (*1 *2 *1) (-12 (-4 *4 (-194)) (-4 *2 (|SubsetCategory| (-743) *4)) (-5 *1 (-637 *3 *4 *2)) (-4 *3 (-43 *4))))) 
+(-13 (-43 |#2|) (-10 -8 (IF (|has| |#1| (-867)) (-6 (-867)) |noBranch|) (-15 -3313 ($ $ |#3|)) (-15 -3313 ($ |#1| |#3|)) (-15 -1448 (|#1| $)) (-15 -1456 (|#3| $)))) 
+((-3878 ((|#2| |#2| (-1191) (-1191)) 18))) 
+(((-638 |#1| |#2|) (-10 -7 (-15 -3878 (|#2| |#2| (-1191) (-1191)))) (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592))) (-13 (-1211) (-987) (-29 |#1|))) (T -638)) 
+((-3878 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-638 *4 *2)) (-4 *2 (-13 (-1211) (-987) (-29 *4)))))) 
+(-10 -7 (-15 -3878 (|#2| |#2| (-1191) (-1191)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 52)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2970 ((|#1| $) 49)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1504 (((-2 (|:| -4104 $) (|:| -4134 (-433 |#2|))) (-433 |#2|)) 95 (|has| |#1| (-388)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 83) (((-3 |#2| "failed") $) 80)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL) ((|#2| $) NIL)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) 24)) (-3371 (((-3 $ "failed") $) 74)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-4346 (((-592) $) 19)) (-3558 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) 36)) (-4526 (($ |#1| (-592)) 21)) (-4579 ((|#1| $) 51)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) 85 (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 98 (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-3616 (((-3 $ "failed") $ $) 78)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2769 (((-790) $) 97 (|has| |#1| (-388)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 96 (|has| |#1| (-388)))) (-3644 (($ $ (-1 |#2| |#2|)) 65) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-790)) NIL (|has| |#2| (-247))) (($ $) NIL (|has| |#2| (-247)))) (-4525 (((-592) $) 34)) (-1778 (((-433 |#2|) $) 42)) (-1683 (((-877) $) 61) (($ (-592)) 32) (($ $) NIL) (($ (-433 (-592))) NIL (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) 31) (($ |#2|) 22)) (-1937 ((|#1| $ (-592)) 62)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) 29)) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 9 T CONST)) (-4257 (($) 12 T CONST)) (-1940 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-790)) NIL (|has| |#2| (-247))) (($ $) NIL (|has| |#2| (-247)))) (-3255 (((-141) $ $) 17)) (-3306 (($ $) 46) (($ $ $) NIL)) (-3300 (($ $ $) 75)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 26) (($ $ $) 44))) 
+(((-639 |#1| |#2|) (-13 (-245 |#2|) (-582) (-633 (-433 |#2|)) (-437 |#1|) (-1065 |#2|) (-10 -8 (-15 -2027 ((-141) $)) (-15 -4525 ((-592) $)) (-15 -4346 ((-592) $)) (-15 -4593 ($ $)) (-15 -4579 (|#1| $)) (-15 -2970 (|#1| $)) (-15 -1937 (|#1| $ (-592))) (-15 -4526 ($ |#1| (-592))) (IF (|has| |#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-6 (-323)) (-15 -1504 ((-2 (|:| -4104 $) (|:| -4134 (-433 |#2|))) (-433 |#2|)))) |noBranch|))) (-582) (-1255 |#1|)) (T -639)) 
+((-2027 (*1 *2 *1) (-12 (-4 *3 (-582)) (-5 *2 (-141)) (-5 *1 (-639 *3 *4)) (-4 *4 (-1255 *3)))) (-4525 (*1 *2 *1) (-12 (-4 *3 (-582)) (-5 *2 (-592)) (-5 *1 (-639 *3 *4)) (-4 *4 (-1255 *3)))) (-4346 (*1 *2 *1) (-12 (-4 *3 (-582)) (-5 *2 (-592)) (-5 *1 (-639 *3 *4)) (-4 *4 (-1255 *3)))) (-4593 (*1 *1 *1) (-12 (-4 *2 (-582)) (-5 *1 (-639 *2 *3)) (-4 *3 (-1255 *2)))) (-4579 (*1 *2 *1) (-12 (-4 *2 (-582)) (-5 *1 (-639 *2 *3)) (-4 *3 (-1255 *2)))) (-2970 (*1 *2 *1) (-12 (-4 *2 (-582)) (-5 *1 (-639 *2 *3)) (-4 *3 (-1255 *2)))) (-1937 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *2 (-582)) (-5 *1 (-639 *2 *4)) (-4 *4 (-1255 *2)))) (-4526 (*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-4 *2 (-582)) (-5 *1 (-639 *2 *4)) (-4 *4 (-1255 *2)))) (-1504 (*1 *2 *3) (-12 (-4 *4 (-388)) (-4 *4 (-582)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -4104 (-639 *4 *5)) (|:| -4134 (-433 *5)))) (-5 *1 (-639 *4 *5)) (-5 *3 (-433 *5))))) 
+(-13 (-245 |#2|) (-582) (-633 (-433 |#2|)) (-437 |#1|) (-1065 |#2|) (-10 -8 (-15 -2027 ((-141) $)) (-15 -4525 ((-592) $)) (-15 -4346 ((-592) $)) (-15 -4593 ($ $)) (-15 -4579 (|#1| $)) (-15 -2970 (|#1| $)) (-15 -1937 (|#1| $ (-592))) (-15 -4526 ($ |#1| (-592))) (IF (|has| |#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-6 (-323)) (-15 -1504 ((-2 (|:| -4104 $) (|:| -4134 (-433 |#2|))) (-433 |#2|)))) |noBranch|))) 
+((-2248 (((-658 |#6|) (-658 |#4|) (-141)) 46)) (-3337 ((|#6| |#6|) 39))) 
+(((-640 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -3337 (|#6| |#6|)) (-15 -2248 ((-658 |#6|) (-658 |#4|) (-141)))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1094 |#1| |#2| |#3| |#4|) (-1128 |#1| |#2| |#3| |#4|)) (T -640)) 
+((-2248 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 *10)) (-5 *1 (-640 *5 *6 *7 *8 *9 *10)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *10 (-1128 *5 *6 *7 *8)))) (-3337 (*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-640 *3 *4 *5 *6 *7 *2)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *2 (-1128 *3 *4 *5 *6))))) 
+(-10 -7 (-15 -3337 (|#6| |#6|)) (-15 -2248 ((-658 |#6|) (-658 |#4|) (-141)))) 
+((-3420 (((-141) |#3| (-790) (-658 |#3|)) 22)) (-3477 (((-3 (-2 (|:| |polfac| (-658 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-658 (-1187 |#3|)))) "failed") |#3| (-658 (-1187 |#3|)) (-2 (|:| |contp| |#3|) (|:| -2033 (-658 (-2 (|:| |irr| |#4|) (|:| -1777 (-592)))))) (-658 |#3|) (-658 |#1|) (-658 |#3|)) 51))) 
+(((-641 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3420 ((-141) |#3| (-790) (-658 |#3|))) (-15 -3477 ((-3 (-2 (|:| |polfac| (-658 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-658 (-1187 |#3|)))) "failed") |#3| (-658 (-1187 |#3|)) (-2 (|:| |contp| |#3|) (|:| -2033 (-658 (-2 (|:| |irr| |#4|) (|:| -1777 (-592)))))) (-658 |#3|) (-658 |#1|) (-658 |#3|)))) (-869) (-815) (-323) (-977 |#3| |#2| |#1|)) (T -641)) 
+((-3477 (*1 *2 *3 *4 *5 *6 *7 *6) (|partial| -12 (-5 *5 (-2 (|:| |contp| *3) (|:| -2033 (-658 (-2 (|:| |irr| *10) (|:| -1777 (-592))))))) (-5 *6 (-658 *3)) (-5 *7 (-658 *8)) (-4 *8 (-869)) (-4 *3 (-323)) (-4 *10 (-977 *3 *9 *8)) (-4 *9 (-815)) (-5 *2 (-2 (|:| |polfac| (-658 *10)) (|:| |correct| *3) (|:| |corrfact| (-658 (-1187 *3))))) (-5 *1 (-641 *8 *9 *3 *10)) (-5 *4 (-658 (-1187 *3))))) (-3420 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-790)) (-5 *5 (-658 *3)) (-4 *3 (-323)) (-4 *6 (-869)) (-4 *7 (-815)) (-5 *2 (-141)) (-5 *1 (-641 *6 *7 *3 *8)) (-4 *8 (-977 *3 *7 *6))))) 
+(-10 -7 (-15 -3420 ((-141) |#3| (-790) (-658 |#3|))) (-15 -3477 ((-3 (-2 (|:| |polfac| (-658 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-658 (-1187 |#3|)))) "failed") |#3| (-658 (-1187 |#3|)) (-2 (|:| |contp| |#3|) (|:| -2033 (-658 (-2 (|:| |irr| |#4|) (|:| -1777 (-592)))))) (-658 |#3|) (-658 |#1|) (-658 |#3|)))) 
+((-1641 (((-141) $ $) NIL)) (-2692 (((-658 |#1|) $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-4103 (($ $) 67)) (-4546 (((-681 |#1| |#2|) $) 52)) (-3725 (((-658 (-2 (|:| |k| (-915 |#1|)) (|:| |c| |#2|))) $) 36)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 70)) (-2203 (((-658 (-310 |#2|)) $ $) 33)) (-2951 (((-1137) $) NIL)) (-1430 (($ (-681 |#1| |#2|)) 48)) (-2227 (($ $ $) NIL)) (-2131 (($ $ $) NIL)) (-1683 (((-877) $) 58) (((-1293 |#1| |#2|) $) NIL) (((-1298 |#1| |#2|) $) 66)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-4257 (($) 53 T CONST)) (-3954 (((-658 (-2 (|:| |k| (-688 |#1|)) (|:| |c| |#2|))) $) 31)) (-3298 (((-658 (-681 |#1| |#2|)) (-658 |#1|)) 65)) (-3255 (((-141) $ $) 54)) (-3313 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ $ $) 44))) 
+(((-642 |#1| |#2| |#3|) (-13 (-502) (-10 -8 (-15 -1430 ($ (-681 |#1| |#2|))) (-15 -4546 ((-681 |#1| |#2|) $)) (-15 -3725 ((-658 (-2 (|:| |k| (-915 |#1|)) (|:| |c| |#2|))) $)) (-15 -1683 ((-1293 |#1| |#2|) $)) (-15 -1683 ((-1298 |#1| |#2|) $)) (-15 -4103 ($ $)) (-15 -2692 ((-658 |#1|) $)) (-15 -3298 ((-658 (-681 |#1| |#2|)) (-658 |#1|))) (-15 -3954 ((-658 (-2 (|:| |k| (-688 |#1|)) (|:| |c| |#2|))) $)) (-15 -2203 ((-658 (-310 |#2|)) $ $)))) (-869) (-13 (-194) (-734 (-433 (-592)))) (-944)) (T -642)) 
+((-1430 (*1 *1 *2) (-12 (-5 *2 (-681 *3 *4)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-5 *1 (-642 *3 *4 *5)) (-14 *5 (-944)))) (-4546 (*1 *2 *1) (-12 (-5 *2 (-681 *3 *4)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) (-3725 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |k| (-915 *3)) (|:| |c| *4)))) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1293 *3 *4)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1298 *3 *4)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) (-4103 (*1 *1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-869)) (-4 *3 (-13 (-194) (-734 (-433 (-592))))) (-14 *4 (-944)))) (-2692 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) (-3298 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-869)) (-5 *2 (-658 (-681 *4 *5))) (-5 *1 (-642 *4 *5 *6)) (-4 *5 (-13 (-194) (-734 (-433 (-592))))) (-14 *6 (-944)))) (-3954 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |k| (-688 *3)) (|:| |c| *4)))) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) (-2203 (*1 *2 *1 *1) (-12 (-5 *2 (-658 (-310 *4))) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944))))) 
+(-13 (-502) (-10 -8 (-15 -1430 ($ (-681 |#1| |#2|))) (-15 -4546 ((-681 |#1| |#2|) $)) (-15 -3725 ((-658 (-2 (|:| |k| (-915 |#1|)) (|:| |c| |#2|))) $)) (-15 -1683 ((-1293 |#1| |#2|) $)) (-15 -1683 ((-1298 |#1| |#2|) $)) (-15 -4103 ($ $)) (-15 -2692 ((-658 |#1|) $)) (-15 -3298 ((-658 (-681 |#1| |#2|)) (-658 |#1|))) (-15 -3954 ((-658 (-2 (|:| |k| (-688 |#1|)) (|:| |c| |#2|))) $)) (-15 -2203 ((-658 (-310 |#2|)) $ $)))) 
+((-2248 (((-658 (-1160 |#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|)))) (-658 (-802 |#1| (-879 |#2|))) (-141)) 70) (((-658 (-1072 |#1| |#2|)) (-658 (-802 |#1| (-879 |#2|))) (-141)) 56)) (-1480 (((-141) (-658 (-802 |#1| (-879 |#2|)))) 22)) (-2567 (((-658 (-1160 |#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|)))) (-658 (-802 |#1| (-879 |#2|))) (-141)) 69)) (-4571 (((-658 (-1072 |#1| |#2|)) (-658 (-802 |#1| (-879 |#2|))) (-141)) 55)) (-3903 (((-658 (-802 |#1| (-879 |#2|))) (-658 (-802 |#1| (-879 |#2|)))) 26)) (-4338 (((-3 (-658 (-802 |#1| (-879 |#2|))) "failed") (-658 (-802 |#1| (-879 |#2|)))) 25))) 
+(((-643 |#1| |#2|) (-10 -7 (-15 -1480 ((-141) (-658 (-802 |#1| (-879 |#2|))))) (-15 -4338 ((-3 (-658 (-802 |#1| (-879 |#2|))) "failed") (-658 (-802 |#1| (-879 |#2|))))) (-15 -3903 ((-658 (-802 |#1| (-879 |#2|))) (-658 (-802 |#1| (-879 |#2|))))) (-15 -4571 ((-658 (-1072 |#1| |#2|)) (-658 (-802 |#1| (-879 |#2|))) (-141))) (-15 -2567 ((-658 (-1160 |#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|)))) (-658 (-802 |#1| (-879 |#2|))) (-141))) (-15 -2248 ((-658 (-1072 |#1| |#2|)) (-658 (-802 |#1| (-879 |#2|))) (-141))) (-15 -2248 ((-658 (-1160 |#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|)))) (-658 (-802 |#1| (-879 |#2|))) (-141)))) (-477) (-658 (-1191))) (T -643)) 
+((-2248 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1160 *5 (-558 (-879 *6)) (-879 *6) (-802 *5 (-879 *6))))) (-5 *1 (-643 *5 *6)))) (-2248 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-643 *5 *6)))) (-2567 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1160 *5 (-558 (-879 *6)) (-879 *6) (-802 *5 (-879 *6))))) (-5 *1 (-643 *5 *6)))) (-4571 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-643 *5 *6)))) (-3903 (*1 *2 *2) (-12 (-5 *2 (-658 (-802 *3 (-879 *4)))) (-4 *3 (-477)) (-14 *4 (-658 (-1191))) (-5 *1 (-643 *3 *4)))) (-4338 (*1 *2 *2) (|partial| -12 (-5 *2 (-658 (-802 *3 (-879 *4)))) (-4 *3 (-477)) (-14 *4 (-658 (-1191))) (-5 *1 (-643 *3 *4)))) (-1480 (*1 *2 *3) (-12 (-5 *3 (-658 (-802 *4 (-879 *5)))) (-4 *4 (-477)) (-14 *5 (-658 (-1191))) (-5 *2 (-141)) (-5 *1 (-643 *4 *5))))) 
+(-10 -7 (-15 -1480 ((-141) (-658 (-802 |#1| (-879 |#2|))))) (-15 -4338 ((-3 (-658 (-802 |#1| (-879 |#2|))) "failed") (-658 (-802 |#1| (-879 |#2|))))) (-15 -3903 ((-658 (-802 |#1| (-879 |#2|))) (-658 (-802 |#1| (-879 |#2|))))) (-15 -4571 ((-658 (-1072 |#1| |#2|)) (-658 (-802 |#1| (-879 |#2|))) (-141))) (-15 -2567 ((-658 (-1160 |#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|)))) (-658 (-802 |#1| (-879 |#2|))) (-141))) (-15 -2248 ((-658 (-1072 |#1| |#2|)) (-658 (-802 |#1| (-879 |#2|))) (-141))) (-15 -2248 ((-658 (-1160 |#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|)))) (-658 (-802 |#1| (-879 |#2|))) (-141)))) 
+((-1588 (($ $) 38)) (-1507 (($ $) 21)) (-1575 (($ $) 37)) (-1495 (($ $) 22)) (-1601 (($ $) 36)) (-1521 (($ $) 23)) (-1435 (($) 48)) (-4546 (($ $) 45)) (-1457 (($ $) 17)) (-1868 (($ $ (-1111 $)) 7) (($ $ (-1191)) 6)) (-2424 (($ $) 14)) (-1927 (($ $) 13)) (-1430 (($ $) 46)) (-1463 (($ $) 15)) (-1486 (($ $) 16)) (-1609 (($ $) 35)) (-1527 (($ $) 24)) (-1594 (($ $) 34)) (-1515 (($ $) 25)) (-1581 (($ $) 33)) (-1501 (($ $) 26)) (-1630 (($ $) 44)) (-1546 (($ $) 32)) (-1617 (($ $) 43)) (-1533 (($ $) 31)) (-1642 (($ $) 42)) (-1559 (($ $) 30)) (-2892 (($ $) 41)) (-1567 (($ $) 29)) (-1636 (($ $) 40)) (-1552 (($ $) 28)) (-1624 (($ $) 39)) (-1540 (($ $) 27)) (-2672 (($ $) 19)) (-4299 (($ $) 20)) (-4157 (($ $) 18)) (** (($ $ $) 47))) 
+(((-644) (-1311)) (T -644)) 
+((-4299 (*1 *1 *1) (-4 *1 (-644))) (-2672 (*1 *1 *1) (-4 *1 (-644))) (-4157 (*1 *1 *1) (-4 *1 (-644))) (-1457 (*1 *1 *1) (-4 *1 (-644))) (-1486 (*1 *1 *1) (-4 *1 (-644))) (-1463 (*1 *1 *1) (-4 *1 (-644))) (-2424 (*1 *1 *1) (-4 *1 (-644))) (-1927 (*1 *1 *1) (-4 *1 (-644)))) 
+(-13 (-987) (-1211) (-10 -8 (-15 -4299 ($ $)) (-15 -2672 ($ $)) (-15 -4157 ($ $)) (-15 -1457 ($ $)) (-15 -1486 ($ $)) (-15 -1463 ($ $)) (-15 -2424 ($ $)) (-15 -1927 ($ $)))) 
+(((-40) . T) ((-116) . T) ((-301) . T) ((-526) . T) ((-987) . T) ((-1211) . T) ((-1214) . T)) 
+((-2791 (((-143) (-143)) 87)) (-1457 ((|#2| |#2|) 32)) (-1868 ((|#2| |#2| (-1111 |#2|)) 83) ((|#2| |#2| (-1191)) 56)) (-2424 ((|#2| |#2|) 34)) (-1927 ((|#2| |#2|) 35)) (-1463 ((|#2| |#2|) 31)) (-1486 ((|#2| |#2|) 33)) (-3038 (((-141) (-143)) 38)) (-2672 ((|#2| |#2|) 28)) (-4299 ((|#2| |#2|) 30)) (-4157 ((|#2| |#2|) 29))) 
+(((-645 |#1| |#2|) (-10 -7 (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -4299 (|#2| |#2|)) (-15 -2672 (|#2| |#2|)) (-15 -4157 (|#2| |#2|)) (-15 -1457 (|#2| |#2|)) (-15 -1463 (|#2| |#2|)) (-15 -1486 (|#2| |#2|)) (-15 -2424 (|#2| |#2|)) (-15 -1927 (|#2| |#2|)) (-15 -1868 (|#2| |#2| (-1191))) (-15 -1868 (|#2| |#2| (-1111 |#2|)))) (-13 (-869) (-582)) (-13 (-456 |#1|) (-1030) (-1211))) (T -645)) 
+((-1868 (*1 *2 *2 *3) (-12 (-5 *3 (-1111 *2)) (-4 *2 (-13 (-456 *4) (-1030) (-1211))) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-645 *4 *2)))) (-1868 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-645 *4 *2)) (-4 *2 (-13 (-456 *4) (-1030) (-1211))))) (-1927 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211))))) (-2424 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211))))) (-1486 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211))))) (-1463 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211))))) (-1457 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211))))) (-4157 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211))))) (-2672 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211))))) (-4299 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211))))) (-2791 (*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *4)) (-4 *4 (-13 (-456 *3) (-1030) (-1211))))) (-3038 (*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-645 *4 *5)) (-4 *5 (-13 (-456 *4) (-1030) (-1211)))))) 
+(-10 -7 (-15 -3038 ((-141) (-143))) (-15 -2791 ((-143) (-143))) (-15 -4299 (|#2| |#2|)) (-15 -2672 (|#2| |#2|)) (-15 -4157 (|#2| |#2|)) (-15 -1457 (|#2| |#2|)) (-15 -1463 (|#2| |#2|)) (-15 -1486 (|#2| |#2|)) (-15 -2424 (|#2| |#2|)) (-15 -1927 (|#2| |#2|)) (-15 -1868 (|#2| |#2| (-1191))) (-15 -1868 (|#2| |#2| (-1111 |#2|)))) 
+((-2239 (((-516 |#1| |#2|) (-264 |#1| |#2|)) 52)) (-3937 (((-658 (-264 |#1| |#2|)) (-658 (-516 |#1| |#2|))) 67)) (-3905 (((-516 |#1| |#2|) (-658 (-516 |#1| |#2|)) (-879 |#1|)) 69) (((-516 |#1| |#2|) (-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|)) (-879 |#1|)) 68)) (-2018 (((-2 (|:| |gblist| (-658 (-264 |#1| |#2|))) (|:| |gvlist| (-658 (-592)))) (-658 (-516 |#1| |#2|))) 105)) (-4173 (((-658 (-516 |#1| |#2|)) (-879 |#1|) (-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|))) 82)) (-4318 (((-2 (|:| |glbase| (-658 (-264 |#1| |#2|))) (|:| |glval| (-658 (-592)))) (-658 (-264 |#1| |#2|))) 116)) (-3302 (((-1280 |#2|) (-516 |#1| |#2|) (-658 (-516 |#1| |#2|))) 57)) (-3646 (((-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|))) 39)) (-1865 (((-264 |#1| |#2|) (-264 |#1| |#2|) (-658 (-264 |#1| |#2|))) 49)) (-2739 (((-264 |#1| |#2|) (-658 |#2|) (-264 |#1| |#2|) (-658 (-264 |#1| |#2|))) 89))) 
+(((-646 |#1| |#2|) (-10 -7 (-15 -2018 ((-2 (|:| |gblist| (-658 (-264 |#1| |#2|))) (|:| |gvlist| (-658 (-592)))) (-658 (-516 |#1| |#2|)))) (-15 -4318 ((-2 (|:| |glbase| (-658 (-264 |#1| |#2|))) (|:| |glval| (-658 (-592)))) (-658 (-264 |#1| |#2|)))) (-15 -3937 ((-658 (-264 |#1| |#2|)) (-658 (-516 |#1| |#2|)))) (-15 -3905 ((-516 |#1| |#2|) (-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|)) (-879 |#1|))) (-15 -3905 ((-516 |#1| |#2|) (-658 (-516 |#1| |#2|)) (-879 |#1|))) (-15 -3646 ((-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|)))) (-15 -3302 ((-1280 |#2|) (-516 |#1| |#2|) (-658 (-516 |#1| |#2|)))) (-15 -2739 ((-264 |#1| |#2|) (-658 |#2|) (-264 |#1| |#2|) (-658 (-264 |#1| |#2|)))) (-15 -4173 ((-658 (-516 |#1| |#2|)) (-879 |#1|) (-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|)))) (-15 -1865 ((-264 |#1| |#2|) (-264 |#1| |#2|) (-658 (-264 |#1| |#2|)))) (-15 -2239 ((-516 |#1| |#2|) (-264 |#1| |#2|)))) (-658 (-1191)) (-477)) (T -646)) 
+((-2239 (*1 *2 *3) (-12 (-5 *3 (-264 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *2 (-516 *4 *5)) (-5 *1 (-646 *4 *5)))) (-1865 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-264 *4 *5))) (-5 *2 (-264 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *1 (-646 *4 *5)))) (-4173 (*1 *2 *3 *2 *2) (-12 (-5 *2 (-658 (-516 *4 *5))) (-5 *3 (-879 *4)) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *1 (-646 *4 *5)))) (-2739 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-658 (-264 *5 *6))) (-4 *6 (-477)) (-5 *2 (-264 *5 *6)) (-14 *5 (-658 (-1191))) (-5 *1 (-646 *5 *6)))) (-3302 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-516 *5 *6))) (-5 *3 (-516 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-477)) (-5 *2 (-1280 *6)) (-5 *1 (-646 *5 *6)))) (-3646 (*1 *2 *2) (-12 (-5 *2 (-658 (-516 *3 *4))) (-14 *3 (-658 (-1191))) (-4 *4 (-477)) (-5 *1 (-646 *3 *4)))) (-3905 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-516 *5 *6))) (-5 *4 (-879 *5)) (-14 *5 (-658 (-1191))) (-5 *2 (-516 *5 *6)) (-5 *1 (-646 *5 *6)) (-4 *6 (-477)))) (-3905 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 (-516 *5 *6))) (-5 *4 (-879 *5)) (-14 *5 (-658 (-1191))) (-5 *2 (-516 *5 *6)) (-5 *1 (-646 *5 *6)) (-4 *6 (-477)))) (-3937 (*1 *2 *3) (-12 (-5 *3 (-658 (-516 *4 *5))) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *2 (-658 (-264 *4 *5))) (-5 *1 (-646 *4 *5)))) (-4318 (*1 *2 *3) (-12 (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *2 (-2 (|:| |glbase| (-658 (-264 *4 *5))) (|:| |glval| (-658 (-592))))) (-5 *1 (-646 *4 *5)) (-5 *3 (-658 (-264 *4 *5))))) (-2018 (*1 *2 *3) (-12 (-5 *3 (-658 (-516 *4 *5))) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *2 (-2 (|:| |gblist| (-658 (-264 *4 *5))) (|:| |gvlist| (-658 (-592))))) (-5 *1 (-646 *4 *5))))) 
+(-10 -7 (-15 -2018 ((-2 (|:| |gblist| (-658 (-264 |#1| |#2|))) (|:| |gvlist| (-658 (-592)))) (-658 (-516 |#1| |#2|)))) (-15 -4318 ((-2 (|:| |glbase| (-658 (-264 |#1| |#2|))) (|:| |glval| (-658 (-592)))) (-658 (-264 |#1| |#2|)))) (-15 -3937 ((-658 (-264 |#1| |#2|)) (-658 (-516 |#1| |#2|)))) (-15 -3905 ((-516 |#1| |#2|) (-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|)) (-879 |#1|))) (-15 -3905 ((-516 |#1| |#2|) (-658 (-516 |#1| |#2|)) (-879 |#1|))) (-15 -3646 ((-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|)))) (-15 -3302 ((-1280 |#2|) (-516 |#1| |#2|) (-658 (-516 |#1| |#2|)))) (-15 -2739 ((-264 |#1| |#2|) (-658 |#2|) (-264 |#1| |#2|) (-658 (-264 |#1| |#2|)))) (-15 -4173 ((-658 (-516 |#1| |#2|)) (-879 |#1|) (-658 (-516 |#1| |#2|)) (-658 (-516 |#1| |#2|)))) (-15 -1865 ((-264 |#1| |#2|) (-264 |#1| |#2|) (-658 (-264 |#1| |#2|)))) (-15 -2239 ((-516 |#1| |#2|) (-264 |#1| |#2|)))) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) NIL)) (-3898 (((-1285) $ (-1173) (-1173)) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-57) $ (-1173) (-57)) 16) (((-57) $ (-1191) (-57)) 17)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 (-57) "failed") (-1173) $) NIL)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119))))) (-4065 (($ (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-3 (-57) "failed") (-1173) $) NIL)) (-4459 (($ (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $ (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119)))) (((-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $ (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-57) $ (-1173) (-57)) NIL (|has| $ (-6 -4626)))) (-3959 (((-57) $ (-1173)) NIL)) (-4004 (((-658 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-658 (-57)) $) NIL (|has| $ (-6 -4625)))) (-2538 (($ $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-1173) $) NIL (|has| (-1173) (-869)))) (-4467 (((-658 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-658 (-57)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119)))) (((-141) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119))))) (-1813 (((-1173) $) NIL (|has| (-1173) (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4626))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-1848 (($ (-414)) 9)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119))))) (-2840 (((-658 (-1173)) $) NIL)) (-2396 (((-141) (-1173) $) NIL)) (-4137 (((-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) $) NIL)) (-2113 (($ (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) $) NIL)) (-3708 (((-658 (-1173)) $) NIL)) (-3780 (((-141) (-1173) $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119))))) (-1918 (((-57) $) NIL (|has| (-1173) (-869)))) (-4050 (((-3 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) "failed") (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL)) (-1892 (($ $ (-57)) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119)))) (($ $ (-310 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119)))) (($ $ (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119)))) (($ $ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119)))) (($ $ (-658 (-57)) (-658 (-57))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-310 (-57))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-658 (-310 (-57)))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119))))) (-4210 (((-658 (-57)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 (((-57) $ (-1173)) 14) (((-57) $ (-1173) (-57)) NIL) (((-57) $ (-1191)) 15)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119)))) (((-790) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119)))) (((-790) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119))))) (-2607 (($ $) NIL)) (-4560 (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 (-57))) (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-647) (-13 (-1202 (-1173) (-57)) (-10 -8 (-15 -1848 ($ (-414))) (-15 -2538 ($ $)) (-15 -3927 ((-57) $ (-1191))) (-15 -3932 ((-57) $ (-1191) (-57))) (-15 -2607 ($ $))))) (T -647)) 
+((-1848 (*1 *1 *2) (-12 (-5 *2 (-414)) (-5 *1 (-647)))) (-2538 (*1 *1 *1) (-5 *1 (-647))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-57)) (-5 *1 (-647)))) (-3932 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-57)) (-5 *3 (-1191)) (-5 *1 (-647)))) (-2607 (*1 *1 *1) (-5 *1 (-647)))) 
+(-13 (-1202 (-1173) (-57)) (-10 -8 (-15 -1848 ($ (-414))) (-15 -2538 ($ $)) (-15 -3927 ((-57) $ (-1191))) (-15 -3932 ((-57) $ (-1191) (-57))) (-15 -2607 ($ $)))) 
+((-3313 (($ $ |#2|) 10))) 
+(((-648 |#1| |#2|) (-10 -8 (-15 -3313 (|#1| |#1| |#2|))) (-649 |#2|) (-194)) (T -648)) 
+NIL 
+(-10 -8 (-15 -3313 (|#1| |#1| |#2|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-4466 (($ $ $) 26)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 25 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
+(((-649 |#1|) (-1311) (-194)) (T -649)) 
+((-4466 (*1 *1 *1 *1) (-12 (-4 *1 (-649 *2)) (-4 *2 (-194)))) (-3313 (*1 *1 *1 *2) (-12 (-4 *1 (-649 *2)) (-4 *2 (-194)) (-4 *2 (-388))))) 
+(-13 (-734 |t#1|) (-10 -8 (-15 -4466 ($ $ $)) (-6 |NullSquare|) (-6 |JacobiIdentity|) (IF (|has| |t#1| (-388)) (-15 -3313 ($ $ |t#1|)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-734 |#1|) . T) ((-1081 |#1|) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4509 (((-3 $ "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4061 (((-1280 (-706 |#1|))) NIL (|has| |#2| (-443 |#1|))) (((-1280 (-706 |#1|)) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-3360 (((-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-3001 (($) NIL T CONST)) (-2604 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-2661 (((-3 $ "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-1951 (((-706 |#1|)) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-4282 ((|#1| $) NIL (|has| |#2| (-392 |#1|)))) (-2302 (((-706 |#1|) $) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) $ (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-2503 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-2120 (((-1187 (-980 |#1|))) NIL (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-388))))) (-2111 (($ $ (-944)) NIL)) (-1431 ((|#1| $) NIL (|has| |#2| (-392 |#1|)))) (-3916 (((-1187 |#1|) $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-1874 ((|#1|) NIL (|has| |#2| (-443 |#1|))) ((|#1| (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-1582 (((-1187 |#1|) $) NIL (|has| |#2| (-392 |#1|)))) (-4194 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-1626 (($ (-1280 |#1|)) NIL (|has| |#2| (-443 |#1|))) (($ (-1280 |#1|) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-3371 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-4175 (((-944)) NIL (|has| |#2| (-392 |#1|)))) (-2169 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-1833 (($ $ (-944)) NIL)) (-3700 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2973 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2467 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-1563 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-3994 (((-3 $ "failed")) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-2794 (((-706 |#1|)) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-1869 ((|#1| $) NIL (|has| |#2| (-392 |#1|)))) (-1802 (((-706 |#1|) $) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) $ (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-4158 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-3004 (((-1187 (-980 |#1|))) NIL (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-388))))) (-2682 (($ $ (-944)) NIL)) (-3061 ((|#1| $) NIL (|has| |#2| (-392 |#1|)))) (-2013 (((-1187 |#1|) $) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-3030 ((|#1|) NIL (|has| |#2| (-443 |#1|))) ((|#1| (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-2397 (((-1187 |#1|) $) NIL (|has| |#2| (-392 |#1|)))) (-3847 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2685 (((-1173) $) NIL)) (-4106 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2339 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2297 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2951 (((-1137) $) NIL)) (-2716 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-3927 ((|#1| $ (-592)) NIL (|has| |#2| (-443 |#1|)))) (-2231 (((-706 |#1|) (-1280 $)) NIL (|has| |#2| (-443 |#1|))) (((-1280 |#1|) $) NIL (|has| |#2| (-443 |#1|))) (((-706 |#1|) (-1280 $) (-1280 $)) NIL (|has| |#2| (-392 |#1|))) (((-1280 |#1|) $ (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-1778 (($ (-1280 |#1|)) NIL (|has| |#2| (-443 |#1|))) (((-1280 |#1|) $) NIL (|has| |#2| (-443 |#1|)))) (-1473 (((-658 (-980 |#1|))) NIL (|has| |#2| (-443 |#1|))) (((-658 (-980 |#1|)) (-1280 $)) NIL (|has| |#2| (-392 |#1|)))) (-2131 (($ $ $) NIL)) (-3545 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-1683 (((-877) $) NIL) ((|#2| $) 12) (($ |#2|) 13)) (-2195 (((-1280 $)) NIL (|has| |#2| (-443 |#1|)))) (-3664 (((-658 (-1280 |#1|))) NIL (-3836 (-12 (|has| |#2| (-392 |#1|)) (|has| |#1| (-582))) (-12 (|has| |#2| (-443 |#1|)) (|has| |#1| (-582)))))) (-3667 (($ $ $ $) NIL)) (-1516 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-4572 (($ (-706 |#1|) $) NIL (|has| |#2| (-443 |#1|)))) (-2844 (($ $ $) NIL)) (-3135 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2723 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-2359 (((-141)) NIL (|has| |#2| (-392 |#1|)))) (-3514 (($) 15 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) 17)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 11) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-650 |#1| |#2|) (-13 (-763 |#1|) (-632 |#2|) (-10 -8 (-15 -1683 ($ |#2|)) (IF (|has| |#2| (-443 |#1|)) (-6 (-443 |#1|)) |noBranch|) (IF (|has| |#2| (-392 |#1|)) (-6 (-392 |#1|)) |noBranch|))) (-194) (-763 |#1|)) (T -650)) 
+((-1683 (*1 *1 *2) (-12 (-4 *3 (-194)) (-5 *1 (-650 *3 *2)) (-4 *2 (-763 *3))))) 
+(-13 (-763 |#1|) (-632 |#2|) (-10 -8 (-15 -1683 ($ |#2|)) (IF (|has| |#2| (-443 |#1|)) (-6 (-443 |#1|)) |noBranch|) (IF (|has| |#2| (-392 |#1|)) (-6 (-392 |#1|)) |noBranch|))) 
+((-2061 (((-3 (-862 |#2|) "failed") |#2| (-310 |#2|) (-1173)) 78) (((-3 (-862 |#2|) (-2 (|:| |leftHandLimit| (-3 (-862 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-862 |#2|) "failed"))) "failed") |#2| (-310 (-862 |#2|))) 100)) (-4131 (((-3 (-855 |#2|) "failed") |#2| (-310 (-855 |#2|))) 105))) 
+(((-651 |#1| |#2|) (-10 -7 (-15 -2061 ((-3 (-862 |#2|) (-2 (|:| |leftHandLimit| (-3 (-862 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-862 |#2|) "failed"))) "failed") |#2| (-310 (-862 |#2|)))) (-15 -4131 ((-3 (-855 |#2|) "failed") |#2| (-310 (-855 |#2|)))) (-15 -2061 ((-3 (-862 |#2|) "failed") |#2| (-310 |#2|) (-1173)))) (-13 (-477) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|))) (T -651)) 
+((-2061 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-310 *3)) (-5 *5 (-1173)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-862 *3)) (-5 *1 (-651 *6 *3)))) (-4131 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-310 (-855 *3))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-855 *3)) (-5 *1 (-651 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) (-2061 (*1 *2 *3 *4) (-12 (-5 *4 (-310 (-862 *3))) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (-862 *3) (-2 (|:| |leftHandLimit| (-3 (-862 *3) "failed")) (|:| |rightHandLimit| (-3 (-862 *3) "failed"))) "failed")) (-5 *1 (-651 *5 *3))))) 
+(-10 -7 (-15 -2061 ((-3 (-862 |#2|) (-2 (|:| |leftHandLimit| (-3 (-862 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-862 |#2|) "failed"))) "failed") |#2| (-310 (-862 |#2|)))) (-15 -4131 ((-3 (-855 |#2|) "failed") |#2| (-310 (-855 |#2|)))) (-15 -2061 ((-3 (-862 |#2|) "failed") |#2| (-310 |#2|) (-1173)))) 
+((-2061 (((-3 (-862 (-433 (-980 |#1|))) "failed") (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))) (-1173)) 79) (((-3 (-862 (-433 (-980 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed"))) "failed") (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|)))) 18) (((-3 (-862 (-433 (-980 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed"))) "failed") (-433 (-980 |#1|)) (-310 (-862 (-980 |#1|)))) 34)) (-4131 (((-855 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|)))) 21) (((-855 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-310 (-855 (-980 |#1|)))) 42))) 
+(((-652 |#1|) (-10 -7 (-15 -2061 ((-3 (-862 (-433 (-980 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed"))) "failed") (-433 (-980 |#1|)) (-310 (-862 (-980 |#1|))))) (-15 -2061 ((-3 (-862 (-433 (-980 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed"))) "failed") (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))))) (-15 -4131 ((-855 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-310 (-855 (-980 |#1|))))) (-15 -4131 ((-855 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))))) (-15 -2061 ((-3 (-862 (-433 (-980 |#1|))) "failed") (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))) (-1173)))) (-477)) (T -652)) 
+((-2061 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-310 (-433 (-980 *6)))) (-5 *5 (-1173)) (-5 *3 (-433 (-980 *6))) (-4 *6 (-477)) (-5 *2 (-862 *3)) (-5 *1 (-652 *6)))) (-4131 (*1 *2 *3 *4) (-12 (-5 *4 (-310 (-433 (-980 *5)))) (-5 *3 (-433 (-980 *5))) (-4 *5 (-477)) (-5 *2 (-855 *3)) (-5 *1 (-652 *5)))) (-4131 (*1 *2 *3 *4) (-12 (-5 *4 (-310 (-855 (-980 *5)))) (-4 *5 (-477)) (-5 *2 (-855 (-433 (-980 *5)))) (-5 *1 (-652 *5)) (-5 *3 (-433 (-980 *5))))) (-2061 (*1 *2 *3 *4) (-12 (-5 *4 (-310 (-433 (-980 *5)))) (-5 *3 (-433 (-980 *5))) (-4 *5 (-477)) (-5 *2 (-3 (-862 *3) (-2 (|:| |leftHandLimit| (-3 (-862 *3) "failed")) (|:| |rightHandLimit| (-3 (-862 *3) "failed"))) "failed")) (-5 *1 (-652 *5)))) (-2061 (*1 *2 *3 *4) (-12 (-5 *4 (-310 (-862 (-980 *5)))) (-4 *5 (-477)) (-5 *2 (-3 (-862 (-433 (-980 *5))) (-2 (|:| |leftHandLimit| (-3 (-862 (-433 (-980 *5))) "failed")) (|:| |rightHandLimit| (-3 (-862 (-433 (-980 *5))) "failed"))) "failed")) (-5 *1 (-652 *5)) (-5 *3 (-433 (-980 *5)))))) 
+(-10 -7 (-15 -2061 ((-3 (-862 (-433 (-980 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed"))) "failed") (-433 (-980 |#1|)) (-310 (-862 (-980 |#1|))))) (-15 -2061 ((-3 (-862 (-433 (-980 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-862 (-433 (-980 |#1|))) "failed"))) "failed") (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))))) (-15 -4131 ((-855 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-310 (-855 (-980 |#1|))))) (-15 -4131 ((-855 (-433 (-980 |#1|))) (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))))) (-15 -2061 ((-3 (-862 (-433 (-980 |#1|))) "failed") (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))) (-1173)))) 
+((-2811 (((-3 (-1280 (-433 |#1|)) "failed") (-1280 |#2|) |#2|) 57 (-3252 (|has| |#1| (-388)))) (((-3 (-1280 |#1|) "failed") (-1280 |#2|) |#2|) 42 (|has| |#1| (-388)))) (-2428 (((-141) (-1280 |#2|)) 30)) (-3422 (((-3 (-1280 |#1|) "failed") (-1280 |#2|)) 33))) 
+(((-653 |#1| |#2|) (-10 -7 (-15 -2428 ((-141) (-1280 |#2|))) (-15 -3422 ((-3 (-1280 |#1|) "failed") (-1280 |#2|))) (IF (|has| |#1| (-388)) (-15 -2811 ((-3 (-1280 |#1|) "failed") (-1280 |#2|) |#2|)) (-15 -2811 ((-3 (-1280 (-433 |#1|)) "failed") (-1280 |#2|) |#2|)))) (-582) (-654 |#1|)) (T -653)) 
+((-2811 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1280 *4)) (-4 *4 (-654 *5)) (-3252 (-4 *5 (-388))) (-4 *5 (-582)) (-5 *2 (-1280 (-433 *5))) (-5 *1 (-653 *5 *4)))) (-2811 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1280 *4)) (-4 *4 (-654 *5)) (-4 *5 (-388)) (-4 *5 (-582)) (-5 *2 (-1280 *5)) (-5 *1 (-653 *5 *4)))) (-3422 (*1 *2 *3) (|partial| -12 (-5 *3 (-1280 *5)) (-4 *5 (-654 *4)) (-4 *4 (-582)) (-5 *2 (-1280 *4)) (-5 *1 (-653 *4 *5)))) (-2428 (*1 *2 *3) (-12 (-5 *3 (-1280 *5)) (-4 *5 (-654 *4)) (-4 *4 (-582)) (-5 *2 (-141)) (-5 *1 (-653 *4 *5))))) 
+(-10 -7 (-15 -2428 ((-141) (-1280 |#2|))) (-15 -3422 ((-3 (-1280 |#1|) "failed") (-1280 |#2|))) (IF (|has| |#1| (-388)) (-15 -2811 ((-3 (-1280 |#1|) "failed") (-1280 |#2|) |#2|)) (-15 -2811 ((-3 (-1280 (-433 |#1|)) "failed") (-1280 |#2|) |#2|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3945 (((-706 |#1|) (-706 $)) 35) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 34)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-654 |#1|) (-1311) (-1075)) (T -654)) 
+((-3945 (*1 *2 *3) (-12 (-5 *3 (-706 *1)) (-4 *1 (-654 *4)) (-4 *4 (-1075)) (-5 *2 (-706 *4)))) (-3945 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *1)) (-5 *4 (-1280 *1)) (-4 *1 (-654 *5)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -3253 (-706 *5)) (|:| |vec| (-1280 *5))))))) 
+(-13 (-1075) (-10 -8 (-15 -3945 ((-706 |t#1|) (-706 $))) (-15 -3945 ((-2 (|:| -3253 (-706 |t#1|)) (|:| |vec| (-1280 |t#1|))) (-706 $) (-1280 $))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1600 ((|#2| (-658 |#1|) (-658 |#2|) |#1| (-1 |#2| |#1|)) 18) (((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|) (-1 |#2| |#1|)) 19) ((|#2| (-658 |#1|) (-658 |#2|) |#1| |#2|) 16) (((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|) |#2|) 17) ((|#2| (-658 |#1|) (-658 |#2|) |#1|) 10) (((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|)) 12))) 
+(((-655 |#1| |#2|) (-10 -7 (-15 -1600 ((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|))) (-15 -1600 (|#2| (-658 |#1|) (-658 |#2|) |#1|)) (-15 -1600 ((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|) |#2|)) (-15 -1600 (|#2| (-658 |#1|) (-658 |#2|) |#1| |#2|)) (-15 -1600 ((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|) (-1 |#2| |#1|))) (-15 -1600 (|#2| (-658 |#1|) (-658 |#2|) |#1| (-1 |#2| |#1|)))) (-1119) (-1225)) (T -655)) 
+((-1600 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 *2)) (-5 *6 (-1 *2 *5)) (-4 *5 (-1119)) (-4 *2 (-1225)) (-5 *1 (-655 *5 *2)))) (-1600 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-1 *6 *5)) (-5 *3 (-658 *5)) (-5 *4 (-658 *6)) (-4 *5 (-1119)) (-4 *6 (-1225)) (-5 *1 (-655 *5 *6)))) (-1600 (*1 *2 *3 *4 *5 *2) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 *2)) (-4 *5 (-1119)) (-4 *2 (-1225)) (-5 *1 (-655 *5 *2)))) (-1600 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *6)) (-5 *4 (-658 *5)) (-4 *6 (-1119)) (-4 *5 (-1225)) (-5 *2 (-1 *5 *6)) (-5 *1 (-655 *6 *5)))) (-1600 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 *2)) (-4 *5 (-1119)) (-4 *2 (-1225)) (-5 *1 (-655 *5 *2)))) (-1600 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 *6)) (-4 *5 (-1119)) (-4 *6 (-1225)) (-5 *2 (-1 *6 *5)) (-5 *1 (-655 *5 *6))))) 
+(-10 -7 (-15 -1600 ((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|))) (-15 -1600 (|#2| (-658 |#1|) (-658 |#2|) |#1|)) (-15 -1600 ((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|) |#2|)) (-15 -1600 (|#2| (-658 |#1|) (-658 |#2|) |#1| |#2|)) (-15 -1600 ((-1 |#2| |#1|) (-658 |#1|) (-658 |#2|) (-1 |#2| |#1|))) (-15 -1600 (|#2| (-658 |#1|) (-658 |#2|) |#1| (-1 |#2| |#1|)))) 
+((-1779 (((-658 |#2|) (-1 |#2| |#1| |#2|) (-658 |#1|) |#2|) 16)) (-3657 ((|#2| (-1 |#2| |#1| |#2|) (-658 |#1|) |#2|) 18)) (-2731 (((-658 |#2|) (-1 |#2| |#1|) (-658 |#1|)) 13))) 
+(((-656 |#1| |#2|) (-10 -7 (-15 -1779 ((-658 |#2|) (-1 |#2| |#1| |#2|) (-658 |#1|) |#2|)) (-15 -3657 (|#2| (-1 |#2| |#1| |#2|) (-658 |#1|) |#2|)) (-15 -2731 ((-658 |#2|) (-1 |#2| |#1|) (-658 |#1|)))) (-1225) (-1225)) (T -656)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-658 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-658 *6)) (-5 *1 (-656 *5 *6)))) (-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-658 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-656 *5 *2)))) (-1779 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-658 *6)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-5 *2 (-658 *5)) (-5 *1 (-656 *6 *5))))) 
+(-10 -7 (-15 -1779 ((-658 |#2|) (-1 |#2| |#1| |#2|) (-658 |#1|) |#2|)) (-15 -3657 (|#2| (-1 |#2| |#1| |#2|) (-658 |#1|) |#2|)) (-15 -2731 ((-658 |#2|) (-1 |#2| |#1|) (-658 |#1|)))) 
+((-2731 (((-658 |#3|) (-1 |#3| |#1| |#2|) (-658 |#1|) (-658 |#2|)) 13))) 
+(((-657 |#1| |#2| |#3|) (-10 -7 (-15 -2731 ((-658 |#3|) (-1 |#3| |#1| |#2|) (-658 |#1|) (-658 |#2|)))) (-1225) (-1225) (-1225)) (T -657)) 
+((-2731 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-658 *6)) (-5 *5 (-658 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-658 *8)) (-5 *1 (-657 *6 *7 *8))))) 
+(-10 -7 (-15 -2731 ((-658 |#3|) (-1 |#3| |#1| |#2|) (-658 |#1|) (-658 |#2|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) NIL)) (-1915 ((|#1| $) NIL)) (-3188 (($ $) NIL)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) $) NIL (|has| |#1| (-869))) (((-141) (-1 (-141) |#1| |#1|) $) NIL)) (-2831 (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869)))) (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-3960 (($ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-3153 (($ $ $) NIL (|has| $ (-6 -4626)))) (-4496 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-2101 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ "first" |#1|) NIL (|has| $ (-6 -4626))) (($ $ "rest" $) NIL (|has| $ (-6 -4626))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-1397 (($ $ $) 31 (|has| |#1| (-1119)))) (-1385 (($ $ $) 33 (|has| |#1| (-1119)))) (-1379 (($ $ $) 36 (|has| |#1| (-1119)))) (-4125 (($ (-1 (-141) |#1|) $) NIL)) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-1765 ((|#1| $) NIL)) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1366 (($ $) NIL) (($ $ (-790)) NIL)) (-1461 (($ $) NIL (|has| |#1| (-1119)))) (-1360 (($ $) 30 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4065 (($ |#1| $) NIL (|has| |#1| (-1119))) (($ (-1 (-141) |#1|) $) NIL)) (-4459 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-3868 (((-141) $) NIL)) (-1721 (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119))) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) (-1 (-141) |#1|) $) NIL)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3258 (((-141) $) 9)) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2623 (($) 7)) (-3242 (($ (-790) |#1|) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-2713 (($ $ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) NIL)) (-4491 (($ $ $) NIL (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 32 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1333 (($ |#1|) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4255 ((|#1| $) NIL) (($ $ (-790)) NIL)) (-2113 (($ $ $ (-592)) NIL) (($ |#1| $ (-592)) NIL)) (-3666 (($ $ $ (-592)) NIL) (($ |#1| $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) NIL) (($ $ (-790)) NIL)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-2955 (((-141) $) NIL)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1246 (-592))) NIL) ((|#1| $ (-592)) 35) ((|#1| $ (-592) |#1|) NIL)) (-2920 (((-592) $ $) NIL)) (-4113 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-3208 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-3228 (((-141) $) NIL)) (-2399 (($ $) NIL)) (-1337 (($ $) NIL (|has| $ (-6 -4626)))) (-3318 (((-790) $) NIL)) (-3184 (($ $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) 44 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-4592 (($ |#1| $) 10)) (-3619 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2266 (($ $ $) 29) (($ |#1| $) NIL) (($ (-658 $)) NIL) (($ $ |#1|) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1318 (($ $ $) 11)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-1637 (((-1173) $) 25 (|has| |#1| (-850))) (((-1173) $ (-141)) 26 (|has| |#1| (-850))) (((-1285) (-844) $) 27 (|has| |#1| (-850))) (((-1285) (-844) $ (-141)) 28 (|has| |#1| (-850)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-658 |#1|) (-13 (-683 |#1|) (-10 -8 (-15 -2623 ($)) (-15 -3258 ((-141) $)) (-15 -4592 ($ |#1| $)) (-15 -1318 ($ $ $)) (IF (|has| |#1| (-1119)) (PROGN (-15 -1397 ($ $ $)) (-15 -1385 ($ $ $)) (-15 -1379 ($ $ $))) |noBranch|) (IF (|has| |#1| (-850)) (-6 (-850)) |noBranch|))) (-1225)) (T -658)) 
+((-2623 (*1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1225)))) (-3258 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-658 *3)) (-4 *3 (-1225)))) (-4592 (*1 *1 *2 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1225)))) (-1318 (*1 *1 *1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1225)))) (-1397 (*1 *1 *1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1119)) (-4 *2 (-1225)))) (-1385 (*1 *1 *1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1119)) (-4 *2 (-1225)))) (-1379 (*1 *1 *1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1119)) (-4 *2 (-1225))))) 
+(-13 (-683 |#1|) (-10 -8 (-15 -2623 ($)) (-15 -3258 ((-141) $)) (-15 -4592 ($ |#1| $)) (-15 -1318 ($ $ $)) (IF (|has| |#1| (-1119)) (PROGN (-15 -1397 ($ $ $)) (-15 -1385 ($ $ $)) (-15 -1379 ($ $ $))) |noBranch|) (IF (|has| |#1| (-850)) (-6 (-850)) |noBranch|))) 
+((-2923 (((-658 |#1|) |#2| (-592)) 21)) (-2985 (((-706 |#1|) (-658 |#2|) (-592)) 30)) (-1797 (((-706 |#1|) (-658 |#2|) (-592)) 28))) 
+(((-659 |#1| |#2|) (-10 -7 (-15 -2985 ((-706 |#1|) (-658 |#2|) (-592))) (-15 -1797 ((-706 |#1|) (-658 |#2|) (-592))) (-15 -2923 ((-658 |#1|) |#2| (-592)))) (-388) (-665 |#1|)) (T -659)) 
+((-2923 (*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-388)) (-5 *2 (-658 *5)) (-5 *1 (-659 *5 *3)) (-4 *3 (-665 *5)))) (-1797 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-592)) (-4 *6 (-665 *5)) (-4 *5 (-388)) (-5 *2 (-706 *5)) (-5 *1 (-659 *5 *6)))) (-2985 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-592)) (-4 *6 (-665 *5)) (-4 *5 (-388)) (-5 *2 (-706 *5)) (-5 *1 (-659 *5 *6))))) 
+(-10 -7 (-15 -2985 ((-706 |#1|) (-658 |#2|) (-592))) (-15 -1797 ((-706 |#1|) (-658 |#2|) (-592))) (-15 -2923 ((-658 |#1|) |#2| (-592)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1410 (($ |#1| |#1| $) 43)) (-2126 (((-141) $ (-790)) NIL)) (-4125 (($ (-1 (-141) |#1|) $) 56 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-1461 (($ $) 45)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4065 (($ |#1| $) 51 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) 53 (|has| $ (-6 -4625)))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-4004 (((-658 |#1|) $) 9 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) 39 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 37)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4137 ((|#1| $) 46)) (-2113 (($ |#1| $) 26) (($ |#1| $ (-790)) 42)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-2106 ((|#1| $) 48)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 21)) (-2890 (($) 25)) (-2284 (((-141) $) 49)) (-2043 (((-658 (-2 (|:| -3552 |#1|) (|:| -3452 (-790)))) $) 60)) (-1653 (($) 23) (($ (-658 |#1|)) 18)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) 57 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) 19)) (-1778 (((-565) $) 34 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-1683 (((-877) $) 14 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 22)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 62 (|has| |#1| (-1119)))) (-1699 (((-790) $) 16 (|has| $ (-6 -4625))))) 
+(((-660 |#1|) (-13 (-711 |#1|) (-10 -8 (-6 -4625) (-15 -2284 ((-141) $)) (-15 -1410 ($ |#1| |#1| $)))) (-1119)) (T -660)) 
+((-2284 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-660 *3)) (-4 *3 (-1119)))) (-1410 (*1 *1 *2 *2 *1) (-12 (-5 *1 (-660 *2)) (-4 *2 (-1119))))) 
+(-13 (-711 |#1|) (-10 -8 (-6 -4625) (-15 -2284 ((-141) $)) (-15 -1410 ($ |#1| |#1| $)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ |#1| $) 22))) 
+(((-661 |#1|) (-1311) (-1082)) (T -661)) 
+((* (*1 *1 *2 *1) (-12 (-4 *1 (-661 *2)) (-4 *2 (-1082))))) 
 (-13 (-21) (-10 -8 (-15 * ($ |t#1| $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1685 (((-769) $) 15)) (-3636 (($ $ |#1|) 55)) (-2985 (($ $) 32)) (-1656 (($ $) 31)) (-3376 (((-3 |#1| "failed") $) 47)) (-1318 ((|#1| $) NIL)) (-2515 (($ |#1| |#2| $) 60) (($ $ $) 61)) (-2147 (((-856) $ (-1 (-856) (-856) (-856)) (-1 (-856) (-856) (-856)) (-572)) 45)) (-4351 ((|#1| $ (-572)) 30)) (-1606 ((|#2| $ (-572)) 29)) (-3629 (($ (-1 |#1| |#1|) $) 34)) (-1538 (($ (-1 |#2| |#2|) $) 38)) (-4072 (($) 10)) (-3802 (($ |#1| |#2|) 22)) (-3726 (($ (-638 (-2 (|:| |gen| |#1|) (|:| -4179 |#2|)))) 23)) (-2275 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 |#2|))) $) 13)) (-2522 (($ |#1| $) 56)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2064 (((-121) $ $) 58)) (-3972 (((-856) $) 19) (($ |#1|) 16)) (-1324 (((-121) $ $) 25))) 
-(((-642 |#1| |#2| |#3|) (-13 (-1098) (-1044 |#1|) (-10 -8 (-15 -2147 ((-856) $ (-1 (-856) (-856) (-856)) (-1 (-856) (-856) (-856)) (-572))) (-15 -2275 ((-638 (-2 (|:| |gen| |#1|) (|:| -4179 |#2|))) $)) (-15 -3802 ($ |#1| |#2|)) (-15 -3726 ($ (-638 (-2 (|:| |gen| |#1|) (|:| -4179 |#2|))))) (-15 -1606 (|#2| $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -1656 ($ $)) (-15 -2985 ($ $)) (-15 -1685 ((-769) $)) (-15 -4072 ($)) (-15 -3636 ($ $ |#1|)) (-15 -2522 ($ |#1| $)) (-15 -2515 ($ |#1| |#2| $)) (-15 -2515 ($ $ $)) (-15 -2064 ((-121) $ $)) (-15 -1538 ($ (-1 |#2| |#2|) $)) (-15 -3629 ($ (-1 |#1| |#1|) $)))) (-1098) (-23) |#2|) (T -642)) 
-((-2147 (*1 *2 *1 *3 *3 *4) (-12 (-5 *3 (-1 (-856) (-856) (-856))) (-5 *4 (-572)) (-5 *2 (-856)) (-5 *1 (-642 *5 *6 *7)) (-4 *5 (-1098)) (-4 *6 (-23)) (-14 *7 *6))) (-2275 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 *4)))) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-1098)) (-4 *4 (-23)) (-14 *5 *4))) (-3802 (*1 *1 *2 *3) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) (-3726 (*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 *4)))) (-4 *3 (-1098)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-642 *3 *4 *5)))) (-1606 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *2 (-23)) (-5 *1 (-642 *4 *2 *5)) (-4 *4 (-1098)) (-14 *5 *2))) (-4351 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *2 (-1098)) (-5 *1 (-642 *2 *4 *5)) (-4 *4 (-23)) (-14 *5 *4))) (-1656 (*1 *1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) (-2985 (*1 *1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) (-1685 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-1098)) (-4 *4 (-23)) (-14 *5 *4))) (-4072 (*1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) (-3636 (*1 *1 *1 *2) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) (-2522 (*1 *1 *2 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) (-2515 (*1 *1 *2 *3 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) (-2515 (*1 *1 *1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) (-2064 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-1098)) (-4 *4 (-23)) (-14 *5 *4))) (-1538 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-1098)))) (-3629 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-642 *3 *4 *5)) (-4 *4 (-23)) (-14 *5 *4)))) 
-(-13 (-1098) (-1044 |#1|) (-10 -8 (-15 -2147 ((-856) $ (-1 (-856) (-856) (-856)) (-1 (-856) (-856) (-856)) (-572))) (-15 -2275 ((-638 (-2 (|:| |gen| |#1|) (|:| -4179 |#2|))) $)) (-15 -3802 ($ |#1| |#2|)) (-15 -3726 ($ (-638 (-2 (|:| |gen| |#1|) (|:| -4179 |#2|))))) (-15 -1606 (|#2| $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -1656 ($ $)) (-15 -2985 ($ $)) (-15 -1685 ((-769) $)) (-15 -4072 ($)) (-15 -3636 ($ $ |#1|)) (-15 -2522 ($ |#1| $)) (-15 -2515 ($ |#1| |#2| $)) (-15 -2515 ($ $ $)) (-15 -2064 ((-121) $ $)) (-15 -1538 ($ (-1 |#2| |#2|) $)) (-15 -3629 ($ (-1 |#1| |#1|) $)))) 
-((-2026 (((-572) $) 23)) (-2603 (($ |#2| $ (-572)) 21) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) 12)) (-1601 (((-121) (-572) $) 14)) (-4500 (($ $ |#2|) 18) (($ |#2| $) 19) (($ $ $) NIL) (($ (-638 $)) NIL))) 
-(((-643 |#1| |#2|) (-10 -8 (-15 -2603 (|#1| |#1| |#1| (-572))) (-15 -2603 (|#1| |#2| |#1| (-572))) (-15 -4500 (|#1| (-638 |#1|))) (-15 -4500 (|#1| |#1| |#1|)) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#2|)) (-15 -2026 ((-572) |#1|)) (-15 -2739 ((-638 (-572)) |#1|)) (-15 -1601 ((-121) (-572) |#1|))) (-644 |#2|) (-1204)) (T -643)) 
-NIL 
-(-10 -8 (-15 -2603 (|#1| |#1| |#1| (-572))) (-15 -2603 (|#1| |#2| |#1| (-572))) (-15 -4500 (|#1| (-638 |#1|))) (-15 -4500 (|#1| |#1| |#1|)) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#2|)) (-15 -2026 ((-572) |#1|)) (-15 -2739 ((-638 (-572)) |#1|)) (-15 -1601 ((-121) (-572) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#1| $ (-572) |#1|) 49 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 53 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-1643 (($ $) 73 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#1| $) 72 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) 50 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 48)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-1364 (($ (-769) |#1|) 64)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) 55) (($ $ $ (-572)) 54)) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 39 (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3299 (($ $ |#1|) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ (-572) |#1|) 47) ((|#1| $ (-572)) 46) (($ $ (-1225 (-572))) 58)) (-1940 (($ $ (-572)) 57) (($ $ (-1225 (-572))) 56)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 74 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 65)) (-4500 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-638 $)) 60)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-644 |#1|) (-1290) (-1204)) (T -644)) 
-((-1364 (*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) (-4500 (*1 *1 *1 *2) (-12 (-4 *1 (-644 *2)) (-4 *2 (-1204)))) (-4500 (*1 *1 *2 *1) (-12 (-4 *1 (-644 *2)) (-4 *2 (-1204)))) (-4500 (*1 *1 *1 *1) (-12 (-4 *1 (-644 *2)) (-4 *2 (-1204)))) (-4500 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) (-3828 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 (-1225 (-572))) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) (-1940 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) (-1940 (*1 *1 *1 *2) (-12 (-5 *2 (-1225 (-572))) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) (-2603 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-644 *2)) (-4 *2 (-1204)))) (-2603 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) (-3283 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-1225 (-572))) (|has| *1 (-6 -4603)) (-4 *1 (-644 *2)) (-4 *2 (-1204))))) 
-(-13 (-605 (-572) |t#1|) (-155 |t#1|) (-10 -8 (-15 -1364 ($ (-769) |t#1|)) (-15 -4500 ($ $ |t#1|)) (-15 -4500 ($ |t#1| $)) (-15 -4500 ($ $ $)) (-15 -4500 ($ (-638 $))) (-15 -3828 ($ (-1 |t#1| |t#1| |t#1|) $ $)) (-15 -3277 ($ $ (-1225 (-572)))) (-15 -1940 ($ $ (-572))) (-15 -1940 ($ $ (-1225 (-572)))) (-15 -2603 ($ |t#1| $ (-572))) (-15 -2603 ($ $ $ (-572))) (IF (|has| $ (-6 -4603)) (-15 -3283 (|t#1| $ (-1225 (-572)) |t#1|)) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 (-1082)) $) 115)) (-3342 (((-1170) $) 120)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-2525 (($ $ (-572) (-572)) 126) (($ $ (-572)) 125)) (-2640 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) 118)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-3351 (($ $ (-572)) 86)) (-4521 (($ (-572) |#1| $) 87)) (-2085 (($ $ $) 92)) (-2211 (($) 16 T CONST)) (-3729 (($ (-572) $) 89) (($ $) 88)) (-3185 (($ $) 93)) (-2190 (($ $ $) 53)) (-4383 (($ $) 108)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-2936 (((-121) (-121)) 83) (((-121)) 82)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-1526 (((-121) $) 69)) (-3591 (($ $) 95)) (-1347 (((-121) $) 116)) (-2306 (((-3 (-572) "failed") $) 94)) (-3377 (((-572) $ (-572)) 124) (((-572) $) 123) (((-572) $) 99)) (-3893 (((-121) $) 30)) (-3965 (($ $ (-923)) 122)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-4581 (((-121) $) 106)) (-4195 (($ (-638 $) (-638 (-769)) (-572)) 90)) (-4328 (($ $ (-638 (-1082)) (-638 (-572))) 114) (($ $ (-1082) (-572)) 113) (($ |#1| (-572)) 107)) (-3828 (($ (-1 |#1| |#1|) $) 105)) (-4368 (($ $) 103)) (-4373 ((|#1| $) 102)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-2906 ((|#1| $ (-572)) 98)) (-1295 (($ $ (-572)) 85)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1977 (($ $ (-572)) 128)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4485 (((-1150 |#1|) $ |#1|) 129 (|has| |#1| (-15 ** (|#1| |#1| (-572)))))) (-4029 (((-769) $) 56)) (-3277 (($ $ $) 142 (|has| (-572) (-1110))) ((|#1| $ (-572)) 119)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3139 (($ $) 141 (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $ (-769)) 139 (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $ (-1170)) 137 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170))) 136 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-1170) (-769)) 135 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) 134 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))))) (-4216 (($ (-1 $)) 91)) (-4316 (((-572) $) 104)) (-2424 (($ $) 117)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ |#1|) 112 (|has| |#1| (-174))) (($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) 97) (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) 96)) (-1958 ((|#1| $ (-572)) 109)) (-2224 ((|#1| $) 84)) (-2779 (((-3 $ "failed") $) 111 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-1694 ((|#1| $) 121)) (-3774 (((-121) $ $) 38)) (-3410 ((|#1| $ (-572)) 127 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-572)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $) 140 (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $ (-769)) 138 (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $ (-1170)) 133 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170))) 132 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-1170) (-769)) 131 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) 130 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62) (($ $ |#1|) 110 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64) (($ |#1| $) 101) (($ $ |#1|) 100))) 
-(((-645 |#1|) (-1290) (-368)) (T -645)) 
-((-3377 (*1 *2 *1) (-12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-572)))) (-3377 (*1 *2 *1) (-12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-572)))) (-2906 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-645 *2)) (-4 *2 (-368)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))) (-4 *3 (-368)) (-4 *1 (-645 *3)))) (-3972 (*1 *2 *1) (-12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))))) (-3591 (*1 *1 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368)))) (-2306 (*1 *2 *1) (|partial| -12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-572)))) (-3185 (*1 *1 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368)))) (-2085 (*1 *1 *1 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368)))) (-4216 (*1 *1 *2) (-12 (-5 *2 (-1 *1)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) (-4195 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-638 *1)) (-5 *3 (-638 (-769))) (-5 *4 (-572)) (-4 *1 (-645 *5)) (-4 *5 (-368)))) (-3729 (*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) (-3729 (*1 *1 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368)))) (-4521 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-572)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) (-3351 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) (-1295 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) (-2224 (*1 *2 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368)))) (-2936 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) (-2936 (*1 *2) (-12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-121))))) 
-(-13 (-368) (-1236 |t#1| (-572)) (-10 -8 (-15 -3377 ((-572) $)) (-15 -2906 (|t#1| $ (-572))) (-15 -3972 ($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |t#1|))))) (-15 -3972 ((-1150 (-2 (|:| |k| (-572)) (|:| |c| |t#1|))) $)) (-15 -3591 ($ $)) (-15 -2306 ((-3 (-572) "failed") $)) (-15 -3185 ($ $)) (-15 -2085 ($ $ $)) (-15 -4216 ($ (-1 $))) (-15 -4195 ($ (-638 $) (-638 (-769)) (-572))) (-15 -3729 ($ (-572) $)) (-15 -3729 ($ $)) (-15 -4521 ($ (-572) |t#1| $)) (-15 -3351 ($ $ (-572))) (-15 -1295 ($ $ (-572))) (-15 -2224 (|t#1| $)) (-15 -2936 ((-121) (-121))) (-15 -2936 ((-121))))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-572)) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) . T) ((-227) |has| |#1| (-15 * (|#1| (-572) |#1|))) ((-240) . T) ((-283 $ $) |has| (-572) (-1110)) ((-287) . T) ((-303) . T) ((-368) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) . T) ((-722) . T) ((-901 (-1170)) -12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))) ((-981 |#1| (-572) (-1082)) . T) ((-922) . T) ((-1060 (-413 (-572))) . T) ((-1060 |#1|) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T) ((-1236 |#1| (-572)) . T)) 
-((-2800 (((-3 |#2| "failed") |#3| |#2| (-1170) |#2| (-638 |#2|)) 159) (((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) "failed") |#3| |#2| (-1170)) 43))) 
-(((-646 |#1| |#2| |#3|) (-10 -7 (-15 -2800 ((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) "failed") |#3| |#2| (-1170))) (-15 -2800 ((-3 |#2| "failed") |#3| |#2| (-1170) |#2| (-638 |#2|)))) (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151)) (-13 (-29 |#1|) (-1190) (-966)) (-650 |#2|)) (T -646)) 
-((-2800 (*1 *2 *3 *2 *4 *2 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-646 *6 *2 *3)) (-4 *3 (-650 *2)))) (-2800 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1170)) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-4 *4 (-13 (-29 *6) (-1190) (-966))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2237 (-638 *4)))) (-5 *1 (-646 *6 *4 *3)) (-4 *3 (-650 *4))))) 
-(-10 -7 (-15 -2800 ((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) "failed") |#3| |#2| (-1170))) (-15 -2800 ((-3 |#2| "failed") |#3| |#2| (-1170) |#2| (-638 |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3646 (($ $) NIL (|has| |#1| (-368)))) (-1701 (($ $ $) NIL (|has| |#1| (-368)))) (-1551 (($ $ (-769)) NIL (|has| |#1| (-368)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1887 (($ $ $) NIL (|has| |#1| (-368)))) (-3467 (($ $ $) NIL (|has| |#1| (-368)))) (-2349 (($ $ $) NIL (|has| |#1| (-368)))) (-3296 (($ $ $) NIL (|has| |#1| (-368)))) (-2366 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-4549 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-4046 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457)))) (-3893 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) NIL)) (-4441 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-2196 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-1784 (((-769) $) NIL)) (-3197 (($ $ $) NIL (|has| |#1| (-368)))) (-3874 (($ $ $) NIL (|has| |#1| (-368)))) (-4008 (($ $ $) NIL (|has| |#1| (-368)))) (-3373 (($ $ $) NIL (|has| |#1| (-368)))) (-2123 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-2955 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-3230 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562)))) (-3277 ((|#1| $ |#1|) NIL)) (-2545 (($ $ $) NIL (|has| |#1| (-368)))) (-4316 (((-769) $) NIL)) (-3694 ((|#1| $) NIL (|has| |#1| (-457)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) NIL)) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) NIL)) (-2140 (((-769)) NIL)) (-1591 ((|#1| $ |#1| |#1|) NIL)) (-2527 (($ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($) NIL)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-647 |#1|) (-650 |#1|) (-227)) (T -647)) 
-NIL 
-(-650 |#1|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3646 (($ $) NIL (|has| |#1| (-368)))) (-1701 (($ $ $) NIL (|has| |#1| (-368)))) (-1551 (($ $ (-769)) NIL (|has| |#1| (-368)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1887 (($ $ $) NIL (|has| |#1| (-368)))) (-3467 (($ $ $) NIL (|has| |#1| (-368)))) (-2349 (($ $ $) NIL (|has| |#1| (-368)))) (-3296 (($ $ $) NIL (|has| |#1| (-368)))) (-2366 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-4549 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-4046 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457)))) (-3893 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) NIL)) (-4441 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-2196 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-1784 (((-769) $) NIL)) (-3197 (($ $ $) NIL (|has| |#1| (-368)))) (-3874 (($ $ $) NIL (|has| |#1| (-368)))) (-4008 (($ $ $) NIL (|has| |#1| (-368)))) (-3373 (($ $ $) NIL (|has| |#1| (-368)))) (-2123 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-2955 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-3230 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562)))) (-3277 ((|#1| $ |#1|) NIL) ((|#2| $ |#2|) 13)) (-2545 (($ $ $) NIL (|has| |#1| (-368)))) (-4316 (((-769) $) NIL)) (-3694 ((|#1| $) NIL (|has| |#1| (-457)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) NIL)) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) NIL)) (-2140 (((-769)) NIL)) (-1591 ((|#1| $ |#1| |#1|) NIL)) (-2527 (($ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($) NIL)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-648 |#1| |#2|) (-13 (-650 |#1|) (-283 |#2| |#2|)) (-227) (-13 (-641 |#1|) (-10 -8 (-15 -3139 ($ $))))) (T -648)) 
-NIL 
-(-13 (-650 |#1|) (-283 |#2| |#2|)) 
-((-3646 (($ $) 26)) (-2527 (($ $) 24)) (-1557 (($) 12))) 
-(((-649 |#1| |#2|) (-10 -8 (-15 -3646 (|#1| |#1|)) (-15 -2527 (|#1| |#1|)) (-15 -1557 (|#1|))) (-650 |#2|) (-1054)) (T -649)) 
-NIL 
-(-10 -8 (-15 -3646 (|#1| |#1|)) (-15 -2527 (|#1| |#1|)) (-15 -1557 (|#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3646 (($ $) 79 (|has| |#1| (-368)))) (-1701 (($ $ $) 81 (|has| |#1| (-368)))) (-1551 (($ $ (-769)) 80 (|has| |#1| (-368)))) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1887 (($ $ $) 44 (|has| |#1| (-368)))) (-3467 (($ $ $) 45 (|has| |#1| (-368)))) (-2349 (($ $ $) 47 (|has| |#1| (-368)))) (-3296 (($ $ $) 42 (|has| |#1| (-368)))) (-2366 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 41 (|has| |#1| (-368)))) (-4549 (((-3 $ "failed") $ $) 43 (|has| |#1| (-368)))) (-4046 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 46 (|has| |#1| (-368)))) (-3376 (((-3 (-572) "failed") $) 73 (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 71 (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 68)) (-1318 (((-572) $) 74 (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) 72 (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 67)) (-4383 (($ $) 63)) (-1799 (((-3 $ "failed") $) 33)) (-3988 (($ $) 54 (|has| |#1| (-457)))) (-3893 (((-121) $) 30)) (-4328 (($ |#1| (-769)) 61)) (-4441 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 56 (|has| |#1| (-562)))) (-2196 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 57 (|has| |#1| (-562)))) (-1784 (((-769) $) 65)) (-3197 (($ $ $) 51 (|has| |#1| (-368)))) (-3874 (($ $ $) 52 (|has| |#1| (-368)))) (-4008 (($ $ $) 40 (|has| |#1| (-368)))) (-3373 (($ $ $) 49 (|has| |#1| (-368)))) (-2123 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 48 (|has| |#1| (-368)))) (-2955 (((-3 $ "failed") $ $) 50 (|has| |#1| (-368)))) (-3230 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 53 (|has| |#1| (-368)))) (-4373 ((|#1| $) 64)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ |#1|) 58 (|has| |#1| (-562)))) (-3277 ((|#1| $ |#1|) 84)) (-2545 (($ $ $) 78 (|has| |#1| (-368)))) (-4316 (((-769) $) 66)) (-3694 ((|#1| $) 55 (|has| |#1| (-457)))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 70 (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) 69)) (-3193 (((-638 |#1|) $) 60)) (-1958 ((|#1| $ (-769)) 62)) (-2140 (((-769)) 28)) (-1591 ((|#1| $ |#1| |#1|) 59)) (-2527 (($ $) 82)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($) 83)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 76) (($ |#1| $) 75))) 
-(((-650 |#1|) (-1290) (-1054)) (T -650)) 
-((-1557 (*1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)))) (-2527 (*1 *1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)))) (-1701 (*1 *1 *1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-1551 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-650 *3)) (-4 *3 (-1054)) (-4 *3 (-368)))) (-3646 (*1 *1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-2545 (*1 *1 *1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(-13 (-850 |t#1|) (-283 |t#1| |t#1|) (-10 -8 (-15 -1557 ($)) (-15 -2527 ($ $)) (IF (|has| |t#1| (-368)) (PROGN (-15 -1701 ($ $ $)) (-15 -1551 ($ $ (-769))) (-15 -3646 ($ $)) (-15 -2545 ($ $ $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-174)) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-283 |#1| |#1|) . T) ((-417 |#1|) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 |#1|) |has| |#1| (-174)) ((-722) . T) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1060 |#1|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-850 |#1|) . T)) 
-((-2791 (((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|))) 72 (|has| |#1| (-27)))) (-4304 (((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|))) 71 (|has| |#1| (-27))) (((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|)) 15))) 
-(((-651 |#1| |#2|) (-10 -7 (-15 -4304 ((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -4304 ((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|)))) (-15 -2791 ((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|))))) |noBranch|)) (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572)))) (-1234 |#1|)) (T -651)) 
-((-2791 (*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-647 (-413 *5)))) (-5 *1 (-651 *4 *5)) (-5 *3 (-647 (-413 *5))))) (-4304 (*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-647 (-413 *5)))) (-5 *1 (-651 *4 *5)) (-5 *3 (-647 (-413 *5))))) (-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-647 (-413 *6)))) (-5 *1 (-651 *5 *6)) (-5 *3 (-647 (-413 *6)))))) 
-(-10 -7 (-15 -4304 ((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -4304 ((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|)))) (-15 -2791 ((-638 (-647 (-413 |#2|))) (-647 (-413 |#2|))))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3646 (($ $) NIL (|has| |#1| (-368)))) (-1701 (($ $ $) 28 (|has| |#1| (-368)))) (-1551 (($ $ (-769)) 31 (|has| |#1| (-368)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1887 (($ $ $) NIL (|has| |#1| (-368)))) (-3467 (($ $ $) NIL (|has| |#1| (-368)))) (-2349 (($ $ $) NIL (|has| |#1| (-368)))) (-3296 (($ $ $) NIL (|has| |#1| (-368)))) (-2366 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-4549 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-4046 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457)))) (-3893 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) NIL)) (-4441 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-2196 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-1784 (((-769) $) NIL)) (-3197 (($ $ $) NIL (|has| |#1| (-368)))) (-3874 (($ $ $) NIL (|has| |#1| (-368)))) (-4008 (($ $ $) NIL (|has| |#1| (-368)))) (-3373 (($ $ $) NIL (|has| |#1| (-368)))) (-2123 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-2955 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-3230 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562)))) (-3277 ((|#1| $ |#1|) 24)) (-2545 (($ $ $) 33 (|has| |#1| (-368)))) (-4316 (((-769) $) NIL)) (-3694 ((|#1| $) NIL (|has| |#1| (-457)))) (-3972 (((-856) $) 20) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) NIL)) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) NIL)) (-2140 (((-769)) NIL)) (-1591 ((|#1| $ |#1| |#1|) 23)) (-2527 (($ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 21 T CONST)) (-3255 (($) 8 T CONST)) (-1557 (($) NIL)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-652 |#1| |#2|) (-650 |#1|) (-1054) (-1 |#1| |#1|)) (T -652)) 
-NIL 
-(-650 |#1|) 
-((-1701 ((|#2| |#2| |#2| (-1 |#1| |#1|)) 61)) (-1551 ((|#2| |#2| (-769) (-1 |#1| |#1|)) 42)) (-2545 ((|#2| |#2| |#2| (-1 |#1| |#1|)) 63))) 
-(((-653 |#1| |#2|) (-10 -7 (-15 -1701 (|#2| |#2| |#2| (-1 |#1| |#1|))) (-15 -1551 (|#2| |#2| (-769) (-1 |#1| |#1|))) (-15 -2545 (|#2| |#2| |#2| (-1 |#1| |#1|)))) (-368) (-650 |#1|)) (T -653)) 
-((-2545 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-368)) (-5 *1 (-653 *4 *2)) (-4 *2 (-650 *4)))) (-1551 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-769)) (-5 *4 (-1 *5 *5)) (-4 *5 (-368)) (-5 *1 (-653 *5 *2)) (-4 *2 (-650 *5)))) (-1701 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-368)) (-5 *1 (-653 *4 *2)) (-4 *2 (-650 *4))))) 
-(-10 -7 (-15 -1701 (|#2| |#2| |#2| (-1 |#1| |#1|))) (-15 -1551 (|#2| |#2| (-769) (-1 |#1| |#1|))) (-15 -2545 (|#2| |#2| |#2| (-1 |#1| |#1|)))) 
-((-2235 (($ $ $) 9))) 
-(((-654 |#1|) (-10 -8 (-15 -2235 (|#1| |#1| |#1|))) (-655)) (T -654)) 
-NIL 
-(-10 -8 (-15 -2235 (|#1| |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-2004 (($ $) 10)) (-2235 (($ $ $) 8)) (-1324 (((-121) $ $) 6)) (-2226 (($ $ $) 9))) 
-(((-655) (-1290)) (T -655)) 
-((-2004 (*1 *1 *1) (-4 *1 (-655))) (-2226 (*1 *1 *1 *1) (-4 *1 (-655))) (-2235 (*1 *1 *1 *1) (-4 *1 (-655)))) 
-(-13 (-105) (-10 -8 (-15 -2004 ($ $)) (-15 -2226 ($ $ $)) (-15 -2235 ($ $ $)))) 
-(((-105) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-4487 ((|#1| $) 21)) (-1771 (($ $ $) NIL (|has| |#1| (-792)))) (-4238 (($ $ $) NIL (|has| |#1| (-792)))) (-1658 (((-1152) $) 46)) (-2607 (((-1116) $) NIL)) (-4492 ((|#3| $) 22)) (-3972 (((-856) $) 42)) (-2378 (($) 10 T CONST)) (-1349 (((-121) $ $) NIL (|has| |#1| (-792)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-792)))) (-1324 (((-121) $ $) 20)) (-1343 (((-121) $ $) NIL (|has| |#1| (-792)))) (-1334 (((-121) $ $) 24 (|has| |#1| (-792)))) (-1379 (($ $ |#3|) 34) (($ |#1| |#3|) 35)) (-1373 (($ $) 17) (($ $ $) NIL)) (-1367 (($ $ $) 27)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 30) (($ |#2| $) 32) (($ $ |#2|) NIL))) 
-(((-656 |#1| |#2| |#3|) (-13 (-713 |#2|) (-10 -8 (IF (|has| |#1| (-792)) (-6 (-792)) |noBranch|) (-15 -1379 ($ $ |#3|)) (-15 -1379 ($ |#1| |#3|)) (-15 -4487 (|#1| $)) (-15 -4492 (|#3| $)))) (-713 |#2|) (-174) (|SubsetCategory| (-722) |#2|)) (T -656)) 
-((-1379 (*1 *1 *1 *2) (-12 (-4 *4 (-174)) (-5 *1 (-656 *3 *4 *2)) (-4 *3 (-713 *4)) (-4 *2 (|SubsetCategory| (-722) *4)))) (-1379 (*1 *1 *2 *3) (-12 (-4 *4 (-174)) (-5 *1 (-656 *2 *4 *3)) (-4 *2 (-713 *4)) (-4 *3 (|SubsetCategory| (-722) *4)))) (-4487 (*1 *2 *1) (-12 (-4 *3 (-174)) (-4 *2 (-713 *3)) (-5 *1 (-656 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-722) *3)))) (-4492 (*1 *2 *1) (-12 (-4 *4 (-174)) (-4 *2 (|SubsetCategory| (-722) *4)) (-5 *1 (-656 *3 *4 *2)) (-4 *3 (-713 *4))))) 
-(-13 (-713 |#2|) (-10 -8 (IF (|has| |#1| (-792)) (-6 (-792)) |noBranch|) (-15 -1379 ($ $ |#3|)) (-15 -1379 ($ |#1| |#3|)) (-15 -4487 (|#1| $)) (-15 -4492 (|#3| $)))) 
-((-3090 (((-685 |#1|) (-685 |#1|)) 27)) (-2377 (((-685 |#1|) (-685 |#1|)) 26)) (-1827 (((-638 (-638 |#1|)) (-638 |#1|) (-638 (-638 |#1|))) 44)) (-4027 (((-638 (-638 |#1|)) (-638 (-638 |#1|))) 29)) (-3072 (((-638 |#1|) (-638 |#1|) (-638 |#1|) |#1|) 43)) (-2329 (((-638 (-638 |#1|)) (-638 (-638 |#1|)) (-638 (-638 |#1|))) 34))) 
-(((-657 |#1|) (-10 -7 (-15 -3090 ((-685 |#1|) (-685 |#1|))) (-15 -2377 ((-685 |#1|) (-685 |#1|))) (-15 -4027 ((-638 (-638 |#1|)) (-638 (-638 |#1|)))) (-15 -2329 ((-638 (-638 |#1|)) (-638 (-638 |#1|)) (-638 (-638 |#1|)))) (-15 -3072 ((-638 |#1|) (-638 |#1|) (-638 |#1|) |#1|)) (-15 -1827 ((-638 (-638 |#1|)) (-638 |#1|) (-638 (-638 |#1|))))) (-368)) (T -657)) 
-((-1827 (*1 *2 *3 *2) (-12 (-5 *2 (-638 (-638 *4))) (-5 *3 (-638 *4)) (-4 *4 (-368)) (-5 *1 (-657 *4)))) (-3072 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-5 *1 (-657 *3)))) (-2329 (*1 *2 *2 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-368)) (-5 *1 (-657 *3)))) (-4027 (*1 *2 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-368)) (-5 *1 (-657 *3)))) (-2377 (*1 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-368)) (-5 *1 (-657 *3)))) (-3090 (*1 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-368)) (-5 *1 (-657 *3))))) 
-(-10 -7 (-15 -3090 ((-685 |#1|) (-685 |#1|))) (-15 -2377 ((-685 |#1|) (-685 |#1|))) (-15 -4027 ((-638 (-638 |#1|)) (-638 (-638 |#1|)))) (-15 -2329 ((-638 (-638 |#1|)) (-638 (-638 |#1|)) (-638 (-638 |#1|)))) (-15 -3072 ((-638 |#1|) (-638 |#1|) (-638 |#1|) |#1|)) (-15 -1827 ((-638 (-638 |#1|)) (-638 |#1|) (-638 (-638 |#1|))))) 
-((-2936 (((-121)) 46) (((-121) (-121)) 47)) (-4464 ((|#7| |#5| |#3|) 44)) (-4543 ((|#5| |#7|) 29)) (-2709 (((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-638 (-572)))) |#3| |#5| |#3| (-572)) 99)) (-3120 (((-638 |#6|) |#5| |#3| (-572)) 35))) 
-(((-658 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -2936 ((-121) (-121))) (-15 -2936 ((-121))) (-15 -4464 (|#7| |#5| |#3|)) (-15 -3120 ((-638 |#6|) |#5| |#3| (-572))) (-15 -4543 (|#5| |#7|)) (-15 -2709 ((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-638 (-572)))) |#3| |#5| |#3| (-572)))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|) (-645 |#1|) (-926 |#1| |#6|)) (T -658)) 
-((-2709 (*1 *2 *3 *4 *3 *5) (-12 (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *9 (-645 *6)) (-5 *2 (-2 (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (-638 (-572))))) (-5 *1 (-658 *6 *7 *3 *8 *4 *9 *10)) (-5 *5 (-572)) (-4 *3 (-956 *6 *8 (-858 *7))) (-4 *4 (-978 *6)) (-4 *10 (-926 *6 *9)))) (-4543 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-645 *4)) (-4 *2 (-978 *4)) (-5 *1 (-658 *4 *5 *6 *7 *2 *8 *3)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *3 (-926 *4 *8)))) (-3120 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-572)) (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *9 (-645 *6)) (-5 *2 (-638 *9)) (-5 *1 (-658 *6 *7 *4 *8 *3 *9 *10)) (-4 *4 (-956 *6 *8 (-858 *7))) (-4 *3 (-978 *6)) (-4 *10 (-926 *6 *9)))) (-4464 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *2 (-926 *5 *8)) (-5 *1 (-658 *5 *6 *4 *7 *3 *8 *2)) (-4 *4 (-956 *5 *7 (-858 *6))) (-4 *3 (-978 *5)) (-4 *8 (-645 *5)))) (-2936 (*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-5 *2 (-121)) (-5 *1 (-658 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *9 (-926 *3 *8)))) (-2936 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-5 *1 (-658 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *9 (-926 *3 *8))))) 
-(-10 -7 (-15 -2936 ((-121) (-121))) (-15 -2936 ((-121))) (-15 -4464 (|#7| |#5| |#3|)) (-15 -3120 ((-638 |#6|) |#5| |#3| (-572))) (-15 -4543 (|#5| |#7|)) (-15 -2709 ((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-638 (-572)))) |#3| |#5| |#3| (-572)))) 
-((-3127 (((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|)) 33))) 
-(((-659 |#1|) (-10 -7 (-15 -3127 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|)))) (-910)) (T -659)) 
-((-3127 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *4))) (-5 *3 (-1166 *4)) (-4 *4 (-910)) (-5 *1 (-659 *4))))) 
-(-10 -7 (-15 -3127 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2199 (((-638 |#1|) $) 82)) (-2007 (($ $ (-769)) 90)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3754 (((-1281 |#1| |#2|) (-1281 |#1| |#2|) $) 48)) (-3376 (((-3 (-667 |#1|) "failed") $) NIL)) (-1318 (((-667 |#1|) $) NIL)) (-4383 (($ $) 89)) (-3475 (((-769) $) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4518 (($ (-667 |#1|) |#2|) 68)) (-4076 (($ $) 86)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-3561 (((-1281 |#1| |#2|) (-1281 |#1| |#2|) $) 47)) (-2081 (((-638 (-2 (|:| |k| (-667 |#1|)) (|:| |c| |#2|))) $) NIL)) (-4136 (((-2 (|:| |k| (-667 |#1|)) (|:| |c| |#2|)) $) NIL)) (-4368 (((-667 |#1|) $) NIL)) (-4373 ((|#2| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4485 (($ $ |#1| $) 30) (($ $ (-638 |#1|) (-638 $)) 32)) (-4316 (((-769) $) 88)) (-3921 (($ $ $) 20) (($ (-667 |#1|) (-667 |#1|)) 77) (($ (-667 |#1|) $) 75) (($ $ (-667 |#1|)) 76)) (-3972 (((-856) $) NIL) (($ |#1|) 74) (((-1272 |#1| |#2|) $) 58) (((-1281 |#1| |#2|) $) 41) (($ (-667 |#1|)) 25)) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-667 |#1|)) NIL)) (-4513 ((|#2| (-1281 |#1| |#2|) $) 43)) (-2378 (($) 23 T CONST)) (-2019 (((-3 $ "failed") (-1272 |#1| |#2|)) 60)) (-1960 (($ (-667 |#1|)) 14)) (-1324 (((-121) $ $) 44)) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $) 66) (($ $ $) NIL)) (-1367 (($ $ $) 29)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ |#2| $) 28) (($ $ |#2|) NIL) (($ |#2| (-667 |#1|)) NIL))) 
-(((-660 |#1| |#2|) (-13 (-380 |#1| |#2|) (-388 |#2| (-667 |#1|)) (-10 -8 (-15 -2019 ((-3 $ "failed") (-1272 |#1| |#2|))) (-15 -3921 ($ (-667 |#1|) (-667 |#1|))) (-15 -3921 ($ (-667 |#1|) $)) (-15 -3921 ($ $ (-667 |#1|))))) (-848) (-174)) (T -660)) 
-((-2019 (*1 *1 *2) (|partial| -12 (-5 *2 (-1272 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *1 (-660 *3 *4)))) (-3921 (*1 *1 *2 *2) (-12 (-5 *2 (-667 *3)) (-4 *3 (-848)) (-5 *1 (-660 *3 *4)) (-4 *4 (-174)))) (-3921 (*1 *1 *2 *1) (-12 (-5 *2 (-667 *3)) (-4 *3 (-848)) (-5 *1 (-660 *3 *4)) (-4 *4 (-174)))) (-3921 (*1 *1 *1 *2) (-12 (-5 *2 (-667 *3)) (-4 *3 (-848)) (-5 *1 (-660 *3 *4)) (-4 *4 (-174))))) 
-(-13 (-380 |#1| |#2|) (-388 |#2| (-667 |#1|)) (-10 -8 (-15 -2019 ((-3 $ "failed") (-1272 |#1| |#2|))) (-15 -3921 ($ (-667 |#1|) (-667 |#1|))) (-15 -3921 ($ (-667 |#1|) $)) (-15 -3921 ($ $ (-667 |#1|))))) 
-((-2041 (((-121) $) NIL) (((-121) (-1 (-121) |#2| |#2|) $) 49)) (-4131 (($ $) NIL) (($ (-1 (-121) |#2| |#2|) $) 11)) (-1550 (($ (-1 (-121) |#2|) $) 27)) (-2985 (($ $) 55)) (-3259 (($ $) 62)) (-1544 (($ |#2| $) NIL) (($ (-1 (-121) |#2|) $) 36)) (-3116 ((|#2| (-1 |#2| |#2| |#2|) $) 21) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 50) ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 52)) (-4014 (((-572) |#2| $ (-572)) 60) (((-572) |#2| $) NIL) (((-572) (-1 (-121) |#2|) $) 46)) (-1364 (($ (-769) |#2|) 53)) (-3279 (($ $ $) NIL) (($ (-1 (-121) |#2| |#2|) $ $) 29)) (-4475 (($ $ $) NIL) (($ (-1 (-121) |#2| |#2|) $ $) 24)) (-3828 (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) 54)) (-1624 (($ |#2|) 14)) (-1335 (($ $ $ (-572)) 35) (($ |#2| $ (-572)) 33)) (-3361 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 45)) (-2145 (($ $ (-1225 (-572))) 43) (($ $ (-572)) 37)) (-2907 (($ $ $ (-572)) 59)) (-1607 (($ $) 57)) (-1334 (((-121) $ $) 64))) 
-(((-661 |#1| |#2|) (-10 -8 (-15 -1624 (|#1| |#2|)) (-15 -2145 (|#1| |#1| (-572))) (-15 -2145 (|#1| |#1| (-1225 (-572)))) (-15 -1544 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1335 (|#1| |#2| |#1| (-572))) (-15 -1335 (|#1| |#1| |#1| (-572))) (-15 -3279 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -1550 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1544 (|#1| |#2| |#1|)) (-15 -3259 (|#1| |#1|)) (-15 -3279 (|#1| |#1| |#1|)) (-15 -4475 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -2041 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -4014 ((-572) (-1 (-121) |#2|) |#1|)) (-15 -4014 ((-572) |#2| |#1|)) (-15 -4014 ((-572) |#2| |#1| (-572))) (-15 -4475 (|#1| |#1| |#1|)) (-15 -2041 ((-121) |#1|)) (-15 -2907 (|#1| |#1| |#1| (-572))) (-15 -2985 (|#1| |#1|)) (-15 -4131 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -4131 (|#1| |#1|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3361 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -1364 (|#1| (-769) |#2|)) (-15 -3828 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1607 (|#1| |#1|))) (-662 |#2|) (-1204)) (T -661)) 
-NIL 
-(-10 -8 (-15 -1624 (|#1| |#2|)) (-15 -2145 (|#1| |#1| (-572))) (-15 -2145 (|#1| |#1| (-1225 (-572)))) (-15 -1544 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1335 (|#1| |#2| |#1| (-572))) (-15 -1335 (|#1| |#1| |#1| (-572))) (-15 -3279 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -1550 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1544 (|#1| |#2| |#1|)) (-15 -3259 (|#1| |#1|)) (-15 -3279 (|#1| |#1| |#1|)) (-15 -4475 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -2041 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -4014 ((-572) (-1 (-121) |#2|) |#1|)) (-15 -4014 ((-572) |#2| |#1|)) (-15 -4014 ((-572) |#2| |#1| (-572))) (-15 -4475 (|#1| |#1| |#1|)) (-15 -2041 ((-121) |#1|)) (-15 -2907 (|#1| |#1| |#1| (-572))) (-15 -2985 (|#1| |#1|)) (-15 -4131 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -4131 (|#1| |#1|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3116 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3361 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -1364 (|#1| (-769) |#2|)) (-15 -3828 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1607 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-4230 ((|#1| $) 62)) (-4232 (($ $) 64)) (-2430 (((-1264) $ (-572) (-572)) 94 (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) 49 (|has| $ (-6 -4603)))) (-2041 (((-121) $) 136 (|has| |#1| (-848))) (((-121) (-1 (-121) |#1| |#1|) $) 130)) (-4131 (($ $) 140 (-12 (|has| |#1| (-848)) (|has| $ (-6 -4603)))) (($ (-1 (-121) |#1| |#1|) $) 139 (|has| $ (-6 -4603)))) (-3008 (($ $) 135 (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $) 129)) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-3749 (($ $ $) 53 (|has| $ (-6 -4603)))) (-2656 ((|#1| $ |#1|) 51 (|has| $ (-6 -4603)))) (-4055 ((|#1| $ |#1|) 55 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4603))) (($ $ "rest" $) 52 (|has| $ (-6 -4603))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 114 (|has| $ (-6 -4603))) ((|#1| $ (-572) |#1|) 83 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-1550 (($ (-1 (-121) |#1|) $) 123)) (-2561 (($ (-1 (-121) |#1|) $) 99 (|has| $ (-6 -4602)))) (-4066 ((|#1| $) 63)) (-2211 (($) 7 T CONST)) (-2985 (($ $) 138 (|has| $ (-6 -4603)))) (-1656 (($ $) 128)) (-1651 (($ $) 70) (($ $ (-769)) 68)) (-3259 (($ $) 125 (|has| |#1| (-1098)))) (-1643 (($ $) 96 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ |#1| $) 124 (|has| |#1| (-1098))) (($ (-1 (-121) |#1|) $) 119)) (-3445 (($ (-1 (-121) |#1|) $) 100 (|has| $ (-6 -4602))) (($ |#1| $) 97 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3037 ((|#1| $ (-572) |#1|) 82 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 84)) (-2429 (((-121) $) 80)) (-4014 (((-572) |#1| $ (-572)) 133 (|has| |#1| (-1098))) (((-572) |#1| $) 132 (|has| |#1| (-1098))) (((-572) (-1 (-121) |#1|) $) 131)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-1364 (($ (-769) |#1|) 105)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 92 (|has| (-572) (-848)))) (-1771 (($ $ $) 141 (|has| |#1| (-848)))) (-3279 (($ $ $) 126 (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) 122)) (-4475 (($ $ $) 134 (|has| |#1| (-848))) (($ (-1 (-121) |#1| |#1|) $ $) 127)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 91 (|has| (-572) (-848)))) (-4238 (($ $ $) 142 (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-1624 (($ |#1|) 116)) (-3524 (((-121) $ (-769)) 10)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-3253 ((|#1| $) 67) (($ $ (-769)) 65)) (-1335 (($ $ $ (-572)) 121) (($ |#1| $ (-572)) 120)) (-2603 (($ $ $ (-572)) 113) (($ |#1| $ (-572)) 112)) (-2739 (((-638 (-572)) $) 89)) (-1601 (((-121) (-572) $) 88)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 73) (($ $ (-769)) 71)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-3299 (($ $ |#1|) 93 (|has| $ (-6 -4603)))) (-3540 (((-121) $) 81)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 87)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1225 (-572))) 109) ((|#1| $ (-572)) 86) ((|#1| $ (-572) |#1|) 85)) (-3537 (((-572) $ $) 41)) (-2145 (($ $ (-1225 (-572))) 118) (($ $ (-572)) 117)) (-1940 (($ $ (-1225 (-572))) 111) (($ $ (-572)) 110)) (-1791 (((-121) $) 43)) (-2619 (($ $) 59)) (-3316 (($ $) 56 (|has| $ (-6 -4603)))) (-1471 (((-769) $) 60)) (-3622 (($ $) 61)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2907 (($ $ $ (-572)) 137 (|has| $ (-6 -4603)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 95 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 104)) (-2977 (($ $ $) 58) (($ $ |#1|) 57)) (-4500 (($ $ $) 75) (($ |#1| $) 74) (($ (-638 $)) 107) (($ $ |#1|) 106)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) 144 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 145 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-1343 (((-121) $ $) 143 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 146 (|has| |#1| (-848)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-662 |#1|) (-1290) (-1204)) (T -662)) 
-((-1624 (*1 *1 *2) (-12 (-4 *1 (-662 *2)) (-4 *2 (-1204))))) 
-(-13 (-1142 |t#1|) (-379 |t#1|) (-279 |t#1|) (-10 -8 (-15 -1624 ($ |t#1|)))) 
-(((-39) . T) ((-105) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-612 (-856)) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-279 |#1|) . T) ((-379 |#1|) . T) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-644 |#1|) . T) ((-848) |has| |#1| (-848)) ((-1017 |#1|) . T) ((-1098) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-1142 |#1|) . T) ((-1204) . T) ((-1246 |#1|) . T)) 
-((-2800 (((-638 (-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|))))) (-638 (-638 |#1|)) (-638 (-1259 |#1|))) 21) (((-638 (-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|))))) (-685 |#1|) (-638 (-1259 |#1|))) 20) (((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-638 (-638 |#1|)) (-1259 |#1|)) 16) (((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-685 |#1|) (-1259 |#1|)) 13)) (-2667 (((-769) (-685 |#1|) (-1259 |#1|)) 29)) (-3473 (((-3 (-1259 |#1|) "failed") (-685 |#1|) (-1259 |#1|)) 23)) (-3074 (((-121) (-685 |#1|) (-1259 |#1|)) 26))) 
-(((-663 |#1|) (-10 -7 (-15 -2800 ((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-685 |#1|) (-1259 |#1|))) (-15 -2800 ((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-638 (-638 |#1|)) (-1259 |#1|))) (-15 -2800 ((-638 (-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|))))) (-685 |#1|) (-638 (-1259 |#1|)))) (-15 -2800 ((-638 (-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|))))) (-638 (-638 |#1|)) (-638 (-1259 |#1|)))) (-15 -3473 ((-3 (-1259 |#1|) "failed") (-685 |#1|) (-1259 |#1|))) (-15 -3074 ((-121) (-685 |#1|) (-1259 |#1|))) (-15 -2667 ((-769) (-685 |#1|) (-1259 |#1|)))) (-368)) (T -663)) 
-((-2667 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *5)) (-5 *4 (-1259 *5)) (-4 *5 (-368)) (-5 *2 (-769)) (-5 *1 (-663 *5)))) (-3074 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *5)) (-5 *4 (-1259 *5)) (-4 *5 (-368)) (-5 *2 (-121)) (-5 *1 (-663 *5)))) (-3473 (*1 *2 *3 *2) (|partial| -12 (-5 *2 (-1259 *4)) (-5 *3 (-685 *4)) (-4 *4 (-368)) (-5 *1 (-663 *4)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 *5))) (-4 *5 (-368)) (-5 *2 (-638 (-2 (|:| |particular| (-3 (-1259 *5) "failed")) (|:| -2237 (-638 (-1259 *5)))))) (-5 *1 (-663 *5)) (-5 *4 (-638 (-1259 *5))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *5)) (-4 *5 (-368)) (-5 *2 (-638 (-2 (|:| |particular| (-3 (-1259 *5) "failed")) (|:| -2237 (-638 (-1259 *5)))))) (-5 *1 (-663 *5)) (-5 *4 (-638 (-1259 *5))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 *5))) (-4 *5 (-368)) (-5 *2 (-2 (|:| |particular| (-3 (-1259 *5) "failed")) (|:| -2237 (-638 (-1259 *5))))) (-5 *1 (-663 *5)) (-5 *4 (-1259 *5)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |particular| (-3 (-1259 *5) "failed")) (|:| -2237 (-638 (-1259 *5))))) (-5 *1 (-663 *5)) (-5 *4 (-1259 *5))))) 
-(-10 -7 (-15 -2800 ((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-685 |#1|) (-1259 |#1|))) (-15 -2800 ((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-638 (-638 |#1|)) (-1259 |#1|))) (-15 -2800 ((-638 (-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|))))) (-685 |#1|) (-638 (-1259 |#1|)))) (-15 -2800 ((-638 (-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|))))) (-638 (-638 |#1|)) (-638 (-1259 |#1|)))) (-15 -3473 ((-3 (-1259 |#1|) "failed") (-685 |#1|) (-1259 |#1|))) (-15 -3074 ((-121) (-685 |#1|) (-1259 |#1|))) (-15 -2667 ((-769) (-685 |#1|) (-1259 |#1|)))) 
-((-2800 (((-638 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|)))) |#4| (-638 |#3|)) 47) (((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|))) |#4| |#3|) 45)) (-2667 (((-769) |#4| |#3|) 17)) (-3473 (((-3 |#3| "failed") |#4| |#3|) 20)) (-3074 (((-121) |#4| |#3|) 13))) 
-(((-664 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2800 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|))) |#4| |#3|)) (-15 -2800 ((-638 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|)))) |#4| (-638 |#3|))) (-15 -3473 ((-3 |#3| "failed") |#4| |#3|)) (-15 -3074 ((-121) |#4| |#3|)) (-15 -2667 ((-769) |#4| |#3|))) (-368) (-13 (-379 |#1|) (-10 -7 (-6 -4603))) (-13 (-379 |#1|) (-10 -7 (-6 -4603))) (-683 |#1| |#2| |#3|)) (T -664)) 
-((-2667 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-5 *2 (-769)) (-5 *1 (-664 *5 *6 *4 *3)) (-4 *3 (-683 *5 *6 *4)))) (-3074 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-5 *2 (-121)) (-5 *1 (-664 *5 *6 *4 *3)) (-4 *3 (-683 *5 *6 *4)))) (-3473 (*1 *2 *3 *2) (|partial| -12 (-4 *4 (-368)) (-4 *5 (-13 (-379 *4) (-10 -7 (-6 -4603)))) (-4 *2 (-13 (-379 *4) (-10 -7 (-6 -4603)))) (-5 *1 (-664 *4 *5 *2 *3)) (-4 *3 (-683 *4 *5 *2)))) (-2800 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-4 *7 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-5 *2 (-638 (-2 (|:| |particular| (-3 *7 "failed")) (|:| -2237 (-638 *7))))) (-5 *1 (-664 *5 *6 *7 *3)) (-5 *4 (-638 *7)) (-4 *3 (-683 *5 *6 *7)))) (-2800 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-664 *5 *6 *4 *3)) (-4 *3 (-683 *5 *6 *4))))) 
-(-10 -7 (-15 -2800 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|))) |#4| |#3|)) (-15 -2800 ((-638 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|)))) |#4| (-638 |#3|))) (-15 -3473 ((-3 |#3| "failed") |#4| |#3|)) (-15 -3074 ((-121) |#4| |#3|)) (-15 -2667 ((-769) |#4| |#3|))) 
-((-4279 (((-2 (|:| |particular| (-3 (-1259 (-413 |#4|)) "failed")) (|:| -2237 (-638 (-1259 (-413 |#4|))))) (-638 |#4|) (-638 |#3|)) 44))) 
-(((-665 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4279 ((-2 (|:| |particular| (-3 (-1259 (-413 |#4|)) "failed")) (|:| -2237 (-638 (-1259 (-413 |#4|))))) (-638 |#4|) (-638 |#3|)))) (-562) (-794) (-848) (-956 |#1| |#2| |#3|)) (T -665)) 
-((-4279 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *7)) (-4 *7 (-848)) (-4 *8 (-956 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-5 *2 (-2 (|:| |particular| (-3 (-1259 (-413 *8)) "failed")) (|:| -2237 (-638 (-1259 (-413 *8)))))) (-5 *1 (-665 *5 *6 *7 *8))))) 
-(-10 -7 (-15 -4279 ((-2 (|:| |particular| (-3 (-1259 (-413 |#4|)) "failed")) (|:| -2237 (-638 (-1259 (-413 |#4|))))) (-638 |#4|) (-638 |#3|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3029 (((-3 $ "failed")) NIL (|has| |#2| (-562)))) (-3520 ((|#2| $) NIL)) (-3083 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1354 (((-1259 (-685 |#2|))) NIL) (((-1259 (-685 |#2|)) (-1259 $)) NIL)) (-4044 (((-121) $) NIL)) (-2167 (((-1259 $)) 37)) (-1946 (((-121) $ (-769)) NIL)) (-1468 (($ |#2|) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) NIL (|has| |#2| (-303)))) (-4267 (((-234 |#1| |#2|) $ (-572)) NIL)) (-4511 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL (|has| |#2| (-562)))) (-2095 (((-3 $ "failed")) NIL (|has| |#2| (-562)))) (-2882 (((-685 |#2|)) NIL) (((-685 |#2|) (-1259 $)) NIL)) (-3487 ((|#2| $) NIL)) (-3700 (((-685 |#2|) $) NIL) (((-685 |#2|) $ (-1259 $)) NIL)) (-2848 (((-3 $ "failed") $) NIL (|has| |#2| (-562)))) (-4535 (((-1166 (-959 |#2|))) NIL (|has| |#2| (-368)))) (-3014 (($ $ (-923)) NIL)) (-3588 ((|#2| $) NIL)) (-2135 (((-1166 |#2|) $) NIL (|has| |#2| (-562)))) (-4146 ((|#2|) NIL) ((|#2| (-1259 $)) NIL)) (-1593 (((-1166 |#2|) $) NIL)) (-2048 (((-121)) NIL)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 |#2| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) ((|#2| $) NIL)) (-4337 (($ (-1259 |#2|)) NIL) (($ (-1259 |#2|) (-1259 $)) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2667 (((-769) $) NIL (|has| |#2| (-562))) (((-923)) 38)) (-4212 ((|#2| $ (-572) (-572)) NIL)) (-4160 (((-121)) NIL)) (-2027 (($ $ (-923)) NIL)) (-2010 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3893 (((-121) $) NIL)) (-3095 (((-769) $) NIL (|has| |#2| (-562)))) (-1301 (((-638 (-234 |#1| |#2|)) $) NIL (|has| |#2| (-562)))) (-3704 (((-769) $) NIL)) (-1814 (((-121)) NIL)) (-3712 (((-769) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-1522 ((|#2| $) NIL (|has| |#2| (-6 (-4604 "*"))))) (-2660 (((-572) $) NIL)) (-3092 (((-572) $) NIL)) (-4467 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-3927 (((-572) $) NIL)) (-3227 (((-572) $) NIL)) (-3597 (($ (-638 (-638 |#2|))) NIL)) (-2435 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 |#2| |#2|) $) NIL)) (-2259 (((-638 (-638 |#2|)) $) NIL)) (-2209 (((-121)) NIL)) (-1648 (((-121)) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1903 (((-3 (-2 (|:| |particular| $) (|:| -2237 (-638 $))) "failed")) NIL (|has| |#2| (-562)))) (-2036 (((-3 $ "failed")) NIL (|has| |#2| (-562)))) (-1663 (((-685 |#2|)) NIL) (((-685 |#2|) (-1259 $)) NIL)) (-3550 ((|#2| $) NIL)) (-3343 (((-685 |#2|) $) NIL) (((-685 |#2|) $ (-1259 $)) NIL)) (-2046 (((-3 $ "failed") $) NIL (|has| |#2| (-562)))) (-2339 (((-1166 (-959 |#2|))) NIL (|has| |#2| (-368)))) (-3276 (($ $ (-923)) NIL)) (-2340 ((|#2| $) NIL)) (-3665 (((-1166 |#2|) $) NIL (|has| |#2| (-562)))) (-2110 ((|#2|) NIL) ((|#2| (-1259 $)) NIL)) (-1989 (((-1166 |#2|) $) NIL)) (-3602 (((-121)) NIL)) (-1658 (((-1152) $) NIL)) (-4219 (((-121)) NIL)) (-2395 (((-121)) NIL)) (-3046 (((-121)) NIL)) (-3750 (((-3 $ "failed") $) NIL (|has| |#2| (-368)))) (-2607 (((-1116) $) NIL)) (-4128 (((-121)) NIL)) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562)))) (-2109 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ (-572) (-572) |#2|) NIL) ((|#2| $ (-572) (-572)) 22) ((|#2| $ (-572)) NIL)) (-3139 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-769)) NIL (|has| |#2| (-227))) (($ $) NIL (|has| |#2| (-227)))) (-3807 ((|#2| $) NIL)) (-3132 (($ (-638 |#2|)) NIL)) (-3785 (((-121) $) NIL)) (-4479 (((-234 |#1| |#2|) $) NIL)) (-2271 ((|#2| $) NIL (|has| |#2| (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-1607 (($ $) NIL)) (-3160 (((-685 |#2|) (-1259 $)) NIL) (((-1259 |#2|) $) NIL) (((-685 |#2|) (-1259 $) (-1259 $)) NIL) (((-1259 |#2|) $ (-1259 $)) 25)) (-4081 (($ (-1259 |#2|)) NIL) (((-1259 |#2|) $) NIL)) (-3188 (((-638 (-959 |#2|))) NIL) (((-638 (-959 |#2|)) (-1259 $)) NIL)) (-4056 (($ $ $) NIL)) (-2073 (((-121)) NIL)) (-4580 (((-234 |#1| |#2|) $ (-572)) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#2| (-1044 (-413 (-572))))) (($ |#2|) NIL) (((-685 |#2|) $) NIL)) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) 36)) (-4414 (((-638 (-1259 |#2|))) NIL (|has| |#2| (-562)))) (-4250 (($ $ $ $) NIL)) (-2928 (((-121)) NIL)) (-1591 (($ (-685 |#2|) $) NIL)) (-3501 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1397 (($ $ $) NIL)) (-2773 (((-121)) NIL)) (-2756 (((-121)) NIL)) (-1447 (((-121)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-769)) NIL (|has| |#2| (-227))) (($ $) NIL (|has| |#2| (-227)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#2| (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (((-234 |#1| |#2|) $ (-234 |#1| |#2|)) NIL) (((-234 |#1| |#2|) (-234 |#1| |#2|) $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-666 |#1| |#2|) (-13 (-1119 |#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) (-612 (-685 |#2|)) (-423 |#2|)) (-923) (-174)) (T -666)) 
-NIL 
-(-13 (-1119 |#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) (-612 (-685 |#2|)) (-423 |#2|)) 
-((-2262 (((-121) $ $) NIL)) (-2199 (((-638 |#1|) $) NIL)) (-1862 (($ $) 50)) (-1804 (((-121) $) NIL)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-2539 (((-3 $ "failed") (-820 |#1|)) 22)) (-2871 (((-121) (-820 |#1|)) 14)) (-4271 (($ (-820 |#1|)) 23)) (-3763 (((-121) $ $) 28)) (-3200 (((-923) $) 35)) (-1866 (($ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4304 (((-638 $) (-820 |#1|)) 16)) (-3972 (((-856) $) 41) (($ |#1|) 32) (((-820 |#1|) $) 37) (((-672 |#1|) $) 42)) (-4252 (((-64 (-638 $)) (-638 |#1|) (-923)) 55)) (-4253 (((-638 $) (-638 |#1|) (-923)) 57)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 51)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 36))) 
-(((-667 |#1|) (-13 (-848) (-1044 |#1|) (-10 -8 (-15 -1804 ((-121) $)) (-15 -1866 ($ $)) (-15 -1862 ($ $)) (-15 -3200 ((-923) $)) (-15 -3763 ((-121) $ $)) (-15 -3972 ((-820 |#1|) $)) (-15 -3972 ((-672 |#1|) $)) (-15 -4304 ((-638 $) (-820 |#1|))) (-15 -2871 ((-121) (-820 |#1|))) (-15 -4271 ($ (-820 |#1|))) (-15 -2539 ((-3 $ "failed") (-820 |#1|))) (-15 -2199 ((-638 |#1|) $)) (-15 -4252 ((-64 (-638 $)) (-638 |#1|) (-923))) (-15 -4253 ((-638 $) (-638 |#1|) (-923))))) (-848)) (T -667)) 
-((-1804 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) (-1866 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-848)))) (-1862 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-848)))) (-3200 (*1 *2 *1) (-12 (-5 *2 (-923)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) (-3763 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-820 *3)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-672 *3)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) (-4304 (*1 *2 *3) (-12 (-5 *3 (-820 *4)) (-4 *4 (-848)) (-5 *2 (-638 (-667 *4))) (-5 *1 (-667 *4)))) (-2871 (*1 *2 *3) (-12 (-5 *3 (-820 *4)) (-4 *4 (-848)) (-5 *2 (-121)) (-5 *1 (-667 *4)))) (-4271 (*1 *1 *2) (-12 (-5 *2 (-820 *3)) (-4 *3 (-848)) (-5 *1 (-667 *3)))) (-2539 (*1 *1 *2) (|partial| -12 (-5 *2 (-820 *3)) (-4 *3 (-848)) (-5 *1 (-667 *3)))) (-2199 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) (-4252 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-923)) (-4 *5 (-848)) (-5 *2 (-64 (-638 (-667 *5)))) (-5 *1 (-667 *5)))) (-4253 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-923)) (-4 *5 (-848)) (-5 *2 (-638 (-667 *5))) (-5 *1 (-667 *5))))) 
-(-13 (-848) (-1044 |#1|) (-10 -8 (-15 -1804 ((-121) $)) (-15 -1866 ($ $)) (-15 -1862 ($ $)) (-15 -3200 ((-923) $)) (-15 -3763 ((-121) $ $)) (-15 -3972 ((-820 |#1|) $)) (-15 -3972 ((-672 |#1|) $)) (-15 -4304 ((-638 $) (-820 |#1|))) (-15 -2871 ((-121) (-820 |#1|))) (-15 -4271 ($ (-820 |#1|))) (-15 -2539 ((-3 $ "failed") (-820 |#1|))) (-15 -2199 ((-638 |#1|) $)) (-15 -4252 ((-64 (-638 $)) (-638 |#1|) (-923))) (-15 -4253 ((-638 $) (-638 |#1|) (-923))))) 
-((-2148 ((|#2| $) 76)) (-4232 (($ $) 96)) (-1946 (((-121) $ (-769)) 26)) (-1651 (($ $) 85) (($ $ (-769)) 88)) (-2429 (((-121) $) 97)) (-2202 (((-638 $) $) 72)) (-1303 (((-121) $ $) 71)) (-2157 (((-121) $ (-769)) 24)) (-3940 (((-572) $) 46)) (-2026 (((-572) $) 45)) (-3524 (((-121) $ (-769)) 22)) (-3113 (((-121) $) 74)) (-3253 ((|#2| $) 89) (($ $ (-769)) 92)) (-2603 (($ $ $ (-572)) 62) (($ |#2| $ (-572)) 61)) (-2739 (((-638 (-572)) $) 44)) (-1601 (((-121) (-572) $) 42)) (-1837 ((|#2| $) NIL) (($ $ (-769)) 84)) (-1977 (($ $ (-572)) 99)) (-3540 (((-121) $) 98)) (-2109 (((-121) (-1 (-121) |#2|) $) 32)) (-2957 (((-638 |#2|) $) 33)) (-3277 ((|#2| $ "value") NIL) ((|#2| $ "first") 83) (($ $ "rest") 87) ((|#2| $ "last") 95) (($ $ (-1225 (-572))) 58) ((|#2| $ (-572)) 40) ((|#2| $ (-572) |#2|) 41)) (-3537 (((-572) $ $) 70)) (-1940 (($ $ (-1225 (-572))) 57) (($ $ (-572)) 51)) (-1791 (((-121) $) 66)) (-2619 (($ $) 81)) (-1471 (((-769) $) 80)) (-3622 (($ $) 79)) (-3921 (($ (-638 |#2|)) 37)) (-2424 (($ $) 100)) (-4118 (((-638 $) $) 69)) (-3432 (((-121) $ $) 68)) (-3501 (((-121) (-1 (-121) |#2|) $) 31)) (-1324 (((-121) $ $) 18)) (-4032 (((-769) $) 29))) 
-(((-668 |#1| |#2|) (-10 -8 (-15 -2424 (|#1| |#1|)) (-15 -1977 (|#1| |#1| (-572))) (-15 -2429 ((-121) |#1|)) (-15 -3540 ((-121) |#1|)) (-15 -3277 (|#2| |#1| (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572))) (-15 -2957 ((-638 |#2|) |#1|)) (-15 -1601 ((-121) (-572) |#1|)) (-15 -2739 ((-638 (-572)) |#1|)) (-15 -2026 ((-572) |#1|)) (-15 -3940 ((-572) |#1|)) (-15 -3921 (|#1| (-638 |#2|))) (-15 -3277 (|#1| |#1| (-1225 (-572)))) (-15 -1940 (|#1| |#1| (-572))) (-15 -1940 (|#1| |#1| (-1225 (-572)))) (-15 -2603 (|#1| |#2| |#1| (-572))) (-15 -2603 (|#1| |#1| |#1| (-572))) (-15 -2619 (|#1| |#1|)) (-15 -1471 ((-769) |#1|)) (-15 -3622 (|#1| |#1|)) (-15 -4232 (|#1| |#1|)) (-15 -3253 (|#1| |#1| (-769))) (-15 -3277 (|#2| |#1| "last")) (-15 -3253 (|#2| |#1|)) (-15 -1651 (|#1| |#1| (-769))) (-15 -3277 (|#1| |#1| "rest")) (-15 -1651 (|#1| |#1|)) (-15 -1837 (|#1| |#1| (-769))) (-15 -3277 (|#2| |#1| "first")) (-15 -1837 (|#2| |#1|)) (-15 -1303 ((-121) |#1| |#1|)) (-15 -3432 ((-121) |#1| |#1|)) (-15 -3537 ((-572) |#1| |#1|)) (-15 -1791 ((-121) |#1|)) (-15 -3277 (|#2| |#1| "value")) (-15 -2148 (|#2| |#1|)) (-15 -3113 ((-121) |#1|)) (-15 -2202 ((-638 |#1|) |#1|)) (-15 -4118 ((-638 |#1|) |#1|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -4032 ((-769) |#1|)) (-15 -1946 ((-121) |#1| (-769))) (-15 -2157 ((-121) |#1| (-769))) (-15 -3524 ((-121) |#1| (-769)))) (-669 |#2|) (-1204)) (T -668)) 
-NIL 
-(-10 -8 (-15 -2424 (|#1| |#1|)) (-15 -1977 (|#1| |#1| (-572))) (-15 -2429 ((-121) |#1|)) (-15 -3540 ((-121) |#1|)) (-15 -3277 (|#2| |#1| (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572))) (-15 -2957 ((-638 |#2|) |#1|)) (-15 -1601 ((-121) (-572) |#1|)) (-15 -2739 ((-638 (-572)) |#1|)) (-15 -2026 ((-572) |#1|)) (-15 -3940 ((-572) |#1|)) (-15 -3921 (|#1| (-638 |#2|))) (-15 -3277 (|#1| |#1| (-1225 (-572)))) (-15 -1940 (|#1| |#1| (-572))) (-15 -1940 (|#1| |#1| (-1225 (-572)))) (-15 -2603 (|#1| |#2| |#1| (-572))) (-15 -2603 (|#1| |#1| |#1| (-572))) (-15 -2619 (|#1| |#1|)) (-15 -1471 ((-769) |#1|)) (-15 -3622 (|#1| |#1|)) (-15 -4232 (|#1| |#1|)) (-15 -3253 (|#1| |#1| (-769))) (-15 -3277 (|#2| |#1| "last")) (-15 -3253 (|#2| |#1|)) (-15 -1651 (|#1| |#1| (-769))) (-15 -3277 (|#1| |#1| "rest")) (-15 -1651 (|#1| |#1|)) (-15 -1837 (|#1| |#1| (-769))) (-15 -3277 (|#2| |#1| "first")) (-15 -1837 (|#2| |#1|)) (-15 -1303 ((-121) |#1| |#1|)) (-15 -3432 ((-121) |#1| |#1|)) (-15 -3537 ((-572) |#1| |#1|)) (-15 -1791 ((-121) |#1|)) (-15 -3277 (|#2| |#1| "value")) (-15 -2148 (|#2| |#1|)) (-15 -3113 ((-121) |#1|)) (-15 -2202 ((-638 |#1|) |#1|)) (-15 -4118 ((-638 |#1|) |#1|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -2109 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -4032 ((-769) |#1|)) (-15 -1946 ((-121) |#1| (-769))) (-15 -2157 ((-121) |#1| (-769))) (-15 -3524 ((-121) |#1| (-769)))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-4230 ((|#1| $) 62)) (-4232 (($ $) 64)) (-2430 (((-1264) $ (-572) (-572)) 94 (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) 49 (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-3749 (($ $ $) 53 (|has| $ (-6 -4603)))) (-2656 ((|#1| $ |#1|) 51 (|has| $ (-6 -4603)))) (-4055 ((|#1| $ |#1|) 55 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4603))) (($ $ "rest" $) 52 (|has| $ (-6 -4603))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 114 (|has| $ (-6 -4603))) ((|#1| $ (-572) |#1|) 83 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) 99)) (-4066 ((|#1| $) 63)) (-2211 (($) 7 T CONST)) (-2438 (($ $) 118)) (-1651 (($ $) 70) (($ $ (-769)) 68)) (-1643 (($ $) 96 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#1| $) 97 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 100)) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3037 ((|#1| $ (-572) |#1|) 82 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 84)) (-2429 (((-121) $) 80)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2050 (((-769) $) 117)) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-1364 (($ (-769) |#1|) 105)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 92 (|has| (-572) (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 91 (|has| (-572) (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-3524 (((-121) $ (-769)) 10)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-2556 (($ $) 120)) (-1493 (((-121) $) 121)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-3253 ((|#1| $) 67) (($ $ (-769)) 65)) (-2603 (($ $ $ (-572)) 113) (($ |#1| $ (-572)) 112)) (-2739 (((-638 (-572)) $) 89)) (-1601 (((-121) (-572) $) 88)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-3179 ((|#1| $) 119)) (-1837 ((|#1| $) 73) (($ $ (-769)) 71)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-3299 (($ $ |#1|) 93 (|has| $ (-6 -4603)))) (-1977 (($ $ (-572)) 116)) (-3540 (((-121) $) 81)) (-3173 (((-121) $) 122)) (-4249 (((-121) $) 123)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 87)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1225 (-572))) 109) ((|#1| $ (-572)) 86) ((|#1| $ (-572) |#1|) 85)) (-3537 (((-572) $ $) 41)) (-1940 (($ $ (-1225 (-572))) 111) (($ $ (-572)) 110)) (-1791 (((-121) $) 43)) (-2619 (($ $) 59)) (-3316 (($ $) 56 (|has| $ (-6 -4603)))) (-1471 (((-769) $) 60)) (-3622 (($ $) 61)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 95 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 104)) (-2977 (($ $ $) 58 (|has| $ (-6 -4603))) (($ $ |#1|) 57 (|has| $ (-6 -4603)))) (-4500 (($ $ $) 75) (($ |#1| $) 74) (($ (-638 $)) 107) (($ $ |#1|) 106)) (-2424 (($ $) 115)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-669 |#1|) (-1290) (-1204)) (T -669)) 
-((-3445 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-669 *3)) (-4 *3 (-1204)))) (-2561 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-669 *3)) (-4 *3 (-1204)))) (-4249 (*1 *2 *1) (-12 (-4 *1 (-669 *3)) (-4 *3 (-1204)) (-5 *2 (-121)))) (-3173 (*1 *2 *1) (-12 (-4 *1 (-669 *3)) (-4 *3 (-1204)) (-5 *2 (-121)))) (-1493 (*1 *2 *1) (-12 (-4 *1 (-669 *3)) (-4 *3 (-1204)) (-5 *2 (-121)))) (-2556 (*1 *1 *1) (-12 (-4 *1 (-669 *2)) (-4 *2 (-1204)))) (-3179 (*1 *2 *1) (-12 (-4 *1 (-669 *2)) (-4 *2 (-1204)))) (-2438 (*1 *1 *1) (-12 (-4 *1 (-669 *2)) (-4 *2 (-1204)))) (-2050 (*1 *2 *1) (-12 (-4 *1 (-669 *3)) (-4 *3 (-1204)) (-5 *2 (-769)))) (-1977 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-669 *3)) (-4 *3 (-1204)))) (-2424 (*1 *1 *1) (-12 (-4 *1 (-669 *2)) (-4 *2 (-1204))))) 
-(-13 (-1142 |t#1|) (-10 -8 (-15 -3445 ($ (-1 (-121) |t#1|) $)) (-15 -2561 ($ (-1 (-121) |t#1|) $)) (-15 -4249 ((-121) $)) (-15 -3173 ((-121) $)) (-15 -1493 ((-121) $)) (-15 -2556 ($ $)) (-15 -3179 (|t#1| $)) (-15 -2438 ($ $)) (-15 -2050 ((-769) $)) (-15 -1977 ($ $ (-572))) (-15 -2424 ($ $)))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-644 |#1|) . T) ((-1017 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1142 |#1|) . T) ((-1204) . T) ((-1246 |#1|) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3841 (($ (-769) (-769) (-769)) 32 (|has| |#1| (-1054)))) (-1946 (((-121) $ (-769)) NIL)) (-3271 ((|#1| $ (-769) (-769) (-769) |#1|) 27)) (-2211 (($) NIL T CONST)) (-2515 (($ $ $) 36 (|has| |#1| (-1054)))) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3001 (((-1259 (-769)) $) 8)) (-2889 (($ (-1170) $ $) 22)) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-1392 (($ (-769)) 34 (|has| |#1| (-1054)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-769) (-769) (-769)) 25)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3921 (($ (-638 (-638 (-638 |#1|)))) 43)) (-3972 (((-856) $) NIL (|has| |#1| (-1098))) (($ (-965 (-965 (-965 |#1|)))) 15) (((-965 (-965 (-965 |#1|))) $) 12)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-670 |#1|) (-13 (-503 |#1|) (-10 -8 (IF (|has| |#1| (-1054)) (PROGN (-15 -3841 ($ (-769) (-769) (-769))) (-15 -1392 ($ (-769))) (-15 -2515 ($ $ $))) |noBranch|) (-15 -3921 ($ (-638 (-638 (-638 |#1|))))) (-15 -3277 (|#1| $ (-769) (-769) (-769))) (-15 -3271 (|#1| $ (-769) (-769) (-769) |#1|)) (-15 -3972 ($ (-965 (-965 (-965 |#1|))))) (-15 -3972 ((-965 (-965 (-965 |#1|))) $)) (-15 -2889 ($ (-1170) $ $)) (-15 -3001 ((-1259 (-769)) $)))) (-1098)) (T -670)) 
-((-3841 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-769)) (-5 *1 (-670 *3)) (-4 *3 (-1054)) (-4 *3 (-1098)))) (-1392 (*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-670 *3)) (-4 *3 (-1054)) (-4 *3 (-1098)))) (-2515 (*1 *1 *1 *1) (-12 (-5 *1 (-670 *2)) (-4 *2 (-1054)) (-4 *2 (-1098)))) (-3921 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-638 *3)))) (-4 *3 (-1098)) (-5 *1 (-670 *3)))) (-3277 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-769)) (-5 *1 (-670 *2)) (-4 *2 (-1098)))) (-3271 (*1 *2 *1 *3 *3 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-670 *2)) (-4 *2 (-1098)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-965 (-965 (-965 *3)))) (-4 *3 (-1098)) (-5 *1 (-670 *3)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-965 (-965 (-965 *3)))) (-5 *1 (-670 *3)) (-4 *3 (-1098)))) (-2889 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-670 *3)) (-4 *3 (-1098)))) (-3001 (*1 *2 *1) (-12 (-5 *2 (-1259 (-769))) (-5 *1 (-670 *3)) (-4 *3 (-1098))))) 
-(-13 (-503 |#1|) (-10 -8 (IF (|has| |#1| (-1054)) (PROGN (-15 -3841 ($ (-769) (-769) (-769))) (-15 -1392 ($ (-769))) (-15 -2515 ($ $ $))) |noBranch|) (-15 -3921 ($ (-638 (-638 (-638 |#1|))))) (-15 -3277 (|#1| $ (-769) (-769) (-769))) (-15 -3271 (|#1| $ (-769) (-769) (-769) |#1|)) (-15 -3972 ($ (-965 (-965 (-965 |#1|))))) (-15 -3972 ((-965 (-965 (-965 |#1|))) $)) (-15 -2889 ($ (-1170) $ $)) (-15 -3001 ((-1259 (-769)) $)))) 
-((-1342 (((-121) |#1|) 5)) (-4534 (((-1264) |#1| (-1208) (-572) |#2|) 8)) (-4001 ((|#1| |#1| |#1| |#2|) 1)) (-1947 (((-3 |#2| "failed") (-638 (-959 (-572))) (-638 (-1170)) (-572)) 3)) (-3756 ((|SortedExponentVector| (-572) (-572) |#2|) 7)) (-4316 (((-572) |#1|) 6)) (-3304 (((-3 |#1| "failed") |#1| |#2|) 2)) (-2816 ((|#1| (-959 (-572)) (-1170) (-638 (-1170)) |#2|) 4))) 
-(((-671 |#1| |#2|) (-1290) (-1204) (-1204)) (T -671)) 
-((-4534 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1208)) (-5 *5 (-572)) (-4 *1 (-671 *3 *6)) (-4 *3 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1264)))) (-3756 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-572)) (-4 *1 (-671 *5 *4)) (-4 *5 (-1204)) (-4 *4 (-1204)) (-5 *2 |SortedExponentVector|))) (-4316 (*1 *2 *3) (-12 (-4 *1 (-671 *3 *4)) (-4 *3 (-1204)) (-4 *4 (-1204)) (-5 *2 (-572)))) (-1342 (*1 *2 *3) (-12 (-4 *1 (-671 *3 *4)) (-4 *3 (-1204)) (-4 *4 (-1204)) (-5 *2 (-121)))) (-2816 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-959 (-572))) (-5 *5 (-638 (-1170))) (-4 *1 (-671 *2 *6)) (-4 *6 (-1204)) (-5 *4 (-1170)) (-4 *2 (-1204)))) (-1947 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-638 (-1170))) (-5 *5 (-572)) (-4 *1 (-671 *6 *2)) (-4 *6 (-1204)) (-4 *2 (-1204)))) (-3304 (*1 *2 *2 *3) (|partial| -12 (-4 *1 (-671 *2 *3)) (-4 *2 (-1204)) (-4 *3 (-1204)))) (-4001 (*1 *2 *2 *2 *3) (-12 (-4 *1 (-671 *2 *3)) (-4 *2 (-1204)) (-4 *3 (-1204))))) 
-(-13 (-10 -7 (-15 -4001 (|t#1| |t#1| |t#1| |t#2|)) (-15 -3304 ((-3 |t#1| "failed") |t#1| |t#2|)) (-15 -1947 ((-3 |t#2| "failed") (-638 (-959 (-572))) (-638 (-1170)) (-572))) (-15 -2816 (|t#1| (-959 (-572)) (-1170) (-638 (-1170)) |t#2|)) (-15 -1342 ((-121) |t#1|)) (-15 -4316 ((-572) |t#1|)) (-15 -3756 (|SortedExponentVector| (-572) (-572) |t#2|)) (-15 -4534 ((-1264) |t#1| (-1208) (-572) |t#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-2199 (((-638 |#1|) $) 14)) (-1862 (($ $) 18)) (-1804 (((-121) $) 19)) (-3376 (((-3 |#1| "failed") $) 22)) (-1318 ((|#1| $) 20)) (-1651 (($ $) 36)) (-4076 (($ $) 24)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3763 (((-121) $ $) 41)) (-3200 (((-923) $) 38)) (-1866 (($ $) 17)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 ((|#1| $) 35)) (-3972 (((-856) $) 31) (($ |#1|) 23) (((-820 |#1|) $) 27)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 12)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 40)) (* (($ $ $) 34))) 
-(((-672 |#1|) (-13 (-848) (-1044 |#1|) (-10 -8 (-15 * ($ $ $)) (-15 -3972 ((-820 |#1|) $)) (-15 -1837 (|#1| $)) (-15 -1866 ($ $)) (-15 -3200 ((-923) $)) (-15 -3763 ((-121) $ $)) (-15 -4076 ($ $)) (-15 -1651 ($ $)) (-15 -1804 ((-121) $)) (-15 -1862 ($ $)) (-15 -2199 ((-638 |#1|) $)))) (-848)) (T -672)) 
-((* (*1 *1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-820 *3)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) (-1837 (*1 *2 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) (-1866 (*1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) (-3200 (*1 *2 *1) (-12 (-5 *2 (-923)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) (-3763 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) (-4076 (*1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) (-1651 (*1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) (-1804 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) (-1862 (*1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) (-2199 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-672 *3)) (-4 *3 (-848))))) 
-(-13 (-848) (-1044 |#1|) (-10 -8 (-15 * ($ $ $)) (-15 -3972 ((-820 |#1|) $)) (-15 -1837 (|#1| $)) (-15 -1866 ($ $)) (-15 -3200 ((-923) $)) (-15 -3763 ((-121) $ $)) (-15 -4076 ($ $)) (-15 -1651 ($ $)) (-15 -1804 ((-121) $)) (-15 -1862 ($ $)) (-15 -2199 ((-638 |#1|) $)))) 
-((-1861 (((-638 |#4|) |#4| (-638 (-923))) 72) (((-638 |#4|) |#4| (-923)) 62)) (-2113 ((|#4| (-638 |#4|)) 59)) (-4152 ((|#4| |#4| (-1092 (-923)) (-1092 (-923))) 57) ((|#4| |#4| (-638 (-923)) (-638 (-923))) 54)) (-3682 ((|#4| |#4| (-1092 (-923))) 31) ((|#4| |#4| (-638 (-923))) 30)) (-1892 (((-638 |#4|) |#4| (-638 (-923))) 74) (((-638 |#4|) |#4| (-923)) 73)) (-1865 ((|#4| (-638 |#4|)) 58)) (-1913 ((|#4| |#4| (-923) (-923)) 20)) (-3132 ((|#4| |#4|) 45) ((|#4| |#4| (-572)) 44)) (-1925 ((|#4| |#4| (-1092 (-923))) 37) ((|#4| |#4| (-638 (-923))) 36)) (-3449 (((-638 (-638 |#4|)) |#4| (-638 (-923)) (-638 (-923))) 78) (((-638 (-638 |#4|)) |#4| (-923) (-638 (-923))) 77) (((-638 (-638 |#4|)) |#4| (-638 (-923)) (-923)) 76) (((-638 (-638 |#4|)) |#4| (-923) (-923)) 75)) (-3509 ((|#4| (-638 (-638 |#4|))) 53)) (-3544 ((|#4| |#4| (-1092 (-572))) 51) ((|#4| |#4| (-638 (-572))) 48)) (-3572 ((|#4| |#4| (-923)) 24)) (-3593 ((|#4| |#4| (-923)) 34))) 
-(((-673 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1913 (|#4| |#4| (-923) (-923))) (-15 -3572 (|#4| |#4| (-923))) (-15 -3682 (|#4| |#4| (-638 (-923)))) (-15 -3682 (|#4| |#4| (-1092 (-923)))) (-15 -3593 (|#4| |#4| (-923))) (-15 -1925 (|#4| |#4| (-638 (-923)))) (-15 -1925 (|#4| |#4| (-1092 (-923)))) (-15 -4152 (|#4| |#4| (-638 (-923)) (-638 (-923)))) (-15 -4152 (|#4| |#4| (-1092 (-923)) (-1092 (-923)))) (-15 -3132 (|#4| |#4| (-572))) (-15 -3132 (|#4| |#4|)) (-15 -3544 (|#4| |#4| (-638 (-572)))) (-15 -3544 (|#4| |#4| (-1092 (-572)))) (-15 -1865 (|#4| (-638 |#4|))) (-15 -2113 (|#4| (-638 |#4|))) (-15 -3509 (|#4| (-638 (-638 |#4|)))) (-15 -1861 ((-638 |#4|) |#4| (-923))) (-15 -1861 ((-638 |#4|) |#4| (-638 (-923)))) (-15 -1892 ((-638 |#4|) |#4| (-923))) (-15 -1892 ((-638 |#4|) |#4| (-638 (-923)))) (-15 -3449 ((-638 (-638 |#4|)) |#4| (-923) (-923))) (-15 -3449 ((-638 (-638 |#4|)) |#4| (-638 (-923)) (-923))) (-15 -3449 ((-638 (-638 |#4|)) |#4| (-923) (-638 (-923)))) (-15 -3449 ((-638 (-638 |#4|)) |#4| (-638 (-923)) (-638 (-923))))) (-368) (-379 |#1|) (-379 |#1|) (-683 |#1| |#2| |#3|)) (T -673)) 
-((-3449 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-638 (-923))) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) (-3449 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-638 (-923))) (-5 *4 (-923)) (-4 *6 (-368)) (-4 *7 (-379 *6)) (-4 *8 (-379 *6)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-673 *6 *7 *8 *3)) (-4 *3 (-683 *6 *7 *8)))) (-3449 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-923))) (-5 *5 (-923)) (-4 *6 (-368)) (-4 *7 (-379 *6)) (-4 *8 (-379 *6)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-673 *6 *7 *8 *3)) (-4 *3 (-683 *6 *7 *8)))) (-3449 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) (-1892 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-923))) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 *3)) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) (-1892 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 *3)) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) (-1861 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-923))) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 *3)) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) (-1861 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 *3)) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) (-3509 (*1 *2 *3) (-12 (-5 *3 (-638 (-638 *2))) (-4 *4 (-368)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)))) (-2113 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *4 (-368)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)))) (-1865 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *4 (-368)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)))) (-3544 (*1 *2 *2 *3) (-12 (-5 *3 (-1092 (-572))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-3544 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-572))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-3132 (*1 *2 *2) (-12 (-4 *3 (-368)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-673 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-3132 (*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-4152 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-1092 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-4152 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-638 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-1925 (*1 *2 *2 *3) (-12 (-5 *3 (-1092 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-1925 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-3593 (*1 *2 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-3682 (*1 *2 *2 *3) (-12 (-5 *3 (-1092 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-3682 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-3572 (*1 *2 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-1913 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-923)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6))))) 
-(-10 -7 (-15 -1913 (|#4| |#4| (-923) (-923))) (-15 -3572 (|#4| |#4| (-923))) (-15 -3682 (|#4| |#4| (-638 (-923)))) (-15 -3682 (|#4| |#4| (-1092 (-923)))) (-15 -3593 (|#4| |#4| (-923))) (-15 -1925 (|#4| |#4| (-638 (-923)))) (-15 -1925 (|#4| |#4| (-1092 (-923)))) (-15 -4152 (|#4| |#4| (-638 (-923)) (-638 (-923)))) (-15 -4152 (|#4| |#4| (-1092 (-923)) (-1092 (-923)))) (-15 -3132 (|#4| |#4| (-572))) (-15 -3132 (|#4| |#4|)) (-15 -3544 (|#4| |#4| (-638 (-572)))) (-15 -3544 (|#4| |#4| (-1092 (-572)))) (-15 -1865 (|#4| (-638 |#4|))) (-15 -2113 (|#4| (-638 |#4|))) (-15 -3509 (|#4| (-638 (-638 |#4|)))) (-15 -1861 ((-638 |#4|) |#4| (-923))) (-15 -1861 ((-638 |#4|) |#4| (-638 (-923)))) (-15 -1892 ((-638 |#4|) |#4| (-923))) (-15 -1892 ((-638 |#4|) |#4| (-638 (-923)))) (-15 -3449 ((-638 (-638 |#4|)) |#4| (-923) (-923))) (-15 -3449 ((-638 (-638 |#4|)) |#4| (-638 (-923)) (-923))) (-15 -3449 ((-638 (-638 |#4|)) |#4| (-923) (-638 (-923)))) (-15 -3449 ((-638 (-638 |#4|)) |#4| (-638 (-923)) (-638 (-923))))) 
-((-3952 ((|#1| (-1 |#1| (-769) |#1|) (-769) |#1|) 11)) (-3621 ((|#1| (-1 |#1| |#1|) (-769) |#1|) 9))) 
-(((-674 |#1|) (-10 -7 (-15 -3621 (|#1| (-1 |#1| |#1|) (-769) |#1|)) (-15 -3952 (|#1| (-1 |#1| (-769) |#1|) (-769) |#1|))) (-1098)) (T -674)) 
-((-3952 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 (-769) *2)) (-5 *4 (-769)) (-4 *2 (-1098)) (-5 *1 (-674 *2)))) (-3621 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *2)) (-5 *4 (-769)) (-4 *2 (-1098)) (-5 *1 (-674 *2))))) 
-(-10 -7 (-15 -3621 (|#1| (-1 |#1| |#1|) (-769) |#1|)) (-15 -3952 (|#1| (-1 |#1| (-769) |#1|) (-769) |#1|))) 
-((-2351 ((|#2| |#1| |#2|) 9)) (-2342 ((|#1| |#1| |#2|) 8))) 
-(((-675 |#1| |#2|) (-10 -7 (-15 -2342 (|#1| |#1| |#2|)) (-15 -2351 (|#2| |#1| |#2|))) (-1098) (-1098)) (T -675)) 
-((-2351 (*1 *2 *3 *2) (-12 (-5 *1 (-675 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098)))) (-2342 (*1 *2 *2 *3) (-12 (-5 *1 (-675 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098))))) 
-(-10 -7 (-15 -2342 (|#1| |#1| |#2|)) (-15 -2351 (|#2| |#1| |#2|))) 
-((-3052 ((|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|) 11))) 
-(((-676 |#1| |#2| |#3|) (-10 -7 (-15 -3052 (|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|))) (-1098) (-1098) (-1098)) (T -676)) 
-((-3052 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)) (-5 *1 (-676 *5 *6 *2))))) 
-(-10 -7 (-15 -3052 (|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|))) 
-((-3952 (((-1 |#1| (-769) |#1|) (-1 |#1| (-769) |#1|)) 23)) (-2998 (((-1 |#1|) |#1|) 8)) (-4004 ((|#1| |#1|) 16)) (-1891 (((-638 |#1|) (-1 (-638 |#1|) (-638 |#1|)) (-572)) 15) ((|#1| (-1 |#1| |#1|)) 11)) (-3972 (((-1 |#1|) |#1|) 9)) (** (((-1 |#1| |#1|) (-1 |#1| |#1|) (-769)) 20))) 
-(((-677 |#1|) (-10 -7 (-15 -2998 ((-1 |#1|) |#1|)) (-15 -3972 ((-1 |#1|) |#1|)) (-15 -1891 (|#1| (-1 |#1| |#1|))) (-15 -1891 ((-638 |#1|) (-1 (-638 |#1|) (-638 |#1|)) (-572))) (-15 -4004 (|#1| |#1|)) (-15 ** ((-1 |#1| |#1|) (-1 |#1| |#1|) (-769))) (-15 -3952 ((-1 |#1| (-769) |#1|) (-1 |#1| (-769) |#1|)))) (-1098)) (T -677)) 
-((-3952 (*1 *2 *2) (-12 (-5 *2 (-1 *3 (-769) *3)) (-4 *3 (-1098)) (-5 *1 (-677 *3)))) (** (*1 *2 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-769)) (-4 *4 (-1098)) (-5 *1 (-677 *4)))) (-4004 (*1 *2 *2) (-12 (-5 *1 (-677 *2)) (-4 *2 (-1098)))) (-1891 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-638 *5) (-638 *5))) (-5 *4 (-572)) (-5 *2 (-638 *5)) (-5 *1 (-677 *5)) (-4 *5 (-1098)))) (-1891 (*1 *2 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-677 *2)) (-4 *2 (-1098)))) (-3972 (*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-677 *3)) (-4 *3 (-1098)))) (-2998 (*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-677 *3)) (-4 *3 (-1098))))) 
-(-10 -7 (-15 -2998 ((-1 |#1|) |#1|)) (-15 -3972 ((-1 |#1|) |#1|)) (-15 -1891 (|#1| (-1 |#1| |#1|))) (-15 -1891 ((-638 |#1|) (-1 (-638 |#1|) (-638 |#1|)) (-572))) (-15 -4004 (|#1| |#1|)) (-15 ** ((-1 |#1| |#1|) (-1 |#1| |#1|) (-769))) (-15 -3952 ((-1 |#1| (-769) |#1|) (-1 |#1| (-769) |#1|)))) 
-((-3574 (((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)) 16)) (-3298 (((-1 |#2|) (-1 |#2| |#1|) |#1|) 13)) (-3211 (((-1 |#2| |#1|) (-1 |#2|)) 14)) (-3631 (((-1 |#2| |#1|) |#2|) 11))) 
-(((-678 |#1| |#2|) (-10 -7 (-15 -3631 ((-1 |#2| |#1|) |#2|)) (-15 -3298 ((-1 |#2|) (-1 |#2| |#1|) |#1|)) (-15 -3211 ((-1 |#2| |#1|) (-1 |#2|))) (-15 -3574 ((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)))) (-1098) (-1098)) (T -678)) 
-((-3574 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *4 *4)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-5 *2 (-1 *5 *4)) (-5 *1 (-678 *4 *5)))) (-3211 (*1 *2 *3) (-12 (-5 *3 (-1 *5)) (-4 *5 (-1098)) (-5 *2 (-1 *5 *4)) (-5 *1 (-678 *4 *5)) (-4 *4 (-1098)))) (-3298 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *4)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-5 *2 (-1 *5)) (-5 *1 (-678 *4 *5)))) (-3631 (*1 *2 *3) (-12 (-5 *2 (-1 *3 *4)) (-5 *1 (-678 *4 *3)) (-4 *4 (-1098)) (-4 *3 (-1098))))) 
-(-10 -7 (-15 -3631 ((-1 |#2| |#1|) |#2|)) (-15 -3298 ((-1 |#2|) (-1 |#2| |#1|) |#1|)) (-15 -3211 ((-1 |#2| |#1|) (-1 |#2|))) (-15 -3574 ((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)))) 
-((-3638 (((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|)) 17)) (-1519 (((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|) 11)) (-2781 (((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|) 13)) (-3510 (((-1 |#3| |#1| |#2|) (-1 |#3| |#1|)) 14)) (-2448 (((-1 |#3| |#1| |#2|) (-1 |#3| |#2|)) 15)) (* (((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)) 21))) 
-(((-679 |#1| |#2| |#3|) (-10 -7 (-15 -1519 ((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|)) (-15 -2781 ((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|)) (-15 -3510 ((-1 |#3| |#1| |#2|) (-1 |#3| |#1|))) (-15 -2448 ((-1 |#3| |#1| |#2|) (-1 |#3| |#2|))) (-15 -3638 ((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|))) (-15 * ((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)))) (-1098) (-1098) (-1098)) (T -679)) 
-((* (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-1 *7 *5)) (-5 *1 (-679 *5 *6 *7)))) (-3638 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *5 *4)) (-5 *1 (-679 *4 *5 *6)))) (-2448 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-679 *4 *5 *6)) (-4 *4 (-1098)))) (-3510 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *4)) (-4 *4 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-679 *4 *5 *6)) (-4 *5 (-1098)))) (-2781 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *5)) (-5 *1 (-679 *4 *5 *6)))) (-1519 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5 *4)) (-4 *5 (-1098)) (-4 *4 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *5)) (-5 *1 (-679 *5 *4 *6))))) 
-(-10 -7 (-15 -1519 ((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|)) (-15 -2781 ((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|)) (-15 -3510 ((-1 |#3| |#1| |#2|) (-1 |#3| |#1|))) (-15 -2448 ((-1 |#3| |#1| |#2|) (-1 |#3| |#2|))) (-15 -3638 ((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|))) (-15 * ((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)))) 
-((-1379 (((-1 (-312 (-572)) |#1|) (-1 (-312 (-572)) |#1|) (-1 (-312 (-572)) |#1|)) 18)) (-1373 (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 12)) (-1367 (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 10)) (* (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 14))) 
-(((-680 |#1| |#2|) (-10 -7 (-15 -1367 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1373 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 * ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1379 ((-1 (-312 (-572)) |#1|) (-1 (-312 (-572)) |#1|) (-1 (-312 (-572)) |#1|)))) (-1098) (-1054)) (T -680)) 
-((-1379 (*1 *2 *2 *2) (-12 (-5 *2 (-1 (-312 (-572)) *3)) (-4 *3 (-1098)) (-5 *1 (-680 *3 *4)) (-4 *4 (-1054)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1098)) (-4 *4 (-1054)) (-5 *1 (-680 *3 *4)))) (-1373 (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1098)) (-4 *4 (-1054)) (-5 *1 (-680 *3 *4)))) (-1367 (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1098)) (-4 *4 (-1054)) (-5 *1 (-680 *3 *4))))) 
-(-10 -7 (-15 -1367 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1373 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 * ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1379 ((-1 (-312 (-572)) |#1|) (-1 (-312 (-572)) |#1|) (-1 (-312 (-572)) |#1|)))) 
-((-3116 ((|#5| (-1 |#5| |#1| |#5|) |#4| |#5|) 39)) (-3828 (((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|) 37) ((|#8| (-1 |#5| |#1|) |#4|) 31))) 
-(((-681 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -3828 (|#8| (-1 |#5| |#1|) |#4|)) (-15 -3828 ((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|)) (-15 -3116 (|#5| (-1 |#5| |#1| |#5|) |#4| |#5|))) (-1054) (-379 |#1|) (-379 |#1|) (-683 |#1| |#2| |#3|) (-1054) (-379 |#5|) (-379 |#5|) (-683 |#5| |#6| |#7|)) (T -681)) 
-((-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1054)) (-4 *2 (-1054)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-4 *8 (-379 *2)) (-4 *9 (-379 *2)) (-5 *1 (-681 *5 *6 *7 *4 *2 *8 *9 *10)) (-4 *4 (-683 *5 *6 *7)) (-4 *10 (-683 *2 *8 *9)))) (-3828 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *8 "failed") *5)) (-4 *5 (-1054)) (-4 *8 (-1054)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-4 *2 (-683 *8 *9 *10)) (-5 *1 (-681 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-683 *5 *6 *7)) (-4 *9 (-379 *8)) (-4 *10 (-379 *8)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1054)) (-4 *8 (-1054)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-4 *2 (-683 *8 *9 *10)) (-5 *1 (-681 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-683 *5 *6 *7)) (-4 *9 (-379 *8)) (-4 *10 (-379 *8))))) 
-(-10 -7 (-15 -3828 (|#8| (-1 |#5| |#1|) |#4|)) (-15 -3828 ((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|)) (-15 -3116 (|#5| (-1 |#5| |#1| |#5|) |#4| |#5|))) 
-((-4169 (($ (-769) (-769)) 31)) (-2113 (($ $ $) 56)) (-1444 (($ |#3|) 52) (($ $) 53)) (-3083 (((-121) $) 26)) (-3861 (($ $ (-572) (-572)) 58)) (-3595 (($ $ (-572) (-572)) 59)) (-4152 (($ $ (-572) (-572) (-572) (-572)) 63)) (-4369 (($ $) 54)) (-4044 (((-121) $) 14)) (-2569 (($ $ (-572) (-572) $) 64)) (-3283 ((|#2| $ (-572) (-572) |#2|) NIL) (($ $ (-638 (-572)) (-638 (-572)) $) 62)) (-1468 (($ (-769) |#2|) 38)) (-4439 ((|#2| $) 107)) (-3597 (($ (-638 (-638 |#2|))) 34) (($ (-769) (-769) (-1 |#2| (-572) (-572))) 36)) (-2259 (((-638 (-638 |#2|)) $) 57)) (-1865 (($ $ $) 55)) (-1803 (((-3 $ "failed") $ |#2|) 110)) (-3277 ((|#2| $ (-572) (-572)) NIL) ((|#2| $ (-572) (-572) |#2|) NIL) (($ $ (-638 (-572)) (-638 (-572))) 61)) (-3132 (($ (-638 |#2|)) 40) (($ (-638 $)) 42)) (-3785 (((-121) $) 23)) (-1802 (((-638 |#4|) $) 93)) (-3972 (((-856) $) NIL) (($ |#4|) 47)) (-3354 (((-121) $) 28)) (-1379 (($ $ |#2|) 112)) (-1373 (($ $ $) 68) (($ $) 71)) (-1367 (($ $ $) 66)) (** (($ $ (-769)) 80) (($ $ (-572)) 115)) (* (($ $ $) 77) (($ |#2| $) 73) (($ $ |#2|) 74) (($ (-572) $) 76) ((|#4| $ |#4|) 84) ((|#3| |#3| $) 88))) 
-(((-682 |#1| |#2| |#3| |#4|) (-10 -8 (-15 ** (|#1| |#1| (-572))) (-15 -4439 (|#2| |#1|)) (-15 -1802 ((-638 |#4|) |#1|)) (-15 -1379 (|#1| |#1| |#2|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#2|)) (-15 ** (|#1| |#1| (-769))) (-15 * (|#3| |#3| |#1|)) (-15 * (|#4| |#1| |#4|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1367 (|#1| |#1| |#1|)) (-15 -2569 (|#1| |#1| (-572) (-572) |#1|)) (-15 -4152 (|#1| |#1| (-572) (-572) (-572) (-572))) (-15 -3595 (|#1| |#1| (-572) (-572))) (-15 -3861 (|#1| |#1| (-572) (-572))) (-15 -3283 (|#1| |#1| (-638 (-572)) (-638 (-572)) |#1|)) (-15 -3277 (|#1| |#1| (-638 (-572)) (-638 (-572)))) (-15 -2259 ((-638 (-638 |#2|)) |#1|)) (-15 -2113 (|#1| |#1| |#1|)) (-15 -1865 (|#1| |#1| |#1|)) (-15 -4369 (|#1| |#1|)) (-15 -1444 (|#1| |#1|)) (-15 -1444 (|#1| |#3|)) (-15 -3972 (|#1| |#4|)) (-15 -3132 (|#1| (-638 |#1|))) (-15 -3132 (|#1| (-638 |#2|))) (-15 -1468 (|#1| (-769) |#2|)) (-15 -3597 (|#1| (-769) (-769) (-1 |#2| (-572) (-572)))) (-15 -3597 (|#1| (-638 (-638 |#2|)))) (-15 -4169 (|#1| (-769) (-769))) (-15 -3354 ((-121) |#1|)) (-15 -3083 ((-121) |#1|)) (-15 -3785 ((-121) |#1|)) (-15 -4044 ((-121) |#1|)) (-15 -3283 (|#2| |#1| (-572) (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572) (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572) (-572))) (-15 -3972 ((-856) |#1|))) (-683 |#2| |#3| |#4|) (-1054) (-379 |#2|) (-379 |#2|)) (T -682)) 
-NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-572))) (-15 -4439 (|#2| |#1|)) (-15 -1802 ((-638 |#4|) |#1|)) (-15 -1379 (|#1| |#1| |#2|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#2|)) (-15 ** (|#1| |#1| (-769))) (-15 * (|#3| |#3| |#1|)) (-15 * (|#4| |#1| |#4|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1367 (|#1| |#1| |#1|)) (-15 -2569 (|#1| |#1| (-572) (-572) |#1|)) (-15 -4152 (|#1| |#1| (-572) (-572) (-572) (-572))) (-15 -3595 (|#1| |#1| (-572) (-572))) (-15 -3861 (|#1| |#1| (-572) (-572))) (-15 -3283 (|#1| |#1| (-638 (-572)) (-638 (-572)) |#1|)) (-15 -3277 (|#1| |#1| (-638 (-572)) (-638 (-572)))) (-15 -2259 ((-638 (-638 |#2|)) |#1|)) (-15 -2113 (|#1| |#1| |#1|)) (-15 -1865 (|#1| |#1| |#1|)) (-15 -4369 (|#1| |#1|)) (-15 -1444 (|#1| |#1|)) (-15 -1444 (|#1| |#3|)) (-15 -3972 (|#1| |#4|)) (-15 -3132 (|#1| (-638 |#1|))) (-15 -3132 (|#1| (-638 |#2|))) (-15 -1468 (|#1| (-769) |#2|)) (-15 -3597 (|#1| (-769) (-769) (-1 |#2| (-572) (-572)))) (-15 -3597 (|#1| (-638 (-638 |#2|)))) (-15 -4169 (|#1| (-769) (-769))) (-15 -3354 ((-121) |#1|)) (-15 -3083 ((-121) |#1|)) (-15 -3785 ((-121) |#1|)) (-15 -4044 ((-121) |#1|)) (-15 -3283 (|#2| |#1| (-572) (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572) (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572) (-572))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-4169 (($ (-769) (-769)) 95)) (-2113 (($ $ $) 84)) (-1444 (($ |#2|) 88) (($ $) 87)) (-3083 (((-121) $) 97)) (-3861 (($ $ (-572) (-572)) 80)) (-3595 (($ $ (-572) (-572)) 79)) (-4152 (($ $ (-572) (-572) (-572) (-572)) 78)) (-4369 (($ $) 86)) (-4044 (((-121) $) 99)) (-1946 (((-121) $ (-769)) 8)) (-2569 (($ $ (-572) (-572) $) 77)) (-3283 ((|#1| $ (-572) (-572) |#1|) 41) (($ $ (-638 (-572)) (-638 (-572)) $) 81)) (-1823 (($ $ (-572) |#2|) 39)) (-1695 (($ $ (-572) |#3|) 38)) (-1468 (($ (-769) |#1|) 92)) (-2211 (($) 7 T CONST)) (-3292 (($ $) 64 (|has| |#1| (-303)))) (-4267 ((|#2| $ (-572)) 43)) (-2667 (((-769) $) 62 (|has| |#1| (-562)))) (-3037 ((|#1| $ (-572) (-572) |#1|) 40)) (-4212 ((|#1| $ (-572) (-572)) 45)) (-4439 ((|#1| $) 57 (|has| |#1| (-174)))) (-2010 (((-638 |#1|) $) 30)) (-3095 (((-769) $) 61 (|has| |#1| (-562)))) (-1301 (((-638 |#3|) $) 60 (|has| |#1| (-562)))) (-3704 (((-769) $) 48)) (-1364 (($ (-769) (-769) |#1|) 54)) (-3712 (((-769) $) 47)) (-2157 (((-121) $ (-769)) 9)) (-1522 ((|#1| $) 58 (|has| |#1| (-6 (-4604 "*"))))) (-2660 (((-572) $) 52)) (-3092 (((-572) $) 50)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3927 (((-572) $) 51)) (-3227 (((-572) $) 49)) (-3597 (($ (-638 (-638 |#1|))) 94) (($ (-769) (-769) (-1 |#1| (-572) (-572))) 93)) (-2435 (($ (-1 |#1| |#1|) $) 34)) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 37) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) 36)) (-2259 (((-638 (-638 |#1|)) $) 83)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-3750 (((-3 $ "failed") $) 56 (|has| |#1| (-368)))) (-1865 (($ $ $) 85)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-3299 (($ $ |#1|) 53)) (-1803 (((-3 $ "failed") $ |#1|) 66 (|has| |#1| (-562)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ (-572) (-572)) 46) ((|#1| $ (-572) (-572) |#1|) 44) (($ $ (-638 (-572)) (-638 (-572))) 82)) (-3132 (($ (-638 |#1|)) 91) (($ (-638 $)) 90)) (-3785 (((-121) $) 98)) (-2271 ((|#1| $) 59 (|has| |#1| (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-1802 (((-638 |#3|) $) 63 (|has| |#1| (-303)))) (-4580 ((|#3| $ (-572)) 42)) (-3972 (((-856) $) 20 (|has| |#1| (-1098))) (($ |#3|) 89)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-3354 (((-121) $) 96)) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-1379 (($ $ |#1|) 65 (|has| |#1| (-368)))) (-1373 (($ $ $) 75) (($ $) 74)) (-1367 (($ $ $) 76)) (** (($ $ (-769)) 67) (($ $ (-572)) 55 (|has| |#1| (-368)))) (* (($ $ $) 73) (($ |#1| $) 72) (($ $ |#1|) 71) (($ (-572) $) 70) ((|#3| $ |#3|) 69) ((|#2| |#2| $) 68)) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-683 |#1| |#2| |#3|) (-1290) (-1054) (-379 |t#1|) (-379 |t#1|)) (T -683)) 
-((-4044 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-121)))) (-3785 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-121)))) (-3083 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-121)))) (-3354 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-121)))) (-4169 (*1 *1 *2 *2) (-12 (-5 *2 (-769)) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3597 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3597 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-1 *4 (-572) (-572))) (-4 *4 (-1054)) (-4 *1 (-683 *4 *5 *6)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)))) (-1468 (*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3132 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3132 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3972 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *2)) (-4 *4 (-379 *3)) (-4 *2 (-379 *3)))) (-1444 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *1 (-683 *3 *2 *4)) (-4 *2 (-379 *3)) (-4 *4 (-379 *3)))) (-1444 (*1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (-4369 (*1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (-1865 (*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (-2113 (*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (-2259 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-638 (-638 *3))))) (-3277 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-638 (-572))) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3283 (*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-638 (-572))) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3861 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-3595 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-4152 (*1 *1 *1 *2 *2 *2 *2) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-2569 (*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-1367 (*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (-1373 (*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (-1373 (*1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (* (*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (* (*1 *2 *1 *2) (-12 (-4 *1 (-683 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *2 (-379 *3)))) (* (*1 *2 *2 *1) (-12 (-4 *1 (-683 *3 *2 *4)) (-4 *3 (-1054)) (-4 *2 (-379 *3)) (-4 *4 (-379 *3)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) (-1803 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-562)))) (-1379 (*1 *1 *1 *2) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-368)))) (-3292 (*1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-303)))) (-1802 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-303)) (-5 *2 (-638 *5)))) (-2667 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-562)) (-5 *2 (-769)))) (-3095 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-562)) (-5 *2 (-769)))) (-1301 (*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-562)) (-5 *2 (-638 *5)))) (-2271 (*1 *2 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (|has| *2 (-6 (-4604 "*"))) (-4 *2 (-1054)))) (-1522 (*1 *2 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (|has| *2 (-6 (-4604 "*"))) (-4 *2 (-1054)))) (-4439 (*1 *2 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-1054)) (-4 *2 (-174)))) (-3750 (*1 *1 *1) (|partial| -12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-368)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-368))))) 
-(-13 (-62 |t#1| |t#2| |t#3|) (-10 -8 (-6 -4603) (-6 -4602) (-15 -4044 ((-121) $)) (-15 -3785 ((-121) $)) (-15 -3083 ((-121) $)) (-15 -3354 ((-121) $)) (-15 -4169 ($ (-769) (-769))) (-15 -3597 ($ (-638 (-638 |t#1|)))) (-15 -3597 ($ (-769) (-769) (-1 |t#1| (-572) (-572)))) (-15 -1468 ($ (-769) |t#1|)) (-15 -3132 ($ (-638 |t#1|))) (-15 -3132 ($ (-638 $))) (-15 -3972 ($ |t#3|)) (-15 -1444 ($ |t#2|)) (-15 -1444 ($ $)) (-15 -4369 ($ $)) (-15 -1865 ($ $ $)) (-15 -2113 ($ $ $)) (-15 -2259 ((-638 (-638 |t#1|)) $)) (-15 -3277 ($ $ (-638 (-572)) (-638 (-572)))) (-15 -3283 ($ $ (-638 (-572)) (-638 (-572)) $)) (-15 -3861 ($ $ (-572) (-572))) (-15 -3595 ($ $ (-572) (-572))) (-15 -4152 ($ $ (-572) (-572) (-572) (-572))) (-15 -2569 ($ $ (-572) (-572) $)) (-15 -1367 ($ $ $)) (-15 -1373 ($ $ $)) (-15 -1373 ($ $)) (-15 * ($ $ $)) (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|)) (-15 * ($ (-572) $)) (-15 * (|t#3| $ |t#3|)) (-15 * (|t#2| |t#2| $)) (-15 ** ($ $ (-769))) (IF (|has| |t#1| (-562)) (-15 -1803 ((-3 $ "failed") $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-368)) (-15 -1379 ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-303)) (PROGN (-15 -3292 ($ $)) (-15 -1802 ((-638 |t#3|) $))) |noBranch|) (IF (|has| |t#1| (-562)) (PROGN (-15 -2667 ((-769) $)) (-15 -3095 ((-769) $)) (-15 -1301 ((-638 |t#3|) $))) |noBranch|) (IF (|has| |t#1| (-6 (-4604 "*"))) (PROGN (-15 -2271 (|t#1| $)) (-15 -1522 (|t#1| $))) |noBranch|) (IF (|has| |t#1| (-174)) (-15 -4439 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-368)) (PROGN (-15 -3750 ((-3 $ "failed") $)) (-15 ** ($ $ (-572)))) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-62 |#1| |#2| |#3|) . T) ((-1204) . T)) 
-((-3292 ((|#4| |#4|) 67 (|has| |#1| (-303)))) (-2667 (((-769) |#4|) 69 (|has| |#1| (-562)))) (-3095 (((-769) |#4|) 71 (|has| |#1| (-562)))) (-1301 (((-638 |#3|) |#4|) 78 (|has| |#1| (-562)))) (-4145 (((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|) 95 (|has| |#1| (-303)))) (-1522 ((|#1| |#4|) 33)) (-4307 (((-3 |#4| "failed") |#4|) 61 (|has| |#1| (-562)))) (-3750 (((-3 |#4| "failed") |#4|) 75 (|has| |#1| (-368)))) (-3528 ((|#4| |#4|) 54 (|has| |#1| (-562)))) (-2473 ((|#4| |#4| |#1| (-572) (-572)) 41)) (-3011 ((|#4| |#4| (-572) (-572)) 36)) (-1762 ((|#4| |#4| |#1| (-572) (-572)) 46)) (-2271 ((|#1| |#4|) 73)) (-2527 (((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|) 57 (|has| |#1| (-562))))) 
-(((-684 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2271 (|#1| |#4|)) (-15 -1522 (|#1| |#4|)) (-15 -3011 (|#4| |#4| (-572) (-572))) (-15 -2473 (|#4| |#4| |#1| (-572) (-572))) (-15 -1762 (|#4| |#4| |#1| (-572) (-572))) (IF (|has| |#1| (-562)) (PROGN (-15 -2667 ((-769) |#4|)) (-15 -3095 ((-769) |#4|)) (-15 -1301 ((-638 |#3|) |#4|)) (-15 -3528 (|#4| |#4|)) (-15 -4307 ((-3 |#4| "failed") |#4|)) (-15 -2527 ((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|))) |noBranch|) (IF (|has| |#1| (-303)) (PROGN (-15 -3292 (|#4| |#4|)) (-15 -4145 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-368)) (-15 -3750 ((-3 |#4| "failed") |#4|)) |noBranch|)) (-174) (-379 |#1|) (-379 |#1|) (-683 |#1| |#2| |#3|)) (T -684)) 
-((-3750 (*1 *2 *2) (|partial| -12 (-4 *3 (-368)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-684 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-4145 (*1 *2 *3 *3) (-12 (-4 *3 (-303)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-684 *3 *4 *5 *6)) (-4 *6 (-683 *3 *4 *5)))) (-3292 (*1 *2 *2) (-12 (-4 *3 (-303)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-684 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-2527 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-2 (|:| |adjMat| *3) (|:| |detMat| *4))) (-5 *1 (-684 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-4307 (*1 *2 *2) (|partial| -12 (-4 *3 (-562)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-684 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-3528 (*1 *2 *2) (-12 (-4 *3 (-562)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-684 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-1301 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-638 *6)) (-5 *1 (-684 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-3095 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-769)) (-5 *1 (-684 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-2667 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-769)) (-5 *1 (-684 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-1762 (*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-572)) (-4 *3 (-174)) (-4 *5 (-379 *3)) (-4 *6 (-379 *3)) (-5 *1 (-684 *3 *5 *6 *2)) (-4 *2 (-683 *3 *5 *6)))) (-2473 (*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-572)) (-4 *3 (-174)) (-4 *5 (-379 *3)) (-4 *6 (-379 *3)) (-5 *1 (-684 *3 *5 *6 *2)) (-4 *2 (-683 *3 *5 *6)))) (-3011 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-572)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-684 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) (-1522 (*1 *2 *3) (-12 (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-174)) (-5 *1 (-684 *2 *4 *5 *3)) (-4 *3 (-683 *2 *4 *5)))) (-2271 (*1 *2 *3) (-12 (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-174)) (-5 *1 (-684 *2 *4 *5 *3)) (-4 *3 (-683 *2 *4 *5))))) 
-(-10 -7 (-15 -2271 (|#1| |#4|)) (-15 -1522 (|#1| |#4|)) (-15 -3011 (|#4| |#4| (-572) (-572))) (-15 -2473 (|#4| |#4| |#1| (-572) (-572))) (-15 -1762 (|#4| |#4| |#1| (-572) (-572))) (IF (|has| |#1| (-562)) (PROGN (-15 -2667 ((-769) |#4|)) (-15 -3095 ((-769) |#4|)) (-15 -1301 ((-638 |#3|) |#4|)) (-15 -3528 (|#4| |#4|)) (-15 -4307 ((-3 |#4| "failed") |#4|)) (-15 -2527 ((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|))) |noBranch|) (IF (|has| |#1| (-303)) (PROGN (-15 -3292 (|#4| |#4|)) (-15 -4145 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-368)) (-15 -3750 ((-3 |#4| "failed") |#4|)) |noBranch|)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4169 (($ (-769) (-769)) 45)) (-2113 (($ $ $) NIL)) (-1444 (($ (-1259 |#1|)) NIL) (($ $) NIL)) (-3083 (((-121) $) NIL)) (-3861 (($ $ (-572) (-572)) 12)) (-3595 (($ $ (-572) (-572)) NIL)) (-4152 (($ $ (-572) (-572) (-572) (-572)) NIL)) (-4369 (($ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2569 (($ $ (-572) (-572) $) NIL)) (-3283 ((|#1| $ (-572) (-572) |#1|) NIL) (($ $ (-638 (-572)) (-638 (-572)) $) NIL)) (-1823 (($ $ (-572) (-1259 |#1|)) NIL)) (-1695 (($ $ (-572) (-1259 |#1|)) NIL)) (-1468 (($ (-769) |#1|) 22)) (-2211 (($) NIL T CONST)) (-3292 (($ $) 30 (|has| |#1| (-303)))) (-4267 (((-1259 |#1|) $ (-572)) NIL)) (-2667 (((-769) $) 32 (|has| |#1| (-562)))) (-3037 ((|#1| $ (-572) (-572) |#1|) 50)) (-4212 ((|#1| $ (-572) (-572)) NIL)) (-4439 ((|#1| $) NIL (|has| |#1| (-174)))) (-2010 (((-638 |#1|) $) NIL)) (-3095 (((-769) $) 34 (|has| |#1| (-562)))) (-1301 (((-638 (-1259 |#1|)) $) 37 (|has| |#1| (-562)))) (-3704 (((-769) $) 20)) (-1364 (($ (-769) (-769) |#1|) NIL)) (-3712 (((-769) $) 21)) (-2157 (((-121) $ (-769)) NIL)) (-1522 ((|#1| $) 28 (|has| |#1| (-6 (-4604 "*"))))) (-2660 (((-572) $) 9)) (-3092 (((-572) $) 10)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3927 (((-572) $) 11)) (-3227 (((-572) $) 46)) (-3597 (($ (-638 (-638 |#1|))) NIL) (($ (-769) (-769) (-1 |#1| (-572) (-572))) NIL)) (-2435 (($ (-1 |#1| |#1|) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2259 (((-638 (-638 |#1|)) $) 58)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-3750 (((-3 $ "failed") $) 41 (|has| |#1| (-368)))) (-1865 (($ $ $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3299 (($ $ |#1|) NIL)) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) (-572)) NIL) ((|#1| $ (-572) (-572) |#1|) NIL) (($ $ (-638 (-572)) (-638 (-572))) NIL)) (-3132 (($ (-638 |#1|)) NIL) (($ (-638 $)) NIL) (($ (-1259 |#1|)) 51)) (-3785 (((-121) $) NIL)) (-2271 ((|#1| $) 26 (|has| |#1| (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-4081 (((-545) $) 62 (|has| |#1| (-613 (-545))))) (-1802 (((-638 (-1259 |#1|)) $) NIL (|has| |#1| (-303)))) (-4580 (((-1259 |#1|) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098))) (($ (-1259 |#1|)) NIL)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) 23) (($ $ (-572)) 44 (|has| |#1| (-368)))) (* (($ $ $) 13) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-572) $) NIL) (((-1259 |#1|) $ (-1259 |#1|)) NIL) (((-1259 |#1|) (-1259 |#1|) $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-685 |#1|) (-13 (-683 |#1| (-1259 |#1|) (-1259 |#1|)) (-10 -8 (-15 -3132 ($ (-1259 |#1|))) (IF (|has| |#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (IF (|has| |#1| (-368)) (-15 -3750 ((-3 $ "failed") $)) |noBranch|))) (-1054)) (T -685)) 
-((-3750 (*1 *1 *1) (|partial| -12 (-5 *1 (-685 *2)) (-4 *2 (-368)) (-4 *2 (-1054)))) (-3132 (*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-1054)) (-5 *1 (-685 *3))))) 
-(-13 (-683 |#1| (-1259 |#1|) (-1259 |#1|)) (-10 -8 (-15 -3132 ($ (-1259 |#1|))) (IF (|has| |#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (IF (|has| |#1| (-368)) (-15 -3750 ((-3 $ "failed") $)) |noBranch|))) 
-((-4568 (((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|)) 25)) (-2361 (((-685 |#1|) (-685 |#1|) (-685 |#1|) |#1|) 21)) (-4422 (((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|) (-769)) 26)) (-1387 (((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|)) 14)) (-3248 (((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|)) 18) (((-685 |#1|) (-685 |#1|) (-685 |#1|)) 16)) (-1900 (((-685 |#1|) (-685 |#1|) |#1| (-685 |#1|)) 20)) (-3307 (((-685 |#1|) (-685 |#1|) (-685 |#1|)) 12)) (** (((-685 |#1|) (-685 |#1|) (-769)) 30))) 
-(((-686 |#1|) (-10 -7 (-15 -3307 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -1387 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -3248 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -3248 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -1900 ((-685 |#1|) (-685 |#1|) |#1| (-685 |#1|))) (-15 -2361 ((-685 |#1|) (-685 |#1|) (-685 |#1|) |#1|)) (-15 -4568 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -4422 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|) (-769))) (-15 ** ((-685 |#1|) (-685 |#1|) (-769)))) (-1054)) (T -686)) 
-((** (*1 *2 *2 *3) (-12 (-5 *2 (-685 *4)) (-5 *3 (-769)) (-4 *4 (-1054)) (-5 *1 (-686 *4)))) (-4422 (*1 *2 *2 *2 *2 *2 *3) (-12 (-5 *2 (-685 *4)) (-5 *3 (-769)) (-4 *4 (-1054)) (-5 *1 (-686 *4)))) (-4568 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3)))) (-2361 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3)))) (-1900 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3)))) (-3248 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3)))) (-3248 (*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3)))) (-1387 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3)))) (-3307 (*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3))))) 
-(-10 -7 (-15 -3307 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -1387 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -3248 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -3248 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -1900 ((-685 |#1|) (-685 |#1|) |#1| (-685 |#1|))) (-15 -2361 ((-685 |#1|) (-685 |#1|) (-685 |#1|) |#1|)) (-15 -4568 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -4422 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|) (-685 |#1|) (-769))) (-15 ** ((-685 |#1|) (-685 |#1|) (-769)))) 
-((-3907 ((|#2| |#2| |#4|) 25)) (-3441 (((-685 |#2|) |#3| |#4|) 31)) (-3806 (((-685 |#2|) |#2| |#4|) 30)) (-2546 (((-1259 |#2|) |#2| |#4|) 16)) (-3024 ((|#2| |#3| |#4|) 24)) (-2768 (((-685 |#2|) |#3| |#4| (-769) (-769)) 38)) (-3221 (((-685 |#2|) |#2| |#4| (-769)) 37))) 
-(((-687 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2546 ((-1259 |#2|) |#2| |#4|)) (-15 -3024 (|#2| |#3| |#4|)) (-15 -3907 (|#2| |#2| |#4|)) (-15 -3806 ((-685 |#2|) |#2| |#4|)) (-15 -3221 ((-685 |#2|) |#2| |#4| (-769))) (-15 -3441 ((-685 |#2|) |#3| |#4|)) (-15 -2768 ((-685 |#2|) |#3| |#4| (-769) (-769)))) (-1098) (-901 |#1|) (-379 |#2|) (-13 (-379 |#1|) (-10 -7 (-6 -4602)))) (T -687)) 
-((-2768 (*1 *2 *3 *4 *5 *5) (-12 (-5 *5 (-769)) (-4 *6 (-1098)) (-4 *7 (-901 *6)) (-5 *2 (-685 *7)) (-5 *1 (-687 *6 *7 *3 *4)) (-4 *3 (-379 *7)) (-4 *4 (-13 (-379 *6) (-10 -7 (-6 -4602)))))) (-3441 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *6 (-901 *5)) (-5 *2 (-685 *6)) (-5 *1 (-687 *5 *6 *3 *4)) (-4 *3 (-379 *6)) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4602)))))) (-3221 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-1098)) (-4 *3 (-901 *6)) (-5 *2 (-685 *3)) (-5 *1 (-687 *6 *3 *7 *4)) (-4 *7 (-379 *3)) (-4 *4 (-13 (-379 *6) (-10 -7 (-6 -4602)))))) (-3806 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *3 (-901 *5)) (-5 *2 (-685 *3)) (-5 *1 (-687 *5 *3 *6 *4)) (-4 *6 (-379 *3)) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4602)))))) (-3907 (*1 *2 *2 *3) (-12 (-4 *4 (-1098)) (-4 *2 (-901 *4)) (-5 *1 (-687 *4 *2 *5 *3)) (-4 *5 (-379 *2)) (-4 *3 (-13 (-379 *4) (-10 -7 (-6 -4602)))))) (-3024 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *2 (-901 *5)) (-5 *1 (-687 *5 *2 *3 *4)) (-4 *3 (-379 *2)) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4602)))))) (-2546 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *3 (-901 *5)) (-5 *2 (-1259 *3)) (-5 *1 (-687 *5 *3 *6 *4)) (-4 *6 (-379 *3)) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4602))))))) 
-(-10 -7 (-15 -2546 ((-1259 |#2|) |#2| |#4|)) (-15 -3024 (|#2| |#3| |#4|)) (-15 -3907 (|#2| |#2| |#4|)) (-15 -3806 ((-685 |#2|) |#2| |#4|)) (-15 -3221 ((-685 |#2|) |#2| |#4| (-769))) (-15 -3441 ((-685 |#2|) |#3| |#4|)) (-15 -2768 ((-685 |#2|) |#3| |#4| (-769) (-769)))) 
-((-1518 (((-2 (|:| |num| (-685 |#1|)) (|:| |den| |#1|)) (-685 |#2|)) 18)) (-3559 ((|#1| (-685 |#2|)) 9)) (-1443 (((-685 |#1|) (-685 |#2|)) 16))) 
-(((-688 |#1| |#2|) (-10 -7 (-15 -3559 (|#1| (-685 |#2|))) (-15 -1443 ((-685 |#1|) (-685 |#2|))) (-15 -1518 ((-2 (|:| |num| (-685 |#1|)) (|:| |den| |#1|)) (-685 |#2|)))) (-562) (-1000 |#1|)) (T -688)) 
-((-1518 (*1 *2 *3) (-12 (-5 *3 (-685 *5)) (-4 *5 (-1000 *4)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |num| (-685 *4)) (|:| |den| *4))) (-5 *1 (-688 *4 *5)))) (-1443 (*1 *2 *3) (-12 (-5 *3 (-685 *5)) (-4 *5 (-1000 *4)) (-4 *4 (-562)) (-5 *2 (-685 *4)) (-5 *1 (-688 *4 *5)))) (-3559 (*1 *2 *3) (-12 (-5 *3 (-685 *4)) (-4 *4 (-1000 *2)) (-4 *2 (-562)) (-5 *1 (-688 *2 *4))))) 
-(-10 -7 (-15 -3559 (|#1| (-685 |#2|))) (-15 -1443 ((-685 |#1|) (-685 |#2|))) (-15 -1518 ((-2 (|:| |num| (-685 |#1|)) (|:| |den| |#1|)) (-685 |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1845 (((-685 (-694))) NIL) (((-685 (-694)) (-1259 $)) NIL)) (-3520 (((-694) $) NIL)) (-4284 (($ $) NIL (|has| (-694) (-1190)))) (-4224 (($ $) NIL (|has| (-694) (-1190)))) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| (-694) (-353)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-694) (-303)) (|has| (-694) (-910))))) (-2844 (($ $) NIL (-1841 (-12 (|has| (-694) (-303)) (|has| (-694) (-910))) (|has| (-694) (-368))))) (-1466 (((-424 $) $) NIL (-1841 (-12 (|has| (-694) (-303)) (|has| (-694) (-910))) (|has| (-694) (-368))))) (-4190 (($ $) NIL (-12 (|has| (-694) (-1009)) (|has| (-694) (-1190))))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-694) (-303)) (|has| (-694) (-910))))) (-3112 (((-121) $ $) NIL (|has| (-694) (-303)))) (-1685 (((-769)) NIL (|has| (-694) (-374)))) (-4273 (($ $) NIL (|has| (-694) (-1190)))) (-4217 (($ $) NIL (|has| (-694) (-1190)))) (-4295 (($ $) NIL (|has| (-694) (-1190)))) (-4233 (($ $) NIL (|has| (-694) (-1190)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-694) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-694) (-1044 (-413 (-572)))))) (-1318 (((-572) $) NIL) (((-694) $) NIL) (((-413 (-572)) $) NIL (|has| (-694) (-1044 (-413 (-572)))))) (-4337 (($ (-1259 (-694))) NIL) (($ (-1259 (-694)) (-1259 $)) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-694) (-353)))) (-2190 (($ $ $) NIL (|has| (-694) (-303)))) (-1741 (((-685 (-694)) $) NIL) (((-685 (-694)) $ (-1259 $)) NIL)) (-2284 (((-685 (-694)) (-685 $)) NIL) (((-2 (|:| -1369 (-685 (-694))) (|:| |vec| (-1259 (-694)))) (-685 $) (-1259 $)) NIL) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-694) (-634 (-572)))) (((-685 (-572)) (-685 $)) NIL (|has| (-694) (-634 (-572))))) (-3116 (((-3 $ "failed") (-413 (-1166 (-694)))) NIL (|has| (-694) (-368))) (($ (-1166 (-694))) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3359 (((-694) $) 29)) (-2956 (((-3 (-413 (-572)) "failed") $) NIL (|has| (-694) (-554)))) (-3175 (((-121) $) NIL (|has| (-694) (-554)))) (-4299 (((-413 (-572)) $) NIL (|has| (-694) (-554)))) (-2667 (((-923)) NIL)) (-3286 (($) NIL (|has| (-694) (-374)))) (-2208 (($ $ $) NIL (|has| (-694) (-303)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| (-694) (-303)))) (-2754 (($) NIL (|has| (-694) (-353)))) (-1297 (((-121) $) NIL (|has| (-694) (-353)))) (-4486 (($ $) NIL (|has| (-694) (-353))) (($ $ (-769)) NIL (|has| (-694) (-353)))) (-1526 (((-121) $) NIL (-1841 (-12 (|has| (-694) (-303)) (|has| (-694) (-910))) (|has| (-694) (-368))))) (-4527 (((-2 (|:| |r| (-694)) (|:| |phi| (-694))) $) NIL (-12 (|has| (-694) (-1063)) (|has| (-694) (-1190))))) (-4184 (($) NIL (|has| (-694) (-1190)))) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| (-694) (-887 (-385)))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| (-694) (-887 (-572))))) (-3377 (((-834 (-923)) $) NIL (|has| (-694) (-353))) (((-923) $) NIL (|has| (-694) (-353)))) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (-12 (|has| (-694) (-1009)) (|has| (-694) (-1190))))) (-4429 (((-694) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| (-694) (-353)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| (-694) (-303)))) (-3251 (((-1166 (-694)) $) NIL (|has| (-694) (-368)))) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 (-694) (-694)) $) NIL)) (-3633 (((-923) $) NIL (|has| (-694) (-374)))) (-3539 (($ $) NIL (|has| (-694) (-1190)))) (-3111 (((-1166 (-694)) $) NIL)) (-1629 (($ (-638 $)) NIL (|has| (-694) (-303))) (($ $ $) NIL (|has| (-694) (-303)))) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| (-694) (-368)))) (-1773 (($) NIL (|has| (-694) (-353)) CONST)) (-1763 (($ (-923)) NIL (|has| (-694) (-374)))) (-4130 (($) NIL)) (-4310 (((-694) $) 31)) (-2607 (((-1116) $) NIL)) (-2307 (($) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| (-694) (-303)))) (-3069 (($ (-638 $)) NIL (|has| (-694) (-303))) (($ $ $) NIL (|has| (-694) (-303)))) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| (-694) (-353)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-694) (-303)) (|has| (-694) (-910))))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-694) (-303)) (|has| (-694) (-910))))) (-4304 (((-424 $) $) NIL (-1841 (-12 (|has| (-694) (-303)) (|has| (-694) (-910))) (|has| (-694) (-368))))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-694) (-303))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| (-694) (-303)))) (-1803 (((-3 $ "failed") $ $) NIL) (((-3 $ "failed") $ (-694)) NIL (|has| (-694) (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| (-694) (-303)))) (-4179 (($ $) NIL (|has| (-694) (-1190)))) (-4485 (($ $ (-1170) (-694)) NIL (|has| (-694) (-527 (-1170) (-694)))) (($ $ (-638 (-1170)) (-638 (-694))) NIL (|has| (-694) (-527 (-1170) (-694)))) (($ $ (-638 (-290 (-694)))) NIL (|has| (-694) (-305 (-694)))) (($ $ (-290 (-694))) NIL (|has| (-694) (-305 (-694)))) (($ $ (-694) (-694)) NIL (|has| (-694) (-305 (-694)))) (($ $ (-638 (-694)) (-638 (-694))) NIL (|has| (-694) (-305 (-694))))) (-4029 (((-769) $) NIL (|has| (-694) (-303)))) (-3587 (((-638 $)) NIL (|has| (-694) (-374)))) (-3277 (($ $ (-694)) NIL (|has| (-694) (-283 (-694) (-694))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| (-694) (-303)))) (-2119 (((-694)) NIL) (((-694) (-1259 $)) NIL)) (-3158 (((-3 (-769) "failed") $ $) NIL (|has| (-694) (-353))) (((-769) $) NIL (|has| (-694) (-353)))) (-3139 (($ $ (-1 (-694) (-694))) NIL) (($ $ (-1 (-694) (-694)) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-694) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-694) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-694) (-901 (-1170)))) (($ $ (-1170)) NIL (|has| (-694) (-901 (-1170)))) (($ $ (-769)) NIL (|has| (-694) (-227))) (($ $) NIL (|has| (-694) (-227)))) (-3482 (((-685 (-694)) (-1259 $) (-1 (-694) (-694))) NIL (|has| (-694) (-368)))) (-2830 (((-1166 (-694))) NIL)) (-4302 (($ $) NIL (|has| (-694) (-1190)))) (-4237 (($ $) NIL (|has| (-694) (-1190)))) (-2278 (($) NIL (|has| (-694) (-353)))) (-4289 (($ $) NIL (|has| (-694) (-1190)))) (-4228 (($ $) NIL (|has| (-694) (-1190)))) (-4278 (($ $) NIL (|has| (-694) (-1190)))) (-4220 (($ $) NIL (|has| (-694) (-1190)))) (-3160 (((-685 (-694)) (-1259 $)) NIL) (((-1259 (-694)) $) NIL) (((-685 (-694)) (-1259 $) (-1259 $)) NIL) (((-1259 (-694)) $ (-1259 $)) NIL)) (-4081 (((-545) $) NIL (|has| (-694) (-613 (-545)))) (((-171 (-217)) $) NIL (|has| (-694) (-1028))) (((-171 (-385)) $) NIL (|has| (-694) (-1028))) (((-893 (-385)) $) NIL (|has| (-694) (-613 (-893 (-385))))) (((-893 (-572)) $) NIL (|has| (-694) (-613 (-893 (-572))))) (($ (-1166 (-694))) NIL) (((-1166 (-694)) $) NIL) (($ (-1259 (-694))) NIL) (((-1259 (-694)) $) NIL)) (-3018 (($ $) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-694) (-303)) (|has| (-694) (-910))) (|has| (-694) (-353))))) (-3363 (($ (-694) (-694)) 12)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-572)) NIL) (($ (-694)) NIL) (($ (-171 (-385))) 13) (($ (-171 (-572))) 19) (($ (-171 (-694))) 28) (($ (-171 (-696))) 25) (((-171 (-385)) $) 33) (($ (-413 (-572))) NIL (-1841 (|has| (-694) (-368)) (|has| (-694) (-1044 (-413 (-572))))))) (-2779 (($ $) NIL (|has| (-694) (-353))) (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-694) (-303)) (|has| (-694) (-910))) (|has| (-694) (-149))))) (-2707 (((-1166 (-694)) $) NIL)) (-2140 (((-769)) NIL)) (-2237 (((-1259 $)) NIL)) (-4321 (($ $) NIL (|has| (-694) (-1190)))) (-4251 (($ $) NIL (|has| (-694) (-1190)))) (-3774 (((-121) $ $) NIL)) (-4308 (($ $) NIL (|has| (-694) (-1190)))) (-4241 (($ $) NIL (|has| (-694) (-1190)))) (-4333 (($ $) NIL (|has| (-694) (-1190)))) (-4263 (($ $) NIL (|has| (-694) (-1190)))) (-2917 (((-694) $) NIL (|has| (-694) (-1190)))) (-2104 (($ $) NIL (|has| (-694) (-1190)))) (-4268 (($ $) NIL (|has| (-694) (-1190)))) (-4327 (($ $) NIL (|has| (-694) (-1190)))) (-4257 (($ $) NIL (|has| (-694) (-1190)))) (-4314 (($ $) NIL (|has| (-694) (-1190)))) (-4246 (($ $) NIL (|has| (-694) (-1190)))) (-2264 (($ $) NIL (|has| (-694) (-1063)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-694) (-368)))) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-1 (-694) (-694))) NIL) (($ $ (-1 (-694) (-694)) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-694) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-694) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-694) (-901 (-1170)))) (($ $ (-1170)) NIL (|has| (-694) (-901 (-1170)))) (($ $ (-769)) NIL (|has| (-694) (-227))) (($ $) NIL (|has| (-694) (-227)))) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL (|has| (-694) (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ $) NIL (|has| (-694) (-1190))) (($ $ (-413 (-572))) NIL (-12 (|has| (-694) (-1009)) (|has| (-694) (-1190)))) (($ $ (-572)) NIL (|has| (-694) (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ (-694) $) NIL) (($ $ (-694)) NIL) (($ (-413 (-572)) $) NIL (|has| (-694) (-368))) (($ $ (-413 (-572))) NIL (|has| (-694) (-368))))) 
-(((-689) (-13 (-393) (-168 (-694)) (-10 -8 (-15 -3972 ($ (-171 (-385)))) (-15 -3972 ($ (-171 (-572)))) (-15 -3972 ($ (-171 (-694)))) (-15 -3972 ($ (-171 (-696)))) (-15 -3972 ((-171 (-385)) $))))) (T -689)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-171 (-385))) (-5 *1 (-689)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-171 (-572))) (-5 *1 (-689)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-171 (-694))) (-5 *1 (-689)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-171 (-696))) (-5 *1 (-689)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-171 (-385))) (-5 *1 (-689))))) 
-(-13 (-393) (-168 (-694)) (-10 -8 (-15 -3972 ($ (-171 (-385)))) (-15 -3972 ($ (-171 (-572)))) (-15 -3972 ($ (-171 (-694)))) (-15 -3972 ($ (-171 (-696)))) (-15 -3972 ((-171 (-385)) $)))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-1550 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-3259 (($ $) 58)) (-1643 (($ $) 55 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ |#1| $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4602)))) (-3445 (($ |#1| $) 54 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4602)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37) (($ |#1| $ (-769)) 59)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-4153 (((-638 (-2 (|:| -4320 |#1|) (|:| -1571 (-769)))) $) 57)) (-1535 (($) 46) (($ (-638 |#1|)) 45)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 47)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-690 |#1|) (-1290) (-1098)) (T -690)) 
-((-1335 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-690 *2)) (-4 *2 (-1098)))) (-3259 (*1 *1 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1098)))) (-4153 (*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1098)) (-5 *2 (-638 (-2 (|:| -4320 *3) (|:| -1571 (-769)))))))) 
-(-13 (-229 |t#1|) (-10 -8 (-15 -1335 ($ |t#1| $ (-769))) (-15 -3259 ($ $)) (-15 -4153 ((-638 (-2 (|:| -4320 |t#1|) (|:| -1571 (-769)))) $)))) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-229 |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-4227 (((-638 |#1|) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))) (-572)) 46)) (-3793 ((|#1| |#1| (-572)) 45)) (-3069 ((|#1| |#1| |#1| (-572)) 35)) (-4304 (((-638 |#1|) |#1| (-572)) 38)) (-1319 ((|#1| |#1| (-572) |#1| (-572)) 32)) (-3062 (((-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))) |#1| (-572)) 44))) 
-(((-691 |#1|) (-10 -7 (-15 -3069 (|#1| |#1| |#1| (-572))) (-15 -3793 (|#1| |#1| (-572))) (-15 -4304 ((-638 |#1|) |#1| (-572))) (-15 -3062 ((-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))) |#1| (-572))) (-15 -4227 ((-638 |#1|) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))) (-572))) (-15 -1319 (|#1| |#1| (-572) |#1| (-572)))) (-1234 (-572))) (T -691)) 
-((-1319 (*1 *2 *2 *3 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-691 *2)) (-4 *2 (-1234 *3)))) (-4227 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| -4304 *5) (|:| -4316 (-572))))) (-5 *4 (-572)) (-4 *5 (-1234 *4)) (-5 *2 (-638 *5)) (-5 *1 (-691 *5)))) (-3062 (*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-5 *2 (-638 (-2 (|:| -4304 *3) (|:| -4316 *4)))) (-5 *1 (-691 *3)) (-4 *3 (-1234 *4)))) (-4304 (*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-5 *2 (-638 *3)) (-5 *1 (-691 *3)) (-4 *3 (-1234 *4)))) (-3793 (*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-691 *2)) (-4 *2 (-1234 *3)))) (-3069 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-691 *2)) (-4 *2 (-1234 *3))))) 
-(-10 -7 (-15 -3069 (|#1| |#1| |#1| (-572))) (-15 -3793 (|#1| |#1| (-572))) (-15 -4304 ((-638 |#1|) |#1| (-572))) (-15 -3062 ((-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))) |#1| (-572))) (-15 -4227 ((-638 |#1|) (-638 (-2 (|:| -4304 |#1|) (|:| -4316 (-572)))) (-572))) (-15 -1319 (|#1| |#1| (-572) |#1| (-572)))) 
-((-3728 (((-1 (-950 (-217)) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217) (-217))) 17)) (-3656 (((-1129 (-217)) (-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-638 (-258))) 38) (((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-638 (-258))) 40) (((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-3 (-1 (-217) (-217) (-217) (-217)) "undefined") (-1092 (-217)) (-1092 (-217)) (-638 (-258))) 42)) (-2507 (((-1129 (-217)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-638 (-258))) NIL)) (-3571 (((-1129 (-217)) (-1 (-217) (-217) (-217)) (-3 (-1 (-217) (-217) (-217) (-217)) "undefined") (-1092 (-217)) (-1092 (-217)) (-638 (-258))) 43))) 
-(((-692) (-10 -7 (-15 -3656 ((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-3 (-1 (-217) (-217) (-217) (-217)) "undefined") (-1092 (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -3656 ((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -3656 ((-1129 (-217)) (-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -3571 ((-1129 (-217)) (-1 (-217) (-217) (-217)) (-3 (-1 (-217) (-217) (-217) (-217)) "undefined") (-1092 (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -2507 ((-1129 (-217)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -3728 ((-1 (-950 (-217)) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217) (-217)))))) (T -692)) 
-((-3728 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1 (-217) (-217) (-217) (-217))) (-5 *2 (-1 (-950 (-217)) (-217) (-217))) (-5 *1 (-692)))) (-2507 (*1 *2 *3 *3 *3 *4 *5 *6) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-692)))) (-3571 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-3 (-1 (-217) (-217) (-217) (-217)) "undefined")) (-5 *5 (-1092 (-217))) (-5 *6 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-692)))) (-3656 (*1 *2 *2 *3 *4 *4 *5) (-12 (-5 *2 (-1129 (-217))) (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-217))) (-5 *5 (-638 (-258))) (-5 *1 (-692)))) (-3656 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-217))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-692)))) (-3656 (*1 *2 *3 *3 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-3 (-1 (-217) (-217) (-217) (-217)) "undefined")) (-5 *5 (-1092 (-217))) (-5 *6 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-692))))) 
-(-10 -7 (-15 -3656 ((-1129 (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-3 (-1 (-217) (-217) (-217) (-217)) "undefined") (-1092 (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -3656 ((-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -3656 ((-1129 (-217)) (-1129 (-217)) (-1 (-950 (-217)) (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -3571 ((-1129 (-217)) (-1 (-217) (-217) (-217)) (-3 (-1 (-217) (-217) (-217) (-217)) "undefined") (-1092 (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -2507 ((-1129 (-217)) (-312 (-572)) (-312 (-572)) (-312 (-572)) (-1 (-217) (-217)) (-1092 (-217)) (-638 (-258)))) (-15 -3728 ((-1 (-950 (-217)) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217)) (-1 (-217) (-217) (-217) (-217))))) 
-((-4304 (((-424 (-1166 |#4|)) (-1166 |#4|)) 73) (((-424 |#4|) |#4|) 215))) 
-(((-693 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4304 ((-424 |#4|) |#4|)) (-15 -4304 ((-424 (-1166 |#4|)) (-1166 |#4|)))) (-848) (-794) (-353) (-956 |#3| |#2| |#1|)) (T -693)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-353)) (-4 *7 (-956 *6 *5 *4)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-693 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) (-4304 (*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-693 *4 *5 *6 *3)) (-4 *3 (-956 *6 *5 *4))))) 
-(-10 -7 (-15 -4304 ((-424 |#4|) |#4|)) (-15 -4304 ((-424 (-1166 |#4|)) (-1166 |#4|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 84)) (-2551 (((-572) $) 30)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2525 (($ $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4190 (($ $) NIL)) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL)) (-2211 (($) NIL T CONST)) (-3599 (($ $) NIL)) (-3376 (((-3 (-572) "failed") $) 73) (((-3 (-413 (-572)) "failed") $) 26) (((-3 (-385) "failed") $) 70)) (-1318 (((-572) $) 75) (((-413 (-572)) $) 67) (((-385) $) 68)) (-2190 (($ $ $) 96)) (-1799 (((-3 $ "failed") $) 87)) (-2208 (($ $ $) 95)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1539 (((-923)) 77) (((-923) (-923)) 76)) (-1908 (((-121) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL)) (-3377 (((-572) $) NIL)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL)) (-4429 (($ $) NIL)) (-4472 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4365 (((-572) (-572)) 81) (((-572)) 82)) (-1771 (($ $ $) NIL) (($) NIL (-12 (-2959 (|has| $ (-6 -4585))) (-2959 (|has| $ (-6 -4593)))))) (-3506 (((-572) (-572)) 79) (((-572)) 80)) (-4238 (($ $ $) NIL) (($) NIL (-12 (-2959 (|has| $ (-6 -4585))) (-2959 (|has| $ (-6 -4593)))))) (-3917 (((-572) $) 16)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 91)) (-3794 (((-923) (-572)) NIL (|has| $ (-6 -4593)))) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL)) (-1716 (($ $) NIL)) (-3997 (($ (-572) (-572)) NIL) (($ (-572) (-572) (-923)) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) 92)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3751 (((-572) $) 22)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 94)) (-4465 (((-923)) NIL) (((-923) (-923)) NIL (|has| $ (-6 -4593)))) (-1506 (((-923) (-572)) NIL (|has| $ (-6 -4593)))) (-4081 (((-385) $) NIL) (((-217) $) NIL) (((-893 (-385)) $) NIL)) (-3972 (((-856) $) 52) (($ (-572)) 63) (($ $) NIL) (($ (-413 (-572))) 66) (($ (-572)) 63) (($ (-413 (-572))) 66) (($ (-385)) 60) (((-385) $) 50) (($ (-696)) 55)) (-2140 (((-769)) 103)) (-4222 (($ (-572) (-572) (-923)) 44)) (-2634 (($ $) NIL)) (-1813 (((-923)) NIL) (((-923) (-923)) NIL (|has| $ (-6 -4593)))) (-4393 (((-923)) 35) (((-923) (-923)) 78)) (-3774 (((-121) $ $) NIL)) (-2264 (($ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 32 T CONST)) (-3255 (($) 17 T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 83)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 101)) (-1379 (($ $ $) 65)) (-1373 (($ $) 99) (($ $ $) 100)) (-1367 (($ $ $) 98)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL) (($ $ (-413 (-572))) 90)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 97) (($ $ $) 88) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL))) 
-(((-694) (-13 (-410) (-393) (-368) (-1044 (-385)) (-1044 (-413 (-572))) (-151) (-10 -8 (-15 -1539 ((-923) (-923))) (-15 -1539 ((-923))) (-15 -4393 ((-923) (-923))) (-15 -4393 ((-923))) (-15 -3506 ((-572) (-572))) (-15 -3506 ((-572))) (-15 -4365 ((-572) (-572))) (-15 -4365 ((-572))) (-15 -3972 ((-385) $)) (-15 -3972 ($ (-696))) (-15 -3917 ((-572) $)) (-15 -3751 ((-572) $)) (-15 -4222 ($ (-572) (-572) (-923)))))) (T -694)) 
-((-4393 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-694)))) (-3751 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) (-3917 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) (-1539 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-694)))) (-1539 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-694)))) (-4393 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-694)))) (-3506 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) (-3506 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) (-4365 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) (-4365 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-385)) (-5 *1 (-694)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-696)) (-5 *1 (-694)))) (-4222 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-572)) (-5 *3 (-923)) (-5 *1 (-694))))) 
-(-13 (-410) (-393) (-368) (-1044 (-385)) (-1044 (-413 (-572))) (-151) (-10 -8 (-15 -1539 ((-923) (-923))) (-15 -1539 ((-923))) (-15 -4393 ((-923) (-923))) (-15 -4393 ((-923))) (-15 -3506 ((-572) (-572))) (-15 -3506 ((-572))) (-15 -4365 ((-572) (-572))) (-15 -4365 ((-572))) (-15 -3972 ((-385) $)) (-15 -3972 ($ (-696))) (-15 -3917 ((-572) $)) (-15 -3751 ((-572) $)) (-15 -4222 ($ (-572) (-572) (-923))))) 
-((-1568 (((-685 |#1|) (-685 |#1|) |#1| |#1|) 66)) (-3292 (((-685 |#1|) (-685 |#1|) |#1|) 49)) (-3551 (((-685 |#1|) (-685 |#1|) |#1|) 67)) (-1405 (((-685 |#1|) (-685 |#1|)) 50)) (-4145 (((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|) 65))) 
-(((-695 |#1|) (-10 -7 (-15 -1405 ((-685 |#1|) (-685 |#1|))) (-15 -3292 ((-685 |#1|) (-685 |#1|) |#1|)) (-15 -3551 ((-685 |#1|) (-685 |#1|) |#1|)) (-15 -1568 ((-685 |#1|) (-685 |#1|) |#1| |#1|)) (-15 -4145 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|))) (-303)) (T -695)) 
-((-4145 (*1 *2 *3 *3) (-12 (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-695 *3)) (-4 *3 (-303)))) (-1568 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-303)) (-5 *1 (-695 *3)))) (-3551 (*1 *2 *2 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-303)) (-5 *1 (-695 *3)))) (-3292 (*1 *2 *2 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-303)) (-5 *1 (-695 *3)))) (-1405 (*1 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-303)) (-5 *1 (-695 *3))))) 
-(-10 -7 (-15 -1405 ((-685 |#1|) (-685 |#1|))) (-15 -3292 ((-685 |#1|) (-685 |#1|) |#1|)) (-15 -3551 ((-685 |#1|) (-685 |#1|) |#1|)) (-15 -1568 ((-685 |#1|) (-685 |#1|) |#1| |#1|)) (-15 -4145 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1481 (($ $ $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2934 (($ $ $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL)) (-3351 (($ $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) 27)) (-1318 (((-572) $) 25)) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2956 (((-3 (-413 (-572)) "failed") $) NIL)) (-3175 (((-121) $) NIL)) (-4299 (((-413 (-572)) $) NIL)) (-3286 (($ $) NIL) (($) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1968 (($ $ $ $) NIL)) (-4489 (($ $ $) NIL)) (-1908 (((-121) $) NIL)) (-2133 (($ $ $) NIL)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL)) (-3893 (((-121) $) NIL)) (-4240 (((-121) $) NIL)) (-3961 (((-3 $ "failed") $) NIL)) (-4472 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1628 (($ $ $ $) NIL)) (-1771 (($ $ $) NIL)) (-1856 (((-923) (-923)) 10) (((-923)) 9)) (-4238 (($ $ $) NIL)) (-1582 (($ $) NIL)) (-3200 (($ $) NIL)) (-1629 (($ (-638 $)) NIL) (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2144 (($ $ $) NIL)) (-1773 (($) NIL T CONST)) (-3088 (($ $) NIL)) (-2607 (((-1116) $) NIL) (($ $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ (-638 $)) NIL) (($ $ $) NIL)) (-2900 (($ $) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4247 (((-121) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL) (($ $ (-769)) NIL)) (-4340 (($ $) NIL)) (-1607 (($ $) NIL)) (-4081 (((-217) $) NIL) (((-385) $) NIL) (((-893 (-572)) $) NIL) (((-545) $) NIL) (((-572) $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) 24) (($ $) NIL) (($ (-572)) 24) (((-312 $) (-312 (-572))) 18)) (-2140 (((-769)) NIL)) (-1348 (((-121) $ $) NIL)) (-3610 (($ $ $) NIL)) (-4393 (($) NIL)) (-3774 (((-121) $ $) NIL)) (-1498 (($ $ $ $) NIL)) (-2264 (($ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $) NIL) (($ $ (-769)) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL))) 
-(((-696) (-13 (-393) (-554) (-10 -8 (-15 -1856 ((-923) (-923))) (-15 -1856 ((-923))) (-15 -3972 ((-312 $) (-312 (-572))))))) (T -696)) 
-((-1856 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-696)))) (-1856 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-696)))) (-3972 (*1 *2 *3) (-12 (-5 *3 (-312 (-572))) (-5 *2 (-312 (-696))) (-5 *1 (-696))))) 
-(-13 (-393) (-554) (-10 -8 (-15 -1856 ((-923) (-923))) (-15 -1856 ((-923))) (-15 -3972 ((-312 $) (-312 (-572)))))) 
-((-1919 (((-1 |#4| |#2| |#3|) |#1| (-1170) (-1170)) 19)) (-2171 (((-1 |#4| |#2| |#3|) (-1170)) 12))) 
-(((-697 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2171 ((-1 |#4| |#2| |#3|) (-1170))) (-15 -1919 ((-1 |#4| |#2| |#3|) |#1| (-1170) (-1170)))) (-613 (-545)) (-1204) (-1204) (-1204)) (T -697)) 
-((-1919 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-697 *3 *5 *6 *7)) (-4 *3 (-613 (-545))) (-4 *5 (-1204)) (-4 *6 (-1204)) (-4 *7 (-1204)))) (-2171 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-697 *4 *5 *6 *7)) (-4 *4 (-613 (-545))) (-4 *5 (-1204)) (-4 *6 (-1204)) (-4 *7 (-1204))))) 
-(-10 -7 (-15 -2171 ((-1 |#4| |#2| |#3|) (-1170))) (-15 -1919 ((-1 |#4| |#2| |#3|) |#1| (-1170) (-1170)))) 
-((-2262 (((-121) $ $) NIL)) (-2124 (((-1264) $ (-769)) 14)) (-4014 (((-769) $) 12)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 18) ((|#1| $) 15) (($ |#1|) 23)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 25)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 24))) 
-(((-698 |#1|) (-13 (-139) (-612 |#1|) (-10 -8 (-15 -3972 ($ |#1|)))) (-1098)) (T -698)) 
-((-3972 (*1 *1 *2) (-12 (-5 *1 (-698 *2)) (-4 *2 (-1098))))) 
-(-13 (-139) (-612 |#1|) (-10 -8 (-15 -3972 ($ |#1|)))) 
-((-4000 (((-1 (-217) (-217) (-217)) |#1| (-1170) (-1170)) 33) (((-1 (-217) (-217)) |#1| (-1170)) 38))) 
-(((-699 |#1|) (-10 -7 (-15 -4000 ((-1 (-217) (-217)) |#1| (-1170))) (-15 -4000 ((-1 (-217) (-217) (-217)) |#1| (-1170) (-1170)))) (-613 (-545))) (T -699)) 
-((-4000 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-1 (-217) (-217) (-217))) (-5 *1 (-699 *3)) (-4 *3 (-613 (-545))))) (-4000 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-1 (-217) (-217))) (-5 *1 (-699 *3)) (-4 *3 (-613 (-545)))))) 
-(-10 -7 (-15 -4000 ((-1 (-217) (-217)) |#1| (-1170))) (-15 -4000 ((-1 (-217) (-217) (-217)) |#1| (-1170) (-1170)))) 
-((-3616 (((-1170) |#1| (-1170) (-638 (-1170))) 9) (((-1170) |#1| (-1170) (-1170) (-1170)) 12) (((-1170) |#1| (-1170) (-1170)) 11) (((-1170) |#1| (-1170)) 10))) 
-(((-700 |#1|) (-10 -7 (-15 -3616 ((-1170) |#1| (-1170))) (-15 -3616 ((-1170) |#1| (-1170) (-1170))) (-15 -3616 ((-1170) |#1| (-1170) (-1170) (-1170))) (-15 -3616 ((-1170) |#1| (-1170) (-638 (-1170))))) (-613 (-545))) (T -700)) 
-((-3616 (*1 *2 *3 *2 *4) (-12 (-5 *4 (-638 (-1170))) (-5 *2 (-1170)) (-5 *1 (-700 *3)) (-4 *3 (-613 (-545))))) (-3616 (*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-700 *3)) (-4 *3 (-613 (-545))))) (-3616 (*1 *2 *3 *2 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-700 *3)) (-4 *3 (-613 (-545))))) (-3616 (*1 *2 *3 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-700 *3)) (-4 *3 (-613 (-545)))))) 
-(-10 -7 (-15 -3616 ((-1170) |#1| (-1170))) (-15 -3616 ((-1170) |#1| (-1170) (-1170))) (-15 -3616 ((-1170) |#1| (-1170) (-1170) (-1170))) (-15 -3616 ((-1170) |#1| (-1170) (-638 (-1170))))) 
-((-2604 (((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|) 9))) 
-(((-701 |#1| |#2|) (-10 -7 (-15 -2604 ((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|))) (-1204) (-1204)) (T -701)) 
-((-2604 (*1 *2 *3 *4) (-12 (-5 *2 (-2 (|:| |part1| *3) (|:| |part2| *4))) (-5 *1 (-701 *3 *4)) (-4 *3 (-1204)) (-4 *4 (-1204))))) 
-(-10 -7 (-15 -2604 ((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|))) 
-((-1996 (((-1 |#3| |#2|) (-1170)) 11)) (-1919 (((-1 |#3| |#2|) |#1| (-1170)) 21))) 
-(((-702 |#1| |#2| |#3|) (-10 -7 (-15 -1996 ((-1 |#3| |#2|) (-1170))) (-15 -1919 ((-1 |#3| |#2|) |#1| (-1170)))) (-613 (-545)) (-1204) (-1204)) (T -702)) 
-((-1919 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-1 *6 *5)) (-5 *1 (-702 *3 *5 *6)) (-4 *3 (-613 (-545))) (-4 *5 (-1204)) (-4 *6 (-1204)))) (-1996 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 *6 *5)) (-5 *1 (-702 *4 *5 *6)) (-4 *4 (-613 (-545))) (-4 *5 (-1204)) (-4 *6 (-1204))))) 
-(-10 -7 (-15 -1996 ((-1 |#3| |#2|) (-1170))) (-15 -1919 ((-1 |#3| |#2|) |#1| (-1170)))) 
-((-4406 (((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 (-1166 |#4|)) (-638 |#3|) (-638 |#4|) (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| |#4|)))) (-638 (-769)) (-1259 (-638 (-1166 |#3|))) |#3|) 58)) (-2729 (((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 (-1166 |#3|)) (-638 |#3|) (-638 |#4|) (-638 (-769)) |#3|) 71)) (-3783 (((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 |#3|) (-638 (-769)) (-638 (-1166 |#4|)) (-1259 (-638 (-1166 |#3|))) |#3|) 32))) 
-(((-703 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3783 ((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 |#3|) (-638 (-769)) (-638 (-1166 |#4|)) (-1259 (-638 (-1166 |#3|))) |#3|)) (-15 -2729 ((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 (-1166 |#3|)) (-638 |#3|) (-638 |#4|) (-638 (-769)) |#3|)) (-15 -4406 ((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 (-1166 |#4|)) (-638 |#3|) (-638 |#4|) (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| |#4|)))) (-638 (-769)) (-1259 (-638 (-1166 |#3|))) |#3|))) (-794) (-848) (-303) (-956 |#3| |#1| |#2|)) (T -703)) 
-((-4406 (*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| -12 (-5 *2 (-638 (-1166 *13))) (-5 *3 (-1166 *13)) (-5 *4 (-638 *12)) (-5 *5 (-638 *10)) (-5 *6 (-638 *13)) (-5 *7 (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| *13))))) (-5 *8 (-638 (-769))) (-5 *9 (-1259 (-638 (-1166 *10)))) (-4 *12 (-848)) (-4 *10 (-303)) (-4 *13 (-956 *10 *11 *12)) (-4 *11 (-794)) (-5 *1 (-703 *11 *12 *10 *13)))) (-2729 (*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| -12 (-5 *4 (-638 *11)) (-5 *5 (-638 (-1166 *9))) (-5 *6 (-638 *9)) (-5 *7 (-638 *12)) (-5 *8 (-638 (-769))) (-4 *11 (-848)) (-4 *9 (-303)) (-4 *12 (-956 *9 *10 *11)) (-4 *10 (-794)) (-5 *2 (-638 (-1166 *12))) (-5 *1 (-703 *10 *11 *9 *12)) (-5 *3 (-1166 *12)))) (-3783 (*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| -12 (-5 *2 (-638 (-1166 *11))) (-5 *3 (-1166 *11)) (-5 *4 (-638 *10)) (-5 *5 (-638 *8)) (-5 *6 (-638 (-769))) (-5 *7 (-1259 (-638 (-1166 *8)))) (-4 *10 (-848)) (-4 *8 (-303)) (-4 *11 (-956 *8 *9 *10)) (-4 *9 (-794)) (-5 *1 (-703 *9 *10 *8 *11))))) 
-(-10 -7 (-15 -3783 ((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 |#3|) (-638 (-769)) (-638 (-1166 |#4|)) (-1259 (-638 (-1166 |#3|))) |#3|)) (-15 -2729 ((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 (-1166 |#3|)) (-638 |#3|) (-638 |#4|) (-638 (-769)) |#3|)) (-15 -4406 ((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-638 |#2|) (-638 (-1166 |#4|)) (-638 |#3|) (-638 |#4|) (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| |#4|)))) (-638 (-769)) (-1259 (-638 (-1166 |#3|))) |#3|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-4383 (($ $) 40)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-4328 (($ |#1| (-769)) 38)) (-1784 (((-769) $) 42)) (-4373 ((|#1| $) 41)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4316 (((-769) $) 43)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 37 (|has| |#1| (-174)))) (-1958 ((|#1| $ (-769)) 39)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 45) (($ |#1| $) 44))) 
-(((-704 |#1|) (-1290) (-1054)) (T -704)) 
-((-4316 (*1 *2 *1) (-12 (-4 *1 (-704 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) (-1784 (*1 *2 *1) (-12 (-4 *1 (-704 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) (-4373 (*1 *2 *1) (-12 (-4 *1 (-704 *2)) (-4 *2 (-1054)))) (-4383 (*1 *1 *1) (-12 (-4 *1 (-704 *2)) (-4 *2 (-1054)))) (-1958 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-704 *2)) (-4 *2 (-1054)))) (-4328 (*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-704 *2)) (-4 *2 (-1054))))) 
-(-13 (-1054) (-120 |t#1| |t#1|) (-10 -8 (IF (|has| |t#1| (-174)) (-6 (-43 |t#1|)) |noBranch|) (-15 -4316 ((-769) $)) (-15 -1784 ((-769) $)) (-15 -4373 (|t#1| $)) (-15 -4383 ($ $)) (-15 -1958 (|t#1| $ (-769))) (-15 -4328 ($ |t#1| (-769))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-174)) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 |#1|) |has| |#1| (-174)) ((-722) . T) ((-1060 |#1|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3828 ((|#6| (-1 |#4| |#1|) |#3|) 23))) 
-(((-705 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -3828 (|#6| (-1 |#4| |#1|) |#3|))) (-562) (-1234 |#1|) (-1234 (-413 |#2|)) (-562) (-1234 |#4|) (-1234 (-413 |#5|))) (T -705)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-562)) (-4 *7 (-562)) (-4 *6 (-1234 *5)) (-4 *2 (-1234 (-413 *8))) (-5 *1 (-705 *5 *6 *4 *7 *8 *2)) (-4 *4 (-1234 (-413 *6))) (-4 *8 (-1234 *7))))) 
-(-10 -7 (-15 -3828 (|#6| (-1 |#4| |#1|) |#3|))) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1438 (((-1152) (-856)) 31)) (-2415 (((-1264) (-1152)) 28)) (-3956 (((-1152) (-856)) 24)) (-2093 (((-1152) (-856)) 25)) (-3972 (((-856) $) NIL) (((-1152) (-856)) 23)) (-1324 (((-121) $ $) NIL))) 
-(((-706) (-13 (-1098) (-10 -7 (-15 -3972 ((-1152) (-856))) (-15 -3956 ((-1152) (-856))) (-15 -2093 ((-1152) (-856))) (-15 -1438 ((-1152) (-856))) (-15 -2415 ((-1264) (-1152)))))) (T -706)) 
-((-3972 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-706)))) (-3956 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-706)))) (-2093 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-706)))) (-1438 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-706)))) (-2415 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-706))))) 
-(-13 (-1098) (-10 -7 (-15 -3972 ((-1152) (-856))) (-15 -3956 ((-1152) (-856))) (-15 -2093 ((-1152) (-856))) (-15 -1438 ((-1152) (-856))) (-15 -2415 ((-1264) (-1152))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-2190 (($ $ $) NIL)) (-3116 (($ |#1| |#2|) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-3893 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3195 ((|#2| $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1698 (((-3 $ "failed") $ $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) ((|#1| $) NIL)) (-2140 (((-769)) NIL)) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL))) 
-(((-707 |#1| |#2| |#3| |#4| |#5|) (-13 (-368) (-10 -8 (-15 -3195 (|#2| $)) (-15 -3972 (|#1| $)) (-15 -3116 ($ |#1| |#2|)) (-15 -1698 ((-3 $ "failed") $ $)))) (-174) (-23) (-1 |#1| |#1| |#2|) (-1 (-3 |#2| "failed") |#2| |#2|) (-1 (-3 |#1| "failed") |#1| |#1| |#2|)) (T -707)) 
-((-3195 (*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-707 *3 *2 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) (-3972 (*1 *2 *1) (-12 (-4 *2 (-174)) (-5 *1 (-707 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3116 (*1 *1 *2 *3) (-12 (-5 *1 (-707 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-1698 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-707 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
-(-13 (-368) (-10 -8 (-15 -3195 (|#2| $)) (-15 -3972 (|#1| $)) (-15 -3116 ($ |#1| |#2|)) (-15 -1698 ((-3 $ "failed") $ $)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 30)) (-3275 (((-1259 |#1|) $ (-769)) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-2383 (($ (-1166 |#1|)) NIL)) (-4297 (((-1166 $) $ (-1082)) NIL) (((-1166 |#1|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1082))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2824 (($ $ $) NIL (|has| |#1| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-1685 (((-769)) 46 (|has| |#1| (-374)))) (-2786 (($ $ (-769)) NIL)) (-3944 (($ $ (-769)) NIL)) (-2127 ((|#2| |#2|) 43)) (-2012 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-457)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-1082) "failed") $) NIL)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-1082) $) NIL)) (-3190 (($ $ $ (-1082)) NIL (|has| |#1| (-174))) ((|#1| $ $) NIL (|has| |#1| (-174)))) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) 33)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-3116 (($ |#2|) 41)) (-1799 (((-3 $ "failed") $) 84)) (-3286 (($) 50 (|has| |#1| (-374)))) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3890 (($ $ $) NIL)) (-3039 (($ $ $) NIL (|has| |#1| (-562)))) (-1449 (((-2 (|:| -4513 |#1|) (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ (-1082)) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3341 (((-965 $)) 78)) (-3977 (($ $ |#1| (-769) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1082) (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1082) (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3377 (((-769) $ $) NIL (|has| |#1| (-562)))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-1144)))) (-4335 (($ (-1166 |#1|) (-1082)) NIL) (($ (-1166 $) (-1082)) NIL)) (-3965 (($ $ (-769)) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) 76) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1082)) NIL) (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3195 ((|#2|) 44)) (-1784 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-769) (-769)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-4155 (((-1166 |#1|) $) NIL)) (-1470 (((-3 (-1082) "failed") $) NIL)) (-3633 (((-923) $) NIL (|has| |#1| (-374)))) (-3111 ((|#2| $) 40)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) 28)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-2845 (((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769)) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-1082)) (|:| -3751 (-769))) "failed") $) NIL)) (-2774 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1773 (($) NIL (|has| |#1| (-1144)) CONST)) (-1763 (($ (-923)) NIL (|has| |#1| (-374)))) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-3362 (($ $) 77 (|has| |#1| (-353)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) 83 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1082) |#1|) NIL) (($ $ (-638 (-1082)) (-638 |#1|)) NIL) (($ $ (-1082) $) NIL) (($ $ (-638 (-1082)) (-638 $)) NIL)) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-3277 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-413 $) (-413 $) (-413 $)) NIL (|has| |#1| (-562))) ((|#1| (-413 $) |#1|) NIL (|has| |#1| (-368))) (((-413 $) $ (-413 $)) NIL (|has| |#1| (-562)))) (-1997 (((-3 $ "failed") $ (-769)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 85 (|has| |#1| (-368)))) (-2119 (($ $ (-1082)) NIL (|has| |#1| (-174))) ((|#1| $) NIL (|has| |#1| (-174)))) (-3139 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-4316 (((-769) $) 31) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-1082) (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) NIL (|has| |#1| (-457))) (($ $ (-1082)) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-4544 (((-965 $)) 35)) (-2268 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562))) (((-3 (-413 $) "failed") (-413 $) $) NIL (|has| |#1| (-562)))) (-3972 (((-856) $) 60) (($ (-572)) NIL) (($ |#1|) 57) (($ (-1082)) NIL) (($ |#2|) 67) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) 62) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 20 T CONST)) (-2277 (((-1259 |#1|) $) 74)) (-2581 (($ (-1259 |#1|)) 49)) (-3255 (($) 8 T CONST)) (-1557 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3009 (((-1259 |#1|) $) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) 68)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) 71) (($ $ $) NIL)) (-1367 (($ $ $) 32)) (** (($ $ (-923)) NIL) (($ $ (-769)) 79)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 56) (($ $ $) 73) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 54) (($ $ |#1|) NIL))) 
-(((-708 |#1| |#2|) (-13 (-1234 |#1|) (-10 -8 (-15 -2127 (|#2| |#2|)) (-15 -3195 (|#2|)) (-15 -3116 ($ |#2|)) (-15 -3111 (|#2| $)) (-15 -3972 ($ |#2|)) (-15 -2277 ((-1259 |#1|) $)) (-15 -2581 ($ (-1259 |#1|))) (-15 -3009 ((-1259 |#1|) $)) (-15 -3341 ((-965 $))) (-15 -4544 ((-965 $))) (IF (|has| |#1| (-353)) (-15 -3362 ($ $)) |noBranch|) (IF (|has| |#1| (-374)) (-6 (-374)) |noBranch|))) (-1054) (-1234 |#1|)) (T -708)) 
-((-2127 (*1 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-708 *3 *2)) (-4 *2 (-1234 *3)))) (-3195 (*1 *2) (-12 (-4 *2 (-1234 *3)) (-5 *1 (-708 *3 *2)) (-4 *3 (-1054)))) (-3116 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-708 *3 *2)) (-4 *2 (-1234 *3)))) (-3111 (*1 *2 *1) (-12 (-4 *2 (-1234 *3)) (-5 *1 (-708 *3 *2)) (-4 *3 (-1054)))) (-3972 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-708 *3 *2)) (-4 *2 (-1234 *3)))) (-2277 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-1259 *3)) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3)))) (-2581 (*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-1054)) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3)))) (-3009 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-1259 *3)) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3)))) (-3341 (*1 *2) (-12 (-4 *3 (-1054)) (-5 *2 (-965 (-708 *3 *4))) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3)))) (-4544 (*1 *2) (-12 (-4 *3 (-1054)) (-5 *2 (-965 (-708 *3 *4))) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3)))) (-3362 (*1 *1 *1) (-12 (-4 *2 (-353)) (-4 *2 (-1054)) (-5 *1 (-708 *2 *3)) (-4 *3 (-1234 *2))))) 
-(-13 (-1234 |#1|) (-10 -8 (-15 -2127 (|#2| |#2|)) (-15 -3195 (|#2|)) (-15 -3116 ($ |#2|)) (-15 -3111 (|#2| $)) (-15 -3972 ($ |#2|)) (-15 -2277 ((-1259 |#1|) $)) (-15 -2581 ($ (-1259 |#1|))) (-15 -3009 ((-1259 |#1|) $)) (-15 -3341 ((-965 $))) (-15 -4544 ((-965 $))) (IF (|has| |#1| (-353)) (-15 -3362 ($ $)) |noBranch|) (IF (|has| |#1| (-374)) (-6 (-374)) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-1763 ((|#1| $) 13)) (-2607 (((-1116) $) NIL)) (-3751 ((|#2| $) 12)) (-3921 (($ |#1| |#2|) 16)) (-3972 (((-856) $) NIL) (($ (-2 (|:| -1763 |#1|) (|:| -3751 |#2|))) 15) (((-2 (|:| -1763 |#1|) (|:| -3751 |#2|)) $) 14)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 11))) 
-(((-709 |#1| |#2| |#3|) (-13 (-848) (-10 -8 (-15 -3751 (|#2| $)) (-15 -1763 (|#1| $)) (-15 -3972 ($ (-2 (|:| -1763 |#1|) (|:| -3751 |#2|)))) (-15 -3972 ((-2 (|:| -1763 |#1|) (|:| -3751 |#2|)) $)) (-15 -3921 ($ |#1| |#2|)))) (-848) (-1098) (-1 (-121) (-2 (|:| -1763 |#1|) (|:| -3751 |#2|)) (-2 (|:| -1763 |#1|) (|:| -3751 |#2|)))) (T -709)) 
-((-3751 (*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-709 *3 *2 *4)) (-4 *3 (-848)) (-14 *4 (-1 (-121) (-2 (|:| -1763 *3) (|:| -3751 *2)) (-2 (|:| -1763 *3) (|:| -3751 *2)))))) (-1763 (*1 *2 *1) (-12 (-4 *2 (-848)) (-5 *1 (-709 *2 *3 *4)) (-4 *3 (-1098)) (-14 *4 (-1 (-121) (-2 (|:| -1763 *2) (|:| -3751 *3)) (-2 (|:| -1763 *2) (|:| -3751 *3)))))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -1763 *3) (|:| -3751 *4))) (-4 *3 (-848)) (-4 *4 (-1098)) (-5 *1 (-709 *3 *4 *5)) (-14 *5 (-1 (-121) *2 *2)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -1763 *3) (|:| -3751 *4))) (-5 *1 (-709 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-1098)) (-14 *5 (-1 (-121) *2 *2)))) (-3921 (*1 *1 *2 *3) (-12 (-5 *1 (-709 *2 *3 *4)) (-4 *2 (-848)) (-4 *3 (-1098)) (-14 *4 (-1 (-121) (-2 (|:| -1763 *2) (|:| -3751 *3)) (-2 (|:| -1763 *2) (|:| -3751 *3))))))) 
-(-13 (-848) (-10 -8 (-15 -3751 (|#2| $)) (-15 -1763 (|#1| $)) (-15 -3972 ($ (-2 (|:| -1763 |#1|) (|:| -3751 |#2|)))) (-15 -3972 ((-2 (|:| -1763 |#1|) (|:| -3751 |#2|)) $)) (-15 -3921 ($ |#1| |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 59)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 89) (((-3 (-123) "failed") $) 95)) (-1318 ((|#1| $) NIL) (((-123) $) 39)) (-1799 (((-3 $ "failed") $) 90)) (-1464 ((|#2| (-123) |#2|) 82)) (-3893 (((-121) $) NIL)) (-3708 (($ |#1| (-366 (-123))) 13)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1625 (($ $ (-1 |#2| |#2|)) 58)) (-3949 (($ $ (-1 |#2| |#2|)) 44)) (-3277 ((|#2| $ |#2|) 32)) (-1739 ((|#1| |#1|) 100 (|has| |#1| (-174)))) (-3972 (((-856) $) 66) (($ (-572)) 17) (($ |#1|) 16) (($ (-123)) 23)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) 36)) (-2527 (($ $) 99 (|has| |#1| (-174))) (($ $ $) 103 (|has| |#1| (-174)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 20 T CONST)) (-3255 (($) 9 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) 48) (($ $ $) NIL)) (-1367 (($ $ $) 73)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ (-123) (-572)) NIL) (($ $ (-572)) 57)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 98) (($ $ $) 50) (($ |#1| $) 96 (|has| |#1| (-174))) (($ $ |#1|) 97 (|has| |#1| (-174))))) 
-(((-710 |#1| |#2|) (-13 (-1054) (-1044 |#1|) (-1044 (-123)) (-283 |#2| |#2|) (-10 -8 (IF (|has| |#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |#1| (-174)) (PROGN (-6 (-43 |#1|)) (-15 -2527 ($ $)) (-15 -2527 ($ $ $)) (-15 -1739 (|#1| |#1|))) |noBranch|) (-15 -3949 ($ $ (-1 |#2| |#2|))) (-15 -1625 ($ $ (-1 |#2| |#2|))) (-15 ** ($ (-123) (-572))) (-15 ** ($ $ (-572))) (-15 -1464 (|#2| (-123) |#2|)) (-15 -3708 ($ |#1| (-366 (-123)))))) (-1054) (-641 |#1|)) (T -710)) 
-((-2527 (*1 *1 *1) (-12 (-4 *2 (-174)) (-4 *2 (-1054)) (-5 *1 (-710 *2 *3)) (-4 *3 (-641 *2)))) (-2527 (*1 *1 *1 *1) (-12 (-4 *2 (-174)) (-4 *2 (-1054)) (-5 *1 (-710 *2 *3)) (-4 *3 (-641 *2)))) (-1739 (*1 *2 *2) (-12 (-4 *2 (-174)) (-4 *2 (-1054)) (-5 *1 (-710 *2 *3)) (-4 *3 (-641 *2)))) (-3949 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-641 *3)) (-4 *3 (-1054)) (-5 *1 (-710 *3 *4)))) (-1625 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-641 *3)) (-4 *3 (-1054)) (-5 *1 (-710 *3 *4)))) (** (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-572)) (-4 *4 (-1054)) (-5 *1 (-710 *4 *5)) (-4 *5 (-641 *4)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *3 (-1054)) (-5 *1 (-710 *3 *4)) (-4 *4 (-641 *3)))) (-1464 (*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-4 *4 (-1054)) (-5 *1 (-710 *4 *2)) (-4 *2 (-641 *4)))) (-3708 (*1 *1 *2 *3) (-12 (-5 *3 (-366 (-123))) (-4 *2 (-1054)) (-5 *1 (-710 *2 *4)) (-4 *4 (-641 *2))))) 
-(-13 (-1054) (-1044 |#1|) (-1044 (-123)) (-283 |#2| |#2|) (-10 -8 (IF (|has| |#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |#1| (-174)) (PROGN (-6 (-43 |#1|)) (-15 -2527 ($ $)) (-15 -2527 ($ $ $)) (-15 -1739 (|#1| |#1|))) |noBranch|) (-15 -3949 ($ $ (-1 |#2| |#2|))) (-15 -1625 ($ $ (-1 |#2| |#2|))) (-15 ** ($ (-123) (-572))) (-15 ** ($ $ (-572))) (-15 -1464 (|#2| (-123) |#2|)) (-15 -3708 ($ |#1| (-366 (-123)))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 33)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3116 (($ |#1| |#2|) 25)) (-1799 (((-3 $ "failed") $) 47)) (-3893 (((-121) $) 35)) (-3195 ((|#2| $) 12)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 48)) (-2607 (((-1116) $) NIL)) (-1698 (((-3 $ "failed") $ $) 46)) (-3972 (((-856) $) 24) (($ (-572)) 19) ((|#1| $) 13)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 16 T CONST)) (-3255 (($) 30 T CONST)) (-1324 (((-121) $ $) 38)) (-1373 (($ $) 43) (($ $ $) 37)) (-1367 (($ $ $) 40)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 21) (($ $ $) 20))) 
-(((-711 |#1| |#2| |#3| |#4| |#5|) (-13 (-1054) (-10 -8 (-15 -3195 (|#2| $)) (-15 -3972 (|#1| $)) (-15 -3116 ($ |#1| |#2|)) (-15 -1698 ((-3 $ "failed") $ $)) (-15 -1799 ((-3 $ "failed") $)) (-15 -4350 ($ $)))) (-174) (-23) (-1 |#1| |#1| |#2|) (-1 (-3 |#2| "failed") |#2| |#2|) (-1 (-3 |#1| "failed") |#1| |#1| |#2|)) (T -711)) 
-((-1799 (*1 *1 *1) (|partial| -12 (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3195 (*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-711 *3 *2 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) (-3972 (*1 *2 *1) (-12 (-4 *2 (-174)) (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3116 (*1 *1 *2 *3) (-12 (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-1698 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-4350 (*1 *1 *1) (-12 (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
-(-13 (-1054) (-10 -8 (-15 -3195 (|#2| $)) (-15 -3972 (|#1| $)) (-15 -3116 ($ |#1| |#2|)) (-15 -1698 ((-3 $ "failed") $ $)) (-15 -1799 ((-3 $ "failed") $)) (-15 -4350 ($ $)))) 
-((* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ |#2| $) NIL) (($ $ |#2|) 9))) 
-(((-712 |#1| |#2|) (-10 -8 (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) (-713 |#2|) (-174)) (T -712)) 
-NIL 
-(-10 -8 (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
-(((-713 |#1|) (-1290) (-174)) (T -713)) 
-NIL 
-(-13 (-120 |t#1| |t#1|)) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-1060 |#1|) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-3351 (($ |#1|) 17) (($ $ |#1|) 20)) (-1355 (($ |#1|) 18) (($ $ |#1|) 21)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL) (($) 19) (($ $) 22)) (-3893 (((-121) $) NIL)) (-3601 (($ |#1| |#1| |#1| |#1|) 8)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 16)) (-2607 (((-1116) $) NIL)) (-4485 ((|#1| $ |#1|) 24) (((-834 |#1|) $ (-834 |#1|)) 32)) (-3018 (($ $ $) NIL)) (-4056 (($ $ $) NIL)) (-3972 (((-856) $) 39)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-3255 (($) 9 T CONST)) (-1324 (((-121) $ $) 44)) (-1379 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ $ $) 14))) 
-(((-714 |#1|) (-13 (-482) (-10 -8 (-15 -3601 ($ |#1| |#1| |#1| |#1|)) (-15 -3351 ($ |#1|)) (-15 -1355 ($ |#1|)) (-15 -1799 ($)) (-15 -3351 ($ $ |#1|)) (-15 -1355 ($ $ |#1|)) (-15 -1799 ($ $)) (-15 -4485 (|#1| $ |#1|)) (-15 -4485 ((-834 |#1|) $ (-834 |#1|))))) (-368)) (T -714)) 
-((-3601 (*1 *1 *2 *2 *2 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) (-3351 (*1 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) (-1355 (*1 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) (-1799 (*1 *1) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) (-3351 (*1 *1 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) (-1355 (*1 *1 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) (-1799 (*1 *1 *1) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) (-4485 (*1 *2 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) (-4485 (*1 *2 *1 *2) (-12 (-5 *2 (-834 *3)) (-4 *3 (-368)) (-5 *1 (-714 *3))))) 
-(-13 (-482) (-10 -8 (-15 -3601 ($ |#1| |#1| |#1| |#1|)) (-15 -3351 ($ |#1|)) (-15 -1355 ($ |#1|)) (-15 -1799 ($)) (-15 -3351 ($ $ |#1|)) (-15 -1355 ($ $ |#1|)) (-15 -1799 ($ $)) (-15 -4485 (|#1| $ |#1|)) (-15 -4485 ((-834 |#1|) $ (-834 |#1|))))) 
-((-3014 (($ $ (-923)) 12)) (-3276 (($ $ (-923)) 13)) (** (($ $ (-923)) 10))) 
-(((-715 |#1|) (-10 -8 (-15 ** (|#1| |#1| (-923))) (-15 -3276 (|#1| |#1| (-923))) (-15 -3014 (|#1| |#1| (-923)))) (-716)) (T -715)) 
-NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-923))) (-15 -3276 (|#1| |#1| (-923))) (-15 -3014 (|#1| |#1| (-923)))) 
-((-2262 (((-121) $ $) 7)) (-3014 (($ $ (-923)) 14)) (-3276 (($ $ (-923)) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6)) (** (($ $ (-923)) 12)) (* (($ $ $) 15))) 
-(((-716) (-1290)) (T -716)) 
-((* (*1 *1 *1 *1) (-4 *1 (-716))) (-3014 (*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-923)))) (-3276 (*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-923)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-923))))) 
-(-13 (-1098) (-10 -8 (-15 * ($ $ $)) (-15 -3014 ($ $ (-923))) (-15 -3276 ($ $ (-923))) (-15 ** ($ $ (-923))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-3014 (($ $ (-923)) NIL) (($ $ (-769)) 17)) (-3893 (((-121) $) 10)) (-3276 (($ $ (-923)) NIL) (($ $ (-769)) 18)) (** (($ $ (-923)) NIL) (($ $ (-769)) 15))) 
-(((-717 |#1|) (-10 -8 (-15 ** (|#1| |#1| (-769))) (-15 -3276 (|#1| |#1| (-769))) (-15 -3014 (|#1| |#1| (-769))) (-15 -3893 ((-121) |#1|)) (-15 ** (|#1| |#1| (-923))) (-15 -3276 (|#1| |#1| (-923))) (-15 -3014 (|#1| |#1| (-923)))) (-718)) (T -717)) 
-NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-769))) (-15 -3276 (|#1| |#1| (-769))) (-15 -3014 (|#1| |#1| (-769))) (-15 -3893 ((-121) |#1|)) (-15 ** (|#1| |#1| (-923))) (-15 -3276 (|#1| |#1| (-923))) (-15 -3014 (|#1| |#1| (-923)))) 
-((-2262 (((-121) $ $) 7)) (-2848 (((-3 $ "failed") $) 16)) (-3014 (($ $ (-923)) 14) (($ $ (-769)) 21)) (-1799 (((-3 $ "failed") $) 18)) (-3893 (((-121) $) 22)) (-2046 (((-3 $ "failed") $) 17)) (-3276 (($ $ (-923)) 13) (($ $ (-769)) 20)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-3255 (($) 23 T CONST)) (-1324 (((-121) $ $) 6)) (** (($ $ (-923)) 12) (($ $ (-769)) 19)) (* (($ $ $) 15))) 
-(((-718) (-1290)) (T -718)) 
-((-3255 (*1 *1) (-4 *1 (-718))) (-3893 (*1 *2 *1) (-12 (-4 *1 (-718)) (-5 *2 (-121)))) (-3014 (*1 *1 *1 *2) (-12 (-4 *1 (-718)) (-5 *2 (-769)))) (-3276 (*1 *1 *1 *2) (-12 (-4 *1 (-718)) (-5 *2 (-769)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-718)) (-5 *2 (-769)))) (-1799 (*1 *1 *1) (|partial| -4 *1 (-718))) (-2046 (*1 *1 *1) (|partial| -4 *1 (-718))) (-2848 (*1 *1 *1) (|partial| -4 *1 (-718)))) 
-(-13 (-716) (-10 -8 (-15 (-3255) ($) -3211) (-15 -3893 ((-121) $)) (-15 -3014 ($ $ (-769))) (-15 -3276 ($ $ (-769))) (-15 ** ($ $ (-769))) (-15 -1799 ((-3 $ "failed") $)) (-15 -2046 ((-3 $ "failed") $)) (-15 -2848 ((-3 $ "failed") $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-716) . T) ((-1098) . T)) 
-((-1685 (((-769)) 35)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 |#2| "failed") $) 25)) (-1318 (((-572) $) NIL) (((-413 (-572)) $) NIL) ((|#2| $) 22)) (-3116 (($ |#3|) NIL) (((-3 $ "failed") (-413 |#3|)) 45)) (-1799 (((-3 $ "failed") $) 65)) (-3286 (($) 39)) (-4429 ((|#2| $) 20)) (-2307 (($) 17)) (-3139 (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) 53) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL) (($ $ (-769)) NIL) (($ $) NIL)) (-3482 (((-685 |#2|) (-1259 $) (-1 |#2| |#2|)) 60)) (-4081 (((-1259 |#2|) $) NIL) (($ (-1259 |#2|)) NIL) ((|#3| $) 10) (($ |#3|) 12)) (-2707 ((|#3| $) 32)) (-2237 (((-1259 $)) 29))) 
-(((-719 |#1| |#2| |#3|) (-10 -8 (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3286 (|#1|)) (-15 -1685 ((-769))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3482 ((-685 |#2|) (-1259 |#1|) (-1 |#2| |#2|))) (-15 -3116 ((-3 |#1| "failed") (-413 |#3|))) (-15 -4081 (|#1| |#3|)) (-15 -3116 (|#1| |#3|)) (-15 -2307 (|#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -4081 (|#3| |#1|)) (-15 -4081 (|#1| (-1259 |#2|))) (-15 -4081 ((-1259 |#2|) |#1|)) (-15 -2237 ((-1259 |#1|))) (-15 -2707 (|#3| |#1|)) (-15 -4429 (|#2| |#1|)) (-15 -1799 ((-3 |#1| "failed") |#1|))) (-720 |#2| |#3|) (-174) (-1234 |#2|)) (T -719)) 
-((-1685 (*1 *2) (-12 (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-769)) (-5 *1 (-719 *3 *4 *5)) (-4 *3 (-720 *4 *5))))) 
-(-10 -8 (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3286 (|#1|)) (-15 -1685 ((-769))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3482 ((-685 |#2|) (-1259 |#1|) (-1 |#2| |#2|))) (-15 -3116 ((-3 |#1| "failed") (-413 |#3|))) (-15 -4081 (|#1| |#3|)) (-15 -3116 (|#1| |#3|)) (-15 -2307 (|#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -4081 (|#3| |#1|)) (-15 -4081 (|#1| (-1259 |#2|))) (-15 -4081 ((-1259 |#2|) |#1|)) (-15 -2237 ((-1259 |#1|))) (-15 -2707 (|#3| |#1|)) (-15 -4429 (|#2| |#1|)) (-15 -1799 ((-3 |#1| "failed") |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 88 (|has| |#1| (-368)))) (-3946 (($ $) 89 (|has| |#1| (-368)))) (-3686 (((-121) $) 91 (|has| |#1| (-368)))) (-1845 (((-685 |#1|) (-1259 $)) 44) (((-685 |#1|)) 55)) (-3520 ((|#1| $) 50)) (-3617 (((-1178 (-923) (-769)) (-572)) 142 (|has| |#1| (-353)))) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 108 (|has| |#1| (-368)))) (-1466 (((-424 $) $) 109 (|has| |#1| (-368)))) (-3112 (((-121) $ $) 99 (|has| |#1| (-368)))) (-1685 (((-769)) 81 (|has| |#1| (-374)))) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 164 (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 162 (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 161)) (-1318 (((-572) $) 165 (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) 163 (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 160)) (-4337 (($ (-1259 |#1|) (-1259 $)) 46) (($ (-1259 |#1|)) 58)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 148 (|has| |#1| (-353)))) (-2190 (($ $ $) 103 (|has| |#1| (-368)))) (-1741 (((-685 |#1|) $ (-1259 $)) 51) (((-685 |#1|) $) 53)) (-2284 (((-685 (-572)) (-685 $)) 159 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 158 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 157) (((-685 |#1|) (-685 $)) 156)) (-3116 (($ |#2|) 153) (((-3 $ "failed") (-413 |#2|)) 150 (|has| |#1| (-368)))) (-1799 (((-3 $ "failed") $) 33)) (-2667 (((-923)) 52)) (-3286 (($) 84 (|has| |#1| (-374)))) (-2208 (($ $ $) 102 (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 97 (|has| |#1| (-368)))) (-2754 (($) 144 (|has| |#1| (-353)))) (-1297 (((-121) $) 145 (|has| |#1| (-353)))) (-4486 (($ $ (-769)) 136 (|has| |#1| (-353))) (($ $) 135 (|has| |#1| (-353)))) (-1526 (((-121) $) 110 (|has| |#1| (-368)))) (-3377 (((-923) $) 147 (|has| |#1| (-353))) (((-834 (-923)) $) 133 (|has| |#1| (-353)))) (-3893 (((-121) $) 30)) (-4429 ((|#1| $) 49)) (-3961 (((-3 $ "failed") $) 137 (|has| |#1| (-353)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 106 (|has| |#1| (-368)))) (-3251 ((|#2| $) 42 (|has| |#1| (-368)))) (-3633 (((-923) $) 83 (|has| |#1| (-374)))) (-3111 ((|#2| $) 151)) (-1629 (($ (-638 $)) 95 (|has| |#1| (-368))) (($ $ $) 94 (|has| |#1| (-368)))) (-1658 (((-1152) $) 9)) (-4350 (($ $) 111 (|has| |#1| (-368)))) (-1773 (($) 138 (|has| |#1| (-353)) CONST)) (-1763 (($ (-923)) 82 (|has| |#1| (-374)))) (-2607 (((-1116) $) 10)) (-2307 (($) 155)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 96 (|has| |#1| (-368)))) (-3069 (($ (-638 $)) 93 (|has| |#1| (-368))) (($ $ $) 92 (|has| |#1| (-368)))) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 141 (|has| |#1| (-353)))) (-4304 (((-424 $) $) 107 (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105 (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 104 (|has| |#1| (-368)))) (-1803 (((-3 $ "failed") $ $) 87 (|has| |#1| (-368)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 98 (|has| |#1| (-368)))) (-4029 (((-769) $) 100 (|has| |#1| (-368)))) (-3587 (((-638 $)) 85 (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 101 (|has| |#1| (-368)))) (-2119 ((|#1| (-1259 $)) 45) ((|#1|) 54)) (-3158 (((-769) $) 146 (|has| |#1| (-353))) (((-3 (-769) "failed") $ $) 134 (|has| |#1| (-353)))) (-3139 (($ $) 132 (-1841 (-4028 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353)))) (($ $ (-769)) 130 (-1841 (-4028 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353)))) (($ $ (-1170)) 128 (-4028 (|has| |#1| (-901 (-1170))) (|has| |#1| (-368)))) (($ $ (-638 (-1170))) 127 (-4028 (|has| |#1| (-901 (-1170))) (|has| |#1| (-368)))) (($ $ (-1170) (-769)) 126 (-4028 (|has| |#1| (-901 (-1170))) (|has| |#1| (-368)))) (($ $ (-638 (-1170)) (-638 (-769))) 125 (-4028 (|has| |#1| (-901 (-1170))) (|has| |#1| (-368)))) (($ $ (-1 |#1| |#1|) (-769)) 118 (|has| |#1| (-368))) (($ $ (-1 |#1| |#1|)) 117 (|has| |#1| (-368)))) (-3482 (((-685 |#1|) (-1259 $) (-1 |#1| |#1|)) 149 (|has| |#1| (-368)))) (-2830 ((|#2|) 154)) (-2278 (($) 143 (|has| |#1| (-353)))) (-3160 (((-1259 |#1|) $ (-1259 $)) 48) (((-685 |#1|) (-1259 $) (-1259 $)) 47) (((-1259 |#1|) $) 60) (((-685 |#1|) (-1259 $)) 59)) (-4081 (((-1259 |#1|) $) 57) (($ (-1259 |#1|)) 56) ((|#2| $) 166) (($ |#2|) 152)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 140 (|has| |#1| (-353)))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 36) (($ $) 86 (|has| |#1| (-368))) (($ (-413 (-572))) 80 (-1841 (|has| |#1| (-368)) (|has| |#1| (-1044 (-413 (-572))))))) (-2779 (($ $) 139 (|has| |#1| (-353))) (((-3 $ "failed") $) 41 (|has| |#1| (-149)))) (-2707 ((|#2| $) 43)) (-2140 (((-769)) 28)) (-2237 (((-1259 $)) 61)) (-3774 (((-121) $ $) 90 (|has| |#1| (-368)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 112 (|has| |#1| (-368)))) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $) 131 (-1841 (-4028 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353)))) (($ $ (-769)) 129 (-1841 (-4028 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353)))) (($ $ (-1170)) 124 (-4028 (|has| |#1| (-901 (-1170))) (|has| |#1| (-368)))) (($ $ (-638 (-1170))) 123 (-4028 (|has| |#1| (-901 (-1170))) (|has| |#1| (-368)))) (($ $ (-1170) (-769)) 122 (-4028 (|has| |#1| (-901 (-1170))) (|has| |#1| (-368)))) (($ $ (-638 (-1170)) (-638 (-769))) 121 (-4028 (|has| |#1| (-901 (-1170))) (|has| |#1| (-368)))) (($ $ (-1 |#1| |#1|) (-769)) 120 (|has| |#1| (-368))) (($ $ (-1 |#1| |#1|)) 119 (|has| |#1| (-368)))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 116 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 113 (|has| |#1| (-368)))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ (-413 (-572)) $) 115 (|has| |#1| (-368))) (($ $ (-413 (-572))) 114 (|has| |#1| (-368))))) 
-(((-720 |#1| |#2|) (-1290) (-174) (-1234 |t#1|)) (T -720)) 
-((-2307 (*1 *1) (-12 (-4 *2 (-174)) (-4 *1 (-720 *2 *3)) (-4 *3 (-1234 *2)))) (-2830 (*1 *2) (-12 (-4 *1 (-720 *3 *2)) (-4 *3 (-174)) (-4 *2 (-1234 *3)))) (-3116 (*1 *1 *2) (-12 (-4 *3 (-174)) (-4 *1 (-720 *3 *2)) (-4 *2 (-1234 *3)))) (-4081 (*1 *1 *2) (-12 (-4 *3 (-174)) (-4 *1 (-720 *3 *2)) (-4 *2 (-1234 *3)))) (-3111 (*1 *2 *1) (-12 (-4 *1 (-720 *3 *2)) (-4 *3 (-174)) (-4 *2 (-1234 *3)))) (-3116 (*1 *1 *2) (|partial| -12 (-5 *2 (-413 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-368)) (-4 *3 (-174)) (-4 *1 (-720 *3 *4)))) (-3482 (*1 *2 *3 *4) (-12 (-5 *3 (-1259 *1)) (-5 *4 (-1 *5 *5)) (-4 *5 (-368)) (-4 *1 (-720 *5 *6)) (-4 *5 (-174)) (-4 *6 (-1234 *5)) (-5 *2 (-685 *5))))) 
-(-13 (-415 |t#1| |t#2|) (-174) (-613 |t#2|) (-417 |t#1|) (-383 |t#1|) (-10 -8 (-15 -2307 ($)) (-15 -2830 (|t#2|)) (-15 -3116 ($ |t#2|)) (-15 -4081 ($ |t#2|)) (-15 -3111 (|t#2| $)) (IF (|has| |t#1| (-374)) (-6 (-374)) |noBranch|) (IF (|has| |t#1| (-368)) (PROGN (-6 (-368)) (-6 (-225 |t#1|)) (-15 -3116 ((-3 $ "failed") (-413 |t#2|))) (-15 -3482 ((-685 |t#1|) (-1259 $) (-1 |t#1| |t#1|)))) |noBranch|) (IF (|has| |t#1| (-353)) (-6 (-353)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-43 |#1|) . T) ((-43 $) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-138) . T) ((-149) -1841 (|has| |#1| (-353)) (|has| |#1| (-149))) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) . T) ((-613 |#2|) . T) ((-225 |#1|) |has| |#1| (-368)) ((-227) -1841 (|has| |#1| (-353)) (-12 (|has| |#1| (-227)) (|has| |#1| (-368)))) ((-240) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-287) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-303) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-368) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-408) |has| |#1| (-353)) ((-374) -1841 (|has| |#1| (-374)) (|has| |#1| (-353))) ((-353) |has| |#1| (-353)) ((-376 |#1| |#2|) . T) ((-415 |#1| |#2|) . T) ((-383 |#1|) . T) ((-417 |#1|) . T) ((-457) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-562) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-641 (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-641 |#1|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-713 (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-713 |#1|) . T) ((-713 $) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-722) . T) ((-901 (-1170)) -12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170)))) ((-922) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) -1841 (|has| |#1| (-353)) (|has| |#1| (-368))) ((-1060 |#1|) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) |has| |#1| (-353)) ((-1214) -1841 (|has| |#1| (-353)) (|has| |#1| (-368)))) 
-((-2211 (($) 14)) (-1799 (((-3 $ "failed") $) 16)) (-3893 (((-121) $) 13)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) 9)) (** (($ $ (-923)) NIL) (($ $ (-769)) 20))) 
-(((-721 |#1|) (-10 -8 (-15 -1799 ((-3 |#1| "failed") |#1|)) (-15 -4174 (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-769))) (-15 -3893 ((-121) |#1|)) (-15 -2211 (|#1|)) (-15 -4174 (|#1| |#1| (-923))) (-15 ** (|#1| |#1| (-923)))) (-722)) (T -721)) 
-NIL 
-(-10 -8 (-15 -1799 ((-3 |#1| "failed") |#1|)) (-15 -4174 (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-769))) (-15 -3893 ((-121) |#1|)) (-15 -2211 (|#1|)) (-15 -4174 (|#1| |#1| (-923))) (-15 ** (|#1| |#1| (-923)))) 
-((-2262 (((-121) $ $) 7)) (-2211 (($) 19 T CONST)) (-1799 (((-3 $ "failed") $) 15)) (-3893 (((-121) $) 18)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-4174 (($ $ (-923)) 12) (($ $ (-769)) 16)) (-3255 (($) 20 T CONST)) (-1324 (((-121) $ $) 6)) (** (($ $ (-923)) 13) (($ $ (-769)) 17)) (* (($ $ $) 14))) 
-(((-722) (-1290)) (T -722)) 
-((-3255 (*1 *1) (-4 *1 (-722))) (-2211 (*1 *1) (-4 *1 (-722))) (-3893 (*1 *2 *1) (-12 (-4 *1 (-722)) (-5 *2 (-121)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-722)) (-5 *2 (-769)))) (-4174 (*1 *1 *1 *2) (-12 (-4 *1 (-722)) (-5 *2 (-769)))) (-1799 (*1 *1 *1) (|partial| -4 *1 (-722)))) 
-(-13 (-1110) (-10 -8 (-15 (-3255) ($) -3211) (-15 -2211 ($) -3211) (-15 -3893 ((-121) $)) (-15 ** ($ $ (-769))) (-15 -4174 ($ $ (-769))) (-15 -1799 ((-3 $ "failed") $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1110) . T) ((-1098) . T)) 
-((-3308 (((-2 (|:| -2071 (-424 |#2|)) (|:| |special| (-424 |#2|))) |#2| (-1 |#2| |#2|)) 38)) (-1585 (((-2 (|:| -2071 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|)) 12)) (-4519 ((|#2| (-413 |#2|) (-1 |#2| |#2|)) 13)) (-2880 (((-2 (|:| |poly| |#2|) (|:| -2071 (-413 |#2|)) (|:| |special| (-413 |#2|))) (-413 |#2|) (-1 |#2| |#2|)) 47))) 
-(((-723 |#1| |#2|) (-10 -7 (-15 -1585 ((-2 (|:| -2071 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|))) (-15 -3308 ((-2 (|:| -2071 (-424 |#2|)) (|:| |special| (-424 |#2|))) |#2| (-1 |#2| |#2|))) (-15 -4519 (|#2| (-413 |#2|) (-1 |#2| |#2|))) (-15 -2880 ((-2 (|:| |poly| |#2|) (|:| -2071 (-413 |#2|)) (|:| |special| (-413 |#2|))) (-413 |#2|) (-1 |#2| |#2|)))) (-368) (-1234 |#1|)) (T -723)) 
-((-2880 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |poly| *6) (|:| -2071 (-413 *6)) (|:| |special| (-413 *6)))) (-5 *1 (-723 *5 *6)) (-5 *3 (-413 *6)))) (-4519 (*1 *2 *3 *4) (-12 (-5 *3 (-413 *2)) (-5 *4 (-1 *2 *2)) (-4 *2 (-1234 *5)) (-5 *1 (-723 *5 *2)) (-4 *5 (-368)))) (-3308 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| -2071 (-424 *3)) (|:| |special| (-424 *3)))) (-5 *1 (-723 *5 *3)))) (-1585 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| -2071 *3) (|:| |special| *3))) (-5 *1 (-723 *5 *3))))) 
-(-10 -7 (-15 -1585 ((-2 (|:| -2071 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|))) (-15 -3308 ((-2 (|:| -2071 (-424 |#2|)) (|:| |special| (-424 |#2|))) |#2| (-1 |#2| |#2|))) (-15 -4519 (|#2| (-413 |#2|) (-1 |#2| |#2|))) (-15 -2880 ((-2 (|:| |poly| |#2|) (|:| -2071 (-413 |#2|)) (|:| |special| (-413 |#2|))) (-413 |#2|) (-1 |#2| |#2|)))) 
-((-2675 ((|#7| (-638 |#5|) |#6|) NIL)) (-3828 ((|#7| (-1 |#5| |#4|) |#6|) 26))) 
-(((-724 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -3828 (|#7| (-1 |#5| |#4|) |#6|)) (-15 -2675 (|#7| (-638 |#5|) |#6|))) (-848) (-794) (-794) (-1054) (-1054) (-956 |#4| |#2| |#1|) (-956 |#5| |#3| |#1|)) (T -724)) 
-((-2675 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *9)) (-4 *9 (-1054)) (-4 *5 (-848)) (-4 *6 (-794)) (-4 *8 (-1054)) (-4 *2 (-956 *9 *7 *5)) (-5 *1 (-724 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-794)) (-4 *4 (-956 *8 *6 *5)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *8)) (-4 *8 (-1054)) (-4 *9 (-1054)) (-4 *5 (-848)) (-4 *6 (-794)) (-4 *2 (-956 *9 *7 *5)) (-5 *1 (-724 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-794)) (-4 *4 (-956 *8 *6 *5))))) 
-(-10 -7 (-15 -3828 (|#7| (-1 |#5| |#4|) |#6|)) (-15 -2675 (|#7| (-638 |#5|) |#6|))) 
-((-3828 ((|#7| (-1 |#2| |#1|) |#6|) 28))) 
-(((-725 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -3828 (|#7| (-1 |#2| |#1|) |#6|))) (-848) (-848) (-794) (-794) (-1054) (-956 |#5| |#3| |#1|) (-956 |#5| |#4| |#2|)) (T -725)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-848)) (-4 *6 (-848)) (-4 *7 (-794)) (-4 *9 (-1054)) (-4 *2 (-956 *9 *8 *6)) (-5 *1 (-725 *5 *6 *7 *8 *9 *4 *2)) (-4 *8 (-794)) (-4 *4 (-956 *9 *7 *5))))) 
-(-10 -7 (-15 -3828 (|#7| (-1 |#2| |#1|) |#6|))) 
-((-4304 (((-424 |#4|) |#4|) 39))) 
-(((-726 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4304 ((-424 |#4|) |#4|))) (-794) (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170))))) (-303) (-956 (-959 |#3|) |#1| |#2|)) (T -726)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-4 *6 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-726 *4 *5 *6 *3)) (-4 *3 (-956 (-959 *6) *4 *5))))) 
-(-10 -7 (-15 -4304 ((-424 |#4|) |#4|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-858 |#1|)) $) NIL)) (-4297 (((-1166 $) $ (-858 |#1|)) NIL) (((-1166 |#2|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#2| (-562)))) (-3946 (($ $) NIL (|has| |#2| (-562)))) (-3686 (((-121) $) NIL (|has| |#2| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-858 |#1|))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2844 (($ $) NIL (|has| |#2| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#2| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-858 |#1|) "failed") $) NIL)) (-1318 ((|#2| $) NIL) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-858 |#1|) $) NIL)) (-3190 (($ $ $ (-858 |#1|)) NIL (|has| |#2| (-174)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#2| (-457))) (($ $ (-858 |#1|)) NIL (|has| |#2| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#2| (-910)))) (-3977 (($ $ |#2| (-538 (-858 |#1|)) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-858 |#1|) (-887 (-385))) (|has| |#2| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-858 |#1|) (-887 (-572))) (|has| |#2| (-887 (-572)))))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-4335 (($ (-1166 |#2|) (-858 |#1|)) NIL) (($ (-1166 $) (-858 |#1|)) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#2| (-538 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-858 |#1|)) NIL)) (-1784 (((-538 (-858 |#1|)) $) NIL) (((-769) $ (-858 |#1|)) NIL) (((-638 (-769)) $ (-638 (-858 |#1|))) NIL)) (-1771 (($ $ $) NIL (|has| |#2| (-848)))) (-4238 (($ $ $) NIL (|has| |#2| (-848)))) (-3918 (($ (-1 (-538 (-858 |#1|)) (-538 (-858 |#1|))) $) NIL)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-1470 (((-3 (-858 |#1|) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#2| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-1658 (((-1152) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-858 |#1|)) (|:| -3751 (-769))) "failed") $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#2| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#2| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#2| (-910)))) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-858 |#1|) |#2|) NIL) (($ $ (-638 (-858 |#1|)) (-638 |#2|)) NIL) (($ $ (-858 |#1|) $) NIL) (($ $ (-638 (-858 |#1|)) (-638 $)) NIL)) (-2119 (($ $ (-858 |#1|)) NIL (|has| |#2| (-174)))) (-3139 (($ $ (-858 |#1|)) NIL) (($ $ (-638 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-4316 (((-538 (-858 |#1|)) $) NIL) (((-769) $ (-858 |#1|)) NIL) (((-638 (-769)) $ (-638 (-858 |#1|))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-858 |#1|) (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-858 |#1|) (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-858 |#1|) (-613 (-545))) (|has| |#2| (-613 (-545)))))) (-3694 ((|#2| $) NIL (|has| |#2| (-457))) (($ $ (-858 |#1|)) NIL (|has| |#2| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#2| (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) NIL) (($ (-858 |#1|)) NIL) (($ $) NIL (|has| |#2| (-562))) (($ (-413 (-572))) NIL (-1841 (|has| |#2| (-43 (-413 (-572)))) (|has| |#2| (-1044 (-413 (-572))))))) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-538 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#2| (-910))) (|has| |#2| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#2| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#2| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-858 |#1|)) NIL) (($ $ (-638 (-858 |#1|))) NIL) (($ $ (-858 |#1|) (-769)) NIL) (($ $ (-638 (-858 |#1|)) (-638 (-769))) NIL)) (-1349 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#2| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#2| (-43 (-413 (-572))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-727 |#1| |#2|) (-956 |#2| (-538 (-858 |#1|)) (-858 |#1|)) (-638 (-1170)) (-1054)) (T -727)) 
-NIL 
-(-956 |#2| (-538 (-858 |#1|)) (-858 |#1|)) 
-((-3860 (((-2 (|:| -1614 (-959 |#3|)) (|:| -2685 (-959 |#3|))) |#4|) 13)) (-2164 ((|#4| |#4| |#2|) 30)) (-3713 ((|#4| (-413 (-959 |#3|)) |#2|) 63)) (-4386 ((|#4| (-1166 (-959 |#3|)) |#2|) 76)) (-4468 ((|#4| (-1166 |#4|) |#2|) 49)) (-4385 ((|#4| |#4| |#2|) 52)) (-4304 (((-424 |#4|) |#4|) 38))) 
-(((-728 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3860 ((-2 (|:| -1614 (-959 |#3|)) (|:| -2685 (-959 |#3|))) |#4|)) (-15 -4385 (|#4| |#4| |#2|)) (-15 -4468 (|#4| (-1166 |#4|) |#2|)) (-15 -2164 (|#4| |#4| |#2|)) (-15 -4386 (|#4| (-1166 (-959 |#3|)) |#2|)) (-15 -3713 (|#4| (-413 (-959 |#3|)) |#2|)) (-15 -4304 ((-424 |#4|) |#4|))) (-794) (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)))) (-562) (-956 (-413 (-959 |#3|)) |#1| |#2|)) (T -728)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *6 (-562)) (-5 *2 (-424 *3)) (-5 *1 (-728 *4 *5 *6 *3)) (-4 *3 (-956 (-413 (-959 *6)) *4 *5)))) (-3713 (*1 *2 *3 *4) (-12 (-4 *6 (-562)) (-4 *2 (-956 *3 *5 *4)) (-5 *1 (-728 *5 *4 *6 *2)) (-5 *3 (-413 (-959 *6))) (-4 *5 (-794)) (-4 *4 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))))) (-4386 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 (-959 *6))) (-4 *6 (-562)) (-4 *2 (-956 (-413 (-959 *6)) *5 *4)) (-5 *1 (-728 *5 *4 *6 *2)) (-4 *5 (-794)) (-4 *4 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))))) (-2164 (*1 *2 *2 *3) (-12 (-4 *4 (-794)) (-4 *3 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *5 (-562)) (-5 *1 (-728 *4 *3 *5 *2)) (-4 *2 (-956 (-413 (-959 *5)) *4 *3)))) (-4468 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 *2)) (-4 *2 (-956 (-413 (-959 *6)) *5 *4)) (-5 *1 (-728 *5 *4 *6 *2)) (-4 *5 (-794)) (-4 *4 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *6 (-562)))) (-4385 (*1 *2 *2 *3) (-12 (-4 *4 (-794)) (-4 *3 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *5 (-562)) (-5 *1 (-728 *4 *3 *5 *2)) (-4 *2 (-956 (-413 (-959 *5)) *4 *3)))) (-3860 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *6 (-562)) (-5 *2 (-2 (|:| -1614 (-959 *6)) (|:| -2685 (-959 *6)))) (-5 *1 (-728 *4 *5 *6 *3)) (-4 *3 (-956 (-413 (-959 *6)) *4 *5))))) 
-(-10 -7 (-15 -3860 ((-2 (|:| -1614 (-959 |#3|)) (|:| -2685 (-959 |#3|))) |#4|)) (-15 -4385 (|#4| |#4| |#2|)) (-15 -4468 (|#4| (-1166 |#4|) |#2|)) (-15 -2164 (|#4| |#4| |#2|)) (-15 -4386 (|#4| (-1166 (-959 |#3|)) |#2|)) (-15 -3713 (|#4| (-413 (-959 |#3|)) |#2|)) (-15 -4304 ((-424 |#4|) |#4|))) 
-((-4304 (((-424 |#4|) |#4|) 51))) 
-(((-729 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4304 ((-424 |#4|) |#4|))) (-794) (-848) (-13 (-303) (-151)) (-956 (-413 |#3|) |#1| |#2|)) (T -729)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-13 (-303) (-151))) (-5 *2 (-424 *3)) (-5 *1 (-729 *4 *5 *6 *3)) (-4 *3 (-956 (-413 *6) *4 *5))))) 
-(-10 -7 (-15 -4304 ((-424 |#4|) |#4|))) 
-((-3828 (((-731 |#2| |#3|) (-1 |#2| |#1|) (-731 |#1| |#3|)) 18))) 
-(((-730 |#1| |#2| |#3|) (-10 -7 (-15 -3828 ((-731 |#2| |#3|) (-1 |#2| |#1|) (-731 |#1| |#3|)))) (-1054) (-1054) (-722)) (T -730)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-731 *5 *7)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-4 *7 (-722)) (-5 *2 (-731 *6 *7)) (-5 *1 (-730 *5 *6 *7))))) 
-(-10 -7 (-15 -3828 ((-731 |#2| |#3|) (-1 |#2| |#1|) (-731 |#1| |#3|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 26)) (-2640 (((-638 (-2 (|:| -4513 |#1|) (|:| -4518 |#2|))) $) 27)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1685 (((-769)) 20 (-12 (|has| |#2| (-374)) (|has| |#1| (-374))))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) 55) (((-3 |#1| "failed") $) 58)) (-1318 ((|#2| $) NIL) ((|#1| $) NIL)) (-4383 (($ $) 75 (|has| |#2| (-848)))) (-1799 (((-3 $ "failed") $) 62)) (-3286 (($) 33 (-12 (|has| |#2| (-374)) (|has| |#1| (-374))))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) 53)) (-3658 (((-638 $) $) 37)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| |#2|) 16)) (-3828 (($ (-1 |#1| |#1|) $) 52)) (-3633 (((-923) $) 30 (-12 (|has| |#2| (-374)) (|has| |#1| (-374))))) (-4368 ((|#2| $) 74 (|has| |#2| (-848)))) (-4373 ((|#1| $) 73 (|has| |#2| (-848)))) (-1658 (((-1152) $) NIL)) (-1763 (($ (-923)) 25 (-12 (|has| |#2| (-374)) (|has| |#1| (-374))))) (-2607 (((-1116) $) NIL)) (-3587 (((-638 $)) NIL (-12 (|has| |#2| (-374)) (|has| |#1| (-374))))) (-3972 (((-856) $) 72) (($ (-572)) 44) (($ |#2|) 40) (($ |#1|) 41) (($ (-638 (-2 (|:| -4513 |#1|) (|:| -4518 |#2|)))) 11)) (-3193 (((-638 |#1|) $) 39)) (-1958 ((|#1| $ |#2|) 83)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 12 T CONST)) (-3255 (($) 31 T CONST)) (-1324 (((-121) $ $) 76)) (-1373 (($ $) 46) (($ $ $) NIL)) (-1367 (($ $ $) 24)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 50) (($ $ $) 85) (($ |#1| $) 48 (|has| |#1| (-174))) (($ $ |#1|) NIL (|has| |#1| (-174))))) 
-(((-731 |#1| |#2|) (-13 (-1054) (-1044 |#2|) (-1044 |#1|) (-10 -8 (-15 -4328 ($ |#1| |#2|)) (-15 -1958 (|#1| $ |#2|)) (-15 -3972 ($ (-638 (-2 (|:| -4513 |#1|) (|:| -4518 |#2|))))) (-15 -2640 ((-638 (-2 (|:| -4513 |#1|) (|:| -4518 |#2|))) $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (-15 -4581 ((-121) $)) (-15 -3193 ((-638 |#1|) $)) (-15 -3658 ((-638 $) $)) (-15 -3475 ((-769) $)) (IF (|has| |#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |#1| (-174)) (-6 (-43 |#1|)) |noBranch|) (IF (|has| |#1| (-374)) (IF (|has| |#2| (-374)) (-6 (-374)) |noBranch|) |noBranch|) (IF (|has| |#2| (-848)) (PROGN (-15 -4368 (|#2| $)) (-15 -4373 (|#1| $)) (-15 -4383 ($ $))) |noBranch|))) (-1054) (-722)) (T -731)) 
-((-4328 (*1 *1 *2 *3) (-12 (-5 *1 (-731 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-722)))) (-1958 (*1 *2 *1 *3) (-12 (-4 *2 (-1054)) (-5 *1 (-731 *2 *3)) (-4 *3 (-722)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4513 *3) (|:| -4518 *4)))) (-4 *3 (-1054)) (-4 *4 (-722)) (-5 *1 (-731 *3 *4)))) (-2640 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| -4513 *3) (|:| -4518 *4)))) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-731 *3 *4)) (-4 *4 (-722)))) (-4581 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) (-3193 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) (-3658 (*1 *2 *1) (-12 (-5 *2 (-638 (-731 *3 *4))) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) (-3475 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) (-4368 (*1 *2 *1) (-12 (-4 *2 (-722)) (-4 *2 (-848)) (-5 *1 (-731 *3 *2)) (-4 *3 (-1054)))) (-4373 (*1 *2 *1) (-12 (-4 *2 (-1054)) (-5 *1 (-731 *2 *3)) (-4 *3 (-848)) (-4 *3 (-722)))) (-4383 (*1 *1 *1) (-12 (-5 *1 (-731 *2 *3)) (-4 *3 (-848)) (-4 *2 (-1054)) (-4 *3 (-722))))) 
-(-13 (-1054) (-1044 |#2|) (-1044 |#1|) (-10 -8 (-15 -4328 ($ |#1| |#2|)) (-15 -1958 (|#1| $ |#2|)) (-15 -3972 ($ (-638 (-2 (|:| -4513 |#1|) (|:| -4518 |#2|))))) (-15 -2640 ((-638 (-2 (|:| -4513 |#1|) (|:| -4518 |#2|))) $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (-15 -4581 ((-121) $)) (-15 -3193 ((-638 |#1|) $)) (-15 -3658 ((-638 $) $)) (-15 -3475 ((-769) $)) (IF (|has| |#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |#1| (-174)) (-6 (-43 |#1|)) |noBranch|) (IF (|has| |#1| (-374)) (IF (|has| |#2| (-374)) (-6 (-374)) |noBranch|) |noBranch|) (IF (|has| |#2| (-848)) (PROGN (-15 -4368 (|#2| $)) (-15 -4373 (|#1| $)) (-15 -4383 ($ $))) |noBranch|))) 
-((-2262 (((-121) $ $) 18)) (-3518 (($ |#1| $) 72) (($ $ |#1|) 71) (($ $ $) 70)) (-3710 (($ $ $) 68)) (-3771 (((-121) $ $) 69)) (-1946 (((-121) $ (-769)) 8)) (-4462 (($ (-638 |#1|)) 64) (($) 63)) (-1550 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-3259 (($ $) 58)) (-1643 (($ $) 55 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ |#1| $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4602)))) (-3445 (($ |#1| $) 54 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4602)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22)) (-1931 (($ $ $) 65)) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37) (($ |#1| $ (-769)) 59)) (-2607 (((-1116) $) 21)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-4153 (((-638 (-2 (|:| -4320 |#1|) (|:| -1571 (-769)))) $) 57)) (-3982 (($ $ |#1|) 67) (($ $ $) 66)) (-1535 (($) 46) (($ (-638 |#1|)) 45)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 47)) (-3972 (((-856) $) 20)) (-1599 (($ (-638 |#1|)) 62) (($) 61)) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19)) (-1334 (((-121) $ $) 60)) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-732 |#1|) (-1290) (-1098)) (T -732)) 
-NIL 
-(-13 (-690 |t#1|) (-1095 |t#1|)) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) . T) ((-612 (-856)) . T) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-229 |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-690 |#1|) . T) ((-1095 |#1|) . T) ((-1098) . T) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-3518 (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ $ $) 77)) (-3710 (($ $ $) 80)) (-3771 (((-121) $ $) 83)) (-1946 (((-121) $ (-769)) NIL)) (-4462 (($ (-638 |#1|)) 24) (($) 15)) (-1550 (($ (-1 (-121) |#1|) $) 71 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-3259 (($ $) 72)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1544 (($ |#1| $) 61 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) 64 (|has| $ (-6 -4602))) (($ |#1| $ (-572)) 62) (($ (-1 (-121) |#1|) $ (-572)) 65)) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (($ |#1| $ (-572)) 67) (($ (-1 (-121) |#1|) $ (-572)) 68)) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-2010 (((-638 |#1|) $) 32 (|has| $ (-6 -4602)))) (-3245 (($) 13) (($ |#1|) 26) (($ (-638 |#1|)) 21)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) 38)) (-3002 (((-121) |#1| $) 57 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) 75 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 76)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-1931 (($ $ $) 78)) (-4221 ((|#1| $) 54)) (-1335 (($ |#1| $) 55) (($ |#1| $ (-769)) 73)) (-2607 (((-1116) $) NIL)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2232 ((|#1| $) 53)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 49)) (-1665 (($) 12)) (-4153 (((-638 (-2 (|:| -4320 |#1|) (|:| -1571 (-769)))) $) 47)) (-3982 (($ $ |#1|) NIL) (($ $ $) 79)) (-1535 (($) 14) (($ (-638 |#1|)) 23)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) 60 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) 66)) (-4081 (((-545) $) 36 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 20)) (-3972 (((-856) $) 44)) (-1599 (($ (-638 |#1|)) 25) (($) 16)) (-3058 (($ (-638 |#1|)) 22)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 81)) (-1334 (((-121) $ $) 82)) (-4032 (((-769) $) 59 (|has| $ (-6 -4602))))) 
-(((-733 |#1|) (-13 (-732 |#1|) (-10 -8 (-6 -4602) (-6 -4603) (-15 -3245 ($)) (-15 -3245 ($ |#1|)) (-15 -3245 ($ (-638 |#1|))) (-15 -4467 ((-638 |#1|) $)) (-15 -3445 ($ |#1| $ (-572))) (-15 -3445 ($ (-1 (-121) |#1|) $ (-572))) (-15 -1544 ($ |#1| $ (-572))) (-15 -1544 ($ (-1 (-121) |#1|) $ (-572))))) (-1098)) (T -733)) 
-((-3245 (*1 *1) (-12 (-5 *1 (-733 *2)) (-4 *2 (-1098)))) (-3245 (*1 *1 *2) (-12 (-5 *1 (-733 *2)) (-4 *2 (-1098)))) (-3245 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-733 *3)))) (-4467 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-733 *3)) (-4 *3 (-1098)))) (-3445 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-733 *2)) (-4 *2 (-1098)))) (-3445 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-572)) (-4 *4 (-1098)) (-5 *1 (-733 *4)))) (-1544 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-733 *2)) (-4 *2 (-1098)))) (-1544 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-572)) (-4 *4 (-1098)) (-5 *1 (-733 *4))))) 
-(-13 (-732 |#1|) (-10 -8 (-6 -4602) (-6 -4603) (-15 -3245 ($)) (-15 -3245 ($ |#1|)) (-15 -3245 ($ (-638 |#1|))) (-15 -4467 ((-638 |#1|) $)) (-15 -3445 ($ |#1| $ (-572))) (-15 -3445 ($ (-1 (-121) |#1|) $ (-572))) (-15 -1544 ($ |#1| $ (-572))) (-15 -1544 ($ (-1 (-121) |#1|) $ (-572))))) 
-((-1715 (((-1264) (-1152)) 8))) 
-(((-734) (-10 -7 (-15 -1715 ((-1264) (-1152))))) (T -734)) 
-((-1715 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-734))))) 
-(-10 -7 (-15 -1715 ((-1264) (-1152)))) 
-((-1565 (((-638 |#1|) (-638 |#1|) (-638 |#1|)) 10))) 
-(((-735 |#1|) (-10 -7 (-15 -1565 ((-638 |#1|) (-638 |#1|) (-638 |#1|)))) (-848)) (T -735)) 
-((-1565 (*1 *2 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-735 *3))))) 
-(-10 -7 (-15 -1565 ((-638 |#1|) (-638 |#1|) (-638 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 |#2|) $) 134)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 127 (|has| |#1| (-562)))) (-3946 (($ $) 126 (|has| |#1| (-562)))) (-3686 (((-121) $) 124 (|has| |#1| (-562)))) (-4284 (($ $) 83 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 66 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) 18)) (-4190 (($ $) 65 (|has| |#1| (-43 (-413 (-572)))))) (-4273 (($ $) 82 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 67 (|has| |#1| (-43 (-413 (-572)))))) (-4295 (($ $) 81 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 68 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) 16 T CONST)) (-4383 (($ $) 118)) (-1799 (((-3 $ "failed") $) 33)) (-1896 (((-959 |#1|) $ (-769)) 96) (((-959 |#1|) $ (-769) (-769)) 95)) (-1347 (((-121) $) 135)) (-4184 (($) 93 (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-769) $ |#2|) 98) (((-769) $ |#2| (-769)) 97)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 64 (|has| |#1| (-43 (-413 (-572)))))) (-4581 (((-121) $) 116)) (-4328 (($ $ (-638 |#2|) (-638 (-538 |#2|))) 133) (($ $ |#2| (-538 |#2|)) 132) (($ |#1| (-538 |#2|)) 117) (($ $ |#2| (-769)) 100) (($ $ (-638 |#2|) (-638 (-769))) 99)) (-3828 (($ (-1 |#1| |#1|) $) 115)) (-3539 (($ $) 90 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) 113)) (-4373 ((|#1| $) 112)) (-1658 (((-1152) $) 9)) (-2774 (($ $ |#2|) 94 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) 10)) (-1977 (($ $ (-769)) 101)) (-1803 (((-3 $ "failed") $ $) 128 (|has| |#1| (-562)))) (-4179 (($ $) 91 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (($ $ |#2| $) 109) (($ $ (-638 |#2|) (-638 $)) 108) (($ $ (-638 (-290 $))) 107) (($ $ (-290 $)) 106) (($ $ $ $) 105) (($ $ (-638 $) (-638 $)) 104)) (-3139 (($ $ |#2|) 41) (($ $ (-638 |#2|)) 40) (($ $ |#2| (-769)) 39) (($ $ (-638 |#2|) (-638 (-769))) 38)) (-4316 (((-538 |#2|) $) 114)) (-4302 (($ $) 80 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 69 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 79 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 70 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 78 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 71 (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 136)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 131 (|has| |#1| (-174))) (($ $) 129 (|has| |#1| (-562))) (($ (-413 (-572))) 121 (|has| |#1| (-43 (-413 (-572)))))) (-1958 ((|#1| $ (-538 |#2|)) 119) (($ $ |#2| (-769)) 103) (($ $ (-638 |#2|) (-638 (-769))) 102)) (-2779 (((-3 $ "failed") $) 130 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-4321 (($ $) 89 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 77 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) 125 (|has| |#1| (-562)))) (-4308 (($ $) 88 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 76 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 87 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 75 (|has| |#1| (-43 (-413 (-572)))))) (-2104 (($ $) 86 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 74 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 85 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 73 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 84 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 72 (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ |#2|) 37) (($ $ (-638 |#2|)) 36) (($ $ |#2| (-769)) 35) (($ $ (-638 |#2|) (-638 (-769))) 34)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 120 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ $) 92 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 63 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 123 (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) 122 (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 111) (($ $ |#1|) 110))) 
-(((-736 |#1| |#2|) (-1290) (-1054) (-848)) (T -736)) 
-((-1958 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-736 *4 *2)) (-4 *4 (-1054)) (-4 *2 (-848)))) (-1958 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *5)) (-5 *3 (-638 (-769))) (-4 *1 (-736 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-848)))) (-1977 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-736 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-848)))) (-4328 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-736 *4 *2)) (-4 *4 (-1054)) (-4 *2 (-848)))) (-4328 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *5)) (-5 *3 (-638 (-769))) (-4 *1 (-736 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-848)))) (-3377 (*1 *2 *1 *3) (-12 (-4 *1 (-736 *4 *3)) (-4 *4 (-1054)) (-4 *3 (-848)) (-5 *2 (-769)))) (-3377 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-769)) (-4 *1 (-736 *4 *3)) (-4 *4 (-1054)) (-4 *3 (-848)))) (-1896 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-736 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-848)) (-5 *2 (-959 *4)))) (-1896 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-4 *1 (-736 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-848)) (-5 *2 (-959 *4)))) (-2774 (*1 *1 *1 *2) (-12 (-4 *1 (-736 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-848)) (-4 *3 (-43 (-413 (-572))))))) 
-(-13 (-901 |t#2|) (-981 |t#1| (-538 |t#2|) |t#2|) (-527 |t#2| $) (-305 $) (-10 -8 (-15 -1958 ($ $ |t#2| (-769))) (-15 -1958 ($ $ (-638 |t#2|) (-638 (-769)))) (-15 -1977 ($ $ (-769))) (-15 -4328 ($ $ |t#2| (-769))) (-15 -4328 ($ $ (-638 |t#2|) (-638 (-769)))) (-15 -3377 ((-769) $ |t#2|)) (-15 -3377 ((-769) $ |t#2| (-769))) (-15 -1896 ((-959 |t#1|) $ (-769))) (-15 -1896 ((-959 |t#1|) $ (-769) (-769))) (IF (|has| |t#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $ |t#2|)) (-6 (-1009)) (-6 (-1190))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-538 |#2|)) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) |has| |#1| (-562)) ((-40) |has| |#1| (-43 (-413 (-572)))) ((-98) |has| |#1| (-43 (-413 (-572)))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-281) |has| |#1| (-43 (-413 (-572)))) ((-287) |has| |#1| (-562)) ((-305 $) . T) ((-506) |has| |#1| (-43 (-413 (-572)))) ((-527 |#2| $) . T) ((-527 $ $) . T) ((-562) |has| |#1| (-562)) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) |has| |#1| (-562)) ((-722) . T) ((-901 |#2|) . T) ((-981 |#1| (-538 |#2|) |#2|) . T) ((-1009) |has| |#1| (-43 (-413 (-572)))) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1190) |has| |#1| (-43 (-413 (-572)))) ((-1193) |has| |#1| (-43 (-413 (-572))))) 
-((-4304 (((-424 (-1166 |#4|)) (-1166 |#4|)) 28) (((-424 |#4|) |#4|) 24))) 
-(((-737 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4304 ((-424 |#4|) |#4|)) (-15 -4304 ((-424 (-1166 |#4|)) (-1166 |#4|)))) (-848) (-794) (-13 (-303) (-151)) (-956 |#3| |#2| |#1|)) (T -737)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-956 *6 *5 *4)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-737 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) (-4304 (*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-13 (-303) (-151))) (-5 *2 (-424 *3)) (-5 *1 (-737 *4 *5 *6 *3)) (-4 *3 (-956 *6 *5 *4))))) 
-(-10 -7 (-15 -4304 ((-424 |#4|) |#4|)) (-15 -4304 ((-424 (-1166 |#4|)) (-1166 |#4|)))) 
-((-4079 (((-424 |#4|) |#4| |#2|) 116)) (-3237 (((-424 |#4|) |#4|) NIL)) (-1466 (((-424 (-1166 |#4|)) (-1166 |#4|)) 107) (((-424 |#4|) |#4|) 38)) (-1331 (((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-638 (-2 (|:| -4304 (-1166 |#4|)) (|:| -3751 (-572)))))) (-1166 |#4|) (-638 |#2|) (-638 (-638 |#3|))) 65)) (-2954 (((-1166 |#3|) (-1166 |#3|) (-572)) 133)) (-4346 (((-638 (-769)) (-1166 |#4|) (-638 |#2|) (-769)) 58)) (-3111 (((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-1166 |#3|) (-1166 |#3|) |#4| (-638 |#2|) (-638 (-769)) (-638 |#3|)) 62)) (-3879 (((-2 (|:| |upol| (-1166 |#3|)) (|:| |Lval| (-638 |#3|)) (|:| |Lfact| (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572))))) (|:| |ctpol| |#3|)) (-1166 |#4|) (-638 |#2|) (-638 (-638 |#3|))) 22)) (-3066 (((-2 (|:| -1805 (-1166 |#4|)) (|:| |polval| (-1166 |#3|))) (-1166 |#4|) (-1166 |#3|) (-572)) 54)) (-3840 (((-572) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572))))) 130)) (-2763 ((|#4| (-572) (-424 |#4|)) 55)) (-2285 (((-121) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572)))) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572))))) NIL))) 
-(((-738 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1466 ((-424 |#4|) |#4|)) (-15 -1466 ((-424 (-1166 |#4|)) (-1166 |#4|))) (-15 -3237 ((-424 |#4|) |#4|)) (-15 -3840 ((-572) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572)))))) (-15 -4079 ((-424 |#4|) |#4| |#2|)) (-15 -3066 ((-2 (|:| -1805 (-1166 |#4|)) (|:| |polval| (-1166 |#3|))) (-1166 |#4|) (-1166 |#3|) (-572))) (-15 -1331 ((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-638 (-2 (|:| -4304 (-1166 |#4|)) (|:| -3751 (-572)))))) (-1166 |#4|) (-638 |#2|) (-638 (-638 |#3|)))) (-15 -3879 ((-2 (|:| |upol| (-1166 |#3|)) (|:| |Lval| (-638 |#3|)) (|:| |Lfact| (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572))))) (|:| |ctpol| |#3|)) (-1166 |#4|) (-638 |#2|) (-638 (-638 |#3|)))) (-15 -2763 (|#4| (-572) (-424 |#4|))) (-15 -2285 ((-121) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572)))) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572)))))) (-15 -3111 ((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-1166 |#3|) (-1166 |#3|) |#4| (-638 |#2|) (-638 (-769)) (-638 |#3|))) (-15 -4346 ((-638 (-769)) (-1166 |#4|) (-638 |#2|) (-769))) (-15 -2954 ((-1166 |#3|) (-1166 |#3|) (-572)))) (-794) (-848) (-303) (-956 |#3| |#1| |#2|)) (T -738)) 
-((-2954 (*1 *2 *2 *3) (-12 (-5 *2 (-1166 *6)) (-5 *3 (-572)) (-4 *6 (-303)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-738 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5)))) (-4346 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1166 *9)) (-5 *4 (-638 *7)) (-4 *7 (-848)) (-4 *9 (-956 *8 *6 *7)) (-4 *6 (-794)) (-4 *8 (-303)) (-5 *2 (-638 (-769))) (-5 *1 (-738 *6 *7 *8 *9)) (-5 *5 (-769)))) (-3111 (*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| -12 (-5 *4 (-1166 *11)) (-5 *6 (-638 *10)) (-5 *7 (-638 (-769))) (-5 *8 (-638 *11)) (-4 *10 (-848)) (-4 *11 (-303)) (-4 *9 (-794)) (-4 *5 (-956 *11 *9 *10)) (-5 *2 (-638 (-1166 *5))) (-5 *1 (-738 *9 *10 *11 *5)) (-5 *3 (-1166 *5)))) (-2285 (*1 *2 *3 *3) (-12 (-5 *3 (-638 (-2 (|:| -4304 (-1166 *6)) (|:| -3751 (-572))))) (-4 *6 (-303)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-738 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5)))) (-2763 (*1 *2 *3 *4) (-12 (-5 *3 (-572)) (-5 *4 (-424 *2)) (-4 *2 (-956 *7 *5 *6)) (-5 *1 (-738 *5 *6 *7 *2)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-303)))) (-3879 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1166 *9)) (-5 *4 (-638 *7)) (-5 *5 (-638 (-638 *8))) (-4 *7 (-848)) (-4 *8 (-303)) (-4 *9 (-956 *8 *6 *7)) (-4 *6 (-794)) (-5 *2 (-2 (|:| |upol| (-1166 *8)) (|:| |Lval| (-638 *8)) (|:| |Lfact| (-638 (-2 (|:| -4304 (-1166 *8)) (|:| -3751 (-572))))) (|:| |ctpol| *8))) (-5 *1 (-738 *6 *7 *8 *9)))) (-1331 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 *7)) (-5 *5 (-638 (-638 *8))) (-4 *7 (-848)) (-4 *8 (-303)) (-4 *6 (-794)) (-4 *9 (-956 *8 *6 *7)) (-5 *2 (-2 (|:| |unitPart| *9) (|:| |suPart| (-638 (-2 (|:| -4304 (-1166 *9)) (|:| -3751 (-572))))))) (-5 *1 (-738 *6 *7 *8 *9)) (-5 *3 (-1166 *9)))) (-3066 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-572)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-303)) (-4 *9 (-956 *8 *6 *7)) (-5 *2 (-2 (|:| -1805 (-1166 *9)) (|:| |polval| (-1166 *8)))) (-5 *1 (-738 *6 *7 *8 *9)) (-5 *3 (-1166 *9)) (-5 *4 (-1166 *8)))) (-4079 (*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-738 *5 *4 *6 *3)) (-4 *3 (-956 *6 *5 *4)))) (-3840 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -4304 (-1166 *6)) (|:| -3751 (-572))))) (-4 *6 (-303)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-572)) (-5 *1 (-738 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5)))) (-3237 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-738 *4 *5 *6 *3)) (-4 *3 (-956 *6 *4 *5)))) (-1466 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-738 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) (-1466 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-738 *4 *5 *6 *3)) (-4 *3 (-956 *6 *4 *5))))) 
-(-10 -7 (-15 -1466 ((-424 |#4|) |#4|)) (-15 -1466 ((-424 (-1166 |#4|)) (-1166 |#4|))) (-15 -3237 ((-424 |#4|) |#4|)) (-15 -3840 ((-572) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572)))))) (-15 -4079 ((-424 |#4|) |#4| |#2|)) (-15 -3066 ((-2 (|:| -1805 (-1166 |#4|)) (|:| |polval| (-1166 |#3|))) (-1166 |#4|) (-1166 |#3|) (-572))) (-15 -1331 ((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-638 (-2 (|:| -4304 (-1166 |#4|)) (|:| -3751 (-572)))))) (-1166 |#4|) (-638 |#2|) (-638 (-638 |#3|)))) (-15 -3879 ((-2 (|:| |upol| (-1166 |#3|)) (|:| |Lval| (-638 |#3|)) (|:| |Lfact| (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572))))) (|:| |ctpol| |#3|)) (-1166 |#4|) (-638 |#2|) (-638 (-638 |#3|)))) (-15 -2763 (|#4| (-572) (-424 |#4|))) (-15 -2285 ((-121) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572)))) (-638 (-2 (|:| -4304 (-1166 |#3|)) (|:| -3751 (-572)))))) (-15 -3111 ((-3 (-638 (-1166 |#4|)) "failed") (-1166 |#4|) (-1166 |#3|) (-1166 |#3|) |#4| (-638 |#2|) (-638 (-769)) (-638 |#3|))) (-15 -4346 ((-638 (-769)) (-1166 |#4|) (-638 |#2|) (-769))) (-15 -2954 ((-1166 |#3|) (-1166 |#3|) (-572)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1170)) $) NIL)) (-4297 (((-413 (-1166 $)) $ (-611 $)) NIL (|has| |#2| (-562)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1337 (((-638 (-611 $)) $) NIL)) (-1415 (($ $ (-1090 $)) NIL) (($ $ (-1170)) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1952 (($ $ (-290 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL)) (-2844 (($ $) NIL (|has| |#2| (-562)))) (-1466 (((-424 $) $) NIL (|has| |#2| (-562)))) (-3112 (((-121) $ $) NIL (|has| |#2| (-562)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-611 $) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL) (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-959 |#2|)) "failed") $) NIL (|has| |#2| (-562))) (((-3 (-959 |#2|) "failed") $) NIL (|has| |#2| (-1054))) (((-3 (-740 |#1| |#2|) "failed") $) NIL) (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (-1841 (-12 (|has| |#2| (-562)) (|has| |#2| (-1044 (-572)))) (|has| |#2| (-1044 (-413 (-572))))))) (-1318 (((-611 $) $) NIL) (((-1170) $) NIL) ((|#2| $) NIL) (((-413 (-959 |#2|)) $) 20 (|has| |#2| (-562))) (((-959 |#2|) $) 26 (|has| |#2| (-1054))) (((-740 |#1| |#2|) $) 27) (((-572) $) NIL) (((-413 (-740 |#1| |#2|)) $) 25) (((-413 (-572)) $) NIL (-1841 (-12 (|has| |#2| (-562)) (|has| |#2| (-1044 (-572)))) (|has| |#2| (-1044 (-413 (-572))))))) (-2190 (($ $ $) NIL (|has| |#2| (-562)))) (-2284 (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL (|has| |#2| (-1054))) (((-685 |#2|) (-685 $)) NIL (|has| |#2| (-1054))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054))))) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#2| (-562)))) (-1642 (($ $ (-1090 $)) NIL) (($ $ (-1170)) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#2| (-562)))) (-1526 (((-121) $) NIL (|has| |#2| (-562)))) (-2133 (($ $ $) NIL)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| |#2| (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| |#2| (-887 (-385))))) (-3567 (($ $) NIL) (($ (-638 $)) NIL)) (-4091 (((-638 (-123)) $) NIL)) (-4564 (((-123) (-123)) NIL)) (-3893 (((-121) $) NIL)) (-4240 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4347 (($ $) NIL)) (-4487 (((-1121 |#2| (-611 $)) $) NIL (|has| |#2| (-1054)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#2| (-562)))) (-4127 (((-1166 $) (-611 $)) NIL (|has| $ (-1054)))) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3828 (($ (-1 $ $) (-611 $)) NIL)) (-3614 (((-3 (-611 $) "failed") $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#2| (-562))) (($ $ $) NIL (|has| |#2| (-562)))) (-1658 (((-1152) $) NIL)) (-4291 (((-638 (-611 $)) $) NIL)) (-4496 (($ (-123) $) NIL) (($ (-123) (-638 $)) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL (|has| |#2| (-1110)))) (-2472 (((-3 (-2 (|:| |val| $) (|:| -3751 (-572))) "failed") $) NIL (|has| |#2| (-1054)))) (-2336 (((-3 (-638 $) "failed") $) NIL (|has| |#2| (-25)))) (-1595 (((-3 (-2 (|:| -4513 (-572)) (|:| |var| (-611 $))) "failed") $) NIL (|has| |#2| (-25)))) (-3019 (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $) NIL (|has| |#2| (-1110))) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-123)) NIL (|has| |#2| (-1054))) (((-3 (-2 (|:| |var| (-611 $)) (|:| -3751 (-572))) "failed") $ (-1170)) NIL (|has| |#2| (-1054)))) (-3291 (((-121) $ (-123)) NIL) (((-121) $ (-1170)) NIL)) (-4350 (($ $) NIL (-1841 (|has| |#2| (-482)) (|has| |#2| (-562))))) (-1455 (((-769) $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#2| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#2| (-562)))) (-3069 (($ (-638 $)) NIL (|has| |#2| (-562))) (($ $ $) NIL (|has| |#2| (-562)))) (-4319 (((-121) $ $) NIL) (((-121) $ (-1170)) NIL)) (-3288 (($ $ (-1170)) NIL) (($ $) NIL)) (-2900 (($ $) NIL)) (-4304 (((-424 $) $) NIL (|has| |#2| (-562)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-562))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#2| (-562)))) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#2| (-562)))) (-4247 (((-121) $) NIL (|has| $ (-1044 (-572))))) (-4485 (($ $ (-611 $) $) NIL) (($ $ (-638 (-611 $)) (-638 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-1170)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-1170) (-1 $ (-638 $))) NIL) (($ $ (-1170) (-1 $ $)) NIL) (($ $ (-638 (-123)) (-638 (-1 $ $))) NIL) (($ $ (-638 (-123)) (-638 (-1 $ (-638 $)))) NIL) (($ $ (-123) (-1 $ (-638 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1170)) NIL (|has| |#2| (-613 (-545)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-613 (-545)))) (($ $) NIL (|has| |#2| (-613 (-545)))) (($ $ (-123) $ (-1170)) NIL (|has| |#2| (-613 (-545)))) (($ $ (-638 (-123)) (-638 $) (-1170)) NIL (|has| |#2| (-613 (-545)))) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ $))) NIL (|has| |#2| (-1054))) (($ $ (-638 (-1170)) (-638 (-769)) (-638 (-1 $ (-638 $)))) NIL (|has| |#2| (-1054))) (($ $ (-1170) (-769) (-1 $ (-638 $))) NIL (|has| |#2| (-1054))) (($ $ (-1170) (-769) (-1 $ $)) NIL (|has| |#2| (-1054)))) (-4029 (((-769) $) NIL (|has| |#2| (-562)))) (-3277 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-638 $)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-562)))) (-2759 (($ $) NIL) (($ $ $) NIL)) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL)) (-3425 (($ $) NIL)) (-4492 (((-1121 |#2| (-611 $)) $) NIL (|has| |#2| (-562)))) (-2830 (($ $) NIL (|has| $ (-1054)))) (-4081 (((-893 (-572)) $) NIL (|has| |#2| (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| |#2| (-613 (-893 (-385))))) (($ (-424 $)) NIL (|has| |#2| (-562))) (((-545) $) NIL (|has| |#2| (-613 (-545))))) (-3018 (($ $ $) NIL (|has| |#2| (-482)))) (-4056 (($ $ $) NIL (|has| |#2| (-482)))) (-3972 (((-856) $) NIL) (($ (-611 $)) NIL) (($ (-1170)) NIL) (($ |#2|) NIL) (($ (-1121 |#2| (-611 $))) NIL (|has| |#2| (-1054))) (($ (-413 |#2|)) NIL (|has| |#2| (-562))) (($ (-959 (-413 |#2|))) NIL (|has| |#2| (-562))) (($ (-413 (-959 (-413 |#2|)))) NIL (|has| |#2| (-562))) (($ (-413 (-959 |#2|))) NIL (|has| |#2| (-562))) (($ (-959 |#2|)) NIL (|has| |#2| (-1054))) (($ $) NIL) (($ (-572)) NIL) (($ (-740 |#1| |#2|)) NIL) (($ (-413 (-740 |#1| |#2|))) 35) (($ (-413 (-572))) NIL (-1841 (|has| |#2| (-562)) (|has| |#2| (-1044 (-413 (-572))))))) (-2779 (((-3 $ "failed") $) NIL (|has| |#2| (-149)))) (-2140 (((-769)) NIL)) (-3497 (($ $) NIL) (($ (-638 $)) NIL)) (-3610 (($ $ $) NIL)) (-3228 (((-121) (-123)) NIL)) (-3774 (((-121) $ $) NIL)) (-2973 (($ (-1170) $) NIL) (($ (-1170) $ $) NIL) (($ (-1170) $ $ $) NIL) (($ (-1170) $ $ $ $) NIL) (($ (-1170) (-638 $)) NIL)) (-4174 (($ $ (-769)) NIL) (($ $ (-923)) NIL) (($ $ (-572)) NIL (-1841 (|has| |#2| (-482)) (|has| |#2| (-562))))) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1379 (($ (-1121 |#2| (-611 $)) (-1121 |#2| (-611 $))) NIL (|has| |#2| (-562))) (($ $ $) NIL)) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-923)) NIL) (($ $ $) NIL) (($ $ (-572)) NIL (-1841 (|has| |#2| (-482)) (|has| |#2| (-562))))) (* (($ (-413 (-572)) $) NIL (|has| |#2| (-562))) (($ $ (-413 (-572))) NIL (|has| |#2| (-562))) (($ |#2| $) NIL (|has| |#2| (-174))) (($ $ |#2|) NIL (|has| |#2| (-174))) (($ $ $) NIL) (($ (-572) $) NIL) (($ (-769) $) NIL) (($ (-923) $) NIL))) 
-(((-739 |#1| |#2|) (-13 (-436 |#2|) (-562) (-1044 (-740 |#1| |#2|)) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $)) (-15 -3972 ($ (-413 (-740 |#1| |#2|)))) (-15 -1318 ((-413 (-740 |#1| |#2|)) $)))) (-1170) (-13 (-1054) (-848) (-562))) (T -739)) 
-((-4357 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-739 *3 *4)) (-14 *3 (-1170)) (-4 *4 (-13 (-1054) (-848) (-562))))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) (-1379 (*1 *1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) (** (*1 *1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) (-4347 (*1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) (-3425 (*1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-413 (-740 *3 *4))) (-14 *3 (-1170)) (-4 *4 (-13 (-1054) (-848) (-562))) (-5 *1 (-739 *3 *4)))) (-1318 (*1 *2 *1) (-12 (-5 *2 (-413 (-740 *3 *4))) (-5 *1 (-739 *3 *4)) (-14 *3 (-1170)) (-4 *4 (-13 (-1054) (-848) (-562)))))) 
-(-13 (-436 |#2|) (-562) (-1044 (-740 |#1| |#2|)) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $)) (-15 -3972 ($ (-413 (-740 |#1| |#2|)))) (-15 -1318 ((-413 (-740 |#1| |#2|)) $)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3275 (((-1259 |#2|) $ (-769)) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-2383 (($ (-1166 |#2|)) NIL)) (-4297 (((-1166 $) $ (-1082)) NIL) (((-1166 |#2|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#2| (-562)))) (-3946 (($ $) NIL (|has| |#2| (-562)))) (-3686 (((-121) $) NIL (|has| |#2| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1082))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2824 (($ $ $) NIL (|has| |#2| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2844 (($ $) NIL (|has| |#2| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#2| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3112 (((-121) $ $) NIL (|has| |#2| (-368)))) (-2786 (($ $ (-769)) NIL)) (-3944 (($ $ (-769)) NIL)) (-2012 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#2| (-457)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-1082) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL)) (-1318 ((|#2| $) NIL) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-1082) $) 22) (((-1170) $) 23)) (-3190 (($ $ $ (-1082)) NIL (|has| |#2| (-174))) ((|#2| $ $) NIL (|has| |#2| (-174)))) (-2190 (($ $ $) NIL (|has| |#2| (-368)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#2| (-368)))) (-3890 (($ $ $) NIL)) (-3039 (($ $ $) NIL (|has| |#2| (-562)))) (-1449 (((-2 (|:| -4513 |#2|) (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#2| (-368)))) (-3988 (($ $) NIL (|has| |#2| (-457))) (($ $ (-1082)) NIL (|has| |#2| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#2| (-910)))) (-3977 (($ $ |#2| (-769) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1082) (-887 (-385))) (|has| |#2| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1082) (-887 (-572))) (|has| |#2| (-887 (-572)))))) (-3377 (((-769) $ $) NIL (|has| |#2| (-562)))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| |#2| (-1144)))) (-4335 (($ (-1166 |#2|) (-1082)) NIL) (($ (-1166 $) (-1082)) NIL)) (-3965 (($ $ (-769)) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#2| (-368)))) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#2| (-769)) 17) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1082)) NIL) (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-1784 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-1771 (($ $ $) NIL (|has| |#2| (-848)))) (-4238 (($ $ $) NIL (|has| |#2| (-848)))) (-3918 (($ (-1 (-769) (-769)) $) NIL)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-4155 (((-1166 |#2|) $) NIL)) (-1470 (((-3 (-1082) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#2| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-1658 (((-1152) $) NIL)) (-2845 (((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769)) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-1082)) (|:| -3751 (-769))) "failed") $) NIL)) (-2774 (($ $) NIL (|has| |#2| (-43 (-413 (-572)))))) (-1773 (($) NIL (|has| |#2| (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#2| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#2| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-3311 (($ $ (-769) |#2| $) NIL)) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#2| (-910)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#2| (-368)))) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#2| (-368)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1082) |#2|) NIL) (($ $ (-638 (-1082)) (-638 |#2|)) NIL) (($ $ (-1082) $) NIL) (($ $ (-638 (-1082)) (-638 $)) NIL)) (-4029 (((-769) $) NIL (|has| |#2| (-368)))) (-3277 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-413 $) (-413 $) (-413 $)) NIL (|has| |#2| (-562))) ((|#2| (-413 $) |#2|) NIL (|has| |#2| (-368))) (((-413 $) $ (-413 $)) NIL (|has| |#2| (-562)))) (-1997 (((-3 $ "failed") $ (-769)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-368)))) (-2119 (($ $ (-1082)) NIL (|has| |#2| (-174))) ((|#2| $) NIL (|has| |#2| (-174)))) (-3139 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) $) NIL)) (-4316 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-1082) (-613 (-545))) (|has| |#2| (-613 (-545)))))) (-3694 ((|#2| $) NIL (|has| |#2| (-457))) (($ $ (-1082)) NIL (|has| |#2| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#2| (-910))))) (-2268 (((-3 $ "failed") $ $) NIL (|has| |#2| (-562))) (((-3 (-413 $) "failed") (-413 $) $) NIL (|has| |#2| (-562)))) (-3972 (((-856) $) 13) (($ (-572)) NIL) (($ |#2|) 26) (($ (-1082)) NIL) (($ (-1255 |#1|)) 20) (($ (-959 |#2|)) 34) (($ (-1170)) 18) (($ (-413 (-572))) NIL (-1841 (|has| |#2| (-43 (-413 (-572)))) (|has| |#2| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#2| (-562)))) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-769)) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#2| (-910))) (|has| |#2| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#2| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#2| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) 14 T CONST)) (-1557 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#2| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#2| (-43 (-413 (-572))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-740 |#1| |#2|) (-13 (-1234 |#2|) (-10 -8 (-6 (-1044 (-1170))) (-15 -3972 ($ (-1255 |#1|))) (-15 -3311 ($ $ (-769) |#2| $)) (IF (|has| |#2| (-15 -4297 ((-1166 |#2|) |#2| (-1170)))) (-15 -3972 ($ |#2|)) |noBranch|) (-15 -3972 ($ (-959 |#2|))))) (-1170) (-1054)) (T -740)) 
-((-3972 (*1 *1 *2) (-12 (-5 *1 (-740 *3 *2)) (-14 *3 (-1170)) (-4 *2 (-1054)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *3)) (-14 *3 (-1170)) (-5 *1 (-740 *3 *4)) (-4 *4 (-1054)))) (-3311 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-769)) (-5 *1 (-740 *4 *3)) (-14 *4 (-1170)) (-4 *3 (-1054)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-959 *4)) (-4 *4 (-1054)) (-5 *1 (-740 *3 *4)) (-14 *3 (-1170))))) 
-(-13 (-1234 |#2|) (-10 -8 (-6 (-1044 (-1170))) (-15 -3972 ($ (-1255 |#1|))) (-15 -3311 ($ $ (-769) |#2| $)) (IF (|has| |#2| (-15 -4297 ((-1166 |#2|) |#2| (-1170)))) (-15 -3972 ($ |#2|)) |noBranch|) (-15 -3972 ($ (-959 |#2|))))) 
-((-2027 (($ $ (-923)) 12))) 
-(((-741 |#1| |#2|) (-10 -8 (-15 -2027 (|#1| |#1| (-923)))) (-742 |#2|) (-174)) (T -741)) 
-NIL 
-(-10 -8 (-15 -2027 (|#1| |#1| (-923)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-3014 (($ $ (-923)) 27)) (-2027 (($ $ (-923)) 32)) (-3276 (($ $ (-923)) 28)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4056 (($ $ $) 24)) (-3972 (((-856) $) 11)) (-4250 (($ $ $ $) 25)) (-1397 (($ $ $) 23)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 29)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
-(((-742 |#1|) (-1290) (-174)) (T -742)) 
-((-2027 (*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-742 *3)) (-4 *3 (-174))))) 
-(-13 (-759) (-713 |t#1|) (-10 -8 (-15 -2027 ($ $ (-923))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-713 |#1|) . T) ((-716) . T) ((-759) . T) ((-1060 |#1|) . T) ((-1098) . T)) 
-((-3229 (((-1042) (-685 (-217)) (-572) (-121) (-572)) 24)) (-3234 (((-1042) (-685 (-217)) (-572) (-121) (-572)) 23))) 
-(((-743) (-10 -7 (-15 -3234 ((-1042) (-685 (-217)) (-572) (-121) (-572))) (-15 -3229 ((-1042) (-685 (-217)) (-572) (-121) (-572))))) (T -743)) 
-((-3229 (*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-121)) (-5 *2 (-1042)) (-5 *1 (-743)))) (-3234 (*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-121)) (-5 *2 (-1042)) (-5 *1 (-743))))) 
-(-10 -7 (-15 -3234 ((-1042) (-685 (-217)) (-572) (-121) (-572))) (-15 -3229 ((-1042) (-685 (-217)) (-572) (-121) (-572)))) 
-((-3242 (((-1042) (-572) (-572) (-572) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-79 FCN)))) 43)) (-2172 (((-1042) (-572) (-572) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-86 FCN)))) 39)) (-2182 (((-1042) (-217) (-217) (-217) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) 32))) 
-(((-744) (-10 -7 (-15 -2182 ((-1042) (-217) (-217) (-217) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2172 ((-1042) (-572) (-572) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-86 FCN))))) (-15 -3242 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-79 FCN))))))) (T -744)) 
-((-3242 (*1 *2 *3 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-79 FCN)))) (-5 *2 (-1042)) (-5 *1 (-744)))) (-2172 (*1 *2 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-86 FCN)))) (-5 *2 (-1042)) (-5 *1 (-744)))) (-2182 (*1 *2 *3 *3 *3 *3 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *2 (-1042)) (-5 *1 (-744))))) 
-(-10 -7 (-15 -2182 ((-1042) (-217) (-217) (-217) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2172 ((-1042) (-572) (-572) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-86 FCN))))) (-15 -3242 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-79 FCN)))))) 
-((-2189 (((-1042) (-572) (-572) (-685 (-217)) (-572)) 33)) (-2198 (((-1042) (-572) (-572) (-685 (-217)) (-572)) 32)) (-2210 (((-1042) (-572) (-685 (-217)) (-572)) 31)) (-2220 (((-1042) (-572) (-685 (-217)) (-572)) 30)) (-2227 (((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 29)) (-2238 (((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 28)) (-2247 (((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-572)) 27)) (-2252 (((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-572)) 26)) (-2260 (((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572)) 23)) (-2274 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572)) 22)) (-2283 (((-1042) (-572) (-685 (-217)) (-572)) 21)) (-2292 (((-1042) (-572) (-685 (-217)) (-572)) 20))) 
-(((-745) (-10 -7 (-15 -2292 ((-1042) (-572) (-685 (-217)) (-572))) (-15 -2283 ((-1042) (-572) (-685 (-217)) (-572))) (-15 -2274 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2260 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2252 ((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2247 ((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2238 ((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2227 ((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2220 ((-1042) (-572) (-685 (-217)) (-572))) (-15 -2210 ((-1042) (-572) (-685 (-217)) (-572))) (-15 -2198 ((-1042) (-572) (-572) (-685 (-217)) (-572))) (-15 -2189 ((-1042) (-572) (-572) (-685 (-217)) (-572))))) (T -745)) 
-((-2189 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2198 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2210 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2220 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2227 (*1 *2 *3 *3 *4 *5 *5 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2238 (*1 *2 *3 *3 *4 *5 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2247 (*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2252 (*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2260 (*1 *2 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2274 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2283 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745)))) (-2292 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(-10 -7 (-15 -2292 ((-1042) (-572) (-685 (-217)) (-572))) (-15 -2283 ((-1042) (-572) (-685 (-217)) (-572))) (-15 -2274 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2260 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2252 ((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2247 ((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2238 ((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2227 ((-1042) (-572) (-572) (-1152) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2220 ((-1042) (-572) (-685 (-217)) (-572))) (-15 -2210 ((-1042) (-572) (-685 (-217)) (-572))) (-15 -2198 ((-1042) (-572) (-572) (-685 (-217)) (-572))) (-15 -2189 ((-1042) (-572) (-572) (-685 (-217)) (-572)))) 
-((-3390 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-217) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN)))) 52)) (-3397 (((-1042) (-685 (-217)) (-685 (-217)) (-572) (-572)) 51)) (-3403 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN)))) 50)) (-3411 (((-1042) (-217) (-217) (-572) (-572) (-572) (-572)) 46)) (-3417 (((-1042) (-217) (-217) (-572) (-217) (-572) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) 45)) (-2535 (((-1042) (-217) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) 44)) (-2549 (((-1042) (-217) (-217) (-217) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) 43)) (-2571 (((-1042) (-217) (-217) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) 42)) (-2577 (((-1042) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) 38)) (-2588 (((-1042) (-217) (-217) (-572) (-685 (-217)) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) 37)) (-2605 (((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) 33)) (-2622 (((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) 32))) 
-(((-746) (-10 -7 (-15 -2622 ((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2605 ((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2588 ((-1042) (-217) (-217) (-572) (-685 (-217)) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2577 ((-1042) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2571 ((-1042) (-217) (-217) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G))))) (-15 -2549 ((-1042) (-217) (-217) (-217) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G))))) (-15 -2535 ((-1042) (-217) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G))))) (-15 -3417 ((-1042) (-217) (-217) (-572) (-217) (-572) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G))))) (-15 -3411 ((-1042) (-217) (-217) (-572) (-572) (-572) (-572))) (-15 -3403 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN))))) (-15 -3397 ((-1042) (-685 (-217)) (-685 (-217)) (-572) (-572))) (-15 -3390 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-217) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN))))))) (T -746)) 
-((-3390 (*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1042)) (-5 *1 (-746)))) (-3397 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-746)))) (-3403 (*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1042)) (-5 *1 (-746)))) (-3411 (*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-746)))) (-3417 (*1 *2 *3 *3 *4 *3 *4 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) (-5 *2 (-1042)) (-5 *1 (-746)))) (-2535 (*1 *2 *3 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) (-5 *2 (-1042)) (-5 *1 (-746)))) (-2549 (*1 *2 *3 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) (-5 *2 (-1042)) (-5 *1 (-746)))) (-2571 (*1 *2 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) (-5 *2 (-1042)) (-5 *1 (-746)))) (-2577 (*1 *2 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *2 (-1042)) (-5 *1 (-746)))) (-2588 (*1 *2 *3 *3 *4 *5 *3 *3 *4 *4 *4 *6) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-746)))) (-2605 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *2 (-1042)) (-5 *1 (-746)))) (-2622 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(-10 -7 (-15 -2622 ((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2605 ((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2588 ((-1042) (-217) (-217) (-572) (-685 (-217)) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2577 ((-1042) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313))))) (-15 -2571 ((-1042) (-217) (-217) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G))))) (-15 -2549 ((-1042) (-217) (-217) (-217) (-217) (-572) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G))))) (-15 -2535 ((-1042) (-217) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G))))) (-15 -3417 ((-1042) (-217) (-217) (-572) (-217) (-572) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G))))) (-15 -3411 ((-1042) (-217) (-217) (-572) (-572) (-572) (-572))) (-15 -3403 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-217) (-572) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN))))) (-15 -3397 ((-1042) (-685 (-217)) (-685 (-217)) (-572) (-572))) (-15 -3390 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-217) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN)))))) 
-((-3431 (((-1042) (-572) (-572) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-394)) (|:| |fp| (-81 G JACOBG JACGEP)))) 76)) (-3437 (((-1042) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL))) (-394) (-394)) 69) (((-1042) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL)))) 68)) (-3443 (((-1042) (-217) (-217) (-572) (-217) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-394)) (|:| |fp| (-90 FCNG)))) 57)) (-3450 (((-1042) (-685 (-217)) (-685 (-217)) (-572) (-217) (-217) (-217) (-572) (-572) (-572) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) 50)) (-3457 (((-1042) (-217) (-572) (-572) (-1152) (-572) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) 49)) (-3464 (((-1042) (-217) (-572) (-572) (-217) (-1152) (-217) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) 45)) (-1993 (((-1042) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) 42)) (-2000 (((-1042) (-217) (-572) (-572) (-572) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) 38))) 
-(((-747) (-10 -7 (-15 -2000 ((-1042) (-217) (-572) (-572) (-572) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT))))) (-15 -1993 ((-1042) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))))) (-15 -3464 ((-1042) (-217) (-572) (-572) (-217) (-1152) (-217) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT))))) (-15 -3457 ((-1042) (-217) (-572) (-572) (-1152) (-572) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT))))) (-15 -3450 ((-1042) (-685 (-217)) (-685 (-217)) (-572) (-217) (-217) (-217) (-572) (-572) (-572) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))))) (-15 -3443 ((-1042) (-217) (-217) (-572) (-217) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-394)) (|:| |fp| (-90 FCNG))))) (-15 -3437 ((-1042) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL))))) (-15 -3437 ((-1042) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL))) (-394) (-394))) (-15 -3431 ((-1042) (-572) (-572) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-394)) (|:| |fp| (-81 G JACOBG JACGEP))))))) (T -747)) 
-((-3431 (*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-80 FCN JACOBF JACEPS)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-81 G JACOBG JACGEP)))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-747)))) (-3437 (*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7 *8 *8) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL)))) (-5 *8 (-394)) (-5 *2 (-1042)) (-5 *1 (-747)))) (-3437 (*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL)))) (-5 *2 (-1042)) (-5 *1 (-747)))) (-3443 (*1 *2 *3 *3 *4 *3 *4 *4 *4 *5 *5 *5 *5 *4 *4 *6 *7) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-89 FCNF)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-90 FCNG)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747)))) (-3450 (*1 *2 *3 *3 *4 *5 *5 *5 *4 *4 *4 *3 *4 *4 *6) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *2 (-1042)) (-5 *1 (-747)))) (-3457 (*1 *2 *3 *4 *4 *5 *4 *3 *6 *3 *4 *7 *8 *9 *10) (-12 (-5 *4 (-572)) (-5 *5 (-1152)) (-5 *6 (-685 (-217))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-394)) (|:| |fp| (-76 PEDERV)))) (-5 *10 (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747)))) (-3464 (*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (-12 (-5 *4 (-572)) (-5 *5 (-1152)) (-5 *6 (-685 (-217))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747)))) (-1993 (*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747)))) (-2000 (*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(-10 -7 (-15 -2000 ((-1042) (-217) (-572) (-572) (-572) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT))))) (-15 -1993 ((-1042) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))))) (-15 -3464 ((-1042) (-217) (-572) (-572) (-217) (-1152) (-217) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT))))) (-15 -3457 ((-1042) (-217) (-572) (-572) (-1152) (-572) (-217) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT))))) (-15 -3450 ((-1042) (-685 (-217)) (-685 (-217)) (-572) (-217) (-217) (-217) (-572) (-572) (-572) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN))))) (-15 -3443 ((-1042) (-217) (-217) (-572) (-217) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-394)) (|:| |fp| (-90 FCNG))))) (-15 -3437 ((-1042) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL))))) (-15 -3437 ((-1042) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL))) (-394) (-394))) (-15 -3431 ((-1042) (-572) (-572) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-394)) (|:| |fp| (-81 G JACOBG JACGEP)))))) 
-((-2031 (((-1042) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-670 (-217)) (-572)) 45)) (-2037 (((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-1152) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-394)) (|:| |fp| (-88 BNDY)))) 41)) (-2049 (((-1042) (-572) (-572) (-572) (-572) (-217) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 23))) 
-(((-748) (-10 -7 (-15 -2049 ((-1042) (-572) (-572) (-572) (-572) (-217) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2037 ((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-1152) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-394)) (|:| |fp| (-88 BNDY))))) (-15 -2031 ((-1042) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-670 (-217)) (-572))))) (T -748)) 
-((-2031 (*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-670 (-217))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-748)))) (-2037 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-1152)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-87 PDEF)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-88 BNDY)))) (-5 *2 (-1042)) (-5 *1 (-748)))) (-2049 (*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-748))))) 
-(-10 -7 (-15 -2049 ((-1042) (-572) (-572) (-572) (-572) (-217) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2037 ((-1042) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-1152) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-394)) (|:| |fp| (-88 BNDY))))) (-15 -2031 ((-1042) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-670 (-217)) (-572)))) 
-((-3615 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-685 (-217)) (-217) (-217) (-572)) 35)) (-3263 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-217) (-217) (-572)) 34)) (-3836 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-685 (-217)) (-217) (-217) (-572)) 33)) (-3268 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 29)) (-3273 (((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 28)) (-3278 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572)) 27)) (-3285 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-572)) 23)) (-3290 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-572)) 22)) (-3295 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572)) 21)) (-3300 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572)) 20))) 
-(((-749) (-10 -7 (-15 -3300 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572))) (-15 -3295 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3290 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-572))) (-15 -3285 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-572))) (-15 -3278 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572))) (-15 -3273 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3268 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3836 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-685 (-217)) (-217) (-217) (-572))) (-15 -3263 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-217) (-217) (-572))) (-15 -3615 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-685 (-217)) (-217) (-217) (-572))))) (T -749)) 
-((-3615 (*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3263 (*1 *2 *3 *4 *4 *4 *3 *3 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3836 (*1 *2 *3 *4 *4 *4 *5 *4 *6 *6 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *6 (-217)) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3268 (*1 *2 *3 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3273 (*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3278 (*1 *2 *3 *4 *4 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3285 (*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3290 (*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3295 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749)))) (-3300 (*1 *2 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(-10 -7 (-15 -3300 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572))) (-15 -3295 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3290 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-572))) (-15 -3285 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-572))) (-15 -3278 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-217) (-572))) (-15 -3273 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3268 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3836 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-685 (-217)) (-217) (-217) (-572))) (-15 -3263 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-217) (-217) (-572))) (-15 -3615 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-685 (-217)) (-217) (-217) (-572)))) 
-((-3305 (((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572)) 45)) (-3309 (((-1042) (-572) (-572) (-572) (-217) (-685 (-217)) (-685 (-217)) (-572)) 44)) (-3314 (((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572)) 43)) (-3318 (((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 42)) (-3323 (((-1042) (-1152) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572)) 41)) (-3328 (((-1042) (-1152) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572)) 40)) (-3333 (((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572) (-572) (-572) (-217) (-685 (-217)) (-572)) 39)) (-3338 (((-1042) (-1152) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-572))) 38)) (-3344 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572)) 35)) (-1646 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572)) 34)) (-1649 (((-1042) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572)) 33)) (-1657 (((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 32)) (-1662 (((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-217) (-572)) 31)) (-1667 (((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-572)) 30)) (-2002 (((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-572) (-572) (-572)) 29)) (-2517 (((-1042) (-572) (-572) (-572) (-217) (-217) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572) (-685 (-572)) (-572) (-572) (-572)) 28)) (-3219 (((-1042) (-572) (-685 (-217)) (-217) (-572)) 24)) (-3238 (((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 20))) 
-(((-750) (-10 -7 (-15 -3238 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3219 ((-1042) (-572) (-685 (-217)) (-217) (-572))) (-15 -2517 ((-1042) (-572) (-572) (-572) (-217) (-217) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572) (-685 (-572)) (-572) (-572) (-572))) (-15 -2002 ((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-572) (-572) (-572))) (-15 -1667 ((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-572))) (-15 -1662 ((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-217) (-572))) (-15 -1657 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1649 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572))) (-15 -1646 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572))) (-15 -3344 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3338 ((-1042) (-1152) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-572)))) (-15 -3333 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572) (-572) (-572) (-217) (-685 (-217)) (-572))) (-15 -3328 ((-1042) (-1152) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572))) (-15 -3323 ((-1042) (-1152) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3318 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3314 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572))) (-15 -3309 ((-1042) (-572) (-572) (-572) (-217) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3305 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572))))) (T -750)) 
-((-3305 (*1 *2 *3 *3 *4 *4 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3309 (*1 *2 *3 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3314 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3318 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3323 (*1 *2 *3 *4 *5 *5 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3328 (*1 *2 *3 *4 *5 *4 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *7 *4) (-12 (-5 *3 (-1152)) (-5 *5 (-685 (-217))) (-5 *6 (-217)) (-5 *7 (-685 (-572))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3333 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *5 *3 *3 *3 *6 *4 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *6 (-217)) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3338 (*1 *2 *3 *4 *5 *5 *5 *6 *4 *4 *4 *5 *4 *5 *7) (-12 (-5 *3 (-1152)) (-5 *5 (-685 (-217))) (-5 *6 (-217)) (-5 *7 (-685 (-572))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3344 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750)))) (-1646 (*1 *2 *3 *4 *4 *5 *3 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-1649 (*1 *2 *3 *4 *4 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-1657 (*1 *2 *3 *3 *4 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750)))) (-1662 (*1 *2 *3 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-1667 (*1 *2 *3 *4 *4 *5 *3 *3 *4 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-2002 (*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-2517 (*1 *2 *3 *3 *3 *4 *4 *5 *5 *5 *3 *5 *5 *3 *6 *3 *3 *3) (-12 (-5 *5 (-685 (-217))) (-5 *6 (-685 (-572))) (-5 *3 (-572)) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3219 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-750)))) (-3238 (*1 *2 *3 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(-10 -7 (-15 -3238 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3219 ((-1042) (-572) (-685 (-217)) (-217) (-572))) (-15 -2517 ((-1042) (-572) (-572) (-572) (-217) (-217) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572) (-685 (-572)) (-572) (-572) (-572))) (-15 -2002 ((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-572) (-572) (-572))) (-15 -1667 ((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-217) (-572) (-572) (-572))) (-15 -1662 ((-1042) (-572) (-217) (-217) (-685 (-217)) (-572) (-572) (-217) (-572))) (-15 -1657 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1649 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572))) (-15 -1646 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572))) (-15 -3344 ((-1042) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3338 ((-1042) (-1152) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-572)))) (-15 -3333 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572) (-572) (-572) (-217) (-685 (-217)) (-572))) (-15 -3328 ((-1042) (-1152) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572))) (-15 -3323 ((-1042) (-1152) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3318 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3314 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572))) (-15 -3309 ((-1042) (-572) (-572) (-572) (-217) (-685 (-217)) (-685 (-217)) (-572))) (-15 -3305 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572) (-685 (-217)) (-685 (-217)) (-572) (-572) (-572)))) 
-((-1672 (((-1042) (-572) (-572) (-572) (-217) (-685 (-217)) (-572) (-685 (-217)) (-572)) 63)) (-1679 (((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-121) (-217) (-572) (-217) (-217) (-121) (-217) (-217) (-217) (-217) (-121) (-572) (-572) (-572) (-572) (-572) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-572)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN)))) 62)) (-1683 (((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-217) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-121) (-121) (-121) (-572) (-572) (-685 (-217)) (-685 (-572)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-70 QPHESS)))) 58)) (-1691 (((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-121) (-572) (-572) (-685 (-217)) (-572)) 51)) (-1697 (((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-71 FUNCT1)))) 50)) (-1703 (((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-68 LSFUN2)))) 46)) (-1708 (((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-84 LSFUN1)))) 42)) (-1714 (((-1042) (-572) (-217) (-217) (-572) (-217) (-121) (-217) (-217) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN)))) 38))) 
-(((-751) (-10 -7 (-15 -1714 ((-1042) (-572) (-217) (-217) (-572) (-217) (-121) (-217) (-217) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN))))) (-15 -1708 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-84 LSFUN1))))) (-15 -1703 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-68 LSFUN2))))) (-15 -1697 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-71 FUNCT1))))) (-15 -1691 ((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-121) (-572) (-572) (-685 (-217)) (-572))) (-15 -1683 ((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-217) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-121) (-121) (-121) (-572) (-572) (-685 (-217)) (-685 (-572)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-70 QPHESS))))) (-15 -1679 ((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-121) (-217) (-572) (-217) (-217) (-121) (-217) (-217) (-217) (-217) (-121) (-572) (-572) (-572) (-572) (-572) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-572)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN))))) (-15 -1672 ((-1042) (-572) (-572) (-572) (-217) (-685 (-217)) (-572) (-685 (-217)) (-572))))) (T -751)) 
-((-1672 (*1 *2 *3 *3 *3 *4 *5 *3 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-751)))) (-1679 (*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *3 *3 *5 *6 *3 *6 *6 *5 *6 *6 *6 *6 *5 *3 *3 *3 *3 *3 *6 *6 *6 *3 *3 *3 *3 *3 *7 *4 *4 *4 *4 *3 *8 *9) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-121)) (-5 *6 (-217)) (-5 *7 (-685 (-572))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-85 CONFUN)))) (-5 *9 (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN)))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-751)))) (-1683 (*1 *2 *3 *3 *3 *3 *3 *3 *3 *3 *4 *5 *5 *5 *5 *5 *5 *6 *6 *6 *3 *3 *5 *7 *3 *8) (-12 (-5 *5 (-685 (-217))) (-5 *6 (-121)) (-5 *7 (-685 (-572))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-70 QPHESS)))) (-5 *3 (-572)) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-751)))) (-1691 (*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-121)) (-5 *2 (-1042)) (-5 *1 (-751)))) (-1697 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *3 *5) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-71 FUNCT1)))) (-5 *2 (-1042)) (-5 *1 (-751)))) (-1703 (*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-68 LSFUN2)))) (-5 *2 (-1042)) (-5 *1 (-751)))) (-1708 (*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-84 LSFUN1)))) (-5 *2 (-1042)) (-5 *1 (-751)))) (-1714 (*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (-12 (-5 *3 (-572)) (-5 *5 (-121)) (-5 *6 (-685 (-217))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN)))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(-10 -7 (-15 -1714 ((-1042) (-572) (-217) (-217) (-572) (-217) (-121) (-217) (-217) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN))))) (-15 -1708 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-84 LSFUN1))))) (-15 -1703 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-68 LSFUN2))))) (-15 -1697 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-71 FUNCT1))))) (-15 -1691 ((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-121) (-572) (-572) (-685 (-217)) (-572))) (-15 -1683 ((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-217) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-121) (-121) (-121) (-572) (-572) (-685 (-217)) (-685 (-572)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-70 QPHESS))))) (-15 -1679 ((-1042) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-572) (-121) (-217) (-572) (-217) (-217) (-121) (-217) (-217) (-217) (-217) (-121) (-572) (-572) (-572) (-572) (-572) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-572) (-685 (-572)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN))))) (-15 -1672 ((-1042) (-572) (-572) (-572) (-217) (-685 (-217)) (-572) (-685 (-217)) (-572)))) 
-((-1719 (((-1042) (-1152) (-572) (-572) (-572) (-572) (-685 (-171 (-217))) (-685 (-171 (-217))) (-572)) 46)) (-1724 (((-1042) (-1152) (-1152) (-572) (-572) (-685 (-171 (-217))) (-572) (-685 (-171 (-217))) (-572) (-572) (-685 (-171 (-217))) (-572)) 45)) (-1728 (((-1042) (-572) (-572) (-572) (-685 (-171 (-217))) (-572)) 44)) (-1732 (((-1042) (-1152) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572)) 40)) (-1736 (((-1042) (-1152) (-1152) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-685 (-217)) (-572)) 39)) (-1740 (((-1042) (-572) (-572) (-572) (-685 (-217)) (-572)) 36)) (-1745 (((-1042) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572)) 35)) (-1751 (((-1042) (-572) (-572) (-572) (-572) (-638 (-121)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-217) (-217) (-572)) 34)) (-1755 (((-1042) (-572) (-572) (-572) (-685 (-572)) (-685 (-572)) (-685 (-572)) (-685 (-572)) (-121) (-217) (-121) (-685 (-572)) (-685 (-217)) (-572)) 33)) (-1760 (((-1042) (-572) (-572) (-572) (-572) (-217) (-121) (-121) (-638 (-121)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-572)) 32))) 
-(((-752) (-10 -7 (-15 -1760 ((-1042) (-572) (-572) (-572) (-572) (-217) (-121) (-121) (-638 (-121)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-572))) (-15 -1755 ((-1042) (-572) (-572) (-572) (-685 (-572)) (-685 (-572)) (-685 (-572)) (-685 (-572)) (-121) (-217) (-121) (-685 (-572)) (-685 (-217)) (-572))) (-15 -1751 ((-1042) (-572) (-572) (-572) (-572) (-638 (-121)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-217) (-217) (-572))) (-15 -1745 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572))) (-15 -1740 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-572))) (-15 -1736 ((-1042) (-1152) (-1152) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-685 (-217)) (-572))) (-15 -1732 ((-1042) (-1152) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1728 ((-1042) (-572) (-572) (-572) (-685 (-171 (-217))) (-572))) (-15 -1724 ((-1042) (-1152) (-1152) (-572) (-572) (-685 (-171 (-217))) (-572) (-685 (-171 (-217))) (-572) (-572) (-685 (-171 (-217))) (-572))) (-15 -1719 ((-1042) (-1152) (-572) (-572) (-572) (-572) (-685 (-171 (-217))) (-685 (-171 (-217))) (-572))))) (T -752)) 
-((-1719 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1724 (*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1728 (*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1732 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1736 (*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1740 (*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1745 (*1 *2 *3 *4 *3 *5 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1751 (*1 *2 *3 *3 *3 *3 *4 *5 *6 *6 *7 *7 *3) (-12 (-5 *4 (-638 (-121))) (-5 *5 (-685 (-217))) (-5 *6 (-685 (-572))) (-5 *7 (-217)) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1755 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *5 *6 *5 *4 *7 *3) (-12 (-5 *4 (-685 (-572))) (-5 *5 (-121)) (-5 *7 (-685 (-217))) (-5 *3 (-572)) (-5 *6 (-217)) (-5 *2 (-1042)) (-5 *1 (-752)))) (-1760 (*1 *2 *3 *3 *3 *3 *4 *5 *5 *6 *7 *8 *8 *3) (-12 (-5 *6 (-638 (-121))) (-5 *7 (-685 (-217))) (-5 *8 (-685 (-572))) (-5 *3 (-572)) (-5 *4 (-217)) (-5 *5 (-121)) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(-10 -7 (-15 -1760 ((-1042) (-572) (-572) (-572) (-572) (-217) (-121) (-121) (-638 (-121)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-572))) (-15 -1755 ((-1042) (-572) (-572) (-572) (-685 (-572)) (-685 (-572)) (-685 (-572)) (-685 (-572)) (-121) (-217) (-121) (-685 (-572)) (-685 (-217)) (-572))) (-15 -1751 ((-1042) (-572) (-572) (-572) (-572) (-638 (-121)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-217) (-217) (-572))) (-15 -1745 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572))) (-15 -1740 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-572))) (-15 -1736 ((-1042) (-1152) (-1152) (-572) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-685 (-217)) (-572))) (-15 -1732 ((-1042) (-1152) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1728 ((-1042) (-572) (-572) (-572) (-685 (-171 (-217))) (-572))) (-15 -1724 ((-1042) (-1152) (-1152) (-572) (-572) (-685 (-171 (-217))) (-572) (-685 (-171 (-217))) (-572) (-572) (-685 (-171 (-217))) (-572))) (-15 -1719 ((-1042) (-1152) (-572) (-572) (-572) (-572) (-685 (-171 (-217))) (-685 (-171 (-217))) (-572)))) 
-((-2898 (((-1042) (-572) (-572) (-572) (-572) (-572) (-121) (-572) (-121) (-572) (-685 (-171 (-217))) (-685 (-171 (-217))) (-572)) 64)) (-2904 (((-1042) (-572) (-572) (-572) (-572) (-572) (-121) (-572) (-121) (-572) (-685 (-217)) (-685 (-217)) (-572)) 60)) (-2911 (((-1042) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE))) (-394)) 56) (((-1042) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE)))) 55)) (-2918 (((-1042) (-572) (-572) (-572) (-217) (-121) (-572) (-685 (-217)) (-685 (-217)) (-572)) 37)) (-2925 (((-1042) (-572) (-572) (-217) (-217) (-572) (-572) (-685 (-217)) (-572)) 33)) (-2930 (((-1042) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-572) (-572) (-572)) 29)) (-2937 (((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572)) 28)) (-1487 (((-1042) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572)) 27)) (-1494 (((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572)) 26)) (-1500 (((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572)) 25)) (-1511 (((-1042) (-572) (-572) (-685 (-217)) (-572)) 24)) (-1517 (((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572)) 23)) (-1523 (((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572)) 22)) (-1528 (((-1042) (-685 (-217)) (-572) (-572) (-572) (-572)) 21)) (-1533 (((-1042) (-572) (-572) (-685 (-217)) (-572)) 20))) 
-(((-753) (-10 -7 (-15 -1533 ((-1042) (-572) (-572) (-685 (-217)) (-572))) (-15 -1528 ((-1042) (-685 (-217)) (-572) (-572) (-572) (-572))) (-15 -1523 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1517 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1511 ((-1042) (-572) (-572) (-685 (-217)) (-572))) (-15 -1500 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572))) (-15 -1494 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1487 ((-1042) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2937 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2930 ((-1042) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-572) (-572) (-572))) (-15 -2925 ((-1042) (-572) (-572) (-217) (-217) (-572) (-572) (-685 (-217)) (-572))) (-15 -2918 ((-1042) (-572) (-572) (-572) (-217) (-121) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2911 ((-1042) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE))))) (-15 -2911 ((-1042) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE))) (-394))) (-15 -2904 ((-1042) (-572) (-572) (-572) (-572) (-572) (-121) (-572) (-121) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2898 ((-1042) (-572) (-572) (-572) (-572) (-572) (-121) (-572) (-121) (-572) (-685 (-171 (-217))) (-685 (-171 (-217))) (-572))))) (T -753)) 
-((-2898 (*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-121)) (-5 *5 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-2904 (*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-121)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-2911 (*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE)))) (-5 *8 (-394)) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-753)))) (-2911 (*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE)))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-753)))) (-2918 (*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (-12 (-5 *3 (-572)) (-5 *5 (-121)) (-5 *6 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-753)))) (-2925 (*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-753)))) (-2930 (*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-753)))) (-2937 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-1487 (*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-1494 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-1500 (*1 *2 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-1511 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-1517 (*1 *2 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-1523 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753)))) (-1528 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-753)))) (-1533 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(-10 -7 (-15 -1533 ((-1042) (-572) (-572) (-685 (-217)) (-572))) (-15 -1528 ((-1042) (-685 (-217)) (-572) (-572) (-572) (-572))) (-15 -1523 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1517 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1511 ((-1042) (-572) (-572) (-685 (-217)) (-572))) (-15 -1500 ((-1042) (-572) (-572) (-572) (-572) (-685 (-217)) (-572))) (-15 -1494 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -1487 ((-1042) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2937 ((-1042) (-572) (-572) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2930 ((-1042) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-572) (-572) (-572))) (-15 -2925 ((-1042) (-572) (-572) (-217) (-217) (-572) (-572) (-685 (-217)) (-572))) (-15 -2918 ((-1042) (-572) (-572) (-572) (-217) (-121) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2911 ((-1042) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE))))) (-15 -2911 ((-1042) (-572) (-572) (-217) (-572) (-572) (-572) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE))) (-394))) (-15 -2904 ((-1042) (-572) (-572) (-572) (-572) (-572) (-121) (-572) (-121) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2898 ((-1042) (-572) (-572) (-572) (-572) (-572) (-121) (-572) (-121) (-572) (-685 (-171 (-217))) (-685 (-171 (-217))) (-572)))) 
-((-2687 (((-1042) (-572) (-572) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-75 APROD)))) 60)) (-2697 (((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-572)) (-572) (-685 (-217)) (-572) (-572) (-572) (-572)) 56)) (-2705 (((-1042) (-572) (-685 (-217)) (-121) (-217) (-572) (-572) (-572) (-572) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-394)) (|:| |fp| (-78 MSOLVE)))) 55)) (-2713 (((-1042) (-572) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572) (-685 (-572)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572)) 36)) (-2722 (((-1042) (-572) (-572) (-572) (-217) (-572) (-685 (-217)) (-685 (-217)) (-572)) 35)) (-2730 (((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572)) 31)) (-2738 (((-1042) (-572) (-685 (-217)) (-572) (-685 (-572)) (-685 (-572)) (-572) (-685 (-572)) (-685 (-217))) 30)) (-2747 (((-1042) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-572)) 26)) (-2752 (((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572)) 25)) (-2771 (((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572)) 24)) (-2784 (((-1042) (-572) (-685 (-171 (-217))) (-572) (-572) (-572) (-572) (-685 (-171 (-217))) (-572)) 20))) 
-(((-754) (-10 -7 (-15 -2784 ((-1042) (-572) (-685 (-171 (-217))) (-572) (-572) (-572) (-572) (-685 (-171 (-217))) (-572))) (-15 -2771 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572))) (-15 -2752 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572))) (-15 -2747 ((-1042) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-572))) (-15 -2738 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-572)) (-685 (-572)) (-572) (-685 (-572)) (-685 (-217)))) (-15 -2730 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2722 ((-1042) (-572) (-572) (-572) (-217) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2713 ((-1042) (-572) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572) (-685 (-572)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572))) (-15 -2705 ((-1042) (-572) (-685 (-217)) (-121) (-217) (-572) (-572) (-572) (-572) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-394)) (|:| |fp| (-78 MSOLVE))))) (-15 -2697 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-572)) (-572) (-685 (-217)) (-572) (-572) (-572) (-572))) (-15 -2687 ((-1042) (-572) (-572) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-75 APROD))))))) (T -754)) 
-((-2687 (*1 *2 *3 *3 *4 *4 *4 *4 *3 *3 *3 *3 *5 *3 *6) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-75 APROD)))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2697 (*1 *2 *3 *4 *3 *4 *5 *3 *4 *3 *3 *3 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2705 (*1 *2 *3 *4 *5 *6 *3 *3 *3 *3 *6 *3 *7 *8) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-121)) (-5 *6 (-217)) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-73 APROD)))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-78 MSOLVE)))) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2713 (*1 *2 *3 *3 *4 *3 *5 *3 *5 *4 *5 *5 *4 *4 *5 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2722 (*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2730 (*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2738 (*1 *2 *3 *4 *3 *5 *5 *3 *5 *4) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2747 (*1 *2 *3 *4 *3 *4 *4 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2752 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2771 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-754)))) (-2784 (*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(-10 -7 (-15 -2784 ((-1042) (-572) (-685 (-171 (-217))) (-572) (-572) (-572) (-572) (-685 (-171 (-217))) (-572))) (-15 -2771 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572))) (-15 -2752 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-572))) (-15 -2747 ((-1042) (-685 (-217)) (-572) (-685 (-217)) (-572) (-572) (-572))) (-15 -2738 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-572)) (-685 (-572)) (-572) (-685 (-572)) (-685 (-217)))) (-15 -2730 ((-1042) (-572) (-572) (-685 (-217)) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2722 ((-1042) (-572) (-572) (-572) (-217) (-572) (-685 (-217)) (-685 (-217)) (-572))) (-15 -2713 ((-1042) (-572) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572) (-685 (-572)) (-685 (-217)) (-685 (-572)) (-685 (-572)) (-685 (-217)) (-685 (-217)) (-685 (-572)) (-572))) (-15 -2705 ((-1042) (-572) (-685 (-217)) (-121) (-217) (-572) (-572) (-572) (-572) (-217) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-394)) (|:| |fp| (-78 MSOLVE))))) (-15 -2697 ((-1042) (-572) (-685 (-217)) (-572) (-685 (-217)) (-685 (-572)) (-572) (-685 (-217)) (-572) (-572) (-572) (-572))) (-15 -2687 ((-1042) (-572) (-572) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-685 (-217)) (-572) (-3 (|:| |fn| (-394)) (|:| |fp| (-75 APROD)))))) 
-((-2840 (((-1042) (-1152) (-572) (-572) (-685 (-217)) (-572) (-572) (-685 (-217))) 28)) (-2851 (((-1042) (-1152) (-572) (-572) (-685 (-217))) 27)) (-2858 (((-1042) (-1152) (-572) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572) (-685 (-217))) 26)) (-2863 (((-1042) (-572) (-572) (-572) (-685 (-217))) 20))) 
-(((-755) (-10 -7 (-15 -2863 ((-1042) (-572) (-572) (-572) (-685 (-217)))) (-15 -2858 ((-1042) (-1152) (-572) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572) (-685 (-217)))) (-15 -2851 ((-1042) (-1152) (-572) (-572) (-685 (-217)))) (-15 -2840 ((-1042) (-1152) (-572) (-572) (-685 (-217)) (-572) (-572) (-685 (-217)))))) (T -755)) 
-((-2840 (*1 *2 *3 *4 *4 *5 *4 *4 *5) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-755)))) (-2851 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-755)))) (-2858 (*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (-12 (-5 *3 (-1152)) (-5 *5 (-685 (-217))) (-5 *6 (-685 (-572))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-755)))) (-2863 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-755))))) 
-(-10 -7 (-15 -2863 ((-1042) (-572) (-572) (-572) (-685 (-217)))) (-15 -2858 ((-1042) (-1152) (-572) (-572) (-685 (-217)) (-572) (-685 (-572)) (-572) (-685 (-217)))) (-15 -2851 ((-1042) (-1152) (-572) (-572) (-685 (-217)))) (-15 -2840 ((-1042) (-1152) (-572) (-572) (-685 (-217)) (-572) (-572) (-685 (-217))))) 
-((-2465 (((-1042) (-217) (-217) (-217) (-217) (-572)) 62)) (-2481 (((-1042) (-217) (-217) (-217) (-572)) 61)) (-2490 (((-1042) (-217) (-217) (-217) (-572)) 60)) (-2499 (((-1042) (-217) (-217) (-572)) 59)) (-2508 (((-1042) (-217) (-572)) 58)) (-2526 (((-1042) (-217) (-572)) 57)) (-2544 (((-1042) (-217) (-572)) 56)) (-2562 (((-1042) (-217) (-572)) 55)) (-2596 (((-1042) (-217) (-572)) 54)) (-2616 (((-1042) (-217) (-572)) 53)) (-2631 (((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572)) 52)) (-2642 (((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572)) 51)) (-2651 (((-1042) (-217) (-572)) 50)) (-2659 (((-1042) (-217) (-572)) 49)) (-2669 (((-1042) (-217) (-572)) 48)) (-2679 (((-1042) (-217) (-572)) 47)) (-2877 (((-1042) (-572) (-217) (-171 (-217)) (-572) (-1152) (-572)) 46)) (-2883 (((-1042) (-1152) (-171 (-217)) (-1152) (-572)) 45)) (-2892 (((-1042) (-1152) (-171 (-217)) (-1152) (-572)) 44)) (-2298 (((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572)) 43)) (-2308 (((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572)) 42)) (-2319 (((-1042) (-217) (-572)) 39)) (-2328 (((-1042) (-217) (-572)) 38)) (-2337 (((-1042) (-217) (-572)) 37)) (-2343 (((-1042) (-217) (-572)) 36)) (-2355 (((-1042) (-217) (-572)) 35)) (-2362 (((-1042) (-217) (-572)) 34)) (-2368 (((-1042) (-217) (-572)) 33)) (-2382 (((-1042) (-217) (-572)) 32)) (-2388 (((-1042) (-217) (-572)) 31)) (-2396 (((-1042) (-217) (-572)) 30)) (-2409 (((-1042) (-217) (-217) (-217) (-572)) 29)) (-2418 (((-1042) (-217) (-572)) 28)) (-2423 (((-1042) (-217) (-572)) 27)) (-2432 (((-1042) (-217) (-572)) 26)) (-2444 (((-1042) (-217) (-572)) 25)) (-2454 (((-1042) (-217) (-572)) 24)) (-2461 (((-1042) (-171 (-217)) (-572)) 20))) 
-(((-756) (-10 -7 (-15 -2461 ((-1042) (-171 (-217)) (-572))) (-15 -2454 ((-1042) (-217) (-572))) (-15 -2444 ((-1042) (-217) (-572))) (-15 -2432 ((-1042) (-217) (-572))) (-15 -2423 ((-1042) (-217) (-572))) (-15 -2418 ((-1042) (-217) (-572))) (-15 -2409 ((-1042) (-217) (-217) (-217) (-572))) (-15 -2396 ((-1042) (-217) (-572))) (-15 -2388 ((-1042) (-217) (-572))) (-15 -2382 ((-1042) (-217) (-572))) (-15 -2368 ((-1042) (-217) (-572))) (-15 -2362 ((-1042) (-217) (-572))) (-15 -2355 ((-1042) (-217) (-572))) (-15 -2343 ((-1042) (-217) (-572))) (-15 -2337 ((-1042) (-217) (-572))) (-15 -2328 ((-1042) (-217) (-572))) (-15 -2319 ((-1042) (-217) (-572))) (-15 -2308 ((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2298 ((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2892 ((-1042) (-1152) (-171 (-217)) (-1152) (-572))) (-15 -2883 ((-1042) (-1152) (-171 (-217)) (-1152) (-572))) (-15 -2877 ((-1042) (-572) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2679 ((-1042) (-217) (-572))) (-15 -2669 ((-1042) (-217) (-572))) (-15 -2659 ((-1042) (-217) (-572))) (-15 -2651 ((-1042) (-217) (-572))) (-15 -2642 ((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2631 ((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2616 ((-1042) (-217) (-572))) (-15 -2596 ((-1042) (-217) (-572))) (-15 -2562 ((-1042) (-217) (-572))) (-15 -2544 ((-1042) (-217) (-572))) (-15 -2526 ((-1042) (-217) (-572))) (-15 -2508 ((-1042) (-217) (-572))) (-15 -2499 ((-1042) (-217) (-217) (-572))) (-15 -2490 ((-1042) (-217) (-217) (-217) (-572))) (-15 -2481 ((-1042) (-217) (-217) (-217) (-572))) (-15 -2465 ((-1042) (-217) (-217) (-217) (-217) (-572))))) (T -756)) 
-((-2465 (*1 *2 *3 *3 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2481 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2490 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2499 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2508 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2526 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2544 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2562 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2596 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2616 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2631 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *6 (-1152)) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2642 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *6 (-1152)) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2651 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2659 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2669 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2679 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2877 (*1 *2 *3 *4 *5 *3 *6 *3) (-12 (-5 *3 (-572)) (-5 *5 (-171 (-217))) (-5 *6 (-1152)) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2883 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1152)) (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2892 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1152)) (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2298 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *6 (-1152)) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2308 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *6 (-1152)) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2319 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2328 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2337 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2343 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2355 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2362 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2368 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2382 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2388 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2396 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2409 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2418 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2423 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2432 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2444 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2454 (*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756)))) (-2461 (*1 *2 *3 *4) (-12 (-5 *3 (-171 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(-10 -7 (-15 -2461 ((-1042) (-171 (-217)) (-572))) (-15 -2454 ((-1042) (-217) (-572))) (-15 -2444 ((-1042) (-217) (-572))) (-15 -2432 ((-1042) (-217) (-572))) (-15 -2423 ((-1042) (-217) (-572))) (-15 -2418 ((-1042) (-217) (-572))) (-15 -2409 ((-1042) (-217) (-217) (-217) (-572))) (-15 -2396 ((-1042) (-217) (-572))) (-15 -2388 ((-1042) (-217) (-572))) (-15 -2382 ((-1042) (-217) (-572))) (-15 -2368 ((-1042) (-217) (-572))) (-15 -2362 ((-1042) (-217) (-572))) (-15 -2355 ((-1042) (-217) (-572))) (-15 -2343 ((-1042) (-217) (-572))) (-15 -2337 ((-1042) (-217) (-572))) (-15 -2328 ((-1042) (-217) (-572))) (-15 -2319 ((-1042) (-217) (-572))) (-15 -2308 ((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2298 ((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2892 ((-1042) (-1152) (-171 (-217)) (-1152) (-572))) (-15 -2883 ((-1042) (-1152) (-171 (-217)) (-1152) (-572))) (-15 -2877 ((-1042) (-572) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2679 ((-1042) (-217) (-572))) (-15 -2669 ((-1042) (-217) (-572))) (-15 -2659 ((-1042) (-217) (-572))) (-15 -2651 ((-1042) (-217) (-572))) (-15 -2642 ((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2631 ((-1042) (-217) (-171 (-217)) (-572) (-1152) (-572))) (-15 -2616 ((-1042) (-217) (-572))) (-15 -2596 ((-1042) (-217) (-572))) (-15 -2562 ((-1042) (-217) (-572))) (-15 -2544 ((-1042) (-217) (-572))) (-15 -2526 ((-1042) (-217) (-572))) (-15 -2508 ((-1042) (-217) (-572))) (-15 -2499 ((-1042) (-217) (-217) (-572))) (-15 -2490 ((-1042) (-217) (-217) (-217) (-572))) (-15 -2481 ((-1042) (-217) (-217) (-217) (-572))) (-15 -2465 ((-1042) (-217) (-217) (-217) (-217) (-572)))) 
-((-4336 (((-1264)) 18)) (-1305 (((-1152)) 22)) (-4478 (((-1152)) 21)) (-3321 (((-1102) (-1170) (-685 (-572))) 35) (((-1102) (-1170) (-685 (-217))) 31)) (-3146 (((-121)) 16)) (-3675 (((-1152) (-1152)) 25))) 
-(((-757) (-10 -7 (-15 -4478 ((-1152))) (-15 -1305 ((-1152))) (-15 -3675 ((-1152) (-1152))) (-15 -3321 ((-1102) (-1170) (-685 (-217)))) (-15 -3321 ((-1102) (-1170) (-685 (-572)))) (-15 -3146 ((-121))) (-15 -4336 ((-1264))))) (T -757)) 
-((-4336 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-757)))) (-3146 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-757)))) (-3321 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-685 (-572))) (-5 *2 (-1102)) (-5 *1 (-757)))) (-3321 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-685 (-217))) (-5 *2 (-1102)) (-5 *1 (-757)))) (-3675 (*1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-757)))) (-1305 (*1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-757)))) (-4478 (*1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-757))))) 
-(-10 -7 (-15 -4478 ((-1152))) (-15 -1305 ((-1152))) (-15 -3675 ((-1152) (-1152))) (-15 -3321 ((-1102) (-1170) (-685 (-217)))) (-15 -3321 ((-1102) (-1170) (-685 (-572)))) (-15 -3146 ((-121))) (-15 -4336 ((-1264)))) 
-((-4056 (($ $ $) 10)) (-4250 (($ $ $ $) 9)) (-1397 (($ $ $) 12))) 
-(((-758 |#1|) (-10 -8 (-15 -1397 (|#1| |#1| |#1|)) (-15 -4056 (|#1| |#1| |#1|)) (-15 -4250 (|#1| |#1| |#1| |#1|))) (-759)) (T -758)) 
-NIL 
-(-10 -8 (-15 -1397 (|#1| |#1| |#1|)) (-15 -4056 (|#1| |#1| |#1|)) (-15 -4250 (|#1| |#1| |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-3014 (($ $ (-923)) 27)) (-3276 (($ $ (-923)) 28)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4056 (($ $ $) 24)) (-3972 (((-856) $) 11)) (-4250 (($ $ $ $) 25)) (-1397 (($ $ $) 23)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 29)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 26))) 
-(((-759) (-1290)) (T -759)) 
-((-4250 (*1 *1 *1 *1 *1) (-4 *1 (-759))) (-4056 (*1 *1 *1 *1) (-4 *1 (-759))) (-1397 (*1 *1 *1 *1) (-4 *1 (-759)))) 
-(-13 (-21) (-716) (-10 -8 (-15 -4250 ($ $ $ $)) (-15 -4056 ($ $ $)) (-15 -1397 ($ $ $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-716) . T) ((-1098) . T)) 
-((-3972 (((-856) $) NIL) (($ (-572)) 10))) 
-(((-760 |#1|) (-10 -8 (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) (-761)) (T -760)) 
-NIL 
-(-10 -8 (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-2848 (((-3 $ "failed") $) 39)) (-3014 (($ $ (-923)) 27) (($ $ (-769)) 34)) (-1799 (((-3 $ "failed") $) 37)) (-3893 (((-121) $) 33)) (-2046 (((-3 $ "failed") $) 38)) (-3276 (($ $ (-923)) 28) (($ $ (-769)) 35)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4056 (($ $ $) 24)) (-3972 (((-856) $) 11) (($ (-572)) 30)) (-2140 (((-769)) 31)) (-4250 (($ $ $ $) 25)) (-1397 (($ $ $) 23)) (-2378 (($) 17 T CONST)) (-3255 (($) 32 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 29) (($ $ (-769)) 36)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 26))) 
-(((-761) (-1290)) (T -761)) 
-((-2140 (*1 *2) (-12 (-4 *1 (-761)) (-5 *2 (-769)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-761))))) 
-(-13 (-759) (-718) (-10 -8 (-15 -2140 ((-769))) (-15 -3972 ($ (-572))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-716) . T) ((-718) . T) ((-759) . T) ((-1098) . T)) 
-((-2598 (((-638 (-2 (|:| |outval| (-171 |#1|)) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 (-171 |#1|)))))) (-685 (-171 (-413 (-572)))) |#1|) 27)) (-1722 (((-638 (-171 |#1|)) (-685 (-171 (-413 (-572)))) |#1|) 19)) (-2707 (((-959 (-171 (-413 (-572)))) (-685 (-171 (-413 (-572)))) (-1170)) 16) (((-959 (-171 (-413 (-572)))) (-685 (-171 (-413 (-572))))) 15))) 
-(((-762 |#1|) (-10 -7 (-15 -2707 ((-959 (-171 (-413 (-572)))) (-685 (-171 (-413 (-572)))))) (-15 -2707 ((-959 (-171 (-413 (-572)))) (-685 (-171 (-413 (-572)))) (-1170))) (-15 -1722 ((-638 (-171 |#1|)) (-685 (-171 (-413 (-572)))) |#1|)) (-15 -2598 ((-638 (-2 (|:| |outval| (-171 |#1|)) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 (-171 |#1|)))))) (-685 (-171 (-413 (-572)))) |#1|))) (-13 (-368) (-846))) (T -762)) 
-((-2598 (*1 *2 *3 *4) (-12 (-5 *3 (-685 (-171 (-413 (-572))))) (-5 *2 (-638 (-2 (|:| |outval| (-171 *4)) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 (-171 *4))))))) (-5 *1 (-762 *4)) (-4 *4 (-13 (-368) (-846))))) (-1722 (*1 *2 *3 *4) (-12 (-5 *3 (-685 (-171 (-413 (-572))))) (-5 *2 (-638 (-171 *4))) (-5 *1 (-762 *4)) (-4 *4 (-13 (-368) (-846))))) (-2707 (*1 *2 *3 *4) (-12 (-5 *3 (-685 (-171 (-413 (-572))))) (-5 *4 (-1170)) (-5 *2 (-959 (-171 (-413 (-572))))) (-5 *1 (-762 *5)) (-4 *5 (-13 (-368) (-846))))) (-2707 (*1 *2 *3) (-12 (-5 *3 (-685 (-171 (-413 (-572))))) (-5 *2 (-959 (-171 (-413 (-572))))) (-5 *1 (-762 *4)) (-4 *4 (-13 (-368) (-846)))))) 
-(-10 -7 (-15 -2707 ((-959 (-171 (-413 (-572)))) (-685 (-171 (-413 (-572)))))) (-15 -2707 ((-959 (-171 (-413 (-572)))) (-685 (-171 (-413 (-572)))) (-1170))) (-15 -1722 ((-638 (-171 |#1|)) (-685 (-171 (-413 (-572)))) |#1|)) (-15 -2598 ((-638 (-2 (|:| |outval| (-171 |#1|)) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 (-171 |#1|)))))) (-685 (-171 (-413 (-572)))) |#1|))) 
-((-3915 (((-175 (-572)) |#1|) 25))) 
-(((-763 |#1|) (-10 -7 (-15 -3915 ((-175 (-572)) |#1|))) (-410)) (T -763)) 
-((-3915 (*1 *2 *3) (-12 (-5 *2 (-175 (-572))) (-5 *1 (-763 *3)) (-4 *3 (-410))))) 
-(-10 -7 (-15 -3915 ((-175 (-572)) |#1|))) 
-((-3197 ((|#1| |#1| |#1|) 24)) (-3874 ((|#1| |#1| |#1|) 23)) (-4008 ((|#1| |#1| |#1|) 31)) (-3373 ((|#1| |#1| |#1|) 27)) (-2955 (((-3 |#1| "failed") |#1| |#1|) 26)) (-3230 (((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|) 22))) 
-(((-764 |#1| |#2|) (-10 -7 (-15 -3230 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -3874 (|#1| |#1| |#1|)) (-15 -3197 (|#1| |#1| |#1|)) (-15 -2955 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3373 (|#1| |#1| |#1|)) (-15 -4008 (|#1| |#1| |#1|))) (-704 |#2|) (-368)) (T -764)) 
-((-4008 (*1 *2 *2 *2) (-12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) (-3373 (*1 *2 *2 *2) (-12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) (-2955 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) (-3197 (*1 *2 *2 *2) (-12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) (-3874 (*1 *2 *2 *2) (-12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) (-3230 (*1 *2 *3 *3) (-12 (-4 *4 (-368)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-764 *3 *4)) (-4 *3 (-704 *4))))) 
-(-10 -7 (-15 -3230 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -3874 (|#1| |#1| |#1|)) (-15 -3197 (|#1| |#1| |#1|)) (-15 -2955 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3373 (|#1| |#1| |#1|)) (-15 -4008 (|#1| |#1| |#1|))) 
-((-2996 (((-1166 |#1|) (-638 |#1|)) 25))) 
-(((-765 |#1|) (-10 -7 (-15 -2996 ((-1166 |#1|) (-638 |#1|)))) (-562)) (T -765)) 
-((-2996 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-562)) (-5 *2 (-1166 *4)) (-5 *1 (-765 *4))))) 
-(-10 -7 (-15 -2996 ((-1166 |#1|) (-638 |#1|)))) 
-((-4122 (((-2 (|:| -2237 (-685 (-572))) (|:| |basisDen| (-572)) (|:| |basisInv| (-685 (-572)))) (-572)) 58)) (-1778 (((-2 (|:| -2237 (-685 (-572))) (|:| |basisDen| (-572)) (|:| |basisInv| (-685 (-572))))) 56)) (-2119 (((-572)) 68))) 
-(((-766 |#1| |#2|) (-10 -7 (-15 -2119 ((-572))) (-15 -1778 ((-2 (|:| -2237 (-685 (-572))) (|:| |basisDen| (-572)) (|:| |basisInv| (-685 (-572)))))) (-15 -4122 ((-2 (|:| -2237 (-685 (-572))) (|:| |basisDen| (-572)) (|:| |basisInv| (-685 (-572)))) (-572)))) (-1234 (-572)) (-415 (-572) |#1|)) (T -766)) 
-((-4122 (*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-766 *4 *5)) (-4 *5 (-415 *3 *4)))) (-1778 (*1 *2) (-12 (-4 *3 (-1234 (-572))) (-5 *2 (-2 (|:| -2237 (-685 (-572))) (|:| |basisDen| (-572)) (|:| |basisInv| (-685 (-572))))) (-5 *1 (-766 *3 *4)) (-4 *4 (-415 (-572) *3)))) (-2119 (*1 *2) (-12 (-4 *3 (-1234 *2)) (-5 *2 (-572)) (-5 *1 (-766 *3 *4)) (-4 *4 (-415 *2 *3))))) 
-(-10 -7 (-15 -2119 ((-572))) (-15 -1778 ((-2 (|:| -2237 (-685 (-572))) (|:| |basisDen| (-572)) (|:| |basisInv| (-685 (-572)))))) (-15 -4122 ((-2 (|:| -2237 (-685 (-572))) (|:| |basisDen| (-572)) (|:| |basisInv| (-685 (-572)))) (-572)))) 
-((-2262 (((-121) $ $) NIL)) (-1318 (((-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) $) 15)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 14) (($ (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 8) (($ (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 10) (($ (-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) 12)) (-1324 (((-121) $ $) NIL))) 
-(((-767) (-13 (-1098) (-10 -8 (-15 -3972 ($ (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3972 ($ (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3972 ($ (-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) (-15 -3972 ((-856) $)) (-15 -1318 ((-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) $))))) (T -767)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-767)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *1 (-767)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *1 (-767)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) (-5 *1 (-767)))) (-1318 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) (-5 *1 (-767))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3972 ($ (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3972 ($ (-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) (-15 -3972 ((-856) $)) (-15 -1318 ((-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) $)))) 
-((-4242 (((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|))) 14) (((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|)) (-638 (-1170))) 13)) (-2800 (((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|))) 16) (((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|)) (-638 (-1170))) 15))) 
-(((-768 |#1|) (-10 -7 (-15 -4242 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|)) (-638 (-1170)))) (-15 -4242 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|)))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|)) (-638 (-1170)))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|))))) (-562)) (T -768)) 
-((-2800 (*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *4)))))) (-5 *1 (-768 *4)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *5)))))) (-5 *1 (-768 *5)))) (-4242 (*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *4)))))) (-5 *1 (-768 *4)))) (-4242 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *5)))))) (-5 *1 (-768 *5))))) 
-(-10 -7 (-15 -4242 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|)) (-638 (-1170)))) (-15 -4242 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|)))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|)) (-638 (-1170)))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-959 |#1|))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1614 (($ $ $) 6)) (-1572 (((-3 $ "failed") $ $) 9)) (-3351 (($ $ (-572)) 7)) (-2211 (($) NIL T CONST)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($ $) NIL)) (-2208 (($ $ $) NIL)) (-3893 (((-121) $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3069 (($ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3972 (((-856) $) NIL)) (-4174 (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (* (($ (-769) $) NIL) (($ (-923) $) NIL) (($ $ $) NIL))) 
-(((-769) (-13 (-794) (-722) (-10 -8 (-15 -2208 ($ $ $)) (-15 -2190 ($ $ $)) (-15 -3069 ($ $ $)) (-15 -2541 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -1803 ((-3 $ "failed") $ $)) (-15 -3351 ($ $ (-572))) (-15 -3286 ($ $)) (-6 (-4604 "*"))))) (T -769)) 
-((-2208 (*1 *1 *1 *1) (-5 *1 (-769))) (-2190 (*1 *1 *1 *1) (-5 *1 (-769))) (-3069 (*1 *1 *1 *1) (-5 *1 (-769))) (-2541 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3043 (-769)) (|:| -2492 (-769)))) (-5 *1 (-769)))) (-1803 (*1 *1 *1 *1) (|partial| -5 *1 (-769))) (-3351 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-769)))) (-3286 (*1 *1 *1) (-5 *1 (-769)))) 
-(-13 (-794) (-722) (-10 -8 (-15 -2208 ($ $ $)) (-15 -2190 ($ $ $)) (-15 -3069 ($ $ $)) (-15 -2541 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -1803 ((-3 $ "failed") $ $)) (-15 -3351 ($ $ (-572))) (-15 -3286 ($ $)) (-6 (-4604 "*")))) 
-((-2800 (((-3 |#2| "failed") |#2| |#2| (-123) (-1170)) 35))) 
-(((-770 |#1| |#2|) (-10 -7 (-15 -2800 ((-3 |#2| "failed") |#2| |#2| (-123) (-1170)))) (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151)) (-13 (-29 |#1|) (-1190) (-966))) (T -770)) 
-((-2800 (*1 *2 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-770 *5 *2)) (-4 *2 (-13 (-29 *5) (-1190) (-966)))))) 
-(-10 -7 (-15 -2800 ((-3 |#2| "failed") |#2| |#2| (-123) (-1170)))) 
-((-3972 (((-772) |#1|) 8))) 
-(((-771 |#1|) (-10 -7 (-15 -3972 ((-772) |#1|))) (-1204)) (T -771)) 
-((-3972 (*1 *2 *3) (-12 (-5 *2 (-772)) (-5 *1 (-771 *3)) (-4 *3 (-1204))))) 
-(-10 -7 (-15 -3972 ((-772) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 7)) (-1324 (((-121) $ $) 9))) 
-(((-772) (-1098)) (T -772)) 
-NIL 
-(-1098) 
-((-4429 ((|#2| |#4|) 35))) 
-(((-773 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4429 (|#2| |#4|))) (-457) (-1234 |#1|) (-720 |#1| |#2|) (-1234 |#3|)) (T -773)) 
-((-4429 (*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-720 *4 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-773 *4 *2 *5 *3)) (-4 *3 (-1234 *5))))) 
-(-10 -7 (-15 -4429 (|#2| |#4|))) 
-((-1799 (((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|) 56)) (-2600 (((-1264) (-1152) (-1152) |#4| |#5|) 33)) (-3895 ((|#4| |#4| |#5|) 72)) (-3985 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|) 76)) (-4554 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|) 15))) 
-(((-774 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1799 ((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|)) (-15 -3895 (|#4| |#4| |#5|)) (-15 -3985 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -2600 ((-1264) (-1152) (-1152) |#4| |#5|)) (-15 -4554 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1073 |#1| |#2| |#3| |#4|)) (T -774)) 
-((-4554 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-774 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-2600 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-1152)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *4 (-1068 *6 *7 *8)) (-5 *2 (-1264)) (-5 *1 (-774 *6 *7 *8 *4 *5)) (-4 *5 (-1073 *6 *7 *8 *4)))) (-3985 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-774 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-3895 (*1 *2 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *2 (-1068 *4 *5 *6)) (-5 *1 (-774 *4 *5 *6 *2 *3)) (-4 *3 (-1073 *4 *5 *6 *2)))) (-1799 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *3))) (-5 *1 (-774 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(-10 -7 (-15 -1799 ((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|)) (-15 -3895 (|#4| |#4| |#5|)) (-15 -3985 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -2600 ((-1264) (-1152) (-1152) |#4| |#5|)) (-15 -4554 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|))) 
-((-3376 (((-3 (-1166 (-1166 |#1|)) "failed") |#4|) 43)) (-1399 (((-638 |#4|) |#4|) 15)) (-2611 ((|#4| |#4|) 11))) 
-(((-775 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1399 ((-638 |#4|) |#4|)) (-15 -3376 ((-3 (-1166 (-1166 |#1|)) "failed") |#4|)) (-15 -2611 (|#4| |#4|))) (-353) (-329 |#1|) (-1234 |#2|) (-1234 |#3|) (-923)) (T -775)) 
-((-2611 (*1 *2 *2) (-12 (-4 *3 (-353)) (-4 *4 (-329 *3)) (-4 *5 (-1234 *4)) (-5 *1 (-775 *3 *4 *5 *2 *6)) (-4 *2 (-1234 *5)) (-14 *6 (-923)))) (-3376 (*1 *2 *3) (|partial| -12 (-4 *4 (-353)) (-4 *5 (-329 *4)) (-4 *6 (-1234 *5)) (-5 *2 (-1166 (-1166 *4))) (-5 *1 (-775 *4 *5 *6 *3 *7)) (-4 *3 (-1234 *6)) (-14 *7 (-923)))) (-1399 (*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *5 (-329 *4)) (-4 *6 (-1234 *5)) (-5 *2 (-638 *3)) (-5 *1 (-775 *4 *5 *6 *3 *7)) (-4 *3 (-1234 *6)) (-14 *7 (-923))))) 
-(-10 -7 (-15 -1399 ((-638 |#4|) |#4|)) (-15 -3376 ((-3 (-1166 (-1166 |#1|)) "failed") |#4|)) (-15 -2611 (|#4| |#4|))) 
-((-2262 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-1318 (($ (-1216 |#1|)) 21)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 26)) (-2607 (((-1116) $) NIL)) (-3018 (($ $ $) NIL)) (-4056 (($ $ $) NIL)) (-3972 (((-856) $) 11)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-3255 (($) 18 T CONST)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ $ $) 24))) 
-(((-776 |#1|) (-13 (-482) (-10 -8 (-15 -1318 ($ (-1216 |#1|))))) (-353)) (T -776)) 
-((-1318 (*1 *1 *2) (-12 (-5 *2 (-1216 *3)) (-4 *3 (-353)) (-5 *1 (-776 *3))))) 
-(-13 (-482) (-10 -8 (-15 -1318 ($ (-1216 |#1|))))) 
-((-3529 (((-2 (|:| |deter| (-638 (-1166 |#5|))) (|:| |dterm| (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-638 |#1|)) (|:| |nlead| (-638 |#5|))) (-1166 |#5|) (-638 |#1|) (-638 |#5|)) 51)) (-2483 (((-638 (-769)) |#1|) 12))) 
-(((-777 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3529 ((-2 (|:| |deter| (-638 (-1166 |#5|))) (|:| |dterm| (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-638 |#1|)) (|:| |nlead| (-638 |#5|))) (-1166 |#5|) (-638 |#1|) (-638 |#5|))) (-15 -2483 ((-638 (-769)) |#1|))) (-1234 |#4|) (-794) (-848) (-303) (-956 |#4| |#2| |#3|)) (T -777)) 
-((-2483 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-5 *2 (-638 (-769))) (-5 *1 (-777 *3 *4 *5 *6 *7)) (-4 *3 (-1234 *6)) (-4 *7 (-956 *6 *4 *5)))) (-3529 (*1 *2 *3 *4 *5) (-12 (-4 *6 (-1234 *9)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-303)) (-4 *10 (-956 *9 *7 *8)) (-5 *2 (-2 (|:| |deter| (-638 (-1166 *10))) (|:| |dterm| (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| *10))))) (|:| |nfacts| (-638 *6)) (|:| |nlead| (-638 *10)))) (-5 *1 (-777 *6 *7 *8 *9 *10)) (-5 *3 (-1166 *10)) (-5 *4 (-638 *6)) (-5 *5 (-638 *10))))) 
-(-10 -7 (-15 -3529 ((-2 (|:| |deter| (-638 (-1166 |#5|))) (|:| |dterm| (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-638 |#1|)) (|:| |nlead| (-638 |#5|))) (-1166 |#5|) (-638 |#1|) (-638 |#5|))) (-15 -2483 ((-638 (-769)) |#1|))) 
-((-4059 (((-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal"))) (-638 |#2|)) 18) (((-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|) 16)) (-2912 (((-638 (-638 |#2|)) |#2| (-572) (-572) (-3 "left" "center" "right" "vertical" "horizontal")) 32)) (-4156 (((-638 (-638 |#2|)) |#2| (-638 (-638 |#2|))) 24)) (-1941 (((-769) (-638 (-638 |#2|))) 27))) 
-(((-778 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2912 ((-638 (-638 |#2|)) |#2| (-572) (-572) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -1941 ((-769) (-638 (-638 |#2|)))) (-15 -4156 ((-638 (-638 |#2|)) |#2| (-638 (-638 |#2|)))) (-15 -4059 ((-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|)) (-15 -4059 ((-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal"))) (-638 |#2|)))) (-1054) (-326 |#1| |#3|) (-232 |#4| (-769)) (-769)) (T -778)) 
-((-4059 (*1 *2 *3) (-12 (-5 *3 (-638 *5)) (-4 *5 (-326 *4 *6)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-4 *4 (-1054)) (-5 *2 (-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-778 *4 *5 *6 *7)))) (-4059 (*1 *2 *3 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *2 (-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-778 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) (-4156 (*1 *2 *3 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-326 *4 *5)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-4 *4 (-1054)) (-5 *1 (-778 *4 *3 *5 *6)))) (-1941 (*1 *2 *3) (-12 (-5 *3 (-638 (-638 *5))) (-4 *5 (-326 *4 *6)) (-4 *6 (-232 *7 *2)) (-14 *7 *2) (-4 *4 (-1054)) (-5 *2 (-769)) (-5 *1 (-778 *4 *5 *6 *7)))) (-2912 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-572)) (-5 *5 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *6 (-1054)) (-4 *7 (-232 *8 (-769))) (-14 *8 (-769)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-778 *6 *3 *7 *8)) (-4 *3 (-326 *6 *7))))) 
-(-10 -7 (-15 -2912 ((-638 (-638 |#2|)) |#2| (-572) (-572) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -1941 ((-769) (-638 (-638 |#2|)))) (-15 -4156 ((-638 (-638 |#2|)) |#2| (-638 (-638 |#2|)))) (-15 -4059 ((-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|)) (-15 -4059 ((-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal"))) (-638 |#2|)))) 
-((-3667 (((-638 (-2 (|:| |outval| |#1|) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 |#1|))))) (-685 (-413 (-572))) |#1|) 27)) (-2442 (((-638 |#1|) (-685 (-413 (-572))) |#1|) 19)) (-2707 (((-959 (-413 (-572))) (-685 (-413 (-572))) (-1170)) 16) (((-959 (-413 (-572))) (-685 (-413 (-572)))) 15))) 
-(((-779 |#1|) (-10 -7 (-15 -2707 ((-959 (-413 (-572))) (-685 (-413 (-572))))) (-15 -2707 ((-959 (-413 (-572))) (-685 (-413 (-572))) (-1170))) (-15 -2442 ((-638 |#1|) (-685 (-413 (-572))) |#1|)) (-15 -3667 ((-638 (-2 (|:| |outval| |#1|) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 |#1|))))) (-685 (-413 (-572))) |#1|))) (-13 (-368) (-846))) (T -779)) 
-((-3667 (*1 *2 *3 *4) (-12 (-5 *3 (-685 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| |outval| *4) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 *4)))))) (-5 *1 (-779 *4)) (-4 *4 (-13 (-368) (-846))))) (-2442 (*1 *2 *3 *4) (-12 (-5 *3 (-685 (-413 (-572)))) (-5 *2 (-638 *4)) (-5 *1 (-779 *4)) (-4 *4 (-13 (-368) (-846))))) (-2707 (*1 *2 *3 *4) (-12 (-5 *3 (-685 (-413 (-572)))) (-5 *4 (-1170)) (-5 *2 (-959 (-413 (-572)))) (-5 *1 (-779 *5)) (-4 *5 (-13 (-368) (-846))))) (-2707 (*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-572)))) (-5 *2 (-959 (-413 (-572)))) (-5 *1 (-779 *4)) (-4 *4 (-13 (-368) (-846)))))) 
-(-10 -7 (-15 -2707 ((-959 (-413 (-572))) (-685 (-413 (-572))))) (-15 -2707 ((-959 (-413 (-572))) (-685 (-413 (-572))) (-1170))) (-15 -2442 ((-638 |#1|) (-685 (-413 (-572))) |#1|)) (-15 -3667 ((-638 (-2 (|:| |outval| |#1|) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 |#1|))))) (-685 (-413 (-572))) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 10)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) NIL)) (-2148 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2525 (($ $ (-572) (-572)) NIL) (($ $ (-572)) NIL)) (-4230 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL)) (-2640 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL)) (-4232 (($ $) NIL)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4390 (($ $ (-572)) NIL (|has| $ (-6 -4603)))) (-3112 (((-121) $ $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-3351 (($ $ (-572)) 36)) (-4436 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603)))) (-3749 (($ $ $) NIL (|has| $ (-6 -4603)))) (-2656 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603)))) (-4055 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603)))) (-3283 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603))) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-1225 (-572)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603))) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ "last" (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603))) (($ $ "rest" $) NIL (|has| $ (-6 -4603))) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ "first" (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603))) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ "value" (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-4521 (($ (-572) |#1| $) 41)) (-2561 (($ (-1 (-121) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL)) (-4066 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL)) (-2085 (($ $ $) 51)) (-2211 (($) NIL T CONST)) (-2438 (($ $) 21)) (-1651 (($ $ (-769)) NIL) (($ $) 14)) (-3729 (($ (-572) $) 78) (($ $) 31)) (-3185 (($ $) 35)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098))))) (-3445 (($ (-1 (-121) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL) (($ (-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098))))) (-2190 (($ $ $) NIL)) (-4383 (($ $) NIL)) (-3116 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $ (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098)))) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $ (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4602)))) (-1799 (((-3 $ "failed") $) 38)) (-2208 (($ $ $) NIL)) (-3037 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603)))) (-4212 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572)) NIL)) (-2936 (((-121) (-121)) 30) (((-121)) 29)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-2429 (((-121) $) NIL)) (-3591 (($ $) 22)) (-1347 (((-121) $) NIL)) (-2010 (((-638 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4602)))) (-2306 (((-3 (-572) "failed") $) 16)) (-3377 (((-572) $ (-572)) NIL) (((-572) $) 19) (((-572) $) 19)) (-3893 (((-121) $) NIL)) (-2050 (((-769) $) NIL)) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098)))) (-1364 (($ (-769) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL)) (-3965 (($ $ (-923)) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-4581 (((-121) $) NIL)) (-4195 (($ (-638 $) (-638 (-769)) (-572)) 85)) (-4328 (($ $ (-638 (-1082)) (-638 (-572))) NIL) (($ $ (-1082) (-572)) NIL) (($ |#1| (-572)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-4467 (((-638 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-2435 (($ (-1 (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $ $) NIL) (($ (-1 (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-2699 (((-638 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL)) (-3113 (((-121) $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2556 (($ $) NIL)) (-1493 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-3253 (($ $ (-769)) NIL) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL)) (-4350 (($ $) 39)) (-2603 (($ (-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3179 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) 12)) (-1837 (($ $ (-769)) NIL) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL)) (-3522 (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572)) 24)) (-2906 ((|#1| $ (-572)) 25)) (-3361 (((-3 (-2 (|:| |k| (-572)) (|:| |c| |#1|)) "failed") (-1 (-121) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL)) (-1295 (($ $ (-572)) 89)) (-3299 (($ $ (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1977 (($ $ (-572)) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3540 (((-121) $) NIL)) (-3173 (((-121) $) NIL)) (-4249 (((-121) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4602)))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-572))))) (($ $ (-638 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) (-638 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) NIL (-12 (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-305 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098)))) (($ $ (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (-12 (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-305 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098)))) (($ $ (-290 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) NIL (-12 (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-305 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098)))) (($ $ (-638 (-290 (-2 (|:| |k| (-572)) (|:| |c| |#1|))))) NIL (-12 (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-305 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098))))) (-4029 (((-769) $) NIL)) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098))))) (-2957 (((-638 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL)) (-4037 (((-121) $) 23)) (-1665 (($) 94)) (-3277 (($ $ $) NIL (|has| (-572) (-1110))) ((|#1| $ (-572)) NIL) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572)) NIL) (($ $ (-1225 (-572))) NIL) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ "last") NIL) (($ $ "rest") NIL) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ "first") NIL) (((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ "value") NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3537 (((-572) $ $) NIL)) (-3139 (($ $) NIL (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-4216 (($ (-1 $)) 34)) (-4316 (((-572) $) NIL)) (-1791 (((-121) $) NIL)) (-2619 (($ $) NIL)) (-3316 (($ $) NIL (|has| $ (-6 -4603)))) (-1471 (((-769) $) NIL)) (-3622 (($ $) NIL)) (-1571 (((-769) (-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098)))) (((-769) (-1 (-121) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) 95)) (-2977 (($ $ (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4603))) (($ $ $) NIL (|has| $ (-6 -4603)))) (-4500 (($ $ (-2 (|:| |k| (-572)) (|:| |c| |#1|))) NIL) (($ (-638 $)) NIL) (($ (-2 (|:| |k| (-572)) (|:| |c| |#1|)) $) 32) (($ $ $) NIL)) (-2424 (($ $) NIL)) (-3972 (((-856) $) 65) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) NIL (|has| |#1| (-174))) (($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) 27) (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) 26)) (-1958 ((|#1| $ (-572)) NIL)) (-2224 ((|#1| $) 86)) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| (-2 (|:| |k| (-572)) (|:| |c| |#1|)) (-1098)))) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) NIL)) (-3774 (((-121) $ $) NIL)) (-3410 ((|#1| $ (-572)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-572)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-3501 (((-121) (-1 (-121) (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4602)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 17 T CONST)) (-3255 (($) 74 T CONST)) (-1557 (($ $) NIL (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL) (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) 47) (($ $ $) 43)) (-1367 (($ $ $) 53)) (** (($ $ (-923)) NIL) (($ $ (-769)) 79) (($ $ (-572)) 52)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 42) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ |#1| $) 46) (($ $ |#1|) 100)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-780 |#1|) (-13 (-645 |#1|) (-669 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) (-10 -8 (-15 -3522 ((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572))))) (-368)) (T -780)) 
-((-3522 (*1 *2 *1 *3) (-12 (-5 *2 (-2 (|:| |k| (-572)) (|:| |c| *4))) (-5 *1 (-780 *4)) (-4 *4 (-368)) (-5 *3 (-572))))) 
-(-13 (-645 |#1|) (-669 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) (-10 -8 (-15 -3522 ((-2 (|:| |k| (-572)) (|:| |c| |#1|)) $ (-572))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 34)) (-3456 (((-638 |#2|) $) NIL)) (-4297 (((-1166 $) $ |#2|) NIL) (((-1166 |#1|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 |#2|)) NIL)) (-4232 (($ $) 28)) (-4437 (((-121) $ $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2824 (($ $ $) 92 (|has| |#1| (-562)))) (-1323 (((-638 $) $ $) 105 (|has| |#1| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 |#2| "failed") $) NIL) (((-3 $ "failed") (-959 (-413 (-572)))) NIL (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#2| (-613 (-1170))))) (((-3 $ "failed") (-959 (-572))) NIL (-1841 (-12 (|has| |#1| (-43 (-572))) (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-43 (-413 (-572)))))) (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#2| (-613 (-1170)))))) (((-3 $ "failed") (-959 |#1|)) NIL (-1841 (-12 (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-43 (-413 (-572))))) (-2959 (|has| |#1| (-43 (-572))))) (-12 (|has| |#1| (-43 (-572))) (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-43 (-413 (-572))))) (-2959 (|has| |#1| (-554)))) (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-1000 (-572))))))) (((-3 (-1121 |#1| |#2|) "failed") $) 18)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) ((|#2| $) NIL) (($ (-959 (-413 (-572)))) NIL (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#2| (-613 (-1170))))) (($ (-959 (-572))) NIL (-1841 (-12 (|has| |#1| (-43 (-572))) (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-43 (-413 (-572)))))) (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#2| (-613 (-1170)))))) (($ (-959 |#1|)) NIL (-1841 (-12 (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-43 (-413 (-572))))) (-2959 (|has| |#1| (-43 (-572))))) (-12 (|has| |#1| (-43 (-572))) (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-43 (-413 (-572))))) (-2959 (|has| |#1| (-554)))) (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-1000 (-572))))))) (((-1121 |#1| |#2|) $) NIL)) (-3190 (($ $ $ |#2|) NIL (|has| |#1| (-174))) (($ $ $) 103 (|has| |#1| (-562)))) (-4383 (($ $) NIL) (($ $ |#2|) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-2240 (((-121) $ $) NIL) (((-121) $ (-638 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-1439 (((-121) $) NIL)) (-1449 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 69)) (-3181 (($ $) 118 (|has| |#1| (-457)))) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ |#2|) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-4188 (($ $) NIL (|has| |#1| (-562)))) (-3119 (($ $) NIL (|has| |#1| (-562)))) (-1633 (($ $ $) 64) (($ $ $ |#2|) NIL)) (-1851 (($ $ $) 67) (($ $ $ |#2|) NIL)) (-3977 (($ $ |#1| (-538 |#2|) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| |#1| (-887 (-385))) (|has| |#2| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| |#1| (-887 (-572))) (|has| |#2| (-887 (-572)))))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3824 (((-121) $ $) NIL) (((-121) $ (-638 $)) NIL)) (-2633 (($ $ $ $ $) 89 (|has| |#1| (-562)))) (-1792 ((|#2| $) 19)) (-4335 (($ (-1166 |#1|) |#2|) NIL) (($ (-1166 $) |#2|) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-538 |#2|)) NIL) (($ $ |#2| (-769)) 36) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-3853 (($ $ $) 60)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ |#2|) NIL)) (-3897 (((-121) $) NIL)) (-1784 (((-538 |#2|) $) NIL) (((-769) $ |#2|) NIL) (((-638 (-769)) $ (-638 |#2|)) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-3924 (((-769) $) 20)) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-538 |#2|) (-538 |#2|)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-1470 (((-3 |#2| "failed") $) NIL)) (-3246 (($ $) NIL (|has| |#1| (-457)))) (-3031 (($ $) NIL (|has| |#1| (-457)))) (-3737 (((-638 $) $) NIL)) (-4312 (($ $) 37)) (-2944 (($ $) NIL (|has| |#1| (-457)))) (-1936 (((-638 $) $) 41)) (-4194 (($ $) 39)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL) (($ $ |#2|) 45)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-2767 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -1951 (-769))) $ $) 81)) (-2241 (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $) 66) (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $ |#2|) NIL)) (-3827 (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -2492 $)) $ $) NIL) (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -2492 $)) $ $ |#2|) NIL)) (-1901 (($ $ $) 71) (($ $ $ |#2|) NIL)) (-3720 (($ $ $) 74) (($ $ $ |#2|) NIL)) (-1658 (((-1152) $) NIL)) (-4416 (($ $ $) 107 (|has| |#1| (-562)))) (-4176 (((-638 $) $) 30)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| |#2|) (|:| -3751 (-769))) "failed") $) NIL)) (-1483 (((-121) $ $) NIL) (((-121) $ (-638 $)) NIL)) (-2788 (($ $ $) NIL)) (-1773 (($ $) 21)) (-1843 (((-121) $ $) NIL)) (-1994 (((-121) $ $) NIL) (((-121) $ (-638 $)) NIL)) (-4498 (($ $ $) NIL)) (-2826 (($ $) 23)) (-2607 (((-1116) $) NIL)) (-4483 (((-2 (|:| -3069 $) (|:| |coef2| $)) $ $) 98 (|has| |#1| (-562)))) (-1833 (((-2 (|:| -3069 $) (|:| |coef1| $)) $ $) 95 (|has| |#1| (-562)))) (-4357 (((-121) $) 52)) (-4362 ((|#1| $) 55)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 ((|#1| |#1| $) 115 (|has| |#1| (-457))) (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-3666 (((-2 (|:| -3069 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 101 (|has| |#1| (-562)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) 83 (|has| |#1| (-562)))) (-3916 (($ $ |#1|) 111 (|has| |#1| (-562))) (($ $ $) NIL (|has| |#1| (-562)))) (-1467 (($ $ |#1|) 110 (|has| |#1| (-562))) (($ $ $) NIL (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ |#2| |#1|) NIL) (($ $ (-638 |#2|) (-638 |#1|)) NIL) (($ $ |#2| $) NIL) (($ $ (-638 |#2|) (-638 $)) NIL)) (-2119 (($ $ |#2|) NIL (|has| |#1| (-174)))) (-3139 (($ $ |#2|) NIL) (($ $ (-638 |#2|)) NIL) (($ $ |#2| (-769)) NIL) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-4316 (((-538 |#2|) $) NIL) (((-769) $ |#2|) 43) (((-638 (-769)) $ (-638 |#2|)) NIL)) (-4426 (($ $) NIL)) (-3065 (($ $) 33)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| |#1| (-613 (-545))) (|has| |#2| (-613 (-545))))) (($ (-959 (-413 (-572)))) NIL (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#2| (-613 (-1170))))) (($ (-959 (-572))) NIL (-1841 (-12 (|has| |#1| (-43 (-572))) (|has| |#2| (-613 (-1170))) (-2959 (|has| |#1| (-43 (-413 (-572)))))) (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#2| (-613 (-1170)))))) (($ (-959 |#1|)) NIL (|has| |#2| (-613 (-1170)))) (((-1152) $) NIL (-12 (|has| |#1| (-1044 (-572))) (|has| |#2| (-613 (-1170))))) (((-959 |#1|) $) NIL (|has| |#2| (-613 (-1170))))) (-3694 ((|#1| $) 114 (|has| |#1| (-457))) (($ $ |#2|) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ |#2|) NIL) (((-959 |#1|) $) NIL (|has| |#2| (-613 (-1170)))) (((-1121 |#1| |#2|) $) 15) (($ (-1121 |#1| |#2|)) 16) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-538 |#2|)) NIL) (($ $ |#2| (-769)) 44) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 13 T CONST)) (-1926 (((-3 (-121) "failed") $ $) NIL)) (-3255 (($) 35 T CONST)) (-2407 (($ $ $ $ (-769)) 87 (|has| |#1| (-562)))) (-1923 (($ $ $ (-769)) 86 (|has| |#1| (-562)))) (-1557 (($ $ |#2|) NIL) (($ $ (-638 |#2|)) NIL) (($ $ |#2| (-769)) NIL) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) 54)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) 63)) (-1367 (($ $ $) 73)) (** (($ $ (-923)) NIL) (($ $ (-769)) 61)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 59) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 58) (($ $ |#1|) NIL))) 
-(((-781 |#1| |#2|) (-13 (-1068 |#1| (-538 |#2|) |#2|) (-612 (-1121 |#1| |#2|)) (-1044 (-1121 |#1| |#2|))) (-1054) (-848)) (T -781)) 
-NIL 
-(-13 (-1068 |#1| (-538 |#2|) |#2|) (-612 (-1121 |#1| |#2|)) (-1044 (-1121 |#1| |#2|))) 
-((-3828 (((-783 |#2|) (-1 |#2| |#1|) (-783 |#1|)) 13))) 
-(((-782 |#1| |#2|) (-10 -7 (-15 -3828 ((-783 |#2|) (-1 |#2| |#1|) (-783 |#1|)))) (-1054) (-1054)) (T -782)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-783 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-783 *6)) (-5 *1 (-782 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-783 |#2|) (-1 |#2| |#1|) (-783 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 12)) (-3275 (((-1259 |#1|) $ (-769)) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-2383 (($ (-1166 |#1|)) NIL)) (-4297 (((-1166 $) $ (-1082)) NIL) (((-1166 |#1|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1082))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4259 (((-638 $) $ $) 39 (|has| |#1| (-562)))) (-2824 (($ $ $) 35 (|has| |#1| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-2786 (($ $ (-769)) NIL)) (-3944 (($ $ (-769)) NIL)) (-2012 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-457)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-1082) "failed") $) NIL) (((-3 (-1166 |#1|) "failed") $) 10)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-1082) $) NIL) (((-1166 |#1|) $) NIL)) (-3190 (($ $ $ (-1082)) NIL (|has| |#1| (-174))) ((|#1| $ $) 43 (|has| |#1| (-174)))) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3890 (($ $ $) NIL)) (-3039 (($ $ $) 71 (|has| |#1| (-562)))) (-1449 (((-2 (|:| -4513 |#1|) (|:| -3043 $) (|:| -2492 $)) $ $) 70 (|has| |#1| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ (-1082)) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-769) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1082) (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1082) (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3377 (((-769) $ $) NIL (|has| |#1| (-562)))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-1144)))) (-4335 (($ (-1166 |#1|) (-1082)) NIL) (($ (-1166 $) (-1082)) NIL)) (-3965 (($ $ (-769)) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3853 (($ $ $) 20)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1082)) NIL) (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-1784 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-769) (-769)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-4155 (((-1166 |#1|) $) NIL)) (-1470 (((-3 (-1082) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-2767 (((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -1951 (-769))) $ $) 26)) (-3257 (($ $ $) 29)) (-3210 (($ $ $) 32)) (-2241 (((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $) 31)) (-1658 (((-1152) $) NIL)) (-4416 (($ $ $) 41 (|has| |#1| (-562)))) (-2845 (((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769)) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-1082)) (|:| -3751 (-769))) "failed") $) NIL)) (-2774 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1773 (($) NIL (|has| |#1| (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-4483 (((-2 (|:| -3069 $) (|:| |coef2| $)) $ $) 67 (|has| |#1| (-562)))) (-1833 (((-2 (|:| -3069 $) (|:| |coef1| $)) $ $) 63 (|has| |#1| (-562)))) (-3848 (((-2 (|:| -3190 |#1|) (|:| |coef2| $)) $ $) 55 (|has| |#1| (-562)))) (-4113 (((-2 (|:| -3190 |#1|) (|:| |coef1| $)) $ $) 51 (|has| |#1| (-562)))) (-4357 (((-121) $) 13)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-3311 (($ $ (-769) |#1| $) 19)) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-3666 (((-2 (|:| -3069 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 59 (|has| |#1| (-562)))) (-3028 (((-2 (|:| -3190 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $) 47 (|has| |#1| (-562)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1082) |#1|) NIL) (($ $ (-638 (-1082)) (-638 |#1|)) NIL) (($ $ (-1082) $) NIL) (($ $ (-638 (-1082)) (-638 $)) NIL)) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-413 $) (-413 $) (-413 $)) NIL (|has| |#1| (-562))) ((|#1| (-413 $) |#1|) NIL (|has| |#1| (-368))) (((-413 $) $ (-413 $)) NIL (|has| |#1| (-562)))) (-1997 (((-3 $ "failed") $ (-769)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-2119 (($ $ (-1082)) NIL (|has| |#1| (-174))) ((|#1| $) NIL (|has| |#1| (-174)))) (-3139 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-4316 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-1082) (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) NIL (|has| |#1| (-457))) (($ $ (-1082)) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-2268 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562))) (((-3 (-413 $) "failed") (-413 $) $) NIL (|has| |#1| (-562)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-1082)) NIL) (((-1166 |#1|) $) 7) (($ (-1166 |#1|)) 8) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 21 T CONST)) (-3255 (($) 24 T CONST)) (-1557 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) 28) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 23) (($ $ |#1|) NIL))) 
-(((-783 |#1|) (-13 (-1234 |#1|) (-612 (-1166 |#1|)) (-1044 (-1166 |#1|)) (-10 -8 (-15 -3311 ($ $ (-769) |#1| $)) (-15 -3853 ($ $ $)) (-15 -2767 ((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -1951 (-769))) $ $)) (-15 -3257 ($ $ $)) (-15 -2241 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -3210 ($ $ $)) (IF (|has| |#1| (-562)) (PROGN (-15 -4259 ((-638 $) $ $)) (-15 -4416 ($ $ $)) (-15 -3666 ((-2 (|:| -3069 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1833 ((-2 (|:| -3069 $) (|:| |coef1| $)) $ $)) (-15 -4483 ((-2 (|:| -3069 $) (|:| |coef2| $)) $ $)) (-15 -3028 ((-2 (|:| -3190 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -4113 ((-2 (|:| -3190 |#1|) (|:| |coef1| $)) $ $)) (-15 -3848 ((-2 (|:| -3190 |#1|) (|:| |coef2| $)) $ $))) |noBranch|))) (-1054)) (T -783)) 
-((-3311 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-769)) (-5 *1 (-783 *3)) (-4 *3 (-1054)))) (-3853 (*1 *1 *1 *1) (-12 (-5 *1 (-783 *2)) (-4 *2 (-1054)))) (-2767 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |polnum| (-783 *3)) (|:| |polden| *3) (|:| -1951 (-769)))) (-5 *1 (-783 *3)) (-4 *3 (-1054)))) (-3257 (*1 *1 *1 *1) (-12 (-5 *1 (-783 *2)) (-4 *2 (-1054)))) (-2241 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4513 *3) (|:| |gap| (-769)) (|:| -3043 (-783 *3)) (|:| -2492 (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-1054)))) (-3210 (*1 *1 *1 *1) (-12 (-5 *1 (-783 *2)) (-4 *2 (-1054)))) (-4259 (*1 *2 *1 *1) (-12 (-5 *2 (-638 (-783 *3))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) (-4416 (*1 *1 *1 *1) (-12 (-5 *1 (-783 *2)) (-4 *2 (-562)) (-4 *2 (-1054)))) (-3666 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3069 (-783 *3)) (|:| |coef1| (-783 *3)) (|:| |coef2| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) (-1833 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3069 (-783 *3)) (|:| |coef1| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) (-4483 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3069 (-783 *3)) (|:| |coef2| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) (-3028 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3190 *3) (|:| |coef1| (-783 *3)) (|:| |coef2| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) (-4113 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3190 *3) (|:| |coef1| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) (-3848 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3190 *3) (|:| |coef2| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054))))) 
-(-13 (-1234 |#1|) (-612 (-1166 |#1|)) (-1044 (-1166 |#1|)) (-10 -8 (-15 -3311 ($ $ (-769) |#1| $)) (-15 -3853 ($ $ $)) (-15 -2767 ((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -1951 (-769))) $ $)) (-15 -3257 ($ $ $)) (-15 -2241 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -3210 ($ $ $)) (IF (|has| |#1| (-562)) (PROGN (-15 -4259 ((-638 $) $ $)) (-15 -4416 ($ $ $)) (-15 -3666 ((-2 (|:| -3069 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1833 ((-2 (|:| -3069 $) (|:| |coef1| $)) $ $)) (-15 -4483 ((-2 (|:| -3069 $) (|:| |coef2| $)) $ $)) (-15 -3028 ((-2 (|:| -3190 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -4113 ((-2 (|:| -3190 |#1|) (|:| |coef1| $)) $ $)) (-15 -3848 ((-2 (|:| -3190 |#1|) (|:| |coef2| $)) $ $))) |noBranch|))) 
-((-1558 ((|#1| (-769) |#1|) 32 (|has| |#1| (-43 (-413 (-572)))))) (-2654 ((|#1| (-769) |#1|) 22)) (-1902 ((|#1| (-769) |#1|) 34 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-784 |#1|) (-10 -7 (-15 -2654 (|#1| (-769) |#1|)) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -1902 (|#1| (-769) |#1|)) (-15 -1558 (|#1| (-769) |#1|))) |noBranch|)) (-174)) (T -784)) 
-((-1558 (*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-784 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-174)))) (-1902 (*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-784 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-174)))) (-2654 (*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-784 *2)) (-4 *2 (-174))))) 
-(-10 -7 (-15 -2654 (|#1| (-769) |#1|)) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -1902 (|#1| (-769) |#1|)) (-15 -1558 (|#1| (-769) |#1|))) |noBranch|)) 
-((-2262 (((-121) $ $) 7)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) 78)) (-4165 (((-638 $) (-638 |#4|)) 79) (((-638 $) (-638 |#4|) (-121)) 104)) (-3456 (((-638 |#3|) $) 32)) (-3049 (((-121) $) 25)) (-3289 (((-121) $) 16 (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) 94) (((-121) $) 90)) (-1872 ((|#4| |#4| $) 85)) (-2844 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| $) 119)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) 26)) (-1946 (((-121) $ (-769)) 43)) (-2561 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) 72)) (-2211 (($) 44 T CONST)) (-3097 (((-121) $) 21 (|has| |#1| (-562)))) (-3760 (((-121) $ $) 23 (|has| |#1| (-562)))) (-3819 (((-121) $ $) 22 (|has| |#1| (-562)))) (-4331 (((-121) $) 24 (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3683 (((-638 |#4|) (-638 |#4|) $) 17 (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) 18 (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) 35)) (-1318 (($ (-638 |#4|)) 34)) (-1651 (((-3 $ "failed") $) 75)) (-2242 ((|#4| |#4| $) 82)) (-1643 (($ $) 67 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#4| $) 66 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-1673 ((|#4| |#4| $) 80)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) 98)) (-1706 (((-121) |#4| $) 129)) (-2989 (((-121) |#4| $) 126)) (-1366 (((-121) |#4| $) 130) (((-121) $) 127)) (-2010 (((-638 |#4|) $) 51 (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) 97) (((-121) $) 96)) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) 42)) (-4467 (((-638 |#4|) $) 52 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 46)) (-4062 (((-638 |#3|) $) 31)) (-1346 (((-121) |#3| $) 30)) (-3524 (((-121) $ (-769)) 41)) (-1658 (((-1152) $) 9)) (-2550 (((-3 |#4| (-638 $)) |#4| |#4| $) 121)) (-4416 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| |#4| $) 120)) (-3253 (((-3 |#4| "failed") $) 76)) (-2173 (((-638 $) |#4| $) 122)) (-2471 (((-3 (-121) (-638 $)) |#4| $) 125)) (-2338 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-1931 (((-638 $) |#4| $) 118) (((-638 $) (-638 |#4|) $) 117) (((-638 $) (-638 |#4|) (-638 $)) 116) (((-638 $) |#4| (-638 $)) 115)) (-3078 (($ |#4| $) 110) (($ (-638 |#4|) $) 109)) (-3727 (((-638 |#4|) $) 100)) (-1483 (((-121) |#4| $) 92) (((-121) $) 88)) (-2788 ((|#4| |#4| $) 83)) (-1843 (((-121) $ $) 103)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) 93) (((-121) $) 89)) (-4498 ((|#4| |#4| $) 84)) (-2607 (((-1116) $) 10)) (-1837 (((-3 |#4| "failed") $) 77)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1928 (((-3 $ "failed") $ |#4|) 71)) (-1977 (($ $ |#4|) 70) (((-638 $) |#4| $) 108) (((-638 $) |#4| (-638 $)) 107) (((-638 $) (-638 |#4|) $) 106) (((-638 $) (-638 |#4|) (-638 $)) 105)) (-2109 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) 58 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) 56 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) 55 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) 37)) (-4037 (((-121) $) 40)) (-1665 (($) 39)) (-4316 (((-769) $) 99)) (-1571 (((-769) |#4| $) 53 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4602)))) (-1607 (($ $) 38)) (-4081 (((-545) $) 68 (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 59)) (-1826 (($ $ |#3|) 27)) (-2291 (($ $ |#3|) 29)) (-3134 (($ $) 81)) (-1650 (($ $ |#3|) 28)) (-3972 (((-856) $) 11) (((-638 |#4|) $) 36)) (-2498 (((-769) $) 69 (|has| |#3| (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) 91)) (-2589 (((-638 $) |#4| $) 114) (((-638 $) |#4| (-638 $)) 113) (((-638 $) (-638 |#4|) $) 112) (((-638 $) (-638 |#4|) (-638 $)) 111)) (-3501 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) 74)) (-4191 (((-121) |#4| $) 128)) (-2213 (((-121) |#3| $) 73)) (-1324 (((-121) $ $) 6)) (-4032 (((-769) $) 45 (|has| $ (-6 -4602))))) 
-(((-785 |#1| |#2| |#3| |#4|) (-1290) (-457) (-794) (-848) (-1068 |t#1| |t#2| |t#3|)) (T -785)) 
-NIL 
-(-13 (-1073 |t#1| |t#2| |t#3| |t#4|)) 
-(((-39) . T) ((-105) . T) ((-612 (-638 |#4|)) . T) ((-612 (-856)) . T) ((-155 |#4|) . T) ((-613 (-545)) |has| |#4| (-613 (-545))) ((-305 |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-503 |#4|) . T) ((-527 |#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-984 |#1| |#2| |#3| |#4|) . T) ((-1073 |#1| |#2| |#3| |#4|) . T) ((-1098) . T) ((-1198 |#1| |#2| |#3| |#4|) . T) ((-1204) . T)) 
-((-2017 (((-3 (-385) "failed") (-312 |#1|) (-923)) 60 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-3 (-385) "failed") (-312 |#1|)) 52 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-3 (-385) "failed") (-413 (-959 |#1|)) (-923)) 39 (|has| |#1| (-562))) (((-3 (-385) "failed") (-413 (-959 |#1|))) 35 (|has| |#1| (-562))) (((-3 (-385) "failed") (-959 |#1|) (-923)) 30 (|has| |#1| (-1054))) (((-3 (-385) "failed") (-959 |#1|)) 24 (|has| |#1| (-1054)))) (-1742 (((-385) (-312 |#1|) (-923)) 92 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-385) (-312 |#1|)) 87 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-385) (-413 (-959 |#1|)) (-923)) 84 (|has| |#1| (-562))) (((-385) (-413 (-959 |#1|))) 81 (|has| |#1| (-562))) (((-385) (-959 |#1|) (-923)) 80 (|has| |#1| (-1054))) (((-385) (-959 |#1|)) 77 (|has| |#1| (-1054))) (((-385) |#1| (-923)) 73) (((-385) |#1|) 22)) (-2649 (((-3 (-171 (-385)) "failed") (-312 (-171 |#1|)) (-923)) 68 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-3 (-171 (-385)) "failed") (-312 (-171 |#1|))) 58 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-3 (-171 (-385)) "failed") (-312 |#1|) (-923)) 61 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-3 (-171 (-385)) "failed") (-312 |#1|)) 59 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-3 (-171 (-385)) "failed") (-413 (-959 (-171 |#1|))) (-923)) 44 (|has| |#1| (-562))) (((-3 (-171 (-385)) "failed") (-413 (-959 (-171 |#1|)))) 43 (|has| |#1| (-562))) (((-3 (-171 (-385)) "failed") (-413 (-959 |#1|)) (-923)) 38 (|has| |#1| (-562))) (((-3 (-171 (-385)) "failed") (-413 (-959 |#1|))) 37 (|has| |#1| (-562))) (((-3 (-171 (-385)) "failed") (-959 |#1|) (-923)) 28 (|has| |#1| (-1054))) (((-3 (-171 (-385)) "failed") (-959 |#1|)) 26 (|has| |#1| (-1054))) (((-3 (-171 (-385)) "failed") (-959 (-171 |#1|)) (-923)) 17 (|has| |#1| (-174))) (((-3 (-171 (-385)) "failed") (-959 (-171 |#1|))) 14 (|has| |#1| (-174)))) (-4285 (((-171 (-385)) (-312 (-171 |#1|)) (-923)) 95 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-171 (-385)) (-312 (-171 |#1|))) 94 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-171 (-385)) (-312 |#1|) (-923)) 93 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-171 (-385)) (-312 |#1|)) 91 (-12 (|has| |#1| (-562)) (|has| |#1| (-848)))) (((-171 (-385)) (-413 (-959 (-171 |#1|))) (-923)) 86 (|has| |#1| (-562))) (((-171 (-385)) (-413 (-959 (-171 |#1|)))) 85 (|has| |#1| (-562))) (((-171 (-385)) (-413 (-959 |#1|)) (-923)) 83 (|has| |#1| (-562))) (((-171 (-385)) (-413 (-959 |#1|))) 82 (|has| |#1| (-562))) (((-171 (-385)) (-959 |#1|) (-923)) 79 (|has| |#1| (-1054))) (((-171 (-385)) (-959 |#1|)) 78 (|has| |#1| (-1054))) (((-171 (-385)) (-959 (-171 |#1|)) (-923)) 75 (|has| |#1| (-174))) (((-171 (-385)) (-959 (-171 |#1|))) 74 (|has| |#1| (-174))) (((-171 (-385)) (-171 |#1|) (-923)) 16 (|has| |#1| (-174))) (((-171 (-385)) (-171 |#1|)) 12 (|has| |#1| (-174))) (((-171 (-385)) |#1| (-923)) 27) (((-171 (-385)) |#1|) 25))) 
-(((-786 |#1|) (-10 -7 (-15 -1742 ((-385) |#1|)) (-15 -1742 ((-385) |#1| (-923))) (-15 -4285 ((-171 (-385)) |#1|)) (-15 -4285 ((-171 (-385)) |#1| (-923))) (IF (|has| |#1| (-174)) (PROGN (-15 -4285 ((-171 (-385)) (-171 |#1|))) (-15 -4285 ((-171 (-385)) (-171 |#1|) (-923))) (-15 -4285 ((-171 (-385)) (-959 (-171 |#1|)))) (-15 -4285 ((-171 (-385)) (-959 (-171 |#1|)) (-923)))) |noBranch|) (IF (|has| |#1| (-1054)) (PROGN (-15 -1742 ((-385) (-959 |#1|))) (-15 -1742 ((-385) (-959 |#1|) (-923))) (-15 -4285 ((-171 (-385)) (-959 |#1|))) (-15 -4285 ((-171 (-385)) (-959 |#1|) (-923)))) |noBranch|) (IF (|has| |#1| (-562)) (PROGN (-15 -1742 ((-385) (-413 (-959 |#1|)))) (-15 -1742 ((-385) (-413 (-959 |#1|)) (-923))) (-15 -4285 ((-171 (-385)) (-413 (-959 |#1|)))) (-15 -4285 ((-171 (-385)) (-413 (-959 |#1|)) (-923))) (-15 -4285 ((-171 (-385)) (-413 (-959 (-171 |#1|))))) (-15 -4285 ((-171 (-385)) (-413 (-959 (-171 |#1|))) (-923))) (IF (|has| |#1| (-848)) (PROGN (-15 -1742 ((-385) (-312 |#1|))) (-15 -1742 ((-385) (-312 |#1|) (-923))) (-15 -4285 ((-171 (-385)) (-312 |#1|))) (-15 -4285 ((-171 (-385)) (-312 |#1|) (-923))) (-15 -4285 ((-171 (-385)) (-312 (-171 |#1|)))) (-15 -4285 ((-171 (-385)) (-312 (-171 |#1|)) (-923)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-174)) (PROGN (-15 -2649 ((-3 (-171 (-385)) "failed") (-959 (-171 |#1|)))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-959 (-171 |#1|)) (-923)))) |noBranch|) (IF (|has| |#1| (-1054)) (PROGN (-15 -2017 ((-3 (-385) "failed") (-959 |#1|))) (-15 -2017 ((-3 (-385) "failed") (-959 |#1|) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-959 |#1|))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-959 |#1|) (-923)))) |noBranch|) (IF (|has| |#1| (-562)) (PROGN (-15 -2017 ((-3 (-385) "failed") (-413 (-959 |#1|)))) (-15 -2017 ((-3 (-385) "failed") (-413 (-959 |#1|)) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-413 (-959 |#1|)))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-413 (-959 |#1|)) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-413 (-959 (-171 |#1|))))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-413 (-959 (-171 |#1|))) (-923))) (IF (|has| |#1| (-848)) (PROGN (-15 -2017 ((-3 (-385) "failed") (-312 |#1|))) (-15 -2017 ((-3 (-385) "failed") (-312 |#1|) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-312 |#1|))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-312 |#1|) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-312 (-171 |#1|)))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-312 (-171 |#1|)) (-923)))) |noBranch|)) |noBranch|)) (-613 (-385))) (T -786)) 
-((-2649 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-312 (-171 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-2649 (*1 *2 *3) (|partial| -12 (-5 *3 (-312 (-171 *4))) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-2649 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-312 *5)) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-2649 (*1 *2 *3) (|partial| -12 (-5 *3 (-312 *4)) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-2017 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-312 *5)) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) (-2017 (*1 *2 *3) (|partial| -12 (-5 *3 (-312 *4)) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) (-2649 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-959 (-171 *5)))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-2649 (*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 (-171 *4)))) (-4 *4 (-562)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-2649 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-2649 (*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-2017 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) (-2017 (*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) (-2649 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-959 *5)) (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-2649 (*1 *2 *3) (|partial| -12 (-5 *3 (-959 *4)) (-4 *4 (-1054)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-2017 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-959 *5)) (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) (-2017 (*1 *2 *3) (|partial| -12 (-5 *3 (-959 *4)) (-4 *4 (-1054)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) (-2649 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-959 (-171 *5))) (-5 *4 (-923)) (-4 *5 (-174)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-2649 (*1 *2 *3) (|partial| -12 (-5 *3 (-959 (-171 *4))) (-4 *4 (-174)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-4285 (*1 *2 *3 *4) (-12 (-5 *3 (-312 (-171 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-4285 (*1 *2 *3) (-12 (-5 *3 (-312 (-171 *4))) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-4285 (*1 *2 *3 *4) (-12 (-5 *3 (-312 *5)) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-4285 (*1 *2 *3) (-12 (-5 *3 (-312 *4)) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-1742 (*1 *2 *3 *4) (-12 (-5 *3 (-312 *5)) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) (-1742 (*1 *2 *3) (-12 (-5 *3 (-312 *4)) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) (-4285 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-171 *5)))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-4285 (*1 *2 *3) (-12 (-5 *3 (-413 (-959 (-171 *4)))) (-4 *4 (-562)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-4285 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-4285 (*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-1742 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) (-1742 (*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) (-4285 (*1 *2 *3 *4) (-12 (-5 *3 (-959 *5)) (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-4285 (*1 *2 *3) (-12 (-5 *3 (-959 *4)) (-4 *4 (-1054)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-1742 (*1 *2 *3 *4) (-12 (-5 *3 (-959 *5)) (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) (-1742 (*1 *2 *3) (-12 (-5 *3 (-959 *4)) (-4 *4 (-1054)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) (-4285 (*1 *2 *3 *4) (-12 (-5 *3 (-959 (-171 *5))) (-5 *4 (-923)) (-4 *5 (-174)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-4285 (*1 *2 *3) (-12 (-5 *3 (-959 (-171 *4))) (-4 *4 (-174)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-4285 (*1 *2 *3 *4) (-12 (-5 *3 (-171 *5)) (-5 *4 (-923)) (-4 *5 (-174)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) (-4285 (*1 *2 *3) (-12 (-5 *3 (-171 *4)) (-4 *4 (-174)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) (-4285 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-5 *2 (-171 (-385))) (-5 *1 (-786 *3)) (-4 *3 (-613 (-385))))) (-4285 (*1 *2 *3) (-12 (-5 *2 (-171 (-385))) (-5 *1 (-786 *3)) (-4 *3 (-613 (-385))))) (-1742 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-5 *2 (-385)) (-5 *1 (-786 *3)) (-4 *3 (-613 *2)))) (-1742 (*1 *2 *3) (-12 (-5 *2 (-385)) (-5 *1 (-786 *3)) (-4 *3 (-613 *2))))) 
-(-10 -7 (-15 -1742 ((-385) |#1|)) (-15 -1742 ((-385) |#1| (-923))) (-15 -4285 ((-171 (-385)) |#1|)) (-15 -4285 ((-171 (-385)) |#1| (-923))) (IF (|has| |#1| (-174)) (PROGN (-15 -4285 ((-171 (-385)) (-171 |#1|))) (-15 -4285 ((-171 (-385)) (-171 |#1|) (-923))) (-15 -4285 ((-171 (-385)) (-959 (-171 |#1|)))) (-15 -4285 ((-171 (-385)) (-959 (-171 |#1|)) (-923)))) |noBranch|) (IF (|has| |#1| (-1054)) (PROGN (-15 -1742 ((-385) (-959 |#1|))) (-15 -1742 ((-385) (-959 |#1|) (-923))) (-15 -4285 ((-171 (-385)) (-959 |#1|))) (-15 -4285 ((-171 (-385)) (-959 |#1|) (-923)))) |noBranch|) (IF (|has| |#1| (-562)) (PROGN (-15 -1742 ((-385) (-413 (-959 |#1|)))) (-15 -1742 ((-385) (-413 (-959 |#1|)) (-923))) (-15 -4285 ((-171 (-385)) (-413 (-959 |#1|)))) (-15 -4285 ((-171 (-385)) (-413 (-959 |#1|)) (-923))) (-15 -4285 ((-171 (-385)) (-413 (-959 (-171 |#1|))))) (-15 -4285 ((-171 (-385)) (-413 (-959 (-171 |#1|))) (-923))) (IF (|has| |#1| (-848)) (PROGN (-15 -1742 ((-385) (-312 |#1|))) (-15 -1742 ((-385) (-312 |#1|) (-923))) (-15 -4285 ((-171 (-385)) (-312 |#1|))) (-15 -4285 ((-171 (-385)) (-312 |#1|) (-923))) (-15 -4285 ((-171 (-385)) (-312 (-171 |#1|)))) (-15 -4285 ((-171 (-385)) (-312 (-171 |#1|)) (-923)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-174)) (PROGN (-15 -2649 ((-3 (-171 (-385)) "failed") (-959 (-171 |#1|)))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-959 (-171 |#1|)) (-923)))) |noBranch|) (IF (|has| |#1| (-1054)) (PROGN (-15 -2017 ((-3 (-385) "failed") (-959 |#1|))) (-15 -2017 ((-3 (-385) "failed") (-959 |#1|) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-959 |#1|))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-959 |#1|) (-923)))) |noBranch|) (IF (|has| |#1| (-562)) (PROGN (-15 -2017 ((-3 (-385) "failed") (-413 (-959 |#1|)))) (-15 -2017 ((-3 (-385) "failed") (-413 (-959 |#1|)) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-413 (-959 |#1|)))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-413 (-959 |#1|)) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-413 (-959 (-171 |#1|))))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-413 (-959 (-171 |#1|))) (-923))) (IF (|has| |#1| (-848)) (PROGN (-15 -2017 ((-3 (-385) "failed") (-312 |#1|))) (-15 -2017 ((-3 (-385) "failed") (-312 |#1|) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-312 |#1|))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-312 |#1|) (-923))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-312 (-171 |#1|)))) (-15 -2649 ((-3 (-171 (-385)) "failed") (-312 (-171 |#1|)) (-923)))) |noBranch|)) |noBranch|)) 
-((-3036 (((-923) (-1152)) 63)) (-2837 (((-3 (-385) "failed") (-1152)) 32)) (-2884 (((-385) (-1152)) 30)) (-4283 (((-923) (-1152)) 53)) (-3071 (((-1152) (-923)) 54)) (-1875 (((-1152) (-923)) 52))) 
-(((-787) (-10 -7 (-15 -1875 ((-1152) (-923))) (-15 -4283 ((-923) (-1152))) (-15 -3071 ((-1152) (-923))) (-15 -3036 ((-923) (-1152))) (-15 -2884 ((-385) (-1152))) (-15 -2837 ((-3 (-385) "failed") (-1152))))) (T -787)) 
-((-2837 (*1 *2 *3) (|partial| -12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-787)))) (-2884 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-787)))) (-3036 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-923)) (-5 *1 (-787)))) (-3071 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1152)) (-5 *1 (-787)))) (-4283 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-923)) (-5 *1 (-787)))) (-1875 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1152)) (-5 *1 (-787))))) 
-(-10 -7 (-15 -1875 ((-1152) (-923))) (-15 -4283 ((-923) (-1152))) (-15 -3071 ((-1152) (-923))) (-15 -3036 ((-923) (-1152))) (-15 -2884 ((-385) (-1152))) (-15 -2837 ((-3 (-385) "failed") (-1152)))) 
-((-2262 (((-121) $ $) 7)) (-2553 (((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 14) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042)) 12)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 15) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-788) (-1290)) (T -788)) 
-((-1540 (*1 *2 *3 *4) (-12 (-4 *1 (-788)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042)))))) (-2553 (*1 *2 *3 *2) (-12 (-4 *1 (-788)) (-5 *2 (-1042)) (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) (-1540 (*1 *2 *3 *4) (-12 (-4 *1 (-788)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042)))))) (-2553 (*1 *2 *3 *2) (-12 (-4 *1 (-788)) (-5 *2 (-1042)) (-5 *3 (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) 
-(-13 (-1098) (-10 -7 (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2553 ((-1042) (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -2553 ((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) (-1042))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-1368 (((-1264) (-1259 (-385)) (-572) (-385) (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385))) (-385) (-1259 (-385)) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385))) 44) (((-1264) (-1259 (-385)) (-572) (-385) (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385))) (-385) (-1259 (-385)) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385))) 43)) (-2963 (((-1264) (-1259 (-385)) (-572) (-385) (-385) (-572) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385))) 50)) (-2218 (((-1264) (-1259 (-385)) (-572) (-385) (-385) (-385) (-385) (-572) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385))) 41)) (-2795 (((-1264) (-1259 (-385)) (-572) (-385) (-385) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385))) 52) (((-1264) (-1259 (-385)) (-572) (-385) (-385) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385))) 51))) 
-(((-789) (-10 -7 (-15 -2795 ((-1264) (-1259 (-385)) (-572) (-385) (-385) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)))) (-15 -2795 ((-1264) (-1259 (-385)) (-572) (-385) (-385) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)))) (-15 -2218 ((-1264) (-1259 (-385)) (-572) (-385) (-385) (-385) (-385) (-572) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)))) (-15 -1368 ((-1264) (-1259 (-385)) (-572) (-385) (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385))) (-385) (-1259 (-385)) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)))) (-15 -1368 ((-1264) (-1259 (-385)) (-572) (-385) (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385))) (-385) (-1259 (-385)) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)))) (-15 -2963 ((-1264) (-1259 (-385)) (-572) (-385) (-385) (-572) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)))))) (T -789)) 
-((-2963 (*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *4 (-572)) (-5 *6 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789)))) (-1368 (*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (-12 (-5 *4 (-572)) (-5 *6 (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385)))) (-5 *7 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789)))) (-1368 (*1 *2 *3 *4 *5 *6 *5 *3 *7) (-12 (-5 *4 (-572)) (-5 *6 (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385)))) (-5 *7 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789)))) (-2218 (*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (-12 (-5 *4 (-572)) (-5 *6 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789)))) (-2795 (*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (-12 (-5 *4 (-572)) (-5 *6 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789)))) (-2795 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-572)) (-5 *6 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789))))) 
-(-10 -7 (-15 -2795 ((-1264) (-1259 (-385)) (-572) (-385) (-385) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)))) (-15 -2795 ((-1264) (-1259 (-385)) (-572) (-385) (-385) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)))) (-15 -2218 ((-1264) (-1259 (-385)) (-572) (-385) (-385) (-385) (-385) (-572) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)))) (-15 -1368 ((-1264) (-1259 (-385)) (-572) (-385) (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385))) (-385) (-1259 (-385)) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)))) (-15 -1368 ((-1264) (-1259 (-385)) (-572) (-385) (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385))) (-385) (-1259 (-385)) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)) (-1259 (-385)))) (-15 -2963 ((-1264) (-1259 (-385)) (-572) (-385) (-385) (-572) (-1 (-1264) (-1259 (-385)) (-1259 (-385)) (-385))))) 
-((-3063 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572)) 53)) (-2674 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572)) 30)) (-3466 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572)) 52)) (-3578 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572)) 28)) (-2599 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572)) 51)) (-4258 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572)) 18)) (-3964 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572)) 31)) (-2753 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572)) 29)) (-3580 (((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572)) 27))) 
-(((-790) (-10 -7 (-15 -3580 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572))) (-15 -2753 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572))) (-15 -3964 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572))) (-15 -4258 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -3578 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -2674 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -2599 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -3466 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -3063 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))))) (T -790)) 
-((-3063 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572)))) (-3466 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572)))) (-2599 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572)))) (-2674 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572)))) (-3578 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572)))) (-4258 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572)))) (-3964 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572)))) (-2753 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572)))) (-3580 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(-10 -7 (-15 -3580 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572))) (-15 -2753 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572))) (-15 -3964 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572) (-572))) (-15 -4258 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -3578 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -2674 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -2599 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -3466 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572))) (-15 -3063 ((-2 (|:| -2148 (-385)) (|:| -3900 (-385)) (|:| |totalpts| (-572)) (|:| |success| (-121))) (-1 (-385) (-385)) (-385) (-385) (-385) (-385) (-572) (-572)))) 
-((-1440 (((-1200 |#1|) |#1| (-217) (-572)) 45))) 
-(((-791 |#1|) (-10 -7 (-15 -1440 ((-1200 |#1|) |#1| (-217) (-572)))) (-982)) (T -791)) 
-((-1440 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-217)) (-5 *5 (-572)) (-5 *2 (-1200 *3)) (-5 *1 (-791 *3)) (-4 *3 (-982))))) 
-(-10 -7 (-15 -1440 ((-1200 |#1|) |#1| (-217) (-572)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 23)) (-1572 (((-3 $ "failed") $ $) 25)) (-2211 (($) 22 T CONST)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 21 T CONST)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (-1373 (($ $ $) 27) (($ $) 26)) (-1367 (($ $ $) 19)) (* (($ (-769) $) 24) (($ (-923) $) 20) (($ (-572) $) 28))) 
-(((-792) (-1290)) (T -792)) 
-NIL 
-(-13 (-796) (-21)) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-793) . T) ((-795) . T) ((-796) . T) ((-848) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 23)) (-2211 (($) 22 T CONST)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 21 T CONST)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (-1367 (($ $ $) 19)) (* (($ (-769) $) 24) (($ (-923) $) 20))) 
-(((-793) (-1290)) (T -793)) 
-NIL 
-(-13 (-795) (-23)) 
-(((-23) . T) ((-25) . T) ((-105) . T) ((-612 (-856)) . T) ((-795) . T) ((-848) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 23)) (-1614 (($ $ $) 26)) (-1572 (((-3 $ "failed") $ $) 25)) (-2211 (($) 22 T CONST)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 21 T CONST)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (-1367 (($ $ $) 19)) (* (($ (-769) $) 24) (($ (-923) $) 20))) 
-(((-794) (-1290)) (T -794)) 
-((-1614 (*1 *1 *1 *1) (-4 *1 (-794)))) 
-(-13 (-796) (-10 -8 (-15 -1614 ($ $ $)))) 
-(((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-793) . T) ((-795) . T) ((-796) . T) ((-848) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 23)) (-2211 (($) 22 T CONST)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 21 T CONST)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (-1367 (($ $ $) 19)) (* (($ (-769) $) 24) (($ (-923) $) 20))) 
-(((-795) (-1290)) (T -795)) 
-NIL 
-(-13 (-848) (-23)) 
-(((-23) . T) ((-25) . T) ((-105) . T) ((-612 (-856)) . T) ((-848) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 23)) (-1572 (((-3 $ "failed") $ $) 25)) (-2211 (($) 22 T CONST)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 21 T CONST)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (-1367 (($ $ $) 19)) (* (($ (-769) $) 24) (($ (-923) $) 20))) 
-(((-796) (-1290)) (T -796)) 
-NIL 
-(-13 (-793) (-138)) 
-(((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-793) . T) ((-795) . T) ((-848) . T) ((-1098) . T)) 
-((-1342 (((-121) $) 41)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 |#2| "failed") $) 44)) (-1318 (((-572) $) NIL) (((-413 (-572)) $) NIL) ((|#2| $) 42)) (-2956 (((-3 (-413 (-572)) "failed") $) 78)) (-3175 (((-121) $) 72)) (-4299 (((-413 (-572)) $) 76)) (-4429 ((|#2| $) 26)) (-3828 (($ (-1 |#2| |#2|) $) 23)) (-4350 (($ $) 61)) (-4081 (((-545) $) 67)) (-3018 (($ $) 21)) (-3972 (((-856) $) 56) (($ (-572)) 39) (($ |#2|) 37) (($ (-413 (-572))) NIL)) (-2140 (((-769)) 10)) (-2264 ((|#2| $) 71)) (-1324 (((-121) $ $) 29)) (-1334 (((-121) $ $) 69)) (-1373 (($ $) 31) (($ $ $) NIL)) (-1367 (($ $ $) 30)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 35) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 32))) 
-(((-797 |#1| |#2|) (-10 -8 (-15 -1334 ((-121) |#1| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -4350 (|#1| |#1|)) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -2264 (|#2| |#1|)) (-15 -4429 (|#2| |#1|)) (-15 -3018 (|#1| |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3972 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 -1342 ((-121) |#1|)) (-15 * (|#1| (-923) |#1|)) (-15 -1367 (|#1| |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) (-798 |#2|) (-174)) (T -797)) 
-((-2140 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-769)) (-5 *1 (-797 *3 *4)) (-4 *3 (-798 *4))))) 
-(-10 -8 (-15 -1334 ((-121) |#1| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -4350 (|#1| |#1|)) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -2264 (|#2| |#1|)) (-15 -4429 (|#2| |#1|)) (-15 -3018 (|#1| |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3972 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 -1342 ((-121) |#1|)) (-15 * (|#1| (-923) |#1|)) (-15 -1367 (|#1| |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-1685 (((-769)) 51 (|has| |#1| (-374)))) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 93 (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 91 (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 89)) (-1318 (((-572) $) 94 (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) 92 (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 88)) (-1799 (((-3 $ "failed") $) 33)) (-3359 ((|#1| $) 78)) (-2956 (((-3 (-413 (-572)) "failed") $) 65 (|has| |#1| (-554)))) (-3175 (((-121) $) 67 (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) 66 (|has| |#1| (-554)))) (-3286 (($) 54 (|has| |#1| (-374)))) (-3893 (((-121) $) 30)) (-4099 (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) 69)) (-4429 ((|#1| $) 70)) (-1771 (($ $ $) 61 (|has| |#1| (-848)))) (-4238 (($ $ $) 60 (|has| |#1| (-848)))) (-3828 (($ (-1 |#1| |#1|) $) 80)) (-3633 (((-923) $) 53 (|has| |#1| (-374)))) (-1658 (((-1152) $) 9)) (-4350 (($ $) 64 (|has| |#1| (-368)))) (-1763 (($ (-923)) 52 (|has| |#1| (-374)))) (-2846 ((|#1| $) 75)) (-1604 ((|#1| $) 76)) (-4286 ((|#1| $) 77)) (-4425 ((|#1| $) 71)) (-4229 ((|#1| $) 72)) (-2789 ((|#1| $) 73)) (-2523 ((|#1| $) 74)) (-2607 (((-1116) $) 10)) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) 86 (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) 85 (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) 84 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) 83 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) 82 (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) 81 (|has| |#1| (-527 (-1170) |#1|)))) (-3587 (((-638 $)) 55 (|has| |#1| (-374)))) (-3277 (($ $ |#1|) 87 (|has| |#1| (-283 |#1| |#1|)))) (-4081 (((-545) $) 62 (|has| |#1| (-613 (-545))))) (-3018 (($ $) 79)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 36) (($ (-413 (-572))) 90 (|has| |#1| (-1044 (-413 (-572)))))) (-2779 (((-3 $ "failed") $) 63 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-2264 ((|#1| $) 68 (|has| |#1| (-1063)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1349 (((-121) $ $) 58 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 57 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 59 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 56 (|has| |#1| (-848)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
-(((-798 |#1|) (-1290) (-174)) (T -798)) 
-((-3018 (*1 *1 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-3359 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-4286 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-1604 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-2846 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-2523 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-2789 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-4229 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-4425 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-4429 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-4099 (*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) (-2264 (*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)) (-4 *2 (-1063)))) (-3175 (*1 *2 *1) (-12 (-4 *1 (-798 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-121)))) (-4299 (*1 *2 *1) (-12 (-4 *1 (-798 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) (-2956 (*1 *2 *1) (|partial| -12 (-4 *1 (-798 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) (-4350 (*1 *1 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)) (-4 *2 (-368))))) 
-(-13 (-43 |t#1|) (-417 |t#1|) (-338 |t#1|) (-10 -8 (-15 -3018 ($ $)) (-15 -3359 (|t#1| $)) (-15 -4286 (|t#1| $)) (-15 -1604 (|t#1| $)) (-15 -2846 (|t#1| $)) (-15 -2523 (|t#1| $)) (-15 -2789 (|t#1| $)) (-15 -4229 (|t#1| $)) (-15 -4425 (|t#1| $)) (-15 -4429 (|t#1| $)) (-15 -4099 ($ |t#1| |t#1| |t#1| |t#1| |t#1| |t#1| |t#1| |t#1|)) (IF (|has| |t#1| (-374)) (-6 (-374)) |noBranch|) (IF (|has| |t#1| (-848)) (-6 (-848)) |noBranch|) (IF (|has| |t#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (IF (|has| |t#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |t#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |t#1| (-1063)) (-15 -2264 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|) (IF (|has| |t#1| (-368)) (-15 -4350 ($ $)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 |#1| $) |has| |#1| (-283 |#1| |#1|)) ((-305 |#1|) |has| |#1| (-305 |#1|)) ((-374) |has| |#1| (-374)) ((-338 |#1|) . T) ((-417 |#1|) . T) ((-527 (-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((-527 |#1| |#1|) |has| |#1| (-305 |#1|)) ((-641 |#1|) . T) ((-641 $) . T) ((-713 |#1|) . T) ((-722) . T) ((-848) |has| |#1| (-848)) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1060 |#1|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3828 ((|#3| (-1 |#4| |#2|) |#1|) 20))) 
-(((-799 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#3| (-1 |#4| |#2|) |#1|))) (-798 |#2|) (-174) (-798 |#4|) (-174)) (T -799)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-174)) (-4 *6 (-174)) (-4 *2 (-798 *6)) (-5 *1 (-799 *4 *5 *2 *6)) (-4 *4 (-798 *5))))) 
-(-10 -7 (-15 -3828 (|#3| (-1 |#4| |#2|) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1685 (((-769)) NIL (|has| |#1| (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-1006 |#1|) "failed") $) 35) (((-3 (-572) "failed") $) NIL (-1841 (|has| (-1006 |#1|) (-1044 (-572))) (|has| |#1| (-1044 (-572))))) (((-3 (-413 (-572)) "failed") $) NIL (-1841 (|has| (-1006 |#1|) (-1044 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572))))))) (-1318 ((|#1| $) NIL) (((-1006 |#1|) $) 33) (((-572) $) NIL (-1841 (|has| (-1006 |#1|) (-1044 (-572))) (|has| |#1| (-1044 (-572))))) (((-413 (-572)) $) NIL (-1841 (|has| (-1006 |#1|) (-1044 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572))))))) (-1799 (((-3 $ "failed") $) NIL)) (-3359 ((|#1| $) 16)) (-2956 (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-554)))) (-3175 (((-121) $) NIL (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) NIL (|has| |#1| (-554)))) (-3286 (($) NIL (|has| |#1| (-374)))) (-3893 (((-121) $) NIL)) (-4099 (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) 28) (($ (-1006 |#1|) (-1006 |#1|)) 29)) (-4429 ((|#1| $) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3633 (((-923) $) NIL (|has| |#1| (-374)))) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-1763 (($ (-923)) NIL (|has| |#1| (-374)))) (-2846 ((|#1| $) 22)) (-1604 ((|#1| $) 20)) (-4286 ((|#1| $) 18)) (-4425 ((|#1| $) 26)) (-4229 ((|#1| $) 25)) (-2789 ((|#1| $) 24)) (-2523 ((|#1| $) 23)) (-2607 (((-1116) $) NIL)) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) NIL (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) NIL (|has| |#1| (-527 (-1170) |#1|)))) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-3277 (($ $ |#1|) NIL (|has| |#1| (-283 |#1| |#1|)))) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3018 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-1006 |#1|)) 30) (($ (-413 (-572))) NIL (-1841 (|has| (-1006 |#1|) (-1044 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572))))))) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-2264 ((|#1| $) NIL (|has| |#1| (-1063)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 8 T CONST)) (-3255 (($) 12 T CONST)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 40) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-800 |#1|) (-13 (-798 |#1|) (-417 (-1006 |#1|)) (-10 -8 (-15 -4099 ($ (-1006 |#1|) (-1006 |#1|))))) (-174)) (T -800)) 
-((-4099 (*1 *1 *2 *2) (-12 (-5 *2 (-1006 *3)) (-4 *3 (-174)) (-5 *1 (-800 *3))))) 
-(-13 (-798 |#1|) (-417 (-1006 |#1|)) (-10 -8 (-15 -4099 ($ (-1006 |#1|) (-1006 |#1|))))) 
-((-2262 (((-121) $ $) 7)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1512 (((-1042) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 12)) (-1324 (((-121) $ $) 6))) 
-(((-801) (-1290)) (T -801)) 
-((-1540 (*1 *2 *3 *4) (-12 (-4 *1 (-801)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)))))) (-1512 (*1 *2 *3) (-12 (-4 *1 (-801)) (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-1042))))) 
-(-13 (-1098) (-10 -7 (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -1512 ((-1042) (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-4172 (((-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#3| |#2| (-1170)) 19))) 
-(((-802 |#1| |#2| |#3|) (-10 -7 (-15 -4172 ((-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#3| |#2| (-1170)))) (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151)) (-13 (-29 |#1|) (-1190) (-966)) (-650 |#2|)) (T -802)) 
-((-4172 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-1170)) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-4 *4 (-13 (-29 *6) (-1190) (-966))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2237 (-638 *4)))) (-5 *1 (-802 *6 *4 *3)) (-4 *3 (-650 *4))))) 
-(-10 -7 (-15 -4172 ((-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#3| |#2| (-1170)))) 
-((-2800 (((-3 |#2| "failed") |#2| (-123) (-290 |#2|) (-638 |#2|)) 26) (((-3 |#2| "failed") (-290 |#2|) (-123) (-290 |#2|) (-638 |#2|)) 27) (((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#2| "failed") |#2| (-123) (-1170)) 16) (((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#2| "failed") (-290 |#2|) (-123) (-1170)) 17) (((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-638 |#2|) (-638 (-123)) (-1170)) 22) (((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-638 (-290 |#2|)) (-638 (-123)) (-1170)) 24) (((-3 (-638 (-1259 |#2|)) "failed") (-685 |#2|) (-1170)) 36) (((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-685 |#2|) (-1259 |#2|) (-1170)) 34))) 
-(((-803 |#1| |#2|) (-10 -7 (-15 -2800 ((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-685 |#2|) (-1259 |#2|) (-1170))) (-15 -2800 ((-3 (-638 (-1259 |#2|)) "failed") (-685 |#2|) (-1170))) (-15 -2800 ((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-638 (-290 |#2|)) (-638 (-123)) (-1170))) (-15 -2800 ((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-638 |#2|) (-638 (-123)) (-1170))) (-15 -2800 ((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#2| "failed") (-290 |#2|) (-123) (-1170))) (-15 -2800 ((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#2| "failed") |#2| (-123) (-1170))) (-15 -2800 ((-3 |#2| "failed") (-290 |#2|) (-123) (-290 |#2|) (-638 |#2|))) (-15 -2800 ((-3 |#2| "failed") |#2| (-123) (-290 |#2|) (-638 |#2|)))) (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151)) (-13 (-29 |#1|) (-1190) (-966))) (T -803)) 
-((-2800 (*1 *2 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-290 *2)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-803 *6 *2)))) (-2800 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-290 *2)) (-5 *4 (-123)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-29 *6) (-1190) (-966))) (-5 *1 (-803 *6 *2)) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))))) (-2800 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-123)) (-5 *5 (-1170)) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-3 (-2 (|:| |particular| *3) (|:| -2237 (-638 *3))) *3 "failed")) (-5 *1 (-803 *6 *3)) (-4 *3 (-13 (-29 *6) (-1190) (-966))))) (-2800 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-290 *7)) (-5 *4 (-123)) (-5 *5 (-1170)) (-4 *7 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-3 (-2 (|:| |particular| *7) (|:| -2237 (-638 *7))) *7 "failed")) (-5 *1 (-803 *6 *7)))) (-2800 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-638 *7)) (-5 *4 (-638 (-123))) (-5 *5 (-1170)) (-4 *7 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-2 (|:| |particular| (-1259 *7)) (|:| -2237 (-638 (-1259 *7))))) (-5 *1 (-803 *6 *7)))) (-2800 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-638 (-290 *7))) (-5 *4 (-638 (-123))) (-5 *5 (-1170)) (-4 *7 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-2 (|:| |particular| (-1259 *7)) (|:| -2237 (-638 (-1259 *7))))) (-5 *1 (-803 *6 *7)))) (-2800 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-685 *6)) (-5 *4 (-1170)) (-4 *6 (-13 (-29 *5) (-1190) (-966))) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-1259 *6))) (-5 *1 (-803 *5 *6)))) (-2800 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-685 *7)) (-5 *5 (-1170)) (-4 *7 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-2 (|:| |particular| (-1259 *7)) (|:| -2237 (-638 (-1259 *7))))) (-5 *1 (-803 *6 *7)) (-5 *4 (-1259 *7))))) 
-(-10 -7 (-15 -2800 ((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-685 |#2|) (-1259 |#2|) (-1170))) (-15 -2800 ((-3 (-638 (-1259 |#2|)) "failed") (-685 |#2|) (-1170))) (-15 -2800 ((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-638 (-290 |#2|)) (-638 (-123)) (-1170))) (-15 -2800 ((-3 (-2 (|:| |particular| (-1259 |#2|)) (|:| -2237 (-638 (-1259 |#2|)))) "failed") (-638 |#2|) (-638 (-123)) (-1170))) (-15 -2800 ((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#2| "failed") (-290 |#2|) (-123) (-1170))) (-15 -2800 ((-3 (-2 (|:| |particular| |#2|) (|:| -2237 (-638 |#2|))) |#2| "failed") |#2| (-123) (-1170))) (-15 -2800 ((-3 |#2| "failed") (-290 |#2|) (-123) (-290 |#2|) (-638 |#2|))) (-15 -2800 ((-3 |#2| "failed") |#2| (-123) (-290 |#2|) (-638 |#2|)))) 
-((-3060 (($) 9)) (-2787 (((-3 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))) "failed") (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 26)) (-2760 (((-638 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) $) 23)) (-1335 (($ (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))))) 20)) (-2282 (($ (-638 (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))))))) 18)) (-4536 (((-1264)) 12))) 
-(((-804) (-10 -8 (-15 -3060 ($)) (-15 -4536 ((-1264))) (-15 -2760 ((-638 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) $)) (-15 -2282 ($ (-638 (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))))))) (-15 -1335 ($ (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))))))) (-15 -2787 ((-3 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))) "failed") (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) (T -804)) 
-((-2787 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))) (-5 *1 (-804)))) (-1335 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))))) (-5 *1 (-804)))) (-2282 (*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))))))) (-5 *1 (-804)))) (-2760 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-5 *1 (-804)))) (-4536 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-804)))) (-3060 (*1 *1) (-5 *1 (-804)))) 
-(-10 -8 (-15 -3060 ($)) (-15 -4536 ((-1264))) (-15 -2760 ((-638 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) $)) (-15 -2282 ($ (-638 (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))))))) (-15 -1335 ($ (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))))))) (-15 -2787 ((-3 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))) "failed") (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) 
-((-3293 ((|#2| |#2| (-1170)) 15)) (-1600 ((|#2| |#2| (-1170)) 47)) (-3903 (((-1 |#2| |#2|) (-1170)) 11))) 
-(((-805 |#1| |#2|) (-10 -7 (-15 -3293 (|#2| |#2| (-1170))) (-15 -1600 (|#2| |#2| (-1170))) (-15 -3903 ((-1 |#2| |#2|) (-1170)))) (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151)) (-13 (-29 |#1|) (-1190) (-966))) (T -805)) 
-((-3903 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-1 *5 *5)) (-5 *1 (-805 *4 *5)) (-4 *5 (-13 (-29 *4) (-1190) (-966))))) (-1600 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-805 *4 *2)) (-4 *2 (-13 (-29 *4) (-1190) (-966))))) (-3293 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-805 *4 *2)) (-4 *2 (-13 (-29 *4) (-1190) (-966)))))) 
-(-10 -7 (-15 -3293 (|#2| |#2| (-1170))) (-15 -1600 (|#2| |#2| (-1170))) (-15 -3903 ((-1 |#2| |#2|) (-1170)))) 
-((-2800 (((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-638 (-385)) (-385) (-385)) 114) (((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-638 (-385)) (-385)) 115) (((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-638 (-385)) (-385)) 117) (((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-385)) 118) (((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-385)) 119) (((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385))) 120) (((-1042) (-809) (-1066)) 105) (((-1042) (-809)) 106)) (-1540 (((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-809) (-1066)) 71) (((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-809)) 73))) 
-(((-806) (-10 -7 (-15 -2800 ((-1042) (-809))) (-15 -2800 ((-1042) (-809) (-1066))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-385))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-385))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-638 (-385)) (-385))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-638 (-385)) (-385))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-638 (-385)) (-385) (-385))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-809))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-809) (-1066))))) (T -806)) 
-((-1540 (*1 *2 *3 *4) (-12 (-5 *3 (-809)) (-5 *4 (-1066)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-806)))) (-1540 (*1 *2 *3) (-12 (-5 *3 (-809)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-806)))) (-2800 (*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (-12 (-5 *3 (-1259 (-312 *4))) (-5 *5 (-638 (-385))) (-5 *6 (-312 (-385))) (-5 *4 (-385)) (-5 *2 (-1042)) (-5 *1 (-806)))) (-2800 (*1 *2 *3 *4 *4 *5 *6 *5 *4) (-12 (-5 *3 (-1259 (-312 *4))) (-5 *5 (-638 (-385))) (-5 *6 (-312 (-385))) (-5 *4 (-385)) (-5 *2 (-1042)) (-5 *1 (-806)))) (-2800 (*1 *2 *3 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1259 (-312 (-385)))) (-5 *4 (-385)) (-5 *5 (-638 *4)) (-5 *2 (-1042)) (-5 *1 (-806)))) (-2800 (*1 *2 *3 *4 *4 *5 *6 *4) (-12 (-5 *3 (-1259 (-312 *4))) (-5 *5 (-638 (-385))) (-5 *6 (-312 (-385))) (-5 *4 (-385)) (-5 *2 (-1042)) (-5 *1 (-806)))) (-2800 (*1 *2 *3 *4 *4 *5 *4) (-12 (-5 *3 (-1259 (-312 (-385)))) (-5 *4 (-385)) (-5 *5 (-638 *4)) (-5 *2 (-1042)) (-5 *1 (-806)))) (-2800 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1259 (-312 (-385)))) (-5 *4 (-385)) (-5 *5 (-638 *4)) (-5 *2 (-1042)) (-5 *1 (-806)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-809)) (-5 *4 (-1066)) (-5 *2 (-1042)) (-5 *1 (-806)))) (-2800 (*1 *2 *3) (-12 (-5 *3 (-809)) (-5 *2 (-1042)) (-5 *1 (-806))))) 
-(-10 -7 (-15 -2800 ((-1042) (-809))) (-15 -2800 ((-1042) (-809) (-1066))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-385))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-385))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-638 (-385)) (-385))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-638 (-385)) (-385))) (-15 -2800 ((-1042) (-1259 (-312 (-385))) (-385) (-385) (-638 (-385)) (-312 (-385)) (-638 (-385)) (-385) (-385))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-809))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-809) (-1066)))) 
-((-3573 (((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2237 (-638 |#4|))) (-647 |#4|) |#4|) 32))) 
-(((-807 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3573 ((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2237 (-638 |#4|))) (-647 |#4|) |#4|))) (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572)))) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|)) (T -807)) 
-((-3573 (*1 *2 *3 *4) (-12 (-5 *3 (-647 *4)) (-4 *4 (-342 *5 *6 *7)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-807 *5 *6 *7 *4))))) 
-(-10 -7 (-15 -3573 ((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2237 (-638 |#4|))) (-647 |#4|) |#4|))) 
-((-1518 (((-2 (|:| -2352 |#3|) (|:| |rh| (-638 (-413 |#2|)))) |#4| (-638 (-413 |#2|))) 51)) (-3526 (((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#4| |#2|) 59) (((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#4|) 58) (((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#3| |#2|) 20) (((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#3|) 21)) (-2369 ((|#2| |#4| |#1|) 60) ((|#2| |#3| |#1|) 27)) (-3731 ((|#2| |#3| (-638 (-413 |#2|))) 93) (((-3 |#2| "failed") |#3| (-413 |#2|)) 90))) 
-(((-808 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3731 ((-3 |#2| "failed") |#3| (-413 |#2|))) (-15 -3731 (|#2| |#3| (-638 (-413 |#2|)))) (-15 -3526 ((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#3|)) (-15 -3526 ((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#3| |#2|)) (-15 -2369 (|#2| |#3| |#1|)) (-15 -3526 ((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#4|)) (-15 -3526 ((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#4| |#2|)) (-15 -2369 (|#2| |#4| |#1|)) (-15 -1518 ((-2 (|:| -2352 |#3|) (|:| |rh| (-638 (-413 |#2|)))) |#4| (-638 (-413 |#2|))))) (-13 (-368) (-151) (-1044 (-413 (-572)))) (-1234 |#1|) (-650 |#2|) (-650 (-413 |#2|))) (T -808)) 
-((-1518 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-2 (|:| -2352 *7) (|:| |rh| (-638 (-413 *6))))) (-5 *1 (-808 *5 *6 *7 *3)) (-5 *4 (-638 (-413 *6))) (-4 *7 (-650 *6)) (-4 *3 (-650 (-413 *6))))) (-2369 (*1 *2 *3 *4) (-12 (-4 *2 (-1234 *4)) (-5 *1 (-808 *4 *2 *5 *3)) (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-650 *2)) (-4 *3 (-650 (-413 *2))))) (-3526 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *4 (-1234 *5)) (-5 *2 (-638 (-2 (|:| -1694 *4) (|:| -3821 *4)))) (-5 *1 (-808 *5 *4 *6 *3)) (-4 *6 (-650 *4)) (-4 *3 (-650 (-413 *4))))) (-3526 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-2 (|:| -1694 *5) (|:| -3821 *5)))) (-5 *1 (-808 *4 *5 *6 *3)) (-4 *6 (-650 *5)) (-4 *3 (-650 (-413 *5))))) (-2369 (*1 *2 *3 *4) (-12 (-4 *2 (-1234 *4)) (-5 *1 (-808 *4 *2 *3 *5)) (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-650 *2)) (-4 *5 (-650 (-413 *2))))) (-3526 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *4 (-1234 *5)) (-5 *2 (-638 (-2 (|:| -1694 *4) (|:| -3821 *4)))) (-5 *1 (-808 *5 *4 *3 *6)) (-4 *3 (-650 *4)) (-4 *6 (-650 (-413 *4))))) (-3526 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-2 (|:| -1694 *5) (|:| -3821 *5)))) (-5 *1 (-808 *4 *5 *3 *6)) (-4 *3 (-650 *5)) (-4 *6 (-650 (-413 *5))))) (-3731 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-413 *2))) (-4 *2 (-1234 *5)) (-5 *1 (-808 *5 *2 *3 *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-650 *2)) (-4 *6 (-650 (-413 *2))))) (-3731 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-413 *2)) (-4 *2 (-1234 *5)) (-5 *1 (-808 *5 *2 *3 *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-650 *2)) (-4 *6 (-650 *4))))) 
-(-10 -7 (-15 -3731 ((-3 |#2| "failed") |#3| (-413 |#2|))) (-15 -3731 (|#2| |#3| (-638 (-413 |#2|)))) (-15 -3526 ((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#3|)) (-15 -3526 ((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#3| |#2|)) (-15 -2369 (|#2| |#3| |#1|)) (-15 -3526 ((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#4|)) (-15 -3526 ((-638 (-2 (|:| -1694 |#2|) (|:| -3821 |#2|))) |#4| |#2|)) (-15 -2369 (|#2| |#4| |#1|)) (-15 -1518 ((-2 (|:| -2352 |#3|) (|:| |rh| (-638 (-413 |#2|)))) |#4| (-638 (-413 |#2|))))) 
-((-2262 (((-121) $ $) NIL)) (-1318 (((-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) $) 9)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 11) (($ (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) 8)) (-1324 (((-121) $ $) NIL))) 
-(((-809) (-13 (-1098) (-10 -8 (-15 -3972 ($ (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3972 ((-856) $)) (-15 -1318 ((-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) $))))) (T -809)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-809)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *1 (-809)))) (-1318 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *1 (-809))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-15 -3972 ((-856) $)) (-15 -1318 ((-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))) $)))) 
-((-2879 (((-638 (-2 (|:| |frac| (-413 |#2|)) (|:| -2352 |#3|))) |#3| (-1 (-638 |#2|) |#2| (-1166 |#2|)) (-1 (-424 |#2|) |#2|)) 118)) (-2772 (((-638 (-2 (|:| |poly| |#2|) (|:| -2352 |#3|))) |#3| (-1 (-638 |#1|) |#2|)) 45)) (-2039 (((-638 (-2 (|:| |deg| (-769)) (|:| -2352 |#2|))) |#3|) 95)) (-1645 ((|#2| |#3|) 37)) (-1531 (((-638 (-2 (|:| -3211 |#1|) (|:| -2352 |#3|))) |#3| (-1 (-638 |#1|) |#2|)) 82)) (-3047 ((|#3| |#3| (-413 |#2|)) 63) ((|#3| |#3| |#2|) 79))) 
-(((-810 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1645 (|#2| |#3|)) (-15 -2039 ((-638 (-2 (|:| |deg| (-769)) (|:| -2352 |#2|))) |#3|)) (-15 -1531 ((-638 (-2 (|:| -3211 |#1|) (|:| -2352 |#3|))) |#3| (-1 (-638 |#1|) |#2|))) (-15 -2772 ((-638 (-2 (|:| |poly| |#2|) (|:| -2352 |#3|))) |#3| (-1 (-638 |#1|) |#2|))) (-15 -2879 ((-638 (-2 (|:| |frac| (-413 |#2|)) (|:| -2352 |#3|))) |#3| (-1 (-638 |#2|) |#2| (-1166 |#2|)) (-1 (-424 |#2|) |#2|))) (-15 -3047 (|#3| |#3| |#2|)) (-15 -3047 (|#3| |#3| (-413 |#2|)))) (-13 (-368) (-151) (-1044 (-413 (-572)))) (-1234 |#1|) (-650 |#2|) (-650 (-413 |#2|))) (T -810)) 
-((-3047 (*1 *2 *2 *3) (-12 (-5 *3 (-413 *5)) (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *1 (-810 *4 *5 *2 *6)) (-4 *2 (-650 *5)) (-4 *6 (-650 *3)))) (-3047 (*1 *2 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-1234 *4)) (-5 *1 (-810 *4 *3 *2 *5)) (-4 *2 (-650 *3)) (-4 *5 (-650 (-413 *3))))) (-2879 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 (-638 *7) *7 (-1166 *7))) (-5 *5 (-1 (-424 *7) *7)) (-4 *7 (-1234 *6)) (-4 *6 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-5 *2 (-638 (-2 (|:| |frac| (-413 *7)) (|:| -2352 *3)))) (-5 *1 (-810 *6 *7 *3 *8)) (-4 *3 (-650 *7)) (-4 *8 (-650 (-413 *7))))) (-2772 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-2 (|:| |poly| *6) (|:| -2352 *3)))) (-5 *1 (-810 *5 *6 *3 *7)) (-4 *3 (-650 *6)) (-4 *7 (-650 (-413 *6))))) (-1531 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-2 (|:| -3211 *5) (|:| -2352 *3)))) (-5 *1 (-810 *5 *6 *3 *7)) (-4 *3 (-650 *6)) (-4 *7 (-650 (-413 *6))))) (-2039 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-2 (|:| |deg| (-769)) (|:| -2352 *5)))) (-5 *1 (-810 *4 *5 *3 *6)) (-4 *3 (-650 *5)) (-4 *6 (-650 (-413 *5))))) (-1645 (*1 *2 *3) (-12 (-4 *2 (-1234 *4)) (-5 *1 (-810 *4 *2 *3 *5)) (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-650 *2)) (-4 *5 (-650 (-413 *2)))))) 
-(-10 -7 (-15 -1645 (|#2| |#3|)) (-15 -2039 ((-638 (-2 (|:| |deg| (-769)) (|:| -2352 |#2|))) |#3|)) (-15 -1531 ((-638 (-2 (|:| -3211 |#1|) (|:| -2352 |#3|))) |#3| (-1 (-638 |#1|) |#2|))) (-15 -2772 ((-638 (-2 (|:| |poly| |#2|) (|:| -2352 |#3|))) |#3| (-1 (-638 |#1|) |#2|))) (-15 -2879 ((-638 (-2 (|:| |frac| (-413 |#2|)) (|:| -2352 |#3|))) |#3| (-1 (-638 |#2|) |#2| (-1166 |#2|)) (-1 (-424 |#2|) |#2|))) (-15 -3047 (|#3| |#3| |#2|)) (-15 -3047 (|#3| |#3| (-413 |#2|)))) 
-((-4384 (((-2 (|:| -2237 (-638 (-413 |#2|))) (|:| -1369 (-685 |#1|))) (-648 |#2| (-413 |#2|)) (-638 (-413 |#2|))) 117) (((-2 (|:| |particular| (-3 (-413 |#2|) "failed")) (|:| -2237 (-638 (-413 |#2|)))) (-648 |#2| (-413 |#2|)) (-413 |#2|)) 116) (((-2 (|:| -2237 (-638 (-413 |#2|))) (|:| -1369 (-685 |#1|))) (-647 (-413 |#2|)) (-638 (-413 |#2|))) 111) (((-2 (|:| |particular| (-3 (-413 |#2|) "failed")) (|:| -2237 (-638 (-413 |#2|)))) (-647 (-413 |#2|)) (-413 |#2|)) 109)) (-4533 ((|#2| (-648 |#2| (-413 |#2|))) 77) ((|#2| (-647 (-413 |#2|))) 81))) 
-(((-811 |#1| |#2|) (-10 -7 (-15 -4384 ((-2 (|:| |particular| (-3 (-413 |#2|) "failed")) (|:| -2237 (-638 (-413 |#2|)))) (-647 (-413 |#2|)) (-413 |#2|))) (-15 -4384 ((-2 (|:| -2237 (-638 (-413 |#2|))) (|:| -1369 (-685 |#1|))) (-647 (-413 |#2|)) (-638 (-413 |#2|)))) (-15 -4384 ((-2 (|:| |particular| (-3 (-413 |#2|) "failed")) (|:| -2237 (-638 (-413 |#2|)))) (-648 |#2| (-413 |#2|)) (-413 |#2|))) (-15 -4384 ((-2 (|:| -2237 (-638 (-413 |#2|))) (|:| -1369 (-685 |#1|))) (-648 |#2| (-413 |#2|)) (-638 (-413 |#2|)))) (-15 -4533 (|#2| (-647 (-413 |#2|)))) (-15 -4533 (|#2| (-648 |#2| (-413 |#2|))))) (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572)))) (-1234 |#1|)) (T -811)) 
-((-4533 (*1 *2 *3) (-12 (-5 *3 (-648 *2 (-413 *2))) (-4 *2 (-1234 *4)) (-5 *1 (-811 *4 *2)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))))) (-4533 (*1 *2 *3) (-12 (-5 *3 (-647 (-413 *2))) (-4 *2 (-1234 *4)) (-5 *1 (-811 *4 *2)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))))) (-4384 (*1 *2 *3 *4) (-12 (-5 *3 (-648 *6 (-413 *6))) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-2 (|:| -2237 (-638 (-413 *6))) (|:| -1369 (-685 *5)))) (-5 *1 (-811 *5 *6)) (-5 *4 (-638 (-413 *6))))) (-4384 (*1 *2 *3 *4) (-12 (-5 *3 (-648 *6 (-413 *6))) (-5 *4 (-413 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-811 *5 *6)))) (-4384 (*1 *2 *3 *4) (-12 (-5 *3 (-647 (-413 *6))) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-2 (|:| -2237 (-638 (-413 *6))) (|:| -1369 (-685 *5)))) (-5 *1 (-811 *5 *6)) (-5 *4 (-638 (-413 *6))))) (-4384 (*1 *2 *3 *4) (-12 (-5 *3 (-647 (-413 *6))) (-5 *4 (-413 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-811 *5 *6))))) 
-(-10 -7 (-15 -4384 ((-2 (|:| |particular| (-3 (-413 |#2|) "failed")) (|:| -2237 (-638 (-413 |#2|)))) (-647 (-413 |#2|)) (-413 |#2|))) (-15 -4384 ((-2 (|:| -2237 (-638 (-413 |#2|))) (|:| -1369 (-685 |#1|))) (-647 (-413 |#2|)) (-638 (-413 |#2|)))) (-15 -4384 ((-2 (|:| |particular| (-3 (-413 |#2|) "failed")) (|:| -2237 (-638 (-413 |#2|)))) (-648 |#2| (-413 |#2|)) (-413 |#2|))) (-15 -4384 ((-2 (|:| -2237 (-638 (-413 |#2|))) (|:| -1369 (-685 |#1|))) (-648 |#2| (-413 |#2|)) (-638 (-413 |#2|)))) (-15 -4533 (|#2| (-647 (-413 |#2|)))) (-15 -4533 (|#2| (-648 |#2| (-413 |#2|))))) 
-((-4367 (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#1|))) |#5| |#4|) 47))) 
-(((-812 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4367 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#1|))) |#5| |#4|))) (-368) (-650 |#1|) (-1234 |#1|) (-720 |#1| |#3|) (-650 |#4|)) (T -812)) 
-((-4367 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *7 (-1234 *5)) (-4 *4 (-720 *5 *7)) (-5 *2 (-2 (|:| -1369 (-685 *6)) (|:| |vec| (-1259 *5)))) (-5 *1 (-812 *5 *6 *7 *4 *3)) (-4 *6 (-650 *5)) (-4 *3 (-650 *4))))) 
-(-10 -7 (-15 -4367 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#1|))) |#5| |#4|))) 
-((-2879 (((-638 (-2 (|:| |frac| (-413 |#2|)) (|:| -2352 (-648 |#2| (-413 |#2|))))) (-648 |#2| (-413 |#2|)) (-1 (-424 |#2|) |#2|)) 43)) (-3975 (((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-424 |#2|) |#2|)) 133 (|has| |#1| (-27))) (((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|))) 134 (|has| |#1| (-27))) (((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-424 |#2|) |#2|)) 135 (|has| |#1| (-27))) (((-638 (-413 |#2|)) (-647 (-413 |#2|))) 136 (|has| |#1| (-27))) (((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|) (-1 (-424 |#2|) |#2|)) 36) (((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|)) 37) (((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|) (-1 (-424 |#2|) |#2|)) 34) (((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|)) 35)) (-2772 (((-638 (-2 (|:| |poly| |#2|) (|:| -2352 (-648 |#2| (-413 |#2|))))) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|)) 80))) 
-(((-813 |#1| |#2|) (-10 -7 (-15 -3975 ((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|))) (-15 -3975 ((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|) (-1 (-424 |#2|) |#2|))) (-15 -3975 ((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|))) (-15 -3975 ((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|) (-1 (-424 |#2|) |#2|))) (-15 -2879 ((-638 (-2 (|:| |frac| (-413 |#2|)) (|:| -2352 (-648 |#2| (-413 |#2|))))) (-648 |#2| (-413 |#2|)) (-1 (-424 |#2|) |#2|))) (-15 -2772 ((-638 (-2 (|:| |poly| |#2|) (|:| -2352 (-648 |#2| (-413 |#2|))))) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -3975 ((-638 (-413 |#2|)) (-647 (-413 |#2|)))) (-15 -3975 ((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-424 |#2|) |#2|))) (-15 -3975 ((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)))) (-15 -3975 ((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-424 |#2|) |#2|)))) |noBranch|)) (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572)))) (-1234 |#1|)) (T -813)) 
-((-3975 (*1 *2 *3 *4) (-12 (-5 *3 (-648 *6 (-413 *6))) (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-413 *6))) (-5 *1 (-813 *5 *6)))) (-3975 (*1 *2 *3) (-12 (-5 *3 (-648 *5 (-413 *5))) (-4 *5 (-1234 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-413 *5))) (-5 *1 (-813 *4 *5)))) (-3975 (*1 *2 *3 *4) (-12 (-5 *3 (-647 (-413 *6))) (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-413 *6))) (-5 *1 (-813 *5 *6)))) (-3975 (*1 *2 *3) (-12 (-5 *3 (-647 (-413 *5))) (-4 *5 (-1234 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-413 *5))) (-5 *1 (-813 *4 *5)))) (-2772 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-2 (|:| |poly| *6) (|:| -2352 (-648 *6 (-413 *6)))))) (-5 *1 (-813 *5 *6)) (-5 *3 (-648 *6 (-413 *6))))) (-2879 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-2 (|:| |frac| (-413 *6)) (|:| -2352 (-648 *6 (-413 *6)))))) (-5 *1 (-813 *5 *6)) (-5 *3 (-648 *6 (-413 *6))))) (-3975 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-648 *7 (-413 *7))) (-5 *4 (-1 (-638 *6) *7)) (-5 *5 (-1 (-424 *7) *7)) (-4 *6 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *7 (-1234 *6)) (-5 *2 (-638 (-413 *7))) (-5 *1 (-813 *6 *7)))) (-3975 (*1 *2 *3 *4) (-12 (-5 *3 (-648 *6 (-413 *6))) (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-413 *6))) (-5 *1 (-813 *5 *6)))) (-3975 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-647 (-413 *7))) (-5 *4 (-1 (-638 *6) *7)) (-5 *5 (-1 (-424 *7) *7)) (-4 *6 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *7 (-1234 *6)) (-5 *2 (-638 (-413 *7))) (-5 *1 (-813 *6 *7)))) (-3975 (*1 *2 *3 *4) (-12 (-5 *3 (-647 (-413 *6))) (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-413 *6))) (-5 *1 (-813 *5 *6))))) 
-(-10 -7 (-15 -3975 ((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|))) (-15 -3975 ((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-638 |#1|) |#2|) (-1 (-424 |#2|) |#2|))) (-15 -3975 ((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|))) (-15 -3975 ((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|) (-1 (-424 |#2|) |#2|))) (-15 -2879 ((-638 (-2 (|:| |frac| (-413 |#2|)) (|:| -2352 (-648 |#2| (-413 |#2|))))) (-648 |#2| (-413 |#2|)) (-1 (-424 |#2|) |#2|))) (-15 -2772 ((-638 (-2 (|:| |poly| |#2|) (|:| -2352 (-648 |#2| (-413 |#2|))))) (-648 |#2| (-413 |#2|)) (-1 (-638 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -3975 ((-638 (-413 |#2|)) (-647 (-413 |#2|)))) (-15 -3975 ((-638 (-413 |#2|)) (-647 (-413 |#2|)) (-1 (-424 |#2|) |#2|))) (-15 -3975 ((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)))) (-15 -3975 ((-638 (-413 |#2|)) (-648 |#2| (-413 |#2|)) (-1 (-424 |#2|) |#2|)))) |noBranch|)) 
-((-4108 (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#1|))) (-685 |#2|) (-1259 |#1|)) 86) (((-2 (|:| A (-685 |#1|)) (|:| |eqs| (-638 (-2 (|:| C (-685 |#1|)) (|:| |g| (-1259 |#1|)) (|:| -2352 |#2|) (|:| |rh| |#1|))))) (-685 |#1|) (-1259 |#1|)) 14)) (-4242 (((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-685 |#2|) (-1259 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2237 (-638 |#1|))) |#2| |#1|)) 92)) (-2800 (((-3 (-2 (|:| |particular| (-1259 |#1|)) (|:| -2237 (-685 |#1|))) "failed") (-685 |#1|) (-1259 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2237 (-638 |#1|))) "failed") |#2| |#1|)) 45))) 
-(((-814 |#1| |#2|) (-10 -7 (-15 -4108 ((-2 (|:| A (-685 |#1|)) (|:| |eqs| (-638 (-2 (|:| C (-685 |#1|)) (|:| |g| (-1259 |#1|)) (|:| -2352 |#2|) (|:| |rh| |#1|))))) (-685 |#1|) (-1259 |#1|))) (-15 -4108 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#1|))) (-685 |#2|) (-1259 |#1|))) (-15 -2800 ((-3 (-2 (|:| |particular| (-1259 |#1|)) (|:| -2237 (-685 |#1|))) "failed") (-685 |#1|) (-1259 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2237 (-638 |#1|))) "failed") |#2| |#1|))) (-15 -4242 ((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-685 |#2|) (-1259 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2237 (-638 |#1|))) |#2| |#1|)))) (-368) (-650 |#1|)) (T -814)) 
-((-4242 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *7)) (-5 *5 (-1 (-2 (|:| |particular| (-3 *6 "failed")) (|:| -2237 (-638 *6))) *7 *6)) (-4 *6 (-368)) (-4 *7 (-650 *6)) (-5 *2 (-2 (|:| |particular| (-3 (-1259 *6) "failed")) (|:| -2237 (-638 (-1259 *6))))) (-5 *1 (-814 *6 *7)) (-5 *4 (-1259 *6)))) (-2800 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-2 (|:| |particular| *6) (|:| -2237 (-638 *6))) "failed") *7 *6)) (-4 *6 (-368)) (-4 *7 (-650 *6)) (-5 *2 (-2 (|:| |particular| (-1259 *6)) (|:| -2237 (-685 *6)))) (-5 *1 (-814 *6 *7)) (-5 *3 (-685 *6)) (-5 *4 (-1259 *6)))) (-4108 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-650 *5)) (-5 *2 (-2 (|:| -1369 (-685 *6)) (|:| |vec| (-1259 *5)))) (-5 *1 (-814 *5 *6)) (-5 *3 (-685 *6)) (-5 *4 (-1259 *5)))) (-4108 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-5 *2 (-2 (|:| A (-685 *5)) (|:| |eqs| (-638 (-2 (|:| C (-685 *5)) (|:| |g| (-1259 *5)) (|:| -2352 *6) (|:| |rh| *5)))))) (-5 *1 (-814 *5 *6)) (-5 *3 (-685 *5)) (-5 *4 (-1259 *5)) (-4 *6 (-650 *5))))) 
-(-10 -7 (-15 -4108 ((-2 (|:| A (-685 |#1|)) (|:| |eqs| (-638 (-2 (|:| C (-685 |#1|)) (|:| |g| (-1259 |#1|)) (|:| -2352 |#2|) (|:| |rh| |#1|))))) (-685 |#1|) (-1259 |#1|))) (-15 -4108 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#1|))) (-685 |#2|) (-1259 |#1|))) (-15 -2800 ((-3 (-2 (|:| |particular| (-1259 |#1|)) (|:| -2237 (-685 |#1|))) "failed") (-685 |#1|) (-1259 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2237 (-638 |#1|))) "failed") |#2| |#1|))) (-15 -4242 ((-2 (|:| |particular| (-3 (-1259 |#1|) "failed")) (|:| -2237 (-638 (-1259 |#1|)))) (-685 |#2|) (-1259 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2237 (-638 |#1|))) |#2| |#1|)))) 
-((-3057 (((-685 |#1|) (-638 |#1|) (-769)) 13) (((-685 |#1|) (-638 |#1|)) 14)) (-2364 (((-3 (-1259 |#1|) "failed") |#2| |#1| (-638 |#1|)) 34)) (-3473 (((-3 |#1| "failed") |#2| |#1| (-638 |#1|) (-1 |#1| |#1|)) 42))) 
-(((-815 |#1| |#2|) (-10 -7 (-15 -3057 ((-685 |#1|) (-638 |#1|))) (-15 -3057 ((-685 |#1|) (-638 |#1|) (-769))) (-15 -2364 ((-3 (-1259 |#1|) "failed") |#2| |#1| (-638 |#1|))) (-15 -3473 ((-3 |#1| "failed") |#2| |#1| (-638 |#1|) (-1 |#1| |#1|)))) (-368) (-650 |#1|)) (T -815)) 
-((-3473 (*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *4 (-638 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-368)) (-5 *1 (-815 *2 *3)) (-4 *3 (-650 *2)))) (-2364 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-638 *4)) (-4 *4 (-368)) (-5 *2 (-1259 *4)) (-5 *1 (-815 *4 *3)) (-4 *3 (-650 *4)))) (-3057 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-769)) (-4 *5 (-368)) (-5 *2 (-685 *5)) (-5 *1 (-815 *5 *6)) (-4 *6 (-650 *5)))) (-3057 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-5 *2 (-685 *4)) (-5 *1 (-815 *4 *5)) (-4 *5 (-650 *4))))) 
-(-10 -7 (-15 -3057 ((-685 |#1|) (-638 |#1|))) (-15 -3057 ((-685 |#1|) (-638 |#1|) (-769))) (-15 -2364 ((-3 (-1259 |#1|) "failed") |#2| |#1| (-638 |#1|))) (-15 -3473 ((-3 |#1| "failed") |#2| |#1| (-638 |#1|) (-1 |#1| |#1|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#2| (-1098)))) (-1342 (((-121) $) NIL (|has| |#2| (-138)))) (-3421 (($ (-923)) NIL (|has| |#2| (-1054)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-1614 (($ $ $) NIL (|has| |#2| (-794)))) (-1572 (((-3 $ "failed") $ $) NIL (|has| |#2| (-138)))) (-1946 (((-121) $ (-769)) NIL)) (-1685 (((-769)) NIL (|has| |#2| (-374)))) (-2433 (((-572) $) NIL (|has| |#2| (-846)))) (-3283 ((|#2| $ (-572) |#2|) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) (((-3 |#2| "failed") $) NIL (|has| |#2| (-1098)))) (-1318 (((-572) $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098)))) (((-413 (-572)) $) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) ((|#2| $) NIL (|has| |#2| (-1098)))) (-2284 (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#2| (-1054)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL (|has| |#2| (-1054))) (((-685 |#2|) (-685 $)) NIL (|has| |#2| (-1054)))) (-1799 (((-3 $ "failed") $) NIL (|has| |#2| (-722)))) (-3286 (($) NIL (|has| |#2| (-374)))) (-3037 ((|#2| $ (-572) |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ (-572)) NIL)) (-1908 (((-121) $) NIL (|has| |#2| (-846)))) (-2010 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3893 (((-121) $) NIL (|has| |#2| (-722)))) (-4472 (((-121) $) NIL (|has| |#2| (-846)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-4467 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-2435 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-3633 (((-923) $) NIL (|has| |#2| (-374)))) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#2| (-1098)))) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-1763 (($ (-923)) NIL (|has| |#2| (-374)))) (-2607 (((-1116) $) NIL (|has| |#2| (-1098)))) (-1837 ((|#2| $) NIL (|has| (-572) (-848)))) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3587 (((-638 $)) NIL (|has| |#2| (-374)))) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ (-572) |#2|) NIL) ((|#2| $ (-572)) NIL)) (-1436 ((|#2| $ $) NIL (|has| |#2| (-1054)))) (-4315 (($ (-1259 |#2|)) NIL)) (-2502 (((-140)) NIL (|has| |#2| (-368)))) (-3139 (($ $) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1 |#2| |#2|) (-769)) NIL (|has| |#2| (-1054))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1054)))) (-1571 (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-1259 |#2|) $) NIL) (((-856) $) NIL (|has| |#2| (-1098))) (($ (-572)) NIL (-1841 (-12 (|has| |#2| (-1044 (-572))) (|has| |#2| (-1098))) (|has| |#2| (-1054)))) (($ (-413 (-572))) NIL (-12 (|has| |#2| (-1044 (-413 (-572)))) (|has| |#2| (-1098)))) (($ |#2|) NIL (|has| |#2| (-1098)))) (-2140 (((-769)) NIL (|has| |#2| (-1054)))) (-3501 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-2264 (($ $) NIL (|has| |#2| (-846)))) (-4174 (($ $ (-769)) NIL (|has| |#2| (-722))) (($ $ (-923)) NIL (|has| |#2| (-722)))) (-2378 (($) NIL (|has| |#2| (-138)) CONST)) (-3255 (($) NIL (|has| |#2| (-722)) CONST)) (-1557 (($ $) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#2| (-227)) (|has| |#2| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#2| (-901 (-1170))) (|has| |#2| (-1054)))) (($ $ (-1 |#2| |#2|) (-769)) NIL (|has| |#2| (-1054))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1054)))) (-1349 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1338 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1324 (((-121) $ $) NIL (|has| |#2| (-1098)))) (-1343 (((-121) $ $) NIL (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1334 (((-121) $ $) 11 (-1841 (|has| |#2| (-794)) (|has| |#2| (-846))))) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $ $) NIL (|has| |#2| (-1054))) (($ $) NIL (|has| |#2| (-1054)))) (-1367 (($ $ $) NIL (|has| |#2| (-25)))) (** (($ $ (-769)) NIL (|has| |#2| (-722))) (($ $ (-923)) NIL (|has| |#2| (-722)))) (* (($ (-572) $) NIL (|has| |#2| (-1054))) (($ $ $) NIL (|has| |#2| (-722))) (($ $ |#2|) NIL (|has| |#2| (-722))) (($ |#2| $) NIL (|has| |#2| (-722))) (($ (-769) $) NIL (|has| |#2| (-138))) (($ (-923) $) NIL (|has| |#2| (-25)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-816 |#1| |#2| |#3|) (-232 |#1| |#2|) (-769) (-794) (-1 (-121) (-1259 |#2|) (-1259 |#2|))) (T -816)) 
-NIL 
-(-232 |#1| |#2|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2923 (((-638 (-769)) $) NIL) (((-638 (-769)) $ (-1170)) NIL)) (-3073 (((-769) $) NIL) (((-769) $ (-1170)) NIL)) (-3456 (((-638 (-819 (-1170))) $) NIL)) (-4297 (((-1166 $) $ (-819 (-1170))) NIL) (((-1166 |#1|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-819 (-1170)))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4048 (($ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-819 (-1170)) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL) (((-3 (-1121 |#1| (-1170)) "failed") $) NIL)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-819 (-1170)) $) NIL) (((-1170) $) NIL) (((-1121 |#1| (-1170)) $) NIL)) (-3190 (($ $ $ (-819 (-1170))) NIL (|has| |#1| (-174)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ (-819 (-1170))) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-538 (-819 (-1170))) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-819 (-1170)) (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-819 (-1170)) (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3377 (((-769) $ (-1170)) NIL) (((-769) $) NIL)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-4335 (($ (-1166 |#1|) (-819 (-1170))) NIL) (($ (-1166 $) (-819 (-1170))) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-538 (-819 (-1170)))) NIL) (($ $ (-819 (-1170)) (-769)) NIL) (($ $ (-638 (-819 (-1170))) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-819 (-1170))) NIL)) (-1784 (((-538 (-819 (-1170))) $) NIL) (((-769) $ (-819 (-1170))) NIL) (((-638 (-769)) $ (-638 (-819 (-1170)))) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-538 (-819 (-1170))) (-538 (-819 (-1170)))) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3101 (((-1 $ (-769)) (-1170)) NIL) (((-1 $ (-769)) $) NIL (|has| |#1| (-227)))) (-1470 (((-3 (-819 (-1170)) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-4021 (((-819 (-1170)) $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-3815 (((-121) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-819 (-1170))) (|:| -3751 (-769))) "failed") $) NIL)) (-2106 (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-819 (-1170)) |#1|) NIL) (($ $ (-638 (-819 (-1170))) (-638 |#1|)) NIL) (($ $ (-819 (-1170)) $) NIL) (($ $ (-638 (-819 (-1170))) (-638 $)) NIL) (($ $ (-1170) $) NIL (|has| |#1| (-227))) (($ $ (-638 (-1170)) (-638 $)) NIL (|has| |#1| (-227))) (($ $ (-1170) |#1|) NIL (|has| |#1| (-227))) (($ $ (-638 (-1170)) (-638 |#1|)) NIL (|has| |#1| (-227)))) (-2119 (($ $ (-819 (-1170))) NIL (|has| |#1| (-174)))) (-3139 (($ $ (-819 (-1170))) NIL) (($ $ (-638 (-819 (-1170)))) NIL) (($ $ (-819 (-1170)) (-769)) NIL) (($ $ (-638 (-819 (-1170))) (-638 (-769))) NIL) (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2866 (((-638 (-1170)) $) NIL)) (-4316 (((-538 (-819 (-1170))) $) NIL) (((-769) $ (-819 (-1170))) NIL) (((-638 (-769)) $ (-638 (-819 (-1170)))) NIL) (((-769) $ (-1170)) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-819 (-1170)) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-819 (-1170)) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-819 (-1170)) (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) NIL (|has| |#1| (-457))) (($ $ (-819 (-1170))) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-819 (-1170))) NIL) (($ (-1170)) NIL) (($ (-1121 |#1| (-1170))) NIL) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-538 (-819 (-1170)))) NIL) (($ $ (-819 (-1170)) (-769)) NIL) (($ $ (-638 (-819 (-1170))) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-819 (-1170))) NIL) (($ $ (-638 (-819 (-1170)))) NIL) (($ $ (-819 (-1170)) (-769)) NIL) (($ $ (-638 (-819 (-1170))) (-638 (-769))) NIL) (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-817 |#1|) (-13 (-248 |#1| (-1170) (-819 (-1170)) (-538 (-819 (-1170)))) (-1044 (-1121 |#1| (-1170)))) (-1054)) (T -817)) 
-NIL 
-(-13 (-248 |#1| (-1170) (-819 (-1170)) (-538 (-819 (-1170)))) (-1044 (-1121 |#1| (-1170)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#2| (-368)))) (-3946 (($ $) NIL (|has| |#2| (-368)))) (-3686 (((-121) $) NIL (|has| |#2| (-368)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| |#2| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#2| (-368)))) (-3112 (((-121) $ $) NIL (|has| |#2| (-368)))) (-2211 (($) NIL T CONST)) (-2190 (($ $ $) NIL (|has| |#2| (-368)))) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#2| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#2| (-368)))) (-1526 (((-121) $) NIL (|has| |#2| (-368)))) (-3893 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#2| (-368)))) (-1629 (($ (-638 $)) NIL (|has| |#2| (-368))) (($ $ $) NIL (|has| |#2| (-368)))) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 20 (|has| |#2| (-368)))) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#2| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#2| (-368))) (($ $ $) NIL (|has| |#2| (-368)))) (-4304 (((-424 $) $) NIL (|has| |#2| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#2| (-368)))) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#2| (-368)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#2| (-368)))) (-4029 (((-769) $) NIL (|has| |#2| (-368)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-368)))) (-3139 (($ $ (-769)) NIL) (($ $) 13)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) 10) ((|#2| $) 11) (($ (-413 (-572))) NIL (|has| |#2| (-368))) (($ $) NIL (|has| |#2| (-368)))) (-2140 (((-769)) NIL)) (-3774 (((-121) $ $) NIL (|has| |#2| (-368)))) (-4174 (($ $ (-769)) NIL) (($ $ (-923)) NIL) (($ $ (-572)) NIL (|has| |#2| (-368)))) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) 15 (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-923)) NIL) (($ $ (-572)) 18 (|has| |#2| (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ $) NIL) (($ (-413 (-572)) $) NIL (|has| |#2| (-368))) (($ $ (-413 (-572))) NIL (|has| |#2| (-368))))) 
-(((-818 |#1| |#2| |#3|) (-13 (-120 $ $) (-227) (-10 -8 (IF (|has| |#2| (-368)) (-6 (-368)) |noBranch|) (-15 -3972 ($ |#2|)) (-15 -3972 (|#2| $)))) (-1098) (-901 |#1|) |#1|) (T -818)) 
-((-3972 (*1 *1 *2) (-12 (-4 *3 (-1098)) (-14 *4 *3) (-5 *1 (-818 *3 *2 *4)) (-4 *2 (-901 *3)))) (-3972 (*1 *2 *1) (-12 (-4 *2 (-901 *3)) (-5 *1 (-818 *3 *2 *4)) (-4 *3 (-1098)) (-14 *4 *3)))) 
-(-13 (-120 $ $) (-227) (-10 -8 (IF (|has| |#2| (-368)) (-6 (-368)) |noBranch|) (-15 -3972 ($ |#2|)) (-15 -3972 (|#2| $)))) 
-((-2262 (((-121) $ $) NIL)) (-3073 (((-769) $) NIL)) (-3342 ((|#1| $) 10)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-3377 (((-769) $) 11)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3101 (($ |#1| (-769)) 9)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3139 (($ $) NIL) (($ $ (-769)) NIL)) (-3972 (((-856) $) NIL) (($ |#1|) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL))) 
-(((-819 |#1|) (-264 |#1|) (-848)) (T -819)) 
-NIL 
-(-264 |#1|) 
-((-2262 (((-121) $ $) NIL)) (-2199 (((-638 |#1|) $) 34)) (-1685 (((-769) $) NIL)) (-2211 (($) NIL T CONST)) (-3754 (((-3 $ "failed") $ $) 21) (((-3 $ "failed") $ |#1|) 19)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-1651 (($ $) 36)) (-1799 (((-3 $ "failed") $) NIL)) (-2946 (((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) NIL)) (-3893 (((-121) $) NIL)) (-4351 ((|#1| $ (-572)) NIL)) (-1606 (((-769) $ (-572)) NIL)) (-4076 (($ $) 40)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3561 (((-3 $ "failed") $ $) 20) (((-3 $ "failed") $ |#1|) 16)) (-3763 (((-121) $ $) 38)) (-3200 (((-769) $) 30)) (-1658 (((-1152) $) NIL)) (-2716 (($ $ $) NIL)) (-3852 (($ $ $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 ((|#1| $) 35)) (-4547 (((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-769)))) $) NIL)) (-2541 (((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $) 24)) (-3972 (((-856) $) NIL) (($ |#1|) NIL)) (-4174 (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (-3255 (($) 14 T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 39)) (** (($ $ (-769)) NIL) (($ $ (-923)) NIL) (($ |#1| (-769)) NIL)) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-820 |#1|) (-13 (-844) (-1044 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-769))) (-15 -1837 (|#1| $)) (-15 -1651 ($ $)) (-15 -4076 ($ $)) (-15 -3763 ((-121) $ $)) (-15 -3852 ($ $ $)) (-15 -2716 ($ $ $)) (-15 -3561 ((-3 $ "failed") $ $)) (-15 -3754 ((-3 $ "failed") $ $)) (-15 -3561 ((-3 $ "failed") $ |#1|)) (-15 -3754 ((-3 $ "failed") $ |#1|)) (-15 -2541 ((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $)) (-15 -2946 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -1685 ((-769) $)) (-15 -1606 ((-769) $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -4547 ((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-769)))) $)) (-15 -3200 ((-769) $)) (-15 -2199 ((-638 |#1|) $)))) (-848)) (T -820)) 
-((* (*1 *1 *2 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-1837 (*1 *2 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-1651 (*1 *1 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-4076 (*1 *1 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-3763 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-820 *3)) (-4 *3 (-848)))) (-3852 (*1 *1 *1 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-2716 (*1 *1 *1 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-3561 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-3754 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-3561 (*1 *1 *1 *2) (|partial| -12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-3754 (*1 *1 *1 *2) (|partial| -12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-2541 (*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-3 (-820 *3) "failed")) (|:| |rm| (-3 (-820 *3) "failed")))) (-5 *1 (-820 *3)) (-4 *3 (-848)))) (-2946 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-820 *3)) (|:| |mm| (-820 *3)) (|:| |rm| (-820 *3)))) (-5 *1 (-820 *3)) (-4 *3 (-848)))) (-1685 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-820 *3)) (-4 *3 (-848)))) (-1606 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-769)) (-5 *1 (-820 *4)) (-4 *4 (-848)))) (-4351 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-820 *2)) (-4 *2 (-848)))) (-4547 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 (-769))))) (-5 *1 (-820 *3)) (-4 *3 (-848)))) (-3200 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-820 *3)) (-4 *3 (-848)))) (-2199 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-820 *3)) (-4 *3 (-848))))) 
-(-13 (-844) (-1044 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-769))) (-15 -1837 (|#1| $)) (-15 -1651 ($ $)) (-15 -4076 ($ $)) (-15 -3763 ((-121) $ $)) (-15 -3852 ($ $ $)) (-15 -2716 ($ $ $)) (-15 -3561 ((-3 $ "failed") $ $)) (-15 -3754 ((-3 $ "failed") $ $)) (-15 -3561 ((-3 $ "failed") $ |#1|)) (-15 -3754 ((-3 $ "failed") $ |#1|)) (-15 -2541 ((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $)) (-15 -2946 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -1685 ((-769) $)) (-15 -1606 ((-769) $ (-572))) (-15 -4351 (|#1| $ (-572))) (-15 -4547 ((-638 (-2 (|:| |gen| |#1|) (|:| -4179 (-769)))) $)) (-15 -3200 ((-769) $)) (-15 -2199 ((-638 |#1|) $)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2433 (((-572) $) 52)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-1908 (((-121) $) 50)) (-3893 (((-121) $) 30)) (-4472 (((-121) $) 51)) (-1771 (($ $ $) 49)) (-4238 (($ $ $) 48)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ $) 41)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-2264 (($ $) 53)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1349 (((-121) $ $) 46)) (-1338 (((-121) $ $) 45)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 47)) (-1334 (((-121) $ $) 44)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-821) (-1290)) (T -821)) 
-NIL 
-(-13 (-562) (-846)) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-792) . T) ((-793) . T) ((-795) . T) ((-796) . T) ((-846) . T) ((-848) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-1922 (($ (-1116)) 7)) (-4074 (((-121) $ (-1152) (-1116)) 15)) (-2723 (((-823) $) 12)) (-1769 (((-823) $) 11)) (-2239 (((-1264) $) 9)) (-2909 (((-121) $ (-1116)) 16))) 
-(((-822) (-10 -8 (-15 -1922 ($ (-1116))) (-15 -2239 ((-1264) $)) (-15 -1769 ((-823) $)) (-15 -2723 ((-823) $)) (-15 -4074 ((-121) $ (-1152) (-1116))) (-15 -2909 ((-121) $ (-1116))))) (T -822)) 
-((-2909 (*1 *2 *1 *3) (-12 (-5 *3 (-1116)) (-5 *2 (-121)) (-5 *1 (-822)))) (-4074 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-1116)) (-5 *2 (-121)) (-5 *1 (-822)))) (-2723 (*1 *2 *1) (-12 (-5 *2 (-823)) (-5 *1 (-822)))) (-1769 (*1 *2 *1) (-12 (-5 *2 (-823)) (-5 *1 (-822)))) (-2239 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-822)))) (-1922 (*1 *1 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-822))))) 
-(-10 -8 (-15 -1922 ($ (-1116))) (-15 -2239 ((-1264) $)) (-15 -1769 ((-823) $)) (-15 -2723 ((-823) $)) (-15 -4074 ((-121) $ (-1152) (-1116))) (-15 -2909 ((-121) $ (-1116)))) 
-((-3859 (((-1264) $ (-824)) 12)) (-3164 (((-1264) $ (-1170)) 32)) (-1759 (((-1264) $ (-1152) (-1152)) 34)) (-2248 (((-1264) $ (-1152)) 33)) (-3799 (((-1264) $) 19)) (-2869 (((-1264) $ (-572)) 28)) (-3825 (((-1264) $ (-217)) 30)) (-2265 (((-1264) $) 18)) (-2958 (((-1264) $) 26)) (-2335 (((-1264) $) 25)) (-3152 (((-1264) $) 23)) (-4261 (((-1264) $) 24)) (-3375 (((-1264) $) 22)) (-4045 (((-1264) $) 21)) (-2908 (((-1264) $) 20)) (-3050 (((-1264) $) 16)) (-3676 (((-1264) $) 17)) (-4528 (((-1264) $) 15)) (-3266 (((-1264) $) 14)) (-1932 (((-1264) $) 13)) (-1880 (($ (-1152) (-824)) 9)) (-1370 (($ (-1152) (-1152) (-824)) 8)) (-2712 (((-1170) $) 51)) (-2346 (((-1170) $) 55)) (-2112 (((-2 (|:| |cd| (-1152)) (|:| -3201 (-1152))) $) 54)) (-1578 (((-1152) $) 52)) (-4181 (((-1264) $) 41)) (-1838 (((-572) $) 49)) (-4175 (((-217) $) 50)) (-4149 (((-1264) $) 40)) (-2212 (((-1264) $) 48)) (-2736 (((-1264) $) 47)) (-1409 (((-1264) $) 45)) (-4147 (((-1264) $) 46)) (-1955 (((-1264) $) 44)) (-1743 (((-1264) $) 43)) (-1963 (((-1264) $) 42)) (-3659 (((-1264) $) 38)) (-3484 (((-1264) $) 39)) (-2256 (((-1264) $) 37)) (-3795 (((-1264) $) 36)) (-1631 (((-1264) $) 35)) (-3123 (((-1264) $) 11))) 
-(((-823) (-10 -8 (-15 -1370 ($ (-1152) (-1152) (-824))) (-15 -1880 ($ (-1152) (-824))) (-15 -3123 ((-1264) $)) (-15 -3859 ((-1264) $ (-824))) (-15 -1932 ((-1264) $)) (-15 -3266 ((-1264) $)) (-15 -4528 ((-1264) $)) (-15 -3050 ((-1264) $)) (-15 -3676 ((-1264) $)) (-15 -2265 ((-1264) $)) (-15 -3799 ((-1264) $)) (-15 -2908 ((-1264) $)) (-15 -4045 ((-1264) $)) (-15 -3375 ((-1264) $)) (-15 -3152 ((-1264) $)) (-15 -4261 ((-1264) $)) (-15 -2335 ((-1264) $)) (-15 -2958 ((-1264) $)) (-15 -2869 ((-1264) $ (-572))) (-15 -3825 ((-1264) $ (-217))) (-15 -3164 ((-1264) $ (-1170))) (-15 -2248 ((-1264) $ (-1152))) (-15 -1759 ((-1264) $ (-1152) (-1152))) (-15 -1631 ((-1264) $)) (-15 -3795 ((-1264) $)) (-15 -2256 ((-1264) $)) (-15 -3659 ((-1264) $)) (-15 -3484 ((-1264) $)) (-15 -4149 ((-1264) $)) (-15 -4181 ((-1264) $)) (-15 -1963 ((-1264) $)) (-15 -1743 ((-1264) $)) (-15 -1955 ((-1264) $)) (-15 -1409 ((-1264) $)) (-15 -4147 ((-1264) $)) (-15 -2736 ((-1264) $)) (-15 -2212 ((-1264) $)) (-15 -1838 ((-572) $)) (-15 -4175 ((-217) $)) (-15 -2712 ((-1170) $)) (-15 -1578 ((-1152) $)) (-15 -2112 ((-2 (|:| |cd| (-1152)) (|:| -3201 (-1152))) $)) (-15 -2346 ((-1170) $)))) (T -823)) 
-((-2346 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-823)))) (-2112 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |cd| (-1152)) (|:| -3201 (-1152)))) (-5 *1 (-823)))) (-1578 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-823)))) (-2712 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-823)))) (-4175 (*1 *2 *1) (-12 (-5 *2 (-217)) (-5 *1 (-823)))) (-1838 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-823)))) (-2212 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-2736 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-4147 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-1409 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-1955 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-1743 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-1963 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-4181 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-4149 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3484 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3659 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-2256 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3795 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-1631 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-1759 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-823)))) (-2248 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-823)))) (-3164 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-823)))) (-3825 (*1 *2 *1 *3) (-12 (-5 *3 (-217)) (-5 *2 (-1264)) (-5 *1 (-823)))) (-2869 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-823)))) (-2958 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-2335 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-4261 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3152 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3375 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-4045 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-2908 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3799 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-2265 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3676 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3050 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-4528 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3266 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-1932 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-3859 (*1 *2 *1 *3) (-12 (-5 *3 (-824)) (-5 *2 (-1264)) (-5 *1 (-823)))) (-3123 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823)))) (-1880 (*1 *1 *2 *3) (-12 (-5 *2 (-1152)) (-5 *3 (-824)) (-5 *1 (-823)))) (-1370 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-1152)) (-5 *3 (-824)) (-5 *1 (-823))))) 
-(-10 -8 (-15 -1370 ($ (-1152) (-1152) (-824))) (-15 -1880 ($ (-1152) (-824))) (-15 -3123 ((-1264) $)) (-15 -3859 ((-1264) $ (-824))) (-15 -1932 ((-1264) $)) (-15 -3266 ((-1264) $)) (-15 -4528 ((-1264) $)) (-15 -3050 ((-1264) $)) (-15 -3676 ((-1264) $)) (-15 -2265 ((-1264) $)) (-15 -3799 ((-1264) $)) (-15 -2908 ((-1264) $)) (-15 -4045 ((-1264) $)) (-15 -3375 ((-1264) $)) (-15 -3152 ((-1264) $)) (-15 -4261 ((-1264) $)) (-15 -2335 ((-1264) $)) (-15 -2958 ((-1264) $)) (-15 -2869 ((-1264) $ (-572))) (-15 -3825 ((-1264) $ (-217))) (-15 -3164 ((-1264) $ (-1170))) (-15 -2248 ((-1264) $ (-1152))) (-15 -1759 ((-1264) $ (-1152) (-1152))) (-15 -1631 ((-1264) $)) (-15 -3795 ((-1264) $)) (-15 -2256 ((-1264) $)) (-15 -3659 ((-1264) $)) (-15 -3484 ((-1264) $)) (-15 -4149 ((-1264) $)) (-15 -4181 ((-1264) $)) (-15 -1963 ((-1264) $)) (-15 -1743 ((-1264) $)) (-15 -1955 ((-1264) $)) (-15 -1409 ((-1264) $)) (-15 -4147 ((-1264) $)) (-15 -2736 ((-1264) $)) (-15 -2212 ((-1264) $)) (-15 -1838 ((-572) $)) (-15 -4175 ((-217) $)) (-15 -2712 ((-1170) $)) (-15 -1578 ((-1152) $)) (-15 -2112 ((-2 (|:| |cd| (-1152)) (|:| -3201 (-1152))) $)) (-15 -2346 ((-1170) $))) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 12)) (-3987 (($) 15)) (-4071 (($) 13)) (-3695 (($) 16)) (-1787 (($) 14)) (-1324 (((-121) $ $) 8))) 
-(((-824) (-13 (-1098) (-10 -8 (-15 -4071 ($)) (-15 -3987 ($)) (-15 -3695 ($)) (-15 -1787 ($))))) (T -824)) 
-((-4071 (*1 *1) (-5 *1 (-824))) (-3987 (*1 *1) (-5 *1 (-824))) (-3695 (*1 *1) (-5 *1 (-824))) (-1787 (*1 *1) (-5 *1 (-824)))) 
-(-13 (-1098) (-10 -8 (-15 -4071 ($)) (-15 -3987 ($)) (-15 -3695 ($)) (-15 -1787 ($)))) 
-((-2262 (((-121) $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 21) (($ (-1170)) 17)) (-3380 (((-121) $) 10)) (-2542 (((-121) $) 9)) (-1965 (((-121) $) 11)) (-2505 (((-121) $) 8)) (-1324 (((-121) $ $) 19))) 
-(((-825) (-13 (-1098) (-10 -8 (-15 -3972 ($ (-1170))) (-15 -2505 ((-121) $)) (-15 -2542 ((-121) $)) (-15 -3380 ((-121) $)) (-15 -1965 ((-121) $))))) (T -825)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-825)))) (-2505 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-825)))) (-2542 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-825)))) (-3380 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-825)))) (-1965 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-825))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-1170))) (-15 -2505 ((-121) $)) (-15 -2542 ((-121) $)) (-15 -3380 ((-121) $)) (-15 -1965 ((-121) $)))) 
-((-2262 (((-121) $ $) NIL)) (-2893 (($ (-825) (-638 (-1170))) 24)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1576 (((-825) $) 25)) (-2864 (((-638 (-1170)) $) 26)) (-3972 (((-856) $) 23)) (-1324 (((-121) $ $) NIL))) 
-(((-826) (-13 (-1098) (-10 -8 (-15 -1576 ((-825) $)) (-15 -2864 ((-638 (-1170)) $)) (-15 -2893 ($ (-825) (-638 (-1170))))))) (T -826)) 
-((-1576 (*1 *2 *1) (-12 (-5 *2 (-825)) (-5 *1 (-826)))) (-2864 (*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-826)))) (-2893 (*1 *1 *2 *3) (-12 (-5 *2 (-825)) (-5 *3 (-638 (-1170))) (-5 *1 (-826))))) 
-(-13 (-1098) (-10 -8 (-15 -1576 ((-825) $)) (-15 -2864 ((-638 (-1170)) $)) (-15 -2893 ($ (-825) (-638 (-1170)))))) 
-((-3594 (((-1264) (-823) (-312 |#1|) (-121)) 22) (((-1264) (-823) (-312 |#1|)) 76) (((-1152) (-312 |#1|) (-121)) 75) (((-1152) (-312 |#1|)) 74))) 
-(((-827 |#1|) (-10 -7 (-15 -3594 ((-1152) (-312 |#1|))) (-15 -3594 ((-1152) (-312 |#1|) (-121))) (-15 -3594 ((-1264) (-823) (-312 |#1|))) (-15 -3594 ((-1264) (-823) (-312 |#1|) (-121)))) (-13 (-829) (-848) (-1054))) (T -827)) 
-((-3594 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-823)) (-5 *4 (-312 *6)) (-5 *5 (-121)) (-4 *6 (-13 (-829) (-848) (-1054))) (-5 *2 (-1264)) (-5 *1 (-827 *6)))) (-3594 (*1 *2 *3 *4) (-12 (-5 *3 (-823)) (-5 *4 (-312 *5)) (-4 *5 (-13 (-829) (-848) (-1054))) (-5 *2 (-1264)) (-5 *1 (-827 *5)))) (-3594 (*1 *2 *3 *4) (-12 (-5 *3 (-312 *5)) (-5 *4 (-121)) (-4 *5 (-13 (-829) (-848) (-1054))) (-5 *2 (-1152)) (-5 *1 (-827 *5)))) (-3594 (*1 *2 *3) (-12 (-5 *3 (-312 *4)) (-4 *4 (-13 (-829) (-848) (-1054))) (-5 *2 (-1152)) (-5 *1 (-827 *4))))) 
-(-10 -7 (-15 -3594 ((-1152) (-312 |#1|))) (-15 -3594 ((-1152) (-312 |#1|) (-121))) (-15 -3594 ((-1264) (-823) (-312 |#1|))) (-15 -3594 ((-1264) (-823) (-312 |#1|) (-121)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2280 ((|#1| $) 10)) (-1824 (($ |#1|) 9)) (-3893 (((-121) $) NIL)) (-4328 (($ |#2| (-769)) NIL)) (-1784 (((-769) $) NIL)) (-4373 ((|#2| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3139 (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $) NIL (|has| |#1| (-227)))) (-4316 (((-769) $) NIL)) (-3972 (((-856) $) 17) (($ (-572)) NIL) (($ |#2|) NIL (|has| |#2| (-174)))) (-1958 ((|#2| $ (-769)) NIL)) (-2140 (((-769)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $) NIL (|has| |#1| (-227)))) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 12) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
-(((-828 |#1| |#2|) (-13 (-704 |#2|) (-10 -8 (IF (|has| |#1| (-227)) (-6 (-227)) |noBranch|) (-15 -1824 ($ |#1|)) (-15 -2280 (|#1| $)))) (-704 |#2|) (-1054)) (T -828)) 
-((-1824 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-828 *2 *3)) (-4 *2 (-704 *3)))) (-2280 (*1 *2 *1) (-12 (-4 *2 (-704 *3)) (-5 *1 (-828 *2 *3)) (-4 *3 (-1054))))) 
-(-13 (-704 |#2|) (-10 -8 (IF (|has| |#1| (-227)) (-6 (-227)) |noBranch|) (-15 -1824 ($ |#1|)) (-15 -2280 (|#1| $)))) 
-((-3594 (((-1264) (-823) $ (-121)) 9) (((-1264) (-823) $) 8) (((-1152) $ (-121)) 7) (((-1152) $) 6))) 
-(((-829) (-1290)) (T -829)) 
-((-3594 (*1 *2 *3 *1 *4) (-12 (-4 *1 (-829)) (-5 *3 (-823)) (-5 *4 (-121)) (-5 *2 (-1264)))) (-3594 (*1 *2 *3 *1) (-12 (-4 *1 (-829)) (-5 *3 (-823)) (-5 *2 (-1264)))) (-3594 (*1 *2 *1 *3) (-12 (-4 *1 (-829)) (-5 *3 (-121)) (-5 *2 (-1152)))) (-3594 (*1 *2 *1) (-12 (-4 *1 (-829)) (-5 *2 (-1152))))) 
-(-13 (-10 -8 (-15 -3594 ((-1152) $)) (-15 -3594 ((-1152) $ (-121))) (-15 -3594 ((-1264) (-823) $)) (-15 -3594 ((-1264) (-823) $ (-121))))) 
-((-3715 (((-307) (-1152) (-1152)) 12)) (-4409 (((-121) (-1152) (-1152)) 33)) (-4088 (((-121) (-1152)) 32)) (-4047 (((-57) (-1152)) 25)) (-3833 (((-57) (-1152)) 23)) (-4049 (((-57) (-823)) 17)) (-3608 (((-638 (-1152)) (-1152)) 28)) (-2762 (((-638 (-1152))) 27))) 
-(((-830) (-10 -7 (-15 -4049 ((-57) (-823))) (-15 -3833 ((-57) (-1152))) (-15 -4047 ((-57) (-1152))) (-15 -2762 ((-638 (-1152)))) (-15 -3608 ((-638 (-1152)) (-1152))) (-15 -4088 ((-121) (-1152))) (-15 -4409 ((-121) (-1152) (-1152))) (-15 -3715 ((-307) (-1152) (-1152))))) (T -830)) 
-((-3715 (*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-307)) (-5 *1 (-830)))) (-4409 (*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-121)) (-5 *1 (-830)))) (-4088 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-121)) (-5 *1 (-830)))) (-3608 (*1 *2 *3) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-830)) (-5 *3 (-1152)))) (-2762 (*1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-830)))) (-4047 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-57)) (-5 *1 (-830)))) (-3833 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-57)) (-5 *1 (-830)))) (-4049 (*1 *2 *3) (-12 (-5 *3 (-823)) (-5 *2 (-57)) (-5 *1 (-830))))) 
-(-10 -7 (-15 -4049 ((-57) (-823))) (-15 -3833 ((-57) (-1152))) (-15 -4047 ((-57) (-1152))) (-15 -2762 ((-638 (-1152)))) (-15 -3608 ((-638 (-1152)) (-1152))) (-15 -4088 ((-121) (-1152))) (-15 -4409 ((-121) (-1152) (-1152))) (-15 -3715 ((-307) (-1152) (-1152)))) 
-((-2262 (((-121) $ $) 18)) (-3518 (($ |#1| $) 72) (($ $ |#1|) 71) (($ $ $) 70)) (-3710 (($ $ $) 68)) (-3771 (((-121) $ $) 69)) (-1946 (((-121) $ (-769)) 8)) (-4462 (($ (-638 |#1|)) 64) (($) 63)) (-1550 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-3259 (($ $) 58)) (-1643 (($ $) 55 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ |#1| $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4602)))) (-3445 (($ |#1| $) 54 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4602)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-1771 ((|#1| $) 74)) (-3279 (($ $ $) 77)) (-4475 (($ $ $) 76)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-4238 ((|#1| $) 75)) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22)) (-1931 (($ $ $) 65)) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37) (($ |#1| $ (-769)) 59)) (-2607 (((-1116) $) 21)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-4153 (((-638 (-2 (|:| -4320 |#1|) (|:| -1571 (-769)))) $) 57)) (-3982 (($ $ |#1|) 67) (($ $ $) 66)) (-1535 (($) 46) (($ (-638 |#1|)) 45)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 47)) (-3972 (((-856) $) 20)) (-1599 (($ (-638 |#1|)) 62) (($) 61)) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19)) (-1334 (((-121) $ $) 60)) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-831 |#1|) (-1290) (-848)) (T -831)) 
-((-1771 (*1 *2 *1) (-12 (-4 *1 (-831 *2)) (-4 *2 (-848))))) 
-(-13 (-732 |t#1|) (-976 |t#1|) (-10 -8 (-15 -1771 (|t#1| $)))) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) . T) ((-612 (-856)) . T) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-229 |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-690 |#1|) . T) ((-732 |#1|) . T) ((-976 |#1|) . T) ((-1095 |#1|) . T) ((-1098) . T) ((-1204) . T)) 
-((-3115 (((-1264) (-1116) (-1116)) 47)) (-2677 (((-1264) (-822) (-57)) 44)) (-2810 (((-57) (-822)) 16))) 
-(((-832) (-10 -7 (-15 -2810 ((-57) (-822))) (-15 -2677 ((-1264) (-822) (-57))) (-15 -3115 ((-1264) (-1116) (-1116))))) (T -832)) 
-((-3115 (*1 *2 *3 *3) (-12 (-5 *3 (-1116)) (-5 *2 (-1264)) (-5 *1 (-832)))) (-2677 (*1 *2 *3 *4) (-12 (-5 *3 (-822)) (-5 *4 (-57)) (-5 *2 (-1264)) (-5 *1 (-832)))) (-2810 (*1 *2 *3) (-12 (-5 *3 (-822)) (-5 *2 (-57)) (-5 *1 (-832))))) 
-(-10 -7 (-15 -2810 ((-57) (-822))) (-15 -2677 ((-1264) (-822) (-57))) (-15 -3115 ((-1264) (-1116) (-1116)))) 
-((-3828 (((-834 |#2|) (-1 |#2| |#1|) (-834 |#1|) (-834 |#2|)) 12) (((-834 |#2|) (-1 |#2| |#1|) (-834 |#1|)) 13))) 
-(((-833 |#1| |#2|) (-10 -7 (-15 -3828 ((-834 |#2|) (-1 |#2| |#1|) (-834 |#1|))) (-15 -3828 ((-834 |#2|) (-1 |#2| |#1|) (-834 |#1|) (-834 |#2|)))) (-1098) (-1098)) (T -833)) 
-((-3828 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-834 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-834 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *1 (-833 *5 *6)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-834 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-834 *6)) (-5 *1 (-833 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-834 |#2|) (-1 |#2| |#1|) (-834 |#1|))) (-15 -3828 ((-834 |#2|) (-1 |#2| |#1|) (-834 |#1|) (-834 |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL (|has| |#1| (-21)))) (-1572 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-2433 (((-572) $) NIL (|has| |#1| (-846)))) (-2211 (($) NIL (|has| |#1| (-21)) CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 15)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 9)) (-1799 (((-3 $ "failed") $) 40 (|has| |#1| (-846)))) (-2956 (((-3 (-413 (-572)) "failed") $) 48 (|has| |#1| (-554)))) (-3175 (((-121) $) 43 (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) 45 (|has| |#1| (-554)))) (-1908 (((-121) $) NIL (|has| |#1| (-846)))) (-3893 (((-121) $) NIL (|has| |#1| (-846)))) (-4472 (((-121) $) NIL (|has| |#1| (-846)))) (-1771 (($ $ $) NIL (|has| |#1| (-846)))) (-4238 (($ $ $) NIL (|has| |#1| (-846)))) (-1658 (((-1152) $) NIL)) (-1757 (($) 13)) (-3048 (((-121) $) 12)) (-2607 (((-1116) $) NIL)) (-3508 (((-121) $) 11)) (-3972 (((-856) $) 18) (($ (-413 (-572))) NIL (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) 8) (($ (-572)) NIL (-1841 (|has| |#1| (-846)) (|has| |#1| (-1044 (-572)))))) (-2140 (((-769)) 34 (|has| |#1| (-846)))) (-2264 (($ $) NIL (|has| |#1| (-846)))) (-4174 (($ $ (-923)) NIL (|has| |#1| (-846))) (($ $ (-769)) NIL (|has| |#1| (-846)))) (-2378 (($) 22 (|has| |#1| (-21)) CONST)) (-3255 (($) 31 (|has| |#1| (-846)) CONST)) (-1349 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1324 (((-121) $ $) 20)) (-1343 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1334 (((-121) $ $) 42 (|has| |#1| (-846)))) (-1373 (($ $ $) NIL (|has| |#1| (-21))) (($ $) 27 (|has| |#1| (-21)))) (-1367 (($ $ $) 29 (|has| |#1| (-21)))) (** (($ $ (-923)) NIL (|has| |#1| (-846))) (($ $ (-769)) NIL (|has| |#1| (-846)))) (* (($ $ $) 37 (|has| |#1| (-846))) (($ (-572) $) 25 (|has| |#1| (-21))) (($ (-769) $) NIL (|has| |#1| (-21))) (($ (-923) $) NIL (|has| |#1| (-21))))) 
-(((-834 |#1|) (-13 (-1098) (-417 |#1|) (-10 -8 (-15 -1757 ($)) (-15 -3508 ((-121) $)) (-15 -3048 ((-121) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-846)) (-6 (-846)) |noBranch|) (IF (|has| |#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|))) (-1098)) (T -834)) 
-((-1757 (*1 *1) (-12 (-5 *1 (-834 *2)) (-4 *2 (-1098)))) (-3508 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-834 *3)) (-4 *3 (-1098)))) (-3048 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-834 *3)) (-4 *3 (-1098)))) (-3175 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-834 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) (-4299 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-834 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) (-2956 (*1 *2 *1) (|partial| -12 (-5 *2 (-413 (-572))) (-5 *1 (-834 *3)) (-4 *3 (-554)) (-4 *3 (-1098))))) 
-(-13 (-1098) (-417 |#1|) (-10 -8 (-15 -1757 ($)) (-15 -3508 ((-121) $)) (-15 -3048 ((-121) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-846)) (-6 (-846)) |noBranch|) (IF (|has| |#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-123) "failed") $) NIL)) (-1318 ((|#1| $) NIL) (((-123) $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-1464 ((|#1| (-123) |#1|) NIL)) (-3893 (((-121) $) NIL)) (-3708 (($ |#1| (-366 (-123))) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1625 (($ $ (-1 |#1| |#1|)) NIL)) (-3949 (($ $ (-1 |#1| |#1|)) NIL)) (-3277 ((|#1| $ |#1|) NIL)) (-1739 ((|#1| |#1|) NIL (|has| |#1| (-174)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-123)) NIL)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-2527 (($ $) NIL (|has| |#1| (-174))) (($ $ $) NIL (|has| |#1| (-174)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ (-123) (-572)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL (|has| |#1| (-174))) (($ $ |#1|) NIL (|has| |#1| (-174))))) 
-(((-835 |#1|) (-13 (-1054) (-1044 |#1|) (-1044 (-123)) (-283 |#1| |#1|) (-10 -8 (IF (|has| |#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |#1| (-174)) (PROGN (-6 (-43 |#1|)) (-15 -2527 ($ $)) (-15 -2527 ($ $ $)) (-15 -1739 (|#1| |#1|))) |noBranch|) (-15 -3949 ($ $ (-1 |#1| |#1|))) (-15 -1625 ($ $ (-1 |#1| |#1|))) (-15 ** ($ (-123) (-572))) (-15 ** ($ $ (-572))) (-15 -1464 (|#1| (-123) |#1|)) (-15 -3708 ($ |#1| (-366 (-123)))))) (-1054)) (T -835)) 
-((-2527 (*1 *1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-174)) (-4 *2 (-1054)))) (-2527 (*1 *1 *1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-174)) (-4 *2 (-1054)))) (-1739 (*1 *2 *2) (-12 (-5 *1 (-835 *2)) (-4 *2 (-174)) (-4 *2 (-1054)))) (-3949 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-835 *3)))) (-1625 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-835 *3)))) (** (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-572)) (-5 *1 (-835 *4)) (-4 *4 (-1054)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-835 *3)) (-4 *3 (-1054)))) (-1464 (*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-5 *1 (-835 *2)) (-4 *2 (-1054)))) (-3708 (*1 *1 *2 *3) (-12 (-5 *3 (-366 (-123))) (-5 *1 (-835 *2)) (-4 *2 (-1054))))) 
-(-13 (-1054) (-1044 |#1|) (-1044 (-123)) (-283 |#1| |#1|) (-10 -8 (IF (|has| |#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |#1| (-174)) (PROGN (-6 (-43 |#1|)) (-15 -2527 ($ $)) (-15 -2527 ($ $ $)) (-15 -1739 (|#1| |#1|))) |noBranch|) (-15 -3949 ($ $ (-1 |#1| |#1|))) (-15 -1625 ($ $ (-1 |#1| |#1|))) (-15 ** ($ (-123) (-572))) (-15 ** ($ $ (-572))) (-15 -1464 (|#1| (-123) |#1|)) (-15 -3708 ($ |#1| (-366 (-123)))))) 
-((-3809 (((-207 (-515)) (-1152)) 8))) 
-(((-836) (-10 -7 (-15 -3809 ((-207 (-515)) (-1152))))) (T -836)) 
-((-3809 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-207 (-515))) (-5 *1 (-836))))) 
-(-10 -7 (-15 -3809 ((-207 (-515)) (-1152)))) 
-((-2262 (((-121) $ $) 7)) (-3690 (((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 13) (((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 12)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 15) (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 14)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-837) (-1290)) (T -837)) 
-((-1540 (*1 *2 *3 *4) (-12 (-4 *1 (-837)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)))))) (-1540 (*1 *2 *3 *4) (-12 (-4 *1 (-837)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)))))) (-3690 (*1 *2 *3) (-12 (-4 *1 (-837)) (-5 *3 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *2 (-1042)))) (-3690 (*1 *2 *3) (-12 (-4 *1 (-837)) (-5 *3 (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (-5 *2 (-1042))))) 
-(-13 (-1098) (-10 -7 (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) (-15 -3690 ((-1042) (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) (-15 -3690 ((-1042) (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2375 (((-1042) (-638 (-312 (-385))) (-638 (-385))) 143) (((-1042) (-312 (-385)) (-638 (-385))) 141) (((-1042) (-312 (-385)) (-638 (-385)) (-638 (-841 (-385))) (-638 (-841 (-385)))) 140) (((-1042) (-312 (-385)) (-638 (-385)) (-638 (-841 (-385))) (-638 (-312 (-385))) (-638 (-841 (-385)))) 139) (((-1042) (-839)) 112) (((-1042) (-839) (-1066)) 111)) (-1540 (((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-839) (-1066)) 76) (((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-839)) 78)) (-4542 (((-1042) (-638 (-312 (-385))) (-638 (-385))) 144) (((-1042) (-839)) 128))) 
-(((-838) (-10 -7 (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-839))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-839) (-1066))) (-15 -2375 ((-1042) (-839) (-1066))) (-15 -2375 ((-1042) (-839))) (-15 -4542 ((-1042) (-839))) (-15 -2375 ((-1042) (-312 (-385)) (-638 (-385)) (-638 (-841 (-385))) (-638 (-312 (-385))) (-638 (-841 (-385))))) (-15 -2375 ((-1042) (-312 (-385)) (-638 (-385)) (-638 (-841 (-385))) (-638 (-841 (-385))))) (-15 -2375 ((-1042) (-312 (-385)) (-638 (-385)))) (-15 -2375 ((-1042) (-638 (-312 (-385))) (-638 (-385)))) (-15 -4542 ((-1042) (-638 (-312 (-385))) (-638 (-385)))))) (T -838)) 
-((-4542 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-312 (-385)))) (-5 *4 (-638 (-385))) (-5 *2 (-1042)) (-5 *1 (-838)))) (-2375 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-312 (-385)))) (-5 *4 (-638 (-385))) (-5 *2 (-1042)) (-5 *1 (-838)))) (-2375 (*1 *2 *3 *4) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-385))) (-5 *2 (-1042)) (-5 *1 (-838)))) (-2375 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-385))) (-5 *5 (-638 (-841 (-385)))) (-5 *2 (-1042)) (-5 *1 (-838)))) (-2375 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-638 (-385))) (-5 *5 (-638 (-841 (-385)))) (-5 *6 (-638 (-312 (-385)))) (-5 *3 (-312 (-385))) (-5 *2 (-1042)) (-5 *1 (-838)))) (-4542 (*1 *2 *3) (-12 (-5 *3 (-839)) (-5 *2 (-1042)) (-5 *1 (-838)))) (-2375 (*1 *2 *3) (-12 (-5 *3 (-839)) (-5 *2 (-1042)) (-5 *1 (-838)))) (-2375 (*1 *2 *3 *4) (-12 (-5 *3 (-839)) (-5 *4 (-1066)) (-5 *2 (-1042)) (-5 *1 (-838)))) (-1540 (*1 *2 *3 *4) (-12 (-5 *3 (-839)) (-5 *4 (-1066)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-838)))) (-1540 (*1 *2 *3) (-12 (-5 *3 (-839)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-838))))) 
-(-10 -7 (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-839))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-839) (-1066))) (-15 -2375 ((-1042) (-839) (-1066))) (-15 -2375 ((-1042) (-839))) (-15 -4542 ((-1042) (-839))) (-15 -2375 ((-1042) (-312 (-385)) (-638 (-385)) (-638 (-841 (-385))) (-638 (-312 (-385))) (-638 (-841 (-385))))) (-15 -2375 ((-1042) (-312 (-385)) (-638 (-385)) (-638 (-841 (-385))) (-638 (-841 (-385))))) (-15 -2375 ((-1042) (-312 (-385)) (-638 (-385)))) (-15 -2375 ((-1042) (-638 (-312 (-385))) (-638 (-385)))) (-15 -4542 ((-1042) (-638 (-312 (-385))) (-638 (-385))))) 
-((-2262 (((-121) $ $) NIL)) (-1318 (((-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) $) 15)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 14) (($ (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) 8) (($ (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) 10) (($ (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))) 12)) (-1324 (((-121) $ $) NIL))) 
-(((-839) (-13 (-1098) (-10 -8 (-15 -3972 ($ (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))))) (-15 -3972 ($ (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) (-15 -3972 ($ (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))))) (-15 -3972 ((-856) $)) (-15 -1318 ((-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) $))))) (T -839)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-839)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (-5 *1 (-839)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *1 (-839)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))) (-5 *1 (-839)))) (-1318 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))) (-5 *1 (-839))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217))))))) (-15 -3972 ($ (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) (-15 -3972 ($ (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))))) (-15 -3972 ((-856) $)) (-15 -1318 ((-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217)))))) $)))) 
-((-3828 (((-841 |#2|) (-1 |#2| |#1|) (-841 |#1|) (-841 |#2|) (-841 |#2|)) 13) (((-841 |#2|) (-1 |#2| |#1|) (-841 |#1|)) 14))) 
-(((-840 |#1| |#2|) (-10 -7 (-15 -3828 ((-841 |#2|) (-1 |#2| |#1|) (-841 |#1|))) (-15 -3828 ((-841 |#2|) (-1 |#2| |#1|) (-841 |#1|) (-841 |#2|) (-841 |#2|)))) (-1098) (-1098)) (T -840)) 
-((-3828 (*1 *2 *3 *4 *2 *2) (-12 (-5 *2 (-841 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-841 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *1 (-840 *5 *6)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-841 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-841 *6)) (-5 *1 (-840 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-841 |#2|) (-1 |#2| |#1|) (-841 |#1|))) (-15 -3828 ((-841 |#2|) (-1 |#2| |#1|) (-841 |#1|) (-841 |#2|) (-841 |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL (|has| |#1| (-21)))) (-4117 (((-1116) $) 24)) (-1572 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-2433 (((-572) $) NIL (|has| |#1| (-846)))) (-2211 (($) NIL (|has| |#1| (-21)) CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 16)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 9)) (-1799 (((-3 $ "failed") $) 47 (|has| |#1| (-846)))) (-2956 (((-3 (-413 (-572)) "failed") $) 54 (|has| |#1| (-554)))) (-3175 (((-121) $) 49 (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) 52 (|has| |#1| (-554)))) (-1908 (((-121) $) NIL (|has| |#1| (-846)))) (-3355 (($) 13)) (-3893 (((-121) $) NIL (|has| |#1| (-846)))) (-4472 (((-121) $) NIL (|has| |#1| (-846)))) (-3350 (($) 14)) (-1771 (($ $ $) NIL (|has| |#1| (-846)))) (-4238 (($ $ $) NIL (|has| |#1| (-846)))) (-1658 (((-1152) $) NIL)) (-3048 (((-121) $) 12)) (-2607 (((-1116) $) NIL)) (-3508 (((-121) $) 11)) (-3972 (((-856) $) 22) (($ (-413 (-572))) NIL (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) 8) (($ (-572)) NIL (-1841 (|has| |#1| (-846)) (|has| |#1| (-1044 (-572)))))) (-2140 (((-769)) 41 (|has| |#1| (-846)))) (-2264 (($ $) NIL (|has| |#1| (-846)))) (-4174 (($ $ (-923)) NIL (|has| |#1| (-846))) (($ $ (-769)) NIL (|has| |#1| (-846)))) (-2378 (($) 29 (|has| |#1| (-21)) CONST)) (-3255 (($) 38 (|has| |#1| (-846)) CONST)) (-1349 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1324 (((-121) $ $) 27)) (-1343 (((-121) $ $) NIL (|has| |#1| (-846)))) (-1334 (((-121) $ $) 48 (|has| |#1| (-846)))) (-1373 (($ $ $) NIL (|has| |#1| (-21))) (($ $) 34 (|has| |#1| (-21)))) (-1367 (($ $ $) 36 (|has| |#1| (-21)))) (** (($ $ (-923)) NIL (|has| |#1| (-846))) (($ $ (-769)) NIL (|has| |#1| (-846)))) (* (($ $ $) 44 (|has| |#1| (-846))) (($ (-572) $) 32 (|has| |#1| (-21))) (($ (-769) $) NIL (|has| |#1| (-21))) (($ (-923) $) NIL (|has| |#1| (-21))))) 
-(((-841 |#1|) (-13 (-1098) (-417 |#1|) (-10 -8 (-15 -3355 ($)) (-15 -3350 ($)) (-15 -3508 ((-121) $)) (-15 -3048 ((-121) $)) (-15 -4117 ((-1116) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-846)) (-6 (-846)) |noBranch|) (IF (|has| |#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|))) (-1098)) (T -841)) 
-((-3355 (*1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-1098)))) (-3350 (*1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-1098)))) (-3508 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-841 *3)) (-4 *3 (-1098)))) (-3048 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-841 *3)) (-4 *3 (-1098)))) (-4117 (*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-841 *3)) (-4 *3 (-1098)))) (-3175 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-841 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) (-4299 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-841 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) (-2956 (*1 *2 *1) (|partial| -12 (-5 *2 (-413 (-572))) (-5 *1 (-841 *3)) (-4 *3 (-554)) (-4 *3 (-1098))))) 
-(-13 (-1098) (-417 |#1|) (-10 -8 (-15 -3355 ($)) (-15 -3350 ($)) (-15 -3508 ((-121) $)) (-15 -3048 ((-121) $)) (-15 -4117 ((-1116) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-846)) (-6 (-846)) |noBranch|) (IF (|has| |#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|))) 
-((-2262 (((-121) $ $) 7)) (-1685 (((-769)) 19)) (-3286 (($) 22)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-3633 (((-923) $) 21)) (-1658 (((-1152) $) 9)) (-1763 (($ (-923)) 20)) (-2607 (((-1116) $) 10)) (-3587 (((-638 $)) 23)) (-3972 (((-856) $) 11)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17))) 
-(((-842) (-1290)) (T -842)) 
-NIL 
-(-13 (-848) (-374)) 
-(((-105) . T) ((-612 (-856)) . T) ((-374) . T) ((-848) . T) ((-1098) . T)) 
-((-3770 (((-121) (-1259 |#2|) (-1259 |#2|)) 17)) (-2176 (((-121) (-1259 |#2|) (-1259 |#2|)) 18)) (-2975 (((-121) (-1259 |#2|) (-1259 |#2|)) 14))) 
-(((-843 |#1| |#2|) (-10 -7 (-15 -2975 ((-121) (-1259 |#2|) (-1259 |#2|))) (-15 -3770 ((-121) (-1259 |#2|) (-1259 |#2|))) (-15 -2176 ((-121) (-1259 |#2|) (-1259 |#2|)))) (-769) (-793)) (T -843)) 
-((-2176 (*1 *2 *3 *3) (-12 (-5 *3 (-1259 *5)) (-4 *5 (-793)) (-5 *2 (-121)) (-5 *1 (-843 *4 *5)) (-14 *4 (-769)))) (-3770 (*1 *2 *3 *3) (-12 (-5 *3 (-1259 *5)) (-4 *5 (-793)) (-5 *2 (-121)) (-5 *1 (-843 *4 *5)) (-14 *4 (-769)))) (-2975 (*1 *2 *3 *3) (-12 (-5 *3 (-1259 *5)) (-4 *5 (-793)) (-5 *2 (-121)) (-5 *1 (-843 *4 *5)) (-14 *4 (-769))))) 
-(-10 -7 (-15 -2975 ((-121) (-1259 |#2|) (-1259 |#2|))) (-15 -3770 ((-121) (-1259 |#2|) (-1259 |#2|))) (-15 -2176 ((-121) (-1259 |#2|) (-1259 |#2|)))) 
-((-2262 (((-121) $ $) 7)) (-2211 (($) 23 T CONST)) (-1799 (((-3 $ "failed") $) 27)) (-3893 (((-121) $) 24)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-4174 (($ $ (-769)) 26) (($ $ (-923)) 21)) (-3255 (($) 22 T CONST)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (** (($ $ (-769)) 25) (($ $ (-923)) 20)) (* (($ $ $) 19))) 
-(((-844) (-1290)) (T -844)) 
-NIL 
-(-13 (-848) (-722)) 
-(((-105) . T) ((-612 (-856)) . T) ((-722) . T) ((-848) . T) ((-1110) . T) ((-1098) . T)) 
-((-2433 (((-572) $) 17)) (-1908 (((-121) $) 10)) (-4472 (((-121) $) 11)) (-2264 (($ $) 19))) 
-(((-845 |#1|) (-10 -8 (-15 -2264 (|#1| |#1|)) (-15 -2433 ((-572) |#1|)) (-15 -4472 ((-121) |#1|)) (-15 -1908 ((-121) |#1|))) (-846)) (T -845)) 
-NIL 
-(-10 -8 (-15 -2264 (|#1| |#1|)) (-15 -2433 ((-572) |#1|)) (-15 -4472 ((-121) |#1|)) (-15 -1908 ((-121) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 23)) (-1572 (((-3 $ "failed") $ $) 25)) (-2433 (((-572) $) 32)) (-2211 (($) 22 T CONST)) (-1799 (((-3 $ "failed") $) 38)) (-1908 (((-121) $) 34)) (-3893 (((-121) $) 41)) (-4472 (((-121) $) 33)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 44)) (-2140 (((-769)) 43)) (-2264 (($ $) 31)) (-4174 (($ $ (-769)) 39) (($ $ (-923)) 35)) (-2378 (($) 21 T CONST)) (-3255 (($) 42 T CONST)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17)) (-1373 (($ $ $) 27) (($ $) 26)) (-1367 (($ $ $) 19)) (** (($ $ (-769)) 40) (($ $ (-923)) 36)) (* (($ (-769) $) 24) (($ (-923) $) 20) (($ (-572) $) 28) (($ $ $) 37))) 
-(((-846) (-1290)) (T -846)) 
-((-1908 (*1 *2 *1) (-12 (-4 *1 (-846)) (-5 *2 (-121)))) (-4472 (*1 *2 *1) (-12 (-4 *1 (-846)) (-5 *2 (-121)))) (-2433 (*1 *2 *1) (-12 (-4 *1 (-846)) (-5 *2 (-572)))) (-2264 (*1 *1 *1) (-4 *1 (-846)))) 
-(-13 (-792) (-1054) (-722) (-10 -8 (-15 -1908 ((-121) $)) (-15 -4472 ((-121) $)) (-15 -2433 ((-572) $)) (-15 -2264 ($ $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-792) . T) ((-793) . T) ((-795) . T) ((-796) . T) ((-848) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-1771 (($ $ $) 10)) (-4238 (($ $ $) 9)) (-1349 (((-121) $ $) 12)) (-1338 (((-121) $ $) 11)) (-1343 (((-121) $ $) 13))) 
-(((-847 |#1|) (-10 -8 (-15 -1771 (|#1| |#1| |#1|)) (-15 -4238 (|#1| |#1| |#1|)) (-15 -1343 ((-121) |#1| |#1|)) (-15 -1349 ((-121) |#1| |#1|)) (-15 -1338 ((-121) |#1| |#1|))) (-848)) (T -847)) 
-NIL 
-(-10 -8 (-15 -1771 (|#1| |#1| |#1|)) (-15 -4238 (|#1| |#1| |#1|)) (-15 -1343 ((-121) |#1| |#1|)) (-15 -1349 ((-121) |#1| |#1|)) (-15 -1338 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1771 (($ $ $) 12)) (-4238 (($ $ $) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1349 (((-121) $ $) 15)) (-1338 (((-121) $ $) 16)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 14)) (-1334 (((-121) $ $) 17))) 
-(((-848) (-1290)) (T -848)) 
-((-1334 (*1 *2 *1 *1) (-12 (-4 *1 (-848)) (-5 *2 (-121)))) (-1338 (*1 *2 *1 *1) (-12 (-4 *1 (-848)) (-5 *2 (-121)))) (-1349 (*1 *2 *1 *1) (-12 (-4 *1 (-848)) (-5 *2 (-121)))) (-1343 (*1 *2 *1 *1) (-12 (-4 *1 (-848)) (-5 *2 (-121)))) (-4238 (*1 *1 *1 *1) (-4 *1 (-848))) (-1771 (*1 *1 *1 *1) (-4 *1 (-848)))) 
-(-13 (-1098) (-10 -8 (-15 -1334 ((-121) $ $)) (-15 -1338 ((-121) $ $)) (-15 -1349 ((-121) $ $)) (-15 -1343 ((-121) $ $)) (-15 -4238 ($ $ $)) (-15 -1771 ($ $ $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-1887 (($ $ $) 45)) (-3467 (($ $ $) 44)) (-2349 (($ $ $) 42)) (-3296 (($ $ $) 51)) (-2366 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 46)) (-4549 (((-3 $ "failed") $ $) 49)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 |#2| "failed") $) 25)) (-3988 (($ $) 35)) (-3197 (($ $ $) 39)) (-3874 (($ $ $) 38)) (-4008 (($ $ $) 47)) (-3373 (($ $ $) 53)) (-2123 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 41)) (-2955 (((-3 $ "failed") $ $) 48)) (-1803 (((-3 $ "failed") $ |#2|) 28)) (-3694 ((|#2| $) 32)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 (-572))) NIL) (($ |#2|) 12)) (-3193 (((-638 |#2|) $) 18)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 22))) 
-(((-849 |#1| |#2|) (-10 -8 (-15 -4008 (|#1| |#1| |#1|)) (-15 -2366 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2307 |#1|)) |#1| |#1|)) (-15 -3296 (|#1| |#1| |#1|)) (-15 -4549 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1887 (|#1| |#1| |#1|)) (-15 -3467 (|#1| |#1| |#1|)) (-15 -2349 (|#1| |#1| |#1|)) (-15 -2123 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2307 |#1|)) |#1| |#1|)) (-15 -3373 (|#1| |#1| |#1|)) (-15 -2955 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3197 (|#1| |#1| |#1|)) (-15 -3874 (|#1| |#1| |#1|)) (-15 -3988 (|#1| |#1|)) (-15 -3694 (|#2| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#2|)) (-15 -3193 ((-638 |#2|) |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|)) (-15 -3972 ((-856) |#1|))) (-850 |#2|) (-1054)) (T -849)) 
-NIL 
-(-10 -8 (-15 -4008 (|#1| |#1| |#1|)) (-15 -2366 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2307 |#1|)) |#1| |#1|)) (-15 -3296 (|#1| |#1| |#1|)) (-15 -4549 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1887 (|#1| |#1| |#1|)) (-15 -3467 (|#1| |#1| |#1|)) (-15 -2349 (|#1| |#1| |#1|)) (-15 -2123 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2307 |#1|)) |#1| |#1|)) (-15 -3373 (|#1| |#1| |#1|)) (-15 -2955 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3197 (|#1| |#1| |#1|)) (-15 -3874 (|#1| |#1| |#1|)) (-15 -3988 (|#1| |#1|)) (-15 -3694 (|#2| |#1|)) (-15 -1803 ((-3 |#1| "failed") |#1| |#2|)) (-15 -3193 ((-638 |#2|) |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|)) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1887 (($ $ $) 44 (|has| |#1| (-368)))) (-3467 (($ $ $) 45 (|has| |#1| (-368)))) (-2349 (($ $ $) 47 (|has| |#1| (-368)))) (-3296 (($ $ $) 42 (|has| |#1| (-368)))) (-2366 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 41 (|has| |#1| (-368)))) (-4549 (((-3 $ "failed") $ $) 43 (|has| |#1| (-368)))) (-4046 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 46 (|has| |#1| (-368)))) (-3376 (((-3 (-572) "failed") $) 73 (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 71 (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 68)) (-1318 (((-572) $) 74 (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) 72 (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 67)) (-4383 (($ $) 63)) (-1799 (((-3 $ "failed") $) 33)) (-3988 (($ $) 54 (|has| |#1| (-457)))) (-3893 (((-121) $) 30)) (-4328 (($ |#1| (-769)) 61)) (-4441 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 56 (|has| |#1| (-562)))) (-2196 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 57 (|has| |#1| (-562)))) (-1784 (((-769) $) 65)) (-3197 (($ $ $) 51 (|has| |#1| (-368)))) (-3874 (($ $ $) 52 (|has| |#1| (-368)))) (-4008 (($ $ $) 40 (|has| |#1| (-368)))) (-3373 (($ $ $) 49 (|has| |#1| (-368)))) (-2123 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 48 (|has| |#1| (-368)))) (-2955 (((-3 $ "failed") $ $) 50 (|has| |#1| (-368)))) (-3230 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 53 (|has| |#1| (-368)))) (-4373 ((|#1| $) 64)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ |#1|) 58 (|has| |#1| (-562)))) (-4316 (((-769) $) 66)) (-3694 ((|#1| $) 55 (|has| |#1| (-457)))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 70 (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) 69)) (-3193 (((-638 |#1|) $) 60)) (-1958 ((|#1| $ (-769)) 62)) (-2140 (((-769)) 28)) (-1591 ((|#1| $ |#1| |#1|) 59)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 76) (($ |#1| $) 75))) 
-(((-850 |#1|) (-1290) (-1054)) (T -850)) 
-((-4316 (*1 *2 *1) (-12 (-4 *1 (-850 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) (-1784 (*1 *2 *1) (-12 (-4 *1 (-850 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) (-4373 (*1 *2 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)))) (-4383 (*1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)))) (-1958 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-850 *2)) (-4 *2 (-1054)))) (-4328 (*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-850 *2)) (-4 *2 (-1054)))) (-3193 (*1 *2 *1) (-12 (-4 *1 (-850 *3)) (-4 *3 (-1054)) (-5 *2 (-638 *3)))) (-1591 (*1 *2 *1 *2 *2) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)))) (-1803 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-562)))) (-2196 (*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-850 *3)))) (-4441 (*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-850 *3)))) (-3694 (*1 *2 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-457)))) (-3988 (*1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-457)))) (-3230 (*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-850 *3)))) (-3874 (*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-3197 (*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-2955 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-3373 (*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-2123 (*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2307 *1))) (-4 *1 (-850 *3)))) (-2349 (*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-4046 (*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-850 *3)))) (-3467 (*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-1887 (*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-4549 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-3296 (*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-2366 (*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2307 *1))) (-4 *1 (-850 *3)))) (-4008 (*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(-13 (-1054) (-120 |t#1| |t#1|) (-417 |t#1|) (-10 -8 (-15 -4316 ((-769) $)) (-15 -1784 ((-769) $)) (-15 -4373 (|t#1| $)) (-15 -4383 ($ $)) (-15 -1958 (|t#1| $ (-769))) (-15 -4328 ($ |t#1| (-769))) (-15 -3193 ((-638 |t#1|) $)) (-15 -1591 (|t#1| $ |t#1| |t#1|)) (IF (|has| |t#1| (-174)) (-6 (-43 |t#1|)) |noBranch|) (IF (|has| |t#1| (-562)) (PROGN (-15 -1803 ((-3 $ "failed") $ |t#1|)) (-15 -2196 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -4441 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $))) |noBranch|) (IF (|has| |t#1| (-457)) (PROGN (-15 -3694 (|t#1| $)) (-15 -3988 ($ $))) |noBranch|) (IF (|has| |t#1| (-368)) (PROGN (-15 -3230 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -3874 ($ $ $)) (-15 -3197 ($ $ $)) (-15 -2955 ((-3 $ "failed") $ $)) (-15 -3373 ($ $ $)) (-15 -2123 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $)) (-15 -2349 ($ $ $)) (-15 -4046 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -3467 ($ $ $)) (-15 -1887 ($ $ $)) (-15 -4549 ((-3 $ "failed") $ $)) (-15 -3296 ($ $ $)) (-15 -2366 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $)) (-15 -4008 ($ $ $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-174)) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-417 |#1|) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 |#1|) |has| |#1| (-174)) ((-722) . T) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1060 |#1|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3463 ((|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|)) 20)) (-4046 (((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|)) 43 (|has| |#1| (-368)))) (-4441 (((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|)) 40 (|has| |#1| (-562)))) (-2196 (((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|)) 39 (|has| |#1| (-562)))) (-3230 (((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|)) 42 (|has| |#1| (-368)))) (-1591 ((|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|)) 31))) 
-(((-851 |#1| |#2|) (-10 -7 (-15 -3463 (|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|))) (-15 -1591 (|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|))) (IF (|has| |#1| (-562)) (PROGN (-15 -2196 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -4441 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-15 -3230 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -4046 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|)) (-1054) (-850 |#1|)) (T -851)) 
-((-4046 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-851 *5 *3)) (-4 *3 (-850 *5)))) (-3230 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-851 *5 *3)) (-4 *3 (-850 *5)))) (-4441 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-562)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-851 *5 *3)) (-4 *3 (-850 *5)))) (-2196 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-562)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-851 *5 *3)) (-4 *3 (-850 *5)))) (-1591 (*1 *2 *3 *2 *2 *4 *5) (-12 (-5 *4 (-101 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-1054)) (-5 *1 (-851 *2 *3)) (-4 *3 (-850 *2)))) (-3463 (*1 *2 *2 *2 *3 *4) (-12 (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-1054)) (-5 *1 (-851 *5 *2)) (-4 *2 (-850 *5))))) 
-(-10 -7 (-15 -3463 (|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|))) (-15 -1591 (|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|))) (IF (|has| |#1| (-562)) (PROGN (-15 -2196 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -4441 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-15 -3230 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -4046 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1887 (($ $ $) NIL (|has| |#1| (-368)))) (-3467 (($ $ $) NIL (|has| |#1| (-368)))) (-2349 (($ $ $) NIL (|has| |#1| (-368)))) (-3296 (($ $ $) NIL (|has| |#1| (-368)))) (-2366 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-4549 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-4046 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 25 (|has| |#1| (-368)))) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457)))) (-2147 (((-856) $ (-856)) NIL)) (-3893 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) NIL)) (-4441 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 21 (|has| |#1| (-562)))) (-2196 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 19 (|has| |#1| (-562)))) (-1784 (((-769) $) NIL)) (-3197 (($ $ $) NIL (|has| |#1| (-368)))) (-3874 (($ $ $) NIL (|has| |#1| (-368)))) (-4008 (($ $ $) NIL (|has| |#1| (-368)))) (-3373 (($ $ $) NIL (|has| |#1| (-368)))) (-2123 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-2955 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-3230 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 23 (|has| |#1| (-368)))) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562)))) (-4316 (((-769) $) NIL)) (-3694 ((|#1| $) NIL (|has| |#1| (-457)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#1| (-1044 (-413 (-572))))) (($ |#1|) NIL)) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) NIL)) (-2140 (((-769)) NIL)) (-1591 ((|#1| $ |#1| |#1|) 15)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 13) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-852 |#1| |#2| |#3|) (-13 (-850 |#1|) (-10 -8 (-15 -2147 ((-856) $ (-856))))) (-1054) (-101 |#1|) (-1 |#1| |#1|)) (T -852)) 
-((-2147 (*1 *2 *1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-852 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-101 *3)) (-14 *5 (-1 *3 *3))))) 
-(-13 (-850 |#1|) (-10 -8 (-15 -2147 ((-856) $ (-856))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1887 (($ $ $) NIL (|has| |#2| (-368)))) (-3467 (($ $ $) NIL (|has| |#2| (-368)))) (-2349 (($ $ $) NIL (|has| |#2| (-368)))) (-3296 (($ $ $) NIL (|has| |#2| (-368)))) (-2366 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#2| (-368)))) (-4549 (((-3 $ "failed") $ $) NIL (|has| |#2| (-368)))) (-4046 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-368)))) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 |#2| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) ((|#2| $) NIL)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#2| (-457)))) (-3893 (((-121) $) NIL)) (-4328 (($ |#2| (-769)) 16)) (-4441 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-562)))) (-2196 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-562)))) (-1784 (((-769) $) NIL)) (-3197 (($ $ $) NIL (|has| |#2| (-368)))) (-3874 (($ $ $) NIL (|has| |#2| (-368)))) (-4008 (($ $ $) NIL (|has| |#2| (-368)))) (-3373 (($ $ $) NIL (|has| |#2| (-368)))) (-2123 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#2| (-368)))) (-2955 (((-3 $ "failed") $ $) NIL (|has| |#2| (-368)))) (-3230 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-368)))) (-4373 ((|#2| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562)))) (-4316 (((-769) $) NIL)) (-3694 ((|#2| $) NIL (|has| |#2| (-457)))) (-3972 (((-856) $) 23) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#2| (-1044 (-413 (-572))))) (($ |#2|) NIL) (($ (-1255 |#1|)) 18)) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-769)) NIL)) (-2140 (((-769)) NIL)) (-1591 ((|#2| $ |#2| |#2|) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) 13 T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
-(((-853 |#1| |#2| |#3| |#4|) (-13 (-850 |#2|) (-10 -8 (-15 -3972 ($ (-1255 |#1|))))) (-1170) (-1054) (-101 |#2|) (-1 |#2| |#2|)) (T -853)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *3)) (-14 *3 (-1170)) (-5 *1 (-853 *3 *4 *5 *6)) (-4 *4 (-1054)) (-14 *5 (-101 *4)) (-14 *6 (-1 *4 *4))))) 
-(-13 (-850 |#2|) (-10 -8 (-15 -3972 ($ (-1255 |#1|))))) 
-((-3995 ((|#1| (-769) |#1|) 35 (|has| |#1| (-43 (-413 (-572)))))) (-3388 ((|#1| (-769) (-769) |#1|) 27) ((|#1| (-769) |#1|) 20)) (-3404 ((|#1| (-769) |#1|) 31)) (-3294 ((|#1| (-769) |#1|) 29)) (-3297 ((|#1| (-769) |#1|) 28))) 
-(((-854 |#1|) (-10 -7 (-15 -3297 (|#1| (-769) |#1|)) (-15 -3294 (|#1| (-769) |#1|)) (-15 -3404 (|#1| (-769) |#1|)) (-15 -3388 (|#1| (-769) |#1|)) (-15 -3388 (|#1| (-769) (-769) |#1|)) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -3995 (|#1| (-769) |#1|)) |noBranch|)) (-174)) (T -854)) 
-((-3995 (*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-174)))) (-3388 (*1 *2 *3 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174)))) (-3388 (*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174)))) (-3404 (*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174)))) (-3294 (*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174)))) (-3297 (*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174))))) 
-(-10 -7 (-15 -3297 (|#1| (-769) |#1|)) (-15 -3294 (|#1| (-769) |#1|)) (-15 -3404 (|#1| (-769) |#1|)) (-15 -3388 (|#1| (-769) |#1|)) (-15 -3388 (|#1| (-769) (-769) |#1|)) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -3995 (|#1| (-769) |#1|)) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-2148 (((-572) $) 12)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 18) (($ (-572)) 11)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 8)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 9))) 
-(((-855) (-13 (-848) (-10 -8 (-15 -3972 ($ (-572))) (-15 -2148 ((-572) $))))) (T -855)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-855)))) (-2148 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-855))))) 
-(-13 (-848) (-10 -8 (-15 -3972 ($ (-572))) (-15 -2148 ((-572) $)))) 
-((-2262 (((-121) $ $) NIL)) (-4446 (($ $ $) 115)) (-3632 (((-572) $) 30) (((-572)) 35)) (-1808 (($ (-572)) 44)) (-3325 (($ $ $) 45) (($ (-638 $)) 76)) (-4309 (($ $ (-638 $)) 74)) (-3025 (((-572) $) 33)) (-1489 (($ $ $) 63)) (-4360 (($ $) 128) (($ $ $) 129) (($ $ $ $) 130)) (-4570 (((-572) $) 32)) (-4234 (($ $ $) 62)) (-4035 (($ $) 105)) (-4395 (($ $ $) 119)) (-2105 (($ (-638 $)) 52)) (-3206 (($ $ (-638 $)) 69)) (-3971 (($ (-572) (-572)) 46)) (-1431 (($ $) 116) (($ $ $) 117)) (-1862 (($ $ (-572)) 40) (($ $) 43)) (-2190 (($ $ $) 89)) (-1592 (($ $ $) 122)) (-2467 (($ $) 106)) (-2208 (($ $ $) 90)) (-2225 (($ $) 131) (($ $ $) 132) (($ $ $ $) 133)) (-1817 (((-1264) $) 8)) (-4200 (($ $) 109) (($ $ (-769)) 112)) (-2951 (($ $ $) 65)) (-3398 (($ $ $) 64)) (-2799 (($ $ (-638 $)) 100)) (-1737 (($ $ $) 104)) (-2090 (($ (-638 $)) 50)) (-3567 (($ $) 60) (($ (-638 $)) 61)) (-2559 (($ $ $) 113)) (-3546 (($ $) 107)) (-3357 (($ $ $) 118)) (-2147 (($ (-572)) 20) (($ (-1170)) 22) (($ (-1152)) 29) (($ (-217)) 24)) (-2468 (($ $ $) 93)) (-2959 (($ $) 94)) (-2518 (((-1264) (-1152)) 14)) (-3801 (($ (-1152)) 13)) (-3597 (($ (-638 (-638 $))) 48)) (-1866 (($ $ (-572)) 39) (($ $) 42)) (-1658 (((-1152) $) NIL)) (-1460 (($ $ $) 121)) (-3293 (($ $) 134) (($ $ $) 135) (($ $ $ $) 136)) (-3272 (((-121) $) 98)) (-2737 (($ $ (-638 $)) 102) (($ $ $ $) 103)) (-2254 (($ (-572)) 36)) (-1455 (((-572) $) 31) (((-572)) 34)) (-4539 (($ $ $) 37) (($ (-638 $)) 75)) (-2607 (((-1116) $) NIL)) (-1803 (($ $ $) 91)) (-1665 (($) 12)) (-3277 (($ $ (-638 $)) 99)) (-1436 (($ $) 108) (($ $ (-769)) 111)) (-1807 (($ $ $) 88)) (-3139 (($ $ (-769)) 127)) (-1507 (($ (-638 $)) 51)) (-3972 (((-856) $) 18)) (-1694 (($ $ (-572)) 38) (($ $) 41)) (-3407 (($ $) 58) (($ (-638 $)) 59)) (-1599 (($ $) 56) (($ (-638 $)) 57)) (-3497 (($ $) 114)) (-1636 (($ (-638 $)) 55)) (-3610 (($ $ $) 97)) (-3863 (($ $ $) 120)) (-4028 (($ $ $) 92)) (-1819 (($ $ $) 77)) (-2770 (($ $ $) 95) (($ $) 96)) (-1349 (($ $ $) 81)) (-1338 (($ $ $) 79)) (-1324 (((-121) $ $) 15) (($ $ $) 16)) (-1343 (($ $ $) 80)) (-1334 (($ $ $) 78)) (-1379 (($ $ $) 86)) (-1373 (($ $ $) 83) (($ $) 84)) (-1367 (($ $ $) 82)) (** (($ $ $) 87)) (* (($ $ $) 85))) 
-(((-856) (-13 (-1098) (-10 -8 (-15 -1817 ((-1264) $)) (-15 -3801 ($ (-1152))) (-15 -2518 ((-1264) (-1152))) (-15 -2147 ($ (-572))) (-15 -2147 ($ (-1170))) (-15 -2147 ($ (-1152))) (-15 -2147 ($ (-217))) (-15 -1665 ($)) (-15 -3632 ((-572) $)) (-15 -1455 ((-572) $)) (-15 -3632 ((-572))) (-15 -1455 ((-572))) (-15 -4570 ((-572) $)) (-15 -3025 ((-572) $)) (-15 -2254 ($ (-572))) (-15 -1808 ($ (-572))) (-15 -3971 ($ (-572) (-572))) (-15 -1866 ($ $ (-572))) (-15 -1862 ($ $ (-572))) (-15 -1694 ($ $ (-572))) (-15 -1866 ($ $)) (-15 -1862 ($ $)) (-15 -1694 ($ $)) (-15 -4539 ($ $ $)) (-15 -3325 ($ $ $)) (-15 -4539 ($ (-638 $))) (-15 -3325 ($ (-638 $))) (-15 -2799 ($ $ (-638 $))) (-15 -2737 ($ $ (-638 $))) (-15 -2737 ($ $ $ $)) (-15 -1737 ($ $ $)) (-15 -3272 ((-121) $)) (-15 -3277 ($ $ (-638 $))) (-15 -4035 ($ $)) (-15 -1460 ($ $ $)) (-15 -3497 ($ $)) (-15 -3597 ($ (-638 (-638 $)))) (-15 -4446 ($ $ $)) (-15 -1431 ($ $)) (-15 -1431 ($ $ $)) (-15 -3357 ($ $ $)) (-15 -4395 ($ $ $)) (-15 -3863 ($ $ $)) (-15 -1592 ($ $ $)) (-15 -3139 ($ $ (-769))) (-15 -3610 ($ $ $)) (-15 -4234 ($ $ $)) (-15 -1489 ($ $ $)) (-15 -3398 ($ $ $)) (-15 -2951 ($ $ $)) (-15 -3206 ($ $ (-638 $))) (-15 -4309 ($ $ (-638 $))) (-15 -2467 ($ $)) (-15 -1436 ($ $)) (-15 -1436 ($ $ (-769))) (-15 -4200 ($ $)) (-15 -4200 ($ $ (-769))) (-15 -3546 ($ $)) (-15 -2559 ($ $ $)) (-15 -4360 ($ $)) (-15 -4360 ($ $ $)) (-15 -4360 ($ $ $ $)) (-15 -2225 ($ $)) (-15 -2225 ($ $ $)) (-15 -2225 ($ $ $ $)) (-15 -3293 ($ $)) (-15 -3293 ($ $ $)) (-15 -3293 ($ $ $ $)) (-15 -1599 ($ $)) (-15 -1599 ($ (-638 $))) (-15 -3407 ($ $)) (-15 -3407 ($ (-638 $))) (-15 -3567 ($ $)) (-15 -3567 ($ (-638 $))) (-15 -2090 ($ (-638 $))) (-15 -1507 ($ (-638 $))) (-15 -2105 ($ (-638 $))) (-15 -1636 ($ (-638 $))) (-15 -1324 ($ $ $)) (-15 -1819 ($ $ $)) (-15 -1334 ($ $ $)) (-15 -1338 ($ $ $)) (-15 -1343 ($ $ $)) (-15 -1349 ($ $ $)) (-15 -1367 ($ $ $)) (-15 -1373 ($ $ $)) (-15 -1373 ($ $)) (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -1807 ($ $ $)) (-15 -2190 ($ $ $)) (-15 -2208 ($ $ $)) (-15 -1803 ($ $ $)) (-15 -4028 ($ $ $)) (-15 -2468 ($ $ $)) (-15 -2959 ($ $)) (-15 -2770 ($ $ $)) (-15 -2770 ($ $))))) (T -856)) 
-((-1817 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-856)))) (-3801 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-856)))) (-2518 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-856)))) (-2147 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-2147 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-856)))) (-2147 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-856)))) (-2147 (*1 *1 *2) (-12 (-5 *2 (-217)) (-5 *1 (-856)))) (-1665 (*1 *1) (-5 *1 (-856))) (-3632 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-1455 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-3632 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-1455 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-4570 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-3025 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-2254 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-1808 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-3971 (*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-1866 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-1862 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-1694 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) (-1866 (*1 *1 *1) (-5 *1 (-856))) (-1862 (*1 *1 *1) (-5 *1 (-856))) (-1694 (*1 *1 *1) (-5 *1 (-856))) (-4539 (*1 *1 *1 *1) (-5 *1 (-856))) (-3325 (*1 *1 *1 *1) (-5 *1 (-856))) (-4539 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-3325 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-2799 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-2737 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-2737 (*1 *1 *1 *1 *1) (-5 *1 (-856))) (-1737 (*1 *1 *1 *1) (-5 *1 (-856))) (-3272 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-856)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-4035 (*1 *1 *1) (-5 *1 (-856))) (-1460 (*1 *1 *1 *1) (-5 *1 (-856))) (-3497 (*1 *1 *1) (-5 *1 (-856))) (-3597 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-856)))) (-5 *1 (-856)))) (-4446 (*1 *1 *1 *1) (-5 *1 (-856))) (-1431 (*1 *1 *1) (-5 *1 (-856))) (-1431 (*1 *1 *1 *1) (-5 *1 (-856))) (-3357 (*1 *1 *1 *1) (-5 *1 (-856))) (-4395 (*1 *1 *1 *1) (-5 *1 (-856))) (-3863 (*1 *1 *1 *1) (-5 *1 (-856))) (-1592 (*1 *1 *1 *1) (-5 *1 (-856))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-856)))) (-3610 (*1 *1 *1 *1) (-5 *1 (-856))) (-4234 (*1 *1 *1 *1) (-5 *1 (-856))) (-1489 (*1 *1 *1 *1) (-5 *1 (-856))) (-3398 (*1 *1 *1 *1) (-5 *1 (-856))) (-2951 (*1 *1 *1 *1) (-5 *1 (-856))) (-3206 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-4309 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-2467 (*1 *1 *1) (-5 *1 (-856))) (-1436 (*1 *1 *1) (-5 *1 (-856))) (-1436 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-856)))) (-4200 (*1 *1 *1) (-5 *1 (-856))) (-4200 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-856)))) (-3546 (*1 *1 *1) (-5 *1 (-856))) (-2559 (*1 *1 *1 *1) (-5 *1 (-856))) (-4360 (*1 *1 *1) (-5 *1 (-856))) (-4360 (*1 *1 *1 *1) (-5 *1 (-856))) (-4360 (*1 *1 *1 *1 *1) (-5 *1 (-856))) (-2225 (*1 *1 *1) (-5 *1 (-856))) (-2225 (*1 *1 *1 *1) (-5 *1 (-856))) (-2225 (*1 *1 *1 *1 *1) (-5 *1 (-856))) (-3293 (*1 *1 *1) (-5 *1 (-856))) (-3293 (*1 *1 *1 *1) (-5 *1 (-856))) (-3293 (*1 *1 *1 *1 *1) (-5 *1 (-856))) (-1599 (*1 *1 *1) (-5 *1 (-856))) (-1599 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-3407 (*1 *1 *1) (-5 *1 (-856))) (-3407 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-3567 (*1 *1 *1) (-5 *1 (-856))) (-3567 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-2090 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-1507 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-2105 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-1636 (*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) (-1324 (*1 *1 *1 *1) (-5 *1 (-856))) (-1819 (*1 *1 *1 *1) (-5 *1 (-856))) (-1334 (*1 *1 *1 *1) (-5 *1 (-856))) (-1338 (*1 *1 *1 *1) (-5 *1 (-856))) (-1343 (*1 *1 *1 *1) (-5 *1 (-856))) (-1349 (*1 *1 *1 *1) (-5 *1 (-856))) (-1367 (*1 *1 *1 *1) (-5 *1 (-856))) (-1373 (*1 *1 *1 *1) (-5 *1 (-856))) (-1373 (*1 *1 *1) (-5 *1 (-856))) (* (*1 *1 *1 *1) (-5 *1 (-856))) (-1379 (*1 *1 *1 *1) (-5 *1 (-856))) (** (*1 *1 *1 *1) (-5 *1 (-856))) (-1807 (*1 *1 *1 *1) (-5 *1 (-856))) (-2190 (*1 *1 *1 *1) (-5 *1 (-856))) (-2208 (*1 *1 *1 *1) (-5 *1 (-856))) (-1803 (*1 *1 *1 *1) (-5 *1 (-856))) (-4028 (*1 *1 *1 *1) (-5 *1 (-856))) (-2468 (*1 *1 *1 *1) (-5 *1 (-856))) (-2959 (*1 *1 *1) (-5 *1 (-856))) (-2770 (*1 *1 *1 *1) (-5 *1 (-856))) (-2770 (*1 *1 *1) (-5 *1 (-856)))) 
-(-13 (-1098) (-10 -8 (-15 -1817 ((-1264) $)) (-15 -3801 ($ (-1152))) (-15 -2518 ((-1264) (-1152))) (-15 -2147 ($ (-572))) (-15 -2147 ($ (-1170))) (-15 -2147 ($ (-1152))) (-15 -2147 ($ (-217))) (-15 -1665 ($)) (-15 -3632 ((-572) $)) (-15 -1455 ((-572) $)) (-15 -3632 ((-572))) (-15 -1455 ((-572))) (-15 -4570 ((-572) $)) (-15 -3025 ((-572) $)) (-15 -2254 ($ (-572))) (-15 -1808 ($ (-572))) (-15 -3971 ($ (-572) (-572))) (-15 -1866 ($ $ (-572))) (-15 -1862 ($ $ (-572))) (-15 -1694 ($ $ (-572))) (-15 -1866 ($ $)) (-15 -1862 ($ $)) (-15 -1694 ($ $)) (-15 -4539 ($ $ $)) (-15 -3325 ($ $ $)) (-15 -4539 ($ (-638 $))) (-15 -3325 ($ (-638 $))) (-15 -2799 ($ $ (-638 $))) (-15 -2737 ($ $ (-638 $))) (-15 -2737 ($ $ $ $)) (-15 -1737 ($ $ $)) (-15 -3272 ((-121) $)) (-15 -3277 ($ $ (-638 $))) (-15 -4035 ($ $)) (-15 -1460 ($ $ $)) (-15 -3497 ($ $)) (-15 -3597 ($ (-638 (-638 $)))) (-15 -4446 ($ $ $)) (-15 -1431 ($ $)) (-15 -1431 ($ $ $)) (-15 -3357 ($ $ $)) (-15 -4395 ($ $ $)) (-15 -3863 ($ $ $)) (-15 -1592 ($ $ $)) (-15 -3139 ($ $ (-769))) (-15 -3610 ($ $ $)) (-15 -4234 ($ $ $)) (-15 -1489 ($ $ $)) (-15 -3398 ($ $ $)) (-15 -2951 ($ $ $)) (-15 -3206 ($ $ (-638 $))) (-15 -4309 ($ $ (-638 $))) (-15 -2467 ($ $)) (-15 -1436 ($ $)) (-15 -1436 ($ $ (-769))) (-15 -4200 ($ $)) (-15 -4200 ($ $ (-769))) (-15 -3546 ($ $)) (-15 -2559 ($ $ $)) (-15 -4360 ($ $)) (-15 -4360 ($ $ $)) (-15 -4360 ($ $ $ $)) (-15 -2225 ($ $)) (-15 -2225 ($ $ $)) (-15 -2225 ($ $ $ $)) (-15 -3293 ($ $)) (-15 -3293 ($ $ $)) (-15 -3293 ($ $ $ $)) (-15 -1599 ($ $)) (-15 -1599 ($ (-638 $))) (-15 -3407 ($ $)) (-15 -3407 ($ (-638 $))) (-15 -3567 ($ $)) (-15 -3567 ($ (-638 $))) (-15 -2090 ($ (-638 $))) (-15 -1507 ($ (-638 $))) (-15 -2105 ($ (-638 $))) (-15 -1636 ($ (-638 $))) (-15 -1324 ($ $ $)) (-15 -1819 ($ $ $)) (-15 -1334 ($ $ $)) (-15 -1338 ($ $ $)) (-15 -1343 ($ $ $)) (-15 -1349 ($ $ $)) (-15 -1367 ($ $ $)) (-15 -1373 ($ $ $)) (-15 -1373 ($ $)) (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -1807 ($ $ $)) (-15 -2190 ($ $ $)) (-15 -2208 ($ $ $)) (-15 -1803 ($ $ $)) (-15 -4028 ($ $ $)) (-15 -2468 ($ $ $)) (-15 -2959 ($ $)) (-15 -2770 ($ $ $)) (-15 -2770 ($ $)))) 
-((-2691 (((-1264) (-638 (-57))) 24)) (-1857 (((-1264) (-1152) (-856)) 14) (((-1264) (-856)) 9) (((-1264) (-1152)) 11))) 
-(((-857) (-10 -7 (-15 -1857 ((-1264) (-1152))) (-15 -1857 ((-1264) (-856))) (-15 -1857 ((-1264) (-1152) (-856))) (-15 -2691 ((-1264) (-638 (-57)))))) (T -857)) 
-((-2691 (*1 *2 *3) (-12 (-5 *3 (-638 (-57))) (-5 *2 (-1264)) (-5 *1 (-857)))) (-1857 (*1 *2 *3 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-856)) (-5 *2 (-1264)) (-5 *1 (-857)))) (-1857 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-857)))) (-1857 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-857))))) 
-(-10 -7 (-15 -1857 ((-1264) (-1152))) (-15 -1857 ((-1264) (-856))) (-15 -1857 ((-1264) (-1152) (-856))) (-15 -2691 ((-1264) (-638 (-57))))) 
-((-2262 (((-121) $ $) NIL)) (-3342 (((-3 $ "failed") (-1170)) 32)) (-1685 (((-769)) 30)) (-3286 (($) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3633 (((-923) $) 28)) (-1658 (((-1152) $) 38)) (-1763 (($ (-923)) 27)) (-2607 (((-1116) $) NIL)) (-3587 (((-638 $)) NIL)) (-4081 (((-1170) $) 13) (((-545) $) 19) (((-893 (-385)) $) 25) (((-893 (-572)) $) 22)) (-3972 (((-856) $) 16)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 35)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 34))) 
-(((-858 |#1|) (-13 (-842) (-613 (-1170)) (-613 (-545)) (-613 (-893 (-385))) (-613 (-893 (-572))) (-10 -8 (-15 -3342 ((-3 $ "failed") (-1170))))) (-638 (-1170))) (T -858)) 
-((-3342 (*1 *1 *2) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-858 *3)) (-14 *3 (-638 *2))))) 
-(-13 (-842) (-613 (-1170)) (-613 (-545)) (-613 (-893 (-385))) (-613 (-893 (-572))) (-10 -8 (-15 -3342 ((-3 $ "failed") (-1170))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (((-959 |#1|) $) NIL) (($ (-959 |#1|)) NIL) (($ |#1|) NIL (|has| |#1| (-174)))) (-2140 (((-769)) NIL)) (-2733 (((-1264) (-769)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1379 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL (|has| |#1| (-174))) (($ $ |#1|) NIL (|has| |#1| (-174))))) 
-(((-859 |#1| |#2| |#3| |#4|) (-13 (-1054) (-10 -8 (IF (|has| |#1| (-174)) (-6 (-43 |#1|)) |noBranch|) (-15 -3972 ((-959 |#1|) $)) (-15 -3972 ($ (-959 |#1|))) (IF (|has| |#1| (-368)) (-15 -1379 ((-3 $ "failed") $ $)) |noBranch|) (-15 -2733 ((-1264) (-769))))) (-1054) (-638 (-1170)) (-638 (-769)) (-769)) (T -859)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-959 *3)) (-5 *1 (-859 *3 *4 *5 *6)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))) (-14 *5 (-638 (-769))) (-14 *6 (-769)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-959 *3)) (-4 *3 (-1054)) (-5 *1 (-859 *3 *4 *5 *6)) (-14 *4 (-638 (-1170))) (-14 *5 (-638 (-769))) (-14 *6 (-769)))) (-1379 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-859 *2 *3 *4 *5)) (-4 *2 (-368)) (-4 *2 (-1054)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-769))) (-14 *5 (-769)))) (-2733 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-859 *4 *5 *6 *7)) (-4 *4 (-1054)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 *3)) (-14 *7 *3)))) 
-(-13 (-1054) (-10 -8 (IF (|has| |#1| (-174)) (-6 (-43 |#1|)) |noBranch|) (-15 -3972 ((-959 |#1|) $)) (-15 -3972 ($ (-959 |#1|))) (IF (|has| |#1| (-368)) (-15 -1379 ((-3 $ "failed") $ $)) |noBranch|) (-15 -2733 ((-1264) (-769))))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3275 (((-1259 $) $ $) 78)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-2376 (((-121) $) 111)) (-1486 (((-769)) 115)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-2032 (((-1264) $) 74)) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 122) (((-3 (-413 (-572)) "failed") $) 119) (((-3 (-413 (-572)) "failed") $) 104) (((-3 (-866) "failed") $) 136) (((-3 (-866) "failed") $) 130)) (-1318 (((-572) $) 121) (((-413 (-572)) $) 118) (((-413 (-572)) $) 105) (((-866) $) 135) (((-866) $) 131)) (-2190 (($ $ $) 53)) (-3116 (($ (-1166 $)) 84)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-4486 (($ $ (-769)) 102 (-1841 (|has| (-866) (-149)) (|has| (-866) (-374)) (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374)))) (($ $) 101 (-1841 (|has| (-866) (-149)) (|has| (-866) (-374)) (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-1526 (((-121) $) 69)) (-4430 (($ $) 79)) (-3377 (((-834 (-923)) $) 99 (-1841 (|has| (-866) (-149)) (|has| (-866) (-374)) (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-3893 (((-121) $) 30)) (-3203 (($ (-1166 $) $ (-1170)) 76) (($ (-1166 $) (-1170)) 75)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-4334 (($ (-638 $)) 81)) (-3111 (((-1166 $) $) 86) (((-1166 $) $ $) 85)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-1336 (((-121) $) 112)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 82)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-1647 (((-856) $) 73)) (-4304 (((-424 $) $) 72)) (-2728 (((-834 (-923))) 114)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3818 (((-923) $) 80)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-4311 (((-638 $) (-1166 $) $) 83)) (-3158 (((-3 (-769) "failed") $ $) 100 (-1841 (|has| (-866) (-149)) (|has| (-866) (-374)) (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-2502 (((-140)) 106)) (-4316 (((-834 (-923)) $) 113)) (-2830 (((-1166 $)) 88) (((-1166 $) $) 87)) (-3018 (($ $) 77)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ (-572)) 123) (($ (-413 (-572))) 120) (($ (-413 (-572))) 103) (($ (-866)) 137) (($ (-866)) 129)) (-2779 (((-3 $ "failed") $) 98 (-1841 (|has| (-866) (-149)) (|has| (-866) (-374)) (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-2213 (((-121) $) 110)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-2611 (($ $ (-769)) 117 (-1841 (|has| (-866) (-374)) (|has| (-413 (-572)) (-374)))) (($ $) 116 (-1841 (|has| (-866) (-374)) (|has| (-413 (-572)) (-374))))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62) (($ $ (-413 (-572))) 107) (($ $ (-866)) 132)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64) (($ (-413 (-572)) $) 109) (($ $ (-413 (-572))) 108) (($ (-866) $) 134) (($ $ (-866)) 133))) 
-(((-860) (-1290)) (T -860)) 
-NIL 
-(-13 (-865) (-1044 (-866)) (-1276 (-866))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 (-866) (-866)) . T) ((-120 $ $) . T) ((-138) . T) ((-149) -1841 (|has| (-866) (-374)) (|has| (-866) (-149)) (|has| (-413 (-572)) (-374)) (|has| (-413 (-572)) (-149))) ((-151) . T) ((-612 (-856)) . T) ((-174) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-1276 (-413 (-572))) . T) ((-1276 (-866)) . T) ((-368) . T) ((-408) -1841 (|has| (-866) (-374)) (|has| (-866) (-149)) (|has| (-413 (-572)) (-374)) (|has| (-413 (-572)) (-149))) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 (-866)) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 (-866)) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-864) . T) ((-865) . T) ((-1044 (-413 (-572))) . T) ((-1044 (-572)) . T) ((-1044 (-866)) . T) ((-1060 (-413 (-572))) . T) ((-1060 (-866)) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T) ((-1266 (-413 (-572))) . T) ((-1266 (-866)) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 47)) (-3275 (((-1259 $) $ $) 69)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2032 (((-1264) $) 78)) (-2211 (($) NIL T CONST)) (-2451 (((-866) $) 17)) (-3376 (((-3 (-572) "failed") $) 75) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 (-866) "failed") $) 72) (((-3 (-866) "failed") $) 72)) (-1318 (((-572) $) NIL) (((-413 (-572)) $) NIL) (((-413 (-572)) $) NIL) (((-866) $) 111) (((-866) $) 111)) (-2190 (($ $ $) NIL)) (-3116 (($ (-1166 $)) 59)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-4486 (($ $ (-769)) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374)) (|has| (-866) (-149)) (|has| (-866) (-374)))) (($ $) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374)) (|has| (-866) (-149)) (|has| (-866) (-374))))) (-1526 (((-121) $) NIL)) (-4430 (($ $) 63)) (-3377 (((-834 (-923)) $) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374)) (|has| (-866) (-149)) (|has| (-866) (-374))))) (-3893 (((-121) $) 117)) (-3203 (($ (-1166 $) $ (-1170)) 41) (($ (-1166 $) (-1170)) 94)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4334 (($ (-638 $)) 61)) (-3111 (((-1166 $) $) 55) (((-1166 $) $ $) 56)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 101)) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 62)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1647 (((-856) $) 124)) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3818 (((-923) $) 37)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-4311 (((-638 $) (-1166 $) $) 96)) (-3158 (((-3 (-769) "failed") $ $) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374)) (|has| (-866) (-149)) (|has| (-866) (-374))))) (-2502 (((-140)) NIL)) (-4316 (((-834 (-923)) $) NIL)) (-2830 (((-1166 $)) 79) (((-1166 $) $) 64)) (-3018 (($ $) NIL)) (-3972 (((-856) $) 123) (($ (-572)) 44) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-572)) 44) (($ (-413 (-572))) NIL) (($ (-413 (-572))) NIL) (($ (-866)) 118) (($ (-866)) 118)) (-2779 (((-3 $ "failed") $) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374)) (|has| (-866) (-149)) (|has| (-866) (-374))))) (-2140 (((-769)) 126)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 48 T CONST)) (-3255 (($) 38 T CONST)) (-2611 (($ $ (-769)) NIL (-1841 (|has| (-413 (-572)) (-374)) (|has| (-866) (-374)))) (($ $) NIL (-1841 (|has| (-413 (-572)) (-374)) (|has| (-866) (-374))))) (-1324 (((-121) $ $) 114)) (-1379 (($ $ $) 102) (($ $ (-413 (-572))) NIL) (($ $ (-866)) NIL)) (-1373 (($ $) 35) (($ $ $) 105)) (-1367 (($ $ $) 81)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 53) (($ $ $) 31) (($ $ (-413 (-572))) 109) (($ (-413 (-572)) $) NIL) (($ (-413 (-572)) $) NIL) (($ $ (-413 (-572))) 109) (($ (-866) $) 103) (($ $ (-866)) 104))) 
-(((-861 |#1|) (-13 (-860) (-10 -8 (-15 -1647 ((-856) $)) (-15 -2451 ((-866) $)))) (-866)) (T -861)) 
-((-1647 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-861 *3)) (-14 *3 (-866)))) (-2451 (*1 *2 *1) (-12 (-5 *2 (-866)) (-5 *1 (-861 *3)) (-14 *3 *2)))) 
-(-13 (-860) (-10 -8 (-15 -1647 ((-856) $)) (-15 -2451 ((-866) $)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3275 (((-1259 $) $ $) 114)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-3617 (((-1178 (-923) (-769)) (-572)) 88)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-1685 (((-769)) 98)) (-2032 (((-1264) $) 118)) (-2211 (($) 16 T CONST)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 82)) (-2190 (($ $ $) 53)) (-3116 (($ (-1166 $)) 108)) (-1799 (((-3 $ "failed") $) 33)) (-3286 (($) 101)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-2754 (($) 86)) (-1297 (((-121) $) 85)) (-4486 (($ $) 75) (($ $ (-769)) 74)) (-1526 (((-121) $) 69)) (-4430 (($ $) 113)) (-3377 (((-834 (-923)) $) 77) (((-923) $) 83)) (-3893 (((-121) $) 30)) (-3961 (((-3 $ "failed") $) 97)) (-3203 (($ (-1166 $) (-1170)) 117) (($ (-1166 $) $ (-1170)) 116)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-4334 (($ (-638 $)) 111)) (-3633 (((-923) $) 100)) (-3111 (((-1166 $) $ $) 107) (((-1166 $) $) 106)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-1773 (($) 96 T CONST)) (-1763 (($ (-923)) 99)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 110)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-1647 (((-856) $) 119)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) 89)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3818 (((-923) $) 112)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-3587 (((-638 $)) 102)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-4311 (((-638 $) (-1166 $) $) 109)) (-3158 (((-3 (-769) "failed") $ $) 76) (((-769) $) 84)) (-3139 (($ $ (-769)) 94) (($ $) 92)) (-2830 (((-1166 $) $) 105) (((-1166 $)) 104)) (-2278 (($) 87)) (-3018 (($ $) 115)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 90)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63)) (-2779 (((-3 $ "failed") $) 78) (($ $) 91)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-769)) 95) (($ $) 93)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64))) 
-(((-862) (-1290)) (T -862)) 
-NIL 
-(-13 (-353) (-864)) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-149) . T) ((-612 (-856)) . T) ((-174) . T) ((-227) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-408) . T) ((-374) . T) ((-353) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-864) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) . T) ((-1214) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 29)) (-3275 (((-1259 $) $ $) 48)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 39)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3617 (((-1178 (-923) (-769)) (-572)) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) 52)) (-2032 (((-1264) $) 56)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 126)) (-1318 ((|#1| $) 85)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) 139)) (-2190 (($ $ $) NIL)) (-3116 (($ (-1166 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) 82)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL)) (-1297 (((-121) $) NIL)) (-4486 (($ $) NIL) (($ $ (-769)) NIL)) (-1526 (((-121) $) NIL)) (-4430 (($ $) 41)) (-3377 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-3893 (((-121) $) 123)) (-3961 (((-3 $ "failed") $) NIL)) (-3203 (($ (-1166 $) (-1170)) 79) (($ (-1166 $) $ (-1170)) 99)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4334 (($ (-638 $)) 104)) (-3633 (((-923) $) 134)) (-3111 (((-1166 $) $ $) NIL) (((-1166 $) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 27)) (-1773 (($) NIL T CONST)) (-1763 (($ (-923)) 136)) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 40)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1647 (((-856) $) 132)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL)) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3818 (((-923) $) 14)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-4311 (((-638 $) (-1166 $) $) 81)) (-3158 (((-3 (-769) "failed") $ $) NIL) (((-769) $) NIL)) (-2502 (((-140)) NIL)) (-3139 (($ $ (-769)) NIL) (($ $) NIL)) (-4316 (((-834 (-923)) $) 17)) (-2830 (((-1166 $) $) 20) (((-1166 $)) NIL)) (-2278 (($) NIL)) (-3018 (($ $) 90)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL)) (-3972 (((-856) $) 131) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) 124)) (-2779 (((-3 $ "failed") $) NIL) (($ $) 89)) (-2140 (((-769)) 140)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 30 T CONST)) (-3255 (($) 21 T CONST)) (-2611 (($ $ (-769)) NIL (|has| |#1| (-374))) (($ $) NIL (|has| |#1| (-374)))) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1324 (((-121) $ $) 120)) (-1379 (($ $ $) 96) (($ $ |#1|) NIL)) (-1373 (($ $) 97) (($ $ $) 107)) (-1367 (($ $ $) 63)) (** (($ $ (-923)) 33) (($ $ (-769)) 34) (($ $ (-572)) 37)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 111) (($ $ $) 65) (($ $ (-413 (-572))) 112) (($ (-413 (-572)) $) NIL) (($ |#1| $) 105) (($ $ |#1|) 106))) 
-(((-863 |#1|) (-13 (-862) (-1276 |#1|) (-10 -8 (-15 -1647 ((-856) $)))) (-353)) (T -863)) 
-((-1647 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-863 *3)) (-4 *3 (-353))))) 
-(-13 (-862) (-1276 |#1|) (-10 -8 (-15 -1647 ((-856) $)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3275 (((-1259 $) $ $) 78)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-2032 (((-1264) $) 74)) (-2211 (($) 16 T CONST)) (-2190 (($ $ $) 53)) (-3116 (($ (-1166 $)) 84)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-1526 (((-121) $) 69)) (-4430 (($ $) 79)) (-3893 (((-121) $) 30)) (-3203 (($ (-1166 $) $ (-1170)) 76) (($ (-1166 $) (-1170)) 75)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-4334 (($ (-638 $)) 81)) (-3111 (((-1166 $) $) 86) (((-1166 $) $ $) 85)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 82)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-1647 (((-856) $) 73)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3818 (((-923) $) 80)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-4311 (((-638 $) (-1166 $) $) 83)) (-2830 (((-1166 $)) 88) (((-1166 $) $) 87)) (-3018 (($ $) 77)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64))) 
-(((-864) (-1290)) (T -864)) 
-((-2830 (*1 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) (-2830 (*1 *2 *1) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) (-3111 (*1 *2 *1) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) (-3111 (*1 *2 *1 *1) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) (-3116 (*1 *1 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) (-4311 (*1 *2 *3 *1) (-12 (-5 *3 (-1166 *1)) (-4 *1 (-864)) (-5 *2 (-638 *1)))) (-4357 (*1 *2 *1) (-12 (-4 *1 (-864)) (-5 *2 (-121)))) (-4334 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-864)))) (-3818 (*1 *2 *1) (-12 (-4 *1 (-864)) (-5 *2 (-923)))) (-4430 (*1 *1 *1) (-4 *1 (-864))) (-3275 (*1 *2 *1 *1) (-12 (-5 *2 (-1259 *1)) (-4 *1 (-864)))) (-3018 (*1 *1 *1) (-4 *1 (-864))) (-3203 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1166 *1)) (-5 *3 (-1170)) (-4 *1 (-864)))) (-3203 (*1 *1 *2 *3) (-12 (-5 *2 (-1166 *1)) (-5 *3 (-1170)) (-4 *1 (-864)))) (-2032 (*1 *2 *1) (-12 (-4 *1 (-864)) (-5 *2 (-1264)))) (-1647 (*1 *2 *1) (-12 (-4 *1 (-864)) (-5 *2 (-856))))) 
-(-13 (-368) (-10 -8 (-15 -2830 ((-1166 $))) (-15 -2830 ((-1166 $) $)) (-15 -3111 ((-1166 $) $)) (-15 -3111 ((-1166 $) $ $)) (-15 -3116 ($ (-1166 $))) (-15 -4311 ((-638 $) (-1166 $) $)) (-15 -4357 ((-121) $)) (-15 -4334 ($ (-638 $))) (-15 -3818 ((-923) $)) (-15 -4430 ($ $)) (-15 -3275 ((-1259 $) $ $)) (-15 -3018 ($ $)) (-15 -3203 ($ (-1166 $) $ (-1170))) (-15 -3203 ($ (-1166 $) (-1170))) (-15 -2032 ((-1264) $)) (-15 -1647 ((-856) $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T)) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3275 (((-1259 $) $ $) 78)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-2376 (((-121) $) 111)) (-1486 (((-769)) 115)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-2032 (((-1264) $) 74)) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 122) (((-3 (-413 (-572)) "failed") $) 119) (((-3 (-413 (-572)) "failed") $) 104)) (-1318 (((-572) $) 121) (((-413 (-572)) $) 118) (((-413 (-572)) $) 105)) (-2190 (($ $ $) 53)) (-3116 (($ (-1166 $)) 84)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-4486 (($ $ (-769)) 102 (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374)))) (($ $) 101 (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-1526 (((-121) $) 69)) (-4430 (($ $) 79)) (-3377 (((-834 (-923)) $) 99 (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-3893 (((-121) $) 30)) (-3203 (($ (-1166 $) $ (-1170)) 76) (($ (-1166 $) (-1170)) 75)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-4334 (($ (-638 $)) 81)) (-3111 (((-1166 $) $) 86) (((-1166 $) $ $) 85)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-1336 (((-121) $) 112)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 82)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-1647 (((-856) $) 73)) (-4304 (((-424 $) $) 72)) (-2728 (((-834 (-923))) 114)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3818 (((-923) $) 80)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-4311 (((-638 $) (-1166 $) $) 83)) (-3158 (((-3 (-769) "failed") $ $) 100 (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-2502 (((-140)) 106)) (-4316 (((-834 (-923)) $) 113)) (-2830 (((-1166 $)) 88) (((-1166 $) $) 87)) (-3018 (($ $) 77)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ (-572)) 123) (($ (-413 (-572))) 120) (($ (-413 (-572))) 103)) (-2779 (((-3 $ "failed") $) 98 (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-2213 (((-121) $) 110)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-2611 (($ $ (-769)) 117 (|has| (-413 (-572)) (-374))) (($ $) 116 (|has| (-413 (-572)) (-374)))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62) (($ $ (-413 (-572))) 107)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64) (($ (-413 (-572)) $) 109) (($ $ (-413 (-572))) 108))) 
-(((-865) (-1290)) (T -865)) 
-NIL 
-(-13 (-864) (-151) (-1044 (-572)) (-1044 (-413 (-572))) (-1276 (-413 (-572)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-149) -1841 (|has| (-413 (-572)) (-374)) (|has| (-413 (-572)) (-149))) ((-151) . T) ((-612 (-856)) . T) ((-174) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-1276 (-413 (-572))) . T) ((-368) . T) ((-408) -1841 (|has| (-413 (-572)) (-374)) (|has| (-413 (-572)) (-149))) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-864) . T) ((-1044 (-413 (-572))) . T) ((-1044 (-572)) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T) ((-1266 (-413 (-572))) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 16)) (-3275 (((-1259 $) $ $) 47)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2032 (((-1264) $) 51)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) 104) (((-3 (-413 (-572)) "failed") $) 106) (((-3 (-413 (-572)) "failed") $) 106)) (-1318 (((-572) $) NIL) (((-413 (-572)) $) 94) (((-413 (-572)) $) 94)) (-2190 (($ $ $) NIL)) (-3116 (($ (-1166 $)) 34)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-4486 (($ $ (-769)) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374)))) (($ $) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-1526 (((-121) $) NIL)) (-4430 (($ $) 40)) (-3377 (((-834 (-923)) $) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-3893 (((-121) $) 100)) (-3203 (($ (-1166 $) $ (-1170)) 79) (($ (-1166 $) (-1170)) 70) (($ (-1166 $) (-1166 $) (-923) $ (-1170)) 80)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4334 (($ (-638 $)) 38)) (-3111 (((-1166 $) $) 29) (((-1166 $) $ $) 31)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 86)) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 39)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1647 (((-856) $) 112)) (-4304 (((-424 $) $) NIL)) (-2728 (((-834 (-923))) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3818 (((-923) $) 30)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-4311 (((-638 $) (-1166 $) $) 72)) (-3158 (((-3 (-769) "failed") $ $) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-2502 (((-140)) NIL)) (-4316 (((-834 (-923)) $) NIL)) (-2830 (((-1166 $)) 52) (((-1166 $) $) 41)) (-3018 (($ $) NIL)) (-3972 (((-856) $) 111) (($ (-572)) 14) (($ $) NIL) (($ (-413 (-572))) 101) (($ (-572)) 14) (($ (-413 (-572))) 101) (($ (-413 (-572))) 101)) (-2779 (((-3 $ "failed") $) NIL (-1841 (|has| (-413 (-572)) (-149)) (|has| (-413 (-572)) (-374))))) (-2140 (((-769)) 114)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 17 T CONST)) (-3255 (($) 73 T CONST)) (-2611 (($ $ (-769)) NIL (|has| (-413 (-572)) (-374))) (($ $) NIL (|has| (-413 (-572)) (-374)))) (-1324 (((-121) $ $) 97)) (-1379 (($ $ $) 78) (($ $ (-413 (-572))) NIL)) (-1373 (($ $) 19) (($ $ $) 89)) (-1367 (($ $ $) 54)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 18) (($ $ $) 57) (($ $ (-413 (-572))) 88) (($ (-413 (-572)) $) 87) (($ (-413 (-572)) $) 87) (($ $ (-413 (-572))) 88))) 
-(((-866) (-13 (-865) (-10 -8 (-15 -1647 ((-856) $)) (-15 -3203 ($ (-1166 $) (-1166 $) (-923) $ (-1170)))))) (T -866)) 
-((-1647 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-866)))) (-3203 (*1 *1 *2 *2 *3 *1 *4) (-12 (-5 *2 (-1166 (-866))) (-5 *3 (-923)) (-5 *4 (-1170)) (-5 *1 (-866))))) 
-(-13 (-865) (-10 -8 (-15 -1647 ((-856) $)) (-15 -3203 ($ (-1166 $) (-1166 $) (-923) $ (-1170))))) 
-((-2373 (((-3 (-175 |#3|) "failed") (-769) (-769) |#2| |#2|) 31)) (-2714 (((-3 (-413 |#3|) "failed") (-769) (-769) |#2| |#2|) 24))) 
-(((-867 |#1| |#2| |#3|) (-10 -7 (-15 -2714 ((-3 (-413 |#3|) "failed") (-769) (-769) |#2| |#2|)) (-15 -2373 ((-3 (-175 |#3|) "failed") (-769) (-769) |#2| |#2|))) (-368) (-1249 |#1|) (-1234 |#1|)) (T -867)) 
-((-2373 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-769)) (-4 *5 (-368)) (-5 *2 (-175 *6)) (-5 *1 (-867 *5 *4 *6)) (-4 *4 (-1249 *5)) (-4 *6 (-1234 *5)))) (-2714 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-769)) (-4 *5 (-368)) (-5 *2 (-413 *6)) (-5 *1 (-867 *5 *4 *6)) (-4 *4 (-1249 *5)) (-4 *6 (-1234 *5))))) 
-(-10 -7 (-15 -2714 ((-3 (-413 |#3|) "failed") (-769) (-769) |#2| |#2|)) (-15 -2373 ((-3 (-175 |#3|) "failed") (-769) (-769) |#2| |#2|))) 
-((-2714 (((-3 (-413 (-1231 |#2| |#1|)) "failed") (-769) (-769) (-1250 |#1| |#2| |#3|)) 28) (((-3 (-413 (-1231 |#2| |#1|)) "failed") (-769) (-769) (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|)) 26))) 
-(((-868 |#1| |#2| |#3|) (-10 -7 (-15 -2714 ((-3 (-413 (-1231 |#2| |#1|)) "failed") (-769) (-769) (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|))) (-15 -2714 ((-3 (-413 (-1231 |#2| |#1|)) "failed") (-769) (-769) (-1250 |#1| |#2| |#3|)))) (-368) (-1170) |#1|) (T -868)) 
-((-2714 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-769)) (-5 *4 (-1250 *5 *6 *7)) (-4 *5 (-368)) (-14 *6 (-1170)) (-14 *7 *5) (-5 *2 (-413 (-1231 *6 *5))) (-5 *1 (-868 *5 *6 *7)))) (-2714 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-769)) (-5 *4 (-1250 *5 *6 *7)) (-4 *5 (-368)) (-14 *6 (-1170)) (-14 *7 *5) (-5 *2 (-413 (-1231 *6 *5))) (-5 *1 (-868 *5 *6 *7))))) 
-(-10 -7 (-15 -2714 ((-3 (-413 (-1231 |#2| |#1|)) "failed") (-769) (-769) (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|))) (-15 -2714 ((-3 (-413 (-1231 |#2| |#1|)) "failed") (-769) (-769) (-1250 |#1| |#2| |#3|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-4190 (($ $ (-572)) 60)) (-3112 (((-121) $ $) 57)) (-2211 (($) 16 T CONST)) (-1431 (($ (-1166 (-572)) (-572)) 59)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-4070 (($ $) 62)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-3377 (((-769) $) 67)) (-3893 (((-121) $) 30)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-3195 (((-572)) 64)) (-2671 (((-572) $) 63)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1977 (($ $ (-572)) 66)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-4465 (((-1150 (-572)) $) 68)) (-2424 (($ $) 65)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-3410 (((-572) $ (-572)) 61)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-869 |#1|) (-1290) (-572)) (T -869)) 
-((-4465 (*1 *2 *1) (-12 (-4 *1 (-869 *3)) (-5 *2 (-1150 (-572))))) (-3377 (*1 *2 *1) (-12 (-4 *1 (-869 *3)) (-5 *2 (-769)))) (-1977 (*1 *1 *1 *2) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572)))) (-2424 (*1 *1 *1) (-4 *1 (-869 *2))) (-3195 (*1 *2) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572)))) (-2671 (*1 *2 *1) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572)))) (-4070 (*1 *1 *1) (-4 *1 (-869 *2))) (-3410 (*1 *2 *1 *2) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572)))) (-4190 (*1 *1 *1 *2) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572)))) (-1431 (*1 *1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *3 (-572)) (-4 *1 (-869 *4))))) 
-(-13 (-303) (-151) (-10 -8 (-15 -4465 ((-1150 (-572)) $)) (-15 -3377 ((-769) $)) (-15 -1977 ($ $ (-572))) (-15 -2424 ($ $)) (-15 -3195 ((-572))) (-15 -2671 ((-572) $)) (-15 -4070 ($ $)) (-15 -3410 ((-572) $ (-572))) (-15 -4190 ($ $ (-572))) (-15 -1431 ($ (-1166 (-572)) (-572))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-151) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-303) . T) ((-457) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $ (-572)) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-1431 (($ (-1166 (-572)) (-572)) NIL)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-4070 (($ $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-3377 (((-769) $) NIL)) (-3893 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3195 (((-572)) NIL)) (-2671 (((-572) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1977 (($ $ (-572)) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-4465 (((-1150 (-572)) $) NIL)) (-2424 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL)) (-2140 (((-769)) NIL)) (-3774 (((-121) $ $) NIL)) (-3410 (((-572) $ (-572)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL))) 
-(((-870 |#1|) (-869 |#1|) (-572)) (T -870)) 
-NIL 
-(-869 |#1|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 (((-870 |#1|) $) NIL (|has| (-870 |#1|) (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-870 |#1|) (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| (-870 |#1|) (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| (-870 |#1|) (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-870 |#1|) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL (|has| (-870 |#1|) (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-870 |#1|) (-1044 (-572)))) (((-3 (-572) "failed") $) NIL (|has| (-870 |#1|) (-1044 (-572))))) (-1318 (((-870 |#1|) $) NIL) (((-1170) $) NIL (|has| (-870 |#1|) (-1044 (-1170)))) (((-413 (-572)) $) NIL (|has| (-870 |#1|) (-1044 (-572)))) (((-572) $) NIL (|has| (-870 |#1|) (-1044 (-572))))) (-3729 (($ $) NIL) (($ (-572) $) NIL)) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-870 |#1|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-870 |#1|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-870 |#1|))) (|:| |vec| (-1259 (-870 |#1|)))) (-685 $) (-1259 $)) NIL) (((-685 (-870 |#1|)) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-870 |#1|) (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) NIL (|has| (-870 |#1|) (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| (-870 |#1|) (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| (-870 |#1|) (-887 (-385))))) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL)) (-4487 (((-870 |#1|) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| (-870 |#1|) (-1144)))) (-4472 (((-121) $) NIL (|has| (-870 |#1|) (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| (-870 |#1|) (-848)))) (-4238 (($ $ $) NIL (|has| (-870 |#1|) (-848)))) (-3828 (($ (-1 (-870 |#1|) (-870 |#1|)) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-870 |#1|) (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| (-870 |#1|) (-303)))) (-1716 (((-870 |#1|) $) NIL (|has| (-870 |#1|) (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-870 |#1|) (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-870 |#1|) (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 (-870 |#1|)) (-638 (-870 |#1|))) NIL (|has| (-870 |#1|) (-305 (-870 |#1|)))) (($ $ (-870 |#1|) (-870 |#1|)) NIL (|has| (-870 |#1|) (-305 (-870 |#1|)))) (($ $ (-290 (-870 |#1|))) NIL (|has| (-870 |#1|) (-305 (-870 |#1|)))) (($ $ (-638 (-290 (-870 |#1|)))) NIL (|has| (-870 |#1|) (-305 (-870 |#1|)))) (($ $ (-638 (-1170)) (-638 (-870 |#1|))) NIL (|has| (-870 |#1|) (-527 (-1170) (-870 |#1|)))) (($ $ (-1170) (-870 |#1|)) NIL (|has| (-870 |#1|) (-527 (-1170) (-870 |#1|))))) (-4029 (((-769) $) NIL)) (-3277 (($ $ (-870 |#1|)) NIL (|has| (-870 |#1|) (-283 (-870 |#1|) (-870 |#1|))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL (|has| (-870 |#1|) (-227))) (($ $ (-769)) NIL (|has| (-870 |#1|) (-227))) (($ $ (-1170)) NIL (|has| (-870 |#1|) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-870 |#1|) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-870 |#1|) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-870 |#1|) (-901 (-1170)))) (($ $ (-1 (-870 |#1|) (-870 |#1|)) (-769)) NIL) (($ $ (-1 (-870 |#1|) (-870 |#1|))) NIL)) (-3425 (($ $) NIL)) (-4492 (((-870 |#1|) $) NIL)) (-4081 (((-893 (-572)) $) NIL (|has| (-870 |#1|) (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| (-870 |#1|) (-613 (-893 (-385))))) (((-545) $) NIL (|has| (-870 |#1|) (-613 (-545)))) (((-385) $) NIL (|has| (-870 |#1|) (-1028))) (((-217) $) NIL (|has| (-870 |#1|) (-1028)))) (-3915 (((-175 (-413 (-572))) $) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-870 |#1|) (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL) (($ (-870 |#1|)) NIL) (($ (-1170)) NIL (|has| (-870 |#1|) (-1044 (-1170))))) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-870 |#1|) (-910))) (|has| (-870 |#1|) (-149))))) (-2140 (((-769)) NIL)) (-2634 (((-870 |#1|) $) NIL (|has| (-870 |#1|) (-554)))) (-3774 (((-121) $ $) NIL)) (-3410 (((-413 (-572)) $ (-572)) NIL)) (-2264 (($ $) NIL (|has| (-870 |#1|) (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $) NIL (|has| (-870 |#1|) (-227))) (($ $ (-769)) NIL (|has| (-870 |#1|) (-227))) (($ $ (-1170)) NIL (|has| (-870 |#1|) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-870 |#1|) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-870 |#1|) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-870 |#1|) (-901 (-1170)))) (($ $ (-1 (-870 |#1|) (-870 |#1|)) (-769)) NIL) (($ $ (-1 (-870 |#1|) (-870 |#1|))) NIL)) (-1349 (((-121) $ $) NIL (|has| (-870 |#1|) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-870 |#1|) (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| (-870 |#1|) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-870 |#1|) (-848)))) (-1379 (($ $ $) NIL) (($ (-870 |#1|) (-870 |#1|)) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ (-870 |#1|) $) NIL) (($ $ (-870 |#1|)) NIL))) 
-(((-871 |#1|) (-13 (-1000 (-870 |#1|)) (-10 -8 (-15 -3410 ((-413 (-572)) $ (-572))) (-15 -3915 ((-175 (-413 (-572))) $)) (-15 -3729 ($ $)) (-15 -3729 ($ (-572) $)))) (-572)) (T -871)) 
-((-3410 (*1 *2 *1 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-871 *4)) (-14 *4 *3) (-5 *3 (-572)))) (-3915 (*1 *2 *1) (-12 (-5 *2 (-175 (-413 (-572)))) (-5 *1 (-871 *3)) (-14 *3 (-572)))) (-3729 (*1 *1 *1) (-12 (-5 *1 (-871 *2)) (-14 *2 (-572)))) (-3729 (*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-871 *3)) (-14 *3 *2)))) 
-(-13 (-1000 (-870 |#1|)) (-10 -8 (-15 -3410 ((-413 (-572)) $ (-572))) (-15 -3915 ((-175 (-413 (-572))) $)) (-15 -3729 ($ $)) (-15 -3729 ($ (-572) $)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 ((|#2| $) NIL (|has| |#2| (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| |#2| (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-1170) "failed") $) NIL (|has| |#2| (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572))))) (-1318 ((|#2| $) NIL) (((-1170) $) NIL (|has| |#2| (-1044 (-1170)))) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-572)))) (((-572) $) NIL (|has| |#2| (-1044 (-572))))) (-3729 (($ $) 31) (($ (-572) $) 32)) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) 53)) (-3286 (($) NIL (|has| |#2| (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) NIL (|has| |#2| (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| |#2| (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| |#2| (-887 (-385))))) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL)) (-4487 ((|#2| $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| |#2| (-1144)))) (-4472 (((-121) $) NIL (|has| |#2| (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| |#2| (-848)))) (-4238 (($ $ $) NIL (|has| |#2| (-848)))) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 49)) (-1773 (($) NIL (|has| |#2| (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| |#2| (-303)))) (-1716 ((|#2| $) NIL (|has| |#2| (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 |#2|) (-638 |#2|)) NIL (|has| |#2| (-305 |#2|))) (($ $ |#2| |#2|) NIL (|has| |#2| (-305 |#2|))) (($ $ (-290 |#2|)) NIL (|has| |#2| (-305 |#2|))) (($ $ (-638 (-290 |#2|))) NIL (|has| |#2| (-305 |#2|))) (($ $ (-638 (-1170)) (-638 |#2|)) NIL (|has| |#2| (-527 (-1170) |#2|))) (($ $ (-1170) |#2|) NIL (|has| |#2| (-527 (-1170) |#2|)))) (-4029 (((-769) $) NIL)) (-3277 (($ $ |#2|) NIL (|has| |#2| (-283 |#2| |#2|)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) NIL (|has| |#2| (-227))) (($ $ (-769)) NIL (|has| |#2| (-227))) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-3425 (($ $) NIL)) (-4492 ((|#2| $) NIL)) (-4081 (((-893 (-572)) $) NIL (|has| |#2| (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| |#2| (-613 (-893 (-385))))) (((-545) $) NIL (|has| |#2| (-613 (-545)))) (((-385) $) NIL (|has| |#2| (-1028))) (((-217) $) NIL (|has| |#2| (-1028)))) (-3915 (((-175 (-413 (-572))) $) 68)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#2| (-910))))) (-3972 (((-856) $) 85) (($ (-572)) 19) (($ $) NIL) (($ (-413 (-572))) 24) (($ |#2|) 18) (($ (-1170)) NIL (|has| |#2| (-1044 (-1170))))) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#2| (-910))) (|has| |#2| (-149))))) (-2140 (((-769)) NIL)) (-2634 ((|#2| $) NIL (|has| |#2| (-554)))) (-3774 (((-121) $ $) NIL)) (-3410 (((-413 (-572)) $ (-572)) 60)) (-2264 (($ $) NIL (|has| |#2| (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 14 T CONST)) (-3255 (($) 16 T CONST)) (-1557 (($ $) NIL (|has| |#2| (-227))) (($ $ (-769)) NIL (|has| |#2| (-227))) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1324 (((-121) $ $) 35)) (-1343 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1379 (($ $ $) 23) (($ |#2| |#2|) 54)) (-1373 (($ $) 39) (($ $ $) 41)) (-1367 (($ $ $) 37)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) 50)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 42) (($ $ $) 44) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ |#2| $) 55) (($ $ |#2|) NIL))) 
-(((-872 |#1| |#2|) (-13 (-1000 |#2|) (-10 -8 (-15 -3410 ((-413 (-572)) $ (-572))) (-15 -3915 ((-175 (-413 (-572))) $)) (-15 -3729 ($ $)) (-15 -3729 ($ (-572) $)))) (-572) (-869 |#1|)) (T -872)) 
-((-3410 (*1 *2 *1 *3) (-12 (-14 *4 *3) (-5 *2 (-413 (-572))) (-5 *1 (-872 *4 *5)) (-5 *3 (-572)) (-4 *5 (-869 *4)))) (-3915 (*1 *2 *1) (-12 (-14 *3 (-572)) (-5 *2 (-175 (-413 (-572)))) (-5 *1 (-872 *3 *4)) (-4 *4 (-869 *3)))) (-3729 (*1 *1 *1) (-12 (-14 *2 (-572)) (-5 *1 (-872 *2 *3)) (-4 *3 (-869 *2)))) (-3729 (*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-14 *3 *2) (-5 *1 (-872 *3 *4)) (-4 *4 (-869 *3))))) 
-(-13 (-1000 |#2|) (-10 -8 (-15 -3410 ((-413 (-572)) $ (-572))) (-15 -3915 ((-175 (-413 (-572))) $)) (-15 -3729 ($ $)) (-15 -3729 ($ (-572) $)))) 
-((-1309 (((-244 |#2| (-863 |#1|)) (-244 |#2| |#1|) (-974 |#1|)) NIL)) (-3391 (((-244 |#2| |#1|)) 107)) (-2194 (((-638 (-974 |#1|))) 116)) (-4265 (((-638 (-974 |#1|)) (-638 (-974 |#1|))) 27)) (-1915 (((-244 |#2| |#1|) (-244 |#2| |#1|)) 35)) (-3356 (((-638 (-974 |#1|))) 60)) (-2653 (((-638 (-928 |#1|))) 58)) (-1413 (((-974 |#1|) (-638 (-863 |#1|))) 17)) (-4543 (((-974 |#1|) (-928 |#1|)) 21)) (-2201 (((-638 (-928 |#1|)) (-923)) 45 (|has| (-863 |#1|) (-374)))) (-1956 (((-638 (-928 |#1|)) (-974 |#1|)) 24)) (-1534 (((-780 (-863 |#1|)) (-244 |#2| |#1|) (-928 |#1|)) 119)) (-2931 (((-572) (-923)) 47 (|has| (-863 |#1|) (-374)))) (-1613 (((-572) (-923) (-923)) 49 (|has| (-863 |#1|) (-374)))) (-4183 (((-572) (-923)) 43 (|has| (-863 |#1|) (-374)))) (-2528 (((-2 (|:| |num| (-638 (-244 |#2| |#1|))) (|:| |den| (-244 |#2| |#1|))) (-238 (-928 |#1|))) 62) (((-638 (-413 (-244 |#2| |#1|))) (-238 (-928 |#1|)) (-769)) NIL)) (-2420 (((-238 (-928 |#1|)) (-244 |#2| |#1|)) 135)) (-2390 (((-638 (-244 |#2| (-863 |#1|))) (-238 (-928 |#1|)) (-638 (-244 |#2| |#1|))) 125)) (-3711 (((-638 (-244 |#2| |#1|)) (-238 (-928 |#1|)) (-769)) 123)) (-3991 (((-244 |#2| |#1|) (-244 |#2| |#1|) (-572)) 13)) (-2091 (((-685 |#1|) (-238 (-928 |#1|)) (-638 (-928 |#1|))) 67) (((-685 |#1|) (-238 (-928 |#1|)) (-238 (-928 |#1|))) 69)) (-1639 (((-572)) 105)) (-1774 (((-769)) 103)) (-4280 (((-1264)) 144)) (-4192 (((-1264)) 140)) (-2715 (((-2 (|:| -3306 (-572)) (|:| |num| (-244 |#2| |#1|)) (|:| |den| (-244 |#2| |#1|)) (|:| |upTo| (-572))) (-238 (-928 |#1|)) (-572) (-572)) 32)) (-2655 (((-3 |#1| "failed") (-413 (-244 |#2| |#1|)) (-928 |#1|)) 132) (((-3 |#1| "failed") (-244 |#2| |#1|) (-244 |#2| |#1|) (-928 |#1|)) 127) (((-3 |#1| "failed") (-244 |#2| |#1|) (-928 |#1|)) 96)) (-4485 ((|#1| (-413 (-244 |#2| |#1|)) (-928 |#1|)) 133) ((|#1| (-244 |#2| |#1|) (-244 |#2| |#1|) (-928 |#1|)) 63) ((|#1| (-244 |#2| |#1|) (-928 |#1|)) 98)) (-3064 (((-638 (-261 (-541 |#1| |#2| |#3|)))) 112)) (-3548 (((-638 (-261 (-541 |#1| |#2| |#3|)))) 110)) (-3426 (((-572)) 56 (|has| (-863 |#1|) (-374)))) (-4457 (((-238 (-928 |#1|))) 114)) (-3647 (((-1254 (-572) -3512) (-923)) 41 (|has| (-863 |#1|) (-374))) (((-1254 (-572) -3512)) 38 (|has| (-863 |#1|) (-374)))) (-3282 (((-1166 (-572)) (-923)) 54 (|has| (-863 |#1|) (-374))) (((-1166 (-572))) 52 (|has| (-863 |#1|) (-374))))) 
-(((-873 |#1| |#2| |#3|) (-10 -7 (-15 -3991 ((-244 |#2| |#1|) (-244 |#2| |#1|) (-572))) (-15 -4192 ((-1264))) (-15 -4280 ((-1264))) (-15 -1915 ((-244 |#2| |#1|) (-244 |#2| |#1|))) (-15 -1309 ((-244 |#2| (-863 |#1|)) (-244 |#2| |#1|) (-974 |#1|))) (-15 -2091 ((-685 |#1|) (-238 (-928 |#1|)) (-238 (-928 |#1|)))) (-15 -2091 ((-685 |#1|) (-238 (-928 |#1|)) (-638 (-928 |#1|)))) (-15 -4543 ((-974 |#1|) (-928 |#1|))) (-15 -1956 ((-638 (-928 |#1|)) (-974 |#1|))) (-15 -1413 ((-974 |#1|) (-638 (-863 |#1|)))) (-15 -4265 ((-638 (-974 |#1|)) (-638 (-974 |#1|)))) (-15 -2653 ((-638 (-928 |#1|)))) (-15 -3391 ((-244 |#2| |#1|))) (-15 -1774 ((-769))) (-15 -1639 ((-572))) (-15 -3064 ((-638 (-261 (-541 |#1| |#2| |#3|))))) (-15 -3548 ((-638 (-261 (-541 |#1| |#2| |#3|))))) (-15 -3356 ((-638 (-974 |#1|)))) (-15 -2194 ((-638 (-974 |#1|)))) (-15 -1534 ((-780 (-863 |#1|)) (-244 |#2| |#1|) (-928 |#1|))) (-15 -2528 ((-638 (-413 (-244 |#2| |#1|))) (-238 (-928 |#1|)) (-769))) (-15 -2528 ((-2 (|:| |num| (-638 (-244 |#2| |#1|))) (|:| |den| (-244 |#2| |#1|))) (-238 (-928 |#1|)))) (-15 -2715 ((-2 (|:| -3306 (-572)) (|:| |num| (-244 |#2| |#1|)) (|:| |den| (-244 |#2| |#1|)) (|:| |upTo| (-572))) (-238 (-928 |#1|)) (-572) (-572))) (-15 -2390 ((-638 (-244 |#2| (-863 |#1|))) (-238 (-928 |#1|)) (-638 (-244 |#2| |#1|)))) (-15 -3711 ((-638 (-244 |#2| |#1|)) (-238 (-928 |#1|)) (-769))) (-15 -4485 (|#1| (-244 |#2| |#1|) (-928 |#1|))) (-15 -4485 (|#1| (-244 |#2| |#1|) (-244 |#2| |#1|) (-928 |#1|))) (-15 -4485 (|#1| (-413 (-244 |#2| |#1|)) (-928 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-244 |#2| |#1|) (-928 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-244 |#2| |#1|) (-244 |#2| |#1|) (-928 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-413 (-244 |#2| |#1|)) (-928 |#1|))) (-15 -2420 ((-238 (-928 |#1|)) (-244 |#2| |#1|))) (-15 -4457 ((-238 (-928 |#1|)))) (IF (|has| (-863 |#1|) (-374)) (PROGN (-15 -3282 ((-1166 (-572)))) (-15 -3282 ((-1166 (-572)) (-923))) (-15 -3426 ((-572))) (-15 -2201 ((-638 (-928 |#1|)) (-923))) (-15 -4183 ((-572) (-923))) (-15 -2931 ((-572) (-923))) (-15 -1613 ((-572) (-923) (-923))) (-15 -3647 ((-1254 (-572) -3512))) (-15 -3647 ((-1254 (-572) -3512) (-923)))) |noBranch|)) (-353) (-638 (-1170)) (-117)) (T -873)) 
-((-3647 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-3647 (*1 *2) (-12 (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-873 *3 *4 *5)) (-4 (-863 *3) (-374)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1613 (*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-2931 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-4183 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-2201 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-638 (-928 *4))) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-3426 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-873 *3 *4 *5)) (-4 (-863 *3) (-374)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3282 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 (-572))) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-3282 (*1 *2) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-873 *3 *4 *5)) (-4 (-863 *3) (-374)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-4457 (*1 *2) (-12 (-5 *2 (-238 (-928 *3))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-2420 (*1 *2 *3) (-12 (-5 *3 (-244 *5 *4)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-5 *2 (-238 (-928 *4))) (-5 *1 (-873 *4 *5 *6)) (-4 *6 (-117)))) (-2655 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-244 *5 *2))) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) (-2655 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-244 *5 *2)) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) (-2655 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-244 *5 *2)) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) (-4485 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-244 *5 *2))) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) (-4485 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-244 *5 *2)) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) (-4485 (*1 *2 *3 *4) (-12 (-5 *3 (-244 *5 *2)) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) (-3711 (*1 *2 *3 *4) (-12 (-5 *3 (-238 (-928 *5))) (-5 *4 (-769)) (-4 *5 (-353)) (-5 *2 (-638 (-244 *6 *5))) (-5 *1 (-873 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) (-2390 (*1 *2 *3 *4) (-12 (-5 *3 (-238 (-928 *5))) (-5 *4 (-638 (-244 *6 *5))) (-4 *5 (-353)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-244 *6 (-863 *5)))) (-5 *1 (-873 *5 *6 *7)) (-4 *7 (-117)))) (-2715 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-238 (-928 *5))) (-4 *5 (-353)) (-5 *2 (-2 (|:| -3306 (-572)) (|:| |num| (-244 *6 *5)) (|:| |den| (-244 *6 *5)) (|:| |upTo| (-572)))) (-5 *1 (-873 *5 *6 *7)) (-5 *4 (-572)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) (-2528 (*1 *2 *3) (-12 (-5 *3 (-238 (-928 *4))) (-4 *4 (-353)) (-5 *2 (-2 (|:| |num| (-638 (-244 *5 *4))) (|:| |den| (-244 *5 *4)))) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-2528 (*1 *2 *3 *4) (-12 (-5 *3 (-238 (-928 *5))) (-5 *4 (-769)) (-4 *5 (-353)) (-5 *2 (-638 (-413 (-244 *6 *5)))) (-5 *1 (-873 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) (-1534 (*1 *2 *3 *4) (-12 (-5 *3 (-244 *6 *5)) (-5 *4 (-928 *5)) (-4 *5 (-353)) (-14 *6 (-638 (-1170))) (-5 *2 (-780 (-863 *5))) (-5 *1 (-873 *5 *6 *7)) (-4 *7 (-117)))) (-2194 (*1 *2) (-12 (-5 *2 (-638 (-974 *3))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3356 (*1 *2) (-12 (-5 *2 (-638 (-974 *3))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3548 (*1 *2) (-12 (-5 *2 (-638 (-261 (-541 *3 *4 *5)))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3064 (*1 *2) (-12 (-5 *2 (-638 (-261 (-541 *3 *4 *5)))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1639 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1774 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3391 (*1 *2) (-12 (-5 *2 (-244 *4 *3)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-2653 (*1 *2) (-12 (-5 *2 (-638 (-928 *3))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-4265 (*1 *2 *2) (-12 (-5 *2 (-638 (-974 *3))) (-4 *3 (-353)) (-5 *1 (-873 *3 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1413 (*1 *2 *3) (-12 (-5 *3 (-638 (-863 *4))) (-4 *4 (-353)) (-5 *2 (-974 *4)) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-1956 (*1 *2 *3) (-12 (-5 *3 (-974 *4)) (-4 *4 (-353)) (-5 *2 (-638 (-928 *4))) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-4543 (*1 *2 *3) (-12 (-5 *3 (-928 *4)) (-4 *4 (-353)) (-5 *2 (-974 *4)) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-2091 (*1 *2 *3 *4) (-12 (-5 *3 (-238 (-928 *5))) (-5 *4 (-638 (-928 *5))) (-4 *5 (-353)) (-5 *2 (-685 *5)) (-5 *1 (-873 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) (-2091 (*1 *2 *3 *3) (-12 (-5 *3 (-238 (-928 *4))) (-4 *4 (-353)) (-5 *2 (-685 *4)) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-1309 (*1 *2 *3 *4) (-12 (-5 *3 (-244 *6 *5)) (-5 *4 (-974 *5)) (-4 *5 (-353)) (-14 *6 (-638 (-1170))) (-5 *2 (-244 *6 (-863 *5))) (-5 *1 (-873 *5 *6 *7)) (-4 *7 (-117)))) (-1915 (*1 *2 *2) (-12 (-5 *2 (-244 *4 *3)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-5 *1 (-873 *3 *4 *5)) (-4 *5 (-117)))) (-4280 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-4192 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3991 (*1 *2 *2 *3) (-12 (-5 *2 (-244 *5 *4)) (-5 *3 (-572)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-5 *1 (-873 *4 *5 *6)) (-4 *6 (-117))))) 
-(-10 -7 (-15 -3991 ((-244 |#2| |#1|) (-244 |#2| |#1|) (-572))) (-15 -4192 ((-1264))) (-15 -4280 ((-1264))) (-15 -1915 ((-244 |#2| |#1|) (-244 |#2| |#1|))) (-15 -1309 ((-244 |#2| (-863 |#1|)) (-244 |#2| |#1|) (-974 |#1|))) (-15 -2091 ((-685 |#1|) (-238 (-928 |#1|)) (-238 (-928 |#1|)))) (-15 -2091 ((-685 |#1|) (-238 (-928 |#1|)) (-638 (-928 |#1|)))) (-15 -4543 ((-974 |#1|) (-928 |#1|))) (-15 -1956 ((-638 (-928 |#1|)) (-974 |#1|))) (-15 -1413 ((-974 |#1|) (-638 (-863 |#1|)))) (-15 -4265 ((-638 (-974 |#1|)) (-638 (-974 |#1|)))) (-15 -2653 ((-638 (-928 |#1|)))) (-15 -3391 ((-244 |#2| |#1|))) (-15 -1774 ((-769))) (-15 -1639 ((-572))) (-15 -3064 ((-638 (-261 (-541 |#1| |#2| |#3|))))) (-15 -3548 ((-638 (-261 (-541 |#1| |#2| |#3|))))) (-15 -3356 ((-638 (-974 |#1|)))) (-15 -2194 ((-638 (-974 |#1|)))) (-15 -1534 ((-780 (-863 |#1|)) (-244 |#2| |#1|) (-928 |#1|))) (-15 -2528 ((-638 (-413 (-244 |#2| |#1|))) (-238 (-928 |#1|)) (-769))) (-15 -2528 ((-2 (|:| |num| (-638 (-244 |#2| |#1|))) (|:| |den| (-244 |#2| |#1|))) (-238 (-928 |#1|)))) (-15 -2715 ((-2 (|:| -3306 (-572)) (|:| |num| (-244 |#2| |#1|)) (|:| |den| (-244 |#2| |#1|)) (|:| |upTo| (-572))) (-238 (-928 |#1|)) (-572) (-572))) (-15 -2390 ((-638 (-244 |#2| (-863 |#1|))) (-238 (-928 |#1|)) (-638 (-244 |#2| |#1|)))) (-15 -3711 ((-638 (-244 |#2| |#1|)) (-238 (-928 |#1|)) (-769))) (-15 -4485 (|#1| (-244 |#2| |#1|) (-928 |#1|))) (-15 -4485 (|#1| (-244 |#2| |#1|) (-244 |#2| |#1|) (-928 |#1|))) (-15 -4485 (|#1| (-413 (-244 |#2| |#1|)) (-928 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-244 |#2| |#1|) (-928 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-244 |#2| |#1|) (-244 |#2| |#1|) (-928 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-413 (-244 |#2| |#1|)) (-928 |#1|))) (-15 -2420 ((-238 (-928 |#1|)) (-244 |#2| |#1|))) (-15 -4457 ((-238 (-928 |#1|)))) (IF (|has| (-863 |#1|) (-374)) (PROGN (-15 -3282 ((-1166 (-572)))) (-15 -3282 ((-1166 (-572)) (-923))) (-15 -3426 ((-572))) (-15 -2201 ((-638 (-928 |#1|)) (-923))) (-15 -4183 ((-572) (-923))) (-15 -2931 ((-572) (-923))) (-15 -1613 ((-572) (-923) (-923))) (-15 -3647 ((-1254 (-572) -3512))) (-15 -3647 ((-1254 (-572) -3512) (-923)))) |noBranch|)) 
-((-3391 (((-244 |#2| |#1|)) 83)) (-2194 (((-638 (-973 |#1|))) 92)) (-4265 (((-638 (-973 |#1|)) (-638 (-973 |#1|))) 24)) (-1915 (((-244 |#2| |#1|) (-244 |#2| |#1|)) 75)) (-3356 (((-638 (-973 |#1|))) 65)) (-2653 (((-638 (-927 |#1|))) 63)) (-1413 (((-973 |#1|) (-638 |#1|)) 27)) (-4543 (((-973 |#1|) (-927 |#1|)) 18)) (-2201 (((-638 (-927 |#1|)) (-923)) 50 (|has| |#1| (-374)))) (-1956 (((-638 (-927 |#1|)) (-973 |#1|)) 21)) (-1534 (((-780 |#1|) (-244 |#2| |#1|) (-927 |#1|)) 95)) (-2931 (((-572) (-923)) 52 (|has| |#1| (-374)))) (-1613 (((-572) (-923) (-923)) 54 (|has| |#1| (-374)))) (-4183 (((-572) (-923)) 48 (|has| |#1| (-374)))) (-2528 (((-2 (|:| |num| (-638 (-244 |#2| |#1|))) (|:| |den| (-244 |#2| |#1|))) (-238 (-927 |#1|))) 33) (((-638 (-413 (-244 |#2| |#1|))) (-238 (-927 |#1|)) (-769)) NIL)) (-2420 (((-238 (-927 |#1|)) (-244 |#2| |#1|)) 107)) (-2390 (((-638 (-244 |#2| |#1|)) (-238 (-927 |#1|)) (-638 (-244 |#2| |#1|))) 31)) (-3711 (((-638 (-244 |#2| |#1|)) (-238 (-927 |#1|)) (-769)) 97)) (-3991 (((-244 |#2| |#1|) (-244 |#2| |#1|) (-572)) 13)) (-2091 (((-685 |#1|) (-238 (-927 |#1|)) (-638 (-927 |#1|))) 38) (((-685 |#1|) (-238 (-927 |#1|)) (-238 (-927 |#1|))) 40)) (-1639 (((-572)) 81)) (-1774 (((-769)) 79)) (-4280 (((-1264)) 116)) (-4192 (((-1264)) 112)) (-2715 (((-2 (|:| -3306 (-572)) (|:| |num| (-244 |#2| |#1|)) (|:| |den| (-244 |#2| |#1|)) (|:| |upTo| (-572))) (-238 (-927 |#1|)) (-572) (-572)) NIL)) (-2655 (((-3 |#1| "failed") (-413 (-244 |#2| |#1|)) (-927 |#1|)) 105) (((-3 |#1| "failed") (-244 |#2| |#1|) (-244 |#2| |#1|) (-927 |#1|)) 104) (((-3 |#1| "failed") (-244 |#2| |#1|) (-927 |#1|)) 73)) (-4485 ((|#1| (-413 (-244 |#2| |#1|)) (-927 |#1|)) 102) ((|#1| (-244 |#2| |#1|) (-244 |#2| |#1|) (-927 |#1|)) 34) ((|#1| (-244 |#2| |#1|) (-927 |#1|)) 70)) (-3064 (((-638 (-261 (-517 |#1| |#2| |#3|)))) 88)) (-3548 (((-638 (-261 (-517 |#1| |#2| |#3|)))) 86)) (-3426 (((-572)) 61 (|has| |#1| (-374)))) (-4457 (((-238 (-927 |#1|))) 90)) (-3647 (((-1254 (-572) -3512) (-923)) 46 (|has| |#1| (-374))) (((-1254 (-572) -3512)) 43 (|has| |#1| (-374)))) (-3282 (((-1166 (-572)) (-923)) 59 (|has| |#1| (-374))) (((-1166 (-572))) 57 (|has| |#1| (-374))))) 
-(((-874 |#1| |#2| |#3|) (-10 -7 (-15 -3991 ((-244 |#2| |#1|) (-244 |#2| |#1|) (-572))) (-15 -2390 ((-638 (-244 |#2| |#1|)) (-238 (-927 |#1|)) (-638 (-244 |#2| |#1|)))) (-15 -4192 ((-1264))) (-15 -4280 ((-1264))) (-15 -1915 ((-244 |#2| |#1|) (-244 |#2| |#1|))) (-15 -1413 ((-973 |#1|) (-638 |#1|))) (-15 -4543 ((-973 |#1|) (-927 |#1|))) (-15 -1956 ((-638 (-927 |#1|)) (-973 |#1|))) (-15 -4265 ((-638 (-973 |#1|)) (-638 (-973 |#1|)))) (-15 -2091 ((-685 |#1|) (-238 (-927 |#1|)) (-238 (-927 |#1|)))) (-15 -2091 ((-685 |#1|) (-238 (-927 |#1|)) (-638 (-927 |#1|)))) (-15 -2653 ((-638 (-927 |#1|)))) (-15 -3391 ((-244 |#2| |#1|))) (-15 -1774 ((-769))) (-15 -1639 ((-572))) (-15 -3064 ((-638 (-261 (-517 |#1| |#2| |#3|))))) (-15 -3548 ((-638 (-261 (-517 |#1| |#2| |#3|))))) (-15 -3356 ((-638 (-973 |#1|)))) (-15 -2194 ((-638 (-973 |#1|)))) (-15 -1534 ((-780 |#1|) (-244 |#2| |#1|) (-927 |#1|))) (-15 -2528 ((-638 (-413 (-244 |#2| |#1|))) (-238 (-927 |#1|)) (-769))) (-15 -2528 ((-2 (|:| |num| (-638 (-244 |#2| |#1|))) (|:| |den| (-244 |#2| |#1|))) (-238 (-927 |#1|)))) (-15 -2715 ((-2 (|:| -3306 (-572)) (|:| |num| (-244 |#2| |#1|)) (|:| |den| (-244 |#2| |#1|)) (|:| |upTo| (-572))) (-238 (-927 |#1|)) (-572) (-572))) (-15 -3711 ((-638 (-244 |#2| |#1|)) (-238 (-927 |#1|)) (-769))) (-15 -4485 (|#1| (-244 |#2| |#1|) (-927 |#1|))) (-15 -4485 (|#1| (-244 |#2| |#1|) (-244 |#2| |#1|) (-927 |#1|))) (-15 -4485 (|#1| (-413 (-244 |#2| |#1|)) (-927 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-244 |#2| |#1|) (-927 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-244 |#2| |#1|) (-244 |#2| |#1|) (-927 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-413 (-244 |#2| |#1|)) (-927 |#1|))) (-15 -2420 ((-238 (-927 |#1|)) (-244 |#2| |#1|))) (-15 -4457 ((-238 (-927 |#1|)))) (IF (|has| |#1| (-374)) (PROGN (-15 -3282 ((-1166 (-572)))) (-15 -3282 ((-1166 (-572)) (-923))) (-15 -3426 ((-572))) (-15 -2201 ((-638 (-927 |#1|)) (-923))) (-15 -4183 ((-572) (-923))) (-15 -2931 ((-572) (-923))) (-15 -1613 ((-572) (-923) (-923))) (-15 -3647 ((-1254 (-572) -3512))) (-15 -3647 ((-1254 (-572) -3512) (-923)))) |noBranch|)) (-368) (-638 (-1170)) (-117)) (T -874)) 
-((-3647 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-3647 (*1 *2) (-12 (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1613 (*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-2931 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-4183 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-2201 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-638 (-927 *4))) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-3426 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3282 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 (-572))) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-3282 (*1 *2) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-4457 (*1 *2) (-12 (-5 *2 (-238 (-927 *3))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-2420 (*1 *2 *3) (-12 (-5 *3 (-244 *5 *4)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *2 (-238 (-927 *4))) (-5 *1 (-874 *4 *5 *6)) (-4 *6 (-117)))) (-2655 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-244 *5 *2))) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) (-2655 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-244 *5 *2)) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) (-2655 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-244 *5 *2)) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) (-4485 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-244 *5 *2))) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) (-4485 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-244 *5 *2)) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) (-4485 (*1 *2 *3 *4) (-12 (-5 *3 (-244 *5 *2)) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) (-3711 (*1 *2 *3 *4) (-12 (-5 *3 (-238 (-927 *5))) (-5 *4 (-769)) (-4 *5 (-368)) (-5 *2 (-638 (-244 *6 *5))) (-5 *1 (-874 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) (-2715 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-238 (-927 *5))) (-4 *5 (-368)) (-5 *2 (-2 (|:| -3306 (-572)) (|:| |num| (-244 *6 *5)) (|:| |den| (-244 *6 *5)) (|:| |upTo| (-572)))) (-5 *1 (-874 *5 *6 *7)) (-5 *4 (-572)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) (-2528 (*1 *2 *3) (-12 (-5 *3 (-238 (-927 *4))) (-4 *4 (-368)) (-5 *2 (-2 (|:| |num| (-638 (-244 *5 *4))) (|:| |den| (-244 *5 *4)))) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-2528 (*1 *2 *3 *4) (-12 (-5 *3 (-238 (-927 *5))) (-5 *4 (-769)) (-4 *5 (-368)) (-5 *2 (-638 (-413 (-244 *6 *5)))) (-5 *1 (-874 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) (-1534 (*1 *2 *3 *4) (-12 (-5 *3 (-244 *6 *5)) (-5 *4 (-927 *5)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-5 *2 (-780 *5)) (-5 *1 (-874 *5 *6 *7)) (-4 *7 (-117)))) (-2194 (*1 *2) (-12 (-5 *2 (-638 (-973 *3))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3356 (*1 *2) (-12 (-5 *2 (-638 (-973 *3))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3548 (*1 *2) (-12 (-5 *2 (-638 (-261 (-517 *3 *4 *5)))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3064 (*1 *2) (-12 (-5 *2 (-638 (-261 (-517 *3 *4 *5)))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1639 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1774 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-3391 (*1 *2) (-12 (-5 *2 (-244 *4 *3)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-2653 (*1 *2) (-12 (-5 *2 (-638 (-927 *3))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-2091 (*1 *2 *3 *4) (-12 (-5 *3 (-238 (-927 *5))) (-5 *4 (-638 (-927 *5))) (-4 *5 (-368)) (-5 *2 (-685 *5)) (-5 *1 (-874 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) (-2091 (*1 *2 *3 *3) (-12 (-5 *3 (-238 (-927 *4))) (-4 *4 (-368)) (-5 *2 (-685 *4)) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-4265 (*1 *2 *2) (-12 (-5 *2 (-638 (-973 *3))) (-4 *3 (-368)) (-5 *1 (-874 *3 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-1956 (*1 *2 *3) (-12 (-5 *3 (-973 *4)) (-4 *4 (-368)) (-5 *2 (-638 (-927 *4))) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-4543 (*1 *2 *3) (-12 (-5 *3 (-927 *4)) (-4 *4 (-368)) (-5 *2 (-973 *4)) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-1413 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-5 *2 (-973 *4)) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) (-1915 (*1 *2 *2) (-12 (-5 *2 (-244 *4 *3)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-5 *1 (-874 *3 *4 *5)) (-4 *5 (-117)))) (-4280 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-4192 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) (-2390 (*1 *2 *3 *2) (-12 (-5 *2 (-638 (-244 *5 *4))) (-5 *3 (-238 (-927 *4))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *1 (-874 *4 *5 *6)) (-4 *6 (-117)))) (-3991 (*1 *2 *2 *3) (-12 (-5 *2 (-244 *5 *4)) (-5 *3 (-572)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *1 (-874 *4 *5 *6)) (-4 *6 (-117))))) 
-(-10 -7 (-15 -3991 ((-244 |#2| |#1|) (-244 |#2| |#1|) (-572))) (-15 -2390 ((-638 (-244 |#2| |#1|)) (-238 (-927 |#1|)) (-638 (-244 |#2| |#1|)))) (-15 -4192 ((-1264))) (-15 -4280 ((-1264))) (-15 -1915 ((-244 |#2| |#1|) (-244 |#2| |#1|))) (-15 -1413 ((-973 |#1|) (-638 |#1|))) (-15 -4543 ((-973 |#1|) (-927 |#1|))) (-15 -1956 ((-638 (-927 |#1|)) (-973 |#1|))) (-15 -4265 ((-638 (-973 |#1|)) (-638 (-973 |#1|)))) (-15 -2091 ((-685 |#1|) (-238 (-927 |#1|)) (-238 (-927 |#1|)))) (-15 -2091 ((-685 |#1|) (-238 (-927 |#1|)) (-638 (-927 |#1|)))) (-15 -2653 ((-638 (-927 |#1|)))) (-15 -3391 ((-244 |#2| |#1|))) (-15 -1774 ((-769))) (-15 -1639 ((-572))) (-15 -3064 ((-638 (-261 (-517 |#1| |#2| |#3|))))) (-15 -3548 ((-638 (-261 (-517 |#1| |#2| |#3|))))) (-15 -3356 ((-638 (-973 |#1|)))) (-15 -2194 ((-638 (-973 |#1|)))) (-15 -1534 ((-780 |#1|) (-244 |#2| |#1|) (-927 |#1|))) (-15 -2528 ((-638 (-413 (-244 |#2| |#1|))) (-238 (-927 |#1|)) (-769))) (-15 -2528 ((-2 (|:| |num| (-638 (-244 |#2| |#1|))) (|:| |den| (-244 |#2| |#1|))) (-238 (-927 |#1|)))) (-15 -2715 ((-2 (|:| -3306 (-572)) (|:| |num| (-244 |#2| |#1|)) (|:| |den| (-244 |#2| |#1|)) (|:| |upTo| (-572))) (-238 (-927 |#1|)) (-572) (-572))) (-15 -3711 ((-638 (-244 |#2| |#1|)) (-238 (-927 |#1|)) (-769))) (-15 -4485 (|#1| (-244 |#2| |#1|) (-927 |#1|))) (-15 -4485 (|#1| (-244 |#2| |#1|) (-244 |#2| |#1|) (-927 |#1|))) (-15 -4485 (|#1| (-413 (-244 |#2| |#1|)) (-927 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-244 |#2| |#1|) (-927 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-244 |#2| |#1|) (-244 |#2| |#1|) (-927 |#1|))) (-15 -2655 ((-3 |#1| "failed") (-413 (-244 |#2| |#1|)) (-927 |#1|))) (-15 -2420 ((-238 (-927 |#1|)) (-244 |#2| |#1|))) (-15 -4457 ((-238 (-927 |#1|)))) (IF (|has| |#1| (-374)) (PROGN (-15 -3282 ((-1166 (-572)))) (-15 -3282 ((-1166 (-572)) (-923))) (-15 -3426 ((-572))) (-15 -2201 ((-638 (-927 |#1|)) (-923))) (-15 -4183 ((-572) (-923))) (-15 -2931 ((-572) (-923))) (-15 -1613 ((-572) (-923) (-923))) (-15 -3647 ((-1254 (-572) -3512))) (-15 -3647 ((-1254 (-572) -3512) (-923)))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-4143 (((-572) $) 15)) (-2228 (($ (-159)) 11)) (-3787 (($ (-159)) 12)) (-1658 (((-1152) $) NIL)) (-2132 (((-159) $) 13)) (-2607 (((-1116) $) NIL)) (-3465 (($ (-159)) 9)) (-2745 (($ (-159)) 8)) (-3972 (((-856) $) 23) (($ (-159)) 16)) (-1850 (($ (-159)) 10)) (-1324 (((-121) $ $) NIL))) 
-(((-875) (-13 (-1098) (-10 -8 (-15 -2745 ($ (-159))) (-15 -3465 ($ (-159))) (-15 -1850 ($ (-159))) (-15 -2228 ($ (-159))) (-15 -3787 ($ (-159))) (-15 -2132 ((-159) $)) (-15 -4143 ((-572) $)) (-15 -3972 ($ (-159)))))) (T -875)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875)))) (-3465 (*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875)))) (-1850 (*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875)))) (-2228 (*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875)))) (-3787 (*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875)))) (-2132 (*1 *2 *1) (-12 (-5 *2 (-159)) (-5 *1 (-875)))) (-4143 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-875)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875))))) 
-(-13 (-1098) (-10 -8 (-15 -2745 ($ (-159))) (-15 -3465 ($ (-159))) (-15 -1850 ($ (-159))) (-15 -2228 ($ (-159))) (-15 -3787 ($ (-159))) (-15 -2132 ((-159) $)) (-15 -4143 ((-572) $)) (-15 -3972 ($ (-159))))) 
-((-3972 (((-312 (-572)) (-413 (-959 (-53)))) 21) (((-312 (-572)) (-959 (-53))) 16))) 
-(((-876) (-10 -7 (-15 -3972 ((-312 (-572)) (-959 (-53)))) (-15 -3972 ((-312 (-572)) (-413 (-959 (-53))))))) (T -876)) 
-((-3972 (*1 *2 *3) (-12 (-5 *3 (-413 (-959 (-53)))) (-5 *2 (-312 (-572))) (-5 *1 (-876)))) (-3972 (*1 *2 *3) (-12 (-5 *3 (-959 (-53))) (-5 *2 (-312 (-572))) (-5 *1 (-876))))) 
-(-10 -7 (-15 -3972 ((-312 (-572)) (-959 (-53)))) (-15 -3972 ((-312 (-572)) (-413 (-959 (-53)))))) 
-((-1534 ((|#6| |#3| |#7| (-572)) 36) ((|#6| |#3| |#3| |#7|) 33) ((|#6| |#3| |#7|) 31) ((|#6| |#3| (-638 |#6|)) 28))) 
-(((-877 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -1534 (|#6| |#3| (-638 |#6|))) (-15 -1534 (|#6| |#3| |#7|)) (-15 -1534 (|#6| |#3| |#3| |#7|)) (-15 -1534 (|#6| |#3| |#7| (-572)))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|) (-645 |#1|) (-926 |#1| |#6|)) (T -877)) 
-((-1534 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-572)) (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *2 (-645 *6)) (-5 *1 (-877 *6 *7 *3 *8 *9 *2 *4)) (-4 *3 (-956 *6 *8 (-858 *7))) (-4 *9 (-978 *6)) (-4 *4 (-926 *6 *2)))) (-1534 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *2 (-645 *5)) (-5 *1 (-877 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)) (-4 *4 (-926 *5 *2)))) (-1534 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *2 (-645 *5)) (-5 *1 (-877 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)) (-4 *4 (-926 *5 *2)))) (-1534 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *2)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *2 (-645 *5)) (-5 *1 (-877 *5 *6 *3 *7 *8 *2 *9)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)) (-4 *9 (-926 *5 *2))))) 
-(-10 -7 (-15 -1534 (|#6| |#3| (-638 |#6|))) (-15 -1534 (|#6| |#3| |#7|)) (-15 -1534 (|#6| |#3| |#3| |#7|)) (-15 -1534 (|#6| |#3| |#7| (-572)))) 
-((-3828 (((-879 |#2|) (-1 |#2| |#1|) (-879 |#1|)) 14))) 
-(((-878 |#1| |#2|) (-10 -7 (-15 -3828 ((-879 |#2|) (-1 |#2| |#1|) (-879 |#1|)))) (-1204) (-1204)) (T -878)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-879 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-879 *6)) (-5 *1 (-878 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-879 |#2|) (-1 |#2| |#1|) (-879 |#1|)))) 
-((-3702 (($ |#1| |#1|) 8)) (-1897 ((|#1| $ (-769)) 10))) 
-(((-879 |#1|) (-10 -8 (-15 -3702 ($ |#1| |#1|)) (-15 -1897 (|#1| $ (-769)))) (-1204)) (T -879)) 
-((-1897 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *1 (-879 *2)) (-4 *2 (-1204)))) (-3702 (*1 *1 *2 *2) (-12 (-5 *1 (-879 *2)) (-4 *2 (-1204))))) 
-(-10 -8 (-15 -3702 ($ |#1| |#1|)) (-15 -1897 (|#1| $ (-769)))) 
-((-3828 (((-881 |#2|) (-1 |#2| |#1|) (-881 |#1|)) 14))) 
-(((-880 |#1| |#2|) (-10 -7 (-15 -3828 ((-881 |#2|) (-1 |#2| |#1|) (-881 |#1|)))) (-1204) (-1204)) (T -880)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-881 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-881 *6)) (-5 *1 (-880 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-881 |#2|) (-1 |#2| |#1|) (-881 |#1|)))) 
-((-3702 (($ |#1| |#1| |#1|) 8)) (-1897 ((|#1| $ (-769)) 10))) 
-(((-881 |#1|) (-10 -8 (-15 -3702 ($ |#1| |#1| |#1|)) (-15 -1897 (|#1| $ (-769)))) (-1204)) (T -881)) 
-((-1897 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *1 (-881 *2)) (-4 *2 (-1204)))) (-3702 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-881 *2)) (-4 *2 (-1204))))) 
-(-10 -8 (-15 -3702 ($ |#1| |#1| |#1|)) (-15 -1897 (|#1| $ (-769)))) 
-((-3828 (((-883 |#2|) (-1 |#2| |#1|) (-883 |#1|)) 14))) 
-(((-882 |#1| |#2|) (-10 -7 (-15 -3828 ((-883 |#2|) (-1 |#2| |#1|) (-883 |#1|)))) (-1204) (-1204)) (T -882)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-883 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-883 *6)) (-5 *1 (-882 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-883 |#2|) (-1 |#2| |#1|) (-883 |#1|)))) 
-((-1532 (($ |#1| |#1| |#1|) 8)) (-1897 ((|#1| $ (-769)) 10))) 
-(((-883 |#1|) (-10 -8 (-15 -1532 ($ |#1| |#1| |#1|)) (-15 -1897 (|#1| $ (-769)))) (-1204)) (T -883)) 
-((-1897 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *1 (-883 *2)) (-4 *2 (-1204)))) (-1532 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-883 *2)) (-4 *2 (-1204))))) 
-(-10 -8 (-15 -1532 ($ |#1| |#1| |#1|)) (-15 -1897 (|#1| $ (-769)))) 
-((-2980 (((-1150 (-638 (-572))) (-638 (-572)) (-1150 (-638 (-572)))) 30)) (-1895 (((-1150 (-638 (-572))) (-638 (-572)) (-638 (-572))) 26)) (-1495 (((-1150 (-638 (-572))) (-638 (-572))) 39) (((-1150 (-638 (-572))) (-638 (-572)) (-638 (-572))) 38)) (-1671 (((-1150 (-638 (-572))) (-572)) 40)) (-4556 (((-1150 (-638 (-572))) (-572) (-572)) 22) (((-1150 (-638 (-572))) (-572)) 16) (((-1150 (-638 (-572))) (-572) (-572) (-572)) 12)) (-1795 (((-1150 (-638 (-572))) (-1150 (-638 (-572)))) 24)) (-3018 (((-638 (-572)) (-638 (-572))) 23))) 
-(((-884) (-10 -7 (-15 -4556 ((-1150 (-638 (-572))) (-572) (-572) (-572))) (-15 -4556 ((-1150 (-638 (-572))) (-572))) (-15 -4556 ((-1150 (-638 (-572))) (-572) (-572))) (-15 -3018 ((-638 (-572)) (-638 (-572)))) (-15 -1795 ((-1150 (-638 (-572))) (-1150 (-638 (-572))))) (-15 -1895 ((-1150 (-638 (-572))) (-638 (-572)) (-638 (-572)))) (-15 -2980 ((-1150 (-638 (-572))) (-638 (-572)) (-1150 (-638 (-572))))) (-15 -1495 ((-1150 (-638 (-572))) (-638 (-572)) (-638 (-572)))) (-15 -1495 ((-1150 (-638 (-572))) (-638 (-572)))) (-15 -1671 ((-1150 (-638 (-572))) (-572))))) (T -884)) 
-((-1671 (*1 *2 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-572)))) (-1495 (*1 *2 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-638 (-572))))) (-1495 (*1 *2 *3 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-638 (-572))))) (-2980 (*1 *2 *3 *2) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *3 (-638 (-572))) (-5 *1 (-884)))) (-1895 (*1 *2 *3 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-638 (-572))))) (-1795 (*1 *2 *2) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)))) (-3018 (*1 *2 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-884)))) (-4556 (*1 *2 *3 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-572)))) (-4556 (*1 *2 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-572)))) (-4556 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-572))))) 
-(-10 -7 (-15 -4556 ((-1150 (-638 (-572))) (-572) (-572) (-572))) (-15 -4556 ((-1150 (-638 (-572))) (-572))) (-15 -4556 ((-1150 (-638 (-572))) (-572) (-572))) (-15 -3018 ((-638 (-572)) (-638 (-572)))) (-15 -1795 ((-1150 (-638 (-572))) (-1150 (-638 (-572))))) (-15 -1895 ((-1150 (-638 (-572))) (-638 (-572)) (-638 (-572)))) (-15 -2980 ((-1150 (-638 (-572))) (-638 (-572)) (-1150 (-638 (-572))))) (-15 -1495 ((-1150 (-638 (-572))) (-638 (-572)) (-638 (-572)))) (-15 -1495 ((-1150 (-638 (-572))) (-638 (-572)))) (-15 -1671 ((-1150 (-638 (-572))) (-572)))) 
-((-4081 (((-893 (-385)) $) 9 (|has| |#1| (-613 (-893 (-385))))) (((-893 (-572)) $) 8 (|has| |#1| (-613 (-893 (-572))))))) 
-(((-885 |#1|) (-1290) (-1204)) (T -885)) 
-NIL 
-(-13 (-10 -7 (IF (|has| |t#1| (-613 (-893 (-572)))) (-6 (-613 (-893 (-572)))) |noBranch|) (IF (|has| |t#1| (-613 (-893 (-385)))) (-6 (-613 (-893 (-385)))) |noBranch|))) 
-(((-613 (-893 (-385))) |has| |#1| (-613 (-893 (-385)))) ((-613 (-893 (-572))) |has| |#1| (-613 (-893 (-572))))) 
-((-2262 (((-121) $ $) NIL)) (-1364 (($) 14)) (-3220 (($ (-890 |#1| |#2|) (-890 |#1| |#3|)) 27)) (-3566 (((-890 |#1| |#3|) $) 16)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2952 (((-121) $) 22)) (-1638 (($) 19)) (-3972 (((-856) $) 30)) (-2769 (((-890 |#1| |#2|) $) 15)) (-1324 (((-121) $ $) 25))) 
-(((-886 |#1| |#2| |#3|) (-13 (-1098) (-10 -8 (-15 -2952 ((-121) $)) (-15 -1638 ($)) (-15 -1364 ($)) (-15 -3220 ($ (-890 |#1| |#2|) (-890 |#1| |#3|))) (-15 -2769 ((-890 |#1| |#2|) $)) (-15 -3566 ((-890 |#1| |#3|) $)))) (-1098) (-1098) (-662 |#2|)) (T -886)) 
-((-2952 (*1 *2 *1) (-12 (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-886 *3 *4 *5)) (-4 *3 (-1098)) (-4 *5 (-662 *4)))) (-1638 (*1 *1) (-12 (-4 *3 (-1098)) (-5 *1 (-886 *2 *3 *4)) (-4 *2 (-1098)) (-4 *4 (-662 *3)))) (-1364 (*1 *1) (-12 (-4 *3 (-1098)) (-5 *1 (-886 *2 *3 *4)) (-4 *2 (-1098)) (-4 *4 (-662 *3)))) (-3220 (*1 *1 *2 *3) (-12 (-5 *2 (-890 *4 *5)) (-5 *3 (-890 *4 *6)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-662 *5)) (-5 *1 (-886 *4 *5 *6)))) (-2769 (*1 *2 *1) (-12 (-4 *4 (-1098)) (-5 *2 (-890 *3 *4)) (-5 *1 (-886 *3 *4 *5)) (-4 *3 (-1098)) (-4 *5 (-662 *4)))) (-3566 (*1 *2 *1) (-12 (-4 *4 (-1098)) (-5 *2 (-890 *3 *5)) (-5 *1 (-886 *3 *4 *5)) (-4 *3 (-1098)) (-4 *5 (-662 *4))))) 
-(-13 (-1098) (-10 -8 (-15 -2952 ((-121) $)) (-15 -1638 ($)) (-15 -1364 ($)) (-15 -3220 ($ (-890 |#1| |#2|) (-890 |#1| |#3|))) (-15 -2769 ((-890 |#1| |#2|) $)) (-15 -3566 ((-890 |#1| |#3|) $)))) 
-((-2262 (((-121) $ $) 7)) (-3103 (((-890 |#1| $) $ (-893 |#1|) (-890 |#1| $)) 12)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-887 |#1|) (-1290) (-1098)) (T -887)) 
-((-3103 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-890 *4 *1)) (-5 *3 (-893 *4)) (-4 *1 (-887 *4)) (-4 *4 (-1098))))) 
-(-13 (-1098) (-10 -8 (-15 -3103 ((-890 |t#1| $) $ (-893 |t#1|) (-890 |t#1| $))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-3291 (((-121) (-638 |#2|) |#3|) 22) (((-121) |#2| |#3|) 17)) (-1386 (((-890 |#1| |#2|) |#2| |#3|) 42 (-12 (-2959 (|has| |#2| (-1044 (-1170)))) (-2959 (|has| |#2| (-1054))))) (((-638 (-290 (-959 |#2|))) |#2| |#3|) 41 (-12 (|has| |#2| (-1054)) (-2959 (|has| |#2| (-1044 (-1170)))))) (((-638 (-290 |#2|)) |#2| |#3|) 34 (|has| |#2| (-1044 (-1170)))) (((-886 |#1| |#2| (-638 |#2|)) (-638 |#2|) |#3|) 20))) 
-(((-888 |#1| |#2| |#3|) (-10 -7 (-15 -3291 ((-121) |#2| |#3|)) (-15 -3291 ((-121) (-638 |#2|) |#3|)) (-15 -1386 ((-886 |#1| |#2| (-638 |#2|)) (-638 |#2|) |#3|)) (IF (|has| |#2| (-1044 (-1170))) (-15 -1386 ((-638 (-290 |#2|)) |#2| |#3|)) (IF (|has| |#2| (-1054)) (-15 -1386 ((-638 (-290 (-959 |#2|))) |#2| |#3|)) (-15 -1386 ((-890 |#1| |#2|) |#2| |#3|))))) (-1098) (-887 |#1|) (-613 (-893 |#1|))) (T -888)) 
-((-1386 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-5 *2 (-890 *5 *3)) (-5 *1 (-888 *5 *3 *4)) (-2959 (-4 *3 (-1044 (-1170)))) (-2959 (-4 *3 (-1054))) (-4 *3 (-887 *5)) (-4 *4 (-613 (-893 *5))))) (-1386 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-5 *2 (-638 (-290 (-959 *3)))) (-5 *1 (-888 *5 *3 *4)) (-4 *3 (-1054)) (-2959 (-4 *3 (-1044 (-1170)))) (-4 *3 (-887 *5)) (-4 *4 (-613 (-893 *5))))) (-1386 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-5 *2 (-638 (-290 *3))) (-5 *1 (-888 *5 *3 *4)) (-4 *3 (-1044 (-1170))) (-4 *3 (-887 *5)) (-4 *4 (-613 (-893 *5))))) (-1386 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *6 (-887 *5)) (-5 *2 (-886 *5 *6 (-638 *6))) (-5 *1 (-888 *5 *6 *4)) (-5 *3 (-638 *6)) (-4 *4 (-613 (-893 *5))))) (-3291 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-4 *6 (-887 *5)) (-4 *5 (-1098)) (-5 *2 (-121)) (-5 *1 (-888 *5 *6 *4)) (-4 *4 (-613 (-893 *5))))) (-3291 (*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-5 *2 (-121)) (-5 *1 (-888 *5 *3 *4)) (-4 *3 (-887 *5)) (-4 *4 (-613 (-893 *5)))))) 
-(-10 -7 (-15 -3291 ((-121) |#2| |#3|)) (-15 -3291 ((-121) (-638 |#2|) |#3|)) (-15 -1386 ((-886 |#1| |#2| (-638 |#2|)) (-638 |#2|) |#3|)) (IF (|has| |#2| (-1044 (-1170))) (-15 -1386 ((-638 (-290 |#2|)) |#2| |#3|)) (IF (|has| |#2| (-1054)) (-15 -1386 ((-638 (-290 (-959 |#2|))) |#2| |#3|)) (-15 -1386 ((-890 |#1| |#2|) |#2| |#3|))))) 
-((-3828 (((-890 |#1| |#3|) (-1 |#3| |#2|) (-890 |#1| |#2|)) 21))) 
-(((-889 |#1| |#2| |#3|) (-10 -7 (-15 -3828 ((-890 |#1| |#3|) (-1 |#3| |#2|) (-890 |#1| |#2|)))) (-1098) (-1098) (-1098)) (T -889)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-890 *5 *6)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-890 *5 *7)) (-5 *1 (-889 *5 *6 *7))))) 
-(-10 -7 (-15 -3828 ((-890 |#1| |#3|) (-1 |#3| |#2|) (-890 |#1| |#2|)))) 
-((-2262 (((-121) $ $) NIL)) (-3518 (($ $ $) 37)) (-1412 (((-3 (-121) "failed") $ (-893 |#1|)) 34)) (-1364 (($) 11)) (-1658 (((-1152) $) NIL)) (-3790 (($ (-893 |#1|) |#2| $) 20)) (-2607 (((-1116) $) NIL)) (-4431 (((-3 |#2| "failed") (-893 |#1|) $) 48)) (-2952 (((-121) $) 14)) (-1638 (($) 12)) (-4323 (((-638 (-2 (|:| -4111 (-1170)) (|:| -4320 |#2|))) $) 25)) (-3921 (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 |#2|)))) 23)) (-3972 (((-856) $) 42)) (-1785 (($ (-893 |#1|) |#2| $ |#2|) 46)) (-2353 (($ (-893 |#1|) |#2| $) 45)) (-1324 (((-121) $ $) 39))) 
-(((-890 |#1| |#2|) (-13 (-1098) (-10 -8 (-15 -2952 ((-121) $)) (-15 -1638 ($)) (-15 -1364 ($)) (-15 -3518 ($ $ $)) (-15 -4431 ((-3 |#2| "failed") (-893 |#1|) $)) (-15 -2353 ($ (-893 |#1|) |#2| $)) (-15 -3790 ($ (-893 |#1|) |#2| $)) (-15 -1785 ($ (-893 |#1|) |#2| $ |#2|)) (-15 -4323 ((-638 (-2 (|:| -4111 (-1170)) (|:| -4320 |#2|))) $)) (-15 -3921 ($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 |#2|))))) (-15 -1412 ((-3 (-121) "failed") $ (-893 |#1|))))) (-1098) (-1098)) (T -890)) 
-((-2952 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-890 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-1638 (*1 *1) (-12 (-5 *1 (-890 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) (-1364 (*1 *1) (-12 (-5 *1 (-890 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) (-3518 (*1 *1 *1 *1) (-12 (-5 *1 (-890 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) (-4431 (*1 *2 *3 *1) (|partial| -12 (-5 *3 (-893 *4)) (-4 *4 (-1098)) (-4 *2 (-1098)) (-5 *1 (-890 *4 *2)))) (-2353 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-893 *4)) (-4 *4 (-1098)) (-5 *1 (-890 *4 *3)) (-4 *3 (-1098)))) (-3790 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-893 *4)) (-4 *4 (-1098)) (-5 *1 (-890 *4 *3)) (-4 *3 (-1098)))) (-1785 (*1 *1 *2 *3 *1 *3) (-12 (-5 *2 (-893 *4)) (-4 *4 (-1098)) (-5 *1 (-890 *4 *3)) (-4 *3 (-1098)))) (-4323 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 *4)))) (-5 *1 (-890 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-3921 (*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 *4)))) (-4 *4 (-1098)) (-5 *1 (-890 *3 *4)) (-4 *3 (-1098)))) (-1412 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-893 *4)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-890 *4 *5)) (-4 *5 (-1098))))) 
-(-13 (-1098) (-10 -8 (-15 -2952 ((-121) $)) (-15 -1638 ($)) (-15 -1364 ($)) (-15 -3518 ($ $ $)) (-15 -4431 ((-3 |#2| "failed") (-893 |#1|) $)) (-15 -2353 ($ (-893 |#1|) |#2| $)) (-15 -3790 ($ (-893 |#1|) |#2| $)) (-15 -1785 ($ (-893 |#1|) |#2| $ |#2|)) (-15 -4323 ((-638 (-2 (|:| -4111 (-1170)) (|:| -4320 |#2|))) $)) (-15 -3921 ($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 |#2|))))) (-15 -1412 ((-3 (-121) "failed") $ (-893 |#1|))))) 
-((-3405 (((-893 |#1|) (-893 |#1|) (-638 (-1170)) (-1 (-121) (-638 |#2|))) 30) (((-893 |#1|) (-893 |#1|) (-638 (-1 (-121) |#2|))) 42) (((-893 |#1|) (-893 |#1|) (-1 (-121) |#2|)) 33)) (-1412 (((-121) (-638 |#2|) (-893 |#1|)) 39) (((-121) |#2| (-893 |#1|)) 35)) (-3106 (((-1 (-121) |#2|) (-893 |#1|)) 14)) (-4303 (((-638 |#2|) (-893 |#1|)) 23)) (-2191 (((-893 |#1|) (-893 |#1|) |#2|) 19))) 
-(((-891 |#1| |#2|) (-10 -7 (-15 -3405 ((-893 |#1|) (-893 |#1|) (-1 (-121) |#2|))) (-15 -3405 ((-893 |#1|) (-893 |#1|) (-638 (-1 (-121) |#2|)))) (-15 -3405 ((-893 |#1|) (-893 |#1|) (-638 (-1170)) (-1 (-121) (-638 |#2|)))) (-15 -3106 ((-1 (-121) |#2|) (-893 |#1|))) (-15 -1412 ((-121) |#2| (-893 |#1|))) (-15 -1412 ((-121) (-638 |#2|) (-893 |#1|))) (-15 -2191 ((-893 |#1|) (-893 |#1|) |#2|)) (-15 -4303 ((-638 |#2|) (-893 |#1|)))) (-1098) (-1204)) (T -891)) 
-((-4303 (*1 *2 *3) (-12 (-5 *3 (-893 *4)) (-4 *4 (-1098)) (-5 *2 (-638 *5)) (-5 *1 (-891 *4 *5)) (-4 *5 (-1204)))) (-2191 (*1 *2 *2 *3) (-12 (-5 *2 (-893 *4)) (-4 *4 (-1098)) (-5 *1 (-891 *4 *3)) (-4 *3 (-1204)))) (-1412 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *6 (-1204)) (-5 *2 (-121)) (-5 *1 (-891 *5 *6)))) (-1412 (*1 *2 *3 *4) (-12 (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-5 *2 (-121)) (-5 *1 (-891 *5 *3)) (-4 *3 (-1204)))) (-3106 (*1 *2 *3) (-12 (-5 *3 (-893 *4)) (-4 *4 (-1098)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-891 *4 *5)) (-4 *5 (-1204)))) (-3405 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-893 *5)) (-5 *3 (-638 (-1170))) (-5 *4 (-1 (-121) (-638 *6))) (-4 *5 (-1098)) (-4 *6 (-1204)) (-5 *1 (-891 *5 *6)))) (-3405 (*1 *2 *2 *3) (-12 (-5 *2 (-893 *4)) (-5 *3 (-638 (-1 (-121) *5))) (-4 *4 (-1098)) (-4 *5 (-1204)) (-5 *1 (-891 *4 *5)))) (-3405 (*1 *2 *2 *3) (-12 (-5 *2 (-893 *4)) (-5 *3 (-1 (-121) *5)) (-4 *4 (-1098)) (-4 *5 (-1204)) (-5 *1 (-891 *4 *5))))) 
-(-10 -7 (-15 -3405 ((-893 |#1|) (-893 |#1|) (-1 (-121) |#2|))) (-15 -3405 ((-893 |#1|) (-893 |#1|) (-638 (-1 (-121) |#2|)))) (-15 -3405 ((-893 |#1|) (-893 |#1|) (-638 (-1170)) (-1 (-121) (-638 |#2|)))) (-15 -3106 ((-1 (-121) |#2|) (-893 |#1|))) (-15 -1412 ((-121) |#2| (-893 |#1|))) (-15 -1412 ((-121) (-638 |#2|) (-893 |#1|))) (-15 -2191 ((-893 |#1|) (-893 |#1|) |#2|)) (-15 -4303 ((-638 |#2|) (-893 |#1|)))) 
-((-3828 (((-893 |#2|) (-1 |#2| |#1|) (-893 |#1|)) 17))) 
-(((-892 |#1| |#2|) (-10 -7 (-15 -3828 ((-893 |#2|) (-1 |#2| |#1|) (-893 |#1|)))) (-1098) (-1098)) (T -892)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-893 *6)) (-5 *1 (-892 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-893 |#2|) (-1 |#2| |#1|) (-893 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1315 (($ $ (-638 (-57))) 62)) (-3456 (((-638 $) $) 116)) (-1457 (((-2 (|:| |var| (-638 (-1170))) (|:| |pred| (-57))) $) 22)) (-2150 (((-121) $) 29)) (-3232 (($ $ (-638 (-1170)) (-57)) 24)) (-2058 (($ $ (-638 (-57))) 61)) (-3376 (((-3 |#1| "failed") $) 59) (((-3 (-1170) "failed") $) 138)) (-1318 ((|#1| $) 55) (((-1170) $) NIL)) (-1329 (($ $) 106)) (-2610 (((-121) $) 45)) (-4372 (((-638 (-57)) $) 43)) (-2595 (($ (-1170) (-121) (-121) (-121)) 63)) (-4137 (((-3 (-638 $) "failed") (-638 $)) 70)) (-3332 (((-121) $) 48)) (-2367 (((-121) $) 47)) (-1658 (((-1152) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) 34)) (-3978 (((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $) 41)) (-2472 (((-3 (-2 (|:| |val| $) (|:| -3751 $)) "failed") $) 81)) (-2336 (((-3 (-638 $) "failed") $) 31)) (-3419 (((-3 (-638 $) "failed") $ (-123)) 105) (((-3 (-2 (|:| -1824 (-123)) (|:| |arg| (-638 $))) "failed") $) 93)) (-2940 (((-3 (-638 $) "failed") $) 35)) (-3019 (((-3 (-2 (|:| |val| $) (|:| -3751 (-769))) "failed") $) 38)) (-4497 (((-121) $) 28)) (-2607 (((-1116) $) NIL)) (-1749 (((-121) $) 20)) (-2529 (((-121) $) 44)) (-2905 (((-638 (-57)) $) 109)) (-1878 (((-121) $) 46)) (-3277 (($ (-123) (-638 $)) 90)) (-1564 (((-769) $) 27)) (-1607 (($ $) 60)) (-4081 (($ (-638 $)) 57)) (-2580 (((-121) $) 25)) (-3972 (((-856) $) 50) (($ |#1|) 18) (($ (-1170)) 64)) (-2191 (($ $ (-57)) 108)) (-2378 (($) 89 T CONST)) (-3255 (($) 71 T CONST)) (-1324 (((-121) $ $) 77)) (-1379 (($ $ $) 98)) (-1367 (($ $ $) 102)) (** (($ $ (-769)) 97) (($ $ $) 51)) (* (($ $ $) 103))) 
-(((-893 |#1|) (-13 (-1098) (-1044 |#1|) (-1044 (-1170)) (-10 -8 (-15 0 ($) -3211) (-15 1 ($) -3211) (-15 -2336 ((-3 (-638 $) "failed") $)) (-15 -1921 ((-3 (-638 $) "failed") $)) (-15 -3419 ((-3 (-638 $) "failed") $ (-123))) (-15 -3419 ((-3 (-2 (|:| -1824 (-123)) (|:| |arg| (-638 $))) "failed") $)) (-15 -3019 ((-3 (-2 (|:| |val| $) (|:| -3751 (-769))) "failed") $)) (-15 -3978 ((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $)) (-15 -2940 ((-3 (-638 $) "failed") $)) (-15 -2472 ((-3 (-2 (|:| |val| $) (|:| -3751 $)) "failed") $)) (-15 -3277 ($ (-123) (-638 $))) (-15 -1367 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-769))) (-15 ** ($ $ $)) (-15 -1379 ($ $ $)) (-15 -1564 ((-769) $)) (-15 -4081 ($ (-638 $))) (-15 -1607 ($ $)) (-15 -4497 ((-121) $)) (-15 -2610 ((-121) $)) (-15 -2150 ((-121) $)) (-15 -2580 ((-121) $)) (-15 -1878 ((-121) $)) (-15 -2367 ((-121) $)) (-15 -3332 ((-121) $)) (-15 -2529 ((-121) $)) (-15 -4372 ((-638 (-57)) $)) (-15 -2058 ($ $ (-638 (-57)))) (-15 -1315 ($ $ (-638 (-57)))) (-15 -2595 ($ (-1170) (-121) (-121) (-121))) (-15 -3232 ($ $ (-638 (-1170)) (-57))) (-15 -1457 ((-2 (|:| |var| (-638 (-1170))) (|:| |pred| (-57))) $)) (-15 -1749 ((-121) $)) (-15 -1329 ($ $)) (-15 -2191 ($ $ (-57))) (-15 -2905 ((-638 (-57)) $)) (-15 -3456 ((-638 $) $)) (-15 -4137 ((-3 (-638 $) "failed") (-638 $))))) (-1098)) (T -893)) 
-((-2378 (*1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) (-3255 (*1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) (-2336 (*1 *2 *1) (|partial| -12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-1921 (*1 *2 *1) (|partial| -12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-3419 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-638 (-893 *4))) (-5 *1 (-893 *4)) (-4 *4 (-1098)))) (-3419 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| -1824 (-123)) (|:| |arg| (-638 (-893 *3))))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-3019 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-893 *3)) (|:| -3751 (-769)))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-3978 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |num| (-893 *3)) (|:| |den| (-893 *3)))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2940 (*1 *2 *1) (|partial| -12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2472 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-893 *3)) (|:| -3751 (-893 *3)))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-3277 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-638 (-893 *4))) (-5 *1 (-893 *4)) (-4 *4 (-1098)))) (-1367 (*1 *1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (** (*1 *1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) (-1379 (*1 *1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) (-1564 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-1607 (*1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) (-4497 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2610 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2150 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2580 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-1878 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2367 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-3332 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2529 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-4372 (*1 *2 *1) (-12 (-5 *2 (-638 (-57))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2058 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-57))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-1315 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-57))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2595 (*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-121)) (-5 *1 (-893 *4)) (-4 *4 (-1098)))) (-3232 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-57)) (-5 *1 (-893 *4)) (-4 *4 (-1098)))) (-1457 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |var| (-638 (-1170))) (|:| |pred| (-57)))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-1749 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-1329 (*1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) (-2191 (*1 *1 *1 *2) (-12 (-5 *2 (-57)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-2905 (*1 *2 *1) (-12 (-5 *2 (-638 (-57))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-3456 (*1 *2 *1) (-12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) (-4137 (*1 *2 *2) (|partial| -12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(-13 (-1098) (-1044 |#1|) (-1044 (-1170)) (-10 -8 (-15 (-2378) ($) -3211) (-15 (-3255) ($) -3211) (-15 -2336 ((-3 (-638 $) "failed") $)) (-15 -1921 ((-3 (-638 $) "failed") $)) (-15 -3419 ((-3 (-638 $) "failed") $ (-123))) (-15 -3419 ((-3 (-2 (|:| -1824 (-123)) (|:| |arg| (-638 $))) "failed") $)) (-15 -3019 ((-3 (-2 (|:| |val| $) (|:| -3751 (-769))) "failed") $)) (-15 -3978 ((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $)) (-15 -2940 ((-3 (-638 $) "failed") $)) (-15 -2472 ((-3 (-2 (|:| |val| $) (|:| -3751 $)) "failed") $)) (-15 -3277 ($ (-123) (-638 $))) (-15 -1367 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-769))) (-15 ** ($ $ $)) (-15 -1379 ($ $ $)) (-15 -1564 ((-769) $)) (-15 -4081 ($ (-638 $))) (-15 -1607 ($ $)) (-15 -4497 ((-121) $)) (-15 -2610 ((-121) $)) (-15 -2150 ((-121) $)) (-15 -2580 ((-121) $)) (-15 -1878 ((-121) $)) (-15 -2367 ((-121) $)) (-15 -3332 ((-121) $)) (-15 -2529 ((-121) $)) (-15 -4372 ((-638 (-57)) $)) (-15 -2058 ($ $ (-638 (-57)))) (-15 -1315 ($ $ (-638 (-57)))) (-15 -2595 ($ (-1170) (-121) (-121) (-121))) (-15 -3232 ($ $ (-638 (-1170)) (-57))) (-15 -1457 ((-2 (|:| |var| (-638 (-1170))) (|:| |pred| (-57))) $)) (-15 -1749 ((-121) $)) (-15 -1329 ($ $)) (-15 -2191 ($ $ (-57))) (-15 -2905 ((-638 (-57)) $)) (-15 -3456 ((-638 $) $)) (-15 -4137 ((-3 (-638 $) "failed") (-638 $))))) 
-((-2262 (((-121) $ $) NIL)) (-2199 (((-638 |#1|) $) 16)) (-1804 (((-121) $) 38)) (-3376 (((-3 (-667 |#1|) "failed") $) 41)) (-1318 (((-667 |#1|) $) 39)) (-1651 (($ $) 18)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-2081 (((-638 (-667 |#1|)) $) 23)) (-3200 (((-769) $) 45)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-667 |#1|) $) 17)) (-3972 (((-856) $) 37) (($ (-667 |#1|)) 21) (((-820 |#1|) $) 27) (($ |#1|) 20)) (-3255 (($) 8 T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 11)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 48))) 
-(((-894 |#1|) (-13 (-848) (-1044 (-667 |#1|)) (-10 -8 (-15 1 ($) -3211) (-15 -3972 ((-820 |#1|) $)) (-15 -3972 ($ |#1|)) (-15 -1837 ((-667 |#1|) $)) (-15 -3200 ((-769) $)) (-15 -2081 ((-638 (-667 |#1|)) $)) (-15 -1651 ($ $)) (-15 -1804 ((-121) $)) (-15 -2199 ((-638 |#1|) $)))) (-848)) (T -894)) 
-((-3255 (*1 *1) (-12 (-5 *1 (-894 *2)) (-4 *2 (-848)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-820 *3)) (-5 *1 (-894 *3)) (-4 *3 (-848)))) (-3972 (*1 *1 *2) (-12 (-5 *1 (-894 *2)) (-4 *2 (-848)))) (-1837 (*1 *2 *1) (-12 (-5 *2 (-667 *3)) (-5 *1 (-894 *3)) (-4 *3 (-848)))) (-3200 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-894 *3)) (-4 *3 (-848)))) (-2081 (*1 *2 *1) (-12 (-5 *2 (-638 (-667 *3))) (-5 *1 (-894 *3)) (-4 *3 (-848)))) (-1651 (*1 *1 *1) (-12 (-5 *1 (-894 *2)) (-4 *2 (-848)))) (-1804 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-894 *3)) (-4 *3 (-848)))) (-2199 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-894 *3)) (-4 *3 (-848))))) 
-(-13 (-848) (-1044 (-667 |#1|)) (-10 -8 (-15 (-3255) ($) -3211) (-15 -3972 ((-820 |#1|) $)) (-15 -3972 ($ |#1|)) (-15 -1837 ((-667 |#1|) $)) (-15 -3200 ((-769) $)) (-15 -2081 ((-638 (-667 |#1|)) $)) (-15 -1651 ($ $)) (-15 -1804 ((-121) $)) (-15 -2199 ((-638 |#1|) $)))) 
-((-2437 ((|#1| |#1| |#1|) 19))) 
-(((-895 |#1| |#2|) (-10 -7 (-15 -2437 (|#1| |#1| |#1|))) (-1234 |#2|) (-1054)) (T -895)) 
-((-2437 (*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-895 *2 *3)) (-4 *2 (-1234 *3))))) 
-(-10 -7 (-15 -2437 (|#1| |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1540 (((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) 13)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2047 (((-1042) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) 12)) (-1324 (((-121) $ $) 6))) 
-(((-896) (-1290)) (T -896)) 
-((-1540 (*1 *2 *3 *4) (-12 (-4 *1 (-896)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)))))) (-2047 (*1 *2 *3) (-12 (-4 *1 (-896)) (-5 *3 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *2 (-1042))))) 
-(-13 (-1098) (-10 -7 (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| |explanations| (-1152))) (-1066) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217))))) (-15 -2047 ((-1042) (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217))))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2842 ((|#1| |#1| (-769)) 23)) (-3717 (((-3 |#1| "failed") |#1| |#1|) 22)) (-2880 (((-3 (-2 (|:| -1866 |#1|) (|:| -1862 |#1|)) "failed") |#1| (-769) (-769)) 26) (((-638 |#1|) |#1|) 28))) 
-(((-897 |#1| |#2|) (-10 -7 (-15 -2880 ((-638 |#1|) |#1|)) (-15 -2880 ((-3 (-2 (|:| -1866 |#1|) (|:| -1862 |#1|)) "failed") |#1| (-769) (-769))) (-15 -3717 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2842 (|#1| |#1| (-769)))) (-1234 |#2|) (-368)) (T -897)) 
-((-2842 (*1 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-368)) (-5 *1 (-897 *2 *4)) (-4 *2 (-1234 *4)))) (-3717 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-368)) (-5 *1 (-897 *2 *3)) (-4 *2 (-1234 *3)))) (-2880 (*1 *2 *3 *4 *4) (|partial| -12 (-5 *4 (-769)) (-4 *5 (-368)) (-5 *2 (-2 (|:| -1866 *3) (|:| -1862 *3))) (-5 *1 (-897 *3 *5)) (-4 *3 (-1234 *5)))) (-2880 (*1 *2 *3) (-12 (-4 *4 (-368)) (-5 *2 (-638 *3)) (-5 *1 (-897 *3 *4)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -2880 ((-638 |#1|) |#1|)) (-15 -2880 ((-3 (-2 (|:| -1866 |#1|) (|:| -1862 |#1|)) "failed") |#1| (-769) (-769))) (-15 -3717 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2842 (|#1| |#1| (-769)))) 
-((-2800 (((-1042) (-385) (-385) (-385) (-385) (-769) (-769) (-638 (-312 (-385))) (-638 (-638 (-312 (-385)))) (-1152)) 92) (((-1042) (-385) (-385) (-385) (-385) (-769) (-769) (-638 (-312 (-385))) (-638 (-638 (-312 (-385)))) (-1152) (-217)) 87) (((-1042) (-899) (-1066)) 76) (((-1042) (-899)) 77)) (-1540 (((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-899) (-1066)) 50) (((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-899)) 52))) 
-(((-898) (-10 -7 (-15 -2800 ((-1042) (-899))) (-15 -2800 ((-1042) (-899) (-1066))) (-15 -2800 ((-1042) (-385) (-385) (-385) (-385) (-769) (-769) (-638 (-312 (-385))) (-638 (-638 (-312 (-385)))) (-1152) (-217))) (-15 -2800 ((-1042) (-385) (-385) (-385) (-385) (-769) (-769) (-638 (-312 (-385))) (-638 (-638 (-312 (-385)))) (-1152))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-899))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-899) (-1066))))) (T -898)) 
-((-1540 (*1 *2 *3 *4) (-12 (-5 *3 (-899)) (-5 *4 (-1066)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-898)))) (-1540 (*1 *2 *3) (-12 (-5 *3 (-899)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-898)))) (-2800 (*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (-12 (-5 *4 (-769)) (-5 *6 (-638 (-638 (-312 *3)))) (-5 *7 (-1152)) (-5 *5 (-638 (-312 (-385)))) (-5 *3 (-385)) (-5 *2 (-1042)) (-5 *1 (-898)))) (-2800 (*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (-12 (-5 *4 (-769)) (-5 *6 (-638 (-638 (-312 *3)))) (-5 *7 (-1152)) (-5 *8 (-217)) (-5 *5 (-638 (-312 (-385)))) (-5 *3 (-385)) (-5 *2 (-1042)) (-5 *1 (-898)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-899)) (-5 *4 (-1066)) (-5 *2 (-1042)) (-5 *1 (-898)))) (-2800 (*1 *2 *3) (-12 (-5 *3 (-899)) (-5 *2 (-1042)) (-5 *1 (-898))))) 
-(-10 -7 (-15 -2800 ((-1042) (-899))) (-15 -2800 ((-1042) (-899) (-1066))) (-15 -2800 ((-1042) (-385) (-385) (-385) (-385) (-769) (-769) (-638 (-312 (-385))) (-638 (-638 (-312 (-385)))) (-1152) (-217))) (-15 -2800 ((-1042) (-385) (-385) (-385) (-385) (-769) (-769) (-638 (-312 (-385))) (-638 (-638 (-312 (-385)))) (-1152))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-899))) (-15 -1540 ((-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152)))) (-899) (-1066)))) 
-((-2262 (((-121) $ $) NIL)) (-1318 (((-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217))) $) 10)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 12) (($ (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) 9)) (-1324 (((-121) $ $) NIL))) 
-(((-899) (-13 (-1098) (-10 -8 (-15 -3972 ($ (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217))))) (-15 -3972 ((-856) $)) (-15 -1318 ((-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217))) $))))) (T -899)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-899)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *1 (-899)))) (-1318 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *1 (-899))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217))))) (-15 -3972 ((-856) $)) (-15 -1318 ((-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217))) $)))) 
-((-3139 (($ $ |#2|) NIL) (($ $ (-638 |#2|)) 10) (($ $ |#2| (-769)) 12) (($ $ (-638 |#2|) (-638 (-769))) 15)) (-1557 (($ $ |#2|) 16) (($ $ (-638 |#2|)) 18) (($ $ |#2| (-769)) 19) (($ $ (-638 |#2|) (-638 (-769))) 21))) 
-(((-900 |#1| |#2|) (-10 -8 (-15 -1557 (|#1| |#1| (-638 |#2|) (-638 (-769)))) (-15 -1557 (|#1| |#1| |#2| (-769))) (-15 -1557 (|#1| |#1| (-638 |#2|))) (-15 -1557 (|#1| |#1| |#2|)) (-15 -3139 (|#1| |#1| (-638 |#2|) (-638 (-769)))) (-15 -3139 (|#1| |#1| |#2| (-769))) (-15 -3139 (|#1| |#1| (-638 |#2|))) (-15 -3139 (|#1| |#1| |#2|))) (-901 |#2|) (-1098)) (T -900)) 
-NIL 
-(-10 -8 (-15 -1557 (|#1| |#1| (-638 |#2|) (-638 (-769)))) (-15 -1557 (|#1| |#1| |#2| (-769))) (-15 -1557 (|#1| |#1| (-638 |#2|))) (-15 -1557 (|#1| |#1| |#2|)) (-15 -3139 (|#1| |#1| (-638 |#2|) (-638 (-769)))) (-15 -3139 (|#1| |#1| |#2| (-769))) (-15 -3139 (|#1| |#1| (-638 |#2|))) (-15 -3139 (|#1| |#1| |#2|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3139 (($ $ |#1|) 41) (($ $ (-638 |#1|)) 40) (($ $ |#1| (-769)) 39) (($ $ (-638 |#1|) (-638 (-769))) 38)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ |#1|) 37) (($ $ (-638 |#1|)) 36) (($ $ |#1| (-769)) 35) (($ $ (-638 |#1|) (-638 (-769))) 34)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-901 |#1|) (-1290) (-1098)) (T -901)) 
-((-3139 (*1 *1 *1 *2) (-12 (-4 *1 (-901 *2)) (-4 *2 (-1098)))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *1 (-901 *3)) (-4 *3 (-1098)))) (-3139 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-901 *2)) (-4 *2 (-1098)))) (-3139 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *4)) (-5 *3 (-638 (-769))) (-4 *1 (-901 *4)) (-4 *4 (-1098)))) (-1557 (*1 *1 *1 *2) (-12 (-4 *1 (-901 *2)) (-4 *2 (-1098)))) (-1557 (*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *1 (-901 *3)) (-4 *3 (-1098)))) (-1557 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-901 *2)) (-4 *2 (-1098)))) (-1557 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *4)) (-5 *3 (-638 (-769))) (-4 *1 (-901 *4)) (-4 *4 (-1098))))) 
-(-13 (-1054) (-10 -8 (-15 -3139 ($ $ |t#1|)) (-15 -3139 ($ $ (-638 |t#1|))) (-15 -3139 ($ $ |t#1| (-769))) (-15 -3139 ($ $ (-638 |t#1|) (-638 (-769)))) (-15 -1557 ($ $ |t#1|)) (-15 -1557 ($ $ (-638 |t#1|))) (-15 -1557 ($ $ |t#1| (-769))) (-15 -1557 ($ $ (-638 |t#1|) (-638 (-769)))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) 26)) (-1946 (((-121) $ (-769)) NIL)) (-4436 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-2107 (($ $ $) NIL (|has| $ (-6 -4603)))) (-3184 (($ $ $) NIL (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) (($ $ "left" $) NIL (|has| $ (-6 -4603))) (($ $ "right" $) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-1862 (($ $) 25)) (-3262 (($ |#1|) 12) (($ $ $) 17)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1866 (($ $) 23)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) 20)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-3537 (((-572) $ $) NIL)) (-1791 (((-121) $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-856) $) 29 (|has| |#1| (-1098))) (((-1191 |#1|) $) 9)) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 21 (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-902 |#1|) (-13 (-128 |#1|) (-10 -8 (-15 -3262 ($ |#1|)) (-15 -3262 ($ $ $)) (-15 -3972 ((-1191 |#1|) $)))) (-1098)) (T -902)) 
-((-3262 (*1 *1 *2) (-12 (-5 *1 (-902 *2)) (-4 *2 (-1098)))) (-3262 (*1 *1 *1 *1) (-12 (-5 *1 (-902 *2)) (-4 *2 (-1098)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1191 *3)) (-5 *1 (-902 *3)) (-4 *3 (-1098))))) 
-(-13 (-128 |#1|) (-10 -8 (-15 -3262 ($ |#1|)) (-15 -3262 ($ $ $)) (-15 -3972 ((-1191 |#1|) $)))) 
-((-4559 ((|#2| (-1135 |#1| |#2|)) 39))) 
-(((-903 |#1| |#2|) (-10 -7 (-15 -4559 (|#2| (-1135 |#1| |#2|)))) (-923) (-13 (-1054) (-10 -7 (-6 (-4604 "*"))))) (T -903)) 
-((-4559 (*1 *2 *3) (-12 (-5 *3 (-1135 *4 *2)) (-14 *4 (-923)) (-4 *2 (-13 (-1054) (-10 -7 (-6 (-4604 "*"))))) (-5 *1 (-903 *4 *2))))) 
-(-10 -7 (-15 -4559 (|#2| (-1135 |#1| |#2|)))) 
-((-2262 (((-121) $ $) 7)) (-2211 (($) 19 T CONST)) (-1799 (((-3 $ "failed") $) 15)) (-3035 (((-1100 |#1|) $ |#1|) 34)) (-3893 (((-121) $) 18)) (-1771 (($ $ $) 32 (-1841 (|has| |#1| (-848)) (|has| |#1| (-374))))) (-4238 (($ $ $) 31 (-1841 (|has| |#1| (-848)) (|has| |#1| (-374))))) (-1658 (((-1152) $) 9)) (-4350 (($ $) 26)) (-2607 (((-1116) $) 10)) (-4485 ((|#1| $ |#1|) 36)) (-3277 ((|#1| $ |#1|) 35)) (-2695 (($ (-638 (-638 |#1|))) 37)) (-4476 (($ (-638 |#1|)) 38)) (-3018 (($ $ $) 22)) (-4056 (($ $ $) 21)) (-3972 (((-856) $) 11)) (-4174 (($ $ (-923)) 12) (($ $ (-769)) 16) (($ $ (-572)) 23)) (-3255 (($) 20 T CONST)) (-1349 (((-121) $ $) 29 (-1841 (|has| |#1| (-848)) (|has| |#1| (-374))))) (-1338 (((-121) $ $) 28 (-1841 (|has| |#1| (-848)) (|has| |#1| (-374))))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 30 (-1841 (|has| |#1| (-848)) (|has| |#1| (-374))))) (-1334 (((-121) $ $) 33)) (-1379 (($ $ $) 25)) (** (($ $ (-923)) 13) (($ $ (-769)) 17) (($ $ (-572)) 24)) (* (($ $ $) 14))) 
-(((-904 |#1|) (-1290) (-1098)) (T -904)) 
-((-4476 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-904 *3)))) (-2695 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-4 *1 (-904 *3)))) (-4485 (*1 *2 *1 *2) (-12 (-4 *1 (-904 *2)) (-4 *2 (-1098)))) (-3277 (*1 *2 *1 *2) (-12 (-4 *1 (-904 *2)) (-4 *2 (-1098)))) (-3035 (*1 *2 *1 *3) (-12 (-4 *1 (-904 *3)) (-4 *3 (-1098)) (-5 *2 (-1100 *3)))) (-1334 (*1 *2 *1 *1) (-12 (-4 *1 (-904 *3)) (-4 *3 (-1098)) (-5 *2 (-121))))) 
-(-13 (-482) (-10 -8 (-15 -4476 ($ (-638 |t#1|))) (-15 -2695 ($ (-638 (-638 |t#1|)))) (-15 -4485 (|t#1| $ |t#1|)) (-15 -3277 (|t#1| $ |t#1|)) (-15 -3035 ((-1100 |t#1|) $ |t#1|)) (-15 -1334 ((-121) $ $)) (IF (|has| |t#1| (-848)) (-6 (-848)) |noBranch|) (IF (|has| |t#1| (-374)) (-6 (-848)) |noBranch|))) 
-(((-105) . T) ((-612 (-856)) . T) ((-482) . T) ((-722) . T) ((-848) -1841 (|has| |#1| (-848)) (|has| |#1| (-374))) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-2570 (((-638 (-638 (-769))) $) 106)) (-3267 (((-638 (-769)) (-906 |#1|) $) 128)) (-3453 (((-638 (-769)) (-906 |#1|) $) 129)) (-2521 (((-638 (-906 |#1|)) $) 96)) (-3286 (((-906 |#1|) $ (-572)) 101) (((-906 |#1|) $) 102)) (-1514 (($ (-638 (-906 |#1|))) 108)) (-3377 (((-769) $) 103)) (-4317 (((-1100 (-1100 |#1|)) $) 126)) (-3035 (((-1100 |#1|) $ |#1|) 119) (((-1100 (-1100 |#1|)) $ (-1100 |#1|)) 137) (((-1100 (-638 |#1|)) $ (-638 |#1|)) 140)) (-2547 (((-1100 |#1|) $) 99)) (-3002 (((-121) (-906 |#1|) $) 90)) (-1658 (((-1152) $) NIL)) (-3469 (((-1264) $) 93) (((-1264) $ (-572) (-572)) 141)) (-2607 (((-1116) $) NIL)) (-1758 (((-638 (-906 |#1|)) $) 94)) (-3277 (((-906 |#1|) $ (-769)) 97)) (-4316 (((-769) $) 104)) (-3972 (((-856) $) 117) (((-638 (-906 |#1|)) $) 22) (($ (-638 (-906 |#1|))) 107)) (-4393 (((-638 |#1|) $) 105)) (-1324 (((-121) $ $) 134)) (-1343 (((-121) $ $) 132)) (-1334 (((-121) $ $) 131))) 
-(((-905 |#1|) (-13 (-1098) (-10 -8 (-15 -3972 ((-638 (-906 |#1|)) $)) (-15 -1758 ((-638 (-906 |#1|)) $)) (-15 -3277 ((-906 |#1|) $ (-769))) (-15 -3286 ((-906 |#1|) $ (-572))) (-15 -3286 ((-906 |#1|) $)) (-15 -3377 ((-769) $)) (-15 -4316 ((-769) $)) (-15 -4393 ((-638 |#1|) $)) (-15 -2521 ((-638 (-906 |#1|)) $)) (-15 -2570 ((-638 (-638 (-769))) $)) (-15 -3972 ($ (-638 (-906 |#1|)))) (-15 -1514 ($ (-638 (-906 |#1|)))) (-15 -3035 ((-1100 |#1|) $ |#1|)) (-15 -4317 ((-1100 (-1100 |#1|)) $)) (-15 -3035 ((-1100 (-1100 |#1|)) $ (-1100 |#1|))) (-15 -3035 ((-1100 (-638 |#1|)) $ (-638 |#1|))) (-15 -3002 ((-121) (-906 |#1|) $)) (-15 -3267 ((-638 (-769)) (-906 |#1|) $)) (-15 -3453 ((-638 (-769)) (-906 |#1|) $)) (-15 -2547 ((-1100 |#1|) $)) (-15 -1334 ((-121) $ $)) (-15 -1343 ((-121) $ $)) (-15 -3469 ((-1264) $)) (-15 -3469 ((-1264) $ (-572) (-572))))) (-1098)) (T -905)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-638 (-906 *3))) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-1758 (*1 *2 *1) (-12 (-5 *2 (-638 (-906 *3))) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-906 *4)) (-5 *1 (-905 *4)) (-4 *4 (-1098)))) (-3286 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-906 *4)) (-5 *1 (-905 *4)) (-4 *4 (-1098)))) (-3286 (*1 *2 *1) (-12 (-5 *2 (-906 *3)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-3377 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-4316 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-4393 (*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-2521 (*1 *2 *1) (-12 (-5 *2 (-638 (-906 *3))) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-2570 (*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-769)))) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-906 *3))) (-4 *3 (-1098)) (-5 *1 (-905 *3)))) (-1514 (*1 *1 *2) (-12 (-5 *2 (-638 (-906 *3))) (-4 *3 (-1098)) (-5 *1 (-905 *3)))) (-3035 (*1 *2 *1 *3) (-12 (-5 *2 (-1100 *3)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-4317 (*1 *2 *1) (-12 (-5 *2 (-1100 (-1100 *3))) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-3035 (*1 *2 *1 *3) (-12 (-4 *4 (-1098)) (-5 *2 (-1100 (-1100 *4))) (-5 *1 (-905 *4)) (-5 *3 (-1100 *4)))) (-3035 (*1 *2 *1 *3) (-12 (-4 *4 (-1098)) (-5 *2 (-1100 (-638 *4))) (-5 *1 (-905 *4)) (-5 *3 (-638 *4)))) (-3002 (*1 *2 *3 *1) (-12 (-5 *3 (-906 *4)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-905 *4)))) (-3267 (*1 *2 *3 *1) (-12 (-5 *3 (-906 *4)) (-4 *4 (-1098)) (-5 *2 (-638 (-769))) (-5 *1 (-905 *4)))) (-3453 (*1 *2 *3 *1) (-12 (-5 *3 (-906 *4)) (-4 *4 (-1098)) (-5 *2 (-638 (-769))) (-5 *1 (-905 *4)))) (-2547 (*1 *2 *1) (-12 (-5 *2 (-1100 *3)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-1334 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-1343 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-3469 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) (-3469 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-905 *4)) (-4 *4 (-1098))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ((-638 (-906 |#1|)) $)) (-15 -1758 ((-638 (-906 |#1|)) $)) (-15 -3277 ((-906 |#1|) $ (-769))) (-15 -3286 ((-906 |#1|) $ (-572))) (-15 -3286 ((-906 |#1|) $)) (-15 -3377 ((-769) $)) (-15 -4316 ((-769) $)) (-15 -4393 ((-638 |#1|) $)) (-15 -2521 ((-638 (-906 |#1|)) $)) (-15 -2570 ((-638 (-638 (-769))) $)) (-15 -3972 ($ (-638 (-906 |#1|)))) (-15 -1514 ($ (-638 (-906 |#1|)))) (-15 -3035 ((-1100 |#1|) $ |#1|)) (-15 -4317 ((-1100 (-1100 |#1|)) $)) (-15 -3035 ((-1100 (-1100 |#1|)) $ (-1100 |#1|))) (-15 -3035 ((-1100 (-638 |#1|)) $ (-638 |#1|))) (-15 -3002 ((-121) (-906 |#1|) $)) (-15 -3267 ((-638 (-769)) (-906 |#1|) $)) (-15 -3453 ((-638 (-769)) (-906 |#1|) $)) (-15 -2547 ((-1100 |#1|) $)) (-15 -1334 ((-121) $ $)) (-15 -1343 ((-121) $ $)) (-15 -3469 ((-1264) $)) (-15 -3469 ((-1264) $ (-572) (-572))))) 
-((-2262 (((-121) $ $) NIL)) (-3008 (((-638 $) (-638 $)) 76)) (-2433 (((-572) $) 59)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-3377 (((-769) $) 57)) (-3035 (((-1100 |#1|) $ |#1|) 48)) (-3893 (((-121) $) NIL)) (-4240 (((-121) $) 62)) (-1830 (((-769) $) 60)) (-2547 (((-1100 |#1|) $) 41)) (-1771 (($ $ $) NIL (-1841 (|has| |#1| (-374)) (|has| |#1| (-848))))) (-4238 (($ $ $) NIL (-1841 (|has| |#1| (-374)) (|has| |#1| (-848))))) (-3413 (((-2 (|:| |preimage| (-638 |#1|)) (|:| |image| (-638 |#1|))) $) 35)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 92)) (-2607 (((-1116) $) NIL)) (-3153 (((-1100 |#1|) $) 98 (|has| |#1| (-374)))) (-4247 (((-121) $) 58)) (-4485 ((|#1| $ |#1|) 46)) (-3277 ((|#1| $ |#1|) 93)) (-4316 (((-769) $) 43)) (-2695 (($ (-638 (-638 |#1|))) 84)) (-2354 (((-979) $) 52)) (-4476 (($ (-638 |#1|)) 21)) (-3018 (($ $ $) NIL)) (-4056 (($ $ $) NIL)) (-1979 (($ (-638 (-638 |#1|))) 38)) (-1959 (($ (-638 (-638 |#1|))) 87)) (-1898 (($ (-638 |#1|)) 95)) (-3972 (((-856) $) 83) (($ (-638 (-638 |#1|))) 65) (($ (-638 |#1|)) 66)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-3255 (($) 16 T CONST)) (-1349 (((-121) $ $) NIL (-1841 (|has| |#1| (-374)) (|has| |#1| (-848))))) (-1338 (((-121) $ $) NIL (-1841 (|has| |#1| (-374)) (|has| |#1| (-848))))) (-1324 (((-121) $ $) 44)) (-1343 (((-121) $ $) NIL (-1841 (|has| |#1| (-374)) (|has| |#1| (-848))))) (-1334 (((-121) $ $) 64)) (-1379 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ $ $) 22))) 
-(((-906 |#1|) (-13 (-904 |#1|) (-10 -8 (-15 -3413 ((-2 (|:| |preimage| (-638 |#1|)) (|:| |image| (-638 |#1|))) $)) (-15 -1979 ($ (-638 (-638 |#1|)))) (-15 -3972 ($ (-638 (-638 |#1|)))) (-15 -3972 ($ (-638 |#1|))) (-15 -1959 ($ (-638 (-638 |#1|)))) (-15 -4316 ((-769) $)) (-15 -2547 ((-1100 |#1|) $)) (-15 -2354 ((-979) $)) (-15 -3377 ((-769) $)) (-15 -1830 ((-769) $)) (-15 -2433 ((-572) $)) (-15 -4247 ((-121) $)) (-15 -4240 ((-121) $)) (-15 -3008 ((-638 $) (-638 $))) (IF (|has| |#1| (-374)) (-15 -3153 ((-1100 |#1|) $)) |noBranch|) (IF (|has| |#1| (-554)) (-15 -1898 ($ (-638 |#1|))) (IF (|has| |#1| (-374)) (-15 -1898 ($ (-638 |#1|))) |noBranch|)))) (-1098)) (T -906)) 
-((-3413 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |preimage| (-638 *3)) (|:| |image| (-638 *3)))) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-1979 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-5 *1 (-906 *3)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-5 *1 (-906 *3)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-906 *3)))) (-1959 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-5 *1 (-906 *3)))) (-4316 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-2547 (*1 *2 *1) (-12 (-5 *2 (-1100 *3)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-2354 (*1 *2 *1) (-12 (-5 *2 (-979)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-3377 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-1830 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-2433 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-4247 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-4240 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-3008 (*1 *2 *2) (-12 (-5 *2 (-638 (-906 *3))) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) (-3153 (*1 *2 *1) (-12 (-5 *2 (-1100 *3)) (-5 *1 (-906 *3)) (-4 *3 (-374)) (-4 *3 (-1098)))) (-1898 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-906 *3))))) 
-(-13 (-904 |#1|) (-10 -8 (-15 -3413 ((-2 (|:| |preimage| (-638 |#1|)) (|:| |image| (-638 |#1|))) $)) (-15 -1979 ($ (-638 (-638 |#1|)))) (-15 -3972 ($ (-638 (-638 |#1|)))) (-15 -3972 ($ (-638 |#1|))) (-15 -1959 ($ (-638 (-638 |#1|)))) (-15 -4316 ((-769) $)) (-15 -2547 ((-1100 |#1|) $)) (-15 -2354 ((-979) $)) (-15 -3377 ((-769) $)) (-15 -1830 ((-769) $)) (-15 -2433 ((-572) $)) (-15 -4247 ((-121) $)) (-15 -4240 ((-121) $)) (-15 -3008 ((-638 $) (-638 $))) (IF (|has| |#1| (-374)) (-15 -3153 ((-1100 |#1|) $)) |noBranch|) (IF (|has| |#1| (-554)) (-15 -1898 ($ (-638 |#1|))) (IF (|has| |#1| (-374)) (-15 -1898 ($ (-638 |#1|))) |noBranch|)))) 
-((-3892 (((-3 (-638 (-1166 |#4|)) "failed") (-638 (-1166 |#4|)) (-1166 |#4|)) 127)) (-1473 ((|#1|) 75)) (-2978 (((-424 (-1166 |#4|)) (-1166 |#4|)) 136)) (-3786 (((-424 (-1166 |#4|)) (-638 |#3|) (-1166 |#4|)) 67)) (-1429 (((-424 (-1166 |#4|)) (-1166 |#4|)) 146)) (-1293 (((-3 (-638 (-1166 |#4|)) "failed") (-638 (-1166 |#4|)) (-1166 |#4|) |#3|) 91))) 
-(((-907 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3892 ((-3 (-638 (-1166 |#4|)) "failed") (-638 (-1166 |#4|)) (-1166 |#4|))) (-15 -1429 ((-424 (-1166 |#4|)) (-1166 |#4|))) (-15 -2978 ((-424 (-1166 |#4|)) (-1166 |#4|))) (-15 -1473 (|#1|)) (-15 -1293 ((-3 (-638 (-1166 |#4|)) "failed") (-638 (-1166 |#4|)) (-1166 |#4|) |#3|)) (-15 -3786 ((-424 (-1166 |#4|)) (-638 |#3|) (-1166 |#4|)))) (-910) (-794) (-848) (-956 |#1| |#2| |#3|)) (T -907)) 
-((-3786 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *7)) (-4 *7 (-848)) (-4 *5 (-910)) (-4 *6 (-794)) (-4 *8 (-956 *5 *6 *7)) (-5 *2 (-424 (-1166 *8))) (-5 *1 (-907 *5 *6 *7 *8)) (-5 *4 (-1166 *8)))) (-1293 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *2 (-638 (-1166 *7))) (-5 *3 (-1166 *7)) (-4 *7 (-956 *5 *6 *4)) (-4 *5 (-910)) (-4 *6 (-794)) (-4 *4 (-848)) (-5 *1 (-907 *5 *6 *4 *7)))) (-1473 (*1 *2) (-12 (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-910)) (-5 *1 (-907 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) (-2978 (*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-907 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) (-1429 (*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-907 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) (-3892 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *7))) (-5 *3 (-1166 *7)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-910)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-907 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -3892 ((-3 (-638 (-1166 |#4|)) "failed") (-638 (-1166 |#4|)) (-1166 |#4|))) (-15 -1429 ((-424 (-1166 |#4|)) (-1166 |#4|))) (-15 -2978 ((-424 (-1166 |#4|)) (-1166 |#4|))) (-15 -1473 (|#1|)) (-15 -1293 ((-3 (-638 (-1166 |#4|)) "failed") (-638 (-1166 |#4|)) (-1166 |#4|) |#3|)) (-15 -3786 ((-424 (-1166 |#4|)) (-638 |#3|) (-1166 |#4|)))) 
-((-3892 (((-3 (-638 (-1166 |#2|)) "failed") (-638 (-1166 |#2|)) (-1166 |#2|)) 36)) (-1473 ((|#1|) 53)) (-2978 (((-424 (-1166 |#2|)) (-1166 |#2|)) 101)) (-3786 (((-424 (-1166 |#2|)) (-1166 |#2|)) 88)) (-1429 (((-424 (-1166 |#2|)) (-1166 |#2|)) 112))) 
-(((-908 |#1| |#2|) (-10 -7 (-15 -3892 ((-3 (-638 (-1166 |#2|)) "failed") (-638 (-1166 |#2|)) (-1166 |#2|))) (-15 -1429 ((-424 (-1166 |#2|)) (-1166 |#2|))) (-15 -2978 ((-424 (-1166 |#2|)) (-1166 |#2|))) (-15 -1473 (|#1|)) (-15 -3786 ((-424 (-1166 |#2|)) (-1166 |#2|)))) (-910) (-1234 |#1|)) (T -908)) 
-((-3786 (*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-1234 *4)) (-5 *2 (-424 (-1166 *5))) (-5 *1 (-908 *4 *5)) (-5 *3 (-1166 *5)))) (-1473 (*1 *2) (-12 (-4 *2 (-910)) (-5 *1 (-908 *2 *3)) (-4 *3 (-1234 *2)))) (-2978 (*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-1234 *4)) (-5 *2 (-424 (-1166 *5))) (-5 *1 (-908 *4 *5)) (-5 *3 (-1166 *5)))) (-1429 (*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-1234 *4)) (-5 *2 (-424 (-1166 *5))) (-5 *1 (-908 *4 *5)) (-5 *3 (-1166 *5)))) (-3892 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *5))) (-5 *3 (-1166 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-910)) (-5 *1 (-908 *4 *5))))) 
-(-10 -7 (-15 -3892 ((-3 (-638 (-1166 |#2|)) "failed") (-638 (-1166 |#2|)) (-1166 |#2|))) (-15 -1429 ((-424 (-1166 |#2|)) (-1166 |#2|))) (-15 -2978 ((-424 (-1166 |#2|)) (-1166 |#2|))) (-15 -1473 (|#1|)) (-15 -3786 ((-424 (-1166 |#2|)) (-1166 |#2|)))) 
-((-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 39)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 18)) (-2779 (((-3 $ "failed") $) 33))) 
-(((-909 |#1|) (-10 -8 (-15 -2779 ((-3 |#1| "failed") |#1|)) (-15 -2462 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|))) (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|)))) (-910)) (T -909)) 
-NIL 
-(-10 -8 (-15 -2779 ((-3 |#1| "failed") |#1|)) (-15 -2462 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|))) (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-4073 (((-424 (-1166 $)) (-1166 $)) 57)) (-2844 (($ $) 49)) (-1466 (((-424 $) $) 50)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 54)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-1526 (((-121) $) 51)) (-3893 (((-121) $) 30)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-4364 (((-424 (-1166 $)) (-1166 $)) 55)) (-3992 (((-424 (-1166 $)) (-1166 $)) 56)) (-4304 (((-424 $) $) 48)) (-1803 (((-3 $ "failed") $ $) 41)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 53 (|has| $ (-149)))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42)) (-2779 (((-3 $ "failed") $) 52 (|has| $ (-149)))) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-910) (-1290)) (T -910)) 
-((-3905 (*1 *2 *2 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-910)))) (-4073 (*1 *2 *3) (-12 (-4 *1 (-910)) (-5 *2 (-424 (-1166 *1))) (-5 *3 (-1166 *1)))) (-3992 (*1 *2 *3) (-12 (-4 *1 (-910)) (-5 *2 (-424 (-1166 *1))) (-5 *3 (-1166 *1)))) (-4364 (*1 *2 *3) (-12 (-4 *1 (-910)) (-5 *2 (-424 (-1166 *1))) (-5 *3 (-1166 *1)))) (-2462 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *1))) (-5 *3 (-1166 *1)) (-4 *1 (-910)))) (-1696 (*1 *2 *3) (|partial| -12 (-5 *3 (-685 *1)) (-4 *1 (-149)) (-4 *1 (-910)) (-5 *2 (-1259 *1)))) (-2779 (*1 *1 *1) (|partial| -12 (-4 *1 (-149)) (-4 *1 (-910))))) 
-(-13 (-1214) (-10 -8 (-15 -4073 ((-424 (-1166 $)) (-1166 $))) (-15 -3992 ((-424 (-1166 $)) (-1166 $))) (-15 -4364 ((-424 (-1166 $)) (-1166 $))) (-15 -3905 ((-1166 $) (-1166 $) (-1166 $))) (-15 -2462 ((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $))) (IF (|has| $ (-149)) (PROGN (-15 -1696 ((-3 (-1259 $) "failed") (-685 $))) (-15 -2779 ((-3 $ "failed") $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-457) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-2376 (((-121) $) NIL)) (-1486 (((-769)) NIL)) (-3520 (($ $ (-923)) NIL (|has| $ (-374))) (($ $) NIL)) (-3617 (((-1178 (-923) (-769)) (-572)) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-1685 (((-769)) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 $ "failed") $) NIL)) (-1318 (($ $) NIL)) (-4337 (($ (-1259 $)) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-2754 (($) NIL)) (-1297 (((-121) $) NIL)) (-4486 (($ $) NIL) (($ $ (-769)) NIL)) (-1526 (((-121) $) NIL)) (-3377 (((-834 (-923)) $) NIL) (((-923) $) NIL)) (-3893 (((-121) $) NIL)) (-1664 (($) NIL (|has| $ (-374)))) (-3880 (((-121) $) NIL (|has| $ (-374)))) (-4429 (($ $ (-923)) NIL (|has| $ (-374))) (($ $) NIL)) (-3961 (((-3 $ "failed") $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-3251 (((-1166 $) $ (-923)) NIL (|has| $ (-374))) (((-1166 $) $) NIL)) (-3633 (((-923) $) NIL)) (-4064 (((-1166 $) $) NIL (|has| $ (-374)))) (-4484 (((-3 (-1166 $) "failed") $ $) NIL (|has| $ (-374))) (((-1166 $) $) NIL (|has| $ (-374)))) (-2359 (($ $ (-1166 $)) NIL (|has| $ (-374)))) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL T CONST)) (-1763 (($ (-923)) NIL)) (-1336 (((-121) $) NIL)) (-2607 (((-1116) $) NIL)) (-2307 (($) NIL (|has| $ (-374)))) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL)) (-4304 (((-424 $) $) NIL)) (-2728 (((-923)) NIL) (((-834 (-923))) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-3587 (((-638 $)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3158 (((-3 (-769) "failed") $ $) NIL) (((-769) $) NIL)) (-2502 (((-140)) NIL)) (-3139 (($ $ (-769)) NIL) (($ $) NIL)) (-4316 (((-923) $) NIL) (((-834 (-923)) $) NIL)) (-2830 (((-1166 $)) NIL)) (-2278 (($) NIL)) (-3627 (($) NIL (|has| $ (-374)))) (-3160 (((-685 $) (-1259 $)) NIL) (((-1259 $) $) NIL)) (-4081 (((-572) $) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL)) (-2779 (((-3 $ "failed") $) NIL) (($ $) NIL)) (-2140 (((-769)) NIL)) (-2237 (((-1259 $) (-923)) NIL) (((-1259 $)) NIL)) (-3774 (((-121) $ $) NIL)) (-2213 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-2611 (($ $ (-769)) NIL (|has| $ (-374))) (($ $) NIL (|has| $ (-374)))) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL))) 
-(((-911 |#1|) (-13 (-353) (-329 $) (-613 (-572))) (-923)) (T -911)) 
-NIL 
-(-13 (-353) (-329 $) (-613 (-572))) 
-((-4123 (((-3 (-2 (|:| -3377 (-769)) (|:| -3616 |#5|)) "failed") (-336 |#2| |#3| |#4| |#5|)) 76)) (-1569 (((-121) (-336 |#2| |#3| |#4| |#5|)) 16)) (-3377 (((-3 (-769) "failed") (-336 |#2| |#3| |#4| |#5|)) 14))) 
-(((-912 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3377 ((-3 (-769) "failed") (-336 |#2| |#3| |#4| |#5|))) (-15 -1569 ((-121) (-336 |#2| |#3| |#4| |#5|))) (-15 -4123 ((-3 (-2 (|:| -3377 (-769)) (|:| -3616 |#5|)) "failed") (-336 |#2| |#3| |#4| |#5|)))) (-13 (-848) (-562) (-1044 (-572))) (-436 |#1|) (-1234 |#2|) (-1234 (-413 |#3|)) (-342 |#2| |#3| |#4|)) (T -912)) 
-((-4123 (*1 *2 *3) (|partial| -12 (-5 *3 (-336 *5 *6 *7 *8)) (-4 *5 (-436 *4)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *8 (-342 *5 *6 *7)) (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-2 (|:| -3377 (-769)) (|:| -3616 *8))) (-5 *1 (-912 *4 *5 *6 *7 *8)))) (-1569 (*1 *2 *3) (-12 (-5 *3 (-336 *5 *6 *7 *8)) (-4 *5 (-436 *4)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *8 (-342 *5 *6 *7)) (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-121)) (-5 *1 (-912 *4 *5 *6 *7 *8)))) (-3377 (*1 *2 *3) (|partial| -12 (-5 *3 (-336 *5 *6 *7 *8)) (-4 *5 (-436 *4)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *8 (-342 *5 *6 *7)) (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-769)) (-5 *1 (-912 *4 *5 *6 *7 *8))))) 
-(-10 -7 (-15 -3377 ((-3 (-769) "failed") (-336 |#2| |#3| |#4| |#5|))) (-15 -1569 ((-121) (-336 |#2| |#3| |#4| |#5|))) (-15 -4123 ((-3 (-2 (|:| -3377 (-769)) (|:| -3616 |#5|)) "failed") (-336 |#2| |#3| |#4| |#5|)))) 
-((-4123 (((-3 (-2 (|:| -3377 (-769)) (|:| -3616 |#3|)) "failed") (-336 (-413 (-572)) |#1| |#2| |#3|)) 56)) (-1569 (((-121) (-336 (-413 (-572)) |#1| |#2| |#3|)) 13)) (-3377 (((-3 (-769) "failed") (-336 (-413 (-572)) |#1| |#2| |#3|)) 11))) 
-(((-913 |#1| |#2| |#3|) (-10 -7 (-15 -3377 ((-3 (-769) "failed") (-336 (-413 (-572)) |#1| |#2| |#3|))) (-15 -1569 ((-121) (-336 (-413 (-572)) |#1| |#2| |#3|))) (-15 -4123 ((-3 (-2 (|:| -3377 (-769)) (|:| -3616 |#3|)) "failed") (-336 (-413 (-572)) |#1| |#2| |#3|)))) (-1234 (-413 (-572))) (-1234 (-413 |#1|)) (-342 (-413 (-572)) |#1| |#2|)) (T -913)) 
-((-4123 (*1 *2 *3) (|partial| -12 (-5 *3 (-336 (-413 (-572)) *4 *5 *6)) (-4 *4 (-1234 (-413 (-572)))) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 (-413 (-572)) *4 *5)) (-5 *2 (-2 (|:| -3377 (-769)) (|:| -3616 *6))) (-5 *1 (-913 *4 *5 *6)))) (-1569 (*1 *2 *3) (-12 (-5 *3 (-336 (-413 (-572)) *4 *5 *6)) (-4 *4 (-1234 (-413 (-572)))) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 (-413 (-572)) *4 *5)) (-5 *2 (-121)) (-5 *1 (-913 *4 *5 *6)))) (-3377 (*1 *2 *3) (|partial| -12 (-5 *3 (-336 (-413 (-572)) *4 *5 *6)) (-4 *4 (-1234 (-413 (-572)))) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 (-413 (-572)) *4 *5)) (-5 *2 (-769)) (-5 *1 (-913 *4 *5 *6))))) 
-(-10 -7 (-15 -3377 ((-3 (-769) "failed") (-336 (-413 (-572)) |#1| |#2| |#3|))) (-15 -1569 ((-121) (-336 (-413 (-572)) |#1| |#2| |#3|))) (-15 -4123 ((-3 (-2 (|:| -3377 (-769)) (|:| -3616 |#3|)) "failed") (-336 (-413 (-572)) |#1| |#2| |#3|)))) 
-((-4297 (((-1166 |#1|) |#2|) 36)) (-2953 ((|#2| |#2| (-638 |#1|)) 59) ((|#2| |#2| (-638 |#1|) (-572)) 61)) (-2357 (((-769) |#2|) 70)) (-2724 ((|#2| |#2| |#2| (-572)) 51)) (-1844 ((|#2| |#2| |#2|) 49)) (-4148 ((|#2| |#2| |#2|) 48)) (-4209 ((|#2| |#2| (-572)) 64)) (-1699 ((|#2| |#2| (-572)) 60)) (-3658 (((-638 |#2|) |#2|) 15)) (-1974 ((|#2| |#2|) 82)) (-3918 ((|#2| (-1 |#3| |#3|) |#2|) 40)) (-2961 (((-638 |#2|)) 26)) (-3884 (((-638 |#3|) (-572)) 92)) (-4104 (((-638 |#2|) (-769)) 93)) (-3991 ((|#2| |#2| (-572)) 71)) (-3334 ((|#3| |#2|) NIL)) (-3575 (((-769) |#2|) 83)) (-4316 (((-769) |#2| (-572)) 67)) (-1729 ((|#1| |#2| (-923)) 80)) (-3211 ((|#1| |#2|) 81))) 
-(((-914 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3918 (|#2| (-1 |#3| |#3|) |#2|)) (-15 -4316 ((-769) |#2| (-572))) (-15 -4297 ((-1166 |#1|) |#2|)) (-15 -2357 ((-769) |#2|)) (-15 -4148 (|#2| |#2| |#2|)) (-15 -1844 (|#2| |#2| |#2|)) (-15 -2724 (|#2| |#2| |#2| (-572))) (-15 -1974 (|#2| |#2|)) (-15 -3334 (|#3| |#2|)) (-15 -4209 (|#2| |#2| (-572))) (-15 -1699 (|#2| |#2| (-572))) (-15 -2953 (|#2| |#2| (-638 |#1|) (-572))) (-15 -2953 (|#2| |#2| (-638 |#1|))) (-15 -1729 (|#1| |#2| (-923))) (-15 -3211 (|#1| |#2|)) (-15 -3991 (|#2| |#2| (-572))) (-15 -3884 ((-638 |#3|) (-572))) (-15 -4104 ((-638 |#2|) (-769))) (-15 -3575 ((-769) |#2|)) (-15 -2961 ((-638 |#2|))) (-15 -3658 ((-638 |#2|) |#2|))) (-1054) (-326 |#1| |#3|) (-232 |#4| (-769)) (-769)) (T -914)) 
-((-3658 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *2 (-638 *3)) (-5 *1 (-914 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) (-2961 (*1 *2) (-12 (-4 *3 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *2 (-638 *4)) (-5 *1 (-914 *3 *4 *5 *6)) (-4 *4 (-326 *3 *5)))) (-3575 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 *2)) (-14 *6 *2) (-5 *2 (-769)) (-5 *1 (-914 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) (-4104 (*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-1054)) (-4 *6 (-232 *7 *3)) (-14 *7 *3) (-5 *2 (-638 *5)) (-5 *1 (-914 *4 *5 *6 *7)) (-4 *5 (-326 *4 *6)))) (-3884 (*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-5 *2 (-638 *6)) (-5 *1 (-914 *4 *5 *6 *7)) (-4 *5 (-326 *4 *6)))) (-3991 (*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5)))) (-3211 (*1 *2 *3) (-12 (-4 *4 (-232 *5 (-769))) (-14 *5 (-769)) (-4 *2 (-1054)) (-5 *1 (-914 *2 *3 *4 *5)) (-4 *3 (-326 *2 *4)))) (-1729 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-4 *2 (-1054)) (-5 *1 (-914 *2 *3 *5 *6)) (-4 *3 (-326 *2 *5)))) (-2953 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5)))) (-2953 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-572)) (-4 *5 (-1054)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-5 *1 (-914 *5 *2 *6 *7)) (-4 *2 (-326 *5 *6)))) (-1699 (*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5)))) (-4209 (*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5)))) (-3334 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-232 *5 (-769))) (-5 *1 (-914 *4 *3 *2 *5)) (-4 *3 (-326 *4 *2)) (-14 *5 (-769)))) (-1974 (*1 *2 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-232 *5 (-769))) (-14 *5 (-769)) (-5 *1 (-914 *3 *2 *4 *5)) (-4 *2 (-326 *3 *4)))) (-2724 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5)))) (-1844 (*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-232 *5 (-769))) (-14 *5 (-769)) (-5 *1 (-914 *3 *2 *4 *5)) (-4 *2 (-326 *3 *4)))) (-4148 (*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-232 *5 (-769))) (-14 *5 (-769)) (-5 *1 (-914 *3 *2 *4 *5)) (-4 *2 (-326 *3 *4)))) (-2357 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 *2)) (-14 *6 *2) (-5 *2 (-769)) (-5 *1 (-914 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) (-4297 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *2 (-1166 *4)) (-5 *1 (-914 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) (-4316 (*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-1054)) (-4 *6 (-232 *7 *2)) (-14 *7 *2) (-5 *2 (-769)) (-5 *1 (-914 *5 *3 *6 *7)) (-4 *3 (-326 *5 *6)))) (-3918 (*1 *2 *3 *2) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-4 *4 (-1054)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5))))) 
-(-10 -7 (-15 -3918 (|#2| (-1 |#3| |#3|) |#2|)) (-15 -4316 ((-769) |#2| (-572))) (-15 -4297 ((-1166 |#1|) |#2|)) (-15 -2357 ((-769) |#2|)) (-15 -4148 (|#2| |#2| |#2|)) (-15 -1844 (|#2| |#2| |#2|)) (-15 -2724 (|#2| |#2| |#2| (-572))) (-15 -1974 (|#2| |#2|)) (-15 -3334 (|#3| |#2|)) (-15 -4209 (|#2| |#2| (-572))) (-15 -1699 (|#2| |#2| (-572))) (-15 -2953 (|#2| |#2| (-638 |#1|) (-572))) (-15 -2953 (|#2| |#2| (-638 |#1|))) (-15 -1729 (|#1| |#2| (-923))) (-15 -3211 (|#1| |#2|)) (-15 -3991 (|#2| |#2| (-572))) (-15 -3884 ((-638 |#3|) (-572))) (-15 -4104 ((-638 |#2|) (-769))) (-15 -3575 ((-769) |#2|)) (-15 -2961 ((-638 |#2|))) (-15 -3658 ((-638 |#2|) |#2|))) 
-((-3800 ((|#2| |#2|) 25)) (-1376 (((-572) (-638 (-2 (|:| |den| (-572)) (|:| |gcdnum| (-572))))) 15)) (-2067 (((-923) (-572)) 35)) (-2497 (((-572) |#2|) 42)) (-2229 (((-572) |#2|) 21) (((-2 (|:| |den| (-572)) (|:| |gcdnum| (-572))) |#1|) 20))) 
-(((-915 |#1| |#2|) (-10 -7 (-15 -2067 ((-923) (-572))) (-15 -2229 ((-2 (|:| |den| (-572)) (|:| |gcdnum| (-572))) |#1|)) (-15 -2229 ((-572) |#2|)) (-15 -1376 ((-572) (-638 (-2 (|:| |den| (-572)) (|:| |gcdnum| (-572)))))) (-15 -2497 ((-572) |#2|)) (-15 -3800 (|#2| |#2|))) (-1234 (-413 (-572))) (-1234 (-413 |#1|))) (T -915)) 
-((-3800 (*1 *2 *2) (-12 (-4 *3 (-1234 (-413 (-572)))) (-5 *1 (-915 *3 *2)) (-4 *2 (-1234 (-413 *3))))) (-2497 (*1 *2 *3) (-12 (-4 *4 (-1234 (-413 *2))) (-5 *2 (-572)) (-5 *1 (-915 *4 *3)) (-4 *3 (-1234 (-413 *4))))) (-1376 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| |den| (-572)) (|:| |gcdnum| (-572))))) (-4 *4 (-1234 (-413 *2))) (-5 *2 (-572)) (-5 *1 (-915 *4 *5)) (-4 *5 (-1234 (-413 *4))))) (-2229 (*1 *2 *3) (-12 (-4 *4 (-1234 (-413 *2))) (-5 *2 (-572)) (-5 *1 (-915 *4 *3)) (-4 *3 (-1234 (-413 *4))))) (-2229 (*1 *2 *3) (-12 (-4 *3 (-1234 (-413 (-572)))) (-5 *2 (-2 (|:| |den| (-572)) (|:| |gcdnum| (-572)))) (-5 *1 (-915 *3 *4)) (-4 *4 (-1234 (-413 *3))))) (-2067 (*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1234 (-413 *3))) (-5 *2 (-923)) (-5 *1 (-915 *4 *5)) (-4 *5 (-1234 (-413 *4)))))) 
-(-10 -7 (-15 -2067 ((-923) (-572))) (-15 -2229 ((-2 (|:| |den| (-572)) (|:| |gcdnum| (-572))) |#1|)) (-15 -2229 ((-572) |#2|)) (-15 -1376 ((-572) (-638 (-2 (|:| |den| (-572)) (|:| |gcdnum| (-572)))))) (-15 -2497 ((-572) |#2|)) (-15 -3800 (|#2| |#2|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 ((|#1| $) 80)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-2190 (($ $ $) NIL)) (-1799 (((-3 $ "failed") $) 74)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-3499 (($ |#1| (-424 |#1|)) 72)) (-2645 (((-1166 |#1|) |#1| |#1|) 40)) (-2253 (($ $) 48)) (-3893 (((-121) $) NIL)) (-3674 (((-572) $) 77)) (-3943 (($ $ (-572)) 79)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-4060 ((|#1| $) 76)) (-2913 (((-424 |#1|) $) 75)) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) 73)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3369 (($ $) 38)) (-3972 (((-856) $) 98) (($ (-572)) 53) (($ $) NIL) (($ (-413 (-572))) NIL) (($ |#1|) 30) (((-413 |#1|) $) 58) (($ (-413 (-424 |#1|))) 66)) (-2140 (((-769)) 51)) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 23 T CONST)) (-3255 (($) 11 T CONST)) (-1324 (((-121) $ $) 67)) (-1379 (($ $ $) NIL)) (-1373 (($ $) 87) (($ $ $) NIL)) (-1367 (($ $ $) 37)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 89) (($ $ $) 36) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ |#1| $) 88) (($ $ |#1|) NIL))) 
-(((-916 |#1|) (-13 (-368) (-43 |#1|) (-10 -8 (-15 -3972 ((-413 |#1|) $)) (-15 -3972 ($ (-413 (-424 |#1|)))) (-15 -3369 ($ $)) (-15 -2913 ((-424 |#1|) $)) (-15 -4060 (|#1| $)) (-15 -3943 ($ $ (-572))) (-15 -3674 ((-572) $)) (-15 -2645 ((-1166 |#1|) |#1| |#1|)) (-15 -2253 ($ $)) (-15 -3499 ($ |#1| (-424 |#1|))) (-15 -2551 (|#1| $)))) (-303)) (T -916)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-413 *3)) (-5 *1 (-916 *3)) (-4 *3 (-303)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-413 (-424 *3))) (-4 *3 (-303)) (-5 *1 (-916 *3)))) (-3369 (*1 *1 *1) (-12 (-5 *1 (-916 *2)) (-4 *2 (-303)))) (-2913 (*1 *2 *1) (-12 (-5 *2 (-424 *3)) (-5 *1 (-916 *3)) (-4 *3 (-303)))) (-4060 (*1 *2 *1) (-12 (-5 *1 (-916 *2)) (-4 *2 (-303)))) (-3943 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-916 *3)) (-4 *3 (-303)))) (-3674 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-916 *3)) (-4 *3 (-303)))) (-2645 (*1 *2 *3 *3) (-12 (-5 *2 (-1166 *3)) (-5 *1 (-916 *3)) (-4 *3 (-303)))) (-2253 (*1 *1 *1) (-12 (-5 *1 (-916 *2)) (-4 *2 (-303)))) (-3499 (*1 *1 *2 *3) (-12 (-5 *3 (-424 *2)) (-4 *2 (-303)) (-5 *1 (-916 *2)))) (-2551 (*1 *2 *1) (-12 (-5 *1 (-916 *2)) (-4 *2 (-303))))) 
-(-13 (-368) (-43 |#1|) (-10 -8 (-15 -3972 ((-413 |#1|) $)) (-15 -3972 ($ (-413 (-424 |#1|)))) (-15 -3369 ($ $)) (-15 -2913 ((-424 |#1|) $)) (-15 -4060 (|#1| $)) (-15 -3943 ($ $ (-572))) (-15 -3674 ((-572) $)) (-15 -2645 ((-1166 |#1|) |#1| |#1|)) (-15 -2253 ($ $)) (-15 -3499 ($ |#1| (-424 |#1|))) (-15 -2551 (|#1| $)))) 
-((-3499 (((-57) (-959 |#1|) (-424 (-959 |#1|)) (-1170)) 16) (((-57) (-413 (-959 |#1|)) (-1170)) 17))) 
-(((-917 |#1|) (-10 -7 (-15 -3499 ((-57) (-413 (-959 |#1|)) (-1170))) (-15 -3499 ((-57) (-959 |#1|) (-424 (-959 |#1|)) (-1170)))) (-13 (-303) (-151))) (T -917)) 
-((-3499 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-424 (-959 *6))) (-5 *5 (-1170)) (-5 *3 (-959 *6)) (-4 *6 (-13 (-303) (-151))) (-5 *2 (-57)) (-5 *1 (-917 *6)))) (-3499 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-151))) (-5 *2 (-57)) (-5 *1 (-917 *5))))) 
-(-10 -7 (-15 -3499 ((-57) (-413 (-959 |#1|)) (-1170))) (-15 -3499 ((-57) (-959 |#1|) (-424 (-959 |#1|)) (-1170)))) 
-((-3748 ((|#4| (-638 |#4|)) 118) (((-1166 |#4|) (-1166 |#4|) (-1166 |#4|)) 65) ((|#4| |#4| |#4|) 117)) (-3069 (((-1166 |#4|) (-638 (-1166 |#4|))) 111) (((-1166 |#4|) (-1166 |#4|) (-1166 |#4|)) 48) ((|#4| (-638 |#4|)) 53) ((|#4| |#4| |#4|) 82))) 
-(((-918 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3069 (|#4| |#4| |#4|)) (-15 -3069 (|#4| (-638 |#4|))) (-15 -3069 ((-1166 |#4|) (-1166 |#4|) (-1166 |#4|))) (-15 -3069 ((-1166 |#4|) (-638 (-1166 |#4|)))) (-15 -3748 (|#4| |#4| |#4|)) (-15 -3748 ((-1166 |#4|) (-1166 |#4|) (-1166 |#4|))) (-15 -3748 (|#4| (-638 |#4|)))) (-794) (-848) (-303) (-956 |#3| |#1| |#2|)) (T -918)) 
-((-3748 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *6 *4 *5)) (-5 *1 (-918 *4 *5 *6 *2)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)))) (-3748 (*1 *2 *2 *2) (-12 (-5 *2 (-1166 *6)) (-4 *6 (-956 *5 *3 *4)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-303)) (-5 *1 (-918 *3 *4 *5 *6)))) (-3748 (*1 *2 *2 *2) (-12 (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-303)) (-5 *1 (-918 *3 *4 *5 *2)) (-4 *2 (-956 *5 *3 *4)))) (-3069 (*1 *2 *3) (-12 (-5 *3 (-638 (-1166 *7))) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-5 *2 (-1166 *7)) (-5 *1 (-918 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5)))) (-3069 (*1 *2 *2 *2) (-12 (-5 *2 (-1166 *6)) (-4 *6 (-956 *5 *3 *4)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-303)) (-5 *1 (-918 *3 *4 *5 *6)))) (-3069 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *6 *4 *5)) (-5 *1 (-918 *4 *5 *6 *2)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)))) (-3069 (*1 *2 *2 *2) (-12 (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-303)) (-5 *1 (-918 *3 *4 *5 *2)) (-4 *2 (-956 *5 *3 *4))))) 
-(-10 -7 (-15 -3069 (|#4| |#4| |#4|)) (-15 -3069 (|#4| (-638 |#4|))) (-15 -3069 ((-1166 |#4|) (-1166 |#4|) (-1166 |#4|))) (-15 -3069 ((-1166 |#4|) (-638 (-1166 |#4|)))) (-15 -3748 (|#4| |#4| |#4|)) (-15 -3748 ((-1166 |#4|) (-1166 |#4|) (-1166 |#4|))) (-15 -3748 (|#4| (-638 |#4|)))) 
-((-3605 (((-905 (-572)) (-979)) 22) (((-905 (-572)) (-638 (-572))) 19)) (-1674 (((-905 (-572)) (-638 (-572))) 46) (((-905 (-572)) (-923)) 47)) (-4211 (((-905 (-572))) 23)) (-2295 (((-905 (-572))) 36) (((-905 (-572)) (-638 (-572))) 35)) (-1998 (((-905 (-572))) 34) (((-905 (-572)) (-638 (-572))) 33)) (-3872 (((-905 (-572))) 32) (((-905 (-572)) (-638 (-572))) 31)) (-1644 (((-905 (-572))) 30) (((-905 (-572)) (-638 (-572))) 29)) (-4218 (((-905 (-572))) 28) (((-905 (-572)) (-638 (-572))) 27)) (-3075 (((-905 (-572))) 38) (((-905 (-572)) (-638 (-572))) 37)) (-4541 (((-905 (-572)) (-638 (-572))) 50) (((-905 (-572)) (-923)) 51)) (-1939 (((-905 (-572)) (-638 (-572))) 48) (((-905 (-572)) (-923)) 49)) (-2025 (((-905 (-572)) (-638 (-572))) 43) (((-905 (-572)) (-923)) 45)) (-3933 (((-905 (-572)) (-638 (-923))) 40))) 
-(((-919) (-10 -7 (-15 -1674 ((-905 (-572)) (-923))) (-15 -1674 ((-905 (-572)) (-638 (-572)))) (-15 -2025 ((-905 (-572)) (-923))) (-15 -2025 ((-905 (-572)) (-638 (-572)))) (-15 -3933 ((-905 (-572)) (-638 (-923)))) (-15 -1939 ((-905 (-572)) (-923))) (-15 -1939 ((-905 (-572)) (-638 (-572)))) (-15 -4541 ((-905 (-572)) (-923))) (-15 -4541 ((-905 (-572)) (-638 (-572)))) (-15 -4218 ((-905 (-572)) (-638 (-572)))) (-15 -4218 ((-905 (-572)))) (-15 -1644 ((-905 (-572)) (-638 (-572)))) (-15 -1644 ((-905 (-572)))) (-15 -3872 ((-905 (-572)) (-638 (-572)))) (-15 -3872 ((-905 (-572)))) (-15 -1998 ((-905 (-572)) (-638 (-572)))) (-15 -1998 ((-905 (-572)))) (-15 -2295 ((-905 (-572)) (-638 (-572)))) (-15 -2295 ((-905 (-572)))) (-15 -3075 ((-905 (-572)) (-638 (-572)))) (-15 -3075 ((-905 (-572)))) (-15 -4211 ((-905 (-572)))) (-15 -3605 ((-905 (-572)) (-638 (-572)))) (-15 -3605 ((-905 (-572)) (-979))))) (T -919)) 
-((-3605 (*1 *2 *3) (-12 (-5 *3 (-979)) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-3605 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-4211 (*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-3075 (*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-3075 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-2295 (*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-2295 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-1998 (*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-1998 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-3872 (*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-3872 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-1644 (*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-1644 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-4218 (*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-4218 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-4541 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-4541 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-1939 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-1939 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-3933 (*1 *2 *3) (-12 (-5 *3 (-638 (-923))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-2025 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-2025 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-1674 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) (-1674 (*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(-10 -7 (-15 -1674 ((-905 (-572)) (-923))) (-15 -1674 ((-905 (-572)) (-638 (-572)))) (-15 -2025 ((-905 (-572)) (-923))) (-15 -2025 ((-905 (-572)) (-638 (-572)))) (-15 -3933 ((-905 (-572)) (-638 (-923)))) (-15 -1939 ((-905 (-572)) (-923))) (-15 -1939 ((-905 (-572)) (-638 (-572)))) (-15 -4541 ((-905 (-572)) (-923))) (-15 -4541 ((-905 (-572)) (-638 (-572)))) (-15 -4218 ((-905 (-572)) (-638 (-572)))) (-15 -4218 ((-905 (-572)))) (-15 -1644 ((-905 (-572)) (-638 (-572)))) (-15 -1644 ((-905 (-572)))) (-15 -3872 ((-905 (-572)) (-638 (-572)))) (-15 -3872 ((-905 (-572)))) (-15 -1998 ((-905 (-572)) (-638 (-572)))) (-15 -1998 ((-905 (-572)))) (-15 -2295 ((-905 (-572)) (-638 (-572)))) (-15 -2295 ((-905 (-572)))) (-15 -3075 ((-905 (-572)) (-638 (-572)))) (-15 -3075 ((-905 (-572)))) (-15 -4211 ((-905 (-572)))) (-15 -3605 ((-905 (-572)) (-638 (-572)))) (-15 -3605 ((-905 (-572)) (-979)))) 
-((-2413 (((-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170))) 10)) (-3527 (((-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170))) 9))) 
-(((-920 |#1|) (-10 -7 (-15 -3527 ((-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170)))) (-15 -2413 ((-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170))))) (-457)) (T -920)) 
-((-2413 (*1 *2 *2 *3) (-12 (-5 *2 (-638 (-959 *4))) (-5 *3 (-638 (-1170))) (-4 *4 (-457)) (-5 *1 (-920 *4)))) (-3527 (*1 *2 *2 *3) (-12 (-5 *2 (-638 (-959 *4))) (-5 *3 (-638 (-1170))) (-4 *4 (-457)) (-5 *1 (-920 *4))))) 
-(-10 -7 (-15 -3527 ((-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170)))) (-15 -2413 ((-638 (-959 |#1|)) (-638 (-959 |#1|)) (-638 (-1170))))) 
-((-3972 (((-312 |#1|) (-493)) 15))) 
-(((-921 |#1|) (-10 -7 (-15 -3972 ((-312 |#1|) (-493)))) (-13 (-848) (-562))) (T -921)) 
-((-3972 (*1 *2 *3) (-12 (-5 *3 (-493)) (-5 *2 (-312 *4)) (-5 *1 (-921 *4)) (-4 *4 (-13 (-848) (-562)))))) 
-(-10 -7 (-15 -3972 ((-312 |#1|) (-493)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-3893 (((-121) $) 30)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-922) (-1290)) (T -922)) 
-((-3326 (*1 *2 *3) (-12 (-4 *1 (-922)) (-5 *2 (-2 (|:| -4513 (-638 *1)) (|:| -2307 *1))) (-5 *3 (-638 *1)))) (-4354 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-638 *1)) (-4 *1 (-922))))) 
-(-13 (-457) (-10 -8 (-15 -3326 ((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $))) (-15 -4354 ((-3 (-638 $) "failed") (-638 $) $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-457) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3069 (($ $ $) NIL)) (-3972 (((-856) $) NIL)) (-4174 (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (-3255 (($) NIL T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (* (($ (-923) $) NIL) (($ $ $) NIL))) 
-(((-923) (-13 (-25) (-848) (-722) (-10 -8 (-15 -3069 ($ $ $)) (-6 (-4604 "*"))))) (T -923)) 
-((-3069 (*1 *1 *1 *1) (-5 *1 (-923)))) 
-(-13 (-25) (-848) (-722) (-10 -8 (-15 -3069 ($ $ $)) (-6 (-4604 "*")))) 
-((-2476 ((|#2| (-638 |#1|) (-638 |#1|)) 22))) 
-(((-924 |#1| |#2|) (-10 -7 (-15 -2476 (|#2| (-638 |#1|) (-638 |#1|)))) (-368) (-1234 |#1|)) (T -924)) 
-((-2476 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-4 *2 (-1234 *4)) (-5 *1 (-924 *4 *2))))) 
-(-10 -7 (-15 -2476 (|#2| (-638 |#1|) (-638 |#1|)))) 
-((-4435 (((-1166 |#2|) (-638 |#2|) (-638 |#2|)) 17) (((-1231 |#1| |#2|) (-1231 |#1| |#2|) (-638 |#2|) (-638 |#2|)) 13))) 
-(((-925 |#1| |#2|) (-10 -7 (-15 -4435 ((-1231 |#1| |#2|) (-1231 |#1| |#2|) (-638 |#2|) (-638 |#2|))) (-15 -4435 ((-1166 |#2|) (-638 |#2|) (-638 |#2|)))) (-1170) (-368)) (T -925)) 
-((-4435 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *5)) (-4 *5 (-368)) (-5 *2 (-1166 *5)) (-5 *1 (-925 *4 *5)) (-14 *4 (-1170)))) (-4435 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1231 *4 *5)) (-5 *3 (-638 *5)) (-14 *4 (-1170)) (-4 *5 (-368)) (-5 *1 (-925 *4 *5))))) 
-(-10 -7 (-15 -4435 ((-1231 |#1| |#2|) (-1231 |#1| |#2|) (-638 |#2|) (-638 |#2|))) (-15 -4435 ((-1166 |#2|) (-638 |#2|) (-638 |#2|)))) 
-((-2262 (((-121) $ $) 7)) (-3811 (((-1264) $ (-638 |#2|)) 19)) (-3136 (((-638 $)) 14)) (-2718 (((-1264) $ (-923)) 18)) (-3116 (((-238 $) (-638 $)) 23)) (-4415 (((-638 |#2|) $) 20)) (-3113 (((-121) $) 17)) (-1658 (((-1152) $) 9)) (-1849 (((-1264) $) 16)) (-2607 (((-1116) $) 10)) (-2263 (((-638 $)) 15)) (-3277 ((|#1| $ (-572)) 13)) (-4316 (((-923) $) 12)) (-2652 (($ (-638 |#1|)) 22) (($ (-1170)) 21)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6)) (-1373 (((-238 $) $ $) 28) (((-238 $) (-238 $) $) 27) (((-238 $) $ (-238 $)) 26) (((-238 $) $) 25)) (-1367 (((-238 $) $ $) 31) (((-238 $) (-238 $) $) 30) (((-238 $) $ (-238 $)) 29)) (* (((-238 $) (-572) $) 24))) 
-(((-926 |#1| |#2|) (-1290) (-368) (-645 |t#1|)) (T -926)) 
-((-1367 (*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)))) (-1367 (*1 *2 *2 *1) (-12 (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)))) (-1367 (*1 *2 *1 *2) (-12 (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)))) (-1373 (*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)))) (-1373 (*1 *2 *2 *1) (-12 (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)))) (-1373 (*1 *2 *1 *2) (-12 (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)))) (-1373 (*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)))) (* (*1 *2 *3 *1) (-12 (-5 *3 (-572)) (-4 *4 (-368)) (-4 *5 (-645 *4)) (-5 *2 (-238 *1)) (-4 *1 (-926 *4 *5)))) (-3116 (*1 *2 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-926 *4 *5)) (-4 *4 (-368)) (-4 *5 (-645 *4)) (-5 *2 (-238 *1)))) (-2652 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-926 *3 *4)) (-4 *4 (-645 *3)))) (-2652 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-4 *3 (-368)) (-4 *1 (-926 *3 *4)) (-4 *4 (-645 *3)))) (-4415 (*1 *2 *1) (-12 (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-638 *4)))) (-3811 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *5)) (-4 *1 (-926 *4 *5)) (-4 *4 (-368)) (-4 *5 (-645 *4)) (-5 *2 (-1264)))) (-2718 (*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-4 *1 (-926 *4 *5)) (-4 *4 (-368)) (-4 *5 (-645 *4)) (-5 *2 (-1264)))) (-3113 (*1 *2 *1) (-12 (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-121)))) (-1849 (*1 *2 *1) (-12 (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-1264)))) (-2263 (*1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-638 *1)) (-4 *1 (-926 *3 *4)))) (-3136 (*1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-638 *1)) (-4 *1 (-926 *3 *4)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-926 *2 *4)) (-4 *4 (-645 *2)) (-4 *2 (-368))))) 
-(-13 (-1096) (-10 -8 (-15 -1367 ((-238 $) $ $)) (-15 -1367 ((-238 $) (-238 $) $)) (-15 -1367 ((-238 $) $ (-238 $))) (-15 -1373 ((-238 $) $ $)) (-15 -1373 ((-238 $) (-238 $) $)) (-15 -1373 ((-238 $) $ (-238 $))) (-15 -1373 ((-238 $) $)) (-15 * ((-238 $) (-572) $)) (-15 -3116 ((-238 $) (-638 $))) (-15 -2652 ($ (-638 |t#1|))) (-15 -2652 ($ (-1170))) (-15 -4415 ((-638 |t#2|) $)) (-15 -3811 ((-1264) $ (-638 |t#2|))) (-15 -2718 ((-1264) $ (-923))) (-15 -3113 ((-121) $)) (-15 -1849 ((-1264) $)) (-15 -2263 ((-638 $))) (-15 -3136 ((-638 $))) (-15 -3277 (|t#1| $ (-572))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T) ((-1096) . T)) 
-((-2262 (((-121) $ $) NIL)) (-3811 (((-1264) $ (-638 (-780 |#1|))) NIL)) (-3136 (((-638 $)) NIL)) (-2718 (((-1264) $ (-923)) NIL)) (-3116 (((-238 $) (-638 $)) NIL)) (-4415 (((-638 (-780 |#1|)) $) NIL)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-1849 (((-1264) $) NIL)) (-2607 (((-1116) $) NIL)) (-2263 (((-638 $)) NIL)) (-3277 ((|#1| $ (-572)) NIL)) (-4316 (((-923) $) NIL)) (-2652 (($ (-638 |#1|)) NIL) (($ (-1170)) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL)) (-1373 (((-238 $) $ $) NIL) (((-238 $) (-238 $) $) NIL) (((-238 $) $ (-238 $)) NIL) (((-238 $) $) NIL)) (-1367 (((-238 $) $ $) NIL) (((-238 $) (-238 $) $) NIL) (((-238 $) $ (-238 $)) NIL)) (* (((-238 $) (-572) $) NIL))) 
-(((-927 |#1|) (-926 |#1| (-780 |#1|)) (-368)) (T -927)) 
-NIL 
-(-926 |#1| (-780 |#1|)) 
-((-2262 (((-121) $ $) NIL)) (-3811 (((-1264) $ (-638 (-780 (-863 |#1|)))) NIL)) (-3136 (((-638 $)) NIL)) (-2718 (((-1264) $ (-923)) NIL)) (-3116 (((-238 $) (-638 $)) NIL)) (-4415 (((-638 (-780 (-863 |#1|))) $) NIL)) (-3113 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-1849 (((-1264) $) NIL)) (-2607 (((-1116) $) NIL)) (-2263 (((-638 $)) NIL)) (-3277 (((-863 |#1|) $ (-572)) NIL)) (-4316 (((-923) $) NIL)) (-2652 (($ (-638 (-863 |#1|))) NIL) (($ (-1170)) NIL)) (-3972 (((-856) $) NIL)) (-1324 (((-121) $ $) NIL)) (-1373 (((-238 $) $ $) NIL) (((-238 $) (-238 $) $) NIL) (((-238 $) $ (-238 $)) NIL) (((-238 $) $) NIL)) (-1367 (((-238 $) $ $) NIL) (((-238 $) (-238 $) $) NIL) (((-238 $) $ (-238 $)) NIL)) (* (((-238 $) (-572) $) NIL))) 
-(((-928 |#1|) (-926 (-863 |#1|) (-780 (-863 |#1|))) (-353)) (T -928)) 
-NIL 
-(-926 (-863 |#1|) (-780 (-863 |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-3811 (((-1264) $ (-638 |#2|)) 73)) (-3136 (((-638 $)) 62)) (-2718 (((-1264) $ (-923)) 71)) (-3116 (((-238 $) (-638 $)) 27)) (-4415 (((-638 |#2|) $) 74)) (-3113 (((-121) $) 54)) (-1658 (((-1152) $) NIL)) (-1849 (((-1264) $) 57)) (-2607 (((-1116) $) NIL)) (-2263 (((-638 $)) 59)) (-3277 ((|#1| $ (-572)) 53)) (-4316 (((-923) $) 42)) (-2652 (($ (-638 |#1|)) 69) (($ (-1170)) 70)) (-3972 (((-856) $) 45)) (-1324 (((-121) $ $) 50)) (-1373 (((-238 $) $ $) 18) (((-238 $) (-238 $) $) 30) (((-238 $) $ (-238 $)) 31) (((-238 $) $) 33)) (-1367 (((-238 $) $ $) 16) (((-238 $) (-238 $) $) 28) (((-238 $) $ (-238 $)) 29)) (* (((-238 $) (-572) $) 21))) 
-(((-929 |#1| |#2|) (-926 |#1| |#2|) (-368) (-645 |#1|)) (T -929)) 
-NIL 
-(-926 |#1| |#2|) 
-((-2859 (((-572) (-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-1152)) 137)) (-1454 ((|#4| |#4|) 153)) (-4026 (((-638 (-413 (-959 |#1|))) (-638 (-1170))) 116)) (-1545 (((-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))) (-685 |#4|) (-638 (-413 (-959 |#1|))) (-638 (-638 |#4|)) (-769) (-769) (-572)) 73)) (-1775 (((-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-638 |#4|)) 57)) (-2530 (((-685 |#4|) (-685 |#4|) (-638 |#4|)) 53)) (-1594 (((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-1152)) 149)) (-2885 (((-572) (-685 |#4|) (-923) (-1152)) 130) (((-572) (-685 |#4|) (-638 (-1170)) (-923) (-1152)) 129) (((-572) (-685 |#4|) (-638 |#4|) (-923) (-1152)) 128) (((-572) (-685 |#4|) (-1152)) 125) (((-572) (-685 |#4|) (-638 (-1170)) (-1152)) 124) (((-572) (-685 |#4|) (-638 |#4|) (-1152)) 123) (((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-923)) 122) (((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 (-1170)) (-923)) 121) (((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 |#4|) (-923)) 120) (((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|)) 118) (((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 (-1170))) 117) (((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 |#4|)) 114)) (-4578 ((|#4| (-959 |#1|)) 66)) (-3434 (((-121) (-638 |#4|) (-638 (-638 |#4|))) 150)) (-3937 (((-638 (-638 (-572))) (-572) (-572)) 127)) (-3382 (((-638 (-638 |#4|)) (-638 (-638 |#4|))) 85)) (-3898 (((-769) (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|))))) 83)) (-2401 (((-769) (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|))))) 82)) (-2609 (((-121) (-638 (-959 |#1|))) 17) (((-121) (-638 |#4|)) 13)) (-3826 (((-2 (|:| |sysok| (-121)) (|:| |z0| (-638 |#4|)) (|:| |n0| (-638 |#4|))) (-638 |#4|) (-638 |#4|)) 69)) (-1419 (((-638 |#4|) |#4|) 47)) (-2796 (((-638 (-413 (-959 |#1|))) (-638 |#4|)) 112) (((-685 (-413 (-959 |#1|))) (-685 |#4|)) 54) (((-413 (-959 |#1|)) |#4|) 109)) (-3209 (((-2 (|:| |rgl| (-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))))))) (|:| |rgsz| (-572))) (-685 |#4|) (-638 (-413 (-959 |#1|))) (-769) (-1152) (-572)) 89)) (-4526 (((-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|)))) (-685 |#4|) (-769)) 81)) (-1394 (((-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572))))) (-685 |#4|) (-769)) 98)) (-3649 (((-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-2 (|:| -1369 (-685 (-413 (-959 |#1|)))) (|:| |vec| (-638 (-413 (-959 |#1|)))) (|:| -2667 (-769)) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572))))) 46))) 
-(((-930 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 |#4|))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 (-1170)))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 |#4|) (-923))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 (-1170)) (-923))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-923))) (-15 -2885 ((-572) (-685 |#4|) (-638 |#4|) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-638 (-1170)) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-638 |#4|) (-923) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-638 (-1170)) (-923) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-923) (-1152))) (-15 -2859 ((-572) (-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-1152))) (-15 -1594 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-1152))) (-15 -3209 ((-2 (|:| |rgl| (-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))))))) (|:| |rgsz| (-572))) (-685 |#4|) (-638 (-413 (-959 |#1|))) (-769) (-1152) (-572))) (-15 -2796 ((-413 (-959 |#1|)) |#4|)) (-15 -2796 ((-685 (-413 (-959 |#1|))) (-685 |#4|))) (-15 -2796 ((-638 (-413 (-959 |#1|))) (-638 |#4|))) (-15 -4026 ((-638 (-413 (-959 |#1|))) (-638 (-1170)))) (-15 -4578 (|#4| (-959 |#1|))) (-15 -3826 ((-2 (|:| |sysok| (-121)) (|:| |z0| (-638 |#4|)) (|:| |n0| (-638 |#4|))) (-638 |#4|) (-638 |#4|))) (-15 -4526 ((-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|)))) (-685 |#4|) (-769))) (-15 -1775 ((-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-638 |#4|))) (-15 -3649 ((-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-2 (|:| -1369 (-685 (-413 (-959 |#1|)))) (|:| |vec| (-638 (-413 (-959 |#1|)))) (|:| -2667 (-769)) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (-15 -1419 ((-638 |#4|) |#4|)) (-15 -2401 ((-769) (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|)))))) (-15 -3898 ((-769) (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|)))))) (-15 -3382 ((-638 (-638 |#4|)) (-638 (-638 |#4|)))) (-15 -3937 ((-638 (-638 (-572))) (-572) (-572))) (-15 -3434 ((-121) (-638 |#4|) (-638 (-638 |#4|)))) (-15 -1394 ((-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572))))) (-685 |#4|) (-769))) (-15 -2530 ((-685 |#4|) (-685 |#4|) (-638 |#4|))) (-15 -1545 ((-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))) (-685 |#4|) (-638 (-413 (-959 |#1|))) (-638 (-638 |#4|)) (-769) (-769) (-572))) (-15 -1454 (|#4| |#4|)) (-15 -2609 ((-121) (-638 |#4|))) (-15 -2609 ((-121) (-638 (-959 |#1|))))) (-13 (-303) (-151)) (-13 (-848) (-613 (-1170))) (-794) (-956 |#1| |#3| |#2|)) (T -930)) 
-((-2609 (*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-121)) (-5 *1 (-930 *4 *5 *6 *7)) (-4 *7 (-956 *4 *6 *5)))) (-2609 (*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-121)) (-5 *1 (-930 *4 *5 *6 *7)))) (-1454 (*1 *2 *2) (-12 (-4 *3 (-13 (-303) (-151))) (-4 *4 (-13 (-848) (-613 (-1170)))) (-4 *5 (-794)) (-5 *1 (-930 *3 *4 *5 *2)) (-4 *2 (-956 *3 *5 *4)))) (-1545 (*1 *2 *3 *4 *5 *6 *7 *7 *8) (-12 (-5 *3 (-2 (|:| |det| *12) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572))))) (-5 *4 (-685 *12)) (-5 *5 (-638 (-413 (-959 *9)))) (-5 *6 (-638 (-638 *12))) (-5 *7 (-769)) (-5 *8 (-572)) (-4 *9 (-13 (-303) (-151))) (-4 *12 (-956 *9 *11 *10)) (-4 *10 (-13 (-848) (-613 (-1170)))) (-4 *11 (-794)) (-5 *2 (-2 (|:| |eqzro| (-638 *12)) (|:| |neqzro| (-638 *12)) (|:| |wcond| (-638 (-959 *9))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *9)))) (|:| -2237 (-638 (-1259 (-413 (-959 *9))))))))) (-5 *1 (-930 *9 *10 *11 *12)))) (-2530 (*1 *2 *2 *3) (-12 (-5 *2 (-685 *7)) (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *1 (-930 *4 *5 *6 *7)))) (-1394 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-5 *4 (-769)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| |det| *8) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (-5 *1 (-930 *5 *6 *7 *8)))) (-3434 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-638 *8))) (-5 *3 (-638 *8)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-121)) (-5 *1 (-930 *5 *6 *7 *8)))) (-3937 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-638 (-572)))) (-5 *1 (-930 *4 *5 *6 *7)) (-5 *3 (-572)) (-4 *7 (-956 *4 *6 *5)))) (-3382 (*1 *2 *2) (-12 (-5 *2 (-638 (-638 *6))) (-4 *6 (-956 *3 *5 *4)) (-4 *3 (-13 (-303) (-151))) (-4 *4 (-13 (-848) (-613 (-1170)))) (-4 *5 (-794)) (-5 *1 (-930 *3 *4 *5 *6)))) (-3898 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| *7) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 *7))))) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-769)) (-5 *1 (-930 *4 *5 *6 *7)))) (-2401 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| *7) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 *7))))) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-769)) (-5 *1 (-930 *4 *5 *6 *7)))) (-1419 (*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 *3)) (-5 *1 (-930 *4 *5 *6 *3)) (-4 *3 (-956 *4 *6 *5)))) (-3649 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1369 (-685 (-413 (-959 *4)))) (|:| |vec| (-638 (-413 (-959 *4)))) (|:| -2667 (-769)) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572))))) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-2 (|:| |partsol| (-1259 (-413 (-959 *4)))) (|:| -2237 (-638 (-1259 (-413 (-959 *4))))))) (-5 *1 (-930 *4 *5 *6 *7)) (-4 *7 (-956 *4 *6 *5)))) (-1775 (*1 *2 *2 *3) (-12 (-5 *2 (-2 (|:| |partsol| (-1259 (-413 (-959 *4)))) (|:| -2237 (-638 (-1259 (-413 (-959 *4))))))) (-5 *3 (-638 *7)) (-4 *4 (-13 (-303) (-151))) (-4 *7 (-956 *4 *6 *5)) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *1 (-930 *4 *5 *6 *7)))) (-4526 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| *8) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 *8))))) (-5 *1 (-930 *5 *6 *7 *8)) (-5 *4 (-769)))) (-3826 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-4 *7 (-956 *4 *6 *5)) (-5 *2 (-2 (|:| |sysok| (-121)) (|:| |z0| (-638 *7)) (|:| |n0| (-638 *7)))) (-5 *1 (-930 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) (-4578 (*1 *2 *3) (-12 (-5 *3 (-959 *4)) (-4 *4 (-13 (-303) (-151))) (-4 *2 (-956 *4 *6 *5)) (-5 *1 (-930 *4 *5 *6 *2)) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)))) (-4026 (*1 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-413 (-959 *4)))) (-5 *1 (-930 *4 *5 *6 *7)) (-4 *7 (-956 *4 *6 *5)))) (-2796 (*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-413 (-959 *4)))) (-5 *1 (-930 *4 *5 *6 *7)))) (-2796 (*1 *2 *3) (-12 (-5 *3 (-685 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-685 (-413 (-959 *4)))) (-5 *1 (-930 *4 *5 *6 *7)))) (-2796 (*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-413 (-959 *4))) (-5 *1 (-930 *4 *5 *6 *3)) (-4 *3 (-956 *4 *6 *5)))) (-3209 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-685 *11)) (-5 *4 (-638 (-413 (-959 *8)))) (-5 *5 (-769)) (-5 *6 (-1152)) (-4 *8 (-13 (-303) (-151))) (-4 *11 (-956 *8 *10 *9)) (-4 *9 (-13 (-848) (-613 (-1170)))) (-4 *10 (-794)) (-5 *2 (-2 (|:| |rgl| (-638 (-2 (|:| |eqzro| (-638 *11)) (|:| |neqzro| (-638 *11)) (|:| |wcond| (-638 (-959 *8))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *8)))) (|:| -2237 (-638 (-1259 (-413 (-959 *8)))))))))) (|:| |rgsz| (-572)))) (-5 *1 (-930 *8 *9 *10 *11)) (-5 *7 (-572)))) (-1594 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *7)) (|:| |neqzro| (-638 *7)) (|:| |wcond| (-638 (-959 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *4)))) (|:| -2237 (-638 (-1259 (-413 (-959 *4)))))))))) (-5 *1 (-930 *4 *5 *6 *7)) (-4 *7 (-956 *4 *6 *5)))) (-2859 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| |eqzro| (-638 *8)) (|:| |neqzro| (-638 *8)) (|:| |wcond| (-638 (-959 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *5)))) (|:| -2237 (-638 (-1259 (-413 (-959 *5)))))))))) (-5 *4 (-1152)) (-4 *5 (-13 (-303) (-151))) (-4 *8 (-956 *5 *7 *6)) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *5 *6 *7 *8)))) (-2885 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *4 (-923)) (-5 *5 (-1152)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *6 *7 *8 *9)))) (-2885 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-685 *10)) (-5 *4 (-638 (-1170))) (-5 *5 (-923)) (-5 *6 (-1152)) (-4 *10 (-956 *7 *9 *8)) (-4 *7 (-13 (-303) (-151))) (-4 *8 (-13 (-848) (-613 (-1170)))) (-4 *9 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *7 *8 *9 *10)))) (-2885 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-685 *10)) (-5 *4 (-638 *10)) (-5 *5 (-923)) (-5 *6 (-1152)) (-4 *10 (-956 *7 *9 *8)) (-4 *7 (-13 (-303) (-151))) (-4 *8 (-13 (-848) (-613 (-1170)))) (-4 *9 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *7 *8 *9 *10)))) (-2885 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-5 *4 (-1152)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *5 *6 *7 *8)))) (-2885 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *4 (-638 (-1170))) (-5 *5 (-1152)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *6 *7 *8 *9)))) (-2885 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *4 (-638 *9)) (-5 *5 (-1152)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *6 *7 *8 *9)))) (-2885 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-5 *4 (-923)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *8)) (|:| |neqzro| (-638 *8)) (|:| |wcond| (-638 (-959 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *5)))) (|:| -2237 (-638 (-1259 (-413 (-959 *5)))))))))) (-5 *1 (-930 *5 *6 *7 *8)))) (-2885 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *4 (-638 (-1170))) (-5 *5 (-923)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *9)) (|:| |neqzro| (-638 *9)) (|:| |wcond| (-638 (-959 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *6)))) (|:| -2237 (-638 (-1259 (-413 (-959 *6)))))))))) (-5 *1 (-930 *6 *7 *8 *9)))) (-2885 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *5 (-923)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *9)) (|:| |neqzro| (-638 *9)) (|:| |wcond| (-638 (-959 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *6)))) (|:| -2237 (-638 (-1259 (-413 (-959 *6)))))))))) (-5 *1 (-930 *6 *7 *8 *9)) (-5 *4 (-638 *9)))) (-2885 (*1 *2 *3) (-12 (-5 *3 (-685 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *7)) (|:| |neqzro| (-638 *7)) (|:| |wcond| (-638 (-959 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *4)))) (|:| -2237 (-638 (-1259 (-413 (-959 *4)))))))))) (-5 *1 (-930 *4 *5 *6 *7)))) (-2885 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-5 *4 (-638 (-1170))) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *8)) (|:| |neqzro| (-638 *8)) (|:| |wcond| (-638 (-959 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *5)))) (|:| -2237 (-638 (-1259 (-413 (-959 *5)))))))))) (-5 *1 (-930 *5 *6 *7 *8)))) (-2885 (*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *8)) (|:| |neqzro| (-638 *8)) (|:| |wcond| (-638 (-959 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *5)))) (|:| -2237 (-638 (-1259 (-413 (-959 *5)))))))))) (-5 *1 (-930 *5 *6 *7 *8)) (-5 *4 (-638 *8))))) 
-(-10 -7 (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 |#4|))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 (-1170)))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 |#4|) (-923))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-638 (-1170)) (-923))) (-15 -2885 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-685 |#4|) (-923))) (-15 -2885 ((-572) (-685 |#4|) (-638 |#4|) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-638 (-1170)) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-638 |#4|) (-923) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-638 (-1170)) (-923) (-1152))) (-15 -2885 ((-572) (-685 |#4|) (-923) (-1152))) (-15 -2859 ((-572) (-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-1152))) (-15 -1594 ((-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|))))))))) (-1152))) (-15 -3209 ((-2 (|:| |rgl| (-638 (-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))))))) (|:| |rgsz| (-572))) (-685 |#4|) (-638 (-413 (-959 |#1|))) (-769) (-1152) (-572))) (-15 -2796 ((-413 (-959 |#1|)) |#4|)) (-15 -2796 ((-685 (-413 (-959 |#1|))) (-685 |#4|))) (-15 -2796 ((-638 (-413 (-959 |#1|))) (-638 |#4|))) (-15 -4026 ((-638 (-413 (-959 |#1|))) (-638 (-1170)))) (-15 -4578 (|#4| (-959 |#1|))) (-15 -3826 ((-2 (|:| |sysok| (-121)) (|:| |z0| (-638 |#4|)) (|:| |n0| (-638 |#4|))) (-638 |#4|) (-638 |#4|))) (-15 -4526 ((-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|)))) (-685 |#4|) (-769))) (-15 -1775 ((-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-638 |#4|))) (-15 -3649 ((-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))) (-2 (|:| -1369 (-685 (-413 (-959 |#1|)))) (|:| |vec| (-638 (-413 (-959 |#1|)))) (|:| -2667 (-769)) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (-15 -1419 ((-638 |#4|) |#4|)) (-15 -2401 ((-769) (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|)))))) (-15 -3898 ((-769) (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 |#4|)))))) (-15 -3382 ((-638 (-638 |#4|)) (-638 (-638 |#4|)))) (-15 -3937 ((-638 (-638 (-572))) (-572) (-572))) (-15 -3434 ((-121) (-638 |#4|) (-638 (-638 |#4|)))) (-15 -1394 ((-638 (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572))))) (-685 |#4|) (-769))) (-15 -2530 ((-685 |#4|) (-685 |#4|) (-638 |#4|))) (-15 -1545 ((-2 (|:| |eqzro| (-638 |#4|)) (|:| |neqzro| (-638 |#4|)) (|:| |wcond| (-638 (-959 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 |#1|)))) (|:| -2237 (-638 (-1259 (-413 (-959 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))) (-685 |#4|) (-638 (-413 (-959 |#1|))) (-638 (-638 |#4|)) (-769) (-769) (-572))) (-15 -1454 (|#4| |#4|)) (-15 -2609 ((-121) (-638 |#4|))) (-15 -2609 ((-121) (-638 (-959 |#1|))))) 
-((-2838 (((-933) |#1| (-1170)) 16) (((-933) |#1| (-1170) (-1092 (-217))) 20)) (-2267 (((-933) |#1| |#1| (-1170) (-1092 (-217))) 18) (((-933) |#1| (-1170) (-1092 (-217))) 14))) 
-(((-931 |#1|) (-10 -7 (-15 -2267 ((-933) |#1| (-1170) (-1092 (-217)))) (-15 -2267 ((-933) |#1| |#1| (-1170) (-1092 (-217)))) (-15 -2838 ((-933) |#1| (-1170) (-1092 (-217)))) (-15 -2838 ((-933) |#1| (-1170)))) (-613 (-545))) (T -931)) 
-((-2838 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-933)) (-5 *1 (-931 *3)) (-4 *3 (-613 (-545))))) (-2838 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-1092 (-217))) (-5 *2 (-933)) (-5 *1 (-931 *3)) (-4 *3 (-613 (-545))))) (-2267 (*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-1092 (-217))) (-5 *2 (-933)) (-5 *1 (-931 *3)) (-4 *3 (-613 (-545))))) (-2267 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-1092 (-217))) (-5 *2 (-933)) (-5 *1 (-931 *3)) (-4 *3 (-613 (-545)))))) 
-(-10 -7 (-15 -2267 ((-933) |#1| (-1170) (-1092 (-217)))) (-15 -2267 ((-933) |#1| |#1| (-1170) (-1092 (-217)))) (-15 -2838 ((-933) |#1| (-1170) (-1092 (-217)))) (-15 -2838 ((-933) |#1| (-1170)))) 
-((-4423 (($ $ (-1092 (-217)) (-1092 (-217)) (-1092 (-217))) 68)) (-2721 (((-1092 (-217)) $) 40)) (-1497 (((-1092 (-217)) $) 39)) (-2153 (((-1092 (-217)) $) 38)) (-1587 (((-638 (-638 (-217))) $) 43)) (-2725 (((-1092 (-217)) $) 41)) (-4298 (((-572) (-572)) 32)) (-4389 (((-572) (-572)) 28)) (-3177 (((-572) (-572)) 30)) (-3000 (((-121) (-121)) 35)) (-1484 (((-572)) 31)) (-2436 (($ $ (-1092 (-217))) 71) (($ $) 72)) (-2941 (($ (-1 (-950 (-217)) (-217)) (-1092 (-217))) 76) (($ (-1 (-950 (-217)) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217))) 77)) (-2267 (($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217))) 79) (($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217))) 80) (($ $ (-1092 (-217))) 74)) (-1410 (((-572)) 36)) (-4038 (((-572)) 27)) (-2326 (((-572)) 29)) (-3192 (((-638 (-638 (-950 (-217)))) $) 92)) (-3085 (((-121) (-121)) 37)) (-3972 (((-856) $) 91)) (-4063 (((-121)) 34))) 
-(((-932) (-13 (-982) (-10 -8 (-15 -2941 ($ (-1 (-950 (-217)) (-217)) (-1092 (-217)))) (-15 -2941 ($ (-1 (-950 (-217)) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2267 ($ $ (-1092 (-217)))) (-15 -4423 ($ $ (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2436 ($ $ (-1092 (-217)))) (-15 -2436 ($ $)) (-15 -2725 ((-1092 (-217)) $)) (-15 -1587 ((-638 (-638 (-217))) $)) (-15 -4038 ((-572))) (-15 -4389 ((-572) (-572))) (-15 -2326 ((-572))) (-15 -3177 ((-572) (-572))) (-15 -1484 ((-572))) (-15 -4298 ((-572) (-572))) (-15 -4063 ((-121))) (-15 -3000 ((-121) (-121))) (-15 -1410 ((-572))) (-15 -3085 ((-121) (-121)))))) (T -932)) 
-((-2941 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-932)))) (-2941 (*1 *1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-932)))) (-2267 (*1 *1 *2 *2 *2 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-932)))) (-2267 (*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-932)))) (-2267 (*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-932)))) (-4423 (*1 *1 *1 *2 *2 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-932)))) (-2436 (*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-932)))) (-2436 (*1 *1 *1) (-5 *1 (-932))) (-2725 (*1 *2 *1) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-932)))) (-1587 (*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-217)))) (-5 *1 (-932)))) (-4038 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932)))) (-4389 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932)))) (-2326 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932)))) (-3177 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932)))) (-1484 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932)))) (-4298 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932)))) (-4063 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-932)))) (-3000 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-932)))) (-1410 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932)))) (-3085 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-932))))) 
-(-13 (-982) (-10 -8 (-15 -2941 ($ (-1 (-950 (-217)) (-217)) (-1092 (-217)))) (-15 -2941 ($ (-1 (-950 (-217)) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2267 ($ $ (-1092 (-217)))) (-15 -4423 ($ $ (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2436 ($ $ (-1092 (-217)))) (-15 -2436 ($ $)) (-15 -2725 ((-1092 (-217)) $)) (-15 -1587 ((-638 (-638 (-217))) $)) (-15 -4038 ((-572))) (-15 -4389 ((-572) (-572))) (-15 -2326 ((-572))) (-15 -3177 ((-572) (-572))) (-15 -1484 ((-572))) (-15 -4298 ((-572) (-572))) (-15 -4063 ((-121))) (-15 -3000 ((-121) (-121))) (-15 -1410 ((-572))) (-15 -3085 ((-121) (-121))))) 
-((-4423 (($ $ (-1092 (-217))) 69) (($ $ (-1092 (-217)) (-1092 (-217))) 70)) (-1497 (((-1092 (-217)) $) 43)) (-2153 (((-1092 (-217)) $) 42)) (-2725 (((-1092 (-217)) $) 44)) (-2947 (((-572) (-572)) 36)) (-1590 (((-572) (-572)) 32)) (-2755 (((-572) (-572)) 34)) (-1598 (((-121) (-121)) 38)) (-3923 (((-572)) 35)) (-2436 (($ $ (-1092 (-217))) 73) (($ $) 74)) (-2941 (($ (-1 (-950 (-217)) (-217)) (-1092 (-217))) 83) (($ (-1 (-950 (-217)) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217))) 84)) (-2838 (($ (-1 (-217) (-217)) (-1092 (-217))) 91) (($ (-1 (-217) (-217))) 94)) (-2267 (($ (-1 (-217) (-217)) (-1092 (-217))) 78) (($ (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217))) 79) (($ (-638 (-1 (-217) (-217))) (-1092 (-217))) 86) (($ (-638 (-1 (-217) (-217))) (-1092 (-217)) (-1092 (-217))) 87) (($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217))) 80) (($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217))) 81) (($ $ (-1092 (-217))) 75)) (-3979 (((-121) $) 39)) (-3348 (((-572)) 40)) (-1985 (((-572)) 31)) (-2028 (((-572)) 33)) (-3192 (((-638 (-638 (-950 (-217)))) $) 22)) (-3889 (((-121) (-121)) 41)) (-3972 (((-856) $) 105)) (-4121 (((-121)) 37))) 
-(((-933) (-13 (-962) (-10 -8 (-15 -2267 ($ (-1 (-217) (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2267 ($ (-638 (-1 (-217) (-217))) (-1092 (-217)))) (-15 -2267 ($ (-638 (-1 (-217) (-217))) (-1092 (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2941 ($ (-1 (-950 (-217)) (-217)) (-1092 (-217)))) (-15 -2941 ($ (-1 (-950 (-217)) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2838 ($ (-1 (-217) (-217)) (-1092 (-217)))) (-15 -2838 ($ (-1 (-217) (-217)))) (-15 -2267 ($ $ (-1092 (-217)))) (-15 -3979 ((-121) $)) (-15 -4423 ($ $ (-1092 (-217)))) (-15 -4423 ($ $ (-1092 (-217)) (-1092 (-217)))) (-15 -2436 ($ $ (-1092 (-217)))) (-15 -2436 ($ $)) (-15 -2725 ((-1092 (-217)) $)) (-15 -1985 ((-572))) (-15 -1590 ((-572) (-572))) (-15 -2028 ((-572))) (-15 -2755 ((-572) (-572))) (-15 -3923 ((-572))) (-15 -2947 ((-572) (-572))) (-15 -4121 ((-121))) (-15 -1598 ((-121) (-121))) (-15 -3348 ((-572))) (-15 -3889 ((-121) (-121)))))) (T -933)) 
-((-2267 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2267 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2267 (*1 *1 *2 *3) (-12 (-5 *2 (-638 (-1 (-217) (-217)))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2267 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-638 (-1 (-217) (-217)))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2267 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2267 (*1 *1 *2 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2941 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2941 (*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2838 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) (-2838 (*1 *1 *2) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *1 (-933)))) (-2267 (*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) (-3979 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-933)))) (-4423 (*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) (-4423 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) (-2436 (*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) (-2436 (*1 *1 *1) (-5 *1 (-933))) (-2725 (*1 *2 *1) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) (-1985 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933)))) (-1590 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933)))) (-2028 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933)))) (-2755 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933)))) (-3923 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933)))) (-2947 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933)))) (-4121 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-933)))) (-1598 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-933)))) (-3348 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933)))) (-3889 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-933))))) 
-(-13 (-962) (-10 -8 (-15 -2267 ($ (-1 (-217) (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2267 ($ (-638 (-1 (-217) (-217))) (-1092 (-217)))) (-15 -2267 ($ (-638 (-1 (-217) (-217))) (-1092 (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)))) (-15 -2267 ($ (-1 (-217) (-217)) (-1 (-217) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2941 ($ (-1 (-950 (-217)) (-217)) (-1092 (-217)))) (-15 -2941 ($ (-1 (-950 (-217)) (-217)) (-1092 (-217)) (-1092 (-217)) (-1092 (-217)))) (-15 -2838 ($ (-1 (-217) (-217)) (-1092 (-217)))) (-15 -2838 ($ (-1 (-217) (-217)))) (-15 -2267 ($ $ (-1092 (-217)))) (-15 -3979 ((-121) $)) (-15 -4423 ($ $ (-1092 (-217)))) (-15 -4423 ($ $ (-1092 (-217)) (-1092 (-217)))) (-15 -2436 ($ $ (-1092 (-217)))) (-15 -2436 ($ $)) (-15 -2725 ((-1092 (-217)) $)) (-15 -1985 ((-572))) (-15 -1590 ((-572) (-572))) (-15 -2028 ((-572))) (-15 -2755 ((-572) (-572))) (-15 -3923 ((-572))) (-15 -2947 ((-572) (-572))) (-15 -4121 ((-121))) (-15 -1598 ((-121) (-121))) (-15 -3348 ((-572))) (-15 -3889 ((-121) (-121))))) 
-((-4453 (((-638 (-1092 (-217))) (-638 (-638 (-950 (-217))))) 23))) 
-(((-934) (-10 -7 (-15 -4453 ((-638 (-1092 (-217))) (-638 (-638 (-950 (-217)))))))) (T -934)) 
-((-4453 (*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *2 (-638 (-1092 (-217)))) (-5 *1 (-934))))) 
-(-10 -7 (-15 -4453 ((-638 (-1092 (-217))) (-638 (-638 (-950 (-217))))))) 
-((-1309 ((|#2| |#2| |#5|) 39) ((|#2| |#2| |#5| (-572)) 20)) (-2120 (((-121) (-638 |#2|) |#5|) 23)) (-1941 (((-769) |#2| |#5| (-572)) 42) (((-769) |#2| |#5|) 41)) (-1974 ((|#2| |#2| |#5| (-572)) 45) ((|#2| |#2| |#5|) 44)) (-4485 ((|#1| |#2| |#5|) 21))) 
-(((-935 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2120 ((-121) (-638 |#2|) |#5|)) (-15 -4485 (|#1| |#2| |#5|)) (-15 -1309 (|#2| |#2| |#5| (-572))) (-15 -1309 (|#2| |#2| |#5|)) (-15 -1974 (|#2| |#2| |#5|)) (-15 -1974 (|#2| |#2| |#5| (-572))) (-15 -1941 ((-769) |#2| |#5|)) (-15 -1941 ((-769) |#2| |#5| (-572)))) (-368) (-326 |#1| |#3|) (-232 |#4| (-769)) (-769) (-978 |#1|)) (T -935)) 
-((-1941 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-572)) (-4 *6 (-368)) (-4 *7 (-232 *8 *2)) (-14 *8 *2) (-5 *2 (-769)) (-5 *1 (-935 *6 *3 *7 *8 *4)) (-4 *3 (-326 *6 *7)) (-4 *4 (-978 *6)))) (-1941 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-232 *7 *2)) (-14 *7 *2) (-5 *2 (-769)) (-5 *1 (-935 *5 *3 *6 *7 *4)) (-4 *3 (-326 *5 *6)) (-4 *4 (-978 *5)))) (-1974 (*1 *2 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-368)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-5 *1 (-935 *5 *2 *6 *7 *3)) (-4 *2 (-326 *5 *6)) (-4 *3 (-978 *5)))) (-1974 (*1 *2 *2 *3) (-12 (-4 *4 (-368)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-935 *4 *2 *5 *6 *3)) (-4 *2 (-326 *4 *5)) (-4 *3 (-978 *4)))) (-1309 (*1 *2 *2 *3) (-12 (-4 *4 (-368)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-935 *4 *2 *5 *6 *3)) (-4 *2 (-326 *4 *5)) (-4 *3 (-978 *4)))) (-1309 (*1 *2 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-368)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-5 *1 (-935 *5 *2 *6 *7 *3)) (-4 *2 (-326 *5 *6)) (-4 *3 (-978 *5)))) (-4485 (*1 *2 *3 *4) (-12 (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-4 *2 (-368)) (-5 *1 (-935 *2 *3 *5 *6 *4)) (-4 *3 (-326 *2 *5)) (-4 *4 (-978 *2)))) (-2120 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-4 *6 (-326 *5 *7)) (-4 *7 (-232 *8 (-769))) (-14 *8 (-769)) (-4 *5 (-368)) (-5 *2 (-121)) (-5 *1 (-935 *5 *6 *7 *8 *4)) (-4 *4 (-978 *5))))) 
-(-10 -7 (-15 -2120 ((-121) (-638 |#2|) |#5|)) (-15 -4485 (|#1| |#2| |#5|)) (-15 -1309 (|#2| |#2| |#5| (-572))) (-15 -1309 (|#2| |#2| |#5|)) (-15 -1974 (|#2| |#2| |#5|)) (-15 -1974 (|#2| |#2| |#5| (-572))) (-15 -1941 ((-769) |#2| |#5|)) (-15 -1941 ((-769) |#2| |#5| (-572)))) 
-((-2950 ((|#2| |#2|) 25)) (-2945 ((|#2| |#2|) 26)) (-3211 ((|#2| |#2|) 24)) (-4262 ((|#2| |#2| (-1152)) 23))) 
-(((-936 |#1| |#2|) (-10 -7 (-15 -4262 (|#2| |#2| (-1152))) (-15 -3211 (|#2| |#2|)) (-15 -2950 (|#2| |#2|)) (-15 -2945 (|#2| |#2|))) (-848) (-436 |#1|)) (T -936)) 
-((-2945 (*1 *2 *2) (-12 (-4 *3 (-848)) (-5 *1 (-936 *3 *2)) (-4 *2 (-436 *3)))) (-2950 (*1 *2 *2) (-12 (-4 *3 (-848)) (-5 *1 (-936 *3 *2)) (-4 *2 (-436 *3)))) (-3211 (*1 *2 *2) (-12 (-4 *3 (-848)) (-5 *1 (-936 *3 *2)) (-4 *2 (-436 *3)))) (-4262 (*1 *2 *2 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-848)) (-5 *1 (-936 *4 *2)) (-4 *2 (-436 *4))))) 
-(-10 -7 (-15 -4262 (|#2| |#2| (-1152))) (-15 -3211 (|#2| |#2|)) (-15 -2950 (|#2| |#2|)) (-15 -2945 (|#2| |#2|))) 
-((-2950 (((-312 (-572)) (-1170)) 15)) (-2945 (((-312 (-572)) (-1170)) 13)) (-3211 (((-312 (-572)) (-1170)) 11)) (-4262 (((-312 (-572)) (-1170) (-1152)) 18))) 
-(((-937) (-10 -7 (-15 -4262 ((-312 (-572)) (-1170) (-1152))) (-15 -3211 ((-312 (-572)) (-1170))) (-15 -2950 ((-312 (-572)) (-1170))) (-15 -2945 ((-312 (-572)) (-1170))))) (T -937)) 
-((-2945 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-312 (-572))) (-5 *1 (-937)))) (-2950 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-312 (-572))) (-5 *1 (-937)))) (-3211 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-312 (-572))) (-5 *1 (-937)))) (-4262 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-1152)) (-5 *2 (-312 (-572))) (-5 *1 (-937))))) 
-(-10 -7 (-15 -4262 ((-312 (-572)) (-1170) (-1152))) (-15 -3211 ((-312 (-572)) (-1170))) (-15 -2950 ((-312 (-572)) (-1170))) (-15 -2945 ((-312 (-572)) (-1170)))) 
-((-3103 (((-890 |#1| |#3|) |#2| (-893 |#1|) (-890 |#1| |#3|)) 24)) (-4142 (((-1 (-121) |#2|) (-1 (-121) |#3|)) 12))) 
-(((-938 |#1| |#2| |#3|) (-10 -7 (-15 -4142 ((-1 (-121) |#2|) (-1 (-121) |#3|))) (-15 -3103 ((-890 |#1| |#3|) |#2| (-893 |#1|) (-890 |#1| |#3|)))) (-1098) (-887 |#1|) (-13 (-1098) (-1044 |#2|))) (T -938)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *6)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *6 (-13 (-1098) (-1044 *3))) (-4 *3 (-887 *5)) (-5 *1 (-938 *5 *3 *6)))) (-4142 (*1 *2 *3) (-12 (-5 *3 (-1 (-121) *6)) (-4 *6 (-13 (-1098) (-1044 *5))) (-4 *5 (-887 *4)) (-4 *4 (-1098)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-938 *4 *5 *6))))) 
-(-10 -7 (-15 -4142 ((-1 (-121) |#2|) (-1 (-121) |#3|))) (-15 -3103 ((-890 |#1| |#3|) |#2| (-893 |#1|) (-890 |#1| |#3|)))) 
-((-3103 (((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)) 29))) 
-(((-939 |#1| |#2| |#3|) (-10 -7 (-15 -3103 ((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)))) (-1098) (-13 (-562) (-848) (-887 |#1|)) (-13 (-436 |#2|) (-613 (-893 |#1|)) (-887 |#1|) (-1044 (-611 $)))) (T -939)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *3)) (-4 *5 (-1098)) (-4 *3 (-13 (-436 *6) (-613 *4) (-887 *5) (-1044 (-611 $)))) (-5 *4 (-893 *5)) (-4 *6 (-13 (-562) (-848) (-887 *5))) (-5 *1 (-939 *5 *6 *3))))) 
-(-10 -7 (-15 -3103 ((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)))) 
-((-3103 (((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|)) 12))) 
-(((-940 |#1|) (-10 -7 (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|)))) (-554)) (T -940)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 (-572) *3)) (-5 *4 (-893 (-572))) (-4 *3 (-554)) (-5 *1 (-940 *3))))) 
-(-10 -7 (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|)))) 
-((-3103 (((-890 |#1| |#2|) (-611 |#2|) (-893 |#1|) (-890 |#1| |#2|)) 52))) 
-(((-941 |#1| |#2|) (-10 -7 (-15 -3103 ((-890 |#1| |#2|) (-611 |#2|) (-893 |#1|) (-890 |#1| |#2|)))) (-1098) (-13 (-848) (-1044 (-611 $)) (-613 (-893 |#1|)) (-887 |#1|))) (T -941)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *6)) (-5 *3 (-611 *6)) (-4 *5 (-1098)) (-4 *6 (-13 (-848) (-1044 (-611 $)) (-613 *4) (-887 *5))) (-5 *4 (-893 *5)) (-5 *1 (-941 *5 *6))))) 
-(-10 -7 (-15 -3103 ((-890 |#1| |#2|) (-611 |#2|) (-893 |#1|) (-890 |#1| |#2|)))) 
-((-3103 (((-886 |#1| |#2| |#3|) |#3| (-893 |#1|) (-886 |#1| |#2| |#3|)) 14))) 
-(((-942 |#1| |#2| |#3|) (-10 -7 (-15 -3103 ((-886 |#1| |#2| |#3|) |#3| (-893 |#1|) (-886 |#1| |#2| |#3|)))) (-1098) (-887 |#1|) (-662 |#2|)) (T -942)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-886 *5 *6 *3)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *6 (-887 *5)) (-4 *3 (-662 *6)) (-5 *1 (-942 *5 *6 *3))))) 
-(-10 -7 (-15 -3103 ((-886 |#1| |#2| |#3|) |#3| (-893 |#1|) (-886 |#1| |#2| |#3|)))) 
-((-3103 (((-890 |#1| |#5|) |#5| (-893 |#1|) (-890 |#1| |#5|)) 17 (|has| |#3| (-887 |#1|))) (((-890 |#1| |#5|) |#5| (-893 |#1|) (-890 |#1| |#5|) (-1 (-890 |#1| |#5|) |#3| (-893 |#1|) (-890 |#1| |#5|))) 16))) 
-(((-943 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3103 ((-890 |#1| |#5|) |#5| (-893 |#1|) (-890 |#1| |#5|) (-1 (-890 |#1| |#5|) |#3| (-893 |#1|) (-890 |#1| |#5|)))) (IF (|has| |#3| (-887 |#1|)) (-15 -3103 ((-890 |#1| |#5|) |#5| (-893 |#1|) (-890 |#1| |#5|))) |noBranch|)) (-1098) (-794) (-848) (-13 (-1054) (-848) (-887 |#1|)) (-13 (-956 |#4| |#2| |#3|) (-613 (-893 |#1|)))) (T -943)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *3)) (-4 *5 (-1098)) (-4 *3 (-13 (-956 *8 *6 *7) (-613 *4))) (-5 *4 (-893 *5)) (-4 *7 (-887 *5)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-13 (-1054) (-848) (-887 *5))) (-5 *1 (-943 *5 *6 *7 *8 *3)))) (-3103 (*1 *2 *3 *4 *2 *5) (-12 (-5 *5 (-1 (-890 *6 *3) *8 (-893 *6) (-890 *6 *3))) (-4 *8 (-848)) (-5 *2 (-890 *6 *3)) (-5 *4 (-893 *6)) (-4 *6 (-1098)) (-4 *3 (-13 (-956 *9 *7 *8) (-613 *4))) (-4 *7 (-794)) (-4 *9 (-13 (-1054) (-848) (-887 *6))) (-5 *1 (-943 *6 *7 *8 *9 *3))))) 
-(-10 -7 (-15 -3103 ((-890 |#1| |#5|) |#5| (-893 |#1|) (-890 |#1| |#5|) (-1 (-890 |#1| |#5|) |#3| (-893 |#1|) (-890 |#1| |#5|)))) (IF (|has| |#3| (-887 |#1|)) (-15 -3103 ((-890 |#1| |#5|) |#5| (-893 |#1|) (-890 |#1| |#5|))) |noBranch|)) 
-((-3405 ((|#2| |#2| (-638 (-1 (-121) |#3|))) 11) ((|#2| |#2| (-1 (-121) |#3|)) 12))) 
-(((-944 |#1| |#2| |#3|) (-10 -7 (-15 -3405 (|#2| |#2| (-1 (-121) |#3|))) (-15 -3405 (|#2| |#2| (-638 (-1 (-121) |#3|))))) (-848) (-436 |#1|) (-1204)) (T -944)) 
-((-3405 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-1 (-121) *5))) (-4 *5 (-1204)) (-4 *4 (-848)) (-5 *1 (-944 *4 *2 *5)) (-4 *2 (-436 *4)))) (-3405 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *5)) (-4 *5 (-1204)) (-4 *4 (-848)) (-5 *1 (-944 *4 *2 *5)) (-4 *2 (-436 *4))))) 
-(-10 -7 (-15 -3405 (|#2| |#2| (-1 (-121) |#3|))) (-15 -3405 (|#2| |#2| (-638 (-1 (-121) |#3|))))) 
-((-3405 (((-312 (-572)) (-1170) (-638 (-1 (-121) |#1|))) 16) (((-312 (-572)) (-1170) (-1 (-121) |#1|)) 13))) 
-(((-945 |#1|) (-10 -7 (-15 -3405 ((-312 (-572)) (-1170) (-1 (-121) |#1|))) (-15 -3405 ((-312 (-572)) (-1170) (-638 (-1 (-121) |#1|))))) (-1204)) (T -945)) 
-((-3405 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-638 (-1 (-121) *5))) (-4 *5 (-1204)) (-5 *2 (-312 (-572))) (-5 *1 (-945 *5)))) (-3405 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-1 (-121) *5)) (-4 *5 (-1204)) (-5 *2 (-312 (-572))) (-5 *1 (-945 *5))))) 
-(-10 -7 (-15 -3405 ((-312 (-572)) (-1170) (-1 (-121) |#1|))) (-15 -3405 ((-312 (-572)) (-1170) (-638 (-1 (-121) |#1|))))) 
-((-3103 (((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)) 25))) 
-(((-946 |#1| |#2| |#3|) (-10 -7 (-15 -3103 ((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)))) (-1098) (-13 (-562) (-887 |#1|) (-613 (-893 |#1|))) (-1000 |#2|)) (T -946)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *3)) (-4 *5 (-1098)) (-4 *3 (-1000 *6)) (-4 *6 (-13 (-562) (-887 *5) (-613 *4))) (-5 *4 (-893 *5)) (-5 *1 (-946 *5 *6 *3))))) 
-(-10 -7 (-15 -3103 ((-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)))) 
-((-3103 (((-890 |#1| (-1170)) (-1170) (-893 |#1|) (-890 |#1| (-1170))) 17))) 
-(((-947 |#1|) (-10 -7 (-15 -3103 ((-890 |#1| (-1170)) (-1170) (-893 |#1|) (-890 |#1| (-1170))))) (-1098)) (T -947)) 
-((-3103 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 (-1170))) (-5 *3 (-1170)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-5 *1 (-947 *5))))) 
-(-10 -7 (-15 -3103 ((-890 |#1| (-1170)) (-1170) (-893 |#1|) (-890 |#1| (-1170))))) 
-((-4065 (((-890 |#1| |#3|) (-638 |#3|) (-638 (-893 |#1|)) (-890 |#1| |#3|) (-1 (-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|))) 33)) (-3103 (((-890 |#1| |#3|) (-638 |#3|) (-638 (-893 |#1|)) (-1 |#3| (-638 |#3|)) (-890 |#1| |#3|) (-1 (-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|))) 32))) 
-(((-948 |#1| |#2| |#3|) (-10 -7 (-15 -3103 ((-890 |#1| |#3|) (-638 |#3|) (-638 (-893 |#1|)) (-1 |#3| (-638 |#3|)) (-890 |#1| |#3|) (-1 (-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)))) (-15 -4065 ((-890 |#1| |#3|) (-638 |#3|) (-638 (-893 |#1|)) (-890 |#1| |#3|) (-1 (-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|))))) (-1098) (-13 (-1054) (-848)) (-13 (-1054) (-613 (-893 |#1|)) (-1044 |#2|))) (T -948)) 
-((-4065 (*1 *2 *3 *4 *2 *5) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 (-893 *6))) (-5 *5 (-1 (-890 *6 *8) *8 (-893 *6) (-890 *6 *8))) (-4 *6 (-1098)) (-4 *8 (-13 (-1054) (-613 (-893 *6)) (-1044 *7))) (-5 *2 (-890 *6 *8)) (-4 *7 (-13 (-1054) (-848))) (-5 *1 (-948 *6 *7 *8)))) (-3103 (*1 *2 *3 *4 *5 *2 *6) (-12 (-5 *4 (-638 (-893 *7))) (-5 *5 (-1 *9 (-638 *9))) (-5 *6 (-1 (-890 *7 *9) *9 (-893 *7) (-890 *7 *9))) (-4 *7 (-1098)) (-4 *9 (-13 (-1054) (-613 (-893 *7)) (-1044 *8))) (-5 *2 (-890 *7 *9)) (-5 *3 (-638 *9)) (-4 *8 (-13 (-1054) (-848))) (-5 *1 (-948 *7 *8 *9))))) 
-(-10 -7 (-15 -3103 ((-890 |#1| |#3|) (-638 |#3|) (-638 (-893 |#1|)) (-1 |#3| (-638 |#3|)) (-890 |#1| |#3|) (-1 (-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|)))) (-15 -4065 ((-890 |#1| |#3|) (-638 |#3|) (-638 (-893 |#1|)) (-890 |#1| |#3|) (-1 (-890 |#1| |#3|) |#3| (-893 |#1|) (-890 |#1| |#3|))))) 
-((-1943 (((-1166 (-413 (-572))) (-572)) 61)) (-4474 (((-1166 (-572)) (-572)) 64)) (-1858 (((-1166 (-572)) (-572)) 58)) (-2819 (((-572) (-1166 (-572))) 53)) (-3730 (((-1166 (-413 (-572))) (-572)) 47)) (-2654 (((-1166 (-572)) (-572)) 36)) (-3294 (((-1166 (-572)) (-572)) 66)) (-3297 (((-1166 (-572)) (-572)) 65)) (-2038 (((-1166 (-413 (-572))) (-572)) 49))) 
-(((-949) (-10 -7 (-15 -2038 ((-1166 (-413 (-572))) (-572))) (-15 -3297 ((-1166 (-572)) (-572))) (-15 -3294 ((-1166 (-572)) (-572))) (-15 -2654 ((-1166 (-572)) (-572))) (-15 -3730 ((-1166 (-413 (-572))) (-572))) (-15 -2819 ((-572) (-1166 (-572)))) (-15 -1858 ((-1166 (-572)) (-572))) (-15 -4474 ((-1166 (-572)) (-572))) (-15 -1943 ((-1166 (-413 (-572))) (-572))))) (T -949)) 
-((-1943 (*1 *2 *3) (-12 (-5 *2 (-1166 (-413 (-572)))) (-5 *1 (-949)) (-5 *3 (-572)))) (-4474 (*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572)))) (-1858 (*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572)))) (-2819 (*1 *2 *3) (-12 (-5 *3 (-1166 (-572))) (-5 *2 (-572)) (-5 *1 (-949)))) (-3730 (*1 *2 *3) (-12 (-5 *2 (-1166 (-413 (-572)))) (-5 *1 (-949)) (-5 *3 (-572)))) (-2654 (*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572)))) (-3294 (*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572)))) (-3297 (*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572)))) (-2038 (*1 *2 *3) (-12 (-5 *2 (-1166 (-413 (-572)))) (-5 *1 (-949)) (-5 *3 (-572))))) 
-(-10 -7 (-15 -2038 ((-1166 (-413 (-572))) (-572))) (-15 -3297 ((-1166 (-572)) (-572))) (-15 -3294 ((-1166 (-572)) (-572))) (-15 -2654 ((-1166 (-572)) (-572))) (-15 -3730 ((-1166 (-413 (-572))) (-572))) (-15 -2819 ((-572) (-1166 (-572)))) (-15 -1858 ((-1166 (-572)) (-572))) (-15 -4474 ((-1166 (-572)) (-572))) (-15 -1943 ((-1166 (-413 (-572))) (-572)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4169 (($ (-769)) NIL (|has| |#1| (-23)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) |#1|) 11 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-4014 (((-572) (-1 (-121) |#1|) $) NIL) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098)))) (-1767 (($ (-638 |#1|)) 13)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3349 (((-685 |#1|) $ $) NIL (|has| |#1| (-1054)))) (-1364 (($ (-769) |#1|) 8)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 10 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3169 ((|#1| $) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1054))))) (-3524 (((-121) $ (-769)) NIL)) (-3200 ((|#1| $) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1054))))) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) NIL (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-1977 (($ $ (-638 |#1|)) 24)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) |#1|) NIL) ((|#1| $ (-572)) 18) (($ $ (-1225 (-572))) NIL)) (-1436 ((|#1| $ $) NIL (|has| |#1| (-1054)))) (-2502 (((-923) $) 16)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-3780 (($ $ $) 22)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545)))) (($ (-638 |#1|)) 17)) (-3921 (($ (-638 |#1|)) NIL)) (-4500 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) 23) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1373 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1367 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-572) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-722))) (($ $ |#1|) NIL (|has| |#1| (-722)))) (-4032 (((-769) $) 14 (|has| $ (-6 -4602))))) 
-(((-950 |#1|) (-988 |#1|) (-1054)) (T -950)) 
-NIL 
-(-988 |#1|) 
-((-4550 (((-496 |#1| |#2|) (-959 |#2|)) 17)) (-3148 (((-244 |#1| |#2|) (-959 |#2|)) 29)) (-4377 (((-959 |#2|) (-496 |#1| |#2|)) 22)) (-3424 (((-244 |#1| |#2|) (-496 |#1| |#2|)) 53)) (-1746 (((-959 |#2|) (-244 |#1| |#2|)) 26)) (-4561 (((-496 |#1| |#2|) (-244 |#1| |#2|)) 44))) 
-(((-951 |#1| |#2|) (-10 -7 (-15 -4561 ((-496 |#1| |#2|) (-244 |#1| |#2|))) (-15 -3424 ((-244 |#1| |#2|) (-496 |#1| |#2|))) (-15 -4550 ((-496 |#1| |#2|) (-959 |#2|))) (-15 -4377 ((-959 |#2|) (-496 |#1| |#2|))) (-15 -1746 ((-959 |#2|) (-244 |#1| |#2|))) (-15 -3148 ((-244 |#1| |#2|) (-959 |#2|)))) (-638 (-1170)) (-1054)) (T -951)) 
-((-3148 (*1 *2 *3) (-12 (-5 *3 (-959 *5)) (-4 *5 (-1054)) (-5 *2 (-244 *4 *5)) (-5 *1 (-951 *4 *5)) (-14 *4 (-638 (-1170))))) (-1746 (*1 *2 *3) (-12 (-5 *3 (-244 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-1054)) (-5 *2 (-959 *5)) (-5 *1 (-951 *4 *5)))) (-4377 (*1 *2 *3) (-12 (-5 *3 (-496 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-1054)) (-5 *2 (-959 *5)) (-5 *1 (-951 *4 *5)))) (-4550 (*1 *2 *3) (-12 (-5 *3 (-959 *5)) (-4 *5 (-1054)) (-5 *2 (-496 *4 *5)) (-5 *1 (-951 *4 *5)) (-14 *4 (-638 (-1170))))) (-3424 (*1 *2 *3) (-12 (-5 *3 (-496 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-1054)) (-5 *2 (-244 *4 *5)) (-5 *1 (-951 *4 *5)))) (-4561 (*1 *2 *3) (-12 (-5 *3 (-244 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-1054)) (-5 *2 (-496 *4 *5)) (-5 *1 (-951 *4 *5))))) 
-(-10 -7 (-15 -4561 ((-496 |#1| |#2|) (-244 |#1| |#2|))) (-15 -3424 ((-244 |#1| |#2|) (-496 |#1| |#2|))) (-15 -4550 ((-496 |#1| |#2|) (-959 |#2|))) (-15 -4377 ((-959 |#2|) (-496 |#1| |#2|))) (-15 -1746 ((-959 |#2|) (-244 |#1| |#2|))) (-15 -3148 ((-244 |#1| |#2|) (-959 |#2|)))) 
-((-4135 (((-638 |#2|) |#2| |#2|) 10)) (-2466 (((-769) (-638 |#1|)) 37 (|has| |#1| (-846)))) (-2979 (((-638 |#2|) |#2|) 11)) (-3264 (((-769) (-638 |#1|) (-572) (-572)) 36 (|has| |#1| (-846)))) (-2169 ((|#1| |#2|) 32 (|has| |#1| (-846))))) 
-(((-952 |#1| |#2|) (-10 -7 (-15 -4135 ((-638 |#2|) |#2| |#2|)) (-15 -2979 ((-638 |#2|) |#2|)) (IF (|has| |#1| (-846)) (PROGN (-15 -2169 (|#1| |#2|)) (-15 -2466 ((-769) (-638 |#1|))) (-15 -3264 ((-769) (-638 |#1|) (-572) (-572)))) |noBranch|)) (-368) (-1234 |#1|)) (T -952)) 
-((-3264 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-572)) (-4 *5 (-846)) (-4 *5 (-368)) (-5 *2 (-769)) (-5 *1 (-952 *5 *6)) (-4 *6 (-1234 *5)))) (-2466 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-846)) (-4 *4 (-368)) (-5 *2 (-769)) (-5 *1 (-952 *4 *5)) (-4 *5 (-1234 *4)))) (-2169 (*1 *2 *3) (-12 (-4 *2 (-368)) (-4 *2 (-846)) (-5 *1 (-952 *2 *3)) (-4 *3 (-1234 *2)))) (-2979 (*1 *2 *3) (-12 (-4 *4 (-368)) (-5 *2 (-638 *3)) (-5 *1 (-952 *4 *3)) (-4 *3 (-1234 *4)))) (-4135 (*1 *2 *3 *3) (-12 (-4 *4 (-368)) (-5 *2 (-638 *3)) (-5 *1 (-952 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -4135 ((-638 |#2|) |#2| |#2|)) (-15 -2979 ((-638 |#2|) |#2|)) (IF (|has| |#1| (-846)) (PROGN (-15 -2169 (|#1| |#2|)) (-15 -2466 ((-769) (-638 |#1|))) (-15 -3264 ((-769) (-638 |#1|) (-572) (-572)))) |noBranch|)) 
-((-3828 (((-959 |#2|) (-1 |#2| |#1|) (-959 |#1|)) 18))) 
-(((-953 |#1| |#2|) (-10 -7 (-15 -3828 ((-959 |#2|) (-1 |#2| |#1|) (-959 |#1|)))) (-1054) (-1054)) (T -953)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-959 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-959 *6)) (-5 *1 (-953 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-959 |#2|) (-1 |#2| |#1|) (-959 |#1|)))) 
-((-4297 (((-1231 |#1| (-959 |#2|)) (-959 |#2|) (-1255 |#1|)) 18))) 
-(((-954 |#1| |#2|) (-10 -7 (-15 -4297 ((-1231 |#1| (-959 |#2|)) (-959 |#2|) (-1255 |#1|)))) (-1170) (-1054)) (T -954)) 
-((-4297 (*1 *2 *3 *4) (-12 (-5 *4 (-1255 *5)) (-14 *5 (-1170)) (-4 *6 (-1054)) (-5 *2 (-1231 *5 (-959 *6))) (-5 *1 (-954 *5 *6)) (-5 *3 (-959 *6))))) 
-(-10 -7 (-15 -4297 ((-1231 |#1| (-959 |#2|)) (-959 |#2|) (-1255 |#1|)))) 
-((-2357 (((-769) $) 69) (((-769) $ (-638 |#4|)) 72)) (-2844 (($ $) 169)) (-1466 (((-424 $) $) 161)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 112)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 (-572) "failed") $) NIL) (((-3 |#4| "failed") $) 58)) (-1318 ((|#2| $) NIL) (((-413 (-572)) $) NIL) (((-572) $) NIL) ((|#4| $) 57)) (-3190 (($ $ $ |#4|) 74)) (-2284 (((-685 (-572)) (-685 $)) NIL) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) 102) (((-685 |#2|) (-685 $)) 95)) (-3988 (($ $) 177) (($ $ |#4|) 180)) (-4378 (((-638 $) $) 61)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 195) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 189)) (-3658 (((-638 $) $) 27)) (-4328 (($ |#2| |#3|) NIL) (($ $ |#4| (-769)) NIL) (($ $ (-638 |#4|) (-638 (-769))) 55)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ |#4|) 158)) (-1921 (((-3 (-638 $) "failed") $) 41)) (-2336 (((-3 (-638 $) "failed") $) 30)) (-3019 (((-3 (-2 (|:| |var| |#4|) (|:| -3751 (-769))) "failed") $) 45)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 105)) (-4364 (((-424 (-1166 $)) (-1166 $)) 118)) (-3992 (((-424 (-1166 $)) (-1166 $)) 116)) (-4304 (((-424 $) $) 136)) (-4485 (($ $ (-638 (-290 $))) 20) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ |#4| |#2|) NIL) (($ $ (-638 |#4|) (-638 |#2|)) NIL) (($ $ |#4| $) NIL) (($ $ (-638 |#4|) (-638 $)) NIL)) (-2119 (($ $ |#4|) 76)) (-4081 (((-893 (-385)) $) 209) (((-893 (-572)) $) 202) (((-545) $) 217)) (-3694 ((|#2| $) NIL) (($ $ |#4|) 171)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 150)) (-1958 ((|#2| $ |#3|) NIL) (($ $ |#4| (-769)) 50) (($ $ (-638 |#4|) (-638 (-769))) 53)) (-2779 (((-3 $ "failed") $) 152)) (-1334 (((-121) $ $) 183))) 
-(((-955 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|))) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -2844 (|#1| |#1|)) (-15 -2779 ((-3 |#1| "failed") |#1|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|))) (-15 -3103 ((-890 (-385) |#1|) |#1| (-893 (-385)) (-890 (-385) |#1|))) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -3992 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -4364 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -2462 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|))) (-15 -1696 ((-3 (-1259 |#1|) "failed") (-685 |#1|))) (-15 -3988 (|#1| |#1| |#4|)) (-15 -3694 (|#1| |#1| |#4|)) (-15 -2119 (|#1| |#1| |#4|)) (-15 -3190 (|#1| |#1| |#1| |#4|)) (-15 -4378 ((-638 |#1|) |#1|)) (-15 -2357 ((-769) |#1| (-638 |#4|))) (-15 -2357 ((-769) |#1|)) (-15 -3019 ((-3 (-2 (|:| |var| |#4|) (|:| -3751 (-769))) "failed") |#1|)) (-15 -1921 ((-3 (-638 |#1|) "failed") |#1|)) (-15 -2336 ((-3 (-638 |#1|) "failed") |#1|)) (-15 -4328 (|#1| |#1| (-638 |#4|) (-638 (-769)))) (-15 -4328 (|#1| |#1| |#4| (-769))) (-15 -3835 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1| |#4|)) (-15 -3658 ((-638 |#1|) |#1|)) (-15 -1958 (|#1| |#1| (-638 |#4|) (-638 (-769)))) (-15 -1958 (|#1| |#1| |#4| (-769))) (-15 -2284 ((-685 |#2|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -1318 (|#4| |#1|)) (-15 -3376 ((-3 |#4| "failed") |#1|)) (-15 -4485 (|#1| |#1| (-638 |#4|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#4| |#1|)) (-15 -4485 (|#1| |#1| (-638 |#4|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#4| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4328 (|#1| |#2| |#3|)) (-15 -1958 (|#2| |#1| |#3|)) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3694 (|#2| |#1|)) (-15 -3988 (|#1| |#1|))) (-956 |#2| |#3| |#4|) (-1054) (-794) (-848)) (T -955)) 
-NIL 
-(-10 -8 (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|))) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -2844 (|#1| |#1|)) (-15 -2779 ((-3 |#1| "failed") |#1|)) (-15 -1334 ((-121) |#1| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|))) (-15 -3103 ((-890 (-385) |#1|) |#1| (-893 (-385)) (-890 (-385) |#1|))) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -3992 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -4364 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -2462 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|))) (-15 -1696 ((-3 (-1259 |#1|) "failed") (-685 |#1|))) (-15 -3988 (|#1| |#1| |#4|)) (-15 -3694 (|#1| |#1| |#4|)) (-15 -2119 (|#1| |#1| |#4|)) (-15 -3190 (|#1| |#1| |#1| |#4|)) (-15 -4378 ((-638 |#1|) |#1|)) (-15 -2357 ((-769) |#1| (-638 |#4|))) (-15 -2357 ((-769) |#1|)) (-15 -3019 ((-3 (-2 (|:| |var| |#4|) (|:| -3751 (-769))) "failed") |#1|)) (-15 -1921 ((-3 (-638 |#1|) "failed") |#1|)) (-15 -2336 ((-3 (-638 |#1|) "failed") |#1|)) (-15 -4328 (|#1| |#1| (-638 |#4|) (-638 (-769)))) (-15 -4328 (|#1| |#1| |#4| (-769))) (-15 -3835 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1| |#4|)) (-15 -3658 ((-638 |#1|) |#1|)) (-15 -1958 (|#1| |#1| (-638 |#4|) (-638 (-769)))) (-15 -1958 (|#1| |#1| |#4| (-769))) (-15 -2284 ((-685 |#2|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -1318 (|#4| |#1|)) (-15 -3376 ((-3 |#4| "failed") |#1|)) (-15 -4485 (|#1| |#1| (-638 |#4|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#4| |#1|)) (-15 -4485 (|#1| |#1| (-638 |#4|) (-638 |#2|))) (-15 -4485 (|#1| |#1| |#4| |#2|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4328 (|#1| |#2| |#3|)) (-15 -1958 (|#2| |#1| |#3|)) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3694 (|#2| |#1|)) (-15 -3988 (|#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 |#3|) $) 108)) (-4297 (((-1166 $) $ |#3|) 123) (((-1166 |#1|) $) 122)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 85 (|has| |#1| (-562)))) (-3946 (($ $) 86 (|has| |#1| (-562)))) (-3686 (((-121) $) 88 (|has| |#1| (-562)))) (-2357 (((-769) $) 110) (((-769) $ (-638 |#3|)) 109)) (-1572 (((-3 $ "failed") $ $) 18)) (-4073 (((-424 (-1166 $)) (-1166 $)) 98 (|has| |#1| (-910)))) (-2844 (($ $) 96 (|has| |#1| (-457)))) (-1466 (((-424 $) $) 95 (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 101 (|has| |#1| (-910)))) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 162) (((-3 (-413 (-572)) "failed") $) 160 (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) 158 (|has| |#1| (-1044 (-572)))) (((-3 |#3| "failed") $) 134)) (-1318 ((|#1| $) 163) (((-413 (-572)) $) 159 (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) 157 (|has| |#1| (-1044 (-572)))) ((|#3| $) 133)) (-3190 (($ $ $ |#3|) 106 (|has| |#1| (-174)))) (-4383 (($ $) 152)) (-2284 (((-685 (-572)) (-685 $)) 132 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 131 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 130) (((-685 |#1|) (-685 $)) 129)) (-1799 (((-3 $ "failed") $) 33)) (-3988 (($ $) 174 (|has| |#1| (-457))) (($ $ |#3|) 103 (|has| |#1| (-457)))) (-4378 (((-638 $) $) 107)) (-1526 (((-121) $) 94 (|has| |#1| (-910)))) (-3977 (($ $ |#1| |#2| $) 170)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 82 (-12 (|has| |#3| (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 81 (-12 (|has| |#3| (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3893 (((-121) $) 30)) (-3475 (((-769) $) 167)) (-4335 (($ (-1166 |#1|) |#3|) 115) (($ (-1166 $) |#3|) 114)) (-3658 (((-638 $) $) 124)) (-4581 (((-121) $) 150)) (-4328 (($ |#1| |#2|) 151) (($ $ |#3| (-769)) 117) (($ $ (-638 |#3|) (-638 (-769))) 116)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ |#3|) 118)) (-1784 ((|#2| $) 168) (((-769) $ |#3|) 120) (((-638 (-769)) $ (-638 |#3|)) 119)) (-1771 (($ $ $) 77 (|has| |#1| (-848)))) (-4238 (($ $ $) 76 (|has| |#1| (-848)))) (-3918 (($ (-1 |#2| |#2|) $) 169)) (-3828 (($ (-1 |#1| |#1|) $) 149)) (-1470 (((-3 |#3| "failed") $) 121)) (-4368 (($ $) 147)) (-4373 ((|#1| $) 146)) (-1629 (($ (-638 $)) 92 (|has| |#1| (-457))) (($ $ $) 91 (|has| |#1| (-457)))) (-1658 (((-1152) $) 9)) (-1921 (((-3 (-638 $) "failed") $) 112)) (-2336 (((-3 (-638 $) "failed") $) 113)) (-3019 (((-3 (-2 (|:| |var| |#3|) (|:| -3751 (-769))) "failed") $) 111)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 164)) (-4362 ((|#1| $) 165)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 93 (|has| |#1| (-457)))) (-3069 (($ (-638 $)) 90 (|has| |#1| (-457))) (($ $ $) 89 (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) 100 (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) 99 (|has| |#1| (-910)))) (-4304 (((-424 $) $) 97 (|has| |#1| (-910)))) (-1803 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-562))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) 143) (($ $ (-290 $)) 142) (($ $ $ $) 141) (($ $ (-638 $) (-638 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-638 |#3|) (-638 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-638 |#3|) (-638 $)) 136)) (-2119 (($ $ |#3|) 105 (|has| |#1| (-174)))) (-3139 (($ $ |#3|) 41) (($ $ (-638 |#3|)) 40) (($ $ |#3| (-769)) 39) (($ $ (-638 |#3|) (-638 (-769))) 38)) (-4316 ((|#2| $) 148) (((-769) $ |#3|) 128) (((-638 (-769)) $ (-638 |#3|)) 127)) (-4081 (((-893 (-385)) $) 80 (-12 (|has| |#3| (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) 79 (-12 (|has| |#3| (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) 78 (-12 (|has| |#3| (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) 173 (|has| |#1| (-457))) (($ $ |#3|) 104 (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 102 (-4028 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 161) (($ |#3|) 135) (($ $) 83 (|has| |#1| (-562))) (($ (-413 (-572))) 70 (-1841 (|has| |#1| (-1044 (-413 (-572)))) (|has| |#1| (-43 (-413 (-572))))))) (-3193 (((-638 |#1|) $) 166)) (-1958 ((|#1| $ |#2|) 153) (($ $ |#3| (-769)) 126) (($ $ (-638 |#3|) (-638 (-769))) 125)) (-2779 (((-3 $ "failed") $) 71 (-1841 (-4028 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) 28)) (-2565 (($ $ $ (-769)) 171 (|has| |#1| (-174)))) (-3774 (((-121) $ $) 87 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ |#3|) 37) (($ $ (-638 |#3|)) 36) (($ $ |#3| (-769)) 35) (($ $ (-638 |#3|) (-638 (-769))) 34)) (-1349 (((-121) $ $) 74 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 73 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 75 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 72 (|has| |#1| (-848)))) (-1379 (($ $ |#1|) 154 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 156 (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) 155 (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
-(((-956 |#1| |#2| |#3|) (-1290) (-1054) (-794) (-848)) (T -956)) 
-((-3988 (*1 *1 *1) (-12 (-4 *1 (-956 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457)))) (-4316 (*1 *2 *1 *3) (-12 (-4 *1 (-956 *4 *5 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-769)))) (-4316 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 (-769))))) (-1958 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-956 *4 *5 *2)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *2 (-848)))) (-1958 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *6)) (-5 *3 (-638 (-769))) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)))) (-3658 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-956 *3 *4 *5)))) (-4297 (*1 *2 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-1166 *1)) (-4 *1 (-956 *4 *5 *3)))) (-4297 (*1 *2 *1) (-12 (-4 *1 (-956 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-1166 *3)))) (-1470 (*1 *2 *1) (|partial| -12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) (-1784 (*1 *2 *1 *3) (-12 (-4 *1 (-956 *4 *5 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-769)))) (-1784 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 (-769))))) (-3835 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-956 *4 *5 *3)))) (-4328 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-956 *4 *5 *2)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *2 (-848)))) (-4328 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *6)) (-5 *3 (-638 (-769))) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)))) (-4335 (*1 *1 *2 *3) (-12 (-5 *2 (-1166 *4)) (-4 *4 (-1054)) (-4 *1 (-956 *4 *5 *3)) (-4 *5 (-794)) (-4 *3 (-848)))) (-4335 (*1 *1 *2 *3) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-956 *4 *5 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)))) (-2336 (*1 *2 *1) (|partial| -12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-956 *3 *4 *5)))) (-1921 (*1 *2 *1) (|partial| -12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-956 *3 *4 *5)))) (-3019 (*1 *2 *1) (|partial| -12 (-4 *1 (-956 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| |var| *5) (|:| -3751 (-769)))))) (-2357 (*1 *2 *1) (-12 (-4 *1 (-956 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-769)))) (-2357 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-769)))) (-3456 (*1 *2 *1) (-12 (-4 *1 (-956 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *5)))) (-4378 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-956 *3 *4 *5)))) (-3190 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *3 (-174)))) (-2119 (*1 *1 *1 *2) (-12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *3 (-174)))) (-3694 (*1 *1 *1 *2) (-12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *3 (-457)))) (-3988 (*1 *1 *1 *2) (-12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *3 (-457)))) (-2844 (*1 *1 *1) (-12 (-4 *1 (-956 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457)))) (-1466 (*1 *2 *1) (-12 (-4 *3 (-457)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-424 *1)) (-4 *1 (-956 *3 *4 *5))))) 
-(-13 (-901 |t#3|) (-326 |t#1| |t#2|) (-305 $) (-527 |t#3| |t#1|) (-527 |t#3| $) (-1044 |t#3|) (-383 |t#1|) (-10 -8 (-15 -4316 ((-769) $ |t#3|)) (-15 -4316 ((-638 (-769)) $ (-638 |t#3|))) (-15 -1958 ($ $ |t#3| (-769))) (-15 -1958 ($ $ (-638 |t#3|) (-638 (-769)))) (-15 -3658 ((-638 $) $)) (-15 -4297 ((-1166 $) $ |t#3|)) (-15 -4297 ((-1166 |t#1|) $)) (-15 -1470 ((-3 |t#3| "failed") $)) (-15 -1784 ((-769) $ |t#3|)) (-15 -1784 ((-638 (-769)) $ (-638 |t#3|))) (-15 -3835 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $ |t#3|)) (-15 -4328 ($ $ |t#3| (-769))) (-15 -4328 ($ $ (-638 |t#3|) (-638 (-769)))) (-15 -4335 ($ (-1166 |t#1|) |t#3|)) (-15 -4335 ($ (-1166 $) |t#3|)) (-15 -2336 ((-3 (-638 $) "failed") $)) (-15 -1921 ((-3 (-638 $) "failed") $)) (-15 -3019 ((-3 (-2 (|:| |var| |t#3|) (|:| -3751 (-769))) "failed") $)) (-15 -2357 ((-769) $)) (-15 -2357 ((-769) $ (-638 |t#3|))) (-15 -3456 ((-638 |t#3|) $)) (-15 -4378 ((-638 $) $)) (IF (|has| |t#1| (-848)) (-6 (-848)) |noBranch|) (IF (|has| |t#1| (-613 (-545))) (IF (|has| |t#3| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-613 (-893 (-572)))) (IF (|has| |t#3| (-613 (-893 (-572)))) (-6 (-613 (-893 (-572)))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-613 (-893 (-385)))) (IF (|has| |t#3| (-613 (-893 (-385)))) (-6 (-613 (-893 (-385)))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-887 (-572))) (IF (|has| |t#3| (-887 (-572))) (-6 (-887 (-572))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-887 (-385))) (IF (|has| |t#3| (-887 (-385))) (-6 (-887 (-385))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-174)) (PROGN (-15 -3190 ($ $ $ |t#3|)) (-15 -2119 ($ $ |t#3|))) |noBranch|) (IF (|has| |t#1| (-457)) (PROGN (-6 (-457)) (-15 -3694 ($ $ |t#3|)) (-15 -3988 ($ $)) (-15 -3988 ($ $ |t#3|)) (-15 -1466 ((-424 $) $)) (-15 -2844 ($ $))) |noBranch|) (IF (|has| |t#1| (-6 -4600)) (-6 -4600) |noBranch|) (IF (|has| |t#1| (-910)) (-6 (-910)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-613 (-545)) -12 (|has| |#1| (-613 (-545))) (|has| |#3| (-613 (-545)))) ((-613 (-893 (-385))) -12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#3| (-613 (-893 (-385))))) ((-613 (-893 (-572))) -12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#3| (-613 (-893 (-572))))) ((-287) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-305 $) . T) ((-326 |#1| |#2|) . T) ((-383 |#1|) . T) ((-417 |#1|) . T) ((-457) -1841 (|has| |#1| (-910)) (|has| |#1| (-457))) ((-527 |#3| |#1|) . T) ((-527 |#3| $) . T) ((-527 $ $) . T) ((-562) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-722) . T) ((-848) |has| |#1| (-848)) ((-901 |#3|) . T) ((-887 (-385)) -12 (|has| |#1| (-887 (-385))) (|has| |#3| (-887 (-385)))) ((-887 (-572)) -12 (|has| |#1| (-887 (-572))) (|has| |#3| (-887 (-572)))) ((-910) |has| |#1| (-910)) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1044 |#3|) . T) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) |has| |#1| (-910))) 
-((-3456 (((-638 |#2|) |#5|) 36)) (-4297 (((-1166 |#5|) |#5| |#2| (-1166 |#5|)) 23) (((-413 (-1166 |#5|)) |#5| |#2|) 16)) (-4335 ((|#5| (-413 (-1166 |#5|)) |#2|) 30)) (-1470 (((-3 |#2| "failed") |#5|) 61)) (-1921 (((-3 (-638 |#5|) "failed") |#5|) 55)) (-2472 (((-3 (-2 (|:| |val| |#5|) (|:| -3751 (-572))) "failed") |#5|) 45)) (-2336 (((-3 (-638 |#5|) "failed") |#5|) 57)) (-3019 (((-3 (-2 (|:| |var| |#2|) (|:| -3751 (-572))) "failed") |#5|) 48))) 
-(((-957 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3456 ((-638 |#2|) |#5|)) (-15 -1470 ((-3 |#2| "failed") |#5|)) (-15 -4297 ((-413 (-1166 |#5|)) |#5| |#2|)) (-15 -4335 (|#5| (-413 (-1166 |#5|)) |#2|)) (-15 -4297 ((-1166 |#5|) |#5| |#2| (-1166 |#5|))) (-15 -2336 ((-3 (-638 |#5|) "failed") |#5|)) (-15 -1921 ((-3 (-638 |#5|) "failed") |#5|)) (-15 -3019 ((-3 (-2 (|:| |var| |#2|) (|:| -3751 (-572))) "failed") |#5|)) (-15 -2472 ((-3 (-2 (|:| |val| |#5|) (|:| -3751 (-572))) "failed") |#5|))) (-794) (-848) (-1054) (-956 |#3| |#1| |#2|) (-13 (-368) (-10 -8 (-15 -3972 ($ |#4|)) (-15 -4487 (|#4| $)) (-15 -4492 (|#4| $))))) (T -957)) 
-((-2472 (*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-2 (|:| |val| *3) (|:| -3751 (-572)))) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))))) (-3019 (*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-2 (|:| |var| *5) (|:| -3751 (-572)))) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))))) (-1921 (*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-638 *3)) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))))) (-2336 (*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-638 *3)) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))))) (-4297 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-1166 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))) (-4 *7 (-956 *6 *5 *4)) (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-1054)) (-5 *1 (-957 *5 *4 *6 *7 *3)))) (-4335 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-1166 *2))) (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-1054)) (-4 *2 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))) (-5 *1 (-957 *5 *4 *6 *7 *2)) (-4 *7 (-956 *6 *5 *4)))) (-4297 (*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *5 *4)) (-5 *2 (-413 (-1166 *3))) (-5 *1 (-957 *5 *4 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))))) (-1470 (*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-1054)) (-4 *6 (-956 *5 *4 *2)) (-4 *2 (-848)) (-5 *1 (-957 *4 *2 *5 *6 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *6)) (-15 -4487 (*6 $)) (-15 -4492 (*6 $))))))) (-3456 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-638 *5)) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $)))))))) 
-(-10 -7 (-15 -3456 ((-638 |#2|) |#5|)) (-15 -1470 ((-3 |#2| "failed") |#5|)) (-15 -4297 ((-413 (-1166 |#5|)) |#5| |#2|)) (-15 -4335 (|#5| (-413 (-1166 |#5|)) |#2|)) (-15 -4297 ((-1166 |#5|) |#5| |#2| (-1166 |#5|))) (-15 -2336 ((-3 (-638 |#5|) "failed") |#5|)) (-15 -1921 ((-3 (-638 |#5|) "failed") |#5|)) (-15 -3019 ((-3 (-2 (|:| |var| |#2|) (|:| -3751 (-572))) "failed") |#5|)) (-15 -2472 ((-3 (-2 (|:| |val| |#5|) (|:| -3751 (-572))) "failed") |#5|))) 
-((-3828 ((|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|) 23))) 
-(((-958 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3828 (|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|))) (-794) (-848) (-1054) (-956 |#3| |#1| |#2|) (-13 (-1098) (-10 -8 (-15 -1367 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-769)))))) (T -958)) 
-((-3828 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *7)) (-5 *4 (-1 *2 *8)) (-4 *7 (-848)) (-4 *8 (-1054)) (-4 *6 (-794)) (-4 *2 (-13 (-1098) (-10 -8 (-15 -1367 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-769)))))) (-5 *1 (-958 *6 *7 *8 *5 *2)) (-4 *5 (-956 *8 *6 *7))))) 
-(-10 -7 (-15 -3828 (|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1170)) $) 15)) (-4297 (((-1166 $) $ (-1170)) 21) (((-1166 |#1|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1170))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 8) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-1170) "failed") $) NIL)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-1170) $) NIL)) (-3190 (($ $ $ (-1170)) NIL (|has| |#1| (-174)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ (-1170)) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-538 (-1170)) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1170) (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1170) (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-4335 (($ (-1166 |#1|) (-1170)) NIL) (($ (-1166 $) (-1170)) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-538 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1170)) NIL)) (-1784 (((-538 (-1170)) $) NIL) (((-769) $ (-1170)) NIL) (((-638 (-769)) $ (-638 (-1170))) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-538 (-1170)) (-538 (-1170))) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-1470 (((-3 (-1170) "failed") $) 19)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-1170)) (|:| -3751 (-769))) "failed") $) NIL)) (-2774 (($ $ (-1170)) 29 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1170) |#1|) NIL) (($ $ (-638 (-1170)) (-638 |#1|)) NIL) (($ $ (-1170) $) NIL) (($ $ (-638 (-1170)) (-638 $)) NIL)) (-2119 (($ $ (-1170)) NIL (|has| |#1| (-174)))) (-3139 (($ $ (-1170)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL)) (-4316 (((-538 (-1170)) $) NIL) (((-769) $ (-1170)) NIL) (((-638 (-769)) $ (-638 (-1170))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-1170) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-1170) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-1170) (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) NIL (|has| |#1| (-457))) (($ $ (-1170)) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) 25) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-1170)) 27) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-538 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-1170)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-959 |#1|) (-13 (-956 |#1| (-538 (-1170)) (-1170)) (-10 -8 (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1170))) |noBranch|))) (-1054)) (T -959)) 
-((-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-959 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054))))) 
-(-13 (-956 |#1| (-538 (-1170)) (-1170)) (-10 -8 (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1170))) |noBranch|))) 
-((-2309 (((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) |#3| (-769)) 37)) (-3776 (((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) (-413 (-572)) (-769)) 33)) (-3468 (((-2 (|:| -3751 (-769)) (|:| -4513 |#4|) (|:| |radicand| (-638 |#4|))) |#4| (-769)) 52)) (-2040 (((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) |#5| (-769)) 62 (|has| |#3| (-457))))) 
-(((-960 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2309 ((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) |#3| (-769))) (-15 -3776 ((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) (-413 (-572)) (-769))) (IF (|has| |#3| (-457)) (-15 -2040 ((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) |#5| (-769))) |noBranch|) (-15 -3468 ((-2 (|:| -3751 (-769)) (|:| -4513 |#4|) (|:| |radicand| (-638 |#4|))) |#4| (-769)))) (-794) (-848) (-562) (-956 |#3| |#1| |#2|) (-13 (-368) (-10 -8 (-15 -4487 (|#4| $)) (-15 -4492 (|#4| $)) (-15 -3972 ($ |#4|))))) (T -960)) 
-((-3468 (*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-562)) (-4 *3 (-956 *7 *5 *6)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *3) (|:| |radicand| (-638 *3)))) (-5 *1 (-960 *5 *6 *7 *3 *8)) (-5 *4 (-769)) (-4 *8 (-13 (-368) (-10 -8 (-15 -4487 (*3 $)) (-15 -4492 (*3 $)) (-15 -3972 ($ *3))))))) (-2040 (*1 *2 *3 *4) (-12 (-4 *7 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-562)) (-4 *8 (-956 *7 *5 *6)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *3) (|:| |radicand| *3))) (-5 *1 (-960 *5 *6 *7 *8 *3)) (-5 *4 (-769)) (-4 *3 (-13 (-368) (-10 -8 (-15 -4487 (*8 $)) (-15 -4492 (*8 $)) (-15 -3972 ($ *8))))))) (-3776 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-572))) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-562)) (-4 *8 (-956 *7 *5 *6)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *9) (|:| |radicand| *9))) (-5 *1 (-960 *5 *6 *7 *8 *9)) (-5 *4 (-769)) (-4 *9 (-13 (-368) (-10 -8 (-15 -4487 (*8 $)) (-15 -4492 (*8 $)) (-15 -3972 ($ *8))))))) (-2309 (*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-562)) (-4 *7 (-956 *3 *5 *6)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *8) (|:| |radicand| *8))) (-5 *1 (-960 *5 *6 *3 *7 *8)) (-5 *4 (-769)) (-4 *8 (-13 (-368) (-10 -8 (-15 -4487 (*7 $)) (-15 -4492 (*7 $)) (-15 -3972 ($ *7)))))))) 
-(-10 -7 (-15 -2309 ((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) |#3| (-769))) (-15 -3776 ((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) (-413 (-572)) (-769))) (IF (|has| |#3| (-457)) (-15 -2040 ((-2 (|:| -3751 (-769)) (|:| -4513 |#5|) (|:| |radicand| |#5|)) |#5| (-769))) |noBranch|) (-15 -3468 ((-2 (|:| -3751 (-769)) (|:| -4513 |#4|) (|:| |radicand| (-638 |#4|))) |#4| (-769)))) 
-((-3149 (((-1264) (-1208) (-572) (-1208) (-572) (-572) (-572) (-572)) 33)) (-3174 (((-1264) (-1208) (-1208) (-572) (-572) (-572) (-572)) 27)) (-3183 (((-1208) (-1208) (-1208) (-572) (-572)) 45)) (-3218 (((-1264) (-1208) (-1208) (-1208) (-572) (-572)) 44)) (-3241 (((-1208) (-1166 (-572)) (-572)) 26)) (-3190 (((-572) (-1208) (-1208) (-572)) 54)) (-3260 (((-1264) (-1208) (-1208) (-572)) 36)) (-3341 (((-1208) (-1208) (-923) (-769) (-572)) 48)) (-3281 (((-1264) (-1208) (-572) (-572) (-572)) 31)) (-3317 (((-1264) (-1208) (-572) (-572) (-572)) 28) (((-1264) (-1208) (-572) (-572)) 30)) (-3327 (((-1208) (-1208) (-1208) (-572)) 41)) (-1629 (((-1208) (-965 (-1208)) (-572) (-572) (-572)) 42)) (-3069 (((-1208) (-965 (-1208)) (-572) (-572) (-572)) 40) (((-1208) (-1208) (-1208) (-572)) 38)) (-3367 (((-638 (-1208)) (-1208) (-1208) (-572)) 53)) (-3387 (((-572) (-1208) (-572) (-572) (-572)) 15)) (-3415 (((-1264) (-1208) (-1208) (-1208) (-572)) 35)) (-3139 (((-1208) (-1208) (-769) (-572)) 51) (((-1208) (-1208) (-572)) 50)) (-4316 (((-572) (-1208)) 32)) (-3447 (((-1264) (-1208) (-1208) (-572) (-572)) 12)) (-3478 (((-1264) (-1208) (-1208) (-572)) 11))) 
-(((-961) (-10 -7 (-15 -3478 ((-1264) (-1208) (-1208) (-572))) (-15 -3447 ((-1264) (-1208) (-1208) (-572) (-572))) (-15 -3387 ((-572) (-1208) (-572) (-572) (-572))) (-15 -3174 ((-1264) (-1208) (-1208) (-572) (-572) (-572) (-572))) (-15 -3317 ((-1264) (-1208) (-572) (-572))) (-15 -3317 ((-1264) (-1208) (-572) (-572) (-572))) (-15 -3281 ((-1264) (-1208) (-572) (-572) (-572))) (-15 -3327 ((-1208) (-1208) (-1208) (-572))) (-15 -3183 ((-1208) (-1208) (-1208) (-572) (-572))) (-15 -3218 ((-1264) (-1208) (-1208) (-1208) (-572) (-572))) (-15 -3341 ((-1208) (-1208) (-923) (-769) (-572))) (-15 -3139 ((-1208) (-1208) (-572))) (-15 -3139 ((-1208) (-1208) (-769) (-572))) (-15 -3415 ((-1264) (-1208) (-1208) (-1208) (-572))) (-15 -3260 ((-1264) (-1208) (-1208) (-572))) (-15 -3149 ((-1264) (-1208) (-572) (-1208) (-572) (-572) (-572) (-572))) (-15 -3241 ((-1208) (-1166 (-572)) (-572))) (-15 -3069 ((-1208) (-1208) (-1208) (-572))) (-15 -3069 ((-1208) (-965 (-1208)) (-572) (-572) (-572))) (-15 -1629 ((-1208) (-965 (-1208)) (-572) (-572) (-572))) (-15 -4316 ((-572) (-1208))) (-15 -3367 ((-638 (-1208)) (-1208) (-1208) (-572))) (-15 -3190 ((-572) (-1208) (-1208) (-572))))) (T -961)) 
-((-3190 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-572)) (-5 *3 (-1208)) (-5 *1 (-961)))) (-3367 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-572)) (-5 *2 (-638 (-1208))) (-5 *1 (-961)) (-5 *3 (-1208)))) (-4316 (*1 *2 *3) (-12 (-5 *3 (-1208)) (-5 *2 (-572)) (-5 *1 (-961)))) (-1629 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-965 (-1208))) (-5 *4 (-572)) (-5 *2 (-1208)) (-5 *1 (-961)))) (-3069 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-965 (-1208))) (-5 *4 (-572)) (-5 *2 (-1208)) (-5 *1 (-961)))) (-3069 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-1208)) (-5 *3 (-572)) (-5 *1 (-961)))) (-3241 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 (-572))) (-5 *4 (-572)) (-5 *2 (-1208)) (-5 *1 (-961)))) (-3149 (*1 *2 *3 *4 *3 *4 *4 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3260 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3415 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3139 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-1208)) (-5 *3 (-769)) (-5 *4 (-572)) (-5 *1 (-961)))) (-3139 (*1 *2 *2 *3) (-12 (-5 *2 (-1208)) (-5 *3 (-572)) (-5 *1 (-961)))) (-3341 (*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-1208)) (-5 *3 (-923)) (-5 *4 (-769)) (-5 *5 (-572)) (-5 *1 (-961)))) (-3218 (*1 *2 *3 *3 *3 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3183 (*1 *2 *2 *2 *3 *3) (-12 (-5 *2 (-1208)) (-5 *3 (-572)) (-5 *1 (-961)))) (-3327 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-1208)) (-5 *3 (-572)) (-5 *1 (-961)))) (-3281 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3317 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3317 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3174 (*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3387 (*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *3 (-1208)) (-5 *1 (-961)))) (-3447 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) (-3478 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(-10 -7 (-15 -3478 ((-1264) (-1208) (-1208) (-572))) (-15 -3447 ((-1264) (-1208) (-1208) (-572) (-572))) (-15 -3387 ((-572) (-1208) (-572) (-572) (-572))) (-15 -3174 ((-1264) (-1208) (-1208) (-572) (-572) (-572) (-572))) (-15 -3317 ((-1264) (-1208) (-572) (-572))) (-15 -3317 ((-1264) (-1208) (-572) (-572) (-572))) (-15 -3281 ((-1264) (-1208) (-572) (-572) (-572))) (-15 -3327 ((-1208) (-1208) (-1208) (-572))) (-15 -3183 ((-1208) (-1208) (-1208) (-572) (-572))) (-15 -3218 ((-1264) (-1208) (-1208) (-1208) (-572) (-572))) (-15 -3341 ((-1208) (-1208) (-923) (-769) (-572))) (-15 -3139 ((-1208) (-1208) (-572))) (-15 -3139 ((-1208) (-1208) (-769) (-572))) (-15 -3415 ((-1264) (-1208) (-1208) (-1208) (-572))) (-15 -3260 ((-1264) (-1208) (-1208) (-572))) (-15 -3149 ((-1264) (-1208) (-572) (-1208) (-572) (-572) (-572) (-572))) (-15 -3241 ((-1208) (-1166 (-572)) (-572))) (-15 -3069 ((-1208) (-1208) (-1208) (-572))) (-15 -3069 ((-1208) (-965 (-1208)) (-572) (-572) (-572))) (-15 -1629 ((-1208) (-965 (-1208)) (-572) (-572) (-572))) (-15 -4316 ((-572) (-1208))) (-15 -3367 ((-638 (-1208)) (-1208) (-1208) (-572))) (-15 -3190 ((-572) (-1208) (-1208) (-572)))) 
-((-1497 (((-1092 (-217)) $) 7)) (-2153 (((-1092 (-217)) $) 8)) (-3192 (((-638 (-638 (-950 (-217)))) $) 9)) (-3972 (((-856) $) 6))) 
-(((-962) (-1290)) (T -962)) 
-((-3192 (*1 *2 *1) (-12 (-4 *1 (-962)) (-5 *2 (-638 (-638 (-950 (-217))))))) (-2153 (*1 *2 *1) (-12 (-4 *1 (-962)) (-5 *2 (-1092 (-217))))) (-1497 (*1 *2 *1) (-12 (-4 *1 (-962)) (-5 *2 (-1092 (-217)))))) 
-(-13 (-612 (-856)) (-10 -8 (-15 -3192 ((-638 (-638 (-950 (-217)))) $)) (-15 -2153 ((-1092 (-217)) $)) (-15 -1497 ((-1092 (-217)) $)))) 
-(((-612 (-856)) . T)) 
-((-2999 (((-3 (-685 |#1|) "failed") |#2| (-923)) 14))) 
-(((-963 |#1| |#2|) (-10 -7 (-15 -2999 ((-3 (-685 |#1|) "failed") |#2| (-923)))) (-562) (-650 |#1|)) (T -963)) 
-((-2999 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-923)) (-4 *5 (-562)) (-5 *2 (-685 *5)) (-5 *1 (-963 *5 *3)) (-4 *3 (-650 *5))))) 
-(-10 -7 (-15 -2999 ((-3 (-685 |#1|) "failed") |#2| (-923)))) 
-((-1911 (((-965 |#2|) (-1 |#2| |#1| |#2|) (-965 |#1|) |#2|) 16)) (-3116 ((|#2| (-1 |#2| |#1| |#2|) (-965 |#1|) |#2|) 18)) (-3828 (((-965 |#2|) (-1 |#2| |#1|) (-965 |#1|)) 13))) 
-(((-964 |#1| |#2|) (-10 -7 (-15 -1911 ((-965 |#2|) (-1 |#2| |#1| |#2|) (-965 |#1|) |#2|)) (-15 -3116 (|#2| (-1 |#2| |#1| |#2|) (-965 |#1|) |#2|)) (-15 -3828 ((-965 |#2|) (-1 |#2| |#1|) (-965 |#1|)))) (-1204) (-1204)) (T -964)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-965 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-965 *6)) (-5 *1 (-964 *5 *6)))) (-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-965 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-964 *5 *2)))) (-1911 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-965 *6)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-5 *2 (-965 *5)) (-5 *1 (-964 *6 *5))))) 
-(-10 -7 (-15 -1911 ((-965 |#2|) (-1 |#2| |#1| |#2|) (-965 |#1|) |#2|)) (-15 -3116 (|#2| (-1 |#2| |#1| |#2|) (-965 |#1|) |#2|)) (-15 -3828 ((-965 |#2|) (-1 |#2| |#1|) (-965 |#1|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) |#1|) 17 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) 16 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 14)) (-4014 (((-572) (-1 (-121) |#1|) $) NIL) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098)))) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) |#1|) 13)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 10 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) NIL (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) 12 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 11)) (-3277 ((|#1| $ (-572) |#1|) NIL) ((|#1| $ (-572)) 15) (($ $ (-1225 (-572))) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) NIL)) (-4500 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-4032 (((-769) $) 8 (|has| $ (-6 -4602))))) 
-(((-965 |#1|) (-19 |#1|) (-1204)) (T -965)) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-1403 (((-790) $) 15)) (-3659 (($ $ |#1|) 55)) (-2512 (($ $) 32)) (-1373 (($ $) 31)) (-4368 (((-3 |#1| "failed") $) 47)) (-2400 ((|#1| $) NIL)) (-2119 (($ |#1| |#2| $) 60) (($ $ $) 61)) (-4149 (((-877) $ (-1 (-877) (-877) (-877)) (-1 (-877) (-877) (-877)) (-592)) 45)) (-4449 ((|#1| $ (-592)) 30)) (-3888 ((|#2| $ (-592)) 29)) (-3401 (($ (-1 |#1| |#1|) $) 34)) (-3970 (($ (-1 |#2| |#2|) $) 38)) (-4020 (($) 10)) (-2104 (($ |#1| |#2|) 22)) (-1674 (($ (-658 (-2 (|:| |gen| |#1|) (|:| -1430 |#2|)))) 23)) (-1713 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 |#2|))) $) 13)) (-2249 (($ |#1| $) 56)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3370 (((-141) $ $) 58)) (-1683 (((-877) $) 19) (($ |#1|) 16)) (-3255 (((-141) $ $) 25))) 
+(((-662 |#1| |#2| |#3|) (-13 (-1119) (-1065 |#1|) (-10 -8 (-15 -4149 ((-877) $ (-1 (-877) (-877) (-877)) (-1 (-877) (-877) (-877)) (-592))) (-15 -1713 ((-658 (-2 (|:| |gen| |#1|) (|:| -1430 |#2|))) $)) (-15 -2104 ($ |#1| |#2|)) (-15 -1674 ($ (-658 (-2 (|:| |gen| |#1|) (|:| -1430 |#2|))))) (-15 -3888 (|#2| $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -1373 ($ $)) (-15 -2512 ($ $)) (-15 -1403 ((-790) $)) (-15 -4020 ($)) (-15 -3659 ($ $ |#1|)) (-15 -2249 ($ |#1| $)) (-15 -2119 ($ |#1| |#2| $)) (-15 -2119 ($ $ $)) (-15 -3370 ((-141) $ $)) (-15 -3970 ($ (-1 |#2| |#2|) $)) (-15 -3401 ($ (-1 |#1| |#1|) $)))) (-1119) (-23) |#2|) (T -662)) 
+((-4149 (*1 *2 *1 *3 *3 *4) (-12 (-5 *3 (-1 (-877) (-877) (-877))) (-5 *4 (-592)) (-5 *2 (-877)) (-5 *1 (-662 *5 *6 *7)) (-4 *5 (-1119)) (-4 *6 (-23)) (-14 *7 *6))) (-1713 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 *4)))) (-5 *1 (-662 *3 *4 *5)) (-4 *3 (-1119)) (-4 *4 (-23)) (-14 *5 *4))) (-2104 (*1 *1 *2 *3) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) (-1674 (*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 *4)))) (-4 *3 (-1119)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-662 *3 *4 *5)))) (-3888 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *2 (-23)) (-5 *1 (-662 *4 *2 *5)) (-4 *4 (-1119)) (-14 *5 *2))) (-4449 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *2 (-1119)) (-5 *1 (-662 *2 *4 *5)) (-4 *4 (-23)) (-14 *5 *4))) (-1373 (*1 *1 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) (-2512 (*1 *1 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) (-1403 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-662 *3 *4 *5)) (-4 *3 (-1119)) (-4 *4 (-23)) (-14 *5 *4))) (-4020 (*1 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) (-3659 (*1 *1 *1 *2) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) (-2249 (*1 *1 *2 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) (-2119 (*1 *1 *2 *3 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) (-2119 (*1 *1 *1 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) (-3370 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-662 *3 *4 *5)) (-4 *3 (-1119)) (-4 *4 (-23)) (-14 *5 *4))) (-3970 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-662 *3 *4 *5)) (-4 *3 (-1119)))) (-3401 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-662 *3 *4 *5)) (-4 *4 (-23)) (-14 *5 *4)))) 
+(-13 (-1119) (-1065 |#1|) (-10 -8 (-15 -4149 ((-877) $ (-1 (-877) (-877) (-877)) (-1 (-877) (-877) (-877)) (-592))) (-15 -1713 ((-658 (-2 (|:| |gen| |#1|) (|:| -1430 |#2|))) $)) (-15 -2104 ($ |#1| |#2|)) (-15 -1674 ($ (-658 (-2 (|:| |gen| |#1|) (|:| -1430 |#2|))))) (-15 -3888 (|#2| $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -1373 ($ $)) (-15 -2512 ($ $)) (-15 -1403 ((-790) $)) (-15 -4020 ($)) (-15 -3659 ($ $ |#1|)) (-15 -2249 ($ |#1| $)) (-15 -2119 ($ |#1| |#2| $)) (-15 -2119 ($ $ $)) (-15 -3370 ((-141) $ $)) (-15 -3970 ($ (-1 |#2| |#2|) $)) (-15 -3401 ($ (-1 |#1| |#1|) $)))) 
+((-1813 (((-592) $) 23)) (-3666 (($ |#2| $ (-592)) 21) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) 12)) (-3780 (((-141) (-592) $) 14)) (-2266 (($ $ |#2|) 18) (($ |#2| $) 19) (($ $ $) NIL) (($ (-658 $)) NIL))) 
+(((-663 |#1| |#2|) (-10 -8 (-15 -3666 (|#1| |#1| |#1| (-592))) (-15 -3666 (|#1| |#2| |#1| (-592))) (-15 -2266 (|#1| (-658 |#1|))) (-15 -2266 (|#1| |#1| |#1|)) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#2|)) (-15 -1813 ((-592) |#1|)) (-15 -3708 ((-658 (-592)) |#1|)) (-15 -3780 ((-141) (-592) |#1|))) (-664 |#2|) (-1225)) (T -663)) 
+NIL 
+(-10 -8 (-15 -3666 (|#1| |#1| |#1| (-592))) (-15 -3666 (|#1| |#2| |#1| (-592))) (-15 -2266 (|#1| (-658 |#1|))) (-15 -2266 (|#1| |#1| |#1|)) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#2|)) (-15 -1813 ((-592) |#1|)) (-15 -3708 ((-658 (-592)) |#1|)) (-15 -3780 ((-141) (-592) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#1| $ (-592) |#1|) 49 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 53 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) 70 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1360 (($ $) 73 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#1| $) 72 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 69 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) 50 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 48)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-3242 (($ (-790) |#1|) 64)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) 55) (($ $ $ (-592)) 54)) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 39 (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 66)) (-1892 (($ $ |#1|) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 42 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ (-592) |#1|) 47) ((|#1| $ (-592)) 46) (($ $ (-1246 (-592))) 58)) (-3208 (($ $ (-592)) 57) (($ $ (-1246 (-592))) 56)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 74 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 65)) (-2266 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-658 $)) 60)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-664 |#1|) (-1311) (-1225)) (T -664)) 
+((-3242 (*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) (-2266 (*1 *1 *1 *2) (-12 (-4 *1 (-664 *2)) (-4 *2 (-1225)))) (-2266 (*1 *1 *2 *1) (-12 (-4 *1 (-664 *2)) (-4 *2 (-1225)))) (-2266 (*1 *1 *1 *1) (-12 (-4 *1 (-664 *2)) (-4 *2 (-1225)))) (-2266 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) (-2731 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 (-1246 (-592))) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) (-3208 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) (-3208 (*1 *1 *1 *2) (-12 (-5 *2 (-1246 (-592))) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) (-3666 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-664 *2)) (-4 *2 (-1225)))) (-3666 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) (-3932 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-1246 (-592))) (|has| *1 (-6 -4626)) (-4 *1 (-664 *2)) (-4 *2 (-1225))))) 
+(-13 (-625 (-592) |t#1|) (-175 |t#1|) (-10 -8 (-15 -3242 ($ (-790) |t#1|)) (-15 -2266 ($ $ |t#1|)) (-15 -2266 ($ |t#1| $)) (-15 -2266 ($ $ $)) (-15 -2266 ($ (-658 $))) (-15 -2731 ($ (-1 |t#1| |t#1| |t#1|) $ $)) (-15 -3927 ($ $ (-1246 (-592)))) (-15 -3208 ($ $ (-592))) (-15 -3208 ($ $ (-1246 (-592)))) (-15 -3666 ($ |t#1| $ (-592))) (-15 -3666 ($ $ $ (-592))) (IF (|has| $ (-6 -4626)) (-15 -3932 (|t#1| $ (-1246 (-592)) |t#1|)) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 (-1103)) $) 115)) (-3983 (((-1191) $) 120)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2306 (($ $ (-592) (-592)) 126) (($ $ (-592)) 125)) (-2982 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) 118)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-3651 (($ $ (-592)) 86)) (-2881 (($ (-592) |#1| $) 87)) (-3800 (($ $ $) 92)) (-3001 (($) 16 T CONST)) (-3792 (($ (-592) $) 89) (($ $) 88)) (-1378 (($ $) 93)) (-1586 (($ $ $) 53)) (-4593 (($ $) 108)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-3891 (((-141) (-141)) 83) (((-141)) 82)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2802 (((-141) $) 69)) (-1541 (($ $) 95)) (-2273 (((-141) $) 116)) (-3333 (((-3 (-592) "failed") $) 94)) (-4346 (((-592) $ (-592)) 124) (((-592) $) 123) (((-592) $) 99)) (-3558 (((-141) $) 30)) (-3990 (($ $ (-944)) 122)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-2027 (((-141) $) 106)) (-1535 (($ (-658 $) (-658 (-790)) (-592)) 90)) (-4526 (($ $ (-658 (-1103)) (-658 (-592))) 114) (($ $ (-1103) (-592)) 113) (($ |#1| (-592)) 107)) (-2731 (($ (-1 |#1| |#1|) $) 105)) (-4573 (($ $) 103)) (-4579 ((|#1| $) 102)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-2360 ((|#1| $ (-592)) 98)) (-4301 (($ $ (-592)) 85)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2807 (($ $ (-592)) 128)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2806 (((-1171 |#1|) $ |#1|) 129 (|has| |#1| (-15 ** (|#1| |#1| (-592)))))) (-2769 (((-790) $) 56)) (-3927 (($ $ $) 142 (|has| (-592) (-1131))) ((|#1| $ (-592)) 119)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-3644 (($ $) 141 (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $ (-790)) 139 (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $ (-1191)) 137 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191))) 136 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-1191) (-790)) 135 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) 134 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))))) (-4048 (($ (-1 $)) 91)) (-4525 (((-592) $) 104)) (-1700 (($ $) 117)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63) (($ |#1|) 112 (|has| |#1| (-194))) (($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) 97) (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) 96)) (-1937 ((|#1| $ (-592)) 109)) (-1963 ((|#1| $) 84)) (-1517 (((-3 $ "failed") $) 111 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-2838 ((|#1| $) 121)) (-2537 (((-141) $ $) 38)) (-2642 ((|#1| $ (-592)) 127 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-592)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $) 140 (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $ (-790)) 138 (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $ (-1191)) 133 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191))) 132 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-1191) (-790)) 131 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) 130 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62) (($ $ |#1|) 110 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64) (($ |#1| $) 101) (($ $ |#1|) 100))) 
+(((-665 |#1|) (-1311) (-388)) (T -665)) 
+((-4346 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-592)))) (-4346 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-592)))) (-2360 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-665 *2)) (-4 *2 (-388)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))) (-4 *3 (-388)) (-4 *1 (-665 *3)))) (-1683 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))))) (-1541 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388)))) (-3333 (*1 *2 *1) (|partial| -12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-592)))) (-1378 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388)))) (-3800 (*1 *1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388)))) (-4048 (*1 *1 *2) (-12 (-5 *2 (-1 *1)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) (-1535 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-658 *1)) (-5 *3 (-658 (-790))) (-5 *4 (-592)) (-4 *1 (-665 *5)) (-4 *5 (-388)))) (-3792 (*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) (-3792 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388)))) (-2881 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-592)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) (-3651 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) (-4301 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) (-1963 (*1 *2 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388)))) (-3891 (*1 *2 *2) (-12 (-5 *2 (-141)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) (-3891 (*1 *2) (-12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-141))))) 
+(-13 (-388) (-1257 |t#1| (-592)) (-10 -8 (-15 -4346 ((-592) $)) (-15 -2360 (|t#1| $ (-592))) (-15 -1683 ($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |t#1|))))) (-15 -1683 ((-1171 (-2 (|:| |k| (-592)) (|:| |c| |t#1|))) $)) (-15 -1541 ($ $)) (-15 -3333 ((-3 (-592) "failed") $)) (-15 -1378 ($ $)) (-15 -3800 ($ $ $)) (-15 -4048 ($ (-1 $))) (-15 -1535 ($ (-658 $) (-658 (-790)) (-592))) (-15 -3792 ($ (-592) $)) (-15 -3792 ($ $)) (-15 -2881 ($ (-592) |t#1| $)) (-15 -3651 ($ $ (-592))) (-15 -4301 ($ $ (-592))) (-15 -1963 (|t#1| $)) (-15 -3891 ((-141) (-141))) (-15 -3891 ((-141))))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-592)) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 |#1| |#1|) . T) ((-140 $ $) . T) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) . T) ((-247) |has| |#1| (-15 * (|#1| (-592) |#1|))) ((-260) . T) ((-303 $ $) |has| (-592) (-1131)) ((-307) . T) ((-323) . T) ((-388) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) . T) ((-743) . T) ((-922 (-1191)) -12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))) ((-1002 |#1| (-592) (-1103)) . T) ((-943) . T) ((-1081 (-433 (-592))) . T) ((-1081 |#1|) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T) ((-1257 |#1| (-592)) . T)) 
+((-4005 (((-3 |#2| "failed") |#3| |#2| (-1191) |#2| (-658 |#2|)) 159) (((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) "failed") |#3| |#2| (-1191)) 43))) 
+(((-666 |#1| |#2| |#3|) (-10 -7 (-15 -4005 ((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) "failed") |#3| |#2| (-1191))) (-15 -4005 ((-3 |#2| "failed") |#3| |#2| (-1191) |#2| (-658 |#2|)))) (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171)) (-13 (-29 |#1|) (-1211) (-987)) (-670 |#2|)) (T -666)) 
+((-4005 (*1 *2 *3 *2 *4 *2 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-666 *6 *2 *3)) (-4 *3 (-670 *2)))) (-4005 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1191)) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-4 *4 (-13 (-29 *6) (-1211) (-987))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2195 (-658 *4)))) (-5 *1 (-666 *6 *4 *3)) (-4 *3 (-670 *4))))) 
+(-10 -7 (-15 -4005 ((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) "failed") |#3| |#2| (-1191))) (-15 -4005 ((-3 |#2| "failed") |#3| |#2| (-1191) |#2| (-658 |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2628 (($ $) NIL (|has| |#1| (-388)))) (-3039 (($ $ $) NIL (|has| |#1| (-388)))) (-1735 (($ $ (-790)) NIL (|has| |#1| (-388)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-2484 (($ $ $) NIL (|has| |#1| (-388)))) (-3883 (($ $ $) NIL (|has| |#1| (-388)))) (-1956 (($ $ $) NIL (|has| |#1| (-388)))) (-1819 (($ $ $) NIL (|has| |#1| (-388)))) (-2423 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-1477 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-3172 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477)))) (-3558 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) NIL)) (-1844 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-2641 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-4206 (((-790) $) NIL)) (-1763 (($ $ $) NIL (|has| |#1| (-388)))) (-4308 (($ $ $) NIL (|has| |#1| (-388)))) (-3696 (($ $ $) NIL (|has| |#1| (-388)))) (-4262 (($ $ $) NIL (|has| |#1| (-388)))) (-1603 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-4156 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-4084 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582)))) (-3927 ((|#1| $ |#1|) NIL)) (-1343 (($ $ $) NIL (|has| |#1| (-388)))) (-4525 (((-790) $) NIL)) (-1554 ((|#1| $) NIL (|has| |#1| (-477)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) NIL)) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) NIL)) (-4010 (((-790)) NIL)) (-4572 ((|#1| $ |#1| |#1|) NIL)) (-2332 (($ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($) NIL)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-667 |#1|) (-670 |#1|) (-247)) (T -667)) 
+NIL 
+(-670 |#1|) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2628 (($ $) NIL (|has| |#1| (-388)))) (-3039 (($ $ $) NIL (|has| |#1| (-388)))) (-1735 (($ $ (-790)) NIL (|has| |#1| (-388)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-2484 (($ $ $) NIL (|has| |#1| (-388)))) (-3883 (($ $ $) NIL (|has| |#1| (-388)))) (-1956 (($ $ $) NIL (|has| |#1| (-388)))) (-1819 (($ $ $) NIL (|has| |#1| (-388)))) (-2423 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-1477 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-3172 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477)))) (-3558 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) NIL)) (-1844 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-2641 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-4206 (((-790) $) NIL)) (-1763 (($ $ $) NIL (|has| |#1| (-388)))) (-4308 (($ $ $) NIL (|has| |#1| (-388)))) (-3696 (($ $ $) NIL (|has| |#1| (-388)))) (-4262 (($ $ $) NIL (|has| |#1| (-388)))) (-1603 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-4156 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-4084 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582)))) (-3927 ((|#1| $ |#1|) NIL) ((|#2| $ |#2|) 13)) (-1343 (($ $ $) NIL (|has| |#1| (-388)))) (-4525 (((-790) $) NIL)) (-1554 ((|#1| $) NIL (|has| |#1| (-477)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) NIL)) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) NIL)) (-4010 (((-790)) NIL)) (-4572 ((|#1| $ |#1| |#1|) NIL)) (-2332 (($ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($) NIL)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-668 |#1| |#2|) (-13 (-670 |#1|) (-303 |#2| |#2|)) (-247) (-13 (-661 |#1|) (-10 -8 (-15 -3644 ($ $))))) (T -668)) 
+NIL 
+(-13 (-670 |#1|) (-303 |#2| |#2|)) 
+((-2628 (($ $) 26)) (-2332 (($ $) 24)) (-1940 (($) 12))) 
+(((-669 |#1| |#2|) (-10 -8 (-15 -2628 (|#1| |#1|)) (-15 -2332 (|#1| |#1|)) (-15 -1940 (|#1|))) (-670 |#2|) (-1075)) (T -669)) 
+NIL 
+(-10 -8 (-15 -2628 (|#1| |#1|)) (-15 -2332 (|#1| |#1|)) (-15 -1940 (|#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2628 (($ $) 79 (|has| |#1| (-388)))) (-3039 (($ $ $) 81 (|has| |#1| (-388)))) (-1735 (($ $ (-790)) 80 (|has| |#1| (-388)))) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2484 (($ $ $) 44 (|has| |#1| (-388)))) (-3883 (($ $ $) 45 (|has| |#1| (-388)))) (-1956 (($ $ $) 47 (|has| |#1| (-388)))) (-1819 (($ $ $) 42 (|has| |#1| (-388)))) (-2423 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 41 (|has| |#1| (-388)))) (-1477 (((-3 $ "failed") $ $) 43 (|has| |#1| (-388)))) (-3172 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 46 (|has| |#1| (-388)))) (-4368 (((-3 (-592) "failed") $) 73 (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 71 (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 68)) (-2400 (((-592) $) 74 (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) 72 (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 67)) (-4593 (($ $) 63)) (-3371 (((-3 $ "failed") $) 33)) (-3262 (($ $) 54 (|has| |#1| (-477)))) (-3558 (((-141) $) 30)) (-4526 (($ |#1| (-790)) 61)) (-1844 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 56 (|has| |#1| (-582)))) (-2641 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 57 (|has| |#1| (-582)))) (-4206 (((-790) $) 65)) (-1763 (($ $ $) 51 (|has| |#1| (-388)))) (-4308 (($ $ $) 52 (|has| |#1| (-388)))) (-3696 (($ $ $) 40 (|has| |#1| (-388)))) (-4262 (($ $ $) 49 (|has| |#1| (-388)))) (-1603 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 48 (|has| |#1| (-388)))) (-4156 (((-3 $ "failed") $ $) 50 (|has| |#1| (-388)))) (-4084 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 53 (|has| |#1| (-388)))) (-4579 ((|#1| $) 64)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ |#1|) 58 (|has| |#1| (-582)))) (-3927 ((|#1| $ |#1|) 84)) (-1343 (($ $ $) 78 (|has| |#1| (-388)))) (-4525 (((-790) $) 66)) (-1554 ((|#1| $) 55 (|has| |#1| (-477)))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 70 (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) 69)) (-1647 (((-658 |#1|) $) 60)) (-1937 ((|#1| $ (-790)) 62)) (-4010 (((-790)) 28)) (-4572 ((|#1| $ |#1| |#1|) 59)) (-2332 (($ $) 82)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($) 83)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 76) (($ |#1| $) 75))) 
+(((-670 |#1|) (-1311) (-1075)) (T -670)) 
+((-1940 (*1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)))) (-2332 (*1 *1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)))) (-3039 (*1 *1 *1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-1735 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-670 *3)) (-4 *3 (-1075)) (-4 *3 (-388)))) (-2628 (*1 *1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-1343 (*1 *1 *1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(-13 (-871 |t#1|) (-303 |t#1| |t#1|) (-10 -8 (-15 -1940 ($)) (-15 -2332 ($ $)) (IF (|has| |t#1| (-388)) (PROGN (-15 -3039 ($ $ $)) (-15 -1735 ($ $ (-790))) (-15 -2628 ($ $)) (-15 -1343 ($ $ $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-194)) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-303 |#1| |#1|) . T) ((-437 |#1|) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-734 |#1|) |has| |#1| (-194)) ((-743) . T) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1081 |#1|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-871 |#1|) . T)) 
+((-3826 (((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|))) 72 (|has| |#1| (-27)))) (-4500 (((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|))) 71 (|has| |#1| (-27))) (((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|)) 15))) 
+(((-671 |#1| |#2|) (-10 -7 (-15 -4500 ((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -4500 ((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|)))) (-15 -3826 ((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|))))) |noBranch|)) (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592)))) (-1255 |#1|)) (T -671)) 
+((-3826 (*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-667 (-433 *5)))) (-5 *1 (-671 *4 *5)) (-5 *3 (-667 (-433 *5))))) (-4500 (*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-667 (-433 *5)))) (-5 *1 (-671 *4 *5)) (-5 *3 (-667 (-433 *5))))) (-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-667 (-433 *6)))) (-5 *1 (-671 *5 *6)) (-5 *3 (-667 (-433 *6)))))) 
+(-10 -7 (-15 -4500 ((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -4500 ((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|)))) (-15 -3826 ((-658 (-667 (-433 |#2|))) (-667 (-433 |#2|))))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2628 (($ $) NIL (|has| |#1| (-388)))) (-3039 (($ $ $) 28 (|has| |#1| (-388)))) (-1735 (($ $ (-790)) 31 (|has| |#1| (-388)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-2484 (($ $ $) NIL (|has| |#1| (-388)))) (-3883 (($ $ $) NIL (|has| |#1| (-388)))) (-1956 (($ $ $) NIL (|has| |#1| (-388)))) (-1819 (($ $ $) NIL (|has| |#1| (-388)))) (-2423 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-1477 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-3172 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477)))) (-3558 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) NIL)) (-1844 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-2641 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-4206 (((-790) $) NIL)) (-1763 (($ $ $) NIL (|has| |#1| (-388)))) (-4308 (($ $ $) NIL (|has| |#1| (-388)))) (-3696 (($ $ $) NIL (|has| |#1| (-388)))) (-4262 (($ $ $) NIL (|has| |#1| (-388)))) (-1603 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-4156 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-4084 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582)))) (-3927 ((|#1| $ |#1|) 24)) (-1343 (($ $ $) 33 (|has| |#1| (-388)))) (-4525 (((-790) $) NIL)) (-1554 ((|#1| $) NIL (|has| |#1| (-477)))) (-1683 (((-877) $) 20) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) NIL)) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) NIL)) (-4010 (((-790)) NIL)) (-4572 ((|#1| $ |#1| |#1|) 23)) (-2332 (($ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 21 T CONST)) (-4257 (($) 8 T CONST)) (-1940 (($) NIL)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-672 |#1| |#2|) (-670 |#1|) (-1075) (-1 |#1| |#1|)) (T -672)) 
+NIL 
+(-670 |#1|) 
+((-3039 ((|#2| |#2| |#2| (-1 |#1| |#1|)) 61)) (-1735 ((|#2| |#2| (-790) (-1 |#1| |#1|)) 42)) (-1343 ((|#2| |#2| |#2| (-1 |#1| |#1|)) 63))) 
+(((-673 |#1| |#2|) (-10 -7 (-15 -3039 (|#2| |#2| |#2| (-1 |#1| |#1|))) (-15 -1735 (|#2| |#2| (-790) (-1 |#1| |#1|))) (-15 -1343 (|#2| |#2| |#2| (-1 |#1| |#1|)))) (-388) (-670 |#1|)) (T -673)) 
+((-1343 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-388)) (-5 *1 (-673 *4 *2)) (-4 *2 (-670 *4)))) (-1735 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-790)) (-5 *4 (-1 *5 *5)) (-4 *5 (-388)) (-5 *1 (-673 *5 *2)) (-4 *2 (-670 *5)))) (-3039 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-388)) (-5 *1 (-673 *4 *2)) (-4 *2 (-670 *4))))) 
+(-10 -7 (-15 -3039 (|#2| |#2| |#2| (-1 |#1| |#1|))) (-15 -1735 (|#2| |#2| (-790) (-1 |#1| |#1|))) (-15 -1343 (|#2| |#2| |#2| (-1 |#1| |#1|)))) 
+((-1623 (($ $ $) 9))) 
+(((-674 |#1|) (-10 -8 (-15 -1623 (|#1| |#1| |#1|))) (-675)) (T -674)) 
+NIL 
+(-10 -8 (-15 -1623 (|#1| |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-3163 (($ $) 10)) (-1623 (($ $ $) 8)) (-3255 (((-141) $ $) 6)) (-1616 (($ $ $) 9))) 
+(((-675) (-1311)) (T -675)) 
+((-3163 (*1 *1 *1) (-4 *1 (-675))) (-1616 (*1 *1 *1 *1) (-4 *1 (-675))) (-1623 (*1 *1 *1 *1) (-4 *1 (-675)))) 
+(-13 (-125) (-10 -8 (-15 -3163 ($ $)) (-15 -1616 ($ $ $)) (-15 -1623 ($ $ $)))) 
+(((-125) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-1448 ((|#1| $) 21)) (-1837 (($ $ $) NIL (|has| |#1| (-813)))) (-3319 (($ $ $) NIL (|has| |#1| (-813)))) (-2685 (((-1173) $) 46)) (-2951 (((-1137) $) NIL)) (-1456 ((|#3| $) 22)) (-1683 (((-877) $) 42)) (-3514 (($) 10 T CONST)) (-3286 (((-141) $ $) NIL (|has| |#1| (-813)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-813)))) (-3255 (((-141) $ $) 20)) (-3279 (((-141) $ $) NIL (|has| |#1| (-813)))) (-3266 (((-141) $ $) 24 (|has| |#1| (-813)))) (-3313 (($ $ |#3|) 34) (($ |#1| |#3|) 35)) (-3306 (($ $) 17) (($ $ $) NIL)) (-3300 (($ $ $) 27)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 30) (($ |#2| $) 32) (($ $ |#2|) NIL))) 
+(((-676 |#1| |#2| |#3|) (-13 (-734 |#2|) (-10 -8 (IF (|has| |#1| (-813)) (-6 (-813)) |noBranch|) (-15 -3313 ($ $ |#3|)) (-15 -3313 ($ |#1| |#3|)) (-15 -1448 (|#1| $)) (-15 -1456 (|#3| $)))) (-734 |#2|) (-194) (|SubsetCategory| (-743) |#2|)) (T -676)) 
+((-3313 (*1 *1 *1 *2) (-12 (-4 *4 (-194)) (-5 *1 (-676 *3 *4 *2)) (-4 *3 (-734 *4)) (-4 *2 (|SubsetCategory| (-743) *4)))) (-3313 (*1 *1 *2 *3) (-12 (-4 *4 (-194)) (-5 *1 (-676 *2 *4 *3)) (-4 *2 (-734 *4)) (-4 *3 (|SubsetCategory| (-743) *4)))) (-1448 (*1 *2 *1) (-12 (-4 *3 (-194)) (-4 *2 (-734 *3)) (-5 *1 (-676 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-743) *3)))) (-1456 (*1 *2 *1) (-12 (-4 *4 (-194)) (-4 *2 (|SubsetCategory| (-743) *4)) (-5 *1 (-676 *3 *4 *2)) (-4 *3 (-734 *4))))) 
+(-13 (-734 |#2|) (-10 -8 (IF (|has| |#1| (-813)) (-6 (-813)) |noBranch|) (-15 -3313 ($ $ |#3|)) (-15 -3313 ($ |#1| |#3|)) (-15 -1448 (|#1| $)) (-15 -1456 (|#3| $)))) 
+((-4247 (((-706 |#1|) (-706 |#1|)) 27)) (-1948 (((-706 |#1|) (-706 |#1|)) 26)) (-2652 (((-658 (-658 |#1|)) (-658 |#1|) (-658 (-658 |#1|))) 44)) (-2737 (((-658 (-658 |#1|)) (-658 (-658 |#1|))) 29)) (-3761 (((-658 |#1|) (-658 |#1|) (-658 |#1|) |#1|) 43)) (-2653 (((-658 (-658 |#1|)) (-658 (-658 |#1|)) (-658 (-658 |#1|))) 34))) 
+(((-677 |#1|) (-10 -7 (-15 -4247 ((-706 |#1|) (-706 |#1|))) (-15 -1948 ((-706 |#1|) (-706 |#1|))) (-15 -2737 ((-658 (-658 |#1|)) (-658 (-658 |#1|)))) (-15 -2653 ((-658 (-658 |#1|)) (-658 (-658 |#1|)) (-658 (-658 |#1|)))) (-15 -3761 ((-658 |#1|) (-658 |#1|) (-658 |#1|) |#1|)) (-15 -2652 ((-658 (-658 |#1|)) (-658 |#1|) (-658 (-658 |#1|))))) (-388)) (T -677)) 
+((-2652 (*1 *2 *3 *2) (-12 (-5 *2 (-658 (-658 *4))) (-5 *3 (-658 *4)) (-4 *4 (-388)) (-5 *1 (-677 *4)))) (-3761 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-5 *1 (-677 *3)))) (-2653 (*1 *2 *2 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-388)) (-5 *1 (-677 *3)))) (-2737 (*1 *2 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-388)) (-5 *1 (-677 *3)))) (-1948 (*1 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-388)) (-5 *1 (-677 *3)))) (-4247 (*1 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-388)) (-5 *1 (-677 *3))))) 
+(-10 -7 (-15 -4247 ((-706 |#1|) (-706 |#1|))) (-15 -1948 ((-706 |#1|) (-706 |#1|))) (-15 -2737 ((-658 (-658 |#1|)) (-658 (-658 |#1|)))) (-15 -2653 ((-658 (-658 |#1|)) (-658 (-658 |#1|)) (-658 (-658 |#1|)))) (-15 -3761 ((-658 |#1|) (-658 |#1|) (-658 |#1|) |#1|)) (-15 -2652 ((-658 (-658 |#1|)) (-658 |#1|) (-658 (-658 |#1|))))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 35)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-678) (-1311)) (T -678)) 
+((-1389 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |llcmres| *1) (|:| |coeff1| *1) (|:| |coeff2| *1))) (-4 *1 (-678))))) 
+(-13 (-307) (-10 -8 (-15 -1389 ((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-307) . T) ((-661 $) . T) ((-743) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-3891 (((-141)) 46) (((-141) (-141)) 47)) (-4382 ((|#7| |#5| |#3|) 44)) (-3405 ((|#5| |#7|) 29)) (-4253 (((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-658 (-592)))) |#3| |#5| |#3| (-592)) 99)) (-2506 (((-658 |#6|) |#5| |#3| (-592)) 35))) 
+(((-679 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -3891 ((-141) (-141))) (-15 -3891 ((-141))) (-15 -4382 (|#7| |#5| |#3|)) (-15 -2506 ((-658 |#6|) |#5| |#3| (-592))) (-15 -3405 (|#5| |#7|)) (-15 -4253 ((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-658 (-592)))) |#3| |#5| |#3| (-592)))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|) (-665 |#1|) (-947 |#1| |#6|)) (T -679)) 
+((-4253 (*1 *2 *3 *4 *3 *5) (-12 (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *9 (-665 *6)) (-5 *2 (-2 (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (-658 (-592))))) (-5 *1 (-679 *6 *7 *3 *8 *4 *9 *10)) (-5 *5 (-592)) (-4 *3 (-977 *6 *8 (-879 *7))) (-4 *4 (-999 *6)) (-4 *10 (-947 *6 *9)))) (-3405 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-665 *4)) (-4 *2 (-999 *4)) (-5 *1 (-679 *4 *5 *6 *7 *2 *8 *3)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *3 (-947 *4 *8)))) (-2506 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-592)) (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *9 (-665 *6)) (-5 *2 (-658 *9)) (-5 *1 (-679 *6 *7 *4 *8 *3 *9 *10)) (-4 *4 (-977 *6 *8 (-879 *7))) (-4 *3 (-999 *6)) (-4 *10 (-947 *6 *9)))) (-4382 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *2 (-947 *5 *8)) (-5 *1 (-679 *5 *6 *4 *7 *3 *8 *2)) (-4 *4 (-977 *5 *7 (-879 *6))) (-4 *3 (-999 *5)) (-4 *8 (-665 *5)))) (-3891 (*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-5 *2 (-141)) (-5 *1 (-679 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *9 (-947 *3 *8)))) (-3891 (*1 *2 *2) (-12 (-5 *2 (-141)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-5 *1 (-679 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *9 (-947 *3 *8))))) 
+(-10 -7 (-15 -3891 ((-141) (-141))) (-15 -3891 ((-141))) (-15 -4382 (|#7| |#5| |#3|)) (-15 -2506 ((-658 |#6|) |#5| |#3| (-592))) (-15 -3405 (|#5| |#7|)) (-15 -4253 ((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-658 (-592)))) |#3| |#5| |#3| (-592)))) 
+((-2740 (((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|)) 33))) 
+(((-680 |#1|) (-10 -7 (-15 -2740 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|)))) (-931)) (T -680)) 
+((-2740 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *4))) (-5 *3 (-1187 *4)) (-4 *4 (-931)) (-5 *1 (-680 *4))))) 
+(-10 -7 (-15 -2740 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2692 (((-658 |#1|) $) 82)) (-1394 (($ $ (-790)) 90)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3305 (((-1302 |#1| |#2|) (-1302 |#1| |#2|) $) 48)) (-4368 (((-3 (-688 |#1|) "failed") $) NIL)) (-2400 (((-688 |#1|) $) NIL)) (-4593 (($ $) 89)) (-4036 (((-790) $) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-1493 (($ (-688 |#1|) |#2|) 68)) (-4103 (($ $) 86)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-2141 (((-1302 |#1| |#2|) (-1302 |#1| |#2|) $) 47)) (-3725 (((-658 (-2 (|:| |k| (-688 |#1|)) (|:| |c| |#2|))) $) NIL)) (-2992 (((-2 (|:| |k| (-688 |#1|)) (|:| |c| |#2|)) $) NIL)) (-4573 (((-688 |#1|) $) NIL)) (-4579 ((|#2| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2806 (($ $ |#1| $) 30) (($ $ (-658 |#1|) (-658 $)) 32)) (-4525 (((-790) $) 88)) (-4466 (($ $ $) 20) (($ (-688 |#1|) (-688 |#1|)) 77) (($ (-688 |#1|) $) 75) (($ $ (-688 |#1|)) 76)) (-1683 (((-877) $) NIL) (($ |#1|) 74) (((-1293 |#1| |#2|) $) 58) (((-1302 |#1| |#2|) $) 41) (($ (-688 |#1|)) 25)) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-688 |#1|)) NIL)) (-1487 ((|#2| (-1302 |#1| |#2|) $) 43)) (-3514 (($) 23 T CONST)) (-1651 (((-3 $ "failed") (-1293 |#1| |#2|)) 60)) (-2072 (($ (-688 |#1|)) 14)) (-3255 (((-141) $ $) 44)) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $) 66) (($ $ $) NIL)) (-3300 (($ $ $) 29)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ |#2| $) 28) (($ $ |#2|) NIL) (($ |#2| (-688 |#1|)) NIL))) 
+(((-681 |#1| |#2|) (-13 (-400 |#1| |#2|) (-408 |#2| (-688 |#1|)) (-10 -8 (-15 -1651 ((-3 $ "failed") (-1293 |#1| |#2|))) (-15 -4466 ($ (-688 |#1|) (-688 |#1|))) (-15 -4466 ($ (-688 |#1|) $)) (-15 -4466 ($ $ (-688 |#1|))))) (-869) (-194)) (T -681)) 
+((-1651 (*1 *1 *2) (|partial| -12 (-5 *2 (-1293 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *1 (-681 *3 *4)))) (-4466 (*1 *1 *2 *2) (-12 (-5 *2 (-688 *3)) (-4 *3 (-869)) (-5 *1 (-681 *3 *4)) (-4 *4 (-194)))) (-4466 (*1 *1 *2 *1) (-12 (-5 *2 (-688 *3)) (-4 *3 (-869)) (-5 *1 (-681 *3 *4)) (-4 *4 (-194)))) (-4466 (*1 *1 *1 *2) (-12 (-5 *2 (-688 *3)) (-4 *3 (-869)) (-5 *1 (-681 *3 *4)) (-4 *4 (-194))))) 
+(-13 (-400 |#1| |#2|) (-408 |#2| (-688 |#1|)) (-10 -8 (-15 -1651 ((-3 $ "failed") (-1293 |#1| |#2|))) (-15 -4466 ($ (-688 |#1|) (-688 |#1|))) (-15 -4466 ($ (-688 |#1|) $)) (-15 -4466 ($ $ (-688 |#1|))))) 
+((-4076 (((-141) $) NIL) (((-141) (-1 (-141) |#2| |#2|) $) 49)) (-2831 (($ $) NIL) (($ (-1 (-141) |#2| |#2|) $) 11)) (-4125 (($ (-1 (-141) |#2|) $) 27)) (-2512 (($ $) 55)) (-1461 (($ $) 62)) (-4065 (($ |#2| $) NIL) (($ (-1 (-141) |#2|) $) 36)) (-3657 ((|#2| (-1 |#2| |#2| |#2|) $) 21) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 50) ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 52)) (-1721 (((-592) |#2| $ (-592)) 60) (((-592) |#2| $) NIL) (((-592) (-1 (-141) |#2|) $) 46)) (-3242 (($ (-790) |#2|) 53)) (-2713 (($ $ $) NIL) (($ (-1 (-141) |#2| |#2|) $ $) 29)) (-4491 (($ $ $) NIL) (($ (-1 (-141) |#2| |#2|) $ $) 24)) (-2731 (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) 54)) (-1333 (($ |#2|) 14)) (-2113 (($ $ $ (-592)) 35) (($ |#2| $ (-592)) 33)) (-4050 (((-3 |#2| "failed") (-1 (-141) |#2|) $) 45)) (-4113 (($ $ (-1246 (-592))) 43) (($ $ (-592)) 37)) (-2385 (($ $ $ (-592)) 59)) (-4599 (($ $) 57)) (-3266 (((-141) $ $) 64))) 
+(((-682 |#1| |#2|) (-10 -8 (-15 -1333 (|#1| |#2|)) (-15 -4113 (|#1| |#1| (-592))) (-15 -4113 (|#1| |#1| (-1246 (-592)))) (-15 -4065 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -2113 (|#1| |#2| |#1| (-592))) (-15 -2113 (|#1| |#1| |#1| (-592))) (-15 -2713 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|)) (-15 -4125 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4065 (|#1| |#2| |#1|)) (-15 -1461 (|#1| |#1|)) (-15 -2713 (|#1| |#1| |#1|)) (-15 -4491 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|)) (-15 -4076 ((-141) (-1 (-141) |#2| |#2|) |#1|)) (-15 -1721 ((-592) (-1 (-141) |#2|) |#1|)) (-15 -1721 ((-592) |#2| |#1|)) (-15 -1721 ((-592) |#2| |#1| (-592))) (-15 -4491 (|#1| |#1| |#1|)) (-15 -4076 ((-141) |#1|)) (-15 -2385 (|#1| |#1| |#1| (-592))) (-15 -2512 (|#1| |#1|)) (-15 -2831 (|#1| (-1 (-141) |#2| |#2|) |#1|)) (-15 -2831 (|#1| |#1|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -4050 ((-3 |#2| "failed") (-1 (-141) |#2|) |#1|)) (-15 -3242 (|#1| (-790) |#2|)) (-15 -2731 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4599 (|#1| |#1|))) (-683 |#2|) (-1225)) (T -682)) 
+NIL 
+(-10 -8 (-15 -1333 (|#1| |#2|)) (-15 -4113 (|#1| |#1| (-592))) (-15 -4113 (|#1| |#1| (-1246 (-592)))) (-15 -4065 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -2113 (|#1| |#2| |#1| (-592))) (-15 -2113 (|#1| |#1| |#1| (-592))) (-15 -2713 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|)) (-15 -4125 (|#1| (-1 (-141) |#2|) |#1|)) (-15 -4065 (|#1| |#2| |#1|)) (-15 -1461 (|#1| |#1|)) (-15 -2713 (|#1| |#1| |#1|)) (-15 -4491 (|#1| (-1 (-141) |#2| |#2|) |#1| |#1|)) (-15 -4076 ((-141) (-1 (-141) |#2| |#2|) |#1|)) (-15 -1721 ((-592) (-1 (-141) |#2|) |#1|)) (-15 -1721 ((-592) |#2| |#1|)) (-15 -1721 ((-592) |#2| |#1| (-592))) (-15 -4491 (|#1| |#1| |#1|)) (-15 -4076 ((-141) |#1|)) (-15 -2385 (|#1| |#1| |#1| (-592))) (-15 -2512 (|#1| |#1|)) (-15 -2831 (|#1| (-1 (-141) |#2| |#2|) |#1|)) (-15 -2831 (|#1| |#1|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3657 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -4050 ((-3 |#2| "failed") (-1 (-141) |#2|) |#1|)) (-15 -3242 (|#1| (-790) |#2|)) (-15 -2731 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4599 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-1915 ((|#1| $) 62)) (-3188 (($ $) 64)) (-3898 (((-1285) $ (-592) (-592)) 94 (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) 49 (|has| $ (-6 -4626)))) (-4076 (((-141) $) 136 (|has| |#1| (-869))) (((-141) (-1 (-141) |#1| |#1|) $) 130)) (-2831 (($ $) 140 (-12 (|has| |#1| (-869)) (|has| $ (-6 -4626)))) (($ (-1 (-141) |#1| |#1|) $) 139 (|has| $ (-6 -4626)))) (-3960 (($ $) 135 (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $) 129)) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-3153 (($ $ $) 53 (|has| $ (-6 -4626)))) (-4496 ((|#1| $ |#1|) 51 (|has| $ (-6 -4626)))) (-2101 ((|#1| $ |#1|) 55 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4626))) (($ $ "rest" $) 52 (|has| $ (-6 -4626))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 114 (|has| $ (-6 -4626))) ((|#1| $ (-592) |#1|) 83 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-4125 (($ (-1 (-141) |#1|) $) 123)) (-3113 (($ (-1 (-141) |#1|) $) 99 (|has| $ (-6 -4625)))) (-1765 ((|#1| $) 63)) (-3001 (($) 7 T CONST)) (-2512 (($ $) 138 (|has| $ (-6 -4626)))) (-1373 (($ $) 128)) (-1366 (($ $) 70) (($ $ (-790)) 68)) (-1461 (($ $) 125 (|has| |#1| (-1119)))) (-1360 (($ $) 96 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ |#1| $) 124 (|has| |#1| (-1119))) (($ (-1 (-141) |#1|) $) 119)) (-4459 (($ (-1 (-141) |#1|) $) 100 (|has| $ (-6 -4625))) (($ |#1| $) 97 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1426 ((|#1| $ (-592) |#1|) 82 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 84)) (-3868 (((-141) $) 80)) (-1721 (((-592) |#1| $ (-592)) 133 (|has| |#1| (-1119))) (((-592) |#1| $) 132 (|has| |#1| (-1119))) (((-592) (-1 (-141) |#1|) $) 131)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-3242 (($ (-790) |#1|) 105)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 92 (|has| (-592) (-869)))) (-1837 (($ $ $) 141 (|has| |#1| (-869)))) (-2713 (($ $ $) 126 (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) 122)) (-4491 (($ $ $) 134 (|has| |#1| (-869))) (($ (-1 (-141) |#1| |#1|) $ $) 127)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 91 (|has| (-592) (-869)))) (-3319 (($ $ $) 142 (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-1333 (($ |#1|) 116)) (-2554 (((-141) $ (-790)) 10)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4255 ((|#1| $) 67) (($ $ (-790)) 65)) (-2113 (($ $ $ (-592)) 121) (($ |#1| $ (-592)) 120)) (-3666 (($ $ $ (-592)) 113) (($ |#1| $ (-592)) 112)) (-3708 (((-658 (-592)) $) 89)) (-3780 (((-141) (-592) $) 88)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 73) (($ $ (-790)) 71)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 103)) (-1892 (($ $ |#1|) 93 (|has| $ (-6 -4626)))) (-2955 (((-141) $) 81)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 90 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 87)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1246 (-592))) 109) ((|#1| $ (-592)) 86) ((|#1| $ (-592) |#1|) 85)) (-2920 (((-592) $ $) 41)) (-4113 (($ $ (-1246 (-592))) 118) (($ $ (-592)) 117)) (-3208 (($ $ (-1246 (-592))) 111) (($ $ (-592)) 110)) (-3228 (((-141) $) 43)) (-2399 (($ $) 59)) (-1337 (($ $) 56 (|has| $ (-6 -4626)))) (-3318 (((-790) $) 60)) (-3184 (($ $) 61)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-2385 (($ $ $ (-592)) 137 (|has| $ (-6 -4626)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 95 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 104)) (-3619 (($ $ $) 58) (($ $ |#1|) 57)) (-2266 (($ $ $) 75) (($ |#1| $) 74) (($ (-658 $)) 107) (($ $ |#1|) 106)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) 144 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 145 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-3279 (((-141) $ $) 143 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 146 (|has| |#1| (-869)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-683 |#1|) (-1311) (-1225)) (T -683)) 
+((-1333 (*1 *1 *2) (-12 (-4 *1 (-683 *2)) (-4 *2 (-1225))))) 
+(-13 (-1163 |t#1|) (-399 |t#1|) (-299 |t#1|) (-10 -8 (-15 -1333 ($ |t#1|)))) 
+(((-39) . T) ((-125) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-632 (-877)) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-299 |#1|) . T) ((-399 |#1|) . T) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-664 |#1|) . T) ((-869) |has| |#1| (-869)) ((-1038 |#1|) . T) ((-1119) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-1163 |#1|) . T) ((-1225) . T) ((-1267 |#1|) . T)) 
+((-4005 (((-658 (-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|))))) (-658 (-658 |#1|)) (-658 (-1280 |#1|))) 21) (((-658 (-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|))))) (-706 |#1|) (-658 (-1280 |#1|))) 20) (((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-658 (-658 |#1|)) (-1280 |#1|)) 16) (((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-706 |#1|) (-1280 |#1|)) 13)) (-4175 (((-790) (-706 |#1|) (-1280 |#1|)) 29)) (-3993 (((-3 (-1280 |#1|) "failed") (-706 |#1|) (-1280 |#1|)) 23)) (-3817 (((-141) (-706 |#1|) (-1280 |#1|)) 26))) 
+(((-684 |#1|) (-10 -7 (-15 -4005 ((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-706 |#1|) (-1280 |#1|))) (-15 -4005 ((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-658 (-658 |#1|)) (-1280 |#1|))) (-15 -4005 ((-658 (-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|))))) (-706 |#1|) (-658 (-1280 |#1|)))) (-15 -4005 ((-658 (-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|))))) (-658 (-658 |#1|)) (-658 (-1280 |#1|)))) (-15 -3993 ((-3 (-1280 |#1|) "failed") (-706 |#1|) (-1280 |#1|))) (-15 -3817 ((-141) (-706 |#1|) (-1280 |#1|))) (-15 -4175 ((-790) (-706 |#1|) (-1280 |#1|)))) (-388)) (T -684)) 
+((-4175 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *5)) (-5 *4 (-1280 *5)) (-4 *5 (-388)) (-5 *2 (-790)) (-5 *1 (-684 *5)))) (-3817 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *5)) (-5 *4 (-1280 *5)) (-4 *5 (-388)) (-5 *2 (-141)) (-5 *1 (-684 *5)))) (-3993 (*1 *2 *3 *2) (|partial| -12 (-5 *2 (-1280 *4)) (-5 *3 (-706 *4)) (-4 *4 (-388)) (-5 *1 (-684 *4)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 *5))) (-4 *5 (-388)) (-5 *2 (-658 (-2 (|:| |particular| (-3 (-1280 *5) "failed")) (|:| -2195 (-658 (-1280 *5)))))) (-5 *1 (-684 *5)) (-5 *4 (-658 (-1280 *5))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *5)) (-4 *5 (-388)) (-5 *2 (-658 (-2 (|:| |particular| (-3 (-1280 *5) "failed")) (|:| -2195 (-658 (-1280 *5)))))) (-5 *1 (-684 *5)) (-5 *4 (-658 (-1280 *5))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 *5))) (-4 *5 (-388)) (-5 *2 (-2 (|:| |particular| (-3 (-1280 *5) "failed")) (|:| -2195 (-658 (-1280 *5))))) (-5 *1 (-684 *5)) (-5 *4 (-1280 *5)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |particular| (-3 (-1280 *5) "failed")) (|:| -2195 (-658 (-1280 *5))))) (-5 *1 (-684 *5)) (-5 *4 (-1280 *5))))) 
+(-10 -7 (-15 -4005 ((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-706 |#1|) (-1280 |#1|))) (-15 -4005 ((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-658 (-658 |#1|)) (-1280 |#1|))) (-15 -4005 ((-658 (-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|))))) (-706 |#1|) (-658 (-1280 |#1|)))) (-15 -4005 ((-658 (-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|))))) (-658 (-658 |#1|)) (-658 (-1280 |#1|)))) (-15 -3993 ((-3 (-1280 |#1|) "failed") (-706 |#1|) (-1280 |#1|))) (-15 -3817 ((-141) (-706 |#1|) (-1280 |#1|))) (-15 -4175 ((-790) (-706 |#1|) (-1280 |#1|)))) 
+((-4005 (((-658 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|)))) |#4| (-658 |#3|)) 47) (((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|))) |#4| |#3|) 45)) (-4175 (((-790) |#4| |#3|) 17)) (-3993 (((-3 |#3| "failed") |#4| |#3|) 20)) (-3817 (((-141) |#4| |#3|) 13))) 
+(((-685 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4005 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|))) |#4| |#3|)) (-15 -4005 ((-658 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|)))) |#4| (-658 |#3|))) (-15 -3993 ((-3 |#3| "failed") |#4| |#3|)) (-15 -3817 ((-141) |#4| |#3|)) (-15 -4175 ((-790) |#4| |#3|))) (-388) (-13 (-399 |#1|) (-10 -7 (-6 -4626))) (-13 (-399 |#1|) (-10 -7 (-6 -4626))) (-704 |#1| |#2| |#3|)) (T -685)) 
+((-4175 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-5 *2 (-790)) (-5 *1 (-685 *5 *6 *4 *3)) (-4 *3 (-704 *5 *6 *4)))) (-3817 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-5 *2 (-141)) (-5 *1 (-685 *5 *6 *4 *3)) (-4 *3 (-704 *5 *6 *4)))) (-3993 (*1 *2 *3 *2) (|partial| -12 (-4 *4 (-388)) (-4 *5 (-13 (-399 *4) (-10 -7 (-6 -4626)))) (-4 *2 (-13 (-399 *4) (-10 -7 (-6 -4626)))) (-5 *1 (-685 *4 *5 *2 *3)) (-4 *3 (-704 *4 *5 *2)))) (-4005 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-4 *7 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-5 *2 (-658 (-2 (|:| |particular| (-3 *7 "failed")) (|:| -2195 (-658 *7))))) (-5 *1 (-685 *5 *6 *7 *3)) (-5 *4 (-658 *7)) (-4 *3 (-704 *5 *6 *7)))) (-4005 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-685 *5 *6 *4 *3)) (-4 *3 (-704 *5 *6 *4))))) 
+(-10 -7 (-15 -4005 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|))) |#4| |#3|)) (-15 -4005 ((-658 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|)))) |#4| (-658 |#3|))) (-15 -3993 ((-3 |#3| "failed") |#4| |#3|)) (-15 -3817 ((-141) |#4| |#3|)) (-15 -4175 ((-790) |#4| |#3|))) 
+((-3112 (((-2 (|:| |particular| (-3 (-1280 (-433 |#4|)) "failed")) (|:| -2195 (-658 (-1280 (-433 |#4|))))) (-658 |#4|) (-658 |#3|)) 44))) 
+(((-686 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3112 ((-2 (|:| |particular| (-3 (-1280 (-433 |#4|)) "failed")) (|:| -2195 (-658 (-1280 (-433 |#4|))))) (-658 |#4|) (-658 |#3|)))) (-582) (-815) (-869) (-977 |#1| |#2| |#3|)) (T -686)) 
+((-3112 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *7)) (-4 *7 (-869)) (-4 *8 (-977 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-5 *2 (-2 (|:| |particular| (-3 (-1280 (-433 *8)) "failed")) (|:| -2195 (-658 (-1280 (-433 *8)))))) (-5 *1 (-686 *5 *6 *7 *8))))) 
+(-10 -7 (-15 -3112 ((-2 (|:| |particular| (-3 (-1280 (-433 |#4|)) "failed")) (|:| -2195 (-658 (-1280 (-433 |#4|))))) (-658 |#4|) (-658 |#3|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4509 (((-3 $ "failed")) NIL (|has| |#2| (-582)))) (-4529 ((|#2| $) NIL)) (-4034 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4061 (((-1280 (-706 |#2|))) NIL) (((-1280 (-706 |#2|)) (-1280 $)) NIL)) (-3120 (((-141) $) NIL)) (-3360 (((-1280 $)) 37)) (-2126 (((-141) $ (-790)) NIL)) (-3223 (($ |#2|) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) NIL (|has| |#2| (-323)))) (-2747 (((-254 |#1| |#2|) $ (-592)) NIL)) (-2604 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL (|has| |#2| (-582)))) (-2661 (((-3 $ "failed")) NIL (|has| |#2| (-582)))) (-1951 (((-706 |#2|)) NIL) (((-706 |#2|) (-1280 $)) NIL)) (-4282 ((|#2| $) NIL)) (-2302 (((-706 |#2|) $) NIL) (((-706 |#2|) $ (-1280 $)) NIL)) (-2503 (((-3 $ "failed") $) NIL (|has| |#2| (-582)))) (-2120 (((-1187 (-980 |#2|))) NIL (|has| |#2| (-388)))) (-2111 (($ $ (-944)) NIL)) (-1431 ((|#2| $) NIL)) (-3916 (((-1187 |#2|) $) NIL (|has| |#2| (-582)))) (-1874 ((|#2|) NIL) ((|#2| (-1280 $)) NIL)) (-1582 (((-1187 |#2|) $) NIL)) (-4194 (((-141)) NIL)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 |#2| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) ((|#2| $) NIL)) (-1626 (($ (-1280 |#2|)) NIL) (($ (-1280 |#2|) (-1280 $)) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4175 (((-790) $) NIL (|has| |#2| (-582))) (((-944)) 38)) (-3959 ((|#2| $ (-592) (-592)) NIL)) (-2169 (((-141)) NIL)) (-1833 (($ $ (-944)) NIL)) (-4004 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3558 (((-141) $) NIL)) (-3178 (((-790) $) NIL (|has| |#2| (-582)))) (-3555 (((-658 (-254 |#1| |#2|)) $) NIL (|has| |#2| (-582)))) (-4292 (((-790) $) NIL)) (-3700 (((-141)) NIL)) (-4298 (((-790) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-3781 ((|#2| $) NIL (|has| |#2| (-6 (-4627 "*"))))) (-4577 (((-592) $) NIL)) (-4280 (((-592) $) NIL)) (-4467 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1898 (((-592) $) NIL)) (-3005 (((-592) $) NIL)) (-4186 (($ (-658 (-658 |#2|))) NIL)) (-3987 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 |#2| |#2|) $) NIL)) (-4601 (((-658 (-658 |#2|)) $) NIL)) (-2973 (((-141)) NIL)) (-2467 (((-141)) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-1563 (((-3 (-2 (|:| |particular| $) (|:| -2195 (-658 $))) "failed")) NIL (|has| |#2| (-582)))) (-3994 (((-3 $ "failed")) NIL (|has| |#2| (-582)))) (-2794 (((-706 |#2|)) NIL) (((-706 |#2|) (-1280 $)) NIL)) (-1869 ((|#2| $) NIL)) (-1802 (((-706 |#2|) $) NIL) (((-706 |#2|) $ (-1280 $)) NIL)) (-4158 (((-3 $ "failed") $) NIL (|has| |#2| (-582)))) (-3004 (((-1187 (-980 |#2|))) NIL (|has| |#2| (-388)))) (-2682 (($ $ (-944)) NIL)) (-3061 ((|#2| $) NIL)) (-2013 (((-1187 |#2|) $) NIL (|has| |#2| (-582)))) (-3030 ((|#2|) NIL) ((|#2| (-1280 $)) NIL)) (-2397 (((-1187 |#2|) $) NIL)) (-3847 (((-141)) NIL)) (-2685 (((-1173) $) NIL)) (-4106 (((-141)) NIL)) (-2339 (((-141)) NIL)) (-2297 (((-141)) NIL)) (-3183 (((-3 $ "failed") $) NIL (|has| |#2| (-388)))) (-2951 (((-1137) $) NIL)) (-2716 (((-141)) NIL)) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582)))) (-3002 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ (-592) (-592) |#2|) NIL) ((|#2| $ (-592) (-592)) 22) ((|#2| $ (-592)) NIL)) (-3644 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-790)) NIL (|has| |#2| (-247))) (($ $) NIL (|has| |#2| (-247)))) (-2236 ((|#2| $) NIL)) (-2933 (($ (-658 |#2|)) NIL)) (-2940 (((-141) $) NIL)) (-1332 (((-254 |#1| |#2|) $) NIL)) (-1625 ((|#2| $) NIL (|has| |#2| (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4599 (($ $) NIL)) (-2231 (((-706 |#2|) (-1280 $)) NIL) (((-1280 |#2|) $) NIL) (((-706 |#2|) (-1280 $) (-1280 $)) NIL) (((-1280 |#2|) $ (-1280 $)) 25)) (-1778 (($ (-1280 |#2|)) NIL) (((-1280 |#2|) $) NIL)) (-1473 (((-658 (-980 |#2|))) NIL) (((-658 (-980 |#2|)) (-1280 $)) NIL)) (-2131 (($ $ $) NIL)) (-3545 (((-141)) NIL)) (-2000 (((-254 |#1| |#2|) $ (-592)) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#2| (-1065 (-433 (-592))))) (($ |#2|) NIL) (((-706 |#2|) $) NIL)) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) 36)) (-3664 (((-658 (-1280 |#2|))) NIL (|has| |#2| (-582)))) (-3667 (($ $ $ $) NIL)) (-1516 (((-141)) NIL)) (-4572 (($ (-706 |#2|) $) NIL)) (-3369 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-2844 (($ $ $) NIL)) (-3135 (((-141)) NIL)) (-2723 (((-141)) NIL)) (-2359 (((-141)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-790)) NIL (|has| |#2| (-247))) (($ $) NIL (|has| |#2| (-247)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#2| (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (((-254 |#1| |#2|) $ (-254 |#1| |#2|)) NIL) (((-254 |#1| |#2|) (-254 |#1| |#2|) $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-687 |#1| |#2|) (-13 (-1140 |#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) (-632 (-706 |#2|)) (-443 |#2|)) (-944) (-194)) (T -687)) 
+NIL 
+(-13 (-1140 |#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) (-632 (-706 |#2|)) (-443 |#2|)) 
+((-1641 (((-141) $ $) NIL)) (-2692 (((-658 |#1|) $) NIL)) (-1954 (($ $) 50)) (-3461 (((-141) $) NIL)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-4505 (((-3 $ "failed") (-841 |#1|)) 22)) (-3062 (((-141) (-841 |#1|)) 14)) (-2876 (($ (-841 |#1|)) 23)) (-3547 (((-141) $ $) 28)) (-4233 (((-944) $) 35)) (-1961 (($ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4500 (((-658 $) (-841 |#1|)) 16)) (-1683 (((-877) $) 41) (($ |#1|) 32) (((-841 |#1|) $) 37) (((-693 |#1|) $) 42)) (-3701 (((-64 (-658 $)) (-658 |#1|) (-944)) 55)) (-3733 (((-658 $) (-658 |#1|) (-944)) 57)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 51)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 36))) 
+(((-688 |#1|) (-13 (-869) (-1065 |#1|) (-10 -8 (-15 -3461 ((-141) $)) (-15 -1961 ($ $)) (-15 -1954 ($ $)) (-15 -4233 ((-944) $)) (-15 -3547 ((-141) $ $)) (-15 -1683 ((-841 |#1|) $)) (-15 -1683 ((-693 |#1|) $)) (-15 -4500 ((-658 $) (-841 |#1|))) (-15 -3062 ((-141) (-841 |#1|))) (-15 -2876 ($ (-841 |#1|))) (-15 -4505 ((-3 $ "failed") (-841 |#1|))) (-15 -2692 ((-658 |#1|) $)) (-15 -3701 ((-64 (-658 $)) (-658 |#1|) (-944))) (-15 -3733 ((-658 $) (-658 |#1|) (-944))))) (-869)) (T -688)) 
+((-3461 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) (-1961 (*1 *1 *1) (-12 (-5 *1 (-688 *2)) (-4 *2 (-869)))) (-1954 (*1 *1 *1) (-12 (-5 *1 (-688 *2)) (-4 *2 (-869)))) (-4233 (*1 *2 *1) (-12 (-5 *2 (-944)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) (-3547 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-841 *3)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-693 *3)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) (-4500 (*1 *2 *3) (-12 (-5 *3 (-841 *4)) (-4 *4 (-869)) (-5 *2 (-658 (-688 *4))) (-5 *1 (-688 *4)))) (-3062 (*1 *2 *3) (-12 (-5 *3 (-841 *4)) (-4 *4 (-869)) (-5 *2 (-141)) (-5 *1 (-688 *4)))) (-2876 (*1 *1 *2) (-12 (-5 *2 (-841 *3)) (-4 *3 (-869)) (-5 *1 (-688 *3)))) (-4505 (*1 *1 *2) (|partial| -12 (-5 *2 (-841 *3)) (-4 *3 (-869)) (-5 *1 (-688 *3)))) (-2692 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) (-3701 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-944)) (-4 *5 (-869)) (-5 *2 (-64 (-658 (-688 *5)))) (-5 *1 (-688 *5)))) (-3733 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-944)) (-4 *5 (-869)) (-5 *2 (-658 (-688 *5))) (-5 *1 (-688 *5))))) 
+(-13 (-869) (-1065 |#1|) (-10 -8 (-15 -3461 ((-141) $)) (-15 -1961 ($ $)) (-15 -1954 ($ $)) (-15 -4233 ((-944) $)) (-15 -3547 ((-141) $ $)) (-15 -1683 ((-841 |#1|) $)) (-15 -1683 ((-693 |#1|) $)) (-15 -4500 ((-658 $) (-841 |#1|))) (-15 -3062 ((-141) (-841 |#1|))) (-15 -2876 ($ (-841 |#1|))) (-15 -4505 ((-3 $ "failed") (-841 |#1|))) (-15 -2692 ((-658 |#1|) $)) (-15 -3701 ((-64 (-658 $)) (-658 |#1|) (-944))) (-15 -3733 ((-658 $) (-658 |#1|) (-944))))) 
+((-2324 ((|#2| $) 76)) (-3188 (($ $) 96)) (-2126 (((-141) $ (-790)) 26)) (-1366 (($ $) 85) (($ $ (-790)) 88)) (-3868 (((-141) $) 97)) (-2774 (((-658 $) $) 72)) (-3055 (((-141) $ $) 71)) (-4345 (((-141) $ (-790)) 24)) (-2261 (((-592) $) 46)) (-1813 (((-592) $) 45)) (-2554 (((-141) $ (-790)) 22)) (-3683 (((-141) $) 74)) (-4255 ((|#2| $) 89) (($ $ (-790)) 92)) (-3666 (($ $ $ (-592)) 62) (($ |#2| $ (-592)) 61)) (-3708 (((-658 (-592)) $) 44)) (-3780 (((-141) (-592) $) 42)) (-1918 ((|#2| $) NIL) (($ $ (-790)) 84)) (-2807 (($ $ (-592)) 99)) (-2955 (((-141) $) 98)) (-3002 (((-141) (-1 (-141) |#2|) $) 32)) (-4210 (((-658 |#2|) $) 33)) (-3927 ((|#2| $ "value") NIL) ((|#2| $ "first") 83) (($ $ "rest") 87) ((|#2| $ "last") 95) (($ $ (-1246 (-592))) 58) ((|#2| $ (-592)) 40) ((|#2| $ (-592) |#2|) 41)) (-2920 (((-592) $ $) 70)) (-3208 (($ $ (-1246 (-592))) 57) (($ $ (-592)) 51)) (-3228 (((-141) $) 66)) (-2399 (($ $) 81)) (-3318 (((-790) $) 80)) (-3184 (($ $) 79)) (-4466 (($ (-658 |#2|)) 37)) (-1700 (($ $) 100)) (-2493 (((-658 $) $) 69)) (-2936 (((-141) $ $) 68)) (-3369 (((-141) (-1 (-141) |#2|) $) 31)) (-3255 (((-141) $ $) 18)) (-1699 (((-790) $) 29))) 
+(((-689 |#1| |#2|) (-10 -8 (-15 -1700 (|#1| |#1|)) (-15 -2807 (|#1| |#1| (-592))) (-15 -3868 ((-141) |#1|)) (-15 -2955 ((-141) |#1|)) (-15 -3927 (|#2| |#1| (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592))) (-15 -4210 ((-658 |#2|) |#1|)) (-15 -3780 ((-141) (-592) |#1|)) (-15 -3708 ((-658 (-592)) |#1|)) (-15 -1813 ((-592) |#1|)) (-15 -2261 ((-592) |#1|)) (-15 -4466 (|#1| (-658 |#2|))) (-15 -3927 (|#1| |#1| (-1246 (-592)))) (-15 -3208 (|#1| |#1| (-592))) (-15 -3208 (|#1| |#1| (-1246 (-592)))) (-15 -3666 (|#1| |#2| |#1| (-592))) (-15 -3666 (|#1| |#1| |#1| (-592))) (-15 -2399 (|#1| |#1|)) (-15 -3318 ((-790) |#1|)) (-15 -3184 (|#1| |#1|)) (-15 -3188 (|#1| |#1|)) (-15 -4255 (|#1| |#1| (-790))) (-15 -3927 (|#2| |#1| "last")) (-15 -4255 (|#2| |#1|)) (-15 -1366 (|#1| |#1| (-790))) (-15 -3927 (|#1| |#1| "rest")) (-15 -1366 (|#1| |#1|)) (-15 -1918 (|#1| |#1| (-790))) (-15 -3927 (|#2| |#1| "first")) (-15 -1918 (|#2| |#1|)) (-15 -3055 ((-141) |#1| |#1|)) (-15 -2936 ((-141) |#1| |#1|)) (-15 -2920 ((-592) |#1| |#1|)) (-15 -3228 ((-141) |#1|)) (-15 -3927 (|#2| |#1| "value")) (-15 -2324 (|#2| |#1|)) (-15 -3683 ((-141) |#1|)) (-15 -2774 ((-658 |#1|) |#1|)) (-15 -2493 ((-658 |#1|) |#1|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -1699 ((-790) |#1|)) (-15 -2126 ((-141) |#1| (-790))) (-15 -4345 ((-141) |#1| (-790))) (-15 -2554 ((-141) |#1| (-790)))) (-690 |#2|) (-1225)) (T -689)) 
+NIL 
+(-10 -8 (-15 -1700 (|#1| |#1|)) (-15 -2807 (|#1| |#1| (-592))) (-15 -3868 ((-141) |#1|)) (-15 -2955 ((-141) |#1|)) (-15 -3927 (|#2| |#1| (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592))) (-15 -4210 ((-658 |#2|) |#1|)) (-15 -3780 ((-141) (-592) |#1|)) (-15 -3708 ((-658 (-592)) |#1|)) (-15 -1813 ((-592) |#1|)) (-15 -2261 ((-592) |#1|)) (-15 -4466 (|#1| (-658 |#2|))) (-15 -3927 (|#1| |#1| (-1246 (-592)))) (-15 -3208 (|#1| |#1| (-592))) (-15 -3208 (|#1| |#1| (-1246 (-592)))) (-15 -3666 (|#1| |#2| |#1| (-592))) (-15 -3666 (|#1| |#1| |#1| (-592))) (-15 -2399 (|#1| |#1|)) (-15 -3318 ((-790) |#1|)) (-15 -3184 (|#1| |#1|)) (-15 -3188 (|#1| |#1|)) (-15 -4255 (|#1| |#1| (-790))) (-15 -3927 (|#2| |#1| "last")) (-15 -4255 (|#2| |#1|)) (-15 -1366 (|#1| |#1| (-790))) (-15 -3927 (|#1| |#1| "rest")) (-15 -1366 (|#1| |#1|)) (-15 -1918 (|#1| |#1| (-790))) (-15 -3927 (|#2| |#1| "first")) (-15 -1918 (|#2| |#1|)) (-15 -3055 ((-141) |#1| |#1|)) (-15 -2936 ((-141) |#1| |#1|)) (-15 -2920 ((-592) |#1| |#1|)) (-15 -3228 ((-141) |#1|)) (-15 -3927 (|#2| |#1| "value")) (-15 -2324 (|#2| |#1|)) (-15 -3683 ((-141) |#1|)) (-15 -2774 ((-658 |#1|) |#1|)) (-15 -2493 ((-658 |#1|) |#1|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -3002 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#2|) |#1|)) (-15 -1699 ((-790) |#1|)) (-15 -2126 ((-141) |#1| (-790))) (-15 -4345 ((-141) |#1| (-790))) (-15 -2554 ((-141) |#1| (-790)))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-1915 ((|#1| $) 62)) (-3188 (($ $) 64)) (-3898 (((-1285) $ (-592) (-592)) 94 (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) 49 (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-3153 (($ $ $) 53 (|has| $ (-6 -4626)))) (-4496 ((|#1| $ |#1|) 51 (|has| $ (-6 -4626)))) (-2101 ((|#1| $ |#1|) 55 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4626))) (($ $ "rest" $) 52 (|has| $ (-6 -4626))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 114 (|has| $ (-6 -4626))) ((|#1| $ (-592) |#1|) 83 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) 99)) (-1765 ((|#1| $) 63)) (-3001 (($) 7 T CONST)) (-4083 (($ $) 118)) (-1366 (($ $) 70) (($ $ (-790)) 68)) (-1360 (($ $) 96 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#1| $) 97 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 100)) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1426 ((|#1| $ (-592) |#1|) 82 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 84)) (-3868 (((-141) $) 80)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4219 (((-790) $) 117)) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-3242 (($ (-790) |#1|) 105)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 92 (|has| (-592) (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 91 (|has| (-592) (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-2554 (((-141) $ (-790)) 10)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-1640 (($ $) 120)) (-1323 (((-141) $) 121)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4255 ((|#1| $) 67) (($ $ (-790)) 65)) (-3666 (($ $ $ (-592)) 113) (($ |#1| $ (-592)) 112)) (-3708 (((-658 (-592)) $) 89)) (-3780 (((-141) (-592) $) 88)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-4479 ((|#1| $) 119)) (-1918 ((|#1| $) 73) (($ $ (-790)) 71)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 103)) (-1892 (($ $ |#1|) 93 (|has| $ (-6 -4626)))) (-2807 (($ $ (-592)) 116)) (-2955 (((-141) $) 81)) (-2393 (((-141) $) 122)) (-3630 (((-141) $) 123)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 90 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 87)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1246 (-592))) 109) ((|#1| $ (-592)) 86) ((|#1| $ (-592) |#1|) 85)) (-2920 (((-592) $ $) 41)) (-3208 (($ $ (-1246 (-592))) 111) (($ $ (-592)) 110)) (-3228 (((-141) $) 43)) (-2399 (($ $) 59)) (-1337 (($ $) 56 (|has| $ (-6 -4626)))) (-3318 (((-790) $) 60)) (-3184 (($ $) 61)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 95 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 104)) (-3619 (($ $ $) 58 (|has| $ (-6 -4626))) (($ $ |#1|) 57 (|has| $ (-6 -4626)))) (-2266 (($ $ $) 75) (($ |#1| $) 74) (($ (-658 $)) 107) (($ $ |#1|) 106)) (-1700 (($ $) 115)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-690 |#1|) (-1311) (-1225)) (T -690)) 
+((-4459 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *1 (-690 *3)) (-4 *3 (-1225)))) (-3113 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *1 (-690 *3)) (-4 *3 (-1225)))) (-3630 (*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1225)) (-5 *2 (-141)))) (-2393 (*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1225)) (-5 *2 (-141)))) (-1323 (*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1225)) (-5 *2 (-141)))) (-1640 (*1 *1 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1225)))) (-4479 (*1 *2 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1225)))) (-4083 (*1 *1 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1225)))) (-4219 (*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1225)) (-5 *2 (-790)))) (-2807 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-690 *3)) (-4 *3 (-1225)))) (-1700 (*1 *1 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1225))))) 
+(-13 (-1163 |t#1|) (-10 -8 (-15 -4459 ($ (-1 (-141) |t#1|) $)) (-15 -3113 ($ (-1 (-141) |t#1|) $)) (-15 -3630 ((-141) $)) (-15 -2393 ((-141) $)) (-15 -1323 ((-141) $)) (-15 -1640 ($ $)) (-15 -4479 (|t#1| $)) (-15 -4083 ($ $)) (-15 -4219 ((-790) $)) (-15 -2807 ($ $ (-592))) (-15 -1700 ($ $)))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-664 |#1|) . T) ((-1038 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1163 |#1|) . T) ((-1225) . T) ((-1267 |#1|) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1621 (($ (-790) (-790) (-790)) 32 (|has| |#1| (-1075)))) (-2126 (((-141) $ (-790)) NIL)) (-2586 ((|#1| $ (-790) (-790) (-790) |#1|) 27)) (-3001 (($) NIL T CONST)) (-2119 (($ $ $) 36 (|has| |#1| (-1075)))) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3101 (((-1280 (-790)) $) 8)) (-2100 (($ (-1191) $ $) 22)) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2637 (($ (-790)) 34 (|has| |#1| (-1075)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-790) (-790) (-790)) 25)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-4466 (($ (-658 (-658 (-658 |#1|)))) 43)) (-1683 (((-877) $) NIL (|has| |#1| (-1119))) (($ (-986 (-986 (-986 |#1|)))) 15) (((-986 (-986 (-986 |#1|))) $) 12)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-691 |#1|) (-13 (-523 |#1|) (-10 -8 (IF (|has| |#1| (-1075)) (PROGN (-15 -1621 ($ (-790) (-790) (-790))) (-15 -2637 ($ (-790))) (-15 -2119 ($ $ $))) |noBranch|) (-15 -4466 ($ (-658 (-658 (-658 |#1|))))) (-15 -3927 (|#1| $ (-790) (-790) (-790))) (-15 -2586 (|#1| $ (-790) (-790) (-790) |#1|)) (-15 -1683 ($ (-986 (-986 (-986 |#1|))))) (-15 -1683 ((-986 (-986 (-986 |#1|))) $)) (-15 -2100 ($ (-1191) $ $)) (-15 -3101 ((-1280 (-790)) $)))) (-1119)) (T -691)) 
+((-1621 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-790)) (-5 *1 (-691 *3)) (-4 *3 (-1075)) (-4 *3 (-1119)))) (-2637 (*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-691 *3)) (-4 *3 (-1075)) (-4 *3 (-1119)))) (-2119 (*1 *1 *1 *1) (-12 (-5 *1 (-691 *2)) (-4 *2 (-1075)) (-4 *2 (-1119)))) (-4466 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-658 *3)))) (-4 *3 (-1119)) (-5 *1 (-691 *3)))) (-3927 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-790)) (-5 *1 (-691 *2)) (-4 *2 (-1119)))) (-2586 (*1 *2 *1 *3 *3 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-691 *2)) (-4 *2 (-1119)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-986 (-986 (-986 *3)))) (-4 *3 (-1119)) (-5 *1 (-691 *3)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-986 (-986 (-986 *3)))) (-5 *1 (-691 *3)) (-4 *3 (-1119)))) (-2100 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-691 *3)) (-4 *3 (-1119)))) (-3101 (*1 *2 *1) (-12 (-5 *2 (-1280 (-790))) (-5 *1 (-691 *3)) (-4 *3 (-1119))))) 
+(-13 (-523 |#1|) (-10 -8 (IF (|has| |#1| (-1075)) (PROGN (-15 -1621 ($ (-790) (-790) (-790))) (-15 -2637 ($ (-790))) (-15 -2119 ($ $ $))) |noBranch|) (-15 -4466 ($ (-658 (-658 (-658 |#1|))))) (-15 -3927 (|#1| $ (-790) (-790) (-790))) (-15 -2586 (|#1| $ (-790) (-790) (-790) |#1|)) (-15 -1683 ($ (-986 (-986 (-986 |#1|))))) (-15 -1683 ((-986 (-986 (-986 |#1|))) $)) (-15 -2100 ($ (-1191) $ $)) (-15 -3101 ((-1280 (-790)) $)))) 
+((-2272 (((-141) |#1|) 5)) (-2078 (((-1285) |#1| (-1229) (-592) |#2|) 8)) (-3538 ((|#1| |#1| |#1| |#2|) 1)) (-2267 (((-3 |#2| "failed") (-658 (-980 (-592))) (-658 (-1191)) (-592)) 3)) (-3362 ((|SortedExponentVector| (-592) (-592) |#2|) 7)) (-4525 (((-592) |#1|) 6)) (-1992 (((-3 |#1| "failed") |#1| |#2|) 2)) (-4321 ((|#1| (-980 (-592)) (-1191) (-658 (-1191)) |#2|) 4))) 
+(((-692 |#1| |#2|) (-1311) (-1225) (-1225)) (T -692)) 
+((-2078 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1229)) (-5 *5 (-592)) (-4 *1 (-692 *3 *6)) (-4 *3 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1285)))) (-3362 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-592)) (-4 *1 (-692 *5 *4)) (-4 *5 (-1225)) (-4 *4 (-1225)) (-5 *2 |SortedExponentVector|))) (-4525 (*1 *2 *3) (-12 (-4 *1 (-692 *3 *4)) (-4 *3 (-1225)) (-4 *4 (-1225)) (-5 *2 (-592)))) (-2272 (*1 *2 *3) (-12 (-4 *1 (-692 *3 *4)) (-4 *3 (-1225)) (-4 *4 (-1225)) (-5 *2 (-141)))) (-4321 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-980 (-592))) (-5 *5 (-658 (-1191))) (-4 *1 (-692 *2 *6)) (-4 *6 (-1225)) (-5 *4 (-1191)) (-4 *2 (-1225)))) (-2267 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-658 (-1191))) (-5 *5 (-592)) (-4 *1 (-692 *6 *2)) (-4 *6 (-1225)) (-4 *2 (-1225)))) (-1992 (*1 *2 *2 *3) (|partial| -12 (-4 *1 (-692 *2 *3)) (-4 *2 (-1225)) (-4 *3 (-1225)))) (-3538 (*1 *2 *2 *2 *3) (-12 (-4 *1 (-692 *2 *3)) (-4 *2 (-1225)) (-4 *3 (-1225))))) 
+(-13 (-10 -7 (-15 -3538 (|t#1| |t#1| |t#1| |t#2|)) (-15 -1992 ((-3 |t#1| "failed") |t#1| |t#2|)) (-15 -2267 ((-3 |t#2| "failed") (-658 (-980 (-592))) (-658 (-1191)) (-592))) (-15 -4321 (|t#1| (-980 (-592)) (-1191) (-658 (-1191)) |t#2|)) (-15 -2272 ((-141) |t#1|)) (-15 -4525 ((-592) |t#1|)) (-15 -3362 (|SortedExponentVector| (-592) (-592) |t#2|)) (-15 -2078 ((-1285) |t#1| (-1229) (-592) |t#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-2692 (((-658 |#1|) $) 14)) (-1954 (($ $) 18)) (-3461 (((-141) $) 19)) (-4368 (((-3 |#1| "failed") $) 22)) (-2400 ((|#1| $) 20)) (-1366 (($ $) 36)) (-4103 (($ $) 24)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-3547 (((-141) $ $) 41)) (-4233 (((-944) $) 38)) (-1961 (($ $) 17)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 ((|#1| $) 35)) (-1683 (((-877) $) 31) (($ |#1|) 23) (((-841 |#1|) $) 27)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 12)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 40)) (* (($ $ $) 34))) 
+(((-693 |#1|) (-13 (-869) (-1065 |#1|) (-10 -8 (-15 * ($ $ $)) (-15 -1683 ((-841 |#1|) $)) (-15 -1918 (|#1| $)) (-15 -1961 ($ $)) (-15 -4233 ((-944) $)) (-15 -3547 ((-141) $ $)) (-15 -4103 ($ $)) (-15 -1366 ($ $)) (-15 -3461 ((-141) $)) (-15 -1954 ($ $)) (-15 -2692 ((-658 |#1|) $)))) (-869)) (T -693)) 
+((* (*1 *1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-841 *3)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) (-1918 (*1 *2 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) (-1961 (*1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) (-4233 (*1 *2 *1) (-12 (-5 *2 (-944)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) (-3547 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) (-4103 (*1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) (-1366 (*1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) (-3461 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) (-1954 (*1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) (-2692 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-693 *3)) (-4 *3 (-869))))) 
+(-13 (-869) (-1065 |#1|) (-10 -8 (-15 * ($ $ $)) (-15 -1683 ((-841 |#1|) $)) (-15 -1918 (|#1| $)) (-15 -1961 ($ $)) (-15 -4233 ((-944) $)) (-15 -3547 ((-141) $ $)) (-15 -4103 ($ $)) (-15 -1366 ($ $)) (-15 -3461 ((-141) $)) (-15 -1954 ($ $)) (-15 -2692 ((-658 |#1|) $)))) 
+((-1976 (((-658 |#4|) |#4| (-658 (-944))) 72) (((-658 |#4|) |#4| (-944)) 62)) (-4596 ((|#4| (-658 |#4|)) 59)) (-2019 ((|#4| |#4| (-1113 (-944)) (-1113 (-944))) 57) ((|#4| |#4| (-658 (-944)) (-658 (-944))) 54)) (-4274 ((|#4| |#4| (-1113 (-944))) 31) ((|#4| |#4| (-658 (-944))) 30)) (-4564 (((-658 |#4|) |#4| (-658 (-944))) 74) (((-658 |#4|) |#4| (-944)) 73)) (-2083 ((|#4| (-658 |#4|)) 58)) (-4077 ((|#4| |#4| (-944) (-944)) 20)) (-2933 ((|#4| |#4|) 45) ((|#4| |#4| (-592)) 44)) (-2712 ((|#4| |#4| (-1113 (-944))) 37) ((|#4| |#4| (-658 (-944))) 36)) (-1964 (((-658 (-658 |#4|)) |#4| (-658 (-944)) (-658 (-944))) 78) (((-658 (-658 |#4|)) |#4| (-944) (-658 (-944))) 77) (((-658 (-658 |#4|)) |#4| (-658 (-944)) (-944)) 76) (((-658 (-658 |#4|)) |#4| (-944) (-944)) 75)) (-3582 ((|#4| (-658 (-658 |#4|))) 53)) (-3075 ((|#4| |#4| (-1113 (-592))) 51) ((|#4| |#4| (-658 (-592))) 48)) (-2347 ((|#4| |#4| (-944)) 24)) (-1602 ((|#4| |#4| (-944)) 34))) 
+(((-694 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4077 (|#4| |#4| (-944) (-944))) (-15 -2347 (|#4| |#4| (-944))) (-15 -4274 (|#4| |#4| (-658 (-944)))) (-15 -4274 (|#4| |#4| (-1113 (-944)))) (-15 -1602 (|#4| |#4| (-944))) (-15 -2712 (|#4| |#4| (-658 (-944)))) (-15 -2712 (|#4| |#4| (-1113 (-944)))) (-15 -2019 (|#4| |#4| (-658 (-944)) (-658 (-944)))) (-15 -2019 (|#4| |#4| (-1113 (-944)) (-1113 (-944)))) (-15 -2933 (|#4| |#4| (-592))) (-15 -2933 (|#4| |#4|)) (-15 -3075 (|#4| |#4| (-658 (-592)))) (-15 -3075 (|#4| |#4| (-1113 (-592)))) (-15 -2083 (|#4| (-658 |#4|))) (-15 -4596 (|#4| (-658 |#4|))) (-15 -3582 (|#4| (-658 (-658 |#4|)))) (-15 -1976 ((-658 |#4|) |#4| (-944))) (-15 -1976 ((-658 |#4|) |#4| (-658 (-944)))) (-15 -4564 ((-658 |#4|) |#4| (-944))) (-15 -4564 ((-658 |#4|) |#4| (-658 (-944)))) (-15 -1964 ((-658 (-658 |#4|)) |#4| (-944) (-944))) (-15 -1964 ((-658 (-658 |#4|)) |#4| (-658 (-944)) (-944))) (-15 -1964 ((-658 (-658 |#4|)) |#4| (-944) (-658 (-944)))) (-15 -1964 ((-658 (-658 |#4|)) |#4| (-658 (-944)) (-658 (-944))))) (-388) (-399 |#1|) (-399 |#1|) (-704 |#1| |#2| |#3|)) (T -694)) 
+((-1964 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-658 (-944))) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) (-1964 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-658 (-944))) (-5 *4 (-944)) (-4 *6 (-388)) (-4 *7 (-399 *6)) (-4 *8 (-399 *6)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-694 *6 *7 *8 *3)) (-4 *3 (-704 *6 *7 *8)))) (-1964 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-944))) (-5 *5 (-944)) (-4 *6 (-388)) (-4 *7 (-399 *6)) (-4 *8 (-399 *6)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-694 *6 *7 *8 *3)) (-4 *3 (-704 *6 *7 *8)))) (-1964 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) (-4564 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-944))) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 *3)) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) (-4564 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 *3)) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) (-1976 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-944))) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 *3)) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) (-1976 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 *3)) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) (-3582 (*1 *2 *3) (-12 (-5 *3 (-658 (-658 *2))) (-4 *4 (-388)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)))) (-4596 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *4 (-388)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)))) (-2083 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *4 (-388)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)))) (-3075 (*1 *2 *2 *3) (-12 (-5 *3 (-1113 (-592))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-3075 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-592))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-2933 (*1 *2 *2) (-12 (-4 *3 (-388)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-694 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-2933 (*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-2019 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-1113 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-2019 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-658 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-2712 (*1 *2 *2 *3) (-12 (-5 *3 (-1113 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-2712 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-1602 (*1 *2 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-4274 (*1 *2 *2 *3) (-12 (-5 *3 (-1113 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-4274 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-2347 (*1 *2 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-4077 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-944)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6))))) 
+(-10 -7 (-15 -4077 (|#4| |#4| (-944) (-944))) (-15 -2347 (|#4| |#4| (-944))) (-15 -4274 (|#4| |#4| (-658 (-944)))) (-15 -4274 (|#4| |#4| (-1113 (-944)))) (-15 -1602 (|#4| |#4| (-944))) (-15 -2712 (|#4| |#4| (-658 (-944)))) (-15 -2712 (|#4| |#4| (-1113 (-944)))) (-15 -2019 (|#4| |#4| (-658 (-944)) (-658 (-944)))) (-15 -2019 (|#4| |#4| (-1113 (-944)) (-1113 (-944)))) (-15 -2933 (|#4| |#4| (-592))) (-15 -2933 (|#4| |#4|)) (-15 -3075 (|#4| |#4| (-658 (-592)))) (-15 -3075 (|#4| |#4| (-1113 (-592)))) (-15 -2083 (|#4| (-658 |#4|))) (-15 -4596 (|#4| (-658 |#4|))) (-15 -3582 (|#4| (-658 (-658 |#4|)))) (-15 -1976 ((-658 |#4|) |#4| (-944))) (-15 -1976 ((-658 |#4|) |#4| (-658 (-944)))) (-15 -4564 ((-658 |#4|) |#4| (-944))) (-15 -4564 ((-658 |#4|) |#4| (-658 (-944)))) (-15 -1964 ((-658 (-658 |#4|)) |#4| (-944) (-944))) (-15 -1964 ((-658 (-658 |#4|)) |#4| (-658 (-944)) (-944))) (-15 -1964 ((-658 (-658 |#4|)) |#4| (-944) (-658 (-944)))) (-15 -1964 ((-658 (-658 |#4|)) |#4| (-658 (-944)) (-658 (-944))))) 
+((-1715 ((|#1| (-1 |#1| (-790) |#1|) (-790) |#1|) 11)) (-3154 ((|#1| (-1 |#1| |#1|) (-790) |#1|) 9))) 
+(((-695 |#1|) (-10 -7 (-15 -3154 (|#1| (-1 |#1| |#1|) (-790) |#1|)) (-15 -1715 (|#1| (-1 |#1| (-790) |#1|) (-790) |#1|))) (-1119)) (T -695)) 
+((-1715 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 (-790) *2)) (-5 *4 (-790)) (-4 *2 (-1119)) (-5 *1 (-695 *2)))) (-3154 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *2)) (-5 *4 (-790)) (-4 *2 (-1119)) (-5 *1 (-695 *2))))) 
+(-10 -7 (-15 -3154 (|#1| (-1 |#1| |#1|) (-790) |#1|)) (-15 -1715 (|#1| (-1 |#1| (-790) |#1|) (-790) |#1|))) 
+((-3854 ((|#2| |#1| |#2|) 9)) (-3849 ((|#1| |#1| |#2|) 8))) 
+(((-696 |#1| |#2|) (-10 -7 (-15 -3849 (|#1| |#1| |#2|)) (-15 -3854 (|#2| |#1| |#2|))) (-1119) (-1119)) (T -696)) 
+((-3854 (*1 *2 *3 *2) (-12 (-5 *1 (-696 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119)))) (-3849 (*1 *2 *2 *3) (-12 (-5 *1 (-696 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119))))) 
+(-10 -7 (-15 -3849 (|#1| |#1| |#2|)) (-15 -3854 (|#2| |#1| |#2|))) 
+((-4030 ((|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|) 11))) 
+(((-697 |#1| |#2| |#3|) (-10 -7 (-15 -4030 (|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|))) (-1119) (-1119) (-1119)) (T -697)) 
+((-4030 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)) (-5 *1 (-697 *5 *6 *2))))) 
+(-10 -7 (-15 -4030 (|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|))) 
+((-1715 (((-1 |#1| (-790) |#1|) (-1 |#1| (-790) |#1|)) 23)) (-2984 (((-1 |#1|) |#1|) 8)) (-4547 ((|#1| |#1|) 16)) (-4531 (((-658 |#1|) (-1 (-658 |#1|) (-658 |#1|)) (-592)) 15) ((|#1| (-1 |#1| |#1|)) 11)) (-1683 (((-1 |#1|) |#1|) 9)) (** (((-1 |#1| |#1|) (-1 |#1| |#1|) (-790)) 20))) 
+(((-698 |#1|) (-10 -7 (-15 -2984 ((-1 |#1|) |#1|)) (-15 -1683 ((-1 |#1|) |#1|)) (-15 -4531 (|#1| (-1 |#1| |#1|))) (-15 -4531 ((-658 |#1|) (-1 (-658 |#1|) (-658 |#1|)) (-592))) (-15 -4547 (|#1| |#1|)) (-15 ** ((-1 |#1| |#1|) (-1 |#1| |#1|) (-790))) (-15 -1715 ((-1 |#1| (-790) |#1|) (-1 |#1| (-790) |#1|)))) (-1119)) (T -698)) 
+((-1715 (*1 *2 *2) (-12 (-5 *2 (-1 *3 (-790) *3)) (-4 *3 (-1119)) (-5 *1 (-698 *3)))) (** (*1 *2 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-790)) (-4 *4 (-1119)) (-5 *1 (-698 *4)))) (-4547 (*1 *2 *2) (-12 (-5 *1 (-698 *2)) (-4 *2 (-1119)))) (-4531 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-658 *5) (-658 *5))) (-5 *4 (-592)) (-5 *2 (-658 *5)) (-5 *1 (-698 *5)) (-4 *5 (-1119)))) (-4531 (*1 *2 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-698 *2)) (-4 *2 (-1119)))) (-1683 (*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-698 *3)) (-4 *3 (-1119)))) (-2984 (*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-698 *3)) (-4 *3 (-1119))))) 
+(-10 -7 (-15 -2984 ((-1 |#1|) |#1|)) (-15 -1683 ((-1 |#1|) |#1|)) (-15 -4531 (|#1| (-1 |#1| |#1|))) (-15 -4531 ((-658 |#1|) (-1 (-658 |#1|) (-658 |#1|)) (-592))) (-15 -4547 (|#1| |#1|)) (-15 ** ((-1 |#1| |#1|) (-1 |#1| |#1|) (-790))) (-15 -1715 ((-1 |#1| (-790) |#1|) (-1 |#1| (-790) |#1|)))) 
+((-2387 (((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)) 16)) (-1871 (((-1 |#2|) (-1 |#2| |#1|) |#1|) 13)) (-4249 (((-1 |#2| |#1|) (-1 |#2|)) 14)) (-3479 (((-1 |#2| |#1|) |#2|) 11))) 
+(((-699 |#1| |#2|) (-10 -7 (-15 -3479 ((-1 |#2| |#1|) |#2|)) (-15 -1871 ((-1 |#2|) (-1 |#2| |#1|) |#1|)) (-15 -4249 ((-1 |#2| |#1|) (-1 |#2|))) (-15 -2387 ((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)))) (-1119) (-1119)) (T -699)) 
+((-2387 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *4 *4)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-5 *2 (-1 *5 *4)) (-5 *1 (-699 *4 *5)))) (-4249 (*1 *2 *3) (-12 (-5 *3 (-1 *5)) (-4 *5 (-1119)) (-5 *2 (-1 *5 *4)) (-5 *1 (-699 *4 *5)) (-4 *4 (-1119)))) (-1871 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *4)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-5 *2 (-1 *5)) (-5 *1 (-699 *4 *5)))) (-3479 (*1 *2 *3) (-12 (-5 *2 (-1 *3 *4)) (-5 *1 (-699 *4 *3)) (-4 *4 (-1119)) (-4 *3 (-1119))))) 
+(-10 -7 (-15 -3479 ((-1 |#2| |#1|) |#2|)) (-15 -1871 ((-1 |#2|) (-1 |#2| |#1|) |#1|)) (-15 -4249 ((-1 |#2| |#1|) (-1 |#2|))) (-15 -2387 ((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)))) 
+((-3728 (((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|)) 17)) (-3654 (((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|) 11)) (-1577 (((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|) 13)) (-3612 (((-1 |#3| |#1| |#2|) (-1 |#3| |#1|)) 14)) (-3173 (((-1 |#3| |#1| |#2|) (-1 |#3| |#2|)) 15)) (* (((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)) 21))) 
+(((-700 |#1| |#2| |#3|) (-10 -7 (-15 -3654 ((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|)) (-15 -1577 ((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|)) (-15 -3612 ((-1 |#3| |#1| |#2|) (-1 |#3| |#1|))) (-15 -3173 ((-1 |#3| |#1| |#2|) (-1 |#3| |#2|))) (-15 -3728 ((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|))) (-15 * ((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)))) (-1119) (-1119) (-1119)) (T -700)) 
+((* (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-1 *7 *5)) (-5 *1 (-700 *5 *6 *7)))) (-3728 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *5 *4)) (-5 *1 (-700 *4 *5 *6)))) (-3173 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-700 *4 *5 *6)) (-4 *4 (-1119)))) (-3612 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *4)) (-4 *4 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-700 *4 *5 *6)) (-4 *5 (-1119)))) (-1577 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *5)) (-5 *1 (-700 *4 *5 *6)))) (-3654 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5 *4)) (-4 *5 (-1119)) (-4 *4 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *5)) (-5 *1 (-700 *5 *4 *6))))) 
+(-10 -7 (-15 -3654 ((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|)) (-15 -1577 ((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|)) (-15 -3612 ((-1 |#3| |#1| |#2|) (-1 |#3| |#1|))) (-15 -3173 ((-1 |#3| |#1| |#2|) (-1 |#3| |#2|))) (-15 -3728 ((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|))) (-15 * ((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)))) 
+((-3313 (((-1 (-332 (-592)) |#1|) (-1 (-332 (-592)) |#1|) (-1 (-332 (-592)) |#1|)) 18)) (-3306 (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 12)) (-3300 (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 10)) (* (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 14))) 
+(((-701 |#1| |#2|) (-10 -7 (-15 -3300 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -3306 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 * ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -3313 ((-1 (-332 (-592)) |#1|) (-1 (-332 (-592)) |#1|) (-1 (-332 (-592)) |#1|)))) (-1119) (-1075)) (T -701)) 
+((-3313 (*1 *2 *2 *2) (-12 (-5 *2 (-1 (-332 (-592)) *3)) (-4 *3 (-1119)) (-5 *1 (-701 *3 *4)) (-4 *4 (-1075)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1119)) (-4 *4 (-1075)) (-5 *1 (-701 *3 *4)))) (-3306 (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1119)) (-4 *4 (-1075)) (-5 *1 (-701 *3 *4)))) (-3300 (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1119)) (-4 *4 (-1075)) (-5 *1 (-701 *3 *4))))) 
+(-10 -7 (-15 -3300 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -3306 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 * ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -3313 ((-1 (-332 (-592)) |#1|) (-1 (-332 (-592)) |#1|) (-1 (-332 (-592)) |#1|)))) 
+((-3657 ((|#5| (-1 |#5| |#1| |#5|) |#4| |#5|) 39)) (-2731 (((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|) 37) ((|#8| (-1 |#5| |#1|) |#4|) 31))) 
+(((-702 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2731 (|#8| (-1 |#5| |#1|) |#4|)) (-15 -2731 ((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|)) (-15 -3657 (|#5| (-1 |#5| |#1| |#5|) |#4| |#5|))) (-1075) (-399 |#1|) (-399 |#1|) (-704 |#1| |#2| |#3|) (-1075) (-399 |#5|) (-399 |#5|) (-704 |#5| |#6| |#7|)) (T -702)) 
+((-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1075)) (-4 *2 (-1075)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-4 *8 (-399 *2)) (-4 *9 (-399 *2)) (-5 *1 (-702 *5 *6 *7 *4 *2 *8 *9 *10)) (-4 *4 (-704 *5 *6 *7)) (-4 *10 (-704 *2 *8 *9)))) (-2731 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *8 "failed") *5)) (-4 *5 (-1075)) (-4 *8 (-1075)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-4 *2 (-704 *8 *9 *10)) (-5 *1 (-702 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-704 *5 *6 *7)) (-4 *9 (-399 *8)) (-4 *10 (-399 *8)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1075)) (-4 *8 (-1075)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-4 *2 (-704 *8 *9 *10)) (-5 *1 (-702 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-704 *5 *6 *7)) (-4 *9 (-399 *8)) (-4 *10 (-399 *8))))) 
+(-10 -7 (-15 -2731 (|#8| (-1 |#5| |#1|) |#4|)) (-15 -2731 ((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|)) (-15 -3657 (|#5| (-1 |#5| |#1| |#5|) |#4| |#5|))) 
+((-1417 (($ (-790) (-790)) 31)) (-4596 (($ $ $) 56)) (-2245 (($ |#3|) 52) (($ $) 53)) (-4034 (((-141) $) 26)) (-2668 (($ $ (-592) (-592)) 58)) (-1664 (($ $ (-592) (-592)) 59)) (-2019 (($ $ (-592) (-592) (-592) (-592)) 63)) (-1574 (($ $) 54)) (-3120 (((-141) $) 14)) (-2854 (($ $ (-592) (-592) $) 64)) (-3932 ((|#2| $ (-592) (-592) |#2|) NIL) (($ $ (-658 (-592)) (-658 (-592)) $) 62)) (-3223 (($ (-790) |#2|) 38)) (-1794 ((|#2| $) 107)) (-4186 (($ (-658 (-658 |#2|))) 34) (($ (-790) (-790) (-1 |#2| (-592) (-592))) 36)) (-4601 (((-658 (-658 |#2|)) $) 57)) (-2083 (($ $ $) 55)) (-3616 (((-3 $ "failed") $ |#2|) 110)) (-3927 ((|#2| $ (-592) (-592)) NIL) ((|#2| $ (-592) (-592) |#2|) NIL) (($ $ (-658 (-592)) (-658 (-592))) 61)) (-2933 (($ (-658 |#2|)) 40) (($ (-658 $)) 42)) (-2940 (((-141) $) 23)) (-3430 (((-658 |#4|) $) 93)) (-1683 (((-877) $) NIL) (($ |#4|) 47)) (-3951 (((-141) $) 28)) (-3313 (($ $ |#2|) 112)) (-3306 (($ $ $) 68) (($ $) 71)) (-3300 (($ $ $) 66)) (** (($ $ (-790)) 80) (($ $ (-592)) 115)) (* (($ $ $) 77) (($ |#2| $) 73) (($ $ |#2|) 74) (($ (-592) $) 76) ((|#4| $ |#4|) 84) ((|#3| |#3| $) 88))) 
+(((-703 |#1| |#2| |#3| |#4|) (-10 -8 (-15 ** (|#1| |#1| (-592))) (-15 -1794 (|#2| |#1|)) (-15 -3430 ((-658 |#4|) |#1|)) (-15 -3313 (|#1| |#1| |#2|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#2|)) (-15 ** (|#1| |#1| (-790))) (-15 * (|#3| |#3| |#1|)) (-15 * (|#4| |#1| |#4|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3300 (|#1| |#1| |#1|)) (-15 -2854 (|#1| |#1| (-592) (-592) |#1|)) (-15 -2019 (|#1| |#1| (-592) (-592) (-592) (-592))) (-15 -1664 (|#1| |#1| (-592) (-592))) (-15 -2668 (|#1| |#1| (-592) (-592))) (-15 -3932 (|#1| |#1| (-658 (-592)) (-658 (-592)) |#1|)) (-15 -3927 (|#1| |#1| (-658 (-592)) (-658 (-592)))) (-15 -4601 ((-658 (-658 |#2|)) |#1|)) (-15 -4596 (|#1| |#1| |#1|)) (-15 -2083 (|#1| |#1| |#1|)) (-15 -1574 (|#1| |#1|)) (-15 -2245 (|#1| |#1|)) (-15 -2245 (|#1| |#3|)) (-15 -1683 (|#1| |#4|)) (-15 -2933 (|#1| (-658 |#1|))) (-15 -2933 (|#1| (-658 |#2|))) (-15 -3223 (|#1| (-790) |#2|)) (-15 -4186 (|#1| (-790) (-790) (-1 |#2| (-592) (-592)))) (-15 -4186 (|#1| (-658 (-658 |#2|)))) (-15 -1417 (|#1| (-790) (-790))) (-15 -3951 ((-141) |#1|)) (-15 -4034 ((-141) |#1|)) (-15 -2940 ((-141) |#1|)) (-15 -3120 ((-141) |#1|)) (-15 -3932 (|#2| |#1| (-592) (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592) (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592) (-592))) (-15 -1683 ((-877) |#1|))) (-704 |#2| |#3| |#4|) (-1075) (-399 |#2|) (-399 |#2|)) (T -703)) 
+NIL 
+(-10 -8 (-15 ** (|#1| |#1| (-592))) (-15 -1794 (|#2| |#1|)) (-15 -3430 ((-658 |#4|) |#1|)) (-15 -3313 (|#1| |#1| |#2|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#2|)) (-15 ** (|#1| |#1| (-790))) (-15 * (|#3| |#3| |#1|)) (-15 * (|#4| |#1| |#4|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3300 (|#1| |#1| |#1|)) (-15 -2854 (|#1| |#1| (-592) (-592) |#1|)) (-15 -2019 (|#1| |#1| (-592) (-592) (-592) (-592))) (-15 -1664 (|#1| |#1| (-592) (-592))) (-15 -2668 (|#1| |#1| (-592) (-592))) (-15 -3932 (|#1| |#1| (-658 (-592)) (-658 (-592)) |#1|)) (-15 -3927 (|#1| |#1| (-658 (-592)) (-658 (-592)))) (-15 -4601 ((-658 (-658 |#2|)) |#1|)) (-15 -4596 (|#1| |#1| |#1|)) (-15 -2083 (|#1| |#1| |#1|)) (-15 -1574 (|#1| |#1|)) (-15 -2245 (|#1| |#1|)) (-15 -2245 (|#1| |#3|)) (-15 -1683 (|#1| |#4|)) (-15 -2933 (|#1| (-658 |#1|))) (-15 -2933 (|#1| (-658 |#2|))) (-15 -3223 (|#1| (-790) |#2|)) (-15 -4186 (|#1| (-790) (-790) (-1 |#2| (-592) (-592)))) (-15 -4186 (|#1| (-658 (-658 |#2|)))) (-15 -1417 (|#1| (-790) (-790))) (-15 -3951 ((-141) |#1|)) (-15 -4034 ((-141) |#1|)) (-15 -2940 ((-141) |#1|)) (-15 -3120 ((-141) |#1|)) (-15 -3932 (|#2| |#1| (-592) (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592) (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592) (-592))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-1417 (($ (-790) (-790)) 95)) (-4596 (($ $ $) 84)) (-2245 (($ |#2|) 88) (($ $) 87)) (-4034 (((-141) $) 97)) (-2668 (($ $ (-592) (-592)) 80)) (-1664 (($ $ (-592) (-592)) 79)) (-2019 (($ $ (-592) (-592) (-592) (-592)) 78)) (-1574 (($ $) 86)) (-3120 (((-141) $) 99)) (-2126 (((-141) $ (-790)) 8)) (-2854 (($ $ (-592) (-592) $) 77)) (-3932 ((|#1| $ (-592) (-592) |#1|) 41) (($ $ (-658 (-592)) (-658 (-592)) $) 81)) (-2547 (($ $ (-592) |#2|) 39)) (-2242 (($ $ (-592) |#3|) 38)) (-3223 (($ (-790) |#1|) 92)) (-3001 (($) 7 T CONST)) (-3052 (($ $) 64 (|has| |#1| (-323)))) (-2747 ((|#2| $ (-592)) 43)) (-4175 (((-790) $) 62 (|has| |#1| (-582)))) (-1426 ((|#1| $ (-592) (-592) |#1|) 40)) (-3959 ((|#1| $ (-592) (-592)) 45)) (-1794 ((|#1| $) 57 (|has| |#1| (-194)))) (-4004 (((-658 |#1|) $) 30)) (-3178 (((-790) $) 61 (|has| |#1| (-582)))) (-3555 (((-658 |#3|) $) 60 (|has| |#1| (-582)))) (-4292 (((-790) $) 48)) (-3242 (($ (-790) (-790) |#1|) 54)) (-4298 (((-790) $) 47)) (-4345 (((-141) $ (-790)) 9)) (-3781 ((|#1| $) 58 (|has| |#1| (-6 (-4627 "*"))))) (-4577 (((-592) $) 52)) (-4280 (((-592) $) 50)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1898 (((-592) $) 51)) (-3005 (((-592) $) 49)) (-4186 (($ (-658 (-658 |#1|))) 94) (($ (-790) (-790) (-1 |#1| (-592) (-592))) 93)) (-3987 (($ (-1 |#1| |#1|) $) 34)) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 37) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) 36)) (-4601 (((-658 (-658 |#1|)) $) 83)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-3183 (((-3 $ "failed") $) 56 (|has| |#1| (-388)))) (-2083 (($ $ $) 85)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1892 (($ $ |#1|) 53)) (-3616 (((-3 $ "failed") $ |#1|) 66 (|has| |#1| (-582)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ (-592) (-592)) 46) ((|#1| $ (-592) (-592) |#1|) 44) (($ $ (-658 (-592)) (-658 (-592))) 82)) (-2933 (($ (-658 |#1|)) 91) (($ (-658 $)) 90)) (-2940 (((-141) $) 98)) (-1625 ((|#1| $) 59 (|has| |#1| (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-3430 (((-658 |#3|) $) 63 (|has| |#1| (-323)))) (-2000 ((|#3| $ (-592)) 42)) (-1683 (((-877) $) 20 (|has| |#1| (-1119))) (($ |#3|) 89)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3951 (((-141) $) 96)) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-3313 (($ $ |#1|) 65 (|has| |#1| (-388)))) (-3306 (($ $ $) 75) (($ $) 74)) (-3300 (($ $ $) 76)) (** (($ $ (-790)) 67) (($ $ (-592)) 55 (|has| |#1| (-388)))) (* (($ $ $) 73) (($ |#1| $) 72) (($ $ |#1|) 71) (($ (-592) $) 70) ((|#3| $ |#3|) 69) ((|#2| |#2| $) 68)) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-704 |#1| |#2| |#3|) (-1311) (-1075) (-399 |t#1|) (-399 |t#1|)) (T -704)) 
+((-3120 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-141)))) (-2940 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-141)))) (-4034 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-141)))) (-3951 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-141)))) (-1417 (*1 *1 *2 *2) (-12 (-5 *2 (-790)) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-4186 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-4186 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-1 *4 (-592) (-592))) (-4 *4 (-1075)) (-4 *1 (-704 *4 *5 *6)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)))) (-3223 (*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-2933 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-2933 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-1683 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *2)) (-4 *4 (-399 *3)) (-4 *2 (-399 *3)))) (-2245 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *1 (-704 *3 *2 *4)) (-4 *2 (-399 *3)) (-4 *4 (-399 *3)))) (-2245 (*1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (-1574 (*1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (-2083 (*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (-4596 (*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (-4601 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-658 (-658 *3))))) (-3927 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-658 (-592))) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-3932 (*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-658 (-592))) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-2668 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-1664 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-2019 (*1 *1 *1 *2 *2 *2 *2) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-2854 (*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-3300 (*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (-3306 (*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (-3306 (*1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (* (*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (* (*1 *2 *1 *2) (-12 (-4 *1 (-704 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *2 (-399 *3)))) (* (*1 *2 *2 *1) (-12 (-4 *1 (-704 *3 *2 *4)) (-4 *3 (-1075)) (-4 *2 (-399 *3)) (-4 *4 (-399 *3)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) (-3616 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-582)))) (-3313 (*1 *1 *1 *2) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-388)))) (-3052 (*1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-323)))) (-3430 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-323)) (-5 *2 (-658 *5)))) (-4175 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-582)) (-5 *2 (-790)))) (-3178 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-582)) (-5 *2 (-790)))) (-3555 (*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-582)) (-5 *2 (-658 *5)))) (-1625 (*1 *2 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (|has| *2 (-6 (-4627 "*"))) (-4 *2 (-1075)))) (-3781 (*1 *2 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (|has| *2 (-6 (-4627 "*"))) (-4 *2 (-1075)))) (-1794 (*1 *2 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-1075)) (-4 *2 (-194)))) (-3183 (*1 *1 *1) (|partial| -12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-388)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-388))))) 
+(-13 (-62 |t#1| |t#2| |t#3|) (-10 -8 (-6 -4626) (-6 -4625) (-15 -3120 ((-141) $)) (-15 -2940 ((-141) $)) (-15 -4034 ((-141) $)) (-15 -3951 ((-141) $)) (-15 -1417 ($ (-790) (-790))) (-15 -4186 ($ (-658 (-658 |t#1|)))) (-15 -4186 ($ (-790) (-790) (-1 |t#1| (-592) (-592)))) (-15 -3223 ($ (-790) |t#1|)) (-15 -2933 ($ (-658 |t#1|))) (-15 -2933 ($ (-658 $))) (-15 -1683 ($ |t#3|)) (-15 -2245 ($ |t#2|)) (-15 -2245 ($ $)) (-15 -1574 ($ $)) (-15 -2083 ($ $ $)) (-15 -4596 ($ $ $)) (-15 -4601 ((-658 (-658 |t#1|)) $)) (-15 -3927 ($ $ (-658 (-592)) (-658 (-592)))) (-15 -3932 ($ $ (-658 (-592)) (-658 (-592)) $)) (-15 -2668 ($ $ (-592) (-592))) (-15 -1664 ($ $ (-592) (-592))) (-15 -2019 ($ $ (-592) (-592) (-592) (-592))) (-15 -2854 ($ $ (-592) (-592) $)) (-15 -3300 ($ $ $)) (-15 -3306 ($ $ $)) (-15 -3306 ($ $)) (-15 * ($ $ $)) (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|)) (-15 * ($ (-592) $)) (-15 * (|t#3| $ |t#3|)) (-15 * (|t#2| |t#2| $)) (-15 ** ($ $ (-790))) (IF (|has| |t#1| (-582)) (-15 -3616 ((-3 $ "failed") $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-388)) (-15 -3313 ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-323)) (PROGN (-15 -3052 ($ $)) (-15 -3430 ((-658 |t#3|) $))) |noBranch|) (IF (|has| |t#1| (-582)) (PROGN (-15 -4175 ((-790) $)) (-15 -3178 ((-790) $)) (-15 -3555 ((-658 |t#3|) $))) |noBranch|) (IF (|has| |t#1| (-6 (-4627 "*"))) (PROGN (-15 -1625 (|t#1| $)) (-15 -3781 (|t#1| $))) |noBranch|) (IF (|has| |t#1| (-194)) (-15 -1794 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-388)) (PROGN (-15 -3183 ((-3 $ "failed") $)) (-15 ** ($ $ (-592)))) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-62 |#1| |#2| |#3|) . T) ((-1225) . T)) 
+((-3052 ((|#4| |#4|) 67 (|has| |#1| (-323)))) (-4175 (((-790) |#4|) 69 (|has| |#1| (-582)))) (-3178 (((-790) |#4|) 71 (|has| |#1| (-582)))) (-3555 (((-658 |#3|) |#4|) 78 (|has| |#1| (-582)))) (-1852 (((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|) 95 (|has| |#1| (-323)))) (-3781 ((|#1| |#4|) 33)) (-2433 (((-3 |#4| "failed") |#4|) 61 (|has| |#1| (-582)))) (-3183 (((-3 |#4| "failed") |#4|) 75 (|has| |#1| (-388)))) (-2654 ((|#4| |#4|) 54 (|has| |#1| (-582)))) (-2451 ((|#4| |#4| |#1| (-592) (-592)) 41)) (-2029 ((|#4| |#4| (-592) (-592)) 36)) (-1658 ((|#4| |#4| |#1| (-592) (-592)) 46)) (-1625 ((|#1| |#4|) 73)) (-2332 (((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|) 57 (|has| |#1| (-582))))) 
+(((-705 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1625 (|#1| |#4|)) (-15 -3781 (|#1| |#4|)) (-15 -2029 (|#4| |#4| (-592) (-592))) (-15 -2451 (|#4| |#4| |#1| (-592) (-592))) (-15 -1658 (|#4| |#4| |#1| (-592) (-592))) (IF (|has| |#1| (-582)) (PROGN (-15 -4175 ((-790) |#4|)) (-15 -3178 ((-790) |#4|)) (-15 -3555 ((-658 |#3|) |#4|)) (-15 -2654 (|#4| |#4|)) (-15 -2433 ((-3 |#4| "failed") |#4|)) (-15 -2332 ((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|))) |noBranch|) (IF (|has| |#1| (-323)) (PROGN (-15 -3052 (|#4| |#4|)) (-15 -1852 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-388)) (-15 -3183 ((-3 |#4| "failed") |#4|)) |noBranch|)) (-194) (-399 |#1|) (-399 |#1|) (-704 |#1| |#2| |#3|)) (T -705)) 
+((-3183 (*1 *2 *2) (|partial| -12 (-4 *3 (-388)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-705 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-1852 (*1 *2 *3 *3) (-12 (-4 *3 (-323)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-705 *3 *4 *5 *6)) (-4 *6 (-704 *3 *4 *5)))) (-3052 (*1 *2 *2) (-12 (-4 *3 (-323)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-705 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-2332 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-2 (|:| |adjMat| *3) (|:| |detMat| *4))) (-5 *1 (-705 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-2433 (*1 *2 *2) (|partial| -12 (-4 *3 (-582)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-705 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-2654 (*1 *2 *2) (-12 (-4 *3 (-582)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-705 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-3555 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-658 *6)) (-5 *1 (-705 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-3178 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-790)) (-5 *1 (-705 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-4175 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-790)) (-5 *1 (-705 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-1658 (*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-592)) (-4 *3 (-194)) (-4 *5 (-399 *3)) (-4 *6 (-399 *3)) (-5 *1 (-705 *3 *5 *6 *2)) (-4 *2 (-704 *3 *5 *6)))) (-2451 (*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-592)) (-4 *3 (-194)) (-4 *5 (-399 *3)) (-4 *6 (-399 *3)) (-5 *1 (-705 *3 *5 *6 *2)) (-4 *2 (-704 *3 *5 *6)))) (-2029 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-592)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-705 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) (-3781 (*1 *2 *3) (-12 (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-194)) (-5 *1 (-705 *2 *4 *5 *3)) (-4 *3 (-704 *2 *4 *5)))) (-1625 (*1 *2 *3) (-12 (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-194)) (-5 *1 (-705 *2 *4 *5 *3)) (-4 *3 (-704 *2 *4 *5))))) 
+(-10 -7 (-15 -1625 (|#1| |#4|)) (-15 -3781 (|#1| |#4|)) (-15 -2029 (|#4| |#4| (-592) (-592))) (-15 -2451 (|#4| |#4| |#1| (-592) (-592))) (-15 -1658 (|#4| |#4| |#1| (-592) (-592))) (IF (|has| |#1| (-582)) (PROGN (-15 -4175 ((-790) |#4|)) (-15 -3178 ((-790) |#4|)) (-15 -3555 ((-658 |#3|) |#4|)) (-15 -2654 (|#4| |#4|)) (-15 -2433 ((-3 |#4| "failed") |#4|)) (-15 -2332 ((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|))) |noBranch|) (IF (|has| |#1| (-323)) (PROGN (-15 -3052 (|#4| |#4|)) (-15 -1852 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-388)) (-15 -3183 ((-3 |#4| "failed") |#4|)) |noBranch|)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1417 (($ (-790) (-790)) 45)) (-4596 (($ $ $) NIL)) (-2245 (($ (-1280 |#1|)) NIL) (($ $) NIL)) (-4034 (((-141) $) NIL)) (-2668 (($ $ (-592) (-592)) 12)) (-1664 (($ $ (-592) (-592)) NIL)) (-2019 (($ $ (-592) (-592) (-592) (-592)) NIL)) (-1574 (($ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-2854 (($ $ (-592) (-592) $) NIL)) (-3932 ((|#1| $ (-592) (-592) |#1|) NIL) (($ $ (-658 (-592)) (-658 (-592)) $) NIL)) (-2547 (($ $ (-592) (-1280 |#1|)) NIL)) (-2242 (($ $ (-592) (-1280 |#1|)) NIL)) (-3223 (($ (-790) |#1|) 22)) (-3001 (($) NIL T CONST)) (-3052 (($ $) 30 (|has| |#1| (-323)))) (-2747 (((-1280 |#1|) $ (-592)) NIL)) (-4175 (((-790) $) 32 (|has| |#1| (-582)))) (-1426 ((|#1| $ (-592) (-592) |#1|) 50)) (-3959 ((|#1| $ (-592) (-592)) NIL)) (-1794 ((|#1| $) NIL (|has| |#1| (-194)))) (-4004 (((-658 |#1|) $) NIL)) (-3178 (((-790) $) 34 (|has| |#1| (-582)))) (-3555 (((-658 (-1280 |#1|)) $) 37 (|has| |#1| (-582)))) (-4292 (((-790) $) 20)) (-3242 (($ (-790) (-790) |#1|) NIL)) (-4298 (((-790) $) 21)) (-4345 (((-141) $ (-790)) NIL)) (-3781 ((|#1| $) 28 (|has| |#1| (-6 (-4627 "*"))))) (-4577 (((-592) $) 9)) (-4280 (((-592) $) 10)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1898 (((-592) $) 11)) (-3005 (((-592) $) 46)) (-4186 (($ (-658 (-658 |#1|))) NIL) (($ (-790) (-790) (-1 |#1| (-592) (-592))) NIL)) (-3987 (($ (-1 |#1| |#1|) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-4601 (((-658 (-658 |#1|)) $) 58)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3183 (((-3 $ "failed") $) 41 (|has| |#1| (-388)))) (-2083 (($ $ $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1892 (($ $ |#1|) NIL)) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) (-592)) NIL) ((|#1| $ (-592) (-592) |#1|) NIL) (($ $ (-658 (-592)) (-658 (-592))) NIL)) (-2933 (($ (-658 |#1|)) NIL) (($ (-658 $)) NIL) (($ (-1280 |#1|)) 51)) (-2940 (((-141) $) NIL)) (-1625 ((|#1| $) 26 (|has| |#1| (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1778 (((-565) $) 62 (|has| |#1| (-633 (-565))))) (-3430 (((-658 (-1280 |#1|)) $) NIL (|has| |#1| (-323)))) (-2000 (((-1280 |#1|) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119))) (($ (-1280 |#1|)) NIL)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) 23) (($ $ (-592)) 44 (|has| |#1| (-388)))) (* (($ $ $) 13) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-592) $) NIL) (((-1280 |#1|) $ (-1280 |#1|)) NIL) (((-1280 |#1|) (-1280 |#1|) $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-706 |#1|) (-13 (-704 |#1| (-1280 |#1|) (-1280 |#1|)) (-10 -8 (-15 -2933 ($ (-1280 |#1|))) (IF (|has| |#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (IF (|has| |#1| (-388)) (-15 -3183 ((-3 $ "failed") $)) |noBranch|))) (-1075)) (T -706)) 
+((-3183 (*1 *1 *1) (|partial| -12 (-5 *1 (-706 *2)) (-4 *2 (-388)) (-4 *2 (-1075)))) (-2933 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1075)) (-5 *1 (-706 *3))))) 
+(-13 (-704 |#1| (-1280 |#1|) (-1280 |#1|)) (-10 -8 (-15 -2933 ($ (-1280 |#1|))) (IF (|has| |#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (IF (|has| |#1| (-388)) (-15 -3183 ((-3 $ "failed") $)) |noBranch|))) 
+((-2958 (((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|)) 25)) (-2325 (((-706 |#1|) (-706 |#1|) (-706 |#1|) |#1|) 21)) (-2542 (((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|) (-790)) 26)) (-2473 (((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|)) 14)) (-3192 (((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|)) 18) (((-706 |#1|) (-706 |#1|) (-706 |#1|)) 16)) (-1459 (((-706 |#1|) (-706 |#1|) |#1| (-706 |#1|)) 20)) (-2053 (((-706 |#1|) (-706 |#1|) (-706 |#1|)) 12)) (** (((-706 |#1|) (-706 |#1|) (-790)) 30))) 
+(((-707 |#1|) (-10 -7 (-15 -2053 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -2473 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -3192 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -3192 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -1459 ((-706 |#1|) (-706 |#1|) |#1| (-706 |#1|))) (-15 -2325 ((-706 |#1|) (-706 |#1|) (-706 |#1|) |#1|)) (-15 -2958 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -2542 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|) (-790))) (-15 ** ((-706 |#1|) (-706 |#1|) (-790)))) (-1075)) (T -707)) 
+((** (*1 *2 *2 *3) (-12 (-5 *2 (-706 *4)) (-5 *3 (-790)) (-4 *4 (-1075)) (-5 *1 (-707 *4)))) (-2542 (*1 *2 *2 *2 *2 *2 *3) (-12 (-5 *2 (-706 *4)) (-5 *3 (-790)) (-4 *4 (-1075)) (-5 *1 (-707 *4)))) (-2958 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3)))) (-2325 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3)))) (-1459 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3)))) (-3192 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3)))) (-3192 (*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3)))) (-2473 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3)))) (-2053 (*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3))))) 
+(-10 -7 (-15 -2053 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -2473 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -3192 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -3192 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -1459 ((-706 |#1|) (-706 |#1|) |#1| (-706 |#1|))) (-15 -2325 ((-706 |#1|) (-706 |#1|) (-706 |#1|) |#1|)) (-15 -2958 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -2542 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|) (-706 |#1|) (-790))) (-15 ** ((-706 |#1|) (-706 |#1|) (-790)))) 
+((-2592 ((|#2| |#2| |#4|) 25)) (-3142 (((-706 |#2|) |#3| |#4|) 31)) (-2210 (((-706 |#2|) |#2| |#4|) 30)) (-1371 (((-1280 |#2|) |#2| |#4|) 16)) (-2418 ((|#2| |#3| |#4|) 24)) (-3063 (((-706 |#2|) |#3| |#4| (-790) (-790)) 38)) (-2792 (((-706 |#2|) |#2| |#4| (-790)) 37))) 
+(((-708 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1371 ((-1280 |#2|) |#2| |#4|)) (-15 -2418 (|#2| |#3| |#4|)) (-15 -2592 (|#2| |#2| |#4|)) (-15 -2210 ((-706 |#2|) |#2| |#4|)) (-15 -2792 ((-706 |#2|) |#2| |#4| (-790))) (-15 -3142 ((-706 |#2|) |#3| |#4|)) (-15 -3063 ((-706 |#2|) |#3| |#4| (-790) (-790)))) (-1119) (-922 |#1|) (-399 |#2|) (-13 (-399 |#1|) (-10 -7 (-6 -4625)))) (T -708)) 
+((-3063 (*1 *2 *3 *4 *5 *5) (-12 (-5 *5 (-790)) (-4 *6 (-1119)) (-4 *7 (-922 *6)) (-5 *2 (-706 *7)) (-5 *1 (-708 *6 *7 *3 *4)) (-4 *3 (-399 *7)) (-4 *4 (-13 (-399 *6) (-10 -7 (-6 -4625)))))) (-3142 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *6 (-922 *5)) (-5 *2 (-706 *6)) (-5 *1 (-708 *5 *6 *3 *4)) (-4 *3 (-399 *6)) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4625)))))) (-2792 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-1119)) (-4 *3 (-922 *6)) (-5 *2 (-706 *3)) (-5 *1 (-708 *6 *3 *7 *4)) (-4 *7 (-399 *3)) (-4 *4 (-13 (-399 *6) (-10 -7 (-6 -4625)))))) (-2210 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *3 (-922 *5)) (-5 *2 (-706 *3)) (-5 *1 (-708 *5 *3 *6 *4)) (-4 *6 (-399 *3)) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4625)))))) (-2592 (*1 *2 *2 *3) (-12 (-4 *4 (-1119)) (-4 *2 (-922 *4)) (-5 *1 (-708 *4 *2 *5 *3)) (-4 *5 (-399 *2)) (-4 *3 (-13 (-399 *4) (-10 -7 (-6 -4625)))))) (-2418 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *2 (-922 *5)) (-5 *1 (-708 *5 *2 *3 *4)) (-4 *3 (-399 *2)) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4625)))))) (-1371 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *3 (-922 *5)) (-5 *2 (-1280 *3)) (-5 *1 (-708 *5 *3 *6 *4)) (-4 *6 (-399 *3)) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4625))))))) 
+(-10 -7 (-15 -1371 ((-1280 |#2|) |#2| |#4|)) (-15 -2418 (|#2| |#3| |#4|)) (-15 -2592 (|#2| |#2| |#4|)) (-15 -2210 ((-706 |#2|) |#2| |#4|)) (-15 -2792 ((-706 |#2|) |#2| |#4| (-790))) (-15 -3142 ((-706 |#2|) |#3| |#4|)) (-15 -3063 ((-706 |#2|) |#3| |#4| (-790) (-790)))) 
+((-3626 (((-2 (|:| |num| (-706 |#1|)) (|:| |den| |#1|)) (-706 |#2|)) 18)) (-2088 ((|#1| (-706 |#2|)) 9)) (-2219 (((-706 |#1|) (-706 |#2|)) 16))) 
+(((-709 |#1| |#2|) (-10 -7 (-15 -2088 (|#1| (-706 |#2|))) (-15 -2219 ((-706 |#1|) (-706 |#2|))) (-15 -3626 ((-2 (|:| |num| (-706 |#1|)) (|:| |den| |#1|)) (-706 |#2|)))) (-582) (-1021 |#1|)) (T -709)) 
+((-3626 (*1 *2 *3) (-12 (-5 *3 (-706 *5)) (-4 *5 (-1021 *4)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |num| (-706 *4)) (|:| |den| *4))) (-5 *1 (-709 *4 *5)))) (-2219 (*1 *2 *3) (-12 (-5 *3 (-706 *5)) (-4 *5 (-1021 *4)) (-4 *4 (-582)) (-5 *2 (-706 *4)) (-5 *1 (-709 *4 *5)))) (-2088 (*1 *2 *3) (-12 (-5 *3 (-706 *4)) (-4 *4 (-1021 *2)) (-4 *2 (-582)) (-5 *1 (-709 *2 *4))))) 
+(-10 -7 (-15 -2088 (|#1| (-706 |#2|))) (-15 -2219 ((-706 |#1|) (-706 |#2|))) (-15 -3626 ((-2 (|:| |num| (-706 |#1|)) (|:| |den| |#1|)) (-706 |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1800 (((-706 (-715))) NIL) (((-706 (-715)) (-1280 $)) NIL)) (-4529 (((-715) $) NIL)) (-1588 (($ $) NIL (|has| (-715) (-1211)))) (-1507 (($ $) NIL (|has| (-715) (-1211)))) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| (-715) (-373)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-715) (-323)) (|has| (-715) (-931))))) (-3743 (($ $) NIL (-3836 (-12 (|has| (-715) (-323)) (|has| (-715) (-931))) (|has| (-715) (-388))))) (-3164 (((-444 $) $) NIL (-3836 (-12 (|has| (-715) (-323)) (|has| (-715) (-931))) (|has| (-715) (-388))))) (-1442 (($ $) NIL (-12 (|has| (-715) (-1030)) (|has| (-715) (-1211))))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-715) (-323)) (|has| (-715) (-931))))) (-3652 (((-141) $ $) NIL (|has| (-715) (-323)))) (-1403 (((-790)) NIL (|has| (-715) (-394)))) (-1575 (($ $) NIL (|has| (-715) (-1211)))) (-1495 (($ $) NIL (|has| (-715) (-1211)))) (-1601 (($ $) NIL (|has| (-715) (-1211)))) (-1521 (($ $) NIL (|has| (-715) (-1211)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-715) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-715) (-1065 (-433 (-592)))))) (-2400 (((-592) $) NIL) (((-715) $) NIL) (((-433 (-592)) $) NIL (|has| (-715) (-1065 (-433 (-592)))))) (-1626 (($ (-1280 (-715))) NIL) (($ (-1280 (-715)) (-1280 $)) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-715) (-373)))) (-1586 (($ $ $) NIL (|has| (-715) (-323)))) (-4493 (((-706 (-715)) $) NIL) (((-706 (-715)) $ (-1280 $)) NIL)) (-3945 (((-706 (-715)) (-706 $)) NIL) (((-2 (|:| -3253 (-706 (-715))) (|:| |vec| (-1280 (-715)))) (-706 $) (-1280 $)) NIL) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-715) (-654 (-592)))) (((-706 (-592)) (-706 $)) NIL (|has| (-715) (-654 (-592))))) (-3657 (((-3 $ "failed") (-433 (-1187 (-715)))) NIL (|has| (-715) (-388))) (($ (-1187 (-715))) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3996 (((-715) $) 29)) (-4182 (((-3 (-433 (-592)) "failed") $) NIL (|has| (-715) (-574)))) (-2435 (((-141) $) NIL (|has| (-715) (-574)))) (-2270 (((-433 (-592)) $) NIL (|has| (-715) (-574)))) (-4175 (((-944)) NIL)) (-4290 (($) NIL (|has| (-715) (-394)))) (-1599 (($ $ $) NIL (|has| (-715) (-323)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| (-715) (-323)))) (-2667 (($) NIL (|has| (-715) (-373)))) (-3293 (((-141) $) NIL (|has| (-715) (-373)))) (-1525 (($ $) NIL (|has| (-715) (-373))) (($ $ (-790)) NIL (|has| (-715) (-373)))) (-2802 (((-141) $) NIL (-3836 (-12 (|has| (-715) (-323)) (|has| (-715) (-931))) (|has| (-715) (-388))))) (-4120 (((-2 (|:| |r| (-715)) (|:| |phi| (-715))) $) NIL (-12 (|has| (-715) (-1084)) (|has| (-715) (-1211))))) (-1435 (($) NIL (|has| (-715) (-1211)))) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| (-715) (-908 (-405)))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| (-715) (-908 (-592))))) (-4346 (((-855 (-944)) $) NIL (|has| (-715) (-373))) (((-944) $) NIL (|has| (-715) (-373)))) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (-12 (|has| (-715) (-1030)) (|has| (-715) (-1211))))) (-2793 (((-715) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| (-715) (-373)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| (-715) (-323)))) (-3504 (((-1187 (-715)) $) NIL (|has| (-715) (-388)))) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 (-715) (-715)) $) NIL)) (-3546 (((-944) $) NIL (|has| (-715) (-394)))) (-4546 (($ $) NIL (|has| (-715) (-1211)))) (-3650 (((-1187 (-715)) $) NIL)) (-2750 (($ (-658 $)) NIL (|has| (-715) (-323))) (($ $ $) NIL (|has| (-715) (-323)))) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| (-715) (-388)))) (-3703 (($) NIL (|has| (-715) (-373)) CONST)) (-1825 (($ (-944)) NIL (|has| (-715) (-394)))) (-2795 (($) NIL)) (-4506 (((-715) $) 31)) (-2951 (((-1137) $) NIL)) (-2934 (($) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| (-715) (-323)))) (-3548 (($ (-658 $)) NIL (|has| (-715) (-323))) (($ $ $) NIL (|has| (-715) (-323)))) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| (-715) (-373)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-715) (-323)) (|has| (-715) (-931))))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-715) (-323)) (|has| (-715) (-931))))) (-4500 (((-444 $) $) NIL (-3836 (-12 (|has| (-715) (-323)) (|has| (-715) (-931))) (|has| (-715) (-388))))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-715) (-323))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| (-715) (-323)))) (-3616 (((-3 $ "failed") $ $) NIL) (((-3 $ "failed") $ (-715)) NIL (|has| (-715) (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| (-715) (-323)))) (-1430 (($ $) NIL (|has| (-715) (-1211)))) (-2806 (($ $ (-1191) (-715)) NIL (|has| (-715) (-547 (-1191) (-715)))) (($ $ (-658 (-1191)) (-658 (-715))) NIL (|has| (-715) (-547 (-1191) (-715)))) (($ $ (-658 (-310 (-715)))) NIL (|has| (-715) (-325 (-715)))) (($ $ (-310 (-715))) NIL (|has| (-715) (-325 (-715)))) (($ $ (-715) (-715)) NIL (|has| (-715) (-325 (-715)))) (($ $ (-658 (-715)) (-658 (-715))) NIL (|has| (-715) (-325 (-715))))) (-2769 (((-790) $) NIL (|has| (-715) (-323)))) (-1405 (((-658 $)) NIL (|has| (-715) (-394)))) (-3927 (($ $ (-715)) NIL (|has| (-715) (-303 (-715) (-715))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| (-715) (-323)))) (-1482 (((-715)) NIL) (((-715) (-1280 $)) NIL)) (-2177 (((-3 (-790) "failed") $ $) NIL (|has| (-715) (-373))) (((-790) $) NIL (|has| (-715) (-373)))) (-3644 (($ $ (-1 (-715) (-715))) NIL) (($ $ (-1 (-715) (-715)) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-715) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-715) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-715) (-922 (-1191)))) (($ $ (-1191)) NIL (|has| (-715) (-922 (-1191)))) (($ $ (-790)) NIL (|has| (-715) (-247))) (($ $) NIL (|has| (-715) (-247)))) (-4174 (((-706 (-715)) (-1280 $) (-1 (-715) (-715))) NIL (|has| (-715) (-388)))) (-3390 (((-1187 (-715))) NIL)) (-1609 (($ $) NIL (|has| (-715) (-1211)))) (-1527 (($ $) NIL (|has| (-715) (-1211)))) (-3809 (($) NIL (|has| (-715) (-373)))) (-1594 (($ $) NIL (|has| (-715) (-1211)))) (-1515 (($ $) NIL (|has| (-715) (-1211)))) (-1581 (($ $) NIL (|has| (-715) (-1211)))) (-1501 (($ $) NIL (|has| (-715) (-1211)))) (-2231 (((-706 (-715)) (-1280 $)) NIL) (((-1280 (-715)) $) NIL) (((-706 (-715)) (-1280 $) (-1280 $)) NIL) (((-1280 (-715)) $ (-1280 $)) NIL)) (-1778 (((-565) $) NIL (|has| (-715) (-633 (-565)))) (((-191 (-237)) $) NIL (|has| (-715) (-1049))) (((-191 (-405)) $) NIL (|has| (-715) (-1049))) (((-914 (-405)) $) NIL (|has| (-715) (-633 (-914 (-405))))) (((-914 (-592)) $) NIL (|has| (-715) (-633 (-914 (-592))))) (($ (-1187 (-715))) NIL) (((-1187 (-715)) $) NIL) (($ (-1280 (-715))) NIL) (((-1280 (-715)) $) NIL)) (-2227 (($ $) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-715) (-323)) (|has| (-715) (-931))) (|has| (-715) (-373))))) (-4001 (($ (-715) (-715)) 12)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-592)) NIL) (($ (-715)) NIL) (($ (-191 (-405))) 13) (($ (-191 (-592))) 19) (($ (-191 (-715))) 28) (($ (-191 (-717))) 25) (((-191 (-405)) $) 33) (($ (-433 (-592))) NIL (-3836 (|has| (-715) (-388)) (|has| (-715) (-1065 (-433 (-592))))))) (-1517 (($ $) NIL (|has| (-715) (-373))) (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-715) (-323)) (|has| (-715) (-931))) (|has| (-715) (-169))))) (-4198 (((-1187 (-715)) $) NIL)) (-4010 (((-790)) NIL)) (-2195 (((-1280 $)) NIL)) (-1630 (($ $) NIL (|has| (-715) (-1211)))) (-1546 (($ $) NIL (|has| (-715) (-1211)))) (-2537 (((-141) $ $) NIL)) (-1617 (($ $) NIL (|has| (-715) (-1211)))) (-1533 (($ $) NIL (|has| (-715) (-1211)))) (-1642 (($ $) NIL (|has| (-715) (-1211)))) (-1559 (($ $) NIL (|has| (-715) (-1211)))) (-4575 (((-715) $) NIL (|has| (-715) (-1211)))) (-2892 (($ $) NIL (|has| (-715) (-1211)))) (-1567 (($ $) NIL (|has| (-715) (-1211)))) (-1636 (($ $) NIL (|has| (-715) (-1211)))) (-1552 (($ $) NIL (|has| (-715) (-1211)))) (-1624 (($ $) NIL (|has| (-715) (-1211)))) (-1540 (($ $) NIL (|has| (-715) (-1211)))) (-1392 (($ $) NIL (|has| (-715) (-1084)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-715) (-388)))) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-1 (-715) (-715))) NIL) (($ $ (-1 (-715) (-715)) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-715) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-715) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-715) (-922 (-1191)))) (($ $ (-1191)) NIL (|has| (-715) (-922 (-1191)))) (($ $ (-790)) NIL (|has| (-715) (-247))) (($ $) NIL (|has| (-715) (-247)))) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL (|has| (-715) (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ $) NIL (|has| (-715) (-1211))) (($ $ (-433 (-592))) NIL (-12 (|has| (-715) (-1030)) (|has| (-715) (-1211)))) (($ $ (-592)) NIL (|has| (-715) (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ (-715) $) NIL) (($ $ (-715)) NIL) (($ (-433 (-592)) $) NIL (|has| (-715) (-388))) (($ $ (-433 (-592))) NIL (|has| (-715) (-388))))) 
+(((-710) (-13 (-413) (-188 (-715)) (-10 -8 (-15 -1683 ($ (-191 (-405)))) (-15 -1683 ($ (-191 (-592)))) (-15 -1683 ($ (-191 (-715)))) (-15 -1683 ($ (-191 (-717)))) (-15 -1683 ((-191 (-405)) $))))) (T -710)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-191 (-405))) (-5 *1 (-710)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-191 (-592))) (-5 *1 (-710)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-191 (-715))) (-5 *1 (-710)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-191 (-717))) (-5 *1 (-710)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-191 (-405))) (-5 *1 (-710))))) 
+(-13 (-413) (-188 (-715)) (-10 -8 (-15 -1683 ($ (-191 (-405)))) (-15 -1683 ($ (-191 (-592)))) (-15 -1683 ($ (-191 (-715)))) (-15 -1683 ($ (-191 (-717)))) (-15 -1683 ((-191 (-405)) $)))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-4125 (($ (-1 (-141) |#1|) $) 42 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) 52 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1461 (($ $) 58)) (-1360 (($ $) 55 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ |#1| $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) 43 (|has| $ (-6 -4625)))) (-4459 (($ |#1| $) 54 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 51 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4625)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37) (($ |#1| $ (-790)) 59)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 48)) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-2043 (((-658 (-2 (|:| -3552 |#1|) (|:| -3452 (-790)))) $) 57)) (-1653 (($) 46) (($ (-658 |#1|)) 45)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 47)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-711 |#1|) (-1311) (-1119)) (T -711)) 
+((-2113 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-711 *2)) (-4 *2 (-1119)))) (-1461 (*1 *1 *1) (-12 (-4 *1 (-711 *2)) (-4 *2 (-1119)))) (-2043 (*1 *2 *1) (-12 (-4 *1 (-711 *3)) (-4 *3 (-1119)) (-5 *2 (-658 (-2 (|:| -3552 *3) (|:| -3452 (-790)))))))) 
+(-13 (-249 |t#1|) (-10 -8 (-15 -2113 ($ |t#1| $ (-790))) (-15 -1461 ($ $)) (-15 -2043 ((-658 (-2 (|:| -3552 |t#1|) (|:| -3452 (-790)))) $)))) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-249 |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-4293 (((-658 |#1|) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))) (-592)) 46)) (-1841 ((|#1| |#1| (-592)) 45)) (-3548 ((|#1| |#1| |#1| (-592)) 35)) (-4500 (((-658 |#1|) |#1| (-592)) 38)) (-3473 ((|#1| |#1| (-592) |#1| (-592)) 32)) (-1404 (((-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))) |#1| (-592)) 44))) 
+(((-712 |#1|) (-10 -7 (-15 -3548 (|#1| |#1| |#1| (-592))) (-15 -1841 (|#1| |#1| (-592))) (-15 -4500 ((-658 |#1|) |#1| (-592))) (-15 -1404 ((-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))) |#1| (-592))) (-15 -4293 ((-658 |#1|) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))) (-592))) (-15 -3473 (|#1| |#1| (-592) |#1| (-592)))) (-1255 (-592))) (T -712)) 
+((-3473 (*1 *2 *2 *3 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-712 *2)) (-4 *2 (-1255 *3)))) (-4293 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| -4500 *5) (|:| -4525 (-592))))) (-5 *4 (-592)) (-4 *5 (-1255 *4)) (-5 *2 (-658 *5)) (-5 *1 (-712 *5)))) (-1404 (*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-5 *2 (-658 (-2 (|:| -4500 *3) (|:| -4525 *4)))) (-5 *1 (-712 *3)) (-4 *3 (-1255 *4)))) (-4500 (*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-5 *2 (-658 *3)) (-5 *1 (-712 *3)) (-4 *3 (-1255 *4)))) (-1841 (*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-712 *2)) (-4 *2 (-1255 *3)))) (-3548 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-712 *2)) (-4 *2 (-1255 *3))))) 
+(-10 -7 (-15 -3548 (|#1| |#1| |#1| (-592))) (-15 -1841 (|#1| |#1| (-592))) (-15 -4500 ((-658 |#1|) |#1| (-592))) (-15 -1404 ((-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))) |#1| (-592))) (-15 -4293 ((-658 |#1|) (-658 (-2 (|:| -4500 |#1|) (|:| -4525 (-592)))) (-592))) (-15 -3473 (|#1| |#1| (-592) |#1| (-592)))) 
+((-3765 (((-1 (-971 (-237)) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237) (-237))) 17)) (-3035 (((-1150 (-237)) (-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-658 (-278))) 38) (((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-658 (-278))) 40) (((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-3 (-1 (-237) (-237) (-237) (-237)) "undefined") (-1113 (-237)) (-1113 (-237)) (-658 (-278))) 42)) (-2092 (((-1150 (-237)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-658 (-278))) NIL)) (-2331 (((-1150 (-237)) (-1 (-237) (-237) (-237)) (-3 (-1 (-237) (-237) (-237) (-237)) "undefined") (-1113 (-237)) (-1113 (-237)) (-658 (-278))) 43))) 
+(((-713) (-10 -7 (-15 -3035 ((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-3 (-1 (-237) (-237) (-237) (-237)) "undefined") (-1113 (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -3035 ((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -3035 ((-1150 (-237)) (-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -2331 ((-1150 (-237)) (-1 (-237) (-237) (-237)) (-3 (-1 (-237) (-237) (-237) (-237)) "undefined") (-1113 (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -2092 ((-1150 (-237)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -3765 ((-1 (-971 (-237)) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237) (-237)))))) (T -713)) 
+((-3765 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1 (-237) (-237) (-237) (-237))) (-5 *2 (-1 (-971 (-237)) (-237) (-237))) (-5 *1 (-713)))) (-2092 (*1 *2 *3 *3 *3 *4 *5 *6) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-713)))) (-2331 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-3 (-1 (-237) (-237) (-237) (-237)) "undefined")) (-5 *5 (-1113 (-237))) (-5 *6 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-713)))) (-3035 (*1 *2 *2 *3 *4 *4 *5) (-12 (-5 *2 (-1150 (-237))) (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-237))) (-5 *5 (-658 (-278))) (-5 *1 (-713)))) (-3035 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-237))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-713)))) (-3035 (*1 *2 *3 *3 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-3 (-1 (-237) (-237) (-237) (-237)) "undefined")) (-5 *5 (-1113 (-237))) (-5 *6 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-713))))) 
+(-10 -7 (-15 -3035 ((-1150 (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-3 (-1 (-237) (-237) (-237) (-237)) "undefined") (-1113 (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -3035 ((-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -3035 ((-1150 (-237)) (-1150 (-237)) (-1 (-971 (-237)) (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -2331 ((-1150 (-237)) (-1 (-237) (-237) (-237)) (-3 (-1 (-237) (-237) (-237) (-237)) "undefined") (-1113 (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -2092 ((-1150 (-237)) (-332 (-592)) (-332 (-592)) (-332 (-592)) (-1 (-237) (-237)) (-1113 (-237)) (-658 (-278)))) (-15 -3765 ((-1 (-971 (-237)) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237)) (-1 (-237) (-237) (-237) (-237))))) 
+((-4500 (((-444 (-1187 |#4|)) (-1187 |#4|)) 73) (((-444 |#4|) |#4|) 215))) 
+(((-714 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4500 ((-444 |#4|) |#4|)) (-15 -4500 ((-444 (-1187 |#4|)) (-1187 |#4|)))) (-869) (-815) (-373) (-977 |#3| |#2| |#1|)) (T -714)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-373)) (-4 *7 (-977 *6 *5 *4)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-714 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) (-4500 (*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-714 *4 *5 *6 *3)) (-4 *3 (-977 *6 *5 *4))))) 
+(-10 -7 (-15 -4500 ((-444 |#4|) |#4|)) (-15 -4500 ((-444 (-1187 |#4|)) (-1187 |#4|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 84)) (-1505 (((-592) $) 30)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2306 (($ $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1442 (($ $) NIL)) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL)) (-3001 (($) NIL T CONST)) (-1755 (($ $) NIL)) (-4368 (((-3 (-592) "failed") $) 73) (((-3 (-433 (-592)) "failed") $) 26) (((-3 (-405) "failed") $) 70)) (-2400 (((-592) $) 75) (((-433 (-592)) $) 67) (((-405) $) 68)) (-1586 (($ $ $) 96)) (-3371 (((-3 $ "failed") $) 87)) (-1599 (($ $ $) 95)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-4047 (((-944)) 77) (((-944) (-944)) 76)) (-1691 (((-141) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL)) (-4346 (((-592) $) NIL)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL)) (-2793 (($ $) NIL)) (-1324 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1464 (((-592) (-592)) 81) (((-592)) 82)) (-1837 (($ $ $) NIL) (($) NIL (-12 (-3252 (|has| $ (-6 -4608))) (-3252 (|has| $ (-6 -4616)))))) (-3516 (((-592) (-592)) 79) (((-592)) 80)) (-3319 (($ $ $) NIL) (($) NIL (-12 (-3252 (|has| $ (-6 -4608))) (-3252 (|has| $ (-6 -4616)))))) (-2950 (((-592) $) 16)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 91)) (-1867 (((-944) (-592)) NIL (|has| $ (-6 -4616)))) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL)) (-2039 (($ $) NIL)) (-4540 (($ (-592) (-592)) NIL) (($ (-592) (-592) (-944)) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) 92)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3215 (((-592) $) 22)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 94)) (-4406 (((-944)) NIL) (((-944) (-944)) NIL (|has| $ (-6 -4616)))) (-1738 (((-944) (-592)) NIL (|has| $ (-6 -4616)))) (-1778 (((-405) $) NIL) (((-237) $) NIL) (((-914 (-405)) $) NIL)) (-1683 (((-877) $) 52) (($ (-592)) 63) (($ $) NIL) (($ (-433 (-592))) 66) (($ (-592)) 63) (($ (-433 (-592))) 66) (($ (-405)) 60) (((-405) $) 50) (($ (-717)) 55)) (-4010 (((-790)) 103)) (-4164 (($ (-592) (-592) (-944)) 44)) (-2744 (($ $) NIL)) (-3671 (((-944)) NIL) (((-944) (-944)) NIL (|has| $ (-6 -4616)))) (-4226 (((-944)) 35) (((-944) (-944)) 78)) (-2537 (((-141) $ $) NIL)) (-1392 (($ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 32 T CONST)) (-4257 (($) 17 T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 83)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 101)) (-3313 (($ $ $) 65)) (-3306 (($ $) 99) (($ $ $) 100)) (-3300 (($ $ $) 98)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL) (($ $ (-433 (-592))) 90)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 97) (($ $ $) 88) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL))) 
+(((-715) (-13 (-430) (-413) (-388) (-1065 (-405)) (-1065 (-433 (-592))) (-171) (-10 -8 (-15 -4047 ((-944) (-944))) (-15 -4047 ((-944))) (-15 -4226 ((-944) (-944))) (-15 -4226 ((-944))) (-15 -3516 ((-592) (-592))) (-15 -3516 ((-592))) (-15 -1464 ((-592) (-592))) (-15 -1464 ((-592))) (-15 -1683 ((-405) $)) (-15 -1683 ($ (-717))) (-15 -2950 ((-592) $)) (-15 -3215 ((-592) $)) (-15 -4164 ($ (-592) (-592) (-944)))))) (T -715)) 
+((-4226 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-715)))) (-3215 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) (-2950 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) (-4047 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-715)))) (-4047 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-715)))) (-4226 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-715)))) (-3516 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) (-3516 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) (-1464 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) (-1464 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-405)) (-5 *1 (-715)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-717)) (-5 *1 (-715)))) (-4164 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-592)) (-5 *3 (-944)) (-5 *1 (-715))))) 
+(-13 (-430) (-413) (-388) (-1065 (-405)) (-1065 (-433 (-592))) (-171) (-10 -8 (-15 -4047 ((-944) (-944))) (-15 -4047 ((-944))) (-15 -4226 ((-944) (-944))) (-15 -4226 ((-944))) (-15 -3516 ((-592) (-592))) (-15 -3516 ((-592))) (-15 -1464 ((-592) (-592))) (-15 -1464 ((-592))) (-15 -1683 ((-405) $)) (-15 -1683 ($ (-717))) (-15 -2950 ((-592) $)) (-15 -3215 ((-592) $)) (-15 -4164 ($ (-592) (-592) (-944))))) 
+((-2275 (((-706 |#1|) (-706 |#1|) |#1| |#1|) 66)) (-3052 (((-706 |#1|) (-706 |#1|) |#1|) 49)) (-1889 (((-706 |#1|) (-706 |#1|) |#1|) 67)) (-1816 (((-706 |#1|) (-706 |#1|)) 50)) (-1852 (((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|) 65))) 
+(((-716 |#1|) (-10 -7 (-15 -1816 ((-706 |#1|) (-706 |#1|))) (-15 -3052 ((-706 |#1|) (-706 |#1|) |#1|)) (-15 -1889 ((-706 |#1|) (-706 |#1|) |#1|)) (-15 -2275 ((-706 |#1|) (-706 |#1|) |#1| |#1|)) (-15 -1852 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|))) (-323)) (T -716)) 
+((-1852 (*1 *2 *3 *3) (-12 (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-716 *3)) (-4 *3 (-323)))) (-2275 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-323)) (-5 *1 (-716 *3)))) (-1889 (*1 *2 *2 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-323)) (-5 *1 (-716 *3)))) (-3052 (*1 *2 *2 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-323)) (-5 *1 (-716 *3)))) (-1816 (*1 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-323)) (-5 *1 (-716 *3))))) 
+(-10 -7 (-15 -1816 ((-706 |#1|) (-706 |#1|))) (-15 -3052 ((-706 |#1|) (-706 |#1|) |#1|)) (-15 -1889 ((-706 |#1|) (-706 |#1|) |#1|)) (-15 -2275 ((-706 |#1|) (-706 |#1|) |#1| |#1|)) (-15 -1852 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2204 (($ $ $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1686 (($ $ $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL)) (-3651 (($ $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) 27)) (-2400 (((-592) $) 25)) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4182 (((-3 (-433 (-592)) "failed") $) NIL)) (-2435 (((-141) $) NIL)) (-2270 (((-433 (-592)) $) NIL)) (-4290 (($ $) NIL) (($) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-2520 (($ $ $ $) NIL)) (-1592 (($ $ $) NIL)) (-1691 (((-141) $) NIL)) (-3870 (($ $ $) NIL)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL)) (-3558 (((-141) $) NIL)) (-3372 (((-141) $) NIL)) (-3921 (((-3 $ "failed") $) NIL)) (-1324 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3260 (($ $ $ $) NIL)) (-1837 (($ $ $) NIL)) (-3207 (((-944) (-944)) 10) (((-944)) 9)) (-3319 (($ $ $) NIL)) (-4561 (($ $) NIL)) (-4233 (($ $) NIL)) (-2750 (($ (-658 $)) NIL) (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-4092 (($ $ $) NIL)) (-3703 (($) NIL T CONST)) (-4185 (($ $) NIL)) (-2951 (((-1137) $) NIL) (($ $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ (-658 $)) NIL) (($ $ $) NIL)) (-2283 (($ $) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3554 (((-141) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL) (($ $ (-790)) NIL)) (-1676 (($ $) NIL)) (-4599 (($ $) NIL)) (-1778 (((-237) $) NIL) (((-405) $) NIL) (((-914 (-592)) $) NIL) (((-565) $) NIL) (((-592) $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) 24) (($ $) NIL) (($ (-592)) 24) (((-332 $) (-332 (-592))) 18)) (-4010 (((-790)) NIL)) (-3911 (((-141) $ $) NIL)) (-4042 (($ $ $) NIL)) (-4226 (($) NIL)) (-2537 (((-141) $ $) NIL)) (-1475 (($ $ $ $) NIL)) (-1392 (($ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $) NIL) (($ $ (-790)) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL))) 
+(((-717) (-13 (-413) (-574) (-10 -8 (-15 -3207 ((-944) (-944))) (-15 -3207 ((-944))) (-15 -1683 ((-332 $) (-332 (-592))))))) (T -717)) 
+((-3207 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-717)))) (-3207 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-717)))) (-1683 (*1 *2 *3) (-12 (-5 *3 (-332 (-592))) (-5 *2 (-332 (-717))) (-5 *1 (-717))))) 
+(-13 (-413) (-574) (-10 -8 (-15 -3207 ((-944) (-944))) (-15 -3207 ((-944))) (-15 -1683 ((-332 $) (-332 (-592)))))) 
+((-4367 (((-1 |#4| |#2| |#3|) |#1| (-1191) (-1191)) 19)) (-3469 (((-1 |#4| |#2| |#3|) (-1191)) 12))) 
+(((-718 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3469 ((-1 |#4| |#2| |#3|) (-1191))) (-15 -4367 ((-1 |#4| |#2| |#3|) |#1| (-1191) (-1191)))) (-633 (-565)) (-1225) (-1225) (-1225)) (T -718)) 
+((-4367 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-718 *3 *5 *6 *7)) (-4 *3 (-633 (-565))) (-4 *5 (-1225)) (-4 *6 (-1225)) (-4 *7 (-1225)))) (-3469 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-718 *4 *5 *6 *7)) (-4 *4 (-633 (-565))) (-4 *5 (-1225)) (-4 *6 (-1225)) (-4 *7 (-1225))))) 
+(-10 -7 (-15 -3469 ((-1 |#4| |#2| |#3|) (-1191))) (-15 -4367 ((-1 |#4| |#2| |#3|) |#1| (-1191) (-1191)))) 
+((-1641 (((-141) $ $) NIL)) (-1632 (((-1285) $ (-790)) 14)) (-1721 (((-790) $) 12)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 18) ((|#1| $) 15) (($ |#1|) 23)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 25)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 24))) 
+(((-719 |#1|) (-13 (-159) (-632 |#1|) (-10 -8 (-15 -1683 ($ |#1|)))) (-1119)) (T -719)) 
+((-1683 (*1 *1 *2) (-12 (-5 *1 (-719 *2)) (-4 *2 (-1119))))) 
+(-13 (-159) (-632 |#1|) (-10 -8 (-15 -1683 ($ |#1|)))) 
+((-3508 (((-1 (-237) (-237) (-237)) |#1| (-1191) (-1191)) 33) (((-1 (-237) (-237)) |#1| (-1191)) 38))) 
+(((-720 |#1|) (-10 -7 (-15 -3508 ((-1 (-237) (-237)) |#1| (-1191))) (-15 -3508 ((-1 (-237) (-237) (-237)) |#1| (-1191) (-1191)))) (-633 (-565))) (T -720)) 
+((-3508 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-1 (-237) (-237) (-237))) (-5 *1 (-720 *3)) (-4 *3 (-633 (-565))))) (-3508 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-1 (-237) (-237))) (-5 *1 (-720 *3)) (-4 *3 (-633 (-565)))))) 
+(-10 -7 (-15 -3508 ((-1 (-237) (-237)) |#1| (-1191))) (-15 -3508 ((-1 (-237) (-237) (-237)) |#1| (-1191) (-1191)))) 
+((-1325 (((-1191) |#1| (-1191) (-658 (-1191))) 9) (((-1191) |#1| (-1191) (-1191) (-1191)) 12) (((-1191) |#1| (-1191) (-1191)) 11) (((-1191) |#1| (-1191)) 10))) 
+(((-721 |#1|) (-10 -7 (-15 -1325 ((-1191) |#1| (-1191))) (-15 -1325 ((-1191) |#1| (-1191) (-1191))) (-15 -1325 ((-1191) |#1| (-1191) (-1191) (-1191))) (-15 -1325 ((-1191) |#1| (-1191) (-658 (-1191))))) (-633 (-565))) (T -721)) 
+((-1325 (*1 *2 *3 *2 *4) (-12 (-5 *4 (-658 (-1191))) (-5 *2 (-1191)) (-5 *1 (-721 *3)) (-4 *3 (-633 (-565))))) (-1325 (*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-721 *3)) (-4 *3 (-633 (-565))))) (-1325 (*1 *2 *3 *2 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-721 *3)) (-4 *3 (-633 (-565))))) (-1325 (*1 *2 *3 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-721 *3)) (-4 *3 (-633 (-565)))))) 
+(-10 -7 (-15 -1325 ((-1191) |#1| (-1191))) (-15 -1325 ((-1191) |#1| (-1191) (-1191))) (-15 -1325 ((-1191) |#1| (-1191) (-1191) (-1191))) (-15 -1325 ((-1191) |#1| (-1191) (-658 (-1191))))) 
+((-3139 (((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|) 9))) 
+(((-722 |#1| |#2|) (-10 -7 (-15 -3139 ((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|))) (-1225) (-1225)) (T -722)) 
+((-3139 (*1 *2 *3 *4) (-12 (-5 *2 (-2 (|:| |part1| *3) (|:| |part2| *4))) (-5 *1 (-722 *3 *4)) (-4 *3 (-1225)) (-4 *4 (-1225))))) 
+(-10 -7 (-15 -3139 ((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|))) 
+((-4490 (((-1 |#3| |#2|) (-1191)) 11)) (-4367 (((-1 |#3| |#2|) |#1| (-1191)) 21))) 
+(((-723 |#1| |#2| |#3|) (-10 -7 (-15 -4490 ((-1 |#3| |#2|) (-1191))) (-15 -4367 ((-1 |#3| |#2|) |#1| (-1191)))) (-633 (-565)) (-1225) (-1225)) (T -723)) 
+((-4367 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-1 *6 *5)) (-5 *1 (-723 *3 *5 *6)) (-4 *3 (-633 (-565))) (-4 *5 (-1225)) (-4 *6 (-1225)))) (-4490 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 *6 *5)) (-5 *1 (-723 *4 *5 *6)) (-4 *4 (-633 (-565))) (-4 *5 (-1225)) (-4 *6 (-1225))))) 
+(-10 -7 (-15 -4490 ((-1 |#3| |#2|) (-1191))) (-15 -4367 ((-1 |#3| |#2|) |#1| (-1191)))) 
+((-3424 (((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 (-1187 |#4|)) (-658 |#3|) (-658 |#4|) (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| |#4|)))) (-658 (-790)) (-1280 (-658 (-1187 |#3|))) |#3|) 58)) (-3497 (((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 (-1187 |#3|)) (-658 |#3|) (-658 |#4|) (-658 (-790)) |#3|) 71)) (-2868 (((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 |#3|) (-658 (-790)) (-658 (-1187 |#4|)) (-1280 (-658 (-1187 |#3|))) |#3|) 32))) 
+(((-724 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2868 ((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 |#3|) (-658 (-790)) (-658 (-1187 |#4|)) (-1280 (-658 (-1187 |#3|))) |#3|)) (-15 -3497 ((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 (-1187 |#3|)) (-658 |#3|) (-658 |#4|) (-658 (-790)) |#3|)) (-15 -3424 ((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 (-1187 |#4|)) (-658 |#3|) (-658 |#4|) (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| |#4|)))) (-658 (-790)) (-1280 (-658 (-1187 |#3|))) |#3|))) (-815) (-869) (-323) (-977 |#3| |#1| |#2|)) (T -724)) 
+((-3424 (*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| -12 (-5 *2 (-658 (-1187 *13))) (-5 *3 (-1187 *13)) (-5 *4 (-658 *12)) (-5 *5 (-658 *10)) (-5 *6 (-658 *13)) (-5 *7 (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| *13))))) (-5 *8 (-658 (-790))) (-5 *9 (-1280 (-658 (-1187 *10)))) (-4 *12 (-869)) (-4 *10 (-323)) (-4 *13 (-977 *10 *11 *12)) (-4 *11 (-815)) (-5 *1 (-724 *11 *12 *10 *13)))) (-3497 (*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| -12 (-5 *4 (-658 *11)) (-5 *5 (-658 (-1187 *9))) (-5 *6 (-658 *9)) (-5 *7 (-658 *12)) (-5 *8 (-658 (-790))) (-4 *11 (-869)) (-4 *9 (-323)) (-4 *12 (-977 *9 *10 *11)) (-4 *10 (-815)) (-5 *2 (-658 (-1187 *12))) (-5 *1 (-724 *10 *11 *9 *12)) (-5 *3 (-1187 *12)))) (-2868 (*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| -12 (-5 *2 (-658 (-1187 *11))) (-5 *3 (-1187 *11)) (-5 *4 (-658 *10)) (-5 *5 (-658 *8)) (-5 *6 (-658 (-790))) (-5 *7 (-1280 (-658 (-1187 *8)))) (-4 *10 (-869)) (-4 *8 (-323)) (-4 *11 (-977 *8 *9 *10)) (-4 *9 (-815)) (-5 *1 (-724 *9 *10 *8 *11))))) 
+(-10 -7 (-15 -2868 ((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 |#3|) (-658 (-790)) (-658 (-1187 |#4|)) (-1280 (-658 (-1187 |#3|))) |#3|)) (-15 -3497 ((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 (-1187 |#3|)) (-658 |#3|) (-658 |#4|) (-658 (-790)) |#3|)) (-15 -3424 ((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-658 |#2|) (-658 (-1187 |#4|)) (-658 |#3|) (-658 |#4|) (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| |#4|)))) (-658 (-790)) (-1280 (-658 (-1187 |#3|))) |#3|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-4593 (($ $) 40)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-4526 (($ |#1| (-790)) 38)) (-4206 (((-790) $) 42)) (-4579 ((|#1| $) 41)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-4525 (((-790) $) 43)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 37 (|has| |#1| (-194)))) (-1937 ((|#1| $ (-790)) 39)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 45) (($ |#1| $) 44))) 
+(((-725 |#1|) (-1311) (-1075)) (T -725)) 
+((-4525 (*1 *2 *1) (-12 (-4 *1 (-725 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) (-4206 (*1 *2 *1) (-12 (-4 *1 (-725 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) (-4579 (*1 *2 *1) (-12 (-4 *1 (-725 *2)) (-4 *2 (-1075)))) (-4593 (*1 *1 *1) (-12 (-4 *1 (-725 *2)) (-4 *2 (-1075)))) (-1937 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-725 *2)) (-4 *2 (-1075)))) (-4526 (*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-725 *2)) (-4 *2 (-1075))))) 
+(-13 (-1075) (-140 |t#1| |t#1|) (-10 -8 (IF (|has| |t#1| (-194)) (-6 (-43 |t#1|)) |noBranch|) (-15 -4525 ((-790) $)) (-15 -4206 ((-790) $)) (-15 -4579 (|t#1| $)) (-15 -4593 ($ $)) (-15 -1937 (|t#1| $ (-790))) (-15 -4526 ($ |t#1| (-790))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-194)) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-734 |#1|) |has| |#1| (-194)) ((-743) . T) ((-1081 |#1|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-2731 ((|#6| (-1 |#4| |#1|) |#3|) 23))) 
+(((-726 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2731 (|#6| (-1 |#4| |#1|) |#3|))) (-582) (-1255 |#1|) (-1255 (-433 |#2|)) (-582) (-1255 |#4|) (-1255 (-433 |#5|))) (T -726)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-582)) (-4 *7 (-582)) (-4 *6 (-1255 *5)) (-4 *2 (-1255 (-433 *8))) (-5 *1 (-726 *5 *6 *4 *7 *8 *2)) (-4 *4 (-1255 (-433 *6))) (-4 *8 (-1255 *7))))) 
+(-10 -7 (-15 -2731 (|#6| (-1 |#4| |#1|) |#3|))) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1805 (((-1173) (-877)) 31)) (-3536 (((-1285) (-1173)) 28)) (-1807 (((-1173) (-877)) 24)) (-2609 (((-1173) (-877)) 25)) (-1683 (((-877) $) NIL) (((-1173) (-877)) 23)) (-3255 (((-141) $ $) NIL))) 
+(((-727) (-13 (-1119) (-10 -7 (-15 -1683 ((-1173) (-877))) (-15 -1807 ((-1173) (-877))) (-15 -2609 ((-1173) (-877))) (-15 -1805 ((-1173) (-877))) (-15 -3536 ((-1285) (-1173)))))) (T -727)) 
+((-1683 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-727)))) (-1807 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-727)))) (-2609 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-727)))) (-1805 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-727)))) (-3536 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-727))))) 
+(-13 (-1119) (-10 -7 (-15 -1683 ((-1173) (-877))) (-15 -1807 ((-1173) (-877))) (-15 -2609 ((-1173) (-877))) (-15 -1805 ((-1173) (-877))) (-15 -3536 ((-1285) (-1173))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-1586 (($ $ $) NIL)) (-3657 (($ |#1| |#2|) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-3558 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1704 ((|#2| $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2314 (((-3 $ "failed") $ $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) ((|#1| $) NIL)) (-4010 (((-790)) NIL)) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL))) 
+(((-728 |#1| |#2| |#3| |#4| |#5|) (-13 (-388) (-10 -8 (-15 -1704 (|#2| $)) (-15 -1683 (|#1| $)) (-15 -3657 ($ |#1| |#2|)) (-15 -2314 ((-3 $ "failed") $ $)))) (-194) (-23) (-1 |#1| |#1| |#2|) (-1 (-3 |#2| "failed") |#2| |#2|) (-1 (-3 |#1| "failed") |#1| |#1| |#2|)) (T -728)) 
+((-1704 (*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-728 *3 *2 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) (-1683 (*1 *2 *1) (-12 (-4 *2 (-194)) (-5 *1 (-728 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3657 (*1 *1 *2 *3) (-12 (-5 *1 (-728 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2314 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-728 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
+(-13 (-388) (-10 -8 (-15 -1704 (|#2| $)) (-15 -1683 (|#1| $)) (-15 -3657 ($ |#1| |#2|)) (-15 -2314 ((-3 $ "failed") $ $)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 30)) (-2651 (((-1280 |#1|) $ (-790)) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-2085 (($ (-1187 |#1|)) NIL)) (-4492 (((-1187 $) $ (-1103)) NIL) (((-1187 |#1|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1103))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3250 (($ $ $) NIL (|has| |#1| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1403 (((-790)) 46 (|has| |#1| (-394)))) (-1696 (($ $ (-790)) NIL)) (-1498 (($ $ (-790)) NIL)) (-1714 ((|#2| |#2|) 43)) (-1504 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-477)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-1103) "failed") $) NIL)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-1103) $) NIL)) (-1544 (($ $ $ (-1103)) NIL (|has| |#1| (-194))) ((|#1| $ $) NIL (|has| |#1| (-194)))) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) 33)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3657 (($ |#2|) 41)) (-3371 (((-3 $ "failed") $) 84)) (-4290 (($) 50 (|has| |#1| (-394)))) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-3213 (($ $ $) NIL)) (-2133 (($ $ $) NIL (|has| |#1| (-582)))) (-4369 (((-2 (|:| -1487 |#1|) (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ (-1103)) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-1777 (((-986 $)) 78)) (-4209 (($ $ |#1| (-790) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1103) (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1103) (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-4346 (((-790) $ $) NIL (|has| |#1| (-582)))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-1165)))) (-4533 (($ (-1187 |#1|) (-1103)) NIL) (($ (-1187 $) (-1103)) NIL)) (-3990 (($ $ (-790)) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) 76) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1103)) NIL) (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-1704 ((|#2|) 44)) (-4206 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-790) (-790)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2070 (((-1187 |#1|) $) NIL)) (-3254 (((-3 (-1103) "failed") $) NIL)) (-3546 (((-944) $) NIL (|has| |#1| (-394)))) (-3650 ((|#2| $) 40)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) 28)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-3768 (((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790)) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-1103)) (|:| -3215 (-790))) "failed") $) NIL)) (-3162 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3703 (($) NIL (|has| |#1| (-1165)) CONST)) (-1825 (($ (-944)) NIL (|has| |#1| (-394)))) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-4068 (($ $) 77 (|has| |#1| (-373)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) 83 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1103) |#1|) NIL) (($ $ (-658 (-1103)) (-658 |#1|)) NIL) (($ $ (-1103) $) NIL) (($ $ (-658 (-1103)) (-658 $)) NIL)) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-3927 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-433 $) (-433 $) (-433 $)) NIL (|has| |#1| (-582))) ((|#1| (-433 $) |#1|) NIL (|has| |#1| (-388))) (((-433 $) $ (-433 $)) NIL (|has| |#1| (-582)))) (-4510 (((-3 $ "failed") $ (-790)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 85 (|has| |#1| (-388)))) (-1482 (($ $ (-1103)) NIL (|has| |#1| (-194))) ((|#1| $) NIL (|has| |#1| (-194)))) (-3644 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-4525 (((-790) $) 31) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-1103) (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) NIL (|has| |#1| (-477))) (($ $ (-1103)) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-3460 (((-986 $)) 35)) (-1528 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582))) (((-3 (-433 $) "failed") (-433 $) $) NIL (|has| |#1| (-582)))) (-1683 (((-877) $) 60) (($ (-592)) NIL) (($ |#1|) 57) (($ (-1103)) NIL) (($ |#2|) 67) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) 62) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 20 T CONST)) (-3784 (((-1280 |#1|) $) 74)) (-2785 (($ (-1280 |#1|)) 49)) (-4257 (($) 8 T CONST)) (-1940 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1962 (((-1280 |#1|) $) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) 68)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) 71) (($ $ $) NIL)) (-3300 (($ $ $) 32)) (** (($ $ (-944)) NIL) (($ $ (-790)) 79)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 56) (($ $ $) 73) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 54) (($ $ |#1|) NIL))) 
+(((-729 |#1| |#2|) (-13 (-1255 |#1|) (-10 -8 (-15 -1714 (|#2| |#2|)) (-15 -1704 (|#2|)) (-15 -3657 ($ |#2|)) (-15 -3650 (|#2| $)) (-15 -1683 ($ |#2|)) (-15 -3784 ((-1280 |#1|) $)) (-15 -2785 ($ (-1280 |#1|))) (-15 -1962 ((-1280 |#1|) $)) (-15 -1777 ((-986 $))) (-15 -3460 ((-986 $))) (IF (|has| |#1| (-373)) (-15 -4068 ($ $)) |noBranch|) (IF (|has| |#1| (-394)) (-6 (-394)) |noBranch|))) (-1075) (-1255 |#1|)) (T -729)) 
+((-1714 (*1 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-729 *3 *2)) (-4 *2 (-1255 *3)))) (-1704 (*1 *2) (-12 (-4 *2 (-1255 *3)) (-5 *1 (-729 *3 *2)) (-4 *3 (-1075)))) (-3657 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-729 *3 *2)) (-4 *2 (-1255 *3)))) (-3650 (*1 *2 *1) (-12 (-4 *2 (-1255 *3)) (-5 *1 (-729 *3 *2)) (-4 *3 (-1075)))) (-1683 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-729 *3 *2)) (-4 *2 (-1255 *3)))) (-3784 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-1280 *3)) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3)))) (-2785 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1075)) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3)))) (-1962 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-1280 *3)) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3)))) (-1777 (*1 *2) (-12 (-4 *3 (-1075)) (-5 *2 (-986 (-729 *3 *4))) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3)))) (-3460 (*1 *2) (-12 (-4 *3 (-1075)) (-5 *2 (-986 (-729 *3 *4))) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3)))) (-4068 (*1 *1 *1) (-12 (-4 *2 (-373)) (-4 *2 (-1075)) (-5 *1 (-729 *2 *3)) (-4 *3 (-1255 *2))))) 
+(-13 (-1255 |#1|) (-10 -8 (-15 -1714 (|#2| |#2|)) (-15 -1704 (|#2|)) (-15 -3657 ($ |#2|)) (-15 -3650 (|#2| $)) (-15 -1683 ($ |#2|)) (-15 -3784 ((-1280 |#1|) $)) (-15 -2785 ($ (-1280 |#1|))) (-15 -1962 ((-1280 |#1|) $)) (-15 -1777 ((-986 $))) (-15 -3460 ((-986 $))) (IF (|has| |#1| (-373)) (-15 -4068 ($ $)) |noBranch|) (IF (|has| |#1| (-394)) (-6 (-394)) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-1825 ((|#1| $) 13)) (-2951 (((-1137) $) NIL)) (-3215 ((|#2| $) 12)) (-4466 (($ |#1| |#2|) 16)) (-1683 (((-877) $) NIL) (($ (-2 (|:| -1825 |#1|) (|:| -3215 |#2|))) 15) (((-2 (|:| -1825 |#1|) (|:| -3215 |#2|)) $) 14)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 11))) 
+(((-730 |#1| |#2| |#3|) (-13 (-869) (-10 -8 (-15 -3215 (|#2| $)) (-15 -1825 (|#1| $)) (-15 -1683 ($ (-2 (|:| -1825 |#1|) (|:| -3215 |#2|)))) (-15 -1683 ((-2 (|:| -1825 |#1|) (|:| -3215 |#2|)) $)) (-15 -4466 ($ |#1| |#2|)))) (-869) (-1119) (-1 (-141) (-2 (|:| -1825 |#1|) (|:| -3215 |#2|)) (-2 (|:| -1825 |#1|) (|:| -3215 |#2|)))) (T -730)) 
+((-3215 (*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-730 *3 *2 *4)) (-4 *3 (-869)) (-14 *4 (-1 (-141) (-2 (|:| -1825 *3) (|:| -3215 *2)) (-2 (|:| -1825 *3) (|:| -3215 *2)))))) (-1825 (*1 *2 *1) (-12 (-4 *2 (-869)) (-5 *1 (-730 *2 *3 *4)) (-4 *3 (-1119)) (-14 *4 (-1 (-141) (-2 (|:| -1825 *2) (|:| -3215 *3)) (-2 (|:| -1825 *2) (|:| -3215 *3)))))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -1825 *3) (|:| -3215 *4))) (-4 *3 (-869)) (-4 *4 (-1119)) (-5 *1 (-730 *3 *4 *5)) (-14 *5 (-1 (-141) *2 *2)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -1825 *3) (|:| -3215 *4))) (-5 *1 (-730 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-1119)) (-14 *5 (-1 (-141) *2 *2)))) (-4466 (*1 *1 *2 *3) (-12 (-5 *1 (-730 *2 *3 *4)) (-4 *2 (-869)) (-4 *3 (-1119)) (-14 *4 (-1 (-141) (-2 (|:| -1825 *2) (|:| -3215 *3)) (-2 (|:| -1825 *2) (|:| -3215 *3))))))) 
+(-13 (-869) (-10 -8 (-15 -3215 (|#2| $)) (-15 -1825 (|#1| $)) (-15 -1683 ($ (-2 (|:| -1825 |#1|) (|:| -3215 |#2|)))) (-15 -1683 ((-2 (|:| -1825 |#1|) (|:| -3215 |#2|)) $)) (-15 -4466 ($ |#1| |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 59)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 89) (((-3 (-143) "failed") $) 95)) (-2400 ((|#1| $) NIL) (((-143) $) 39)) (-3371 (((-3 $ "failed") $) 90)) (-4297 ((|#2| (-143) |#2|) 82)) (-3558 (((-141) $) NIL)) (-4415 (($ |#1| (-386 (-143))) 13)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3165 (($ $ (-1 |#2| |#2|)) 58)) (-1646 (($ $ (-1 |#2| |#2|)) 44)) (-3927 ((|#2| $ |#2|) 32)) (-4454 ((|#1| |#1|) 100 (|has| |#1| (-194)))) (-1683 (((-877) $) 66) (($ (-592)) 17) (($ |#1|) 16) (($ (-143)) 23)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) 36)) (-2332 (($ $) 99 (|has| |#1| (-194))) (($ $ $) 103 (|has| |#1| (-194)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 20 T CONST)) (-4257 (($) 9 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) 48) (($ $ $) NIL)) (-3300 (($ $ $) 73)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ (-143) (-592)) NIL) (($ $ (-592)) 57)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 98) (($ $ $) 50) (($ |#1| $) 96 (|has| |#1| (-194))) (($ $ |#1|) 97 (|has| |#1| (-194))))) 
+(((-731 |#1| |#2|) (-13 (-1075) (-1065 |#1|) (-1065 (-143)) (-303 |#2| |#2|) (-10 -8 (IF (|has| |#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |#1| (-194)) (PROGN (-6 (-43 |#1|)) (-15 -2332 ($ $)) (-15 -2332 ($ $ $)) (-15 -4454 (|#1| |#1|))) |noBranch|) (-15 -1646 ($ $ (-1 |#2| |#2|))) (-15 -3165 ($ $ (-1 |#2| |#2|))) (-15 ** ($ (-143) (-592))) (-15 ** ($ $ (-592))) (-15 -4297 (|#2| (-143) |#2|)) (-15 -4415 ($ |#1| (-386 (-143)))))) (-1075) (-661 |#1|)) (T -731)) 
+((-2332 (*1 *1 *1) (-12 (-4 *2 (-194)) (-4 *2 (-1075)) (-5 *1 (-731 *2 *3)) (-4 *3 (-661 *2)))) (-2332 (*1 *1 *1 *1) (-12 (-4 *2 (-194)) (-4 *2 (-1075)) (-5 *1 (-731 *2 *3)) (-4 *3 (-661 *2)))) (-4454 (*1 *2 *2) (-12 (-4 *2 (-194)) (-4 *2 (-1075)) (-5 *1 (-731 *2 *3)) (-4 *3 (-661 *2)))) (-1646 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-661 *3)) (-4 *3 (-1075)) (-5 *1 (-731 *3 *4)))) (-3165 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-661 *3)) (-4 *3 (-1075)) (-5 *1 (-731 *3 *4)))) (** (*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-592)) (-4 *4 (-1075)) (-5 *1 (-731 *4 *5)) (-4 *5 (-661 *4)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *3 (-1075)) (-5 *1 (-731 *3 *4)) (-4 *4 (-661 *3)))) (-4297 (*1 *2 *3 *2) (-12 (-5 *3 (-143)) (-4 *4 (-1075)) (-5 *1 (-731 *4 *2)) (-4 *2 (-661 *4)))) (-4415 (*1 *1 *2 *3) (-12 (-5 *3 (-386 (-143))) (-4 *2 (-1075)) (-5 *1 (-731 *2 *4)) (-4 *4 (-661 *2))))) 
+(-13 (-1075) (-1065 |#1|) (-1065 (-143)) (-303 |#2| |#2|) (-10 -8 (IF (|has| |#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |#1| (-194)) (PROGN (-6 (-43 |#1|)) (-15 -2332 ($ $)) (-15 -2332 ($ $ $)) (-15 -4454 (|#1| |#1|))) |noBranch|) (-15 -1646 ($ $ (-1 |#2| |#2|))) (-15 -3165 ($ $ (-1 |#2| |#2|))) (-15 ** ($ (-143) (-592))) (-15 ** ($ $ (-592))) (-15 -4297 (|#2| (-143) |#2|)) (-15 -4415 ($ |#1| (-386 (-143)))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 33)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3657 (($ |#1| |#2|) 25)) (-3371 (((-3 $ "failed") $) 47)) (-3558 (((-141) $) 35)) (-1704 ((|#2| $) 12)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 48)) (-2951 (((-1137) $) NIL)) (-2314 (((-3 $ "failed") $ $) 46)) (-1683 (((-877) $) 24) (($ (-592)) 19) ((|#1| $) 13)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 16 T CONST)) (-4257 (($) 30 T CONST)) (-3255 (((-141) $ $) 38)) (-3306 (($ $) 43) (($ $ $) 37)) (-3300 (($ $ $) 40)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 21) (($ $ $) 20))) 
+(((-732 |#1| |#2| |#3| |#4| |#5|) (-13 (-1075) (-10 -8 (-15 -1704 (|#2| $)) (-15 -1683 (|#1| $)) (-15 -3657 ($ |#1| |#2|)) (-15 -2314 ((-3 $ "failed") $ $)) (-15 -3371 ((-3 $ "failed") $)) (-15 -4552 ($ $)))) (-194) (-23) (-1 |#1| |#1| |#2|) (-1 (-3 |#2| "failed") |#2| |#2|) (-1 (-3 |#1| "failed") |#1| |#1| |#2|)) (T -732)) 
+((-3371 (*1 *1 *1) (|partial| -12 (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-1704 (*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-732 *3 *2 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) (-1683 (*1 *2 *1) (-12 (-4 *2 (-194)) (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3657 (*1 *1 *2 *3) (-12 (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2314 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-4552 (*1 *1 *1) (-12 (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
+(-13 (-1075) (-10 -8 (-15 -1704 (|#2| $)) (-15 -1683 (|#1| $)) (-15 -3657 ($ |#1| |#2|)) (-15 -2314 ((-3 $ "failed") $ $)) (-15 -3371 ((-3 $ "failed") $)) (-15 -4552 ($ $)))) 
+((* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ |#2| $) NIL) (($ $ |#2|) 9))) 
+(((-733 |#1| |#2|) (-10 -8 (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) (-734 |#2|) (-194)) (T -733)) 
+NIL 
+(-10 -8 (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
+(((-734 |#1|) (-1311) (-194)) (T -734)) 
+NIL 
+(-13 (-140 |t#1| |t#1|)) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-1081 |#1|) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-3651 (($ |#1|) 17) (($ $ |#1|) 20)) (-4086 (($ |#1|) 18) (($ $ |#1|) 21)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL) (($) 19) (($ $) 22)) (-3558 (((-141) $) NIL)) (-3818 (($ |#1| |#1| |#1| |#1|) 8)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 16)) (-2951 (((-1137) $) NIL)) (-2806 ((|#1| $ |#1|) 24) (((-855 |#1|) $ (-855 |#1|)) 32)) (-2227 (($ $ $) NIL)) (-2131 (($ $ $) NIL)) (-1683 (((-877) $) 39)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-4257 (($) 9 T CONST)) (-3255 (((-141) $ $) 44)) (-3313 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ $ $) 14))) 
+(((-735 |#1|) (-13 (-502) (-10 -8 (-15 -3818 ($ |#1| |#1| |#1| |#1|)) (-15 -3651 ($ |#1|)) (-15 -4086 ($ |#1|)) (-15 -3371 ($)) (-15 -3651 ($ $ |#1|)) (-15 -4086 ($ $ |#1|)) (-15 -3371 ($ $)) (-15 -2806 (|#1| $ |#1|)) (-15 -2806 ((-855 |#1|) $ (-855 |#1|))))) (-388)) (T -735)) 
+((-3818 (*1 *1 *2 *2 *2 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) (-3651 (*1 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) (-4086 (*1 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) (-3371 (*1 *1) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) (-3651 (*1 *1 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) (-4086 (*1 *1 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) (-3371 (*1 *1 *1) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) (-2806 (*1 *2 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) (-2806 (*1 *2 *1 *2) (-12 (-5 *2 (-855 *3)) (-4 *3 (-388)) (-5 *1 (-735 *3))))) 
+(-13 (-502) (-10 -8 (-15 -3818 ($ |#1| |#1| |#1| |#1|)) (-15 -3651 ($ |#1|)) (-15 -4086 ($ |#1|)) (-15 -3371 ($)) (-15 -3651 ($ $ |#1|)) (-15 -4086 ($ $ |#1|)) (-15 -3371 ($ $)) (-15 -2806 (|#1| $ |#1|)) (-15 -2806 ((-855 |#1|) $ (-855 |#1|))))) 
+((-2111 (($ $ (-944)) 12)) (-2682 (($ $ (-944)) 13)) (** (($ $ (-944)) 10))) 
+(((-736 |#1|) (-10 -8 (-15 ** (|#1| |#1| (-944))) (-15 -2682 (|#1| |#1| (-944))) (-15 -2111 (|#1| |#1| (-944)))) (-737)) (T -736)) 
+NIL 
+(-10 -8 (-15 ** (|#1| |#1| (-944))) (-15 -2682 (|#1| |#1| (-944))) (-15 -2111 (|#1| |#1| (-944)))) 
+((-1641 (((-141) $ $) 7)) (-2111 (($ $ (-944)) 14)) (-2682 (($ $ (-944)) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6)) (** (($ $ (-944)) 12)) (* (($ $ $) 15))) 
+(((-737) (-1311)) (T -737)) 
+((* (*1 *1 *1 *1) (-4 *1 (-737))) (-2111 (*1 *1 *1 *2) (-12 (-4 *1 (-737)) (-5 *2 (-944)))) (-2682 (*1 *1 *1 *2) (-12 (-4 *1 (-737)) (-5 *2 (-944)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-737)) (-5 *2 (-944))))) 
+(-13 (-1119) (-10 -8 (-15 * ($ $ $)) (-15 -2111 ($ $ (-944))) (-15 -2682 ($ $ (-944))) (-15 ** ($ $ (-944))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-2111 (($ $ (-944)) NIL) (($ $ (-790)) 17)) (-3558 (((-141) $) 10)) (-2682 (($ $ (-944)) NIL) (($ $ (-790)) 18)) (** (($ $ (-944)) NIL) (($ $ (-790)) 15))) 
+(((-738 |#1|) (-10 -8 (-15 ** (|#1| |#1| (-790))) (-15 -2682 (|#1| |#1| (-790))) (-15 -2111 (|#1| |#1| (-790))) (-15 -3558 ((-141) |#1|)) (-15 ** (|#1| |#1| (-944))) (-15 -2682 (|#1| |#1| (-944))) (-15 -2111 (|#1| |#1| (-944)))) (-739)) (T -738)) 
+NIL 
+(-10 -8 (-15 ** (|#1| |#1| (-790))) (-15 -2682 (|#1| |#1| (-790))) (-15 -2111 (|#1| |#1| (-790))) (-15 -3558 ((-141) |#1|)) (-15 ** (|#1| |#1| (-944))) (-15 -2682 (|#1| |#1| (-944))) (-15 -2111 (|#1| |#1| (-944)))) 
+((-1641 (((-141) $ $) 7)) (-2503 (((-3 $ "failed") $) 16)) (-2111 (($ $ (-944)) 14) (($ $ (-790)) 21)) (-3371 (((-3 $ "failed") $) 18)) (-3558 (((-141) $) 22)) (-4158 (((-3 $ "failed") $) 17)) (-2682 (($ $ (-944)) 13) (($ $ (-790)) 20)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-4257 (($) 23 T CONST)) (-3255 (((-141) $ $) 6)) (** (($ $ (-944)) 12) (($ $ (-790)) 19)) (* (($ $ $) 15))) 
+(((-739) (-1311)) (T -739)) 
+((-4257 (*1 *1) (-4 *1 (-739))) (-3558 (*1 *2 *1) (-12 (-4 *1 (-739)) (-5 *2 (-141)))) (-2111 (*1 *1 *1 *2) (-12 (-4 *1 (-739)) (-5 *2 (-790)))) (-2682 (*1 *1 *1 *2) (-12 (-4 *1 (-739)) (-5 *2 (-790)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-739)) (-5 *2 (-790)))) (-3371 (*1 *1 *1) (|partial| -4 *1 (-739))) (-4158 (*1 *1 *1) (|partial| -4 *1 (-739))) (-2503 (*1 *1 *1) (|partial| -4 *1 (-739)))) 
+(-13 (-737) (-10 -8 (-15 (-4257) ($) -4249) (-15 -3558 ((-141) $)) (-15 -2111 ($ $ (-790))) (-15 -2682 ($ $ (-790))) (-15 ** ($ $ (-790))) (-15 -3371 ((-3 $ "failed") $)) (-15 -4158 ((-3 $ "failed") $)) (-15 -2503 ((-3 $ "failed") $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-737) . T) ((-1119) . T)) 
+((-1403 (((-790)) 35)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 |#2| "failed") $) 25)) (-2400 (((-592) $) NIL) (((-433 (-592)) $) NIL) ((|#2| $) 22)) (-3657 (($ |#3|) NIL) (((-3 $ "failed") (-433 |#3|)) 45)) (-3371 (((-3 $ "failed") $) 65)) (-4290 (($) 39)) (-2793 ((|#2| $) 20)) (-2934 (($) 17)) (-3644 (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) 53) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL) (($ $ (-790)) NIL) (($ $) NIL)) (-4174 (((-706 |#2|) (-1280 $) (-1 |#2| |#2|)) 60)) (-1778 (((-1280 |#2|) $) NIL) (($ (-1280 |#2|)) NIL) ((|#3| $) 10) (($ |#3|) 12)) (-4198 ((|#3| $) 32)) (-2195 (((-1280 $)) 29))) 
+(((-740 |#1| |#2| |#3|) (-10 -8 (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -4290 (|#1|)) (-15 -1403 ((-790))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -4174 ((-706 |#2|) (-1280 |#1|) (-1 |#2| |#2|))) (-15 -3657 ((-3 |#1| "failed") (-433 |#3|))) (-15 -1778 (|#1| |#3|)) (-15 -3657 (|#1| |#3|)) (-15 -2934 (|#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1778 (|#3| |#1|)) (-15 -1778 (|#1| (-1280 |#2|))) (-15 -1778 ((-1280 |#2|) |#1|)) (-15 -2195 ((-1280 |#1|))) (-15 -4198 (|#3| |#1|)) (-15 -2793 (|#2| |#1|)) (-15 -3371 ((-3 |#1| "failed") |#1|))) (-741 |#2| |#3|) (-194) (-1255 |#2|)) (T -740)) 
+((-1403 (*1 *2) (-12 (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-790)) (-5 *1 (-740 *3 *4 *5)) (-4 *3 (-741 *4 *5))))) 
+(-10 -8 (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -4290 (|#1|)) (-15 -1403 ((-790))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -4174 ((-706 |#2|) (-1280 |#1|) (-1 |#2| |#2|))) (-15 -3657 ((-3 |#1| "failed") (-433 |#3|))) (-15 -1778 (|#1| |#3|)) (-15 -3657 (|#1| |#3|)) (-15 -2934 (|#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1778 (|#3| |#1|)) (-15 -1778 (|#1| (-1280 |#2|))) (-15 -1778 ((-1280 |#2|) |#1|)) (-15 -2195 ((-1280 |#1|))) (-15 -4198 (|#3| |#1|)) (-15 -2793 (|#2| |#1|)) (-15 -3371 ((-3 |#1| "failed") |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 88 (|has| |#1| (-388)))) (-1555 (($ $) 89 (|has| |#1| (-388)))) (-1313 (((-141) $) 91 (|has| |#1| (-388)))) (-1800 (((-706 |#1|) (-1280 $)) 44) (((-706 |#1|)) 55)) (-4529 ((|#1| $) 50)) (-4217 (((-1199 (-944) (-790)) (-592)) 142 (|has| |#1| (-373)))) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 108 (|has| |#1| (-388)))) (-3164 (((-444 $) $) 109 (|has| |#1| (-388)))) (-3652 (((-141) $ $) 99 (|has| |#1| (-388)))) (-1403 (((-790)) 81 (|has| |#1| (-394)))) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 164 (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 162 (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 161)) (-2400 (((-592) $) 165 (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) 163 (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 160)) (-1626 (($ (-1280 |#1|) (-1280 $)) 46) (($ (-1280 |#1|)) 58)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 148 (|has| |#1| (-373)))) (-1586 (($ $ $) 103 (|has| |#1| (-388)))) (-4493 (((-706 |#1|) $ (-1280 $)) 51) (((-706 |#1|) $) 53)) (-3945 (((-706 (-592)) (-706 $)) 159 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 158 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 157) (((-706 |#1|) (-706 $)) 156)) (-3657 (($ |#2|) 153) (((-3 $ "failed") (-433 |#2|)) 150 (|has| |#1| (-388)))) (-3371 (((-3 $ "failed") $) 33)) (-4175 (((-944)) 52)) (-4290 (($) 84 (|has| |#1| (-394)))) (-1599 (($ $ $) 102 (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 97 (|has| |#1| (-388)))) (-2667 (($) 144 (|has| |#1| (-373)))) (-3293 (((-141) $) 145 (|has| |#1| (-373)))) (-1525 (($ $ (-790)) 136 (|has| |#1| (-373))) (($ $) 135 (|has| |#1| (-373)))) (-2802 (((-141) $) 110 (|has| |#1| (-388)))) (-4346 (((-944) $) 147 (|has| |#1| (-373))) (((-855 (-944)) $) 133 (|has| |#1| (-373)))) (-3558 (((-141) $) 30)) (-2793 ((|#1| $) 49)) (-3921 (((-3 $ "failed") $) 137 (|has| |#1| (-373)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 106 (|has| |#1| (-388)))) (-3504 ((|#2| $) 42 (|has| |#1| (-388)))) (-3546 (((-944) $) 83 (|has| |#1| (-394)))) (-3650 ((|#2| $) 151)) (-2750 (($ (-658 $)) 95 (|has| |#1| (-388))) (($ $ $) 94 (|has| |#1| (-388)))) (-2685 (((-1173) $) 9)) (-4552 (($ $) 111 (|has| |#1| (-388)))) (-3703 (($) 138 (|has| |#1| (-373)) CONST)) (-1825 (($ (-944)) 82 (|has| |#1| (-394)))) (-2951 (((-1137) $) 10)) (-2934 (($) 155)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 96 (|has| |#1| (-388)))) (-3548 (($ (-658 $)) 93 (|has| |#1| (-388))) (($ $ $) 92 (|has| |#1| (-388)))) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 141 (|has| |#1| (-373)))) (-4500 (((-444 $) $) 107 (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105 (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 104 (|has| |#1| (-388)))) (-3616 (((-3 $ "failed") $ $) 87 (|has| |#1| (-388)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 98 (|has| |#1| (-388)))) (-2769 (((-790) $) 100 (|has| |#1| (-388)))) (-1405 (((-658 $)) 85 (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 101 (|has| |#1| (-388)))) (-1482 ((|#1| (-1280 $)) 45) ((|#1|) 54)) (-2177 (((-790) $) 146 (|has| |#1| (-373))) (((-3 (-790) "failed") $ $) 134 (|has| |#1| (-373)))) (-3644 (($ $) 132 (-3836 (-1732 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373)))) (($ $ (-790)) 130 (-3836 (-1732 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373)))) (($ $ (-1191)) 128 (-1732 (|has| |#1| (-922 (-1191))) (|has| |#1| (-388)))) (($ $ (-658 (-1191))) 127 (-1732 (|has| |#1| (-922 (-1191))) (|has| |#1| (-388)))) (($ $ (-1191) (-790)) 126 (-1732 (|has| |#1| (-922 (-1191))) (|has| |#1| (-388)))) (($ $ (-658 (-1191)) (-658 (-790))) 125 (-1732 (|has| |#1| (-922 (-1191))) (|has| |#1| (-388)))) (($ $ (-1 |#1| |#1|) (-790)) 118 (|has| |#1| (-388))) (($ $ (-1 |#1| |#1|)) 117 (|has| |#1| (-388)))) (-4174 (((-706 |#1|) (-1280 $) (-1 |#1| |#1|)) 149 (|has| |#1| (-388)))) (-3390 ((|#2|) 154)) (-3809 (($) 143 (|has| |#1| (-373)))) (-2231 (((-1280 |#1|) $ (-1280 $)) 48) (((-706 |#1|) (-1280 $) (-1280 $)) 47) (((-1280 |#1|) $) 60) (((-706 |#1|) (-1280 $)) 59)) (-1778 (((-1280 |#1|) $) 57) (($ (-1280 |#1|)) 56) ((|#2| $) 166) (($ |#2|) 152)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 140 (|has| |#1| (-373)))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 36) (($ $) 86 (|has| |#1| (-388))) (($ (-433 (-592))) 80 (-3836 (|has| |#1| (-388)) (|has| |#1| (-1065 (-433 (-592))))))) (-1517 (($ $) 139 (|has| |#1| (-373))) (((-3 $ "failed") $) 41 (|has| |#1| (-169)))) (-4198 ((|#2| $) 43)) (-4010 (((-790)) 28)) (-2195 (((-1280 $)) 61)) (-2537 (((-141) $ $) 90 (|has| |#1| (-388)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 112 (|has| |#1| (-388)))) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $) 131 (-3836 (-1732 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373)))) (($ $ (-790)) 129 (-3836 (-1732 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373)))) (($ $ (-1191)) 124 (-1732 (|has| |#1| (-922 (-1191))) (|has| |#1| (-388)))) (($ $ (-658 (-1191))) 123 (-1732 (|has| |#1| (-922 (-1191))) (|has| |#1| (-388)))) (($ $ (-1191) (-790)) 122 (-1732 (|has| |#1| (-922 (-1191))) (|has| |#1| (-388)))) (($ $ (-658 (-1191)) (-658 (-790))) 121 (-1732 (|has| |#1| (-922 (-1191))) (|has| |#1| (-388)))) (($ $ (-1 |#1| |#1|) (-790)) 120 (|has| |#1| (-388))) (($ $ (-1 |#1| |#1|)) 119 (|has| |#1| (-388)))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 116 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 113 (|has| |#1| (-388)))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ (-433 (-592)) $) 115 (|has| |#1| (-388))) (($ $ (-433 (-592))) 114 (|has| |#1| (-388))))) 
+(((-741 |#1| |#2|) (-1311) (-194) (-1255 |t#1|)) (T -741)) 
+((-2934 (*1 *1) (-12 (-4 *2 (-194)) (-4 *1 (-741 *2 *3)) (-4 *3 (-1255 *2)))) (-3390 (*1 *2) (-12 (-4 *1 (-741 *3 *2)) (-4 *3 (-194)) (-4 *2 (-1255 *3)))) (-3657 (*1 *1 *2) (-12 (-4 *3 (-194)) (-4 *1 (-741 *3 *2)) (-4 *2 (-1255 *3)))) (-1778 (*1 *1 *2) (-12 (-4 *3 (-194)) (-4 *1 (-741 *3 *2)) (-4 *2 (-1255 *3)))) (-3650 (*1 *2 *1) (-12 (-4 *1 (-741 *3 *2)) (-4 *3 (-194)) (-4 *2 (-1255 *3)))) (-3657 (*1 *1 *2) (|partial| -12 (-5 *2 (-433 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-388)) (-4 *3 (-194)) (-4 *1 (-741 *3 *4)))) (-4174 (*1 *2 *3 *4) (-12 (-5 *3 (-1280 *1)) (-5 *4 (-1 *5 *5)) (-4 *5 (-388)) (-4 *1 (-741 *5 *6)) (-4 *5 (-194)) (-4 *6 (-1255 *5)) (-5 *2 (-706 *5))))) 
+(-13 (-435 |t#1| |t#2|) (-194) (-633 |t#2|) (-437 |t#1|) (-403 |t#1|) (-10 -8 (-15 -2934 ($)) (-15 -3390 (|t#2|)) (-15 -3657 ($ |t#2|)) (-15 -1778 ($ |t#2|)) (-15 -3650 (|t#2| $)) (IF (|has| |t#1| (-394)) (-6 (-394)) |noBranch|) (IF (|has| |t#1| (-388)) (PROGN (-6 (-388)) (-6 (-245 |t#1|)) (-15 -3657 ((-3 $ "failed") (-433 |t#2|))) (-15 -4174 ((-706 |t#1|) (-1280 $) (-1 |t#1| |t#1|)))) |noBranch|) (IF (|has| |t#1| (-373)) (-6 (-373)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-43 |#1|) . T) ((-43 $) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-140 |#1| |#1|) . T) ((-140 $ $) . T) ((-158) . T) ((-169) -3836 (|has| |#1| (-373)) (|has| |#1| (-169))) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) . T) ((-633 |#2|) . T) ((-245 |#1|) |has| |#1| (-388)) ((-247) -3836 (|has| |#1| (-373)) (-12 (|has| |#1| (-247)) (|has| |#1| (-388)))) ((-260) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-307) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-323) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-388) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-428) |has| |#1| (-373)) ((-394) -3836 (|has| |#1| (-394)) (|has| |#1| (-373))) ((-373) |has| |#1| (-373)) ((-396 |#1| |#2|) . T) ((-435 |#1| |#2|) . T) ((-403 |#1|) . T) ((-437 |#1|) . T) ((-477) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-582) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-661 (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-734 (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-734 |#1|) . T) ((-734 $) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-743) . T) ((-922 (-1191)) -12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191)))) ((-943) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) -3836 (|has| |#1| (-373)) (|has| |#1| (-388))) ((-1081 |#1|) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) |has| |#1| (-373)) ((-1235) -3836 (|has| |#1| (-373)) (|has| |#1| (-388)))) 
+((-3001 (($) 14)) (-3371 (((-3 $ "failed") $) 16)) (-3558 (((-141) $) 13)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) 9)) (** (($ $ (-944)) NIL) (($ $ (-790)) 20))) 
+(((-742 |#1|) (-10 -8 (-15 -3371 ((-3 |#1| "failed") |#1|)) (-15 -1424 (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-790))) (-15 -3558 ((-141) |#1|)) (-15 -3001 (|#1|)) (-15 -1424 (|#1| |#1| (-944))) (-15 ** (|#1| |#1| (-944)))) (-743)) (T -742)) 
+NIL 
+(-10 -8 (-15 -3371 ((-3 |#1| "failed") |#1|)) (-15 -1424 (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-790))) (-15 -3558 ((-141) |#1|)) (-15 -3001 (|#1|)) (-15 -1424 (|#1| |#1| (-944))) (-15 ** (|#1| |#1| (-944)))) 
+((-1641 (((-141) $ $) 7)) (-3001 (($) 19 T CONST)) (-3371 (((-3 $ "failed") $) 15)) (-3558 (((-141) $) 18)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-1424 (($ $ (-944)) 12) (($ $ (-790)) 16)) (-4257 (($) 20 T CONST)) (-3255 (((-141) $ $) 6)) (** (($ $ (-944)) 13) (($ $ (-790)) 17)) (* (($ $ $) 14))) 
+(((-743) (-1311)) (T -743)) 
+((-4257 (*1 *1) (-4 *1 (-743))) (-3001 (*1 *1) (-4 *1 (-743))) (-3558 (*1 *2 *1) (-12 (-4 *1 (-743)) (-5 *2 (-141)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-743)) (-5 *2 (-790)))) (-1424 (*1 *1 *1 *2) (-12 (-4 *1 (-743)) (-5 *2 (-790)))) (-3371 (*1 *1 *1) (|partial| -4 *1 (-743)))) 
+(-13 (-1131) (-10 -8 (-15 (-4257) ($) -4249) (-15 -3001 ($) -4249) (-15 -3558 ((-141) $)) (-15 ** ($ $ (-790))) (-15 -1424 ($ $ (-790))) (-15 -3371 ((-3 $ "failed") $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1131) . T) ((-1119) . T)) 
+((-2091 (((-2 (|:| -1947 (-444 |#2|)) (|:| |special| (-444 |#2|))) |#2| (-1 |#2| |#2|)) 38)) (-1356 (((-2 (|:| -1947 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|)) 12)) (-2805 ((|#2| (-433 |#2|) (-1 |#2| |#2|)) 13)) (-1906 (((-2 (|:| |poly| |#2|) (|:| -1947 (-433 |#2|)) (|:| |special| (-433 |#2|))) (-433 |#2|) (-1 |#2| |#2|)) 47))) 
+(((-744 |#1| |#2|) (-10 -7 (-15 -1356 ((-2 (|:| -1947 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|))) (-15 -2091 ((-2 (|:| -1947 (-444 |#2|)) (|:| |special| (-444 |#2|))) |#2| (-1 |#2| |#2|))) (-15 -2805 (|#2| (-433 |#2|) (-1 |#2| |#2|))) (-15 -1906 ((-2 (|:| |poly| |#2|) (|:| -1947 (-433 |#2|)) (|:| |special| (-433 |#2|))) (-433 |#2|) (-1 |#2| |#2|)))) (-388) (-1255 |#1|)) (T -744)) 
+((-1906 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |poly| *6) (|:| -1947 (-433 *6)) (|:| |special| (-433 *6)))) (-5 *1 (-744 *5 *6)) (-5 *3 (-433 *6)))) (-2805 (*1 *2 *3 *4) (-12 (-5 *3 (-433 *2)) (-5 *4 (-1 *2 *2)) (-4 *2 (-1255 *5)) (-5 *1 (-744 *5 *2)) (-4 *5 (-388)))) (-2091 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| -1947 (-444 *3)) (|:| |special| (-444 *3)))) (-5 *1 (-744 *5 *3)))) (-1356 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| -1947 *3) (|:| |special| *3))) (-5 *1 (-744 *5 *3))))) 
+(-10 -7 (-15 -1356 ((-2 (|:| -1947 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|))) (-15 -2091 ((-2 (|:| -1947 (-444 |#2|)) (|:| |special| (-444 |#2|))) |#2| (-1 |#2| |#2|))) (-15 -2805 (|#2| (-433 |#2|) (-1 |#2| |#2|))) (-15 -1906 ((-2 (|:| |poly| |#2|) (|:| -1947 (-433 |#2|)) (|:| |special| (-433 |#2|))) (-433 |#2|) (-1 |#2| |#2|)))) 
+((-3711 ((|#7| (-658 |#5|) |#6|) NIL)) (-2731 ((|#7| (-1 |#5| |#4|) |#6|) 26))) 
+(((-745 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -2731 (|#7| (-1 |#5| |#4|) |#6|)) (-15 -3711 (|#7| (-658 |#5|) |#6|))) (-869) (-815) (-815) (-1075) (-1075) (-977 |#4| |#2| |#1|) (-977 |#5| |#3| |#1|)) (T -745)) 
+((-3711 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *9)) (-4 *9 (-1075)) (-4 *5 (-869)) (-4 *6 (-815)) (-4 *8 (-1075)) (-4 *2 (-977 *9 *7 *5)) (-5 *1 (-745 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-815)) (-4 *4 (-977 *8 *6 *5)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *8)) (-4 *8 (-1075)) (-4 *9 (-1075)) (-4 *5 (-869)) (-4 *6 (-815)) (-4 *2 (-977 *9 *7 *5)) (-5 *1 (-745 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-815)) (-4 *4 (-977 *8 *6 *5))))) 
+(-10 -7 (-15 -2731 (|#7| (-1 |#5| |#4|) |#6|)) (-15 -3711 (|#7| (-658 |#5|) |#6|))) 
+((-2731 ((|#7| (-1 |#2| |#1|) |#6|) 28))) 
+(((-746 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -2731 (|#7| (-1 |#2| |#1|) |#6|))) (-869) (-869) (-815) (-815) (-1075) (-977 |#5| |#3| |#1|) (-977 |#5| |#4| |#2|)) (T -746)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-869)) (-4 *6 (-869)) (-4 *7 (-815)) (-4 *9 (-1075)) (-4 *2 (-977 *9 *8 *6)) (-5 *1 (-746 *5 *6 *7 *8 *9 *4 *2)) (-4 *8 (-815)) (-4 *4 (-977 *9 *7 *5))))) 
+(-10 -7 (-15 -2731 (|#7| (-1 |#2| |#1|) |#6|))) 
+((-4500 (((-444 |#4|) |#4|) 39))) 
+(((-747 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4500 ((-444 |#4|) |#4|))) (-815) (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191))))) (-323) (-977 (-980 |#3|) |#1| |#2|)) (T -747)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-4 *6 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-747 *4 *5 *6 *3)) (-4 *3 (-977 (-980 *6) *4 *5))))) 
+(-10 -7 (-15 -4500 ((-444 |#4|) |#4|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-879 |#1|)) $) NIL)) (-4492 (((-1187 $) $ (-879 |#1|)) NIL) (((-1187 |#2|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#2| (-582)))) (-1555 (($ $) NIL (|has| |#2| (-582)))) (-1313 (((-141) $) NIL (|has| |#2| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-879 |#1|))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3743 (($ $) NIL (|has| |#2| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#2| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-879 |#1|) "failed") $) NIL)) (-2400 ((|#2| $) NIL) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-879 |#1|) $) NIL)) (-1544 (($ $ $ (-879 |#1|)) NIL (|has| |#2| (-194)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#2| (-477))) (($ $ (-879 |#1|)) NIL (|has| |#2| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#2| (-931)))) (-4209 (($ $ |#2| (-558 (-879 |#1|)) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-879 |#1|) (-908 (-405))) (|has| |#2| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-879 |#1|) (-908 (-592))) (|has| |#2| (-908 (-592)))))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-4533 (($ (-1187 |#2|) (-879 |#1|)) NIL) (($ (-1187 $) (-879 |#1|)) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#2| (-558 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-879 |#1|)) NIL)) (-4206 (((-558 (-879 |#1|)) $) NIL) (((-790) $ (-879 |#1|)) NIL) (((-658 (-790)) $ (-658 (-879 |#1|))) NIL)) (-1837 (($ $ $) NIL (|has| |#2| (-869)))) (-3319 (($ $ $) NIL (|has| |#2| (-869)))) (-2976 (($ (-1 (-558 (-879 |#1|)) (-558 (-879 |#1|))) $) NIL)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-3254 (((-3 (-879 |#1|) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#2| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-2685 (((-1173) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-879 |#1|)) (|:| -3215 (-790))) "failed") $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#2| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#2| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#2| (-931)))) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-879 |#1|) |#2|) NIL) (($ $ (-658 (-879 |#1|)) (-658 |#2|)) NIL) (($ $ (-879 |#1|) $) NIL) (($ $ (-658 (-879 |#1|)) (-658 $)) NIL)) (-1482 (($ $ (-879 |#1|)) NIL (|has| |#2| (-194)))) (-3644 (($ $ (-879 |#1|)) NIL) (($ $ (-658 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-4525 (((-558 (-879 |#1|)) $) NIL) (((-790) $ (-879 |#1|)) NIL) (((-658 (-790)) $ (-658 (-879 |#1|))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-879 |#1|) (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-879 |#1|) (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-879 |#1|) (-633 (-565))) (|has| |#2| (-633 (-565)))))) (-1554 ((|#2| $) NIL (|has| |#2| (-477))) (($ $ (-879 |#1|)) NIL (|has| |#2| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#2| (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) NIL) (($ (-879 |#1|)) NIL) (($ $) NIL (|has| |#2| (-582))) (($ (-433 (-592))) NIL (-3836 (|has| |#2| (-43 (-433 (-592)))) (|has| |#2| (-1065 (-433 (-592))))))) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-558 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#2| (-931))) (|has| |#2| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#2| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#2| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-879 |#1|)) NIL) (($ $ (-658 (-879 |#1|))) NIL) (($ $ (-879 |#1|) (-790)) NIL) (($ $ (-658 (-879 |#1|)) (-658 (-790))) NIL)) (-3286 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#2| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#2| (-43 (-433 (-592))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-748 |#1| |#2|) (-977 |#2| (-558 (-879 |#1|)) (-879 |#1|)) (-658 (-1191)) (-1075)) (T -748)) 
+NIL 
+(-977 |#2| (-558 (-879 |#1|)) (-879 |#1|)) 
+((-2631 (((-2 (|:| -4079 (-980 |#3|)) (|:| -1817 (-980 |#3|))) |#4|) 13)) (-3292 ((|#4| |#4| |#2|) 30)) (-4534 ((|#4| (-433 (-980 |#3|)) |#2|) 63)) (-4008 ((|#4| (-1187 (-980 |#3|)) |#2|) 76)) (-4488 ((|#4| (-1187 |#4|) |#2|) 49)) (-3978 ((|#4| |#4| |#2|) 52)) (-4500 (((-444 |#4|) |#4|) 38))) 
+(((-749 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2631 ((-2 (|:| -4079 (-980 |#3|)) (|:| -1817 (-980 |#3|))) |#4|)) (-15 -3978 (|#4| |#4| |#2|)) (-15 -4488 (|#4| (-1187 |#4|) |#2|)) (-15 -3292 (|#4| |#4| |#2|)) (-15 -4008 (|#4| (-1187 (-980 |#3|)) |#2|)) (-15 -4534 (|#4| (-433 (-980 |#3|)) |#2|)) (-15 -4500 ((-444 |#4|) |#4|))) (-815) (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)))) (-582) (-977 (-433 (-980 |#3|)) |#1| |#2|)) (T -749)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *6 (-582)) (-5 *2 (-444 *3)) (-5 *1 (-749 *4 *5 *6 *3)) (-4 *3 (-977 (-433 (-980 *6)) *4 *5)))) (-4534 (*1 *2 *3 *4) (-12 (-4 *6 (-582)) (-4 *2 (-977 *3 *5 *4)) (-5 *1 (-749 *5 *4 *6 *2)) (-5 *3 (-433 (-980 *6))) (-4 *5 (-815)) (-4 *4 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))))) (-4008 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 (-980 *6))) (-4 *6 (-582)) (-4 *2 (-977 (-433 (-980 *6)) *5 *4)) (-5 *1 (-749 *5 *4 *6 *2)) (-4 *5 (-815)) (-4 *4 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))))) (-3292 (*1 *2 *2 *3) (-12 (-4 *4 (-815)) (-4 *3 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *5 (-582)) (-5 *1 (-749 *4 *3 *5 *2)) (-4 *2 (-977 (-433 (-980 *5)) *4 *3)))) (-4488 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 *2)) (-4 *2 (-977 (-433 (-980 *6)) *5 *4)) (-5 *1 (-749 *5 *4 *6 *2)) (-4 *5 (-815)) (-4 *4 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *6 (-582)))) (-3978 (*1 *2 *2 *3) (-12 (-4 *4 (-815)) (-4 *3 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *5 (-582)) (-5 *1 (-749 *4 *3 *5 *2)) (-4 *2 (-977 (-433 (-980 *5)) *4 *3)))) (-2631 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *6 (-582)) (-5 *2 (-2 (|:| -4079 (-980 *6)) (|:| -1817 (-980 *6)))) (-5 *1 (-749 *4 *5 *6 *3)) (-4 *3 (-977 (-433 (-980 *6)) *4 *5))))) 
+(-10 -7 (-15 -2631 ((-2 (|:| -4079 (-980 |#3|)) (|:| -1817 (-980 |#3|))) |#4|)) (-15 -3978 (|#4| |#4| |#2|)) (-15 -4488 (|#4| (-1187 |#4|) |#2|)) (-15 -3292 (|#4| |#4| |#2|)) (-15 -4008 (|#4| (-1187 (-980 |#3|)) |#2|)) (-15 -4534 (|#4| (-433 (-980 |#3|)) |#2|)) (-15 -4500 ((-444 |#4|) |#4|))) 
+((-4500 (((-444 |#4|) |#4|) 51))) 
+(((-750 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4500 ((-444 |#4|) |#4|))) (-815) (-869) (-13 (-323) (-171)) (-977 (-433 |#3|) |#1| |#2|)) (T -750)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-13 (-323) (-171))) (-5 *2 (-444 *3)) (-5 *1 (-750 *4 *5 *6 *3)) (-4 *3 (-977 (-433 *6) *4 *5))))) 
+(-10 -7 (-15 -4500 ((-444 |#4|) |#4|))) 
+((-2731 (((-752 |#2| |#3|) (-1 |#2| |#1|) (-752 |#1| |#3|)) 18))) 
+(((-751 |#1| |#2| |#3|) (-10 -7 (-15 -2731 ((-752 |#2| |#3|) (-1 |#2| |#1|) (-752 |#1| |#3|)))) (-1075) (-1075) (-743)) (T -751)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-752 *5 *7)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-4 *7 (-743)) (-5 *2 (-752 *6 *7)) (-5 *1 (-751 *5 *6 *7))))) 
+(-10 -7 (-15 -2731 ((-752 |#2| |#3|) (-1 |#2| |#1|) (-752 |#1| |#3|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 26)) (-2982 (((-658 (-2 (|:| -1487 |#1|) (|:| -1493 |#2|))) $) 27)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1403 (((-790)) 20 (-12 (|has| |#2| (-394)) (|has| |#1| (-394))))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) 55) (((-3 |#1| "failed") $) 58)) (-2400 ((|#2| $) NIL) ((|#1| $) NIL)) (-4593 (($ $) 75 (|has| |#2| (-869)))) (-3371 (((-3 $ "failed") $) 62)) (-4290 (($) 33 (-12 (|has| |#2| (-394)) (|has| |#1| (-394))))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) 53)) (-3108 (((-658 $) $) 37)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| |#2|) 16)) (-2731 (($ (-1 |#1| |#1|) $) 52)) (-3546 (((-944) $) 30 (-12 (|has| |#2| (-394)) (|has| |#1| (-394))))) (-4573 ((|#2| $) 74 (|has| |#2| (-869)))) (-4579 ((|#1| $) 73 (|has| |#2| (-869)))) (-2685 (((-1173) $) NIL)) (-1825 (($ (-944)) 25 (-12 (|has| |#2| (-394)) (|has| |#1| (-394))))) (-2951 (((-1137) $) NIL)) (-1405 (((-658 $)) NIL (-12 (|has| |#2| (-394)) (|has| |#1| (-394))))) (-1683 (((-877) $) 72) (($ (-592)) 44) (($ |#2|) 40) (($ |#1|) 41) (($ (-658 (-2 (|:| -1487 |#1|) (|:| -1493 |#2|)))) 11)) (-1647 (((-658 |#1|) $) 39)) (-1937 ((|#1| $ |#2|) 83)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 12 T CONST)) (-4257 (($) 31 T CONST)) (-3255 (((-141) $ $) 76)) (-3306 (($ $) 46) (($ $ $) NIL)) (-3300 (($ $ $) 24)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 50) (($ $ $) 85) (($ |#1| $) 48 (|has| |#1| (-194))) (($ $ |#1|) NIL (|has| |#1| (-194))))) 
+(((-752 |#1| |#2|) (-13 (-1075) (-1065 |#2|) (-1065 |#1|) (-10 -8 (-15 -4526 ($ |#1| |#2|)) (-15 -1937 (|#1| $ |#2|)) (-15 -1683 ($ (-658 (-2 (|:| -1487 |#1|) (|:| -1493 |#2|))))) (-15 -2982 ((-658 (-2 (|:| -1487 |#1|) (|:| -1493 |#2|))) $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (-15 -2027 ((-141) $)) (-15 -1647 ((-658 |#1|) $)) (-15 -3108 ((-658 $) $)) (-15 -4036 ((-790) $)) (IF (|has| |#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |#1| (-194)) (-6 (-43 |#1|)) |noBranch|) (IF (|has| |#1| (-394)) (IF (|has| |#2| (-394)) (-6 (-394)) |noBranch|) |noBranch|) (IF (|has| |#2| (-869)) (PROGN (-15 -4573 (|#2| $)) (-15 -4579 (|#1| $)) (-15 -4593 ($ $))) |noBranch|))) (-1075) (-743)) (T -752)) 
+((-4526 (*1 *1 *2 *3) (-12 (-5 *1 (-752 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-743)))) (-1937 (*1 *2 *1 *3) (-12 (-4 *2 (-1075)) (-5 *1 (-752 *2 *3)) (-4 *3 (-743)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1487 *3) (|:| -1493 *4)))) (-4 *3 (-1075)) (-4 *4 (-743)) (-5 *1 (-752 *3 *4)))) (-2982 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| -1487 *3) (|:| -1493 *4)))) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-752 *3 *4)) (-4 *4 (-743)))) (-2027 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) (-1647 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) (-3108 (*1 *2 *1) (-12 (-5 *2 (-658 (-752 *3 *4))) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) (-4036 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) (-4573 (*1 *2 *1) (-12 (-4 *2 (-743)) (-4 *2 (-869)) (-5 *1 (-752 *3 *2)) (-4 *3 (-1075)))) (-4579 (*1 *2 *1) (-12 (-4 *2 (-1075)) (-5 *1 (-752 *2 *3)) (-4 *3 (-869)) (-4 *3 (-743)))) (-4593 (*1 *1 *1) (-12 (-5 *1 (-752 *2 *3)) (-4 *3 (-869)) (-4 *2 (-1075)) (-4 *3 (-743))))) 
+(-13 (-1075) (-1065 |#2|) (-1065 |#1|) (-10 -8 (-15 -4526 ($ |#1| |#2|)) (-15 -1937 (|#1| $ |#2|)) (-15 -1683 ($ (-658 (-2 (|:| -1487 |#1|) (|:| -1493 |#2|))))) (-15 -2982 ((-658 (-2 (|:| -1487 |#1|) (|:| -1493 |#2|))) $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (-15 -2027 ((-141) $)) (-15 -1647 ((-658 |#1|) $)) (-15 -3108 ((-658 $) $)) (-15 -4036 ((-790) $)) (IF (|has| |#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |#1| (-194)) (-6 (-43 |#1|)) |noBranch|) (IF (|has| |#1| (-394)) (IF (|has| |#2| (-394)) (-6 (-394)) |noBranch|) |noBranch|) (IF (|has| |#2| (-869)) (PROGN (-15 -4573 (|#2| $)) (-15 -4579 (|#1| $)) (-15 -4593 ($ $))) |noBranch|))) 
+((-1641 (((-141) $ $) 18)) (-4528 (($ |#1| $) 72) (($ $ |#1|) 71) (($ $ $) 70)) (-4471 (($ $ $) 68)) (-2461 (((-141) $ $) 69)) (-2126 (((-141) $ (-790)) 8)) (-2224 (($ (-658 |#1|)) 64) (($) 63)) (-4125 (($ (-1 (-141) |#1|) $) 42 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) 52 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1461 (($ $) 58)) (-1360 (($ $) 55 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ |#1| $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) 43 (|has| $ (-6 -4625)))) (-4459 (($ |#1| $) 54 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 51 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4625)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22)) (-2852 (($ $ $) 65)) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37) (($ |#1| $ (-790)) 59)) (-2951 (((-1137) $) 21)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 48)) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-2043 (((-658 (-2 (|:| -3552 |#1|) (|:| -3452 (-790)))) $) 57)) (-4328 (($ $ |#1|) 67) (($ $ $) 66)) (-1653 (($) 46) (($ (-658 |#1|)) 45)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 47)) (-1683 (((-877) $) 20)) (-4586 (($ (-658 |#1|)) 62) (($) 61)) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19)) (-3266 (((-141) $ $) 60)) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-753 |#1|) (-1311) (-1119)) (T -753)) 
+NIL 
+(-13 (-711 |t#1|) (-1116 |t#1|)) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) . T) ((-632 (-877)) . T) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-249 |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-711 |#1|) . T) ((-1116 |#1|) . T) ((-1119) . T) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-4528 (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ $ $) 77)) (-4471 (($ $ $) 80)) (-2461 (((-141) $ $) 83)) (-2126 (((-141) $ (-790)) NIL)) (-2224 (($ (-658 |#1|)) 24) (($) 15)) (-4125 (($ (-1 (-141) |#1|) $) 71 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-1461 (($ $) 72)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4065 (($ |#1| $) 61 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) 64 (|has| $ (-6 -4625))) (($ |#1| $ (-592)) 62) (($ (-1 (-141) |#1|) $ (-592)) 65)) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (($ |#1| $ (-592)) 67) (($ (-1 (-141) |#1|) $ (-592)) 68)) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-4004 (((-658 |#1|) $) 32 (|has| $ (-6 -4625)))) (-3126 (($) 13) (($ |#1|) 26) (($ (-658 |#1|)) 21)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) 38)) (-3133 (((-141) |#1| $) 57 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) 75 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 76)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-2852 (($ $ $) 78)) (-4137 ((|#1| $) 54)) (-2113 (($ |#1| $) 55) (($ |#1| $ (-790)) 73)) (-2951 (((-1137) $) NIL)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-2106 ((|#1| $) 53)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 49)) (-2890 (($) 12)) (-2043 (((-658 (-2 (|:| -3552 |#1|) (|:| -3452 (-790)))) $) 47)) (-4328 (($ $ |#1|) NIL) (($ $ $) 79)) (-1653 (($) 14) (($ (-658 |#1|)) 23)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) 60 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) 66)) (-1778 (((-565) $) 36 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 20)) (-1683 (((-877) $) 44)) (-4586 (($ (-658 |#1|)) 25) (($) 16)) (-4560 (($ (-658 |#1|)) 22)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 81)) (-3266 (((-141) $ $) 82)) (-1699 (((-790) $) 59 (|has| $ (-6 -4625))))) 
+(((-754 |#1|) (-13 (-753 |#1|) (-10 -8 (-6 -4625) (-6 -4626) (-15 -3126 ($)) (-15 -3126 ($ |#1|)) (-15 -3126 ($ (-658 |#1|))) (-15 -4467 ((-658 |#1|) $)) (-15 -4459 ($ |#1| $ (-592))) (-15 -4459 ($ (-1 (-141) |#1|) $ (-592))) (-15 -4065 ($ |#1| $ (-592))) (-15 -4065 ($ (-1 (-141) |#1|) $ (-592))))) (-1119)) (T -754)) 
+((-3126 (*1 *1) (-12 (-5 *1 (-754 *2)) (-4 *2 (-1119)))) (-3126 (*1 *1 *2) (-12 (-5 *1 (-754 *2)) (-4 *2 (-1119)))) (-3126 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-754 *3)))) (-4467 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-754 *3)) (-4 *3 (-1119)))) (-4459 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-754 *2)) (-4 *2 (-1119)))) (-4459 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-141) *4)) (-5 *3 (-592)) (-4 *4 (-1119)) (-5 *1 (-754 *4)))) (-4065 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-754 *2)) (-4 *2 (-1119)))) (-4065 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-141) *4)) (-5 *3 (-592)) (-4 *4 (-1119)) (-5 *1 (-754 *4))))) 
+(-13 (-753 |#1|) (-10 -8 (-6 -4625) (-6 -4626) (-15 -3126 ($)) (-15 -3126 ($ |#1|)) (-15 -3126 ($ (-658 |#1|))) (-15 -4467 ((-658 |#1|) $)) (-15 -4459 ($ |#1| $ (-592))) (-15 -4459 ($ (-1 (-141) |#1|) $ (-592))) (-15 -4065 ($ |#1| $ (-592))) (-15 -4065 ($ (-1 (-141) |#1|) $ (-592))))) 
+((-2865 (((-1285) (-1173)) 8))) 
+(((-755) (-10 -7 (-15 -2865 ((-1285) (-1173))))) (T -755)) 
+((-2865 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-755))))) 
+(-10 -7 (-15 -2865 ((-1285) (-1173)))) 
+((-2193 (((-658 |#1|) (-658 |#1|) (-658 |#1|)) 10))) 
+(((-756 |#1|) (-10 -7 (-15 -2193 ((-658 |#1|) (-658 |#1|) (-658 |#1|)))) (-869)) (T -756)) 
+((-2193 (*1 *2 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-756 *3))))) 
+(-10 -7 (-15 -2193 ((-658 |#1|) (-658 |#1|) (-658 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 |#2|) $) 134)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 127 (|has| |#1| (-582)))) (-1555 (($ $) 126 (|has| |#1| (-582)))) (-1313 (((-141) $) 124 (|has| |#1| (-582)))) (-1588 (($ $) 83 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 66 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) 18)) (-1442 (($ $) 65 (|has| |#1| (-43 (-433 (-592)))))) (-1575 (($ $) 82 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 67 (|has| |#1| (-43 (-433 (-592)))))) (-1601 (($ $) 81 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 68 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) 16 T CONST)) (-4593 (($ $) 118)) (-3371 (((-3 $ "failed") $) 33)) (-2012 (((-980 |#1|) $ (-790)) 96) (((-980 |#1|) $ (-790) (-790)) 95)) (-2273 (((-141) $) 135)) (-1435 (($) 93 (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-790) $ |#2|) 98) (((-790) $ |#2| (-790)) 97)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 64 (|has| |#1| (-43 (-433 (-592)))))) (-2027 (((-141) $) 116)) (-4526 (($ $ (-658 |#2|) (-658 (-558 |#2|))) 133) (($ $ |#2| (-558 |#2|)) 132) (($ |#1| (-558 |#2|)) 117) (($ $ |#2| (-790)) 100) (($ $ (-658 |#2|) (-658 (-790))) 99)) (-2731 (($ (-1 |#1| |#1|) $) 115)) (-4546 (($ $) 90 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) 113)) (-4579 ((|#1| $) 112)) (-2685 (((-1173) $) 9)) (-3162 (($ $ |#2|) 94 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) 10)) (-2807 (($ $ (-790)) 101)) (-3616 (((-3 $ "failed") $ $) 128 (|has| |#1| (-582)))) (-1430 (($ $) 91 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (($ $ |#2| $) 109) (($ $ (-658 |#2|) (-658 $)) 108) (($ $ (-658 (-310 $))) 107) (($ $ (-310 $)) 106) (($ $ $ $) 105) (($ $ (-658 $) (-658 $)) 104)) (-3644 (($ $ |#2|) 41) (($ $ (-658 |#2|)) 40) (($ $ |#2| (-790)) 39) (($ $ (-658 |#2|) (-658 (-790))) 38)) (-4525 (((-558 |#2|) $) 114)) (-1609 (($ $) 80 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 69 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 79 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 70 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 78 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 71 (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 136)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 131 (|has| |#1| (-194))) (($ $) 129 (|has| |#1| (-582))) (($ (-433 (-592))) 121 (|has| |#1| (-43 (-433 (-592)))))) (-1937 ((|#1| $ (-558 |#2|)) 119) (($ $ |#2| (-790)) 103) (($ $ (-658 |#2|) (-658 (-790))) 102)) (-1517 (((-3 $ "failed") $) 130 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-1630 (($ $) 89 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 77 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) 125 (|has| |#1| (-582)))) (-1617 (($ $) 88 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 76 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 87 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 75 (|has| |#1| (-43 (-433 (-592)))))) (-2892 (($ $) 86 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 74 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 85 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 73 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 84 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 72 (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ |#2|) 37) (($ $ (-658 |#2|)) 36) (($ $ |#2| (-790)) 35) (($ $ (-658 |#2|) (-658 (-790))) 34)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 120 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ $) 92 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 63 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 123 (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) 122 (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 111) (($ $ |#1|) 110))) 
+(((-757 |#1| |#2|) (-1311) (-1075) (-869)) (T -757)) 
+((-1937 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-757 *4 *2)) (-4 *4 (-1075)) (-4 *2 (-869)))) (-1937 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *5)) (-5 *3 (-658 (-790))) (-4 *1 (-757 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-869)))) (-2807 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-757 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-869)))) (-4526 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-757 *4 *2)) (-4 *4 (-1075)) (-4 *2 (-869)))) (-4526 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *5)) (-5 *3 (-658 (-790))) (-4 *1 (-757 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-869)))) (-4346 (*1 *2 *1 *3) (-12 (-4 *1 (-757 *4 *3)) (-4 *4 (-1075)) (-4 *3 (-869)) (-5 *2 (-790)))) (-4346 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-790)) (-4 *1 (-757 *4 *3)) (-4 *4 (-1075)) (-4 *3 (-869)))) (-2012 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-757 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-869)) (-5 *2 (-980 *4)))) (-2012 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-4 *1 (-757 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-869)) (-5 *2 (-980 *4)))) (-3162 (*1 *1 *1 *2) (-12 (-4 *1 (-757 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-869)) (-4 *3 (-43 (-433 (-592))))))) 
+(-13 (-922 |t#2|) (-1002 |t#1| (-558 |t#2|) |t#2|) (-547 |t#2| $) (-325 $) (-10 -8 (-15 -1937 ($ $ |t#2| (-790))) (-15 -1937 ($ $ (-658 |t#2|) (-658 (-790)))) (-15 -2807 ($ $ (-790))) (-15 -4526 ($ $ |t#2| (-790))) (-15 -4526 ($ $ (-658 |t#2|) (-658 (-790)))) (-15 -4346 ((-790) $ |t#2|)) (-15 -4346 ((-790) $ |t#2| (-790))) (-15 -2012 ((-980 |t#1|) $ (-790))) (-15 -2012 ((-980 |t#1|) $ (-790) (-790))) (IF (|has| |t#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $ |t#2|)) (-6 (-1030)) (-6 (-1211))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-558 |#2|)) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) |has| |#1| (-582)) ((-40) |has| |#1| (-43 (-433 (-592)))) ((-116) |has| |#1| (-43 (-433 (-592)))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-301) |has| |#1| (-43 (-433 (-592)))) ((-307) |has| |#1| (-582)) ((-325 $) . T) ((-526) |has| |#1| (-43 (-433 (-592)))) ((-547 |#2| $) . T) ((-547 $ $) . T) ((-582) |has| |#1| (-582)) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) |has| |#1| (-582)) ((-743) . T) ((-922 |#2|) . T) ((-1002 |#1| (-558 |#2|) |#2|) . T) ((-1030) |has| |#1| (-43 (-433 (-592)))) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1211) |has| |#1| (-43 (-433 (-592)))) ((-1214) |has| |#1| (-43 (-433 (-592))))) 
+((-4500 (((-444 (-1187 |#4|)) (-1187 |#4|)) 28) (((-444 |#4|) |#4|) 24))) 
+(((-758 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4500 ((-444 |#4|) |#4|)) (-15 -4500 ((-444 (-1187 |#4|)) (-1187 |#4|)))) (-869) (-815) (-13 (-323) (-171)) (-977 |#3| |#2| |#1|)) (T -758)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-977 *6 *5 *4)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-758 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) (-4500 (*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-13 (-323) (-171))) (-5 *2 (-444 *3)) (-5 *1 (-758 *4 *5 *6 *3)) (-4 *3 (-977 *6 *5 *4))))) 
+(-10 -7 (-15 -4500 ((-444 |#4|) |#4|)) (-15 -4500 ((-444 (-1187 |#4|)) (-1187 |#4|)))) 
+((-4161 (((-444 |#4|) |#4| |#2|) 116)) (-2046 (((-444 |#4|) |#4|) NIL)) (-3164 (((-444 (-1187 |#4|)) (-1187 |#4|)) 107) (((-444 |#4|) |#4|) 38)) (-2051 (((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-658 (-2 (|:| -4500 (-1187 |#4|)) (|:| -3215 (-592)))))) (-1187 |#4|) (-658 |#2|) (-658 (-658 |#3|))) 65)) (-4127 (((-1187 |#3|) (-1187 |#3|) (-592)) 133)) (-3814 (((-658 (-790)) (-1187 |#4|) (-658 |#2|) (-790)) 58)) (-3650 (((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-1187 |#3|) (-1187 |#3|) |#4| (-658 |#2|) (-658 (-790)) (-658 |#3|)) 62)) (-2059 (((-2 (|:| |upol| (-1187 |#3|)) (|:| |Lval| (-658 |#3|)) (|:| |Lfact| (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592))))) (|:| |ctpol| |#3|)) (-1187 |#4|) (-658 |#2|) (-658 (-658 |#3|))) 22)) (-1557 (((-2 (|:| -3489 (-1187 |#4|)) (|:| |polval| (-1187 |#3|))) (-1187 |#4|) (-1187 |#3|) (-592)) 54)) (-1585 (((-592) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592))))) 130)) (-2921 ((|#4| (-592) (-444 |#4|)) 55)) (-3971 (((-141) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592)))) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592))))) NIL))) 
+(((-759 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3164 ((-444 |#4|) |#4|)) (-15 -3164 ((-444 (-1187 |#4|)) (-1187 |#4|))) (-15 -2046 ((-444 |#4|) |#4|)) (-15 -1585 ((-592) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592)))))) (-15 -4161 ((-444 |#4|) |#4| |#2|)) (-15 -1557 ((-2 (|:| -3489 (-1187 |#4|)) (|:| |polval| (-1187 |#3|))) (-1187 |#4|) (-1187 |#3|) (-592))) (-15 -2051 ((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-658 (-2 (|:| -4500 (-1187 |#4|)) (|:| -3215 (-592)))))) (-1187 |#4|) (-658 |#2|) (-658 (-658 |#3|)))) (-15 -2059 ((-2 (|:| |upol| (-1187 |#3|)) (|:| |Lval| (-658 |#3|)) (|:| |Lfact| (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592))))) (|:| |ctpol| |#3|)) (-1187 |#4|) (-658 |#2|) (-658 (-658 |#3|)))) (-15 -2921 (|#4| (-592) (-444 |#4|))) (-15 -3971 ((-141) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592)))) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592)))))) (-15 -3650 ((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-1187 |#3|) (-1187 |#3|) |#4| (-658 |#2|) (-658 (-790)) (-658 |#3|))) (-15 -3814 ((-658 (-790)) (-1187 |#4|) (-658 |#2|) (-790))) (-15 -4127 ((-1187 |#3|) (-1187 |#3|) (-592)))) (-815) (-869) (-323) (-977 |#3| |#1| |#2|)) (T -759)) 
+((-4127 (*1 *2 *2 *3) (-12 (-5 *2 (-1187 *6)) (-5 *3 (-592)) (-4 *6 (-323)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-759 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5)))) (-3814 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1187 *9)) (-5 *4 (-658 *7)) (-4 *7 (-869)) (-4 *9 (-977 *8 *6 *7)) (-4 *6 (-815)) (-4 *8 (-323)) (-5 *2 (-658 (-790))) (-5 *1 (-759 *6 *7 *8 *9)) (-5 *5 (-790)))) (-3650 (*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| -12 (-5 *4 (-1187 *11)) (-5 *6 (-658 *10)) (-5 *7 (-658 (-790))) (-5 *8 (-658 *11)) (-4 *10 (-869)) (-4 *11 (-323)) (-4 *9 (-815)) (-4 *5 (-977 *11 *9 *10)) (-5 *2 (-658 (-1187 *5))) (-5 *1 (-759 *9 *10 *11 *5)) (-5 *3 (-1187 *5)))) (-3971 (*1 *2 *3 *3) (-12 (-5 *3 (-658 (-2 (|:| -4500 (-1187 *6)) (|:| -3215 (-592))))) (-4 *6 (-323)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-759 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5)))) (-2921 (*1 *2 *3 *4) (-12 (-5 *3 (-592)) (-5 *4 (-444 *2)) (-4 *2 (-977 *7 *5 *6)) (-5 *1 (-759 *5 *6 *7 *2)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-323)))) (-2059 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1187 *9)) (-5 *4 (-658 *7)) (-5 *5 (-658 (-658 *8))) (-4 *7 (-869)) (-4 *8 (-323)) (-4 *9 (-977 *8 *6 *7)) (-4 *6 (-815)) (-5 *2 (-2 (|:| |upol| (-1187 *8)) (|:| |Lval| (-658 *8)) (|:| |Lfact| (-658 (-2 (|:| -4500 (-1187 *8)) (|:| -3215 (-592))))) (|:| |ctpol| *8))) (-5 *1 (-759 *6 *7 *8 *9)))) (-2051 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 *7)) (-5 *5 (-658 (-658 *8))) (-4 *7 (-869)) (-4 *8 (-323)) (-4 *6 (-815)) (-4 *9 (-977 *8 *6 *7)) (-5 *2 (-2 (|:| |unitPart| *9) (|:| |suPart| (-658 (-2 (|:| -4500 (-1187 *9)) (|:| -3215 (-592))))))) (-5 *1 (-759 *6 *7 *8 *9)) (-5 *3 (-1187 *9)))) (-1557 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-592)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-323)) (-4 *9 (-977 *8 *6 *7)) (-5 *2 (-2 (|:| -3489 (-1187 *9)) (|:| |polval| (-1187 *8)))) (-5 *1 (-759 *6 *7 *8 *9)) (-5 *3 (-1187 *9)) (-5 *4 (-1187 *8)))) (-4161 (*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-759 *5 *4 *6 *3)) (-4 *3 (-977 *6 *5 *4)))) (-1585 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4500 (-1187 *6)) (|:| -3215 (-592))))) (-4 *6 (-323)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-592)) (-5 *1 (-759 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5)))) (-2046 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-759 *4 *5 *6 *3)) (-4 *3 (-977 *6 *4 *5)))) (-3164 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-759 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) (-3164 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-759 *4 *5 *6 *3)) (-4 *3 (-977 *6 *4 *5))))) 
+(-10 -7 (-15 -3164 ((-444 |#4|) |#4|)) (-15 -3164 ((-444 (-1187 |#4|)) (-1187 |#4|))) (-15 -2046 ((-444 |#4|) |#4|)) (-15 -1585 ((-592) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592)))))) (-15 -4161 ((-444 |#4|) |#4| |#2|)) (-15 -1557 ((-2 (|:| -3489 (-1187 |#4|)) (|:| |polval| (-1187 |#3|))) (-1187 |#4|) (-1187 |#3|) (-592))) (-15 -2051 ((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-658 (-2 (|:| -4500 (-1187 |#4|)) (|:| -3215 (-592)))))) (-1187 |#4|) (-658 |#2|) (-658 (-658 |#3|)))) (-15 -2059 ((-2 (|:| |upol| (-1187 |#3|)) (|:| |Lval| (-658 |#3|)) (|:| |Lfact| (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592))))) (|:| |ctpol| |#3|)) (-1187 |#4|) (-658 |#2|) (-658 (-658 |#3|)))) (-15 -2921 (|#4| (-592) (-444 |#4|))) (-15 -3971 ((-141) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592)))) (-658 (-2 (|:| -4500 (-1187 |#3|)) (|:| -3215 (-592)))))) (-15 -3650 ((-3 (-658 (-1187 |#4|)) "failed") (-1187 |#4|) (-1187 |#3|) (-1187 |#3|) |#4| (-658 |#2|) (-658 (-790)) (-658 |#3|))) (-15 -3814 ((-658 (-790)) (-1187 |#4|) (-658 |#2|) (-790))) (-15 -4127 ((-1187 |#3|) (-1187 |#3|) (-592)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1191)) $) NIL)) (-4492 (((-433 (-1187 $)) $ (-631 $)) NIL (|has| |#2| (-582)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2165 (((-658 (-631 $)) $) NIL)) (-2178 (($ $ (-1111 $)) NIL) (($ $ (-1191)) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3147 (($ $ (-310 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL)) (-3743 (($ $) NIL (|has| |#2| (-582)))) (-3164 (((-444 $) $) NIL (|has| |#2| (-582)))) (-3652 (((-141) $ $) NIL (|has| |#2| (-582)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-631 $) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL) (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-980 |#2|)) "failed") $) NIL (|has| |#2| (-582))) (((-3 (-980 |#2|) "failed") $) NIL (|has| |#2| (-1075))) (((-3 (-761 |#1| |#2|) "failed") $) NIL) (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (-3836 (-12 (|has| |#2| (-582)) (|has| |#2| (-1065 (-592)))) (|has| |#2| (-1065 (-433 (-592))))))) (-2400 (((-631 $) $) NIL) (((-1191) $) NIL) ((|#2| $) NIL) (((-433 (-980 |#2|)) $) 20 (|has| |#2| (-582))) (((-980 |#2|) $) 26 (|has| |#2| (-1075))) (((-761 |#1| |#2|) $) 27) (((-592) $) NIL) (((-433 (-761 |#1| |#2|)) $) 25) (((-433 (-592)) $) NIL (-3836 (-12 (|has| |#2| (-582)) (|has| |#2| (-1065 (-592)))) (|has| |#2| (-1065 (-433 (-592))))))) (-1586 (($ $ $) NIL (|has| |#2| (-582)))) (-3945 (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL (|has| |#2| (-1075))) (((-706 |#2|) (-706 $)) NIL (|has| |#2| (-1075))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075))))) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#2| (-582)))) (-3679 (($ $ (-1111 $)) NIL) (($ $ (-1191)) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#2| (-582)))) (-2802 (((-141) $) NIL (|has| |#2| (-582)))) (-3870 (($ $ $) NIL)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| |#2| (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| |#2| (-908 (-405))))) (-2243 (($ $) NIL) (($ (-658 $)) NIL)) (-4388 (((-658 (-143)) $) NIL)) (-2791 (((-143) (-143)) NIL)) (-3558 (((-141) $) NIL)) (-3372 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-3838 (($ $) NIL)) (-1448 (((-1142 |#2| (-631 $)) $) NIL (|has| |#2| (-1075)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#2| (-582)))) (-2710 (((-1187 $) (-631 $)) NIL (|has| $ (-1075)))) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2731 (($ (-1 $ $) (-631 $)) NIL)) (-4160 (((-3 (-631 $) "failed") $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#2| (-582))) (($ $ $) NIL (|has| |#2| (-582)))) (-2685 (((-1173) $) NIL)) (-4486 (((-658 (-631 $)) $) NIL)) (-1462 (($ (-143) $) NIL) (($ (-143) (-658 $)) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL (|has| |#2| (-1131)))) (-2427 (((-3 (-2 (|:| |val| $) (|:| -3215 (-592))) "failed") $) NIL (|has| |#2| (-1075)))) (-2947 (((-3 (-658 $) "failed") $) NIL (|has| |#2| (-25)))) (-1649 (((-3 (-2 (|:| -1487 (-592)) (|:| |var| (-631 $))) "failed") $) NIL (|has| |#2| (-25)))) (-2257 (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $) NIL (|has| |#2| (-1131))) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-143)) NIL (|has| |#2| (-1075))) (((-3 (-2 (|:| |var| (-631 $)) (|:| -3215 (-592))) "failed") $ (-1191)) NIL (|has| |#2| (-1075)))) (-3013 (((-141) $ (-143)) NIL) (((-141) $ (-1191)) NIL)) (-4552 (($ $) NIL (-3836 (|has| |#2| (-502)) (|has| |#2| (-582))))) (-2535 (((-790) $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#2| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#2| (-582)))) (-3548 (($ (-658 $)) NIL (|has| |#2| (-582))) (($ $ $) NIL (|has| |#2| (-582)))) (-1319 (((-141) $ $) NIL) (((-141) $ (-1191)) NIL)) (-2944 (($ $ (-1191)) NIL) (($ $) NIL)) (-2283 (($ $) NIL)) (-4500 (((-444 $) $) NIL (|has| |#2| (-582)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-582))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#2| (-582)))) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#2| (-582)))) (-3554 (((-141) $) NIL (|has| $ (-1065 (-592))))) (-2806 (($ $ (-631 $) $) NIL) (($ $ (-658 (-631 $)) (-658 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-1191)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-1191) (-1 $ (-658 $))) NIL) (($ $ (-1191) (-1 $ $)) NIL) (($ $ (-658 (-143)) (-658 (-1 $ $))) NIL) (($ $ (-658 (-143)) (-658 (-1 $ (-658 $)))) NIL) (($ $ (-143) (-1 $ (-658 $))) NIL) (($ $ (-143) (-1 $ $)) NIL) (($ $ (-1191)) NIL (|has| |#2| (-633 (-565)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-633 (-565)))) (($ $) NIL (|has| |#2| (-633 (-565)))) (($ $ (-143) $ (-1191)) NIL (|has| |#2| (-633 (-565)))) (($ $ (-658 (-143)) (-658 $) (-1191)) NIL (|has| |#2| (-633 (-565)))) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ $))) NIL (|has| |#2| (-1075))) (($ $ (-658 (-1191)) (-658 (-790)) (-658 (-1 $ (-658 $)))) NIL (|has| |#2| (-1075))) (($ $ (-1191) (-790) (-1 $ (-658 $))) NIL (|has| |#2| (-1075))) (($ $ (-1191) (-790) (-1 $ $)) NIL (|has| |#2| (-1075)))) (-2769 (((-790) $) NIL (|has| |#2| (-582)))) (-3927 (($ (-143) $) NIL) (($ (-143) $ $) NIL) (($ (-143) $ $ $) NIL) (($ (-143) $ $ $ $) NIL) (($ (-143) (-658 $)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-582)))) (-2818 (($ $) NIL) (($ $ $) NIL)) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL)) (-2782 (($ $) NIL)) (-1456 (((-1142 |#2| (-631 $)) $) NIL (|has| |#2| (-582)))) (-3390 (($ $) NIL (|has| $ (-1075)))) (-1778 (((-914 (-592)) $) NIL (|has| |#2| (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| |#2| (-633 (-914 (-405))))) (($ (-444 $)) NIL (|has| |#2| (-582))) (((-565) $) NIL (|has| |#2| (-633 (-565))))) (-2227 (($ $ $) NIL (|has| |#2| (-502)))) (-2131 (($ $ $) NIL (|has| |#2| (-502)))) (-1683 (((-877) $) NIL) (($ (-631 $)) NIL) (($ (-1191)) NIL) (($ |#2|) NIL) (($ (-1142 |#2| (-631 $))) NIL (|has| |#2| (-1075))) (($ (-433 |#2|)) NIL (|has| |#2| (-582))) (($ (-980 (-433 |#2|))) NIL (|has| |#2| (-582))) (($ (-433 (-980 (-433 |#2|)))) NIL (|has| |#2| (-582))) (($ (-433 (-980 |#2|))) NIL (|has| |#2| (-582))) (($ (-980 |#2|)) NIL (|has| |#2| (-1075))) (($ $) NIL) (($ (-592)) NIL) (($ (-761 |#1| |#2|)) NIL) (($ (-433 (-761 |#1| |#2|))) 35) (($ (-433 (-592))) NIL (-3836 (|has| |#2| (-582)) (|has| |#2| (-1065 (-433 (-592))))))) (-1517 (((-3 $ "failed") $) NIL (|has| |#2| (-169)))) (-4010 (((-790)) NIL)) (-3280 (($ $) NIL) (($ (-658 $)) NIL)) (-4042 (($ $ $) NIL)) (-3038 (((-141) (-143)) NIL)) (-2537 (((-141) $ $) NIL)) (-3270 (($ (-1191) $) NIL) (($ (-1191) $ $) NIL) (($ (-1191) $ $ $) NIL) (($ (-1191) $ $ $ $) NIL) (($ (-1191) (-658 $)) NIL)) (-1424 (($ $ (-790)) NIL) (($ $ (-944)) NIL) (($ $ (-592)) NIL (-3836 (|has| |#2| (-502)) (|has| |#2| (-582))))) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3313 (($ (-1142 |#2| (-631 $)) (-1142 |#2| (-631 $))) NIL (|has| |#2| (-582))) (($ $ $) NIL)) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-944)) NIL) (($ $ $) NIL) (($ $ (-592)) NIL (-3836 (|has| |#2| (-502)) (|has| |#2| (-582))))) (* (($ (-433 (-592)) $) NIL (|has| |#2| (-582))) (($ $ (-433 (-592))) NIL (|has| |#2| (-582))) (($ |#2| $) NIL (|has| |#2| (-194))) (($ $ |#2|) NIL (|has| |#2| (-194))) (($ $ $) NIL) (($ (-592) $) NIL) (($ (-790) $) NIL) (($ (-944) $) NIL))) 
+(((-760 |#1| |#2|) (-13 (-456 |#2|) (-582) (-1065 (-761 |#1| |#2|)) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $)) (-15 -1683 ($ (-433 (-761 |#1| |#2|)))) (-15 -2400 ((-433 (-761 |#1| |#2|)) $)))) (-1191) (-13 (-1075) (-869) (-582))) (T -760)) 
+((-4559 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-760 *3 *4)) (-14 *3 (-1191)) (-4 *4 (-13 (-1075) (-869) (-582))))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) (-3313 (*1 *1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) (** (*1 *1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) (-3838 (*1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) (-2782 (*1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-433 (-761 *3 *4))) (-14 *3 (-1191)) (-4 *4 (-13 (-1075) (-869) (-582))) (-5 *1 (-760 *3 *4)))) (-2400 (*1 *2 *1) (-12 (-5 *2 (-433 (-761 *3 *4))) (-5 *1 (-760 *3 *4)) (-14 *3 (-1191)) (-4 *4 (-13 (-1075) (-869) (-582)))))) 
+(-13 (-456 |#2|) (-582) (-1065 (-761 |#1| |#2|)) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $)) (-15 -1683 ($ (-433 (-761 |#1| |#2|)))) (-15 -2400 ((-433 (-761 |#1| |#2|)) $)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2651 (((-1280 |#2|) $ (-790)) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-2085 (($ (-1187 |#2|)) NIL)) (-4492 (((-1187 $) $ (-1103)) NIL) (((-1187 |#2|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#2| (-582)))) (-1555 (($ $) NIL (|has| |#2| (-582)))) (-1313 (((-141) $) NIL (|has| |#2| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1103))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3250 (($ $ $) NIL (|has| |#2| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3743 (($ $) NIL (|has| |#2| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#2| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3652 (((-141) $ $) NIL (|has| |#2| (-388)))) (-1696 (($ $ (-790)) NIL)) (-1498 (($ $ (-790)) NIL)) (-1504 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#2| (-477)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-1103) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL)) (-2400 ((|#2| $) NIL) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-1103) $) 22) (((-1191) $) 23)) (-1544 (($ $ $ (-1103)) NIL (|has| |#2| (-194))) ((|#2| $ $) NIL (|has| |#2| (-194)))) (-1586 (($ $ $) NIL (|has| |#2| (-388)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#2| (-388)))) (-3213 (($ $ $) NIL)) (-2133 (($ $ $) NIL (|has| |#2| (-582)))) (-4369 (((-2 (|:| -1487 |#2|) (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#2| (-388)))) (-3262 (($ $) NIL (|has| |#2| (-477))) (($ $ (-1103)) NIL (|has| |#2| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#2| (-931)))) (-4209 (($ $ |#2| (-790) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1103) (-908 (-405))) (|has| |#2| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1103) (-908 (-592))) (|has| |#2| (-908 (-592)))))) (-4346 (((-790) $ $) NIL (|has| |#2| (-582)))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| |#2| (-1165)))) (-4533 (($ (-1187 |#2|) (-1103)) NIL) (($ (-1187 $) (-1103)) NIL)) (-3990 (($ $ (-790)) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#2| (-388)))) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#2| (-790)) 17) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1103)) NIL) (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4206 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1837 (($ $ $) NIL (|has| |#2| (-869)))) (-3319 (($ $ $) NIL (|has| |#2| (-869)))) (-2976 (($ (-1 (-790) (-790)) $) NIL)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-2070 (((-1187 |#2|) $) NIL)) (-3254 (((-3 (-1103) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#2| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-2685 (((-1173) $) NIL)) (-3768 (((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790)) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-1103)) (|:| -3215 (-790))) "failed") $) NIL)) (-3162 (($ $) NIL (|has| |#2| (-43 (-433 (-592)))))) (-3703 (($) NIL (|has| |#2| (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#2| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#2| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-4550 (($ $ (-790) |#2| $) NIL)) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#2| (-931)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#2| (-388)))) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#2| (-388)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1103) |#2|) NIL) (($ $ (-658 (-1103)) (-658 |#2|)) NIL) (($ $ (-1103) $) NIL) (($ $ (-658 (-1103)) (-658 $)) NIL)) (-2769 (((-790) $) NIL (|has| |#2| (-388)))) (-3927 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-433 $) (-433 $) (-433 $)) NIL (|has| |#2| (-582))) ((|#2| (-433 $) |#2|) NIL (|has| |#2| (-388))) (((-433 $) $ (-433 $)) NIL (|has| |#2| (-582)))) (-4510 (((-3 $ "failed") $ (-790)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-388)))) (-1482 (($ $ (-1103)) NIL (|has| |#2| (-194))) ((|#2| $) NIL (|has| |#2| (-194)))) (-3644 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) $) NIL)) (-4525 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-1103) (-633 (-565))) (|has| |#2| (-633 (-565)))))) (-1554 ((|#2| $) NIL (|has| |#2| (-477))) (($ $ (-1103)) NIL (|has| |#2| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#2| (-931))))) (-1528 (((-3 $ "failed") $ $) NIL (|has| |#2| (-582))) (((-3 (-433 $) "failed") (-433 $) $) NIL (|has| |#2| (-582)))) (-1683 (((-877) $) 13) (($ (-592)) NIL) (($ |#2|) 26) (($ (-1103)) NIL) (($ (-1276 |#1|)) 20) (($ (-980 |#2|)) 34) (($ (-1191)) 18) (($ (-433 (-592))) NIL (-3836 (|has| |#2| (-43 (-433 (-592)))) (|has| |#2| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#2| (-582)))) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-790)) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#2| (-931))) (|has| |#2| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#2| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#2| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) 14 T CONST)) (-1940 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#2| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#2| (-43 (-433 (-592))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-761 |#1| |#2|) (-13 (-1255 |#2|) (-10 -8 (-6 (-1065 (-1191))) (-15 -1683 ($ (-1276 |#1|))) (-15 -4550 ($ $ (-790) |#2| $)) (IF (|has| |#2| (-15 -4492 ((-1187 |#2|) |#2| (-1191)))) (-15 -1683 ($ |#2|)) |noBranch|) (-15 -1683 ($ (-980 |#2|))))) (-1191) (-1075)) (T -761)) 
+((-1683 (*1 *1 *2) (-12 (-5 *1 (-761 *3 *2)) (-14 *3 (-1191)) (-4 *2 (-1075)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *3)) (-14 *3 (-1191)) (-5 *1 (-761 *3 *4)) (-4 *4 (-1075)))) (-4550 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-790)) (-5 *1 (-761 *4 *3)) (-14 *4 (-1191)) (-4 *3 (-1075)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-980 *4)) (-4 *4 (-1075)) (-5 *1 (-761 *3 *4)) (-14 *3 (-1191))))) 
+(-13 (-1255 |#2|) (-10 -8 (-6 (-1065 (-1191))) (-15 -1683 ($ (-1276 |#1|))) (-15 -4550 ($ $ (-790) |#2| $)) (IF (|has| |#2| (-15 -4492 ((-1187 |#2|) |#2| (-1191)))) (-15 -1683 ($ |#2|)) |noBranch|) (-15 -1683 ($ (-980 |#2|))))) 
+((-1833 (($ $ (-944)) 12))) 
+(((-762 |#1| |#2|) (-10 -8 (-15 -1833 (|#1| |#1| (-944)))) (-763 |#2|) (-194)) (T -762)) 
+NIL 
+(-10 -8 (-15 -1833 (|#1| |#1| (-944)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2111 (($ $ (-944)) 27)) (-1833 (($ $ (-944)) 32)) (-2682 (($ $ (-944)) 28)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2131 (($ $ $) 24)) (-1683 (((-877) $) 11)) (-3667 (($ $ $ $) 25)) (-2844 (($ $ $) 23)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 29)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
+(((-763 |#1|) (-1311) (-194)) (T -763)) 
+((-1833 (*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-763 *3)) (-4 *3 (-194))))) 
+(-13 (-780) (-734 |t#1|) (-10 -8 (-15 -1833 ($ $ (-944))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-734 |#1|) . T) ((-737) . T) ((-780) . T) ((-1081 |#1|) . T) ((-1119) . T)) 
+((-4224 (((-1063) (-706 (-237)) (-592) (-141) (-592)) 24)) (-4230 (((-1063) (-706 (-237)) (-592) (-141) (-592)) 23))) 
+(((-764) (-10 -7 (-15 -4230 ((-1063) (-706 (-237)) (-592) (-141) (-592))) (-15 -4224 ((-1063) (-706 (-237)) (-592) (-141) (-592))))) (T -764)) 
+((-4224 (*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-141)) (-5 *2 (-1063)) (-5 *1 (-764)))) (-4230 (*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-141)) (-5 *2 (-1063)) (-5 *1 (-764))))) 
+(-10 -7 (-15 -4230 ((-1063) (-706 (-237)) (-592) (-141) (-592))) (-15 -4224 ((-1063) (-706 (-237)) (-592) (-141) (-592)))) 
+((-4244 (((-1063) (-592) (-592) (-592) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-79 FCN)))) 43)) (-3380 (((-1063) (-592) (-592) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-86 FCN)))) 39)) (-3386 (((-1063) (-237) (-237) (-237) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) 32))) 
+(((-765) (-10 -7 (-15 -3386 ((-1063) (-237) (-237) (-237) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3380 ((-1063) (-592) (-592) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-86 FCN))))) (-15 -4244 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-79 FCN))))))) (T -765)) 
+((-4244 (*1 *2 *3 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-79 FCN)))) (-5 *2 (-1063)) (-5 *1 (-765)))) (-3380 (*1 *2 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-86 FCN)))) (-5 *2 (-1063)) (-5 *1 (-765)))) (-3386 (*1 *2 *3 *3 *3 *3 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *2 (-1063)) (-5 *1 (-765))))) 
+(-10 -7 (-15 -3386 ((-1063) (-237) (-237) (-237) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3380 ((-1063) (-592) (-592) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-86 FCN))))) (-15 -4244 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-79 FCN)))))) 
+((-3392 (((-1063) (-592) (-592) (-706 (-237)) (-592)) 33)) (-3398 (((-1063) (-592) (-592) (-706 (-237)) (-592)) 32)) (-3404 (((-1063) (-592) (-706 (-237)) (-592)) 31)) (-3410 (((-1063) (-592) (-706 (-237)) (-592)) 30)) (-3416 (((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 29)) (-3423 (((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 28)) (-3428 (((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-592)) 27)) (-3434 (((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-592)) 26)) (-3440 (((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592)) 23)) (-3445 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592)) 22)) (-3453 (((-1063) (-592) (-706 (-237)) (-592)) 21)) (-3459 (((-1063) (-592) (-706 (-237)) (-592)) 20))) 
+(((-766) (-10 -7 (-15 -3459 ((-1063) (-592) (-706 (-237)) (-592))) (-15 -3453 ((-1063) (-592) (-706 (-237)) (-592))) (-15 -3445 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3440 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3434 ((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3428 ((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3423 ((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3416 ((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3410 ((-1063) (-592) (-706 (-237)) (-592))) (-15 -3404 ((-1063) (-592) (-706 (-237)) (-592))) (-15 -3398 ((-1063) (-592) (-592) (-706 (-237)) (-592))) (-15 -3392 ((-1063) (-592) (-592) (-706 (-237)) (-592))))) (T -766)) 
+((-3392 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3398 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3404 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3410 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3416 (*1 *2 *3 *3 *4 *5 *5 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3423 (*1 *2 *3 *3 *4 *5 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3428 (*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3434 (*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3440 (*1 *2 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3445 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3453 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766)))) (-3459 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(-10 -7 (-15 -3459 ((-1063) (-592) (-706 (-237)) (-592))) (-15 -3453 ((-1063) (-592) (-706 (-237)) (-592))) (-15 -3445 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3440 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3434 ((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3428 ((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3423 ((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3416 ((-1063) (-592) (-592) (-1173) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3410 ((-1063) (-592) (-706 (-237)) (-592))) (-15 -3404 ((-1063) (-592) (-706 (-237)) (-592))) (-15 -3398 ((-1063) (-592) (-592) (-706 (-237)) (-592))) (-15 -3392 ((-1063) (-592) (-592) (-706 (-237)) (-592)))) 
+((-4414 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-237) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN)))) 52)) (-4420 (((-1063) (-706 (-237)) (-706 (-237)) (-592) (-592)) 51)) (-4426 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN)))) 50)) (-4432 (((-1063) (-237) (-237) (-592) (-592) (-592) (-592)) 46)) (-4437 (((-1063) (-237) (-237) (-592) (-237) (-592) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) 45)) (-3622 (((-1063) (-237) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) 44)) (-3633 (((-1063) (-237) (-237) (-237) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) 43)) (-3643 (((-1063) (-237) (-237) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) 42)) (-3649 (((-1063) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) 38)) (-3656 (((-1063) (-237) (-237) (-592) (-706 (-237)) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) 37)) (-3670 (((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) 33)) (-3680 (((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) 32))) 
+(((-767) (-10 -7 (-15 -3680 ((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3670 ((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3656 ((-1063) (-237) (-237) (-592) (-706 (-237)) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3649 ((-1063) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3643 ((-1063) (-237) (-237) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G))))) (-15 -3633 ((-1063) (-237) (-237) (-237) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G))))) (-15 -3622 ((-1063) (-237) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G))))) (-15 -4437 ((-1063) (-237) (-237) (-592) (-237) (-592) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G))))) (-15 -4432 ((-1063) (-237) (-237) (-592) (-592) (-592) (-592))) (-15 -4426 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN))))) (-15 -4420 ((-1063) (-706 (-237)) (-706 (-237)) (-592) (-592))) (-15 -4414 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-237) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN))))))) (T -767)) 
+((-4414 (*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1063)) (-5 *1 (-767)))) (-4420 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-767)))) (-4426 (*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1063)) (-5 *1 (-767)))) (-4432 (*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-767)))) (-4437 (*1 *2 *3 *3 *4 *3 *4 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) (-5 *2 (-1063)) (-5 *1 (-767)))) (-3622 (*1 *2 *3 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) (-5 *2 (-1063)) (-5 *1 (-767)))) (-3633 (*1 *2 *3 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) (-5 *2 (-1063)) (-5 *1 (-767)))) (-3643 (*1 *2 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) (-5 *2 (-1063)) (-5 *1 (-767)))) (-3649 (*1 *2 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *2 (-1063)) (-5 *1 (-767)))) (-3656 (*1 *2 *3 *3 *4 *5 *3 *3 *4 *4 *4 *6) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-767)))) (-3670 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *2 (-1063)) (-5 *1 (-767)))) (-3680 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(-10 -7 (-15 -3680 ((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3670 ((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3656 ((-1063) (-237) (-237) (-592) (-706 (-237)) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3649 ((-1063) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958))))) (-15 -3643 ((-1063) (-237) (-237) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G))))) (-15 -3633 ((-1063) (-237) (-237) (-237) (-237) (-592) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G))))) (-15 -3622 ((-1063) (-237) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G))))) (-15 -4437 ((-1063) (-237) (-237) (-592) (-237) (-592) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G))))) (-15 -4432 ((-1063) (-237) (-237) (-592) (-592) (-592) (-592))) (-15 -4426 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-237) (-592) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN))))) (-15 -4420 ((-1063) (-706 (-237)) (-706 (-237)) (-592) (-592))) (-15 -4414 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-237) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN)))))) 
+((-4448 (((-1063) (-592) (-592) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-414)) (|:| |fp| (-81 G JACOBG JACGEP)))) 76)) (-4453 (((-1063) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL))) (-414) (-414)) 69) (((-1063) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL)))) 68)) (-4458 (((-1063) (-237) (-237) (-592) (-237) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-414)) (|:| |fp| (-90 FCNG)))) 57)) (-4464 (((-1063) (-706 (-237)) (-706 (-237)) (-592) (-237) (-237) (-237) (-592) (-592) (-592) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) 50)) (-4470 (((-1063) (-237) (-592) (-592) (-1173) (-592) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) 49)) (-3263 (((-1063) (-237) (-592) (-592) (-237) (-1173) (-237) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) 45)) (-3269 (((-1063) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) 42)) (-3276 (((-1063) (-237) (-592) (-592) (-592) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) 38))) 
+(((-768) (-10 -7 (-15 -3276 ((-1063) (-237) (-592) (-592) (-592) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT))))) (-15 -3269 ((-1063) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))))) (-15 -3263 ((-1063) (-237) (-592) (-592) (-237) (-1173) (-237) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT))))) (-15 -4470 ((-1063) (-237) (-592) (-592) (-1173) (-592) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT))))) (-15 -4464 ((-1063) (-706 (-237)) (-706 (-237)) (-592) (-237) (-237) (-237) (-592) (-592) (-592) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))))) (-15 -4458 ((-1063) (-237) (-237) (-592) (-237) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-414)) (|:| |fp| (-90 FCNG))))) (-15 -4453 ((-1063) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL))))) (-15 -4453 ((-1063) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL))) (-414) (-414))) (-15 -4448 ((-1063) (-592) (-592) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-414)) (|:| |fp| (-81 G JACOBG JACGEP))))))) (T -768)) 
+((-4448 (*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-80 FCN JACOBF JACEPS)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-81 G JACOBG JACGEP)))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-768)))) (-4453 (*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7 *8 *8) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL)))) (-5 *8 (-414)) (-5 *2 (-1063)) (-5 *1 (-768)))) (-4453 (*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL)))) (-5 *2 (-1063)) (-5 *1 (-768)))) (-4458 (*1 *2 *3 *3 *4 *3 *4 *4 *4 *5 *5 *5 *5 *4 *4 *6 *7) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-89 FCNF)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-90 FCNG)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768)))) (-4464 (*1 *2 *3 *3 *4 *5 *5 *5 *4 *4 *4 *3 *4 *4 *6) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *2 (-1063)) (-5 *1 (-768)))) (-4470 (*1 *2 *3 *4 *4 *5 *4 *3 *6 *3 *4 *7 *8 *9 *10) (-12 (-5 *4 (-592)) (-5 *5 (-1173)) (-5 *6 (-706 (-237))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-414)) (|:| |fp| (-76 PEDERV)))) (-5 *10 (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768)))) (-3263 (*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (-12 (-5 *4 (-592)) (-5 *5 (-1173)) (-5 *6 (-706 (-237))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768)))) (-3269 (*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768)))) (-3276 (*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(-10 -7 (-15 -3276 ((-1063) (-237) (-592) (-592) (-592) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT))))) (-15 -3269 ((-1063) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))))) (-15 -3263 ((-1063) (-237) (-592) (-592) (-237) (-1173) (-237) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT))))) (-15 -4470 ((-1063) (-237) (-592) (-592) (-1173) (-592) (-237) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT))))) (-15 -4464 ((-1063) (-706 (-237)) (-706 (-237)) (-592) (-237) (-237) (-237) (-592) (-592) (-592) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN))))) (-15 -4458 ((-1063) (-237) (-237) (-592) (-237) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-414)) (|:| |fp| (-90 FCNG))))) (-15 -4453 ((-1063) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL))))) (-15 -4453 ((-1063) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL))) (-414) (-414))) (-15 -4448 ((-1063) (-592) (-592) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-414)) (|:| |fp| (-81 G JACOBG JACGEP)))))) 
+((-3303 (((-1063) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-691 (-237)) (-592)) 45)) (-3309 (((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-1173) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-414)) (|:| |fp| (-88 BNDY)))) 41)) (-3316 (((-1063) (-592) (-592) (-592) (-592) (-237) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 23))) 
+(((-769) (-10 -7 (-15 -3316 ((-1063) (-592) (-592) (-592) (-592) (-237) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3309 ((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-1173) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-414)) (|:| |fp| (-88 BNDY))))) (-15 -3303 ((-1063) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-691 (-237)) (-592))))) (T -769)) 
+((-3303 (*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-691 (-237))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-769)))) (-3309 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-1173)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-87 PDEF)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-88 BNDY)))) (-5 *2 (-1063)) (-5 *1 (-769)))) (-3316 (*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-769))))) 
+(-10 -7 (-15 -3316 ((-1063) (-592) (-592) (-592) (-592) (-237) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3309 ((-1063) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-1173) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-414)) (|:| |fp| (-88 BNDY))))) (-15 -3303 ((-1063) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-691 (-237)) (-592)))) 
+((-4187 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-706 (-237)) (-237) (-237) (-592)) 35)) (-4267 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-237) (-237) (-592)) 34)) (-2207 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-706 (-237)) (-237) (-237) (-592)) 33)) (-4272 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 29)) (-4279 (((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 28)) (-4284 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592)) 27)) (-4289 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-592)) 23)) (-4296 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-592)) 22)) (-4302 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592)) 21)) (-4307 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592)) 20))) 
+(((-770) (-10 -7 (-15 -4307 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592))) (-15 -4302 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4296 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-592))) (-15 -4289 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-592))) (-15 -4284 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592))) (-15 -4279 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4272 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2207 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-706 (-237)) (-237) (-237) (-592))) (-15 -4267 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-237) (-237) (-592))) (-15 -4187 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-706 (-237)) (-237) (-237) (-592))))) (T -770)) 
+((-4187 (*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-770)))) (-4267 (*1 *2 *3 *4 *4 *4 *3 *3 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-770)))) (-2207 (*1 *2 *3 *4 *4 *4 *5 *4 *6 *6 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *6 (-237)) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-770)))) (-4272 (*1 *2 *3 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770)))) (-4279 (*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770)))) (-4284 (*1 *2 *3 *4 *4 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-770)))) (-4289 (*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770)))) (-4296 (*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770)))) (-4302 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770)))) (-4307 (*1 *2 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(-10 -7 (-15 -4307 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592))) (-15 -4302 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4296 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-592))) (-15 -4289 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-592))) (-15 -4284 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-237) (-592))) (-15 -4279 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4272 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2207 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-706 (-237)) (-237) (-237) (-592))) (-15 -4267 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-237) (-237) (-592))) (-15 -4187 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-706 (-237)) (-237) (-237) (-592)))) 
+((-4313 (((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592)) 45)) (-4317 (((-1063) (-592) (-592) (-592) (-237) (-706 (-237)) (-706 (-237)) (-592)) 44)) (-4323 (((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592)) 43)) (-4329 (((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 42)) (-4335 (((-1063) (-1173) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592)) 41)) (-4341 (((-1063) (-1173) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592)) 40)) (-4347 (((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592) (-592) (-592) (-237) (-706 (-237)) (-592)) 39)) (-4353 (((-1063) (-1173) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-592))) 38)) (-4359 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592)) 35)) (-2776 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592)) 34)) (-2783 (((-1063) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592)) 33)) (-2790 (((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 32)) (-2797 (((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-237) (-592)) 31)) (-2804 (((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-592)) 30)) (-3282 (((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-592) (-592) (-592)) 29)) (-3608 (((-1063) (-592) (-592) (-592) (-237) (-237) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592) (-706 (-592)) (-592) (-592) (-592)) 28)) (-4215 (((-1063) (-592) (-706 (-237)) (-237) (-592)) 24)) (-4237 (((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 20))) 
+(((-771) (-10 -7 (-15 -4237 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4215 ((-1063) (-592) (-706 (-237)) (-237) (-592))) (-15 -3608 ((-1063) (-592) (-592) (-592) (-237) (-237) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592) (-706 (-592)) (-592) (-592) (-592))) (-15 -3282 ((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-592) (-592) (-592))) (-15 -2804 ((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-592))) (-15 -2797 ((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-237) (-592))) (-15 -2790 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2783 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592))) (-15 -2776 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592))) (-15 -4359 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4353 ((-1063) (-1173) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-592)))) (-15 -4347 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592) (-592) (-592) (-237) (-706 (-237)) (-592))) (-15 -4341 ((-1063) (-1173) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592))) (-15 -4335 ((-1063) (-1173) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4329 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4323 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592))) (-15 -4317 ((-1063) (-592) (-592) (-592) (-237) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4313 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592))))) (T -771)) 
+((-4313 (*1 *2 *3 *3 *4 *4 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4317 (*1 *2 *3 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4323 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4329 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4335 (*1 *2 *3 *4 *5 *5 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4341 (*1 *2 *3 *4 *5 *4 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *7 *4) (-12 (-5 *3 (-1173)) (-5 *5 (-706 (-237))) (-5 *6 (-237)) (-5 *7 (-706 (-592))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4347 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *5 *3 *3 *3 *6 *4 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *6 (-237)) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4353 (*1 *2 *3 *4 *5 *5 *5 *6 *4 *4 *4 *5 *4 *5 *7) (-12 (-5 *3 (-1173)) (-5 *5 (-706 (-237))) (-5 *6 (-237)) (-5 *7 (-706 (-592))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4359 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771)))) (-2776 (*1 *2 *3 *4 *4 *5 *3 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-2783 (*1 *2 *3 *4 *4 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-2790 (*1 *2 *3 *3 *4 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771)))) (-2797 (*1 *2 *3 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-2804 (*1 *2 *3 *4 *4 *5 *3 *3 *4 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-3282 (*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-3608 (*1 *2 *3 *3 *3 *4 *4 *5 *5 *5 *3 *5 *5 *3 *6 *3 *3 *3) (-12 (-5 *5 (-706 (-237))) (-5 *6 (-706 (-592))) (-5 *3 (-592)) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4215 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-771)))) (-4237 (*1 *2 *3 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(-10 -7 (-15 -4237 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4215 ((-1063) (-592) (-706 (-237)) (-237) (-592))) (-15 -3608 ((-1063) (-592) (-592) (-592) (-237) (-237) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592) (-706 (-592)) (-592) (-592) (-592))) (-15 -3282 ((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-592) (-592) (-592))) (-15 -2804 ((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-237) (-592) (-592) (-592))) (-15 -2797 ((-1063) (-592) (-237) (-237) (-706 (-237)) (-592) (-592) (-237) (-592))) (-15 -2790 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2783 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592))) (-15 -2776 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592))) (-15 -4359 ((-1063) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4353 ((-1063) (-1173) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-592)))) (-15 -4347 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592) (-592) (-592) (-237) (-706 (-237)) (-592))) (-15 -4341 ((-1063) (-1173) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592))) (-15 -4335 ((-1063) (-1173) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4329 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4323 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592))) (-15 -4317 ((-1063) (-592) (-592) (-592) (-237) (-706 (-237)) (-706 (-237)) (-592))) (-15 -4313 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592) (-706 (-237)) (-706 (-237)) (-592) (-592) (-592)))) 
+((-2812 (((-1063) (-592) (-592) (-592) (-237) (-706 (-237)) (-592) (-706 (-237)) (-592)) 63)) (-2819 (((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-141) (-237) (-592) (-237) (-237) (-141) (-237) (-237) (-237) (-237) (-141) (-592) (-592) (-592) (-592) (-592) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-592)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN)))) 62)) (-2826 (((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-237) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-141) (-141) (-141) (-592) (-592) (-706 (-237)) (-706 (-592)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-70 QPHESS)))) 58)) (-2833 (((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-141) (-592) (-592) (-706 (-237)) (-592)) 51)) (-2841 (((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-71 FUNCT1)))) 50)) (-2849 (((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-68 LSFUN2)))) 46)) (-2857 (((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-84 LSFUN1)))) 42)) (-2864 (((-1063) (-592) (-237) (-237) (-592) (-237) (-141) (-237) (-237) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN)))) 38))) 
+(((-772) (-10 -7 (-15 -2864 ((-1063) (-592) (-237) (-237) (-592) (-237) (-141) (-237) (-237) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN))))) (-15 -2857 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-84 LSFUN1))))) (-15 -2849 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-68 LSFUN2))))) (-15 -2841 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-71 FUNCT1))))) (-15 -2833 ((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-141) (-592) (-592) (-706 (-237)) (-592))) (-15 -2826 ((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-237) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-141) (-141) (-141) (-592) (-592) (-706 (-237)) (-706 (-592)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-70 QPHESS))))) (-15 -2819 ((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-141) (-237) (-592) (-237) (-237) (-141) (-237) (-237) (-237) (-237) (-141) (-592) (-592) (-592) (-592) (-592) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-592)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN))))) (-15 -2812 ((-1063) (-592) (-592) (-592) (-237) (-706 (-237)) (-592) (-706 (-237)) (-592))))) (T -772)) 
+((-2812 (*1 *2 *3 *3 *3 *4 *5 *3 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-772)))) (-2819 (*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *3 *3 *5 *6 *3 *6 *6 *5 *6 *6 *6 *6 *5 *3 *3 *3 *3 *3 *6 *6 *6 *3 *3 *3 *3 *3 *7 *4 *4 *4 *4 *3 *8 *9) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-141)) (-5 *6 (-237)) (-5 *7 (-706 (-592))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-85 CONFUN)))) (-5 *9 (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN)))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-772)))) (-2826 (*1 *2 *3 *3 *3 *3 *3 *3 *3 *3 *4 *5 *5 *5 *5 *5 *5 *6 *6 *6 *3 *3 *5 *7 *3 *8) (-12 (-5 *5 (-706 (-237))) (-5 *6 (-141)) (-5 *7 (-706 (-592))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-70 QPHESS)))) (-5 *3 (-592)) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-772)))) (-2833 (*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-141)) (-5 *2 (-1063)) (-5 *1 (-772)))) (-2841 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *3 *5) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-71 FUNCT1)))) (-5 *2 (-1063)) (-5 *1 (-772)))) (-2849 (*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-68 LSFUN2)))) (-5 *2 (-1063)) (-5 *1 (-772)))) (-2857 (*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-84 LSFUN1)))) (-5 *2 (-1063)) (-5 *1 (-772)))) (-2864 (*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (-12 (-5 *3 (-592)) (-5 *5 (-141)) (-5 *6 (-706 (-237))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN)))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(-10 -7 (-15 -2864 ((-1063) (-592) (-237) (-237) (-592) (-237) (-141) (-237) (-237) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN))))) (-15 -2857 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-84 LSFUN1))))) (-15 -2849 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-68 LSFUN2))))) (-15 -2841 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-71 FUNCT1))))) (-15 -2833 ((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-141) (-592) (-592) (-706 (-237)) (-592))) (-15 -2826 ((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-237) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-141) (-141) (-141) (-592) (-592) (-706 (-237)) (-706 (-592)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-70 QPHESS))))) (-15 -2819 ((-1063) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-592) (-141) (-237) (-592) (-237) (-237) (-141) (-237) (-237) (-237) (-237) (-141) (-592) (-592) (-592) (-592) (-592) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-592) (-706 (-592)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN))))) (-15 -2812 ((-1063) (-592) (-592) (-592) (-237) (-706 (-237)) (-592) (-706 (-237)) (-592)))) 
+((-2872 (((-1063) (-1173) (-592) (-592) (-592) (-592) (-706 (-191 (-237))) (-706 (-191 (-237))) (-592)) 46)) (-2879 (((-1063) (-1173) (-1173) (-592) (-592) (-706 (-191 (-237))) (-592) (-706 (-191 (-237))) (-592) (-592) (-706 (-191 (-237))) (-592)) 45)) (-2886 (((-1063) (-592) (-592) (-592) (-706 (-191 (-237))) (-592)) 44)) (-2893 (((-1063) (-1173) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592)) 40)) (-2900 (((-1063) (-1173) (-1173) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-706 (-237)) (-592)) 39)) (-2907 (((-1063) (-592) (-592) (-592) (-706 (-237)) (-592)) 36)) (-2914 (((-1063) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592)) 35)) (-2922 (((-1063) (-592) (-592) (-592) (-592) (-658 (-141)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-237) (-237) (-592)) 34)) (-2929 (((-1063) (-592) (-592) (-592) (-706 (-592)) (-706 (-592)) (-706 (-592)) (-706 (-592)) (-141) (-237) (-141) (-706 (-592)) (-706 (-237)) (-592)) 33)) (-2937 (((-1063) (-592) (-592) (-592) (-592) (-237) (-141) (-141) (-658 (-141)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-592)) 32))) 
+(((-773) (-10 -7 (-15 -2937 ((-1063) (-592) (-592) (-592) (-592) (-237) (-141) (-141) (-658 (-141)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-592))) (-15 -2929 ((-1063) (-592) (-592) (-592) (-706 (-592)) (-706 (-592)) (-706 (-592)) (-706 (-592)) (-141) (-237) (-141) (-706 (-592)) (-706 (-237)) (-592))) (-15 -2922 ((-1063) (-592) (-592) (-592) (-592) (-658 (-141)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-237) (-237) (-592))) (-15 -2914 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592))) (-15 -2907 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-592))) (-15 -2900 ((-1063) (-1173) (-1173) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-706 (-237)) (-592))) (-15 -2893 ((-1063) (-1173) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2886 ((-1063) (-592) (-592) (-592) (-706 (-191 (-237))) (-592))) (-15 -2879 ((-1063) (-1173) (-1173) (-592) (-592) (-706 (-191 (-237))) (-592) (-706 (-191 (-237))) (-592) (-592) (-706 (-191 (-237))) (-592))) (-15 -2872 ((-1063) (-1173) (-592) (-592) (-592) (-592) (-706 (-191 (-237))) (-706 (-191 (-237))) (-592))))) (T -773)) 
+((-2872 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2879 (*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2886 (*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2893 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2900 (*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2907 (*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2914 (*1 *2 *3 *4 *3 *5 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2922 (*1 *2 *3 *3 *3 *3 *4 *5 *6 *6 *7 *7 *3) (-12 (-5 *4 (-658 (-141))) (-5 *5 (-706 (-237))) (-5 *6 (-706 (-592))) (-5 *7 (-237)) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2929 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *5 *6 *5 *4 *7 *3) (-12 (-5 *4 (-706 (-592))) (-5 *5 (-141)) (-5 *7 (-706 (-237))) (-5 *3 (-592)) (-5 *6 (-237)) (-5 *2 (-1063)) (-5 *1 (-773)))) (-2937 (*1 *2 *3 *3 *3 *3 *4 *5 *5 *6 *7 *8 *8 *3) (-12 (-5 *6 (-658 (-141))) (-5 *7 (-706 (-237))) (-5 *8 (-706 (-592))) (-5 *3 (-592)) (-5 *4 (-237)) (-5 *5 (-141)) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(-10 -7 (-15 -2937 ((-1063) (-592) (-592) (-592) (-592) (-237) (-141) (-141) (-658 (-141)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-592))) (-15 -2929 ((-1063) (-592) (-592) (-592) (-706 (-592)) (-706 (-592)) (-706 (-592)) (-706 (-592)) (-141) (-237) (-141) (-706 (-592)) (-706 (-237)) (-592))) (-15 -2922 ((-1063) (-592) (-592) (-592) (-592) (-658 (-141)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-237) (-237) (-592))) (-15 -2914 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592))) (-15 -2907 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-592))) (-15 -2900 ((-1063) (-1173) (-1173) (-592) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-706 (-237)) (-592))) (-15 -2893 ((-1063) (-1173) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2886 ((-1063) (-592) (-592) (-592) (-706 (-191 (-237))) (-592))) (-15 -2879 ((-1063) (-1173) (-1173) (-592) (-592) (-706 (-191 (-237))) (-592) (-706 (-191 (-237))) (-592) (-592) (-706 (-191 (-237))) (-592))) (-15 -2872 ((-1063) (-1173) (-592) (-592) (-592) (-592) (-706 (-191 (-237))) (-706 (-191 (-237))) (-592)))) 
+((-3857 (((-1063) (-592) (-592) (-592) (-592) (-592) (-141) (-592) (-141) (-592) (-706 (-191 (-237))) (-706 (-191 (-237))) (-592)) 64)) (-3862 (((-1063) (-592) (-592) (-592) (-592) (-592) (-141) (-592) (-141) (-592) (-706 (-237)) (-706 (-237)) (-592)) 60)) (-3867 (((-1063) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE))) (-414)) 56) (((-1063) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE)))) 55)) (-3872 (((-1063) (-592) (-592) (-592) (-237) (-141) (-592) (-706 (-237)) (-706 (-237)) (-592)) 37)) (-3879 (((-1063) (-592) (-592) (-237) (-237) (-592) (-592) (-706 (-237)) (-592)) 33)) (-3885 (((-1063) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-592) (-592) (-592)) 29)) (-2556 (((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592)) 28)) (-2562 (((-1063) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592)) 27)) (-2568 (((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592)) 26)) (-2574 (((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592)) 25)) (-2585 (((-1063) (-592) (-592) (-706 (-237)) (-592)) 24)) (-2591 (((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592)) 23)) (-2597 (((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592)) 22)) (-2603 (((-1063) (-706 (-237)) (-592) (-592) (-592) (-592)) 21)) (-2610 (((-1063) (-592) (-592) (-706 (-237)) (-592)) 20))) 
+(((-774) (-10 -7 (-15 -2610 ((-1063) (-592) (-592) (-706 (-237)) (-592))) (-15 -2603 ((-1063) (-706 (-237)) (-592) (-592) (-592) (-592))) (-15 -2597 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2591 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2585 ((-1063) (-592) (-592) (-706 (-237)) (-592))) (-15 -2574 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592))) (-15 -2568 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2562 ((-1063) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2556 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3885 ((-1063) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-592) (-592) (-592))) (-15 -3879 ((-1063) (-592) (-592) (-237) (-237) (-592) (-592) (-706 (-237)) (-592))) (-15 -3872 ((-1063) (-592) (-592) (-592) (-237) (-141) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3867 ((-1063) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE))))) (-15 -3867 ((-1063) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE))) (-414))) (-15 -3862 ((-1063) (-592) (-592) (-592) (-592) (-592) (-141) (-592) (-141) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3857 ((-1063) (-592) (-592) (-592) (-592) (-592) (-141) (-592) (-141) (-592) (-706 (-191 (-237))) (-706 (-191 (-237))) (-592))))) (T -774)) 
+((-3857 (*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-141)) (-5 *5 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-3862 (*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-141)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-3867 (*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE)))) (-5 *8 (-414)) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-774)))) (-3867 (*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE)))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-774)))) (-3872 (*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (-12 (-5 *3 (-592)) (-5 *5 (-141)) (-5 *6 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-774)))) (-3879 (*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-774)))) (-3885 (*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2556 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2562 (*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2568 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2574 (*1 *2 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2585 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2591 (*1 *2 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2597 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2603 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-774)))) (-2610 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(-10 -7 (-15 -2610 ((-1063) (-592) (-592) (-706 (-237)) (-592))) (-15 -2603 ((-1063) (-706 (-237)) (-592) (-592) (-592) (-592))) (-15 -2597 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2591 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2585 ((-1063) (-592) (-592) (-706 (-237)) (-592))) (-15 -2574 ((-1063) (-592) (-592) (-592) (-592) (-706 (-237)) (-592))) (-15 -2568 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2562 ((-1063) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -2556 ((-1063) (-592) (-592) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3885 ((-1063) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-592) (-592) (-592))) (-15 -3879 ((-1063) (-592) (-592) (-237) (-237) (-592) (-592) (-706 (-237)) (-592))) (-15 -3872 ((-1063) (-592) (-592) (-592) (-237) (-141) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3867 ((-1063) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE))))) (-15 -3867 ((-1063) (-592) (-592) (-237) (-592) (-592) (-592) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE))) (-414))) (-15 -3862 ((-1063) (-592) (-592) (-592) (-592) (-592) (-141) (-592) (-141) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3857 ((-1063) (-592) (-592) (-592) (-592) (-592) (-141) (-592) (-141) (-592) (-706 (-191 (-237))) (-706 (-191 (-237))) (-592)))) 
+((-3721 (((-1063) (-592) (-592) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-75 APROD)))) 60)) (-3726 (((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-592)) (-592) (-706 (-237)) (-592) (-592) (-592) (-592)) 56)) (-3731 (((-1063) (-592) (-706 (-237)) (-141) (-237) (-592) (-592) (-592) (-592) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-414)) (|:| |fp| (-78 MSOLVE)))) 55)) (-3736 (((-1063) (-592) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592) (-706 (-592)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592)) 36)) (-3741 (((-1063) (-592) (-592) (-592) (-237) (-592) (-706 (-237)) (-706 (-237)) (-592)) 35)) (-3745 (((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592)) 31)) (-3750 (((-1063) (-592) (-706 (-237)) (-592) (-706 (-592)) (-706 (-592)) (-592) (-706 (-592)) (-706 (-237))) 30)) (-3755 (((-1063) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-592)) 26)) (-3760 (((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592)) 25)) (-3770 (((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592)) 24)) (-3778 (((-1063) (-592) (-706 (-191 (-237))) (-592) (-592) (-592) (-592) (-706 (-191 (-237))) (-592)) 20))) 
+(((-775) (-10 -7 (-15 -3778 ((-1063) (-592) (-706 (-191 (-237))) (-592) (-592) (-592) (-592) (-706 (-191 (-237))) (-592))) (-15 -3770 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592))) (-15 -3760 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592))) (-15 -3755 ((-1063) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-592))) (-15 -3750 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-592)) (-706 (-592)) (-592) (-706 (-592)) (-706 (-237)))) (-15 -3745 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3741 ((-1063) (-592) (-592) (-592) (-237) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3736 ((-1063) (-592) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592) (-706 (-592)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592))) (-15 -3731 ((-1063) (-592) (-706 (-237)) (-141) (-237) (-592) (-592) (-592) (-592) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-414)) (|:| |fp| (-78 MSOLVE))))) (-15 -3726 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-592)) (-592) (-706 (-237)) (-592) (-592) (-592) (-592))) (-15 -3721 ((-1063) (-592) (-592) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-75 APROD))))))) (T -775)) 
+((-3721 (*1 *2 *3 *3 *4 *4 *4 *4 *3 *3 *3 *3 *5 *3 *6) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-75 APROD)))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3726 (*1 *2 *3 *4 *3 *4 *5 *3 *4 *3 *3 *3 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3731 (*1 *2 *3 *4 *5 *6 *3 *3 *3 *3 *6 *3 *7 *8) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-141)) (-5 *6 (-237)) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-73 APROD)))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-78 MSOLVE)))) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3736 (*1 *2 *3 *3 *4 *3 *5 *3 *5 *4 *5 *5 *4 *4 *5 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3741 (*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3745 (*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3750 (*1 *2 *3 *4 *3 *5 *5 *3 *5 *4) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3755 (*1 *2 *3 *4 *3 *4 *4 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3760 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3770 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-775)))) (-3778 (*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(-10 -7 (-15 -3778 ((-1063) (-592) (-706 (-191 (-237))) (-592) (-592) (-592) (-592) (-706 (-191 (-237))) (-592))) (-15 -3770 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592))) (-15 -3760 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-592))) (-15 -3755 ((-1063) (-706 (-237)) (-592) (-706 (-237)) (-592) (-592) (-592))) (-15 -3750 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-592)) (-706 (-592)) (-592) (-706 (-592)) (-706 (-237)))) (-15 -3745 ((-1063) (-592) (-592) (-706 (-237)) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3741 ((-1063) (-592) (-592) (-592) (-237) (-592) (-706 (-237)) (-706 (-237)) (-592))) (-15 -3736 ((-1063) (-592) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592) (-706 (-592)) (-706 (-237)) (-706 (-592)) (-706 (-592)) (-706 (-237)) (-706 (-237)) (-706 (-592)) (-592))) (-15 -3731 ((-1063) (-592) (-706 (-237)) (-141) (-237) (-592) (-592) (-592) (-592) (-237) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-414)) (|:| |fp| (-78 MSOLVE))))) (-15 -3726 ((-1063) (-592) (-706 (-237)) (-592) (-706 (-237)) (-706 (-592)) (-592) (-706 (-237)) (-592) (-592) (-592) (-592))) (-15 -3721 ((-1063) (-592) (-592) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-706 (-237)) (-592) (-3 (|:| |fn| (-414)) (|:| |fp| (-75 APROD)))))) 
+((-3811 (((-1063) (-1173) (-592) (-592) (-706 (-237)) (-592) (-592) (-706 (-237))) 28)) (-3816 (((-1063) (-1173) (-592) (-592) (-706 (-237))) 27)) (-3823 (((-1063) (-1173) (-592) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592) (-706 (-237))) 26)) (-3828 (((-1063) (-592) (-592) (-592) (-706 (-237))) 20))) 
+(((-776) (-10 -7 (-15 -3828 ((-1063) (-592) (-592) (-592) (-706 (-237)))) (-15 -3823 ((-1063) (-1173) (-592) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592) (-706 (-237)))) (-15 -3816 ((-1063) (-1173) (-592) (-592) (-706 (-237)))) (-15 -3811 ((-1063) (-1173) (-592) (-592) (-706 (-237)) (-592) (-592) (-706 (-237)))))) (T -776)) 
+((-3811 (*1 *2 *3 *4 *4 *5 *4 *4 *5) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-776)))) (-3816 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-776)))) (-3823 (*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (-12 (-5 *3 (-1173)) (-5 *5 (-706 (-237))) (-5 *6 (-706 (-592))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-776)))) (-3828 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-776))))) 
+(-10 -7 (-15 -3828 ((-1063) (-592) (-592) (-592) (-706 (-237)))) (-15 -3823 ((-1063) (-1173) (-592) (-592) (-706 (-237)) (-592) (-706 (-592)) (-592) (-706 (-237)))) (-15 -3816 ((-1063) (-1173) (-592) (-592) (-706 (-237)))) (-15 -3811 ((-1063) (-1173) (-592) (-592) (-706 (-237)) (-592) (-592) (-706 (-237))))) 
+((-3578 (((-1063) (-237) (-237) (-237) (-237) (-592)) 62)) (-3584 (((-1063) (-237) (-237) (-237) (-592)) 61)) (-3590 (((-1063) (-237) (-237) (-237) (-592)) 60)) (-3597 (((-1063) (-237) (-237) (-592)) 59)) (-3603 (((-1063) (-237) (-592)) 58)) (-3615 (((-1063) (-237) (-592)) 57)) (-3628 (((-1063) (-237) (-592)) 56)) (-3638 (((-1063) (-237) (-592)) 55)) (-3662 (((-1063) (-237) (-592)) 54)) (-3675 (((-1063) (-237) (-592)) 53)) (-3687 (((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592)) 52)) (-3692 (((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592)) 51)) (-3697 (((-1063) (-237) (-592)) 50)) (-3704 (((-1063) (-237) (-592)) 49)) (-3709 (((-1063) (-237) (-592)) 48)) (-3715 (((-1063) (-237) (-592)) 47)) (-3840 (((-1063) (-592) (-237) (-191 (-237)) (-592) (-1173) (-592)) 46)) (-3846 (((-1063) (-1173) (-191 (-237)) (-1173) (-592)) 45)) (-3851 (((-1063) (-1173) (-191 (-237)) (-1173) (-592)) 44)) (-3465 (((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592)) 43)) (-3471 (((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592)) 42)) (-3476 (((-1063) (-237) (-592)) 39)) (-3482 (((-1063) (-237) (-592)) 38)) (-3488 (((-1063) (-237) (-592)) 37)) (-3493 (((-1063) (-237) (-592)) 36)) (-3498 (((-1063) (-237) (-592)) 35)) (-3503 (((-1063) (-237) (-592)) 34)) (-3509 (((-1063) (-237) (-592)) 33)) (-3518 (((-1063) (-237) (-592)) 32)) (-3523 (((-1063) (-237) (-592)) 31)) (-3528 (((-1063) (-237) (-592)) 30)) (-3533 (((-1063) (-237) (-237) (-237) (-592)) 29)) (-3539 (((-1063) (-237) (-592)) 28)) (-3544 (((-1063) (-237) (-592)) 27)) (-3551 (((-1063) (-237) (-592)) 26)) (-3557 (((-1063) (-237) (-592)) 25)) (-3563 (((-1063) (-237) (-592)) 24)) (-3570 (((-1063) (-191 (-237)) (-592)) 20))) 
+(((-777) (-10 -7 (-15 -3570 ((-1063) (-191 (-237)) (-592))) (-15 -3563 ((-1063) (-237) (-592))) (-15 -3557 ((-1063) (-237) (-592))) (-15 -3551 ((-1063) (-237) (-592))) (-15 -3544 ((-1063) (-237) (-592))) (-15 -3539 ((-1063) (-237) (-592))) (-15 -3533 ((-1063) (-237) (-237) (-237) (-592))) (-15 -3528 ((-1063) (-237) (-592))) (-15 -3523 ((-1063) (-237) (-592))) (-15 -3518 ((-1063) (-237) (-592))) (-15 -3509 ((-1063) (-237) (-592))) (-15 -3503 ((-1063) (-237) (-592))) (-15 -3498 ((-1063) (-237) (-592))) (-15 -3493 ((-1063) (-237) (-592))) (-15 -3488 ((-1063) (-237) (-592))) (-15 -3482 ((-1063) (-237) (-592))) (-15 -3476 ((-1063) (-237) (-592))) (-15 -3471 ((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3465 ((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3851 ((-1063) (-1173) (-191 (-237)) (-1173) (-592))) (-15 -3846 ((-1063) (-1173) (-191 (-237)) (-1173) (-592))) (-15 -3840 ((-1063) (-592) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3715 ((-1063) (-237) (-592))) (-15 -3709 ((-1063) (-237) (-592))) (-15 -3704 ((-1063) (-237) (-592))) (-15 -3697 ((-1063) (-237) (-592))) (-15 -3692 ((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3687 ((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3675 ((-1063) (-237) (-592))) (-15 -3662 ((-1063) (-237) (-592))) (-15 -3638 ((-1063) (-237) (-592))) (-15 -3628 ((-1063) (-237) (-592))) (-15 -3615 ((-1063) (-237) (-592))) (-15 -3603 ((-1063) (-237) (-592))) (-15 -3597 ((-1063) (-237) (-237) (-592))) (-15 -3590 ((-1063) (-237) (-237) (-237) (-592))) (-15 -3584 ((-1063) (-237) (-237) (-237) (-592))) (-15 -3578 ((-1063) (-237) (-237) (-237) (-237) (-592))))) (T -777)) 
+((-3578 (*1 *2 *3 *3 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3584 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3590 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3597 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3603 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3615 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3628 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3638 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3662 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3675 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3687 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *6 (-1173)) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3692 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *6 (-1173)) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3697 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3704 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3709 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3715 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3840 (*1 *2 *3 *4 *5 *3 *6 *3) (-12 (-5 *3 (-592)) (-5 *5 (-191 (-237))) (-5 *6 (-1173)) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3846 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1173)) (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3851 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1173)) (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3465 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *6 (-1173)) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3471 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *6 (-1173)) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3476 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3482 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3488 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3493 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3498 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3503 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3509 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3518 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3523 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3528 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3533 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3539 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3544 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3551 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3557 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3563 (*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777)))) (-3570 (*1 *2 *3 *4) (-12 (-5 *3 (-191 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(-10 -7 (-15 -3570 ((-1063) (-191 (-237)) (-592))) (-15 -3563 ((-1063) (-237) (-592))) (-15 -3557 ((-1063) (-237) (-592))) (-15 -3551 ((-1063) (-237) (-592))) (-15 -3544 ((-1063) (-237) (-592))) (-15 -3539 ((-1063) (-237) (-592))) (-15 -3533 ((-1063) (-237) (-237) (-237) (-592))) (-15 -3528 ((-1063) (-237) (-592))) (-15 -3523 ((-1063) (-237) (-592))) (-15 -3518 ((-1063) (-237) (-592))) (-15 -3509 ((-1063) (-237) (-592))) (-15 -3503 ((-1063) (-237) (-592))) (-15 -3498 ((-1063) (-237) (-592))) (-15 -3493 ((-1063) (-237) (-592))) (-15 -3488 ((-1063) (-237) (-592))) (-15 -3482 ((-1063) (-237) (-592))) (-15 -3476 ((-1063) (-237) (-592))) (-15 -3471 ((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3465 ((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3851 ((-1063) (-1173) (-191 (-237)) (-1173) (-592))) (-15 -3846 ((-1063) (-1173) (-191 (-237)) (-1173) (-592))) (-15 -3840 ((-1063) (-592) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3715 ((-1063) (-237) (-592))) (-15 -3709 ((-1063) (-237) (-592))) (-15 -3704 ((-1063) (-237) (-592))) (-15 -3697 ((-1063) (-237) (-592))) (-15 -3692 ((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3687 ((-1063) (-237) (-191 (-237)) (-592) (-1173) (-592))) (-15 -3675 ((-1063) (-237) (-592))) (-15 -3662 ((-1063) (-237) (-592))) (-15 -3638 ((-1063) (-237) (-592))) (-15 -3628 ((-1063) (-237) (-592))) (-15 -3615 ((-1063) (-237) (-592))) (-15 -3603 ((-1063) (-237) (-592))) (-15 -3597 ((-1063) (-237) (-237) (-592))) (-15 -3590 ((-1063) (-237) (-237) (-237) (-592))) (-15 -3584 ((-1063) (-237) (-237) (-237) (-592))) (-15 -3578 ((-1063) (-237) (-237) (-237) (-237) (-592)))) 
+((-1590 (((-1285)) 18)) (-2147 (((-1173)) 22)) (-4591 (((-1173)) 21)) (-1407 (((-1123) (-1191) (-706 (-592))) 35) (((-1123) (-1191) (-706 (-237))) 31)) (-4140 (((-141)) 16)) (-2370 (((-1173) (-1173)) 25))) 
+(((-778) (-10 -7 (-15 -4591 ((-1173))) (-15 -2147 ((-1173))) (-15 -2370 ((-1173) (-1173))) (-15 -1407 ((-1123) (-1191) (-706 (-237)))) (-15 -1407 ((-1123) (-1191) (-706 (-592)))) (-15 -4140 ((-141))) (-15 -1590 ((-1285))))) (T -778)) 
+((-1590 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-778)))) (-4140 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-778)))) (-1407 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-706 (-592))) (-5 *2 (-1123)) (-5 *1 (-778)))) (-1407 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-706 (-237))) (-5 *2 (-1123)) (-5 *1 (-778)))) (-2370 (*1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-778)))) (-2147 (*1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-778)))) (-4591 (*1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-778))))) 
+(-10 -7 (-15 -4591 ((-1173))) (-15 -2147 ((-1173))) (-15 -2370 ((-1173) (-1173))) (-15 -1407 ((-1123) (-1191) (-706 (-237)))) (-15 -1407 ((-1123) (-1191) (-706 (-592)))) (-15 -4140 ((-141))) (-15 -1590 ((-1285)))) 
+((-2131 (($ $ $) 10)) (-3667 (($ $ $ $) 9)) (-2844 (($ $ $) 12))) 
+(((-779 |#1|) (-10 -8 (-15 -2844 (|#1| |#1| |#1|)) (-15 -2131 (|#1| |#1| |#1|)) (-15 -3667 (|#1| |#1| |#1| |#1|))) (-780)) (T -779)) 
+NIL 
+(-10 -8 (-15 -2844 (|#1| |#1| |#1|)) (-15 -2131 (|#1| |#1| |#1|)) (-15 -3667 (|#1| |#1| |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2111 (($ $ (-944)) 27)) (-2682 (($ $ (-944)) 28)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2131 (($ $ $) 24)) (-1683 (((-877) $) 11)) (-3667 (($ $ $ $) 25)) (-2844 (($ $ $) 23)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 29)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 26))) 
+(((-780) (-1311)) (T -780)) 
+((-3667 (*1 *1 *1 *1 *1) (-4 *1 (-780))) (-2131 (*1 *1 *1 *1) (-4 *1 (-780))) (-2844 (*1 *1 *1 *1) (-4 *1 (-780)))) 
+(-13 (-21) (-737) (-10 -8 (-15 -3667 ($ $ $ $)) (-15 -2131 ($ $ $)) (-15 -2844 ($ $ $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-737) . T) ((-1119) . T)) 
+((-1683 (((-877) $) NIL) (($ (-592)) 10))) 
+(((-781 |#1|) (-10 -8 (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) (-782)) (T -781)) 
+NIL 
+(-10 -8 (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2503 (((-3 $ "failed") $) 39)) (-2111 (($ $ (-944)) 27) (($ $ (-790)) 34)) (-3371 (((-3 $ "failed") $) 37)) (-3558 (((-141) $) 33)) (-4158 (((-3 $ "failed") $) 38)) (-2682 (($ $ (-944)) 28) (($ $ (-790)) 35)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2131 (($ $ $) 24)) (-1683 (((-877) $) 11) (($ (-592)) 30)) (-4010 (((-790)) 31)) (-3667 (($ $ $ $) 25)) (-2844 (($ $ $) 23)) (-3514 (($) 17 T CONST)) (-4257 (($) 32 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 29) (($ $ (-790)) 36)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 26))) 
+(((-782) (-1311)) (T -782)) 
+((-4010 (*1 *2) (-12 (-4 *1 (-782)) (-5 *2 (-790)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-782))))) 
+(-13 (-780) (-739) (-10 -8 (-15 -4010 ((-790))) (-15 -1683 ($ (-592))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-737) . T) ((-739) . T) ((-780) . T) ((-1119) . T)) 
+((-2102 (((-658 (-2 (|:| |outval| (-191 |#1|)) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 (-191 |#1|)))))) (-706 (-191 (-433 (-592)))) |#1|) 27)) (-2171 (((-658 (-191 |#1|)) (-706 (-191 (-433 (-592)))) |#1|) 19)) (-4198 (((-980 (-191 (-433 (-592)))) (-706 (-191 (-433 (-592)))) (-1191)) 16) (((-980 (-191 (-433 (-592)))) (-706 (-191 (-433 (-592))))) 15))) 
+(((-783 |#1|) (-10 -7 (-15 -4198 ((-980 (-191 (-433 (-592)))) (-706 (-191 (-433 (-592)))))) (-15 -4198 ((-980 (-191 (-433 (-592)))) (-706 (-191 (-433 (-592)))) (-1191))) (-15 -2171 ((-658 (-191 |#1|)) (-706 (-191 (-433 (-592)))) |#1|)) (-15 -2102 ((-658 (-2 (|:| |outval| (-191 |#1|)) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 (-191 |#1|)))))) (-706 (-191 (-433 (-592)))) |#1|))) (-13 (-388) (-867))) (T -783)) 
+((-2102 (*1 *2 *3 *4) (-12 (-5 *3 (-706 (-191 (-433 (-592))))) (-5 *2 (-658 (-2 (|:| |outval| (-191 *4)) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 (-191 *4))))))) (-5 *1 (-783 *4)) (-4 *4 (-13 (-388) (-867))))) (-2171 (*1 *2 *3 *4) (-12 (-5 *3 (-706 (-191 (-433 (-592))))) (-5 *2 (-658 (-191 *4))) (-5 *1 (-783 *4)) (-4 *4 (-13 (-388) (-867))))) (-4198 (*1 *2 *3 *4) (-12 (-5 *3 (-706 (-191 (-433 (-592))))) (-5 *4 (-1191)) (-5 *2 (-980 (-191 (-433 (-592))))) (-5 *1 (-783 *5)) (-4 *5 (-13 (-388) (-867))))) (-4198 (*1 *2 *3) (-12 (-5 *3 (-706 (-191 (-433 (-592))))) (-5 *2 (-980 (-191 (-433 (-592))))) (-5 *1 (-783 *4)) (-4 *4 (-13 (-388) (-867)))))) 
+(-10 -7 (-15 -4198 ((-980 (-191 (-433 (-592)))) (-706 (-191 (-433 (-592)))))) (-15 -4198 ((-980 (-191 (-433 (-592)))) (-706 (-191 (-433 (-592)))) (-1191))) (-15 -2171 ((-658 (-191 |#1|)) (-706 (-191 (-433 (-592)))) |#1|)) (-15 -2102 ((-658 (-2 (|:| |outval| (-191 |#1|)) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 (-191 |#1|)))))) (-706 (-191 (-433 (-592)))) |#1|))) 
+((-2867 (((-195 (-592)) |#1|) 25))) 
+(((-784 |#1|) (-10 -7 (-15 -2867 ((-195 (-592)) |#1|))) (-430)) (T -784)) 
+((-2867 (*1 *2 *3) (-12 (-5 *2 (-195 (-592))) (-5 *1 (-784 *3)) (-4 *3 (-430))))) 
+(-10 -7 (-15 -2867 ((-195 (-592)) |#1|))) 
+((-1763 ((|#1| |#1| |#1|) 24)) (-4308 ((|#1| |#1| |#1|) 23)) (-3696 ((|#1| |#1| |#1|) 31)) (-4262 ((|#1| |#1| |#1|) 27)) (-4156 (((-3 |#1| "failed") |#1| |#1|) 26)) (-4084 (((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|) 22))) 
+(((-785 |#1| |#2|) (-10 -7 (-15 -4084 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -4308 (|#1| |#1| |#1|)) (-15 -1763 (|#1| |#1| |#1|)) (-15 -4156 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4262 (|#1| |#1| |#1|)) (-15 -3696 (|#1| |#1| |#1|))) (-725 |#2|) (-388)) (T -785)) 
+((-3696 (*1 *2 *2 *2) (-12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) (-4262 (*1 *2 *2 *2) (-12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) (-4156 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) (-1763 (*1 *2 *2 *2) (-12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) (-4308 (*1 *2 *2 *2) (-12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) (-4084 (*1 *2 *3 *3) (-12 (-4 *4 (-388)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-785 *3 *4)) (-4 *3 (-725 *4))))) 
+(-10 -7 (-15 -4084 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -4308 (|#1| |#1| |#1|)) (-15 -1763 (|#1| |#1| |#1|)) (-15 -4156 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4262 (|#1| |#1| |#1|)) (-15 -3696 (|#1| |#1| |#1|))) 
+((-2904 (((-1187 |#1|) (-658 |#1|)) 25))) 
+(((-786 |#1|) (-10 -7 (-15 -2904 ((-1187 |#1|) (-658 |#1|)))) (-582)) (T -786)) 
+((-2904 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-582)) (-5 *2 (-1187 *4)) (-5 *1 (-786 *4))))) 
+(-10 -7 (-15 -2904 ((-1187 |#1|) (-658 |#1|)))) 
+((-2583 (((-2 (|:| -2195 (-706 (-592))) (|:| |basisDen| (-592)) (|:| |basisInv| (-706 (-592)))) (-592)) 58)) (-4023 (((-2 (|:| -2195 (-706 (-592))) (|:| |basisDen| (-592)) (|:| |basisInv| (-706 (-592))))) 56)) (-1482 (((-592)) 68))) 
+(((-787 |#1| |#2|) (-10 -7 (-15 -1482 ((-592))) (-15 -4023 ((-2 (|:| -2195 (-706 (-592))) (|:| |basisDen| (-592)) (|:| |basisInv| (-706 (-592)))))) (-15 -2583 ((-2 (|:| -2195 (-706 (-592))) (|:| |basisDen| (-592)) (|:| |basisInv| (-706 (-592)))) (-592)))) (-1255 (-592)) (-435 (-592) |#1|)) (T -787)) 
+((-2583 (*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-787 *4 *5)) (-4 *5 (-435 *3 *4)))) (-4023 (*1 *2) (-12 (-4 *3 (-1255 (-592))) (-5 *2 (-2 (|:| -2195 (-706 (-592))) (|:| |basisDen| (-592)) (|:| |basisInv| (-706 (-592))))) (-5 *1 (-787 *3 *4)) (-4 *4 (-435 (-592) *3)))) (-1482 (*1 *2) (-12 (-4 *3 (-1255 *2)) (-5 *2 (-592)) (-5 *1 (-787 *3 *4)) (-4 *4 (-435 *2 *3))))) 
+(-10 -7 (-15 -1482 ((-592))) (-15 -4023 ((-2 (|:| -2195 (-706 (-592))) (|:| |basisDen| (-592)) (|:| |basisInv| (-706 (-592)))))) (-15 -2583 ((-2 (|:| -2195 (-706 (-592))) (|:| |basisDen| (-592)) (|:| |basisInv| (-706 (-592)))) (-592)))) 
+((-1641 (((-141) $ $) NIL)) (-2400 (((-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) $) 15)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 14) (($ (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 8) (($ (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 10) (($ (-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) 12)) (-3255 (((-141) $ $) NIL))) 
+(((-788) (-13 (-1119) (-10 -8 (-15 -1683 ($ (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1683 ($ (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1683 ($ (-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) (-15 -1683 ((-877) $)) (-15 -2400 ((-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) $))))) (T -788)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-788)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *1 (-788)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *1 (-788)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) (-5 *1 (-788)))) (-2400 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) (-5 *1 (-788))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1683 ($ (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1683 ($ (-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) (-15 -1683 ((-877) $)) (-15 -2400 ((-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) $)))) 
+((-3407 (((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|))) 14) (((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|)) (-658 (-1191))) 13)) (-4005 (((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|))) 16) (((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|)) (-658 (-1191))) 15))) 
+(((-789 |#1|) (-10 -7 (-15 -3407 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|)) (-658 (-1191)))) (-15 -3407 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|)))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|)) (-658 (-1191)))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|))))) (-582)) (T -789)) 
+((-4005 (*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *4)))))) (-5 *1 (-789 *4)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *5)))))) (-5 *1 (-789 *5)))) (-3407 (*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *4)))))) (-5 *1 (-789 *4)))) (-3407 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *5)))))) (-5 *1 (-789 *5))))) 
+(-10 -7 (-15 -3407 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|)) (-658 (-1191)))) (-15 -3407 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|)))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|)) (-658 (-1191)))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-980 |#1|))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4079 (($ $ $) 6)) (-2350 (((-3 $ "failed") $ $) 9)) (-3651 (($ $ (-592)) 7)) (-3001 (($) NIL T CONST)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($ $) NIL)) (-1599 (($ $ $) NIL)) (-3558 (((-141) $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3548 (($ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-1683 (((-877) $) NIL)) (-1424 (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (* (($ (-790) $) NIL) (($ (-944) $) NIL) (($ $ $) NIL))) 
+(((-790) (-13 (-815) (-743) (-10 -8 (-15 -1599 ($ $ $)) (-15 -1586 ($ $ $)) (-15 -3548 ($ $ $)) (-15 -4570 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -3616 ((-3 $ "failed") $ $)) (-15 -3651 ($ $ (-592))) (-15 -4290 ($ $)) (-6 (-4627 "*"))))) (T -790)) 
+((-1599 (*1 *1 *1 *1) (-5 *1 (-790))) (-1586 (*1 *1 *1 *1) (-5 *1 (-790))) (-3548 (*1 *1 *1 *1) (-5 *1 (-790))) (-4570 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2230 (-790)) (|:| -3027 (-790)))) (-5 *1 (-790)))) (-3616 (*1 *1 *1 *1) (|partial| -5 *1 (-790))) (-3651 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-790)))) (-4290 (*1 *1 *1) (-5 *1 (-790)))) 
+(-13 (-815) (-743) (-10 -8 (-15 -1599 ($ $ $)) (-15 -1586 ($ $ $)) (-15 -3548 ($ $ $)) (-15 -4570 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -3616 ((-3 $ "failed") $ $)) (-15 -3651 ($ $ (-592))) (-15 -4290 ($ $)) (-6 (-4627 "*")))) 
+((-4005 (((-3 |#2| "failed") |#2| |#2| (-143) (-1191)) 35))) 
+(((-791 |#1| |#2|) (-10 -7 (-15 -4005 ((-3 |#2| "failed") |#2| |#2| (-143) (-1191)))) (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171)) (-13 (-29 |#1|) (-1211) (-987))) (T -791)) 
+((-4005 (*1 *2 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-143)) (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-791 *5 *2)) (-4 *2 (-13 (-29 *5) (-1211) (-987)))))) 
+(-10 -7 (-15 -4005 ((-3 |#2| "failed") |#2| |#2| (-143) (-1191)))) 
+((-1683 (((-793) |#1|) 8))) 
+(((-792 |#1|) (-10 -7 (-15 -1683 ((-793) |#1|))) (-1225)) (T -792)) 
+((-1683 (*1 *2 *3) (-12 (-5 *2 (-793)) (-5 *1 (-792 *3)) (-4 *3 (-1225))))) 
+(-10 -7 (-15 -1683 ((-793) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 7)) (-3255 (((-141) $ $) 9))) 
+(((-793) (-1119)) (T -793)) 
+NIL 
+(-1119) 
+((-2793 ((|#2| |#4|) 35))) 
+(((-794 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2793 (|#2| |#4|))) (-477) (-1255 |#1|) (-741 |#1| |#2|) (-1255 |#3|)) (T -794)) 
+((-2793 (*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-741 *4 *2)) (-4 *2 (-1255 *4)) (-5 *1 (-794 *4 *2 *5 *3)) (-4 *3 (-1255 *5))))) 
+(-10 -7 (-15 -2793 (|#2| |#4|))) 
+((-3371 (((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|) 56)) (-2279 (((-1285) (-1173) (-1173) |#4| |#5|) 33)) (-1999 ((|#4| |#4| |#5|) 72)) (-4398 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|) 76)) (-2490 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|) 15))) 
+(((-795 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3371 ((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|)) (-15 -1999 (|#4| |#4| |#5|)) (-15 -4398 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2279 ((-1285) (-1173) (-1173) |#4| |#5|)) (-15 -2490 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1094 |#1| |#2| |#3| |#4|)) (T -795)) 
+((-2490 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-795 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-2279 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-1173)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *4 (-1089 *6 *7 *8)) (-5 *2 (-1285)) (-5 *1 (-795 *6 *7 *8 *4 *5)) (-4 *5 (-1094 *6 *7 *8 *4)))) (-4398 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-795 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-1999 (*1 *2 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *2 (-1089 *4 *5 *6)) (-5 *1 (-795 *4 *5 *6 *2 *3)) (-4 *3 (-1094 *4 *5 *6 *2)))) (-3371 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *3))) (-5 *1 (-795 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(-10 -7 (-15 -3371 ((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|)) (-15 -1999 (|#4| |#4| |#5|)) (-15 -4398 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2279 ((-1285) (-1173) (-1173) |#4| |#5|)) (-15 -2490 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|))) 
+((-4368 (((-3 (-1187 (-1187 |#1|)) "failed") |#4|) 43)) (-2941 (((-658 |#4|) |#4|) 15)) (-3417 ((|#4| |#4|) 11))) 
+(((-796 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2941 ((-658 |#4|) |#4|)) (-15 -4368 ((-3 (-1187 (-1187 |#1|)) "failed") |#4|)) (-15 -3417 (|#4| |#4|))) (-373) (-349 |#1|) (-1255 |#2|) (-1255 |#3|) (-944)) (T -796)) 
+((-3417 (*1 *2 *2) (-12 (-4 *3 (-373)) (-4 *4 (-349 *3)) (-4 *5 (-1255 *4)) (-5 *1 (-796 *3 *4 *5 *2 *6)) (-4 *2 (-1255 *5)) (-14 *6 (-944)))) (-4368 (*1 *2 *3) (|partial| -12 (-4 *4 (-373)) (-4 *5 (-349 *4)) (-4 *6 (-1255 *5)) (-5 *2 (-1187 (-1187 *4))) (-5 *1 (-796 *4 *5 *6 *3 *7)) (-4 *3 (-1255 *6)) (-14 *7 (-944)))) (-2941 (*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *5 (-349 *4)) (-4 *6 (-1255 *5)) (-5 *2 (-658 *3)) (-5 *1 (-796 *4 *5 *6 *3 *7)) (-4 *3 (-1255 *6)) (-14 *7 (-944))))) 
+(-10 -7 (-15 -2941 ((-658 |#4|) |#4|)) (-15 -4368 ((-3 (-1187 (-1187 |#1|)) "failed") |#4|)) (-15 -3417 (|#4| |#4|))) 
+((-1641 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-2400 (($ (-1237 |#1|)) 21)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 26)) (-2951 (((-1137) $) NIL)) (-2227 (($ $ $) NIL)) (-2131 (($ $ $) NIL)) (-1683 (((-877) $) 11)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-4257 (($) 18 T CONST)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ $ $) 24))) 
+(((-797 |#1|) (-13 (-502) (-10 -8 (-15 -2400 ($ (-1237 |#1|))))) (-373)) (T -797)) 
+((-2400 (*1 *1 *2) (-12 (-5 *2 (-1237 *3)) (-4 *3 (-373)) (-5 *1 (-797 *3))))) 
+(-13 (-502) (-10 -8 (-15 -2400 ($ (-1237 |#1|))))) 
+((-2678 (((-2 (|:| |deter| (-658 (-1187 |#5|))) (|:| |dterm| (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-658 |#1|)) (|:| |nlead| (-658 |#5|))) (-1187 |#5|) (-658 |#1|) (-658 |#5|)) 51)) (-2734 (((-658 (-790)) |#1|) 12))) 
+(((-798 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2678 ((-2 (|:| |deter| (-658 (-1187 |#5|))) (|:| |dterm| (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-658 |#1|)) (|:| |nlead| (-658 |#5|))) (-1187 |#5|) (-658 |#1|) (-658 |#5|))) (-15 -2734 ((-658 (-790)) |#1|))) (-1255 |#4|) (-815) (-869) (-323) (-977 |#4| |#2| |#3|)) (T -798)) 
+((-2734 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-5 *2 (-658 (-790))) (-5 *1 (-798 *3 *4 *5 *6 *7)) (-4 *3 (-1255 *6)) (-4 *7 (-977 *6 *4 *5)))) (-2678 (*1 *2 *3 *4 *5) (-12 (-4 *6 (-1255 *9)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-323)) (-4 *10 (-977 *9 *7 *8)) (-5 *2 (-2 (|:| |deter| (-658 (-1187 *10))) (|:| |dterm| (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| *10))))) (|:| |nfacts| (-658 *6)) (|:| |nlead| (-658 *10)))) (-5 *1 (-798 *6 *7 *8 *9 *10)) (-5 *3 (-1187 *10)) (-5 *4 (-658 *6)) (-5 *5 (-658 *10))))) 
+(-10 -7 (-15 -2678 ((-2 (|:| |deter| (-658 (-1187 |#5|))) (|:| |dterm| (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-658 |#1|)) (|:| |nlead| (-658 |#5|))) (-1187 |#5|) (-658 |#1|) (-658 |#5|))) (-15 -2734 ((-658 (-790)) |#1|))) 
+((-2206 (((-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal"))) (-658 |#2|)) 18) (((-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|) 16)) (-4455 (((-658 (-658 |#2|)) |#2| (-592) (-592) (-3 "left" "center" "right" "vertical" "horizontal")) 32)) (-2094 (((-658 (-658 |#2|)) |#2| (-658 (-658 |#2|))) 24)) (-1748 (((-790) (-658 (-658 |#2|))) 27))) 
+(((-799 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4455 ((-658 (-658 |#2|)) |#2| (-592) (-592) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -1748 ((-790) (-658 (-658 |#2|)))) (-15 -2094 ((-658 (-658 |#2|)) |#2| (-658 (-658 |#2|)))) (-15 -2206 ((-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|)) (-15 -2206 ((-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal"))) (-658 |#2|)))) (-1075) (-346 |#1| |#3|) (-252 |#4| (-790)) (-790)) (T -799)) 
+((-2206 (*1 *2 *3) (-12 (-5 *3 (-658 *5)) (-4 *5 (-346 *4 *6)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-4 *4 (-1075)) (-5 *2 (-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-799 *4 *5 *6 *7)))) (-2206 (*1 *2 *3 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *2 (-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-799 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) (-2094 (*1 *2 *3 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-346 *4 *5)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-4 *4 (-1075)) (-5 *1 (-799 *4 *3 *5 *6)))) (-1748 (*1 *2 *3) (-12 (-5 *3 (-658 (-658 *5))) (-4 *5 (-346 *4 *6)) (-4 *6 (-252 *7 *2)) (-14 *7 *2) (-4 *4 (-1075)) (-5 *2 (-790)) (-5 *1 (-799 *4 *5 *6 *7)))) (-4455 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-592)) (-5 *5 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *6 (-1075)) (-4 *7 (-252 *8 (-790))) (-14 *8 (-790)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-799 *6 *3 *7 *8)) (-4 *3 (-346 *6 *7))))) 
+(-10 -7 (-15 -4455 ((-658 (-658 |#2|)) |#2| (-592) (-592) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -1748 ((-790) (-658 (-658 |#2|)))) (-15 -2094 ((-658 (-658 |#2|)) |#2| (-658 (-658 |#2|)))) (-15 -2206 ((-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|)) (-15 -2206 ((-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal"))) (-658 |#2|)))) 
+((-2093 (((-658 (-2 (|:| |outval| |#1|) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 |#1|))))) (-706 (-433 (-592))) |#1|) 27)) (-4211 (((-658 |#1|) (-706 (-433 (-592))) |#1|) 19)) (-4198 (((-980 (-433 (-592))) (-706 (-433 (-592))) (-1191)) 16) (((-980 (-433 (-592))) (-706 (-433 (-592)))) 15))) 
+(((-800 |#1|) (-10 -7 (-15 -4198 ((-980 (-433 (-592))) (-706 (-433 (-592))))) (-15 -4198 ((-980 (-433 (-592))) (-706 (-433 (-592))) (-1191))) (-15 -4211 ((-658 |#1|) (-706 (-433 (-592))) |#1|)) (-15 -2093 ((-658 (-2 (|:| |outval| |#1|) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 |#1|))))) (-706 (-433 (-592))) |#1|))) (-13 (-388) (-867))) (T -800)) 
+((-2093 (*1 *2 *3 *4) (-12 (-5 *3 (-706 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| |outval| *4) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 *4)))))) (-5 *1 (-800 *4)) (-4 *4 (-13 (-388) (-867))))) (-4211 (*1 *2 *3 *4) (-12 (-5 *3 (-706 (-433 (-592)))) (-5 *2 (-658 *4)) (-5 *1 (-800 *4)) (-4 *4 (-13 (-388) (-867))))) (-4198 (*1 *2 *3 *4) (-12 (-5 *3 (-706 (-433 (-592)))) (-5 *4 (-1191)) (-5 *2 (-980 (-433 (-592)))) (-5 *1 (-800 *5)) (-4 *5 (-13 (-388) (-867))))) (-4198 (*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-592)))) (-5 *2 (-980 (-433 (-592)))) (-5 *1 (-800 *4)) (-4 *4 (-13 (-388) (-867)))))) 
+(-10 -7 (-15 -4198 ((-980 (-433 (-592))) (-706 (-433 (-592))))) (-15 -4198 ((-980 (-433 (-592))) (-706 (-433 (-592))) (-1191))) (-15 -4211 ((-658 |#1|) (-706 (-433 (-592))) |#1|)) (-15 -2093 ((-658 (-2 (|:| |outval| |#1|) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 |#1|))))) (-706 (-433 (-592))) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 10)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) NIL)) (-2324 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2306 (($ $ (-592) (-592)) NIL) (($ $ (-592)) NIL)) (-1915 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL)) (-2982 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL)) (-3188 (($ $) NIL)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-4143 (($ $ (-592)) NIL (|has| $ (-6 -4626)))) (-3652 (((-141) $ $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3651 (($ $ (-592)) 36)) (-3047 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626)))) (-3153 (($ $ $) NIL (|has| $ (-6 -4626)))) (-4496 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626)))) (-2101 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626)))) (-3932 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626))) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-1246 (-592)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626))) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ "last" (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626))) (($ $ "rest" $) NIL (|has| $ (-6 -4626))) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ "first" (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626))) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ "value" (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-2881 (($ (-592) |#1| $) 41)) (-3113 (($ (-1 (-141) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL)) (-1765 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL)) (-3800 (($ $ $) 51)) (-3001 (($) NIL T CONST)) (-4083 (($ $) 21)) (-1366 (($ $ (-790)) NIL) (($ $) 14)) (-3792 (($ (-592) $) 78) (($ $) 31)) (-1378 (($ $) 35)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119))))) (-4459 (($ (-1 (-141) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL) (($ (-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119))))) (-1586 (($ $ $) NIL)) (-4593 (($ $) NIL)) (-3657 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $ (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119)))) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $ (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4625)))) (-3371 (((-3 $ "failed") $) 38)) (-1599 (($ $ $) NIL)) (-1426 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626)))) (-3959 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592)) NIL)) (-3891 (((-141) (-141)) 30) (((-141)) 29)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-3868 (((-141) $) NIL)) (-1541 (($ $) 22)) (-2273 (((-141) $) NIL)) (-4004 (((-658 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4625)))) (-3333 (((-3 (-592) "failed") $) 16)) (-4346 (((-592) $ (-592)) NIL) (((-592) $) 19) (((-592) $) 19)) (-3558 (((-141) $) NIL)) (-4219 (((-790) $) NIL)) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119)))) (-3242 (($ (-790) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL)) (-3990 (($ $ (-944)) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2027 (((-141) $) NIL)) (-1535 (($ (-658 $) (-658 (-790)) (-592)) 85)) (-4526 (($ $ (-658 (-1103)) (-658 (-592))) NIL) (($ $ (-1103) (-592)) NIL) (($ |#1| (-592)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-4467 (((-658 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3987 (($ (-1 (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $ $) NIL) (($ (-1 (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-4063 (((-658 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL)) (-3683 (((-141) $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1640 (($ $) NIL)) (-1323 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-4255 (($ $ (-790)) NIL) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL)) (-4552 (($ $) 39)) (-3666 (($ (-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-4479 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) 12)) (-1918 (($ $ (-790)) NIL) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL)) (-2508 (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592)) 24)) (-2360 ((|#1| $ (-592)) 25)) (-4050 (((-3 (-2 (|:| |k| (-592)) (|:| |c| |#1|)) "failed") (-1 (-141) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL)) (-4301 (($ $ (-592)) 89)) (-1892 (($ $ (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2807 (($ $ (-592)) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2955 (((-141) $) NIL)) (-2393 (((-141) $) NIL)) (-3630 (((-141) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4625)))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-592))))) (($ $ (-658 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) (-658 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) NIL (-12 (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-325 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119)))) (($ $ (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (-12 (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-325 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119)))) (($ $ (-310 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) NIL (-12 (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-325 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119)))) (($ $ (-658 (-310 (-2 (|:| |k| (-592)) (|:| |c| |#1|))))) NIL (-12 (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-325 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119))))) (-2769 (((-790) $) NIL)) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119))))) (-4210 (((-658 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL)) (-2943 (((-141) $) 23)) (-2890 (($) 94)) (-3927 (($ $ $) NIL (|has| (-592) (-1131))) ((|#1| $ (-592)) NIL) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592)) NIL) (($ $ (-1246 (-592))) NIL) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ "last") NIL) (($ $ "rest") NIL) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ "first") NIL) (((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ "value") NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2920 (((-592) $ $) NIL)) (-3644 (($ $) NIL (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-4048 (($ (-1 $)) 34)) (-4525 (((-592) $) NIL)) (-3228 (((-141) $) NIL)) (-2399 (($ $) NIL)) (-1337 (($ $) NIL (|has| $ (-6 -4626)))) (-3318 (((-790) $) NIL)) (-3184 (($ $) NIL)) (-3452 (((-790) (-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119)))) (((-790) (-1 (-141) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) 95)) (-3619 (($ $ (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4626))) (($ $ $) NIL (|has| $ (-6 -4626)))) (-2266 (($ $ (-2 (|:| |k| (-592)) (|:| |c| |#1|))) NIL) (($ (-658 $)) NIL) (($ (-2 (|:| |k| (-592)) (|:| |c| |#1|)) $) 32) (($ $ $) NIL)) (-1700 (($ $) NIL)) (-1683 (((-877) $) 65) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) NIL (|has| |#1| (-194))) (($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) 27) (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) 26)) (-1937 ((|#1| $ (-592)) NIL)) (-1963 ((|#1| $) 86)) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| (-2 (|:| |k| (-592)) (|:| |c| |#1|)) (-1119)))) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) NIL)) (-2537 (((-141) $ $) NIL)) (-2642 ((|#1| $ (-592)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-592)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-3369 (((-141) (-1 (-141) (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4625)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 17 T CONST)) (-4257 (($) 74 T CONST)) (-1940 (($ $) NIL (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL) (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) 47) (($ $ $) 43)) (-3300 (($ $ $) 53)) (** (($ $ (-944)) NIL) (($ $ (-790)) 79) (($ $ (-592)) 52)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 42) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ |#1| $) 46) (($ $ |#1|) 100)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-801 |#1|) (-13 (-665 |#1|) (-690 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) (-10 -8 (-15 -2508 ((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592))))) (-388)) (T -801)) 
+((-2508 (*1 *2 *1 *3) (-12 (-5 *2 (-2 (|:| |k| (-592)) (|:| |c| *4))) (-5 *1 (-801 *4)) (-4 *4 (-388)) (-5 *3 (-592))))) 
+(-13 (-665 |#1|) (-690 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) (-10 -8 (-15 -2508 ((-2 (|:| |k| (-592)) (|:| |c| |#1|)) $ (-592))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 34)) (-4085 (((-658 |#2|) $) NIL)) (-4492 (((-1187 $) $ |#2|) NIL) (((-1187 |#1|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 |#2|)) NIL)) (-3188 (($ $) 28)) (-3078 (((-141) $ $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3250 (($ $ $) 92 (|has| |#1| (-582)))) (-3181 (((-658 $) $ $) 105 (|has| |#1| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 |#2| "failed") $) NIL) (((-3 $ "failed") (-980 (-433 (-592)))) NIL (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#2| (-633 (-1191))))) (((-3 $ "failed") (-980 (-592))) NIL (-3836 (-12 (|has| |#1| (-43 (-592))) (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-43 (-433 (-592)))))) (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#2| (-633 (-1191)))))) (((-3 $ "failed") (-980 |#1|)) NIL (-3836 (-12 (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-43 (-433 (-592))))) (-3252 (|has| |#1| (-43 (-592))))) (-12 (|has| |#1| (-43 (-592))) (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-43 (-433 (-592))))) (-3252 (|has| |#1| (-574)))) (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-1021 (-592))))))) (((-3 (-1142 |#1| |#2|) "failed") $) 18)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) ((|#2| $) NIL) (($ (-980 (-433 (-592)))) NIL (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#2| (-633 (-1191))))) (($ (-980 (-592))) NIL (-3836 (-12 (|has| |#1| (-43 (-592))) (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-43 (-433 (-592)))))) (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#2| (-633 (-1191)))))) (($ (-980 |#1|)) NIL (-3836 (-12 (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-43 (-433 (-592))))) (-3252 (|has| |#1| (-43 (-592))))) (-12 (|has| |#1| (-43 (-592))) (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-43 (-433 (-592))))) (-3252 (|has| |#1| (-574)))) (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-1021 (-592))))))) (((-1142 |#1| |#2|) $) NIL)) (-1544 (($ $ $ |#2|) NIL (|has| |#1| (-194))) (($ $ $) 103 (|has| |#1| (-582)))) (-4593 (($ $) NIL) (($ $ |#2|) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-2172 (((-141) $ $) NIL) (((-141) $ (-658 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-2034 (((-141) $) NIL)) (-4369 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 69)) (-4544 (($ $) 118 (|has| |#1| (-477)))) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ |#2|) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-1342 (($ $) NIL (|has| |#1| (-582)))) (-2481 (($ $) NIL (|has| |#1| (-582)))) (-3383 (($ $ $) 64) (($ $ $ |#2|) NIL)) (-1877 (($ $ $) 67) (($ $ $ |#2|) NIL)) (-4209 (($ $ |#1| (-558 |#2|) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| |#1| (-908 (-405))) (|has| |#2| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| |#1| (-908 (-592))) (|has| |#2| (-908 (-592)))))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-2479 (((-141) $ $) NIL) (((-141) $ (-658 $)) NIL)) (-2707 (($ $ $ $ $) 89 (|has| |#1| (-582)))) (-3259 ((|#2| $) 19)) (-4533 (($ (-1187 |#1|) |#2|) NIL) (($ (-1187 $) |#2|) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-558 |#2|)) NIL) (($ $ |#2| (-790)) 36) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-4371 (($ $ $) 60)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ |#2|) NIL)) (-1469 (((-141) $) NIL)) (-4206 (((-558 |#2|) $) NIL) (((-790) $ |#2|) NIL) (((-658 (-790)) $ (-658 |#2|)) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-1824 (((-790) $) 20)) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-558 |#2|) (-558 |#2|)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3254 (((-3 |#2| "failed") $) NIL)) (-3158 (($ $) NIL (|has| |#1| (-477)))) (-4568 (($ $) NIL (|has| |#1| (-477)))) (-4003 (((-658 $) $) NIL)) (-4473 (($ $) 37)) (-3923 (($ $) NIL (|has| |#1| (-477)))) (-3026 (((-658 $) $) 41)) (-1508 (($ $) 39)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL) (($ $ |#2|) 45)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-3037 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -3116 (-790))) $ $) 81)) (-2198 (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $) 66) (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $ |#2|) NIL)) (-4517 (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -3027 $)) $ $) NIL) (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -3027 $)) $ $ |#2|) NIL)) (-1499 (($ $ $) 71) (($ $ $ |#2|) NIL)) (-1494 (($ $ $) 74) (($ $ $ |#2|) NIL)) (-2685 (((-1173) $) NIL)) (-3722 (($ $ $) 107 (|has| |#1| (-582)))) (-2434 (((-658 $) $) 30)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| |#2|) (|:| -3215 (-790))) "failed") $) NIL)) (-2346 (((-141) $ $) NIL) (((-141) $ (-658 $)) NIL)) (-1751 (($ $ $) NIL)) (-3703 (($ $) 21)) (-3085 (((-141) $ $) NIL)) (-4442 (((-141) $ $) NIL) (((-141) $ (-658 $)) NIL)) (-1803 (($ $ $) NIL)) (-3296 (($ $) 23)) (-2951 (((-1137) $) NIL)) (-1453 (((-2 (|:| -3548 $) (|:| |coef2| $)) $ $) 98 (|has| |#1| (-582)))) (-2845 (((-2 (|:| -3548 $) (|:| |coef1| $)) $ $) 95 (|has| |#1| (-582)))) (-4559 (((-141) $) 52)) (-4565 ((|#1| $) 55)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 ((|#1| |#1| $) 115 (|has| |#1| (-477))) (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-2049 (((-2 (|:| -3548 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 101 (|has| |#1| (-582)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) 83 (|has| |#1| (-582)))) (-2909 (($ $ |#1|) 111 (|has| |#1| (-582))) (($ $ $) NIL (|has| |#1| (-582)))) (-3194 (($ $ |#1|) 110 (|has| |#1| (-582))) (($ $ $) NIL (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ |#2| |#1|) NIL) (($ $ (-658 |#2|) (-658 |#1|)) NIL) (($ $ |#2| $) NIL) (($ $ (-658 |#2|) (-658 $)) NIL)) (-1482 (($ $ |#2|) NIL (|has| |#1| (-194)))) (-3644 (($ $ |#2|) NIL) (($ $ (-658 |#2|)) NIL) (($ $ |#2| (-790)) NIL) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-4525 (((-558 |#2|) $) NIL) (((-790) $ |#2|) 43) (((-658 (-790)) $ (-658 |#2|)) NIL)) (-2676 (($ $) NIL)) (-1526 (($ $) 33)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| |#1| (-633 (-565))) (|has| |#2| (-633 (-565))))) (($ (-980 (-433 (-592)))) NIL (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#2| (-633 (-1191))))) (($ (-980 (-592))) NIL (-3836 (-12 (|has| |#1| (-43 (-592))) (|has| |#2| (-633 (-1191))) (-3252 (|has| |#1| (-43 (-433 (-592)))))) (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#2| (-633 (-1191)))))) (($ (-980 |#1|)) NIL (|has| |#2| (-633 (-1191)))) (((-1173) $) NIL (-12 (|has| |#1| (-1065 (-592))) (|has| |#2| (-633 (-1191))))) (((-980 |#1|) $) NIL (|has| |#2| (-633 (-1191))))) (-1554 ((|#1| $) 114 (|has| |#1| (-477))) (($ $ |#2|) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ |#2|) NIL) (((-980 |#1|) $) NIL (|has| |#2| (-633 (-1191)))) (((-1142 |#1| |#2|) $) 15) (($ (-1142 |#1| |#2|)) 16) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-558 |#2|)) NIL) (($ $ |#2| (-790)) 44) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 13 T CONST)) (-2745 (((-3 (-141) "failed") $ $) NIL)) (-4257 (($) 35 T CONST)) (-4594 (($ $ $ $ (-790)) 87 (|has| |#1| (-582)))) (-2650 (($ $ $ (-790)) 86 (|has| |#1| (-582)))) (-1940 (($ $ |#2|) NIL) (($ $ (-658 |#2|)) NIL) (($ $ |#2| (-790)) NIL) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) 54)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) 63)) (-3300 (($ $ $) 73)) (** (($ $ (-944)) NIL) (($ $ (-790)) 61)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 59) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 58) (($ $ |#1|) NIL))) 
+(((-802 |#1| |#2|) (-13 (-1089 |#1| (-558 |#2|) |#2|) (-632 (-1142 |#1| |#2|)) (-1065 (-1142 |#1| |#2|))) (-1075) (-869)) (T -802)) 
+NIL 
+(-13 (-1089 |#1| (-558 |#2|) |#2|) (-632 (-1142 |#1| |#2|)) (-1065 (-1142 |#1| |#2|))) 
+((-2731 (((-804 |#2|) (-1 |#2| |#1|) (-804 |#1|)) 13))) 
+(((-803 |#1| |#2|) (-10 -7 (-15 -2731 ((-804 |#2|) (-1 |#2| |#1|) (-804 |#1|)))) (-1075) (-1075)) (T -803)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-804 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-804 *6)) (-5 *1 (-803 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-804 |#2|) (-1 |#2| |#1|) (-804 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 12)) (-2651 (((-1280 |#1|) $ (-790)) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-2085 (($ (-1187 |#1|)) NIL)) (-4492 (((-1187 $) $ (-1103)) NIL) (((-1187 |#1|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1103))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-2522 (((-658 $) $ $) 39 (|has| |#1| (-582)))) (-3250 (($ $ $) 35 (|has| |#1| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1696 (($ $ (-790)) NIL)) (-1498 (($ $ (-790)) NIL)) (-1504 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-477)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-1103) "failed") $) NIL) (((-3 (-1187 |#1|) "failed") $) 10)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-1103) $) NIL) (((-1187 |#1|) $) NIL)) (-1544 (($ $ $ (-1103)) NIL (|has| |#1| (-194))) ((|#1| $ $) 43 (|has| |#1| (-194)))) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-3213 (($ $ $) NIL)) (-2133 (($ $ $) 71 (|has| |#1| (-582)))) (-4369 (((-2 (|:| -1487 |#1|) (|:| -2230 $) (|:| -3027 $)) $ $) 70 (|has| |#1| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ (-1103)) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-790) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1103) (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1103) (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-4346 (((-790) $ $) NIL (|has| |#1| (-582)))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-1165)))) (-4533 (($ (-1187 |#1|) (-1103)) NIL) (($ (-1187 $) (-1103)) NIL)) (-3990 (($ $ (-790)) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-4371 (($ $ $) 20)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1103)) NIL) (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4206 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-790) (-790)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2070 (((-1187 |#1|) $) NIL)) (-3254 (((-3 (-1103) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-3037 (((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -3116 (-790))) $ $) 26)) (-1993 (($ $ $) 29)) (-4380 (($ $ $) 32)) (-2198 (((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $) 31)) (-2685 (((-1173) $) NIL)) (-3722 (($ $ $) 41 (|has| |#1| (-582)))) (-3768 (((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790)) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-1103)) (|:| -3215 (-790))) "failed") $) NIL)) (-3162 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3703 (($) NIL (|has| |#1| (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-1453 (((-2 (|:| -3548 $) (|:| |coef2| $)) $ $) 67 (|has| |#1| (-582)))) (-2845 (((-2 (|:| -3548 $) (|:| |coef1| $)) $ $) 63 (|has| |#1| (-582)))) (-4032 (((-2 (|:| -1544 |#1|) (|:| |coef2| $)) $ $) 55 (|has| |#1| (-582)))) (-3707 (((-2 (|:| -1544 |#1|) (|:| |coef1| $)) $ $) 51 (|has| |#1| (-582)))) (-4559 (((-141) $) 13)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-4550 (($ $ (-790) |#1| $) 19)) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-2049 (((-2 (|:| -3548 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 59 (|has| |#1| (-582)))) (-4483 (((-2 (|:| -1544 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $) 47 (|has| |#1| (-582)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1103) |#1|) NIL) (($ $ (-658 (-1103)) (-658 |#1|)) NIL) (($ $ (-1103) $) NIL) (($ $ (-658 (-1103)) (-658 $)) NIL)) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-433 $) (-433 $) (-433 $)) NIL (|has| |#1| (-582))) ((|#1| (-433 $) |#1|) NIL (|has| |#1| (-388))) (((-433 $) $ (-433 $)) NIL (|has| |#1| (-582)))) (-4510 (((-3 $ "failed") $ (-790)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-1482 (($ $ (-1103)) NIL (|has| |#1| (-194))) ((|#1| $) NIL (|has| |#1| (-194)))) (-3644 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-4525 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-1103) (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) NIL (|has| |#1| (-477))) (($ $ (-1103)) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1528 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582))) (((-3 (-433 $) "failed") (-433 $) $) NIL (|has| |#1| (-582)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-1103)) NIL) (((-1187 |#1|) $) 7) (($ (-1187 |#1|)) 8) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 21 T CONST)) (-4257 (($) 24 T CONST)) (-1940 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) 28) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 23) (($ $ |#1|) NIL))) 
+(((-804 |#1|) (-13 (-1255 |#1|) (-632 (-1187 |#1|)) (-1065 (-1187 |#1|)) (-10 -8 (-15 -4550 ($ $ (-790) |#1| $)) (-15 -4371 ($ $ $)) (-15 -3037 ((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -3116 (-790))) $ $)) (-15 -1993 ($ $ $)) (-15 -2198 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -4380 ($ $ $)) (IF (|has| |#1| (-582)) (PROGN (-15 -2522 ((-658 $) $ $)) (-15 -3722 ($ $ $)) (-15 -2049 ((-2 (|:| -3548 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -2845 ((-2 (|:| -3548 $) (|:| |coef1| $)) $ $)) (-15 -1453 ((-2 (|:| -3548 $) (|:| |coef2| $)) $ $)) (-15 -4483 ((-2 (|:| -1544 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -3707 ((-2 (|:| -1544 |#1|) (|:| |coef1| $)) $ $)) (-15 -4032 ((-2 (|:| -1544 |#1|) (|:| |coef2| $)) $ $))) |noBranch|))) (-1075)) (T -804)) 
+((-4550 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-790)) (-5 *1 (-804 *3)) (-4 *3 (-1075)))) (-4371 (*1 *1 *1 *1) (-12 (-5 *1 (-804 *2)) (-4 *2 (-1075)))) (-3037 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |polnum| (-804 *3)) (|:| |polden| *3) (|:| -3116 (-790)))) (-5 *1 (-804 *3)) (-4 *3 (-1075)))) (-1993 (*1 *1 *1 *1) (-12 (-5 *1 (-804 *2)) (-4 *2 (-1075)))) (-2198 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -1487 *3) (|:| |gap| (-790)) (|:| -2230 (-804 *3)) (|:| -3027 (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-1075)))) (-4380 (*1 *1 *1 *1) (-12 (-5 *1 (-804 *2)) (-4 *2 (-1075)))) (-2522 (*1 *2 *1 *1) (-12 (-5 *2 (-658 (-804 *3))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) (-3722 (*1 *1 *1 *1) (-12 (-5 *1 (-804 *2)) (-4 *2 (-582)) (-4 *2 (-1075)))) (-2049 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3548 (-804 *3)) (|:| |coef1| (-804 *3)) (|:| |coef2| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) (-2845 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3548 (-804 *3)) (|:| |coef1| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) (-1453 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3548 (-804 *3)) (|:| |coef2| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) (-4483 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -1544 *3) (|:| |coef1| (-804 *3)) (|:| |coef2| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) (-3707 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -1544 *3) (|:| |coef1| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) (-4032 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -1544 *3) (|:| |coef2| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075))))) 
+(-13 (-1255 |#1|) (-632 (-1187 |#1|)) (-1065 (-1187 |#1|)) (-10 -8 (-15 -4550 ($ $ (-790) |#1| $)) (-15 -4371 ($ $ $)) (-15 -3037 ((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -3116 (-790))) $ $)) (-15 -1993 ($ $ $)) (-15 -2198 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -4380 ($ $ $)) (IF (|has| |#1| (-582)) (PROGN (-15 -2522 ((-658 $) $ $)) (-15 -3722 ($ $ $)) (-15 -2049 ((-2 (|:| -3548 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -2845 ((-2 (|:| -3548 $) (|:| |coef1| $)) $ $)) (-15 -1453 ((-2 (|:| -3548 $) (|:| |coef2| $)) $ $)) (-15 -4483 ((-2 (|:| -1544 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -3707 ((-2 (|:| -1544 |#1|) (|:| |coef1| $)) $ $)) (-15 -4032 ((-2 (|:| -1544 |#1|) (|:| |coef2| $)) $ $))) |noBranch|))) 
+((-2023 ((|#1| (-790) |#1|) 32 (|has| |#1| (-43 (-433 (-592)))))) (-4446 ((|#1| (-790) |#1|) 22)) (-1531 ((|#1| (-790) |#1|) 34 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-805 |#1|) (-10 -7 (-15 -4446 (|#1| (-790) |#1|)) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -1531 (|#1| (-790) |#1|)) (-15 -2023 (|#1| (-790) |#1|))) |noBranch|)) (-194)) (T -805)) 
+((-2023 (*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-805 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-194)))) (-1531 (*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-805 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-194)))) (-4446 (*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-805 *2)) (-4 *2 (-194))))) 
+(-10 -7 (-15 -4446 (|#1| (-790) |#1|)) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -1531 (|#1| (-790) |#1|)) (-15 -2023 (|#1| (-790) |#1|))) |noBranch|)) 
+((-1641 (((-141) $ $) 7)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) 78)) (-2248 (((-658 $) (-658 |#4|)) 79) (((-658 $) (-658 |#4|) (-141)) 104)) (-4085 (((-658 |#3|) $) 32)) (-4325 (((-141) $) 25)) (-2988 (((-141) $) 16 (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) 94) (((-141) $) 90)) (-2244 ((|#4| |#4| $) 85)) (-3743 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| $) 119)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) 26)) (-2126 (((-141) $ (-790)) 43)) (-3113 (($ (-1 (-141) |#4|) $) 64 (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) 72)) (-3001 (($) 44 T CONST)) (-3239 (((-141) $) 21 (|has| |#1| (-582)))) (-3478 (((-141) $ $) 23 (|has| |#1| (-582)))) (-2398 (((-141) $ $) 22 (|has| |#1| (-582)))) (-1529 (((-141) $) 24 (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 86)) (-4521 (((-658 |#4|) (-658 |#4|) $) 17 (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) 18 (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) 35)) (-2400 (($ (-658 |#4|)) 34)) (-1366 (((-3 $ "failed") $) 75)) (-2226 ((|#4| |#4| $) 82)) (-1360 (($ $) 67 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#4| $) 66 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#4|) $) 63 (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) 95)) (-3092 ((|#4| |#4| $) 80)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 87)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) 98)) (-1836 (((-141) |#4| $) 129)) (-2659 (((-141) |#4| $) 126)) (-3195 (((-141) |#4| $) 130) (((-141) $) 127)) (-4004 (((-658 |#4|) $) 51 (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) 97) (((-141) $) 96)) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) 42)) (-4467 (((-658 |#4|) $) 52 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 54 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 46)) (-2290 (((-658 |#3|) $) 31)) (-2645 (((-141) |#3| $) 30)) (-2554 (((-141) $ (-790)) 41)) (-2685 (((-1173) $) 9)) (-1470 (((-3 |#4| (-658 $)) |#4| |#4| $) 121)) (-3722 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| |#4| $) 120)) (-4255 (((-3 |#4| "failed") $) 76)) (-3501 (((-658 $) |#4| $) 122)) (-3732 (((-3 (-141) (-658 $)) |#4| $) 125)) (-2978 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 $))) |#4| $) 124) (((-141) |#4| $) 123)) (-2852 (((-658 $) |#4| $) 118) (((-658 $) (-658 |#4|) $) 117) (((-658 $) (-658 |#4|) (-658 $)) 116) (((-658 $) |#4| (-658 $)) 115)) (-3902 (($ |#4| $) 110) (($ (-658 |#4|) $) 109)) (-1712 (((-658 |#4|) $) 100)) (-2346 (((-141) |#4| $) 92) (((-141) $) 88)) (-1751 ((|#4| |#4| $) 83)) (-3085 (((-141) $ $) 103)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) 93) (((-141) $) 89)) (-1803 ((|#4| |#4| $) 84)) (-2951 (((-1137) $) 10)) (-1918 (((-3 |#4| "failed") $) 77)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) 60)) (-2778 (((-3 $ "failed") $ |#4|) 71)) (-2807 (($ $ |#4|) 70) (((-658 $) |#4| $) 108) (((-658 $) |#4| (-658 $)) 107) (((-658 $) (-658 |#4|) $) 106) (((-658 $) (-658 |#4|) (-658 $)) 105)) (-3002 (((-141) (-1 (-141) |#4|) $) 49 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) 58 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) 56 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) 55 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) 37)) (-2943 (((-141) $) 40)) (-2890 (($) 39)) (-4525 (((-790) $) 99)) (-3452 (((-790) |#4| $) 53 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#4|) $) 50 (|has| $ (-6 -4625)))) (-4599 (($ $) 38)) (-1778 (((-565) $) 68 (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 59)) (-2613 (($ $ |#3|) 27)) (-4152 (($ $ |#3|) 29)) (-2965 (($ $) 81)) (-2507 (($ $ |#3|) 28)) (-1683 (((-877) $) 11) (((-658 |#4|) $) 36)) (-1857 (((-790) $) 69 (|has| |#3| (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) 101)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) 91)) (-3032 (((-658 $) |#4| $) 114) (((-658 $) |#4| (-658 $)) 113) (((-658 $) (-658 |#4|) $) 112) (((-658 $) (-658 |#4|) (-658 $)) 111)) (-3369 (((-141) (-1 (-141) |#4|) $) 48 (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) 74)) (-1437 (((-141) |#4| $) 128)) (-3069 (((-141) |#3| $) 73)) (-3255 (((-141) $ $) 6)) (-1699 (((-790) $) 45 (|has| $ (-6 -4625))))) 
+(((-806 |#1| |#2| |#3| |#4|) (-1311) (-477) (-815) (-869) (-1089 |t#1| |t#2| |t#3|)) (T -806)) 
+NIL 
+(-13 (-1094 |t#1| |t#2| |t#3| |t#4|)) 
+(((-39) . T) ((-125) . T) ((-632 (-658 |#4|)) . T) ((-632 (-877)) . T) ((-175 |#4|) . T) ((-633 (-565)) |has| |#4| (-633 (-565))) ((-325 |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-523 |#4|) . T) ((-547 |#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-1005 |#1| |#2| |#3| |#4|) . T) ((-1094 |#1| |#2| |#3| |#4|) . T) ((-1119) . T) ((-1219 |#1| |#2| |#3| |#4|) . T) ((-1225) . T)) 
+((-1591 (((-3 (-405) "failed") (-332 |#1|) (-944)) 60 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-3 (-405) "failed") (-332 |#1|)) 52 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-3 (-405) "failed") (-433 (-980 |#1|)) (-944)) 39 (|has| |#1| (-582))) (((-3 (-405) "failed") (-433 (-980 |#1|))) 35 (|has| |#1| (-582))) (((-3 (-405) "failed") (-980 |#1|) (-944)) 30 (|has| |#1| (-1075))) (((-3 (-405) "failed") (-980 |#1|)) 24 (|has| |#1| (-1075)))) (-1806 (((-405) (-332 |#1|) (-944)) 92 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-405) (-332 |#1|)) 87 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-405) (-433 (-980 |#1|)) (-944)) 84 (|has| |#1| (-582))) (((-405) (-433 (-980 |#1|))) 81 (|has| |#1| (-582))) (((-405) (-980 |#1|) (-944)) 80 (|has| |#1| (-1075))) (((-405) (-980 |#1|)) 77 (|has| |#1| (-1075))) (((-405) |#1| (-944)) 73) (((-405) |#1|) 22)) (-2403 (((-3 (-191 (-405)) "failed") (-332 (-191 |#1|)) (-944)) 68 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-3 (-191 (-405)) "failed") (-332 (-191 |#1|))) 58 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-3 (-191 (-405)) "failed") (-332 |#1|) (-944)) 61 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-3 (-191 (-405)) "failed") (-332 |#1|)) 59 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-3 (-191 (-405)) "failed") (-433 (-980 (-191 |#1|))) (-944)) 44 (|has| |#1| (-582))) (((-3 (-191 (-405)) "failed") (-433 (-980 (-191 |#1|)))) 43 (|has| |#1| (-582))) (((-3 (-191 (-405)) "failed") (-433 (-980 |#1|)) (-944)) 38 (|has| |#1| (-582))) (((-3 (-191 (-405)) "failed") (-433 (-980 |#1|))) 37 (|has| |#1| (-582))) (((-3 (-191 (-405)) "failed") (-980 |#1|) (-944)) 28 (|has| |#1| (-1075))) (((-3 (-191 (-405)) "failed") (-980 |#1|)) 26 (|has| |#1| (-1075))) (((-3 (-191 (-405)) "failed") (-980 (-191 |#1|)) (-944)) 17 (|has| |#1| (-194))) (((-3 (-191 (-405)) "failed") (-980 (-191 |#1|))) 14 (|has| |#1| (-194)))) (-4480 (((-191 (-405)) (-332 (-191 |#1|)) (-944)) 95 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-191 (-405)) (-332 (-191 |#1|))) 94 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-191 (-405)) (-332 |#1|) (-944)) 93 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-191 (-405)) (-332 |#1|)) 91 (-12 (|has| |#1| (-582)) (|has| |#1| (-869)))) (((-191 (-405)) (-433 (-980 (-191 |#1|))) (-944)) 86 (|has| |#1| (-582))) (((-191 (-405)) (-433 (-980 (-191 |#1|)))) 85 (|has| |#1| (-582))) (((-191 (-405)) (-433 (-980 |#1|)) (-944)) 83 (|has| |#1| (-582))) (((-191 (-405)) (-433 (-980 |#1|))) 82 (|has| |#1| (-582))) (((-191 (-405)) (-980 |#1|) (-944)) 79 (|has| |#1| (-1075))) (((-191 (-405)) (-980 |#1|)) 78 (|has| |#1| (-1075))) (((-191 (-405)) (-980 (-191 |#1|)) (-944)) 75 (|has| |#1| (-194))) (((-191 (-405)) (-980 (-191 |#1|))) 74 (|has| |#1| (-194))) (((-191 (-405)) (-191 |#1|) (-944)) 16 (|has| |#1| (-194))) (((-191 (-405)) (-191 |#1|)) 12 (|has| |#1| (-194))) (((-191 (-405)) |#1| (-944)) 27) (((-191 (-405)) |#1|) 25))) 
+(((-807 |#1|) (-10 -7 (-15 -1806 ((-405) |#1|)) (-15 -1806 ((-405) |#1| (-944))) (-15 -4480 ((-191 (-405)) |#1|)) (-15 -4480 ((-191 (-405)) |#1| (-944))) (IF (|has| |#1| (-194)) (PROGN (-15 -4480 ((-191 (-405)) (-191 |#1|))) (-15 -4480 ((-191 (-405)) (-191 |#1|) (-944))) (-15 -4480 ((-191 (-405)) (-980 (-191 |#1|)))) (-15 -4480 ((-191 (-405)) (-980 (-191 |#1|)) (-944)))) |noBranch|) (IF (|has| |#1| (-1075)) (PROGN (-15 -1806 ((-405) (-980 |#1|))) (-15 -1806 ((-405) (-980 |#1|) (-944))) (-15 -4480 ((-191 (-405)) (-980 |#1|))) (-15 -4480 ((-191 (-405)) (-980 |#1|) (-944)))) |noBranch|) (IF (|has| |#1| (-582)) (PROGN (-15 -1806 ((-405) (-433 (-980 |#1|)))) (-15 -1806 ((-405) (-433 (-980 |#1|)) (-944))) (-15 -4480 ((-191 (-405)) (-433 (-980 |#1|)))) (-15 -4480 ((-191 (-405)) (-433 (-980 |#1|)) (-944))) (-15 -4480 ((-191 (-405)) (-433 (-980 (-191 |#1|))))) (-15 -4480 ((-191 (-405)) (-433 (-980 (-191 |#1|))) (-944))) (IF (|has| |#1| (-869)) (PROGN (-15 -1806 ((-405) (-332 |#1|))) (-15 -1806 ((-405) (-332 |#1|) (-944))) (-15 -4480 ((-191 (-405)) (-332 |#1|))) (-15 -4480 ((-191 (-405)) (-332 |#1|) (-944))) (-15 -4480 ((-191 (-405)) (-332 (-191 |#1|)))) (-15 -4480 ((-191 (-405)) (-332 (-191 |#1|)) (-944)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-194)) (PROGN (-15 -2403 ((-3 (-191 (-405)) "failed") (-980 (-191 |#1|)))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-980 (-191 |#1|)) (-944)))) |noBranch|) (IF (|has| |#1| (-1075)) (PROGN (-15 -1591 ((-3 (-405) "failed") (-980 |#1|))) (-15 -1591 ((-3 (-405) "failed") (-980 |#1|) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-980 |#1|))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-980 |#1|) (-944)))) |noBranch|) (IF (|has| |#1| (-582)) (PROGN (-15 -1591 ((-3 (-405) "failed") (-433 (-980 |#1|)))) (-15 -1591 ((-3 (-405) "failed") (-433 (-980 |#1|)) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-433 (-980 |#1|)))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-433 (-980 |#1|)) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-433 (-980 (-191 |#1|))))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-433 (-980 (-191 |#1|))) (-944))) (IF (|has| |#1| (-869)) (PROGN (-15 -1591 ((-3 (-405) "failed") (-332 |#1|))) (-15 -1591 ((-3 (-405) "failed") (-332 |#1|) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-332 |#1|))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-332 |#1|) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-332 (-191 |#1|)))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-332 (-191 |#1|)) (-944)))) |noBranch|)) |noBranch|)) (-633 (-405))) (T -807)) 
+((-2403 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-332 (-191 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-2403 (*1 *2 *3) (|partial| -12 (-5 *3 (-332 (-191 *4))) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-2403 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-332 *5)) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-2403 (*1 *2 *3) (|partial| -12 (-5 *3 (-332 *4)) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-1591 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-332 *5)) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) (-1591 (*1 *2 *3) (|partial| -12 (-5 *3 (-332 *4)) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) (-2403 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-980 (-191 *5)))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-2403 (*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 (-191 *4)))) (-4 *4 (-582)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-2403 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-2403 (*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-1591 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) (-1591 (*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) (-2403 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-980 *5)) (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-2403 (*1 *2 *3) (|partial| -12 (-5 *3 (-980 *4)) (-4 *4 (-1075)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-1591 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-980 *5)) (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) (-1591 (*1 *2 *3) (|partial| -12 (-5 *3 (-980 *4)) (-4 *4 (-1075)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) (-2403 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-980 (-191 *5))) (-5 *4 (-944)) (-4 *5 (-194)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-2403 (*1 *2 *3) (|partial| -12 (-5 *3 (-980 (-191 *4))) (-4 *4 (-194)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-4480 (*1 *2 *3 *4) (-12 (-5 *3 (-332 (-191 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-4480 (*1 *2 *3) (-12 (-5 *3 (-332 (-191 *4))) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-4480 (*1 *2 *3 *4) (-12 (-5 *3 (-332 *5)) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-4480 (*1 *2 *3) (-12 (-5 *3 (-332 *4)) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-1806 (*1 *2 *3 *4) (-12 (-5 *3 (-332 *5)) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) (-1806 (*1 *2 *3) (-12 (-5 *3 (-332 *4)) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) (-4480 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-191 *5)))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-4480 (*1 *2 *3) (-12 (-5 *3 (-433 (-980 (-191 *4)))) (-4 *4 (-582)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-4480 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-4480 (*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-1806 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) (-1806 (*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) (-4480 (*1 *2 *3 *4) (-12 (-5 *3 (-980 *5)) (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-4480 (*1 *2 *3) (-12 (-5 *3 (-980 *4)) (-4 *4 (-1075)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-1806 (*1 *2 *3 *4) (-12 (-5 *3 (-980 *5)) (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) (-1806 (*1 *2 *3) (-12 (-5 *3 (-980 *4)) (-4 *4 (-1075)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) (-4480 (*1 *2 *3 *4) (-12 (-5 *3 (-980 (-191 *5))) (-5 *4 (-944)) (-4 *5 (-194)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-4480 (*1 *2 *3) (-12 (-5 *3 (-980 (-191 *4))) (-4 *4 (-194)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-4480 (*1 *2 *3 *4) (-12 (-5 *3 (-191 *5)) (-5 *4 (-944)) (-4 *5 (-194)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) (-4480 (*1 *2 *3) (-12 (-5 *3 (-191 *4)) (-4 *4 (-194)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) (-4480 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-5 *2 (-191 (-405))) (-5 *1 (-807 *3)) (-4 *3 (-633 (-405))))) (-4480 (*1 *2 *3) (-12 (-5 *2 (-191 (-405))) (-5 *1 (-807 *3)) (-4 *3 (-633 (-405))))) (-1806 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-5 *2 (-405)) (-5 *1 (-807 *3)) (-4 *3 (-633 *2)))) (-1806 (*1 *2 *3) (-12 (-5 *2 (-405)) (-5 *1 (-807 *3)) (-4 *3 (-633 *2))))) 
+(-10 -7 (-15 -1806 ((-405) |#1|)) (-15 -1806 ((-405) |#1| (-944))) (-15 -4480 ((-191 (-405)) |#1|)) (-15 -4480 ((-191 (-405)) |#1| (-944))) (IF (|has| |#1| (-194)) (PROGN (-15 -4480 ((-191 (-405)) (-191 |#1|))) (-15 -4480 ((-191 (-405)) (-191 |#1|) (-944))) (-15 -4480 ((-191 (-405)) (-980 (-191 |#1|)))) (-15 -4480 ((-191 (-405)) (-980 (-191 |#1|)) (-944)))) |noBranch|) (IF (|has| |#1| (-1075)) (PROGN (-15 -1806 ((-405) (-980 |#1|))) (-15 -1806 ((-405) (-980 |#1|) (-944))) (-15 -4480 ((-191 (-405)) (-980 |#1|))) (-15 -4480 ((-191 (-405)) (-980 |#1|) (-944)))) |noBranch|) (IF (|has| |#1| (-582)) (PROGN (-15 -1806 ((-405) (-433 (-980 |#1|)))) (-15 -1806 ((-405) (-433 (-980 |#1|)) (-944))) (-15 -4480 ((-191 (-405)) (-433 (-980 |#1|)))) (-15 -4480 ((-191 (-405)) (-433 (-980 |#1|)) (-944))) (-15 -4480 ((-191 (-405)) (-433 (-980 (-191 |#1|))))) (-15 -4480 ((-191 (-405)) (-433 (-980 (-191 |#1|))) (-944))) (IF (|has| |#1| (-869)) (PROGN (-15 -1806 ((-405) (-332 |#1|))) (-15 -1806 ((-405) (-332 |#1|) (-944))) (-15 -4480 ((-191 (-405)) (-332 |#1|))) (-15 -4480 ((-191 (-405)) (-332 |#1|) (-944))) (-15 -4480 ((-191 (-405)) (-332 (-191 |#1|)))) (-15 -4480 ((-191 (-405)) (-332 (-191 |#1|)) (-944)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-194)) (PROGN (-15 -2403 ((-3 (-191 (-405)) "failed") (-980 (-191 |#1|)))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-980 (-191 |#1|)) (-944)))) |noBranch|) (IF (|has| |#1| (-1075)) (PROGN (-15 -1591 ((-3 (-405) "failed") (-980 |#1|))) (-15 -1591 ((-3 (-405) "failed") (-980 |#1|) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-980 |#1|))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-980 |#1|) (-944)))) |noBranch|) (IF (|has| |#1| (-582)) (PROGN (-15 -1591 ((-3 (-405) "failed") (-433 (-980 |#1|)))) (-15 -1591 ((-3 (-405) "failed") (-433 (-980 |#1|)) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-433 (-980 |#1|)))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-433 (-980 |#1|)) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-433 (-980 (-191 |#1|))))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-433 (-980 (-191 |#1|))) (-944))) (IF (|has| |#1| (-869)) (PROGN (-15 -1591 ((-3 (-405) "failed") (-332 |#1|))) (-15 -1591 ((-3 (-405) "failed") (-332 |#1|) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-332 |#1|))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-332 |#1|) (-944))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-332 (-191 |#1|)))) (-15 -2403 ((-3 (-191 (-405)) "failed") (-332 (-191 |#1|)) (-944)))) |noBranch|)) |noBranch|)) 
+((-1393 (((-944) (-1173)) 63)) (-3588 (((-3 (-405) "failed") (-1173)) 32)) (-1981 (((-405) (-1173)) 30)) (-1900 (((-944) (-1173)) 53)) (-1706 (((-1173) (-944)) 54)) (-2296 (((-1173) (-944)) 52))) 
+(((-808) (-10 -7 (-15 -2296 ((-1173) (-944))) (-15 -1900 ((-944) (-1173))) (-15 -1706 ((-1173) (-944))) (-15 -1393 ((-944) (-1173))) (-15 -1981 ((-405) (-1173))) (-15 -3588 ((-3 (-405) "failed") (-1173))))) (T -808)) 
+((-3588 (*1 *2 *3) (|partial| -12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-808)))) (-1981 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-808)))) (-1393 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-944)) (-5 *1 (-808)))) (-1706 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1173)) (-5 *1 (-808)))) (-1900 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-944)) (-5 *1 (-808)))) (-2296 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1173)) (-5 *1 (-808))))) 
+(-10 -7 (-15 -2296 ((-1173) (-944))) (-15 -1900 ((-944) (-1173))) (-15 -1706 ((-1173) (-944))) (-15 -1393 ((-944) (-1173))) (-15 -1981 ((-405) (-1173))) (-15 -3588 ((-3 (-405) "failed") (-1173)))) 
+((-1641 (((-141) $ $) 7)) (-1538 (((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 14) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063)) 12)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 15) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-809) (-1311)) (T -809)) 
+((-2617 (*1 *2 *3 *4) (-12 (-4 *1 (-809)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063)))))) (-1538 (*1 *2 *3 *2) (-12 (-4 *1 (-809)) (-5 *2 (-1063)) (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) (-2617 (*1 *2 *3 *4) (-12 (-4 *1 (-809)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063)))))) (-1538 (*1 *2 *3 *2) (-12 (-4 *1 (-809)) (-5 *2 (-1063)) (-5 *3 (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) 
+(-13 (-1119) (-10 -7 (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1538 ((-1063) (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1538 ((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) (-1063))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-3229 (((-1285) (-1280 (-405)) (-592) (-405) (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405))) (-405) (-1280 (-405)) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405))) 44) (((-1285) (-1280 (-405)) (-592) (-405) (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405))) (-405) (-1280 (-405)) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405))) 43)) (-3179 (((-1285) (-1280 (-405)) (-592) (-405) (-405) (-592) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405))) 50)) (-3175 (((-1285) (-1280 (-405)) (-592) (-405) (-405) (-405) (-405) (-592) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405))) 41)) (-3920 (((-1285) (-1280 (-405)) (-592) (-405) (-405) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405))) 52) (((-1285) (-1280 (-405)) (-592) (-405) (-405) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405))) 51))) 
+(((-810) (-10 -7 (-15 -3920 ((-1285) (-1280 (-405)) (-592) (-405) (-405) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)))) (-15 -3920 ((-1285) (-1280 (-405)) (-592) (-405) (-405) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)))) (-15 -3175 ((-1285) (-1280 (-405)) (-592) (-405) (-405) (-405) (-405) (-592) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)))) (-15 -3229 ((-1285) (-1280 (-405)) (-592) (-405) (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405))) (-405) (-1280 (-405)) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)))) (-15 -3229 ((-1285) (-1280 (-405)) (-592) (-405) (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405))) (-405) (-1280 (-405)) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)))) (-15 -3179 ((-1285) (-1280 (-405)) (-592) (-405) (-405) (-592) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)))))) (T -810)) 
+((-3179 (*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *4 (-592)) (-5 *6 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810)))) (-3229 (*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (-12 (-5 *4 (-592)) (-5 *6 (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405)))) (-5 *7 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810)))) (-3229 (*1 *2 *3 *4 *5 *6 *5 *3 *7) (-12 (-5 *4 (-592)) (-5 *6 (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405)))) (-5 *7 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810)))) (-3175 (*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (-12 (-5 *4 (-592)) (-5 *6 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810)))) (-3920 (*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (-12 (-5 *4 (-592)) (-5 *6 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810)))) (-3920 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-592)) (-5 *6 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810))))) 
+(-10 -7 (-15 -3920 ((-1285) (-1280 (-405)) (-592) (-405) (-405) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)))) (-15 -3920 ((-1285) (-1280 (-405)) (-592) (-405) (-405) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)))) (-15 -3175 ((-1285) (-1280 (-405)) (-592) (-405) (-405) (-405) (-405) (-592) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)))) (-15 -3229 ((-1285) (-1280 (-405)) (-592) (-405) (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405))) (-405) (-1280 (-405)) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)))) (-15 -3229 ((-1285) (-1280 (-405)) (-592) (-405) (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405))) (-405) (-1280 (-405)) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)) (-1280 (-405)))) (-15 -3179 ((-1285) (-1280 (-405)) (-592) (-405) (-405) (-592) (-1 (-1285) (-1280 (-405)) (-1280 (-405)) (-405))))) 
+((-1429 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592)) 53)) (-1597 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592)) 30)) (-3860 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592)) 52)) (-2468 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592)) 28)) (-2132 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592)) 51)) (-2492 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592)) 18)) (-3973 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592)) 31)) (-2643 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592)) 29)) (-4478 (((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592)) 27))) 
+(((-811) (-10 -7 (-15 -4478 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592))) (-15 -2643 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592))) (-15 -3973 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592))) (-15 -2492 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -2468 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -1597 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -2132 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -3860 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -1429 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))))) (T -811)) 
+((-1429 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592)))) (-3860 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592)))) (-2132 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592)))) (-1597 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592)))) (-2468 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592)))) (-2492 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592)))) (-3973 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592)))) (-2643 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592)))) (-4478 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(-10 -7 (-15 -4478 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592))) (-15 -2643 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592))) (-15 -3973 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592) (-592))) (-15 -2492 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -2468 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -1597 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -2132 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -3860 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592))) (-15 -1429 ((-2 (|:| -2324 (-405)) (|:| -1615 (-405)) (|:| |totalpts| (-592)) (|:| |success| (-141))) (-1 (-405) (-405)) (-405) (-405) (-405) (-405) (-592) (-592)))) 
+((-2073 (((-1221 |#1|) |#1| (-237) (-592)) 45))) 
+(((-812 |#1|) (-10 -7 (-15 -2073 ((-1221 |#1|) |#1| (-237) (-592)))) (-1003)) (T -812)) 
+((-2073 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-237)) (-5 *5 (-592)) (-5 *2 (-1221 *3)) (-5 *1 (-812 *3)) (-4 *3 (-1003))))) 
+(-10 -7 (-15 -2073 ((-1221 |#1|) |#1| (-237) (-592)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 23)) (-2350 (((-3 $ "failed") $ $) 25)) (-3001 (($) 22 T CONST)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 21 T CONST)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (-3306 (($ $ $) 27) (($ $) 26)) (-3300 (($ $ $) 19)) (* (($ (-790) $) 24) (($ (-944) $) 20) (($ (-592) $) 28))) 
+(((-813) (-1311)) (T -813)) 
+NIL 
+(-13 (-817) (-21)) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-814) . T) ((-816) . T) ((-817) . T) ((-869) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 23)) (-3001 (($) 22 T CONST)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 21 T CONST)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (-3300 (($ $ $) 19)) (* (($ (-790) $) 24) (($ (-944) $) 20))) 
+(((-814) (-1311)) (T -814)) 
+NIL 
+(-13 (-816) (-23)) 
+(((-23) . T) ((-25) . T) ((-125) . T) ((-632 (-877)) . T) ((-816) . T) ((-869) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 23)) (-4079 (($ $ $) 26)) (-2350 (((-3 $ "failed") $ $) 25)) (-3001 (($) 22 T CONST)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 21 T CONST)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (-3300 (($ $ $) 19)) (* (($ (-790) $) 24) (($ (-944) $) 20))) 
+(((-815) (-1311)) (T -815)) 
+((-4079 (*1 *1 *1 *1) (-4 *1 (-815)))) 
+(-13 (-817) (-10 -8 (-15 -4079 ($ $ $)))) 
+(((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-814) . T) ((-816) . T) ((-817) . T) ((-869) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 23)) (-3001 (($) 22 T CONST)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 21 T CONST)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (-3300 (($ $ $) 19)) (* (($ (-790) $) 24) (($ (-944) $) 20))) 
+(((-816) (-1311)) (T -816)) 
+NIL 
+(-13 (-869) (-23)) 
+(((-23) . T) ((-25) . T) ((-125) . T) ((-632 (-877)) . T) ((-869) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 23)) (-2350 (((-3 $ "failed") $ $) 25)) (-3001 (($) 22 T CONST)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 21 T CONST)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (-3300 (($ $ $) 19)) (* (($ (-790) $) 24) (($ (-944) $) 20))) 
+(((-817) (-1311)) (T -817)) 
+NIL 
+(-13 (-814) (-158)) 
+(((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-814) . T) ((-816) . T) ((-869) . T) ((-1119) . T)) 
+((-2272 (((-141) $) 41)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 |#2| "failed") $) 44)) (-2400 (((-592) $) NIL) (((-433 (-592)) $) NIL) ((|#2| $) 42)) (-4182 (((-3 (-433 (-592)) "failed") $) 78)) (-2435 (((-141) $) 72)) (-2270 (((-433 (-592)) $) 76)) (-2793 ((|#2| $) 26)) (-2731 (($ (-1 |#2| |#2|) $) 23)) (-4552 (($ $) 61)) (-1778 (((-565) $) 67)) (-2227 (($ $) 21)) (-1683 (((-877) $) 56) (($ (-592)) 39) (($ |#2|) 37) (($ (-433 (-592))) NIL)) (-4010 (((-790)) 10)) (-1392 ((|#2| $) 71)) (-3255 (((-141) $ $) 29)) (-3266 (((-141) $ $) 69)) (-3306 (($ $) 31) (($ $ $) NIL)) (-3300 (($ $ $) 30)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 35) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 32))) 
+(((-818 |#1| |#2|) (-10 -8 (-15 -3266 ((-141) |#1| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -4552 (|#1| |#1|)) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -1392 (|#2| |#1|)) (-15 -2793 (|#2| |#1|)) (-15 -2227 (|#1| |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1683 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 -2272 ((-141) |#1|)) (-15 * (|#1| (-944) |#1|)) (-15 -3300 (|#1| |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) (-819 |#2|) (-194)) (T -818)) 
+((-4010 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-790)) (-5 *1 (-818 *3 *4)) (-4 *3 (-819 *4))))) 
+(-10 -8 (-15 -3266 ((-141) |#1| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -4552 (|#1| |#1|)) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -1392 (|#2| |#1|)) (-15 -2793 (|#2| |#1|)) (-15 -2227 (|#1| |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1683 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 -2272 ((-141) |#1|)) (-15 * (|#1| (-944) |#1|)) (-15 -3300 (|#1| |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-1403 (((-790)) 51 (|has| |#1| (-394)))) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 93 (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 91 (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 89)) (-2400 (((-592) $) 94 (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) 92 (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 88)) (-3371 (((-3 $ "failed") $) 33)) (-3996 ((|#1| $) 78)) (-4182 (((-3 (-433 (-592)) "failed") $) 65 (|has| |#1| (-574)))) (-2435 (((-141) $) 67 (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) 66 (|has| |#1| (-574)))) (-4290 (($) 54 (|has| |#1| (-394)))) (-3558 (((-141) $) 30)) (-3352 (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) 69)) (-2793 ((|#1| $) 70)) (-1837 (($ $ $) 61 (|has| |#1| (-869)))) (-3319 (($ $ $) 60 (|has| |#1| (-869)))) (-2731 (($ (-1 |#1| |#1|) $) 80)) (-3546 (((-944) $) 53 (|has| |#1| (-394)))) (-2685 (((-1173) $) 9)) (-4552 (($ $) 64 (|has| |#1| (-388)))) (-1825 (($ (-944)) 52 (|has| |#1| (-394)))) (-3789 ((|#1| $) 75)) (-3831 ((|#1| $) 76)) (-1933 ((|#1| $) 77)) (-2640 ((|#1| $) 71)) (-4326 ((|#1| $) 72)) (-1771 ((|#1| $) 73)) (-2278 ((|#1| $) 74)) (-2951 (((-1137) $) 10)) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) 86 (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) 85 (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) 84 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) 83 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) 82 (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) 81 (|has| |#1| (-547 (-1191) |#1|)))) (-1405 (((-658 $)) 55 (|has| |#1| (-394)))) (-3927 (($ $ |#1|) 87 (|has| |#1| (-303 |#1| |#1|)))) (-1778 (((-565) $) 62 (|has| |#1| (-633 (-565))))) (-2227 (($ $) 79)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 36) (($ (-433 (-592))) 90 (|has| |#1| (-1065 (-433 (-592)))))) (-1517 (((-3 $ "failed") $) 63 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-1392 ((|#1| $) 68 (|has| |#1| (-1084)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3286 (((-141) $ $) 58 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 57 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 59 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 56 (|has| |#1| (-869)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
+(((-819 |#1|) (-1311) (-194)) (T -819)) 
+((-2227 (*1 *1 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-3996 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-1933 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-3831 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-3789 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-2278 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-1771 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-4326 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-2640 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-2793 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-3352 (*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) (-1392 (*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)) (-4 *2 (-1084)))) (-2435 (*1 *2 *1) (-12 (-4 *1 (-819 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-141)))) (-2270 (*1 *2 *1) (-12 (-4 *1 (-819 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) (-4182 (*1 *2 *1) (|partial| -12 (-4 *1 (-819 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) (-4552 (*1 *1 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)) (-4 *2 (-388))))) 
+(-13 (-43 |t#1|) (-437 |t#1|) (-358 |t#1|) (-10 -8 (-15 -2227 ($ $)) (-15 -3996 (|t#1| $)) (-15 -1933 (|t#1| $)) (-15 -3831 (|t#1| $)) (-15 -3789 (|t#1| $)) (-15 -2278 (|t#1| $)) (-15 -1771 (|t#1| $)) (-15 -4326 (|t#1| $)) (-15 -2640 (|t#1| $)) (-15 -2793 (|t#1| $)) (-15 -3352 ($ |t#1| |t#1| |t#1| |t#1| |t#1| |t#1| |t#1| |t#1|)) (IF (|has| |t#1| (-394)) (-6 (-394)) |noBranch|) (IF (|has| |t#1| (-869)) (-6 (-869)) |noBranch|) (IF (|has| |t#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (IF (|has| |t#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |t#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |t#1| (-1084)) (-15 -1392 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|) (IF (|has| |t#1| (-388)) (-15 -4552 ($ $)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 |#1| $) |has| |#1| (-303 |#1| |#1|)) ((-325 |#1|) |has| |#1| (-325 |#1|)) ((-394) |has| |#1| (-394)) ((-358 |#1|) . T) ((-437 |#1|) . T) ((-547 (-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((-547 |#1| |#1|) |has| |#1| (-325 |#1|)) ((-661 |#1|) . T) ((-661 $) . T) ((-734 |#1|) . T) ((-743) . T) ((-869) |has| |#1| (-869)) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1081 |#1|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-2731 ((|#3| (-1 |#4| |#2|) |#1|) 20))) 
+(((-820 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#3| (-1 |#4| |#2|) |#1|))) (-819 |#2|) (-194) (-819 |#4|) (-194)) (T -820)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-194)) (-4 *6 (-194)) (-4 *2 (-819 *6)) (-5 *1 (-820 *4 *5 *2 *6)) (-4 *4 (-819 *5))))) 
+(-10 -7 (-15 -2731 (|#3| (-1 |#4| |#2|) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1403 (((-790)) NIL (|has| |#1| (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-1027 |#1|) "failed") $) 35) (((-3 (-592) "failed") $) NIL (-3836 (|has| (-1027 |#1|) (-1065 (-592))) (|has| |#1| (-1065 (-592))))) (((-3 (-433 (-592)) "failed") $) NIL (-3836 (|has| (-1027 |#1|) (-1065 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592))))))) (-2400 ((|#1| $) NIL) (((-1027 |#1|) $) 33) (((-592) $) NIL (-3836 (|has| (-1027 |#1|) (-1065 (-592))) (|has| |#1| (-1065 (-592))))) (((-433 (-592)) $) NIL (-3836 (|has| (-1027 |#1|) (-1065 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592))))))) (-3371 (((-3 $ "failed") $) NIL)) (-3996 ((|#1| $) 16)) (-4182 (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-574)))) (-2435 (((-141) $) NIL (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) NIL (|has| |#1| (-574)))) (-4290 (($) NIL (|has| |#1| (-394)))) (-3558 (((-141) $) NIL)) (-3352 (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) 28) (($ (-1027 |#1|) (-1027 |#1|)) 29)) (-2793 ((|#1| $) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3546 (((-944) $) NIL (|has| |#1| (-394)))) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-1825 (($ (-944)) NIL (|has| |#1| (-394)))) (-3789 ((|#1| $) 22)) (-3831 ((|#1| $) 20)) (-1933 ((|#1| $) 18)) (-2640 ((|#1| $) 26)) (-4326 ((|#1| $) 25)) (-1771 ((|#1| $) 24)) (-2278 ((|#1| $) 23)) (-2951 (((-1137) $) NIL)) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) NIL (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) NIL (|has| |#1| (-547 (-1191) |#1|)))) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-3927 (($ $ |#1|) NIL (|has| |#1| (-303 |#1| |#1|)))) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-2227 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-1027 |#1|)) 30) (($ (-433 (-592))) NIL (-3836 (|has| (-1027 |#1|) (-1065 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592))))))) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-1392 ((|#1| $) NIL (|has| |#1| (-1084)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 8 T CONST)) (-4257 (($) 12 T CONST)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 40) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-821 |#1|) (-13 (-819 |#1|) (-437 (-1027 |#1|)) (-10 -8 (-15 -3352 ($ (-1027 |#1|) (-1027 |#1|))))) (-194)) (T -821)) 
+((-3352 (*1 *1 *2 *2) (-12 (-5 *2 (-1027 *3)) (-4 *3 (-194)) (-5 *1 (-821 *3))))) 
+(-13 (-819 |#1|) (-437 (-1027 |#1|)) (-10 -8 (-15 -3352 ($ (-1027 |#1|) (-1027 |#1|))))) 
+((-1641 (((-141) $ $) 7)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3356 (((-1063) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 12)) (-3255 (((-141) $ $) 6))) 
+(((-822) (-1311)) (T -822)) 
+((-2617 (*1 *2 *3 *4) (-12 (-4 *1 (-822)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)))))) (-3356 (*1 *2 *3) (-12 (-4 *1 (-822)) (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-1063))))) 
+(-13 (-1119) (-10 -7 (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -3356 ((-1063) (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-2377 (((-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#3| |#2| (-1191)) 19))) 
+(((-823 |#1| |#2| |#3|) (-10 -7 (-15 -2377 ((-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#3| |#2| (-1191)))) (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171)) (-13 (-29 |#1|) (-1211) (-987)) (-670 |#2|)) (T -823)) 
+((-2377 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-1191)) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-4 *4 (-13 (-29 *6) (-1211) (-987))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2195 (-658 *4)))) (-5 *1 (-823 *6 *4 *3)) (-4 *3 (-670 *4))))) 
+(-10 -7 (-15 -2377 ((-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#3| |#2| (-1191)))) 
+((-4005 (((-3 |#2| "failed") |#2| (-143) (-310 |#2|) (-658 |#2|)) 26) (((-3 |#2| "failed") (-310 |#2|) (-143) (-310 |#2|) (-658 |#2|)) 27) (((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#2| "failed") |#2| (-143) (-1191)) 16) (((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#2| "failed") (-310 |#2|) (-143) (-1191)) 17) (((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-658 |#2|) (-658 (-143)) (-1191)) 22) (((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-658 (-310 |#2|)) (-658 (-143)) (-1191)) 24) (((-3 (-658 (-1280 |#2|)) "failed") (-706 |#2|) (-1191)) 36) (((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-706 |#2|) (-1280 |#2|) (-1191)) 34))) 
+(((-824 |#1| |#2|) (-10 -7 (-15 -4005 ((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-706 |#2|) (-1280 |#2|) (-1191))) (-15 -4005 ((-3 (-658 (-1280 |#2|)) "failed") (-706 |#2|) (-1191))) (-15 -4005 ((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-658 (-310 |#2|)) (-658 (-143)) (-1191))) (-15 -4005 ((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-658 |#2|) (-658 (-143)) (-1191))) (-15 -4005 ((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#2| "failed") (-310 |#2|) (-143) (-1191))) (-15 -4005 ((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#2| "failed") |#2| (-143) (-1191))) (-15 -4005 ((-3 |#2| "failed") (-310 |#2|) (-143) (-310 |#2|) (-658 |#2|))) (-15 -4005 ((-3 |#2| "failed") |#2| (-143) (-310 |#2|) (-658 |#2|)))) (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171)) (-13 (-29 |#1|) (-1211) (-987))) (T -824)) 
+((-4005 (*1 *2 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-143)) (-5 *4 (-310 *2)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-824 *6 *2)))) (-4005 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-310 *2)) (-5 *4 (-143)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-29 *6) (-1211) (-987))) (-5 *1 (-824 *6 *2)) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))))) (-4005 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-143)) (-5 *5 (-1191)) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-3 (-2 (|:| |particular| *3) (|:| -2195 (-658 *3))) *3 "failed")) (-5 *1 (-824 *6 *3)) (-4 *3 (-13 (-29 *6) (-1211) (-987))))) (-4005 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 *7)) (-5 *4 (-143)) (-5 *5 (-1191)) (-4 *7 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-3 (-2 (|:| |particular| *7) (|:| -2195 (-658 *7))) *7 "failed")) (-5 *1 (-824 *6 *7)))) (-4005 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-658 *7)) (-5 *4 (-658 (-143))) (-5 *5 (-1191)) (-4 *7 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-2 (|:| |particular| (-1280 *7)) (|:| -2195 (-658 (-1280 *7))))) (-5 *1 (-824 *6 *7)))) (-4005 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-658 (-310 *7))) (-5 *4 (-658 (-143))) (-5 *5 (-1191)) (-4 *7 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-2 (|:| |particular| (-1280 *7)) (|:| -2195 (-658 (-1280 *7))))) (-5 *1 (-824 *6 *7)))) (-4005 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-706 *6)) (-5 *4 (-1191)) (-4 *6 (-13 (-29 *5) (-1211) (-987))) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-1280 *6))) (-5 *1 (-824 *5 *6)))) (-4005 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-706 *7)) (-5 *5 (-1191)) (-4 *7 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-2 (|:| |particular| (-1280 *7)) (|:| -2195 (-658 (-1280 *7))))) (-5 *1 (-824 *6 *7)) (-5 *4 (-1280 *7))))) 
+(-10 -7 (-15 -4005 ((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-706 |#2|) (-1280 |#2|) (-1191))) (-15 -4005 ((-3 (-658 (-1280 |#2|)) "failed") (-706 |#2|) (-1191))) (-15 -4005 ((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-658 (-310 |#2|)) (-658 (-143)) (-1191))) (-15 -4005 ((-3 (-2 (|:| |particular| (-1280 |#2|)) (|:| -2195 (-658 (-1280 |#2|)))) "failed") (-658 |#2|) (-658 (-143)) (-1191))) (-15 -4005 ((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#2| "failed") (-310 |#2|) (-143) (-1191))) (-15 -4005 ((-3 (-2 (|:| |particular| |#2|) (|:| -2195 (-658 |#2|))) |#2| "failed") |#2| (-143) (-1191))) (-15 -4005 ((-3 |#2| "failed") (-310 |#2|) (-143) (-310 |#2|) (-658 |#2|))) (-15 -4005 ((-3 |#2| "failed") |#2| (-143) (-310 |#2|) (-658 |#2|)))) 
+((-1339 (($) 9)) (-1718 (((-3 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))) "failed") (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 26)) (-2840 (((-658 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) $) 23)) (-2113 (($ (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))))) 20)) (-3919 (($ (-658 (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))))))) 18)) (-2260 (((-1285)) 12))) 
+(((-825) (-10 -8 (-15 -1339 ($)) (-15 -2260 ((-1285))) (-15 -2840 ((-658 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) $)) (-15 -3919 ($ (-658 (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))))))) (-15 -2113 ($ (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))))))) (-15 -1718 ((-3 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))) "failed") (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) (T -825)) 
+((-1718 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))) (-5 *1 (-825)))) (-2113 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))))) (-5 *1 (-825)))) (-3919 (*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))))))) (-5 *1 (-825)))) (-2840 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-5 *1 (-825)))) (-2260 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-825)))) (-1339 (*1 *1) (-5 *1 (-825)))) 
+(-10 -8 (-15 -1339 ($)) (-15 -2260 ((-1285))) (-15 -2840 ((-658 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) $)) (-15 -3919 ($ (-658 (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))))))) (-15 -2113 ($ (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))))))) (-15 -1718 ((-3 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))) "failed") (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) 
+((-1749 ((|#2| |#2| (-1191)) 15)) (-1737 ((|#2| |#2| (-1191)) 47)) (-2485 (((-1 |#2| |#2|) (-1191)) 11))) 
+(((-826 |#1| |#2|) (-10 -7 (-15 -1749 (|#2| |#2| (-1191))) (-15 -1737 (|#2| |#2| (-1191))) (-15 -2485 ((-1 |#2| |#2|) (-1191)))) (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171)) (-13 (-29 |#1|) (-1211) (-987))) (T -826)) 
+((-2485 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-1 *5 *5)) (-5 *1 (-826 *4 *5)) (-4 *5 (-13 (-29 *4) (-1211) (-987))))) (-1737 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-826 *4 *2)) (-4 *2 (-13 (-29 *4) (-1211) (-987))))) (-1749 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-826 *4 *2)) (-4 *2 (-13 (-29 *4) (-1211) (-987)))))) 
+(-10 -7 (-15 -1749 (|#2| |#2| (-1191))) (-15 -1737 (|#2| |#2| (-1191))) (-15 -2485 ((-1 |#2| |#2|) (-1191)))) 
+((-4005 (((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-658 (-405)) (-405) (-405)) 114) (((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-658 (-405)) (-405)) 115) (((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-658 (-405)) (-405)) 117) (((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-405)) 118) (((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-405)) 119) (((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405))) 120) (((-1063) (-830) (-1087)) 105) (((-1063) (-830)) 106)) (-2617 (((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-830) (-1087)) 71) (((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-830)) 73))) 
+(((-827) (-10 -7 (-15 -4005 ((-1063) (-830))) (-15 -4005 ((-1063) (-830) (-1087))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-405))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-405))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-658 (-405)) (-405))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-658 (-405)) (-405))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-658 (-405)) (-405) (-405))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-830))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-830) (-1087))))) (T -827)) 
+((-2617 (*1 *2 *3 *4) (-12 (-5 *3 (-830)) (-5 *4 (-1087)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-827)))) (-2617 (*1 *2 *3) (-12 (-5 *3 (-830)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-827)))) (-4005 (*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (-12 (-5 *3 (-1280 (-332 *4))) (-5 *5 (-658 (-405))) (-5 *6 (-332 (-405))) (-5 *4 (-405)) (-5 *2 (-1063)) (-5 *1 (-827)))) (-4005 (*1 *2 *3 *4 *4 *5 *6 *5 *4) (-12 (-5 *3 (-1280 (-332 *4))) (-5 *5 (-658 (-405))) (-5 *6 (-332 (-405))) (-5 *4 (-405)) (-5 *2 (-1063)) (-5 *1 (-827)))) (-4005 (*1 *2 *3 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1280 (-332 (-405)))) (-5 *4 (-405)) (-5 *5 (-658 *4)) (-5 *2 (-1063)) (-5 *1 (-827)))) (-4005 (*1 *2 *3 *4 *4 *5 *6 *4) (-12 (-5 *3 (-1280 (-332 *4))) (-5 *5 (-658 (-405))) (-5 *6 (-332 (-405))) (-5 *4 (-405)) (-5 *2 (-1063)) (-5 *1 (-827)))) (-4005 (*1 *2 *3 *4 *4 *5 *4) (-12 (-5 *3 (-1280 (-332 (-405)))) (-5 *4 (-405)) (-5 *5 (-658 *4)) (-5 *2 (-1063)) (-5 *1 (-827)))) (-4005 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1280 (-332 (-405)))) (-5 *4 (-405)) (-5 *5 (-658 *4)) (-5 *2 (-1063)) (-5 *1 (-827)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-830)) (-5 *4 (-1087)) (-5 *2 (-1063)) (-5 *1 (-827)))) (-4005 (*1 *2 *3) (-12 (-5 *3 (-830)) (-5 *2 (-1063)) (-5 *1 (-827))))) 
+(-10 -7 (-15 -4005 ((-1063) (-830))) (-15 -4005 ((-1063) (-830) (-1087))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-405))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-405))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-658 (-405)) (-405))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-658 (-405)) (-405))) (-15 -4005 ((-1063) (-1280 (-332 (-405))) (-405) (-405) (-658 (-405)) (-332 (-405)) (-658 (-405)) (-405) (-405))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-830))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-830) (-1087)))) 
+((-2371 (((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2195 (-658 |#4|))) (-667 |#4|) |#4|) 32))) 
+(((-828 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2371 ((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2195 (-658 |#4|))) (-667 |#4|) |#4|))) (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592)))) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|)) (T -828)) 
+((-2371 (*1 *2 *3 *4) (-12 (-5 *3 (-667 *4)) (-4 *4 (-362 *5 *6 *7)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-828 *5 *6 *7 *4))))) 
+(-10 -7 (-15 -2371 ((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2195 (-658 |#4|))) (-667 |#4|) |#4|))) 
+((-3626 (((-2 (|:| -2042 |#3|) (|:| |rh| (-658 (-433 |#2|)))) |#4| (-658 (-433 |#2|))) 51)) (-2601 (((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#4| |#2|) 59) (((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#4|) 58) (((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#3| |#2|) 20) (((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#3|) 21)) (-4436 ((|#2| |#4| |#1|) 60) ((|#2| |#3| |#1|) 27)) (-3853 ((|#2| |#3| (-658 (-433 |#2|))) 93) (((-3 |#2| "failed") |#3| (-433 |#2|)) 90))) 
+(((-829 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3853 ((-3 |#2| "failed") |#3| (-433 |#2|))) (-15 -3853 (|#2| |#3| (-658 (-433 |#2|)))) (-15 -2601 ((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#3|)) (-15 -2601 ((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#3| |#2|)) (-15 -4436 (|#2| |#3| |#1|)) (-15 -2601 ((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#4|)) (-15 -2601 ((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#4| |#2|)) (-15 -4436 (|#2| |#4| |#1|)) (-15 -3626 ((-2 (|:| -2042 |#3|) (|:| |rh| (-658 (-433 |#2|)))) |#4| (-658 (-433 |#2|))))) (-13 (-388) (-171) (-1065 (-433 (-592)))) (-1255 |#1|) (-670 |#2|) (-670 (-433 |#2|))) (T -829)) 
+((-3626 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-2 (|:| -2042 *7) (|:| |rh| (-658 (-433 *6))))) (-5 *1 (-829 *5 *6 *7 *3)) (-5 *4 (-658 (-433 *6))) (-4 *7 (-670 *6)) (-4 *3 (-670 (-433 *6))))) (-4436 (*1 *2 *3 *4) (-12 (-4 *2 (-1255 *4)) (-5 *1 (-829 *4 *2 *5 *3)) (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-670 *2)) (-4 *3 (-670 (-433 *2))))) (-2601 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *4 (-1255 *5)) (-5 *2 (-658 (-2 (|:| -2838 *4) (|:| -2724 *4)))) (-5 *1 (-829 *5 *4 *6 *3)) (-4 *6 (-670 *4)) (-4 *3 (-670 (-433 *4))))) (-2601 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-2 (|:| -2838 *5) (|:| -2724 *5)))) (-5 *1 (-829 *4 *5 *6 *3)) (-4 *6 (-670 *5)) (-4 *3 (-670 (-433 *5))))) (-4436 (*1 *2 *3 *4) (-12 (-4 *2 (-1255 *4)) (-5 *1 (-829 *4 *2 *3 *5)) (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-670 *2)) (-4 *5 (-670 (-433 *2))))) (-2601 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *4 (-1255 *5)) (-5 *2 (-658 (-2 (|:| -2838 *4) (|:| -2724 *4)))) (-5 *1 (-829 *5 *4 *3 *6)) (-4 *3 (-670 *4)) (-4 *6 (-670 (-433 *4))))) (-2601 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-2 (|:| -2838 *5) (|:| -2724 *5)))) (-5 *1 (-829 *4 *5 *3 *6)) (-4 *3 (-670 *5)) (-4 *6 (-670 (-433 *5))))) (-3853 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-433 *2))) (-4 *2 (-1255 *5)) (-5 *1 (-829 *5 *2 *3 *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-670 *2)) (-4 *6 (-670 (-433 *2))))) (-3853 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-433 *2)) (-4 *2 (-1255 *5)) (-5 *1 (-829 *5 *2 *3 *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-670 *2)) (-4 *6 (-670 *4))))) 
+(-10 -7 (-15 -3853 ((-3 |#2| "failed") |#3| (-433 |#2|))) (-15 -3853 (|#2| |#3| (-658 (-433 |#2|)))) (-15 -2601 ((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#3|)) (-15 -2601 ((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#3| |#2|)) (-15 -4436 (|#2| |#3| |#1|)) (-15 -2601 ((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#4|)) (-15 -2601 ((-658 (-2 (|:| -2838 |#2|) (|:| -2724 |#2|))) |#4| |#2|)) (-15 -4436 (|#2| |#4| |#1|)) (-15 -3626 ((-2 (|:| -2042 |#3|) (|:| |rh| (-658 (-433 |#2|)))) |#4| (-658 (-433 |#2|))))) 
+((-1641 (((-141) $ $) NIL)) (-2400 (((-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) $) 9)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 11) (($ (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) 8)) (-3255 (((-141) $ $) NIL))) 
+(((-830) (-13 (-1119) (-10 -8 (-15 -1683 ($ (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1683 ((-877) $)) (-15 -2400 ((-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) $))))) (T -830)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-830)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *1 (-830)))) (-2400 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *1 (-830))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-15 -1683 ((-877) $)) (-15 -2400 ((-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))) $)))) 
+((-1884 (((-658 (-2 (|:| |frac| (-433 |#2|)) (|:| -2042 |#3|))) |#3| (-1 (-658 |#2|) |#2| (-1187 |#2|)) (-1 (-444 |#2|) |#2|)) 118)) (-3111 (((-658 (-2 (|:| |poly| |#2|) (|:| -2042 |#3|))) |#3| (-1 (-658 |#1|) |#2|)) 45)) (-4037 (((-658 (-2 (|:| |deg| (-790)) (|:| -2042 |#2|))) |#3|) 95)) (-3742 ((|#2| |#3|) 37)) (-4580 (((-658 (-2 (|:| -4249 |#1|) (|:| -2042 |#3|))) |#3| (-1 (-658 |#1|) |#2|)) 82)) (-2323 ((|#3| |#3| (-433 |#2|)) 63) ((|#3| |#3| |#2|) 79))) 
+(((-831 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3742 (|#2| |#3|)) (-15 -4037 ((-658 (-2 (|:| |deg| (-790)) (|:| -2042 |#2|))) |#3|)) (-15 -4580 ((-658 (-2 (|:| -4249 |#1|) (|:| -2042 |#3|))) |#3| (-1 (-658 |#1|) |#2|))) (-15 -3111 ((-658 (-2 (|:| |poly| |#2|) (|:| -2042 |#3|))) |#3| (-1 (-658 |#1|) |#2|))) (-15 -1884 ((-658 (-2 (|:| |frac| (-433 |#2|)) (|:| -2042 |#3|))) |#3| (-1 (-658 |#2|) |#2| (-1187 |#2|)) (-1 (-444 |#2|) |#2|))) (-15 -2323 (|#3| |#3| |#2|)) (-15 -2323 (|#3| |#3| (-433 |#2|)))) (-13 (-388) (-171) (-1065 (-433 (-592)))) (-1255 |#1|) (-670 |#2|) (-670 (-433 |#2|))) (T -831)) 
+((-2323 (*1 *2 *2 *3) (-12 (-5 *3 (-433 *5)) (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *1 (-831 *4 *5 *2 *6)) (-4 *2 (-670 *5)) (-4 *6 (-670 *3)))) (-2323 (*1 *2 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-1255 *4)) (-5 *1 (-831 *4 *3 *2 *5)) (-4 *2 (-670 *3)) (-4 *5 (-670 (-433 *3))))) (-1884 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 (-658 *7) *7 (-1187 *7))) (-5 *5 (-1 (-444 *7) *7)) (-4 *7 (-1255 *6)) (-4 *6 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-5 *2 (-658 (-2 (|:| |frac| (-433 *7)) (|:| -2042 *3)))) (-5 *1 (-831 *6 *7 *3 *8)) (-4 *3 (-670 *7)) (-4 *8 (-670 (-433 *7))))) (-3111 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-2 (|:| |poly| *6) (|:| -2042 *3)))) (-5 *1 (-831 *5 *6 *3 *7)) (-4 *3 (-670 *6)) (-4 *7 (-670 (-433 *6))))) (-4580 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-2 (|:| -4249 *5) (|:| -2042 *3)))) (-5 *1 (-831 *5 *6 *3 *7)) (-4 *3 (-670 *6)) (-4 *7 (-670 (-433 *6))))) (-4037 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-2 (|:| |deg| (-790)) (|:| -2042 *5)))) (-5 *1 (-831 *4 *5 *3 *6)) (-4 *3 (-670 *5)) (-4 *6 (-670 (-433 *5))))) (-3742 (*1 *2 *3) (-12 (-4 *2 (-1255 *4)) (-5 *1 (-831 *4 *2 *3 *5)) (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-670 *2)) (-4 *5 (-670 (-433 *2)))))) 
+(-10 -7 (-15 -3742 (|#2| |#3|)) (-15 -4037 ((-658 (-2 (|:| |deg| (-790)) (|:| -2042 |#2|))) |#3|)) (-15 -4580 ((-658 (-2 (|:| -4249 |#1|) (|:| -2042 |#3|))) |#3| (-1 (-658 |#1|) |#2|))) (-15 -3111 ((-658 (-2 (|:| |poly| |#2|) (|:| -2042 |#3|))) |#3| (-1 (-658 |#1|) |#2|))) (-15 -1884 ((-658 (-2 (|:| |frac| (-433 |#2|)) (|:| -2042 |#3|))) |#3| (-1 (-658 |#2|) |#2| (-1187 |#2|)) (-1 (-444 |#2|) |#2|))) (-15 -2323 (|#3| |#3| |#2|)) (-15 -2323 (|#3| |#3| (-433 |#2|)))) 
+((-3952 (((-2 (|:| -2195 (-658 (-433 |#2|))) (|:| -3253 (-706 |#1|))) (-668 |#2| (-433 |#2|)) (-658 (-433 |#2|))) 117) (((-2 (|:| |particular| (-3 (-433 |#2|) "failed")) (|:| -2195 (-658 (-433 |#2|)))) (-668 |#2| (-433 |#2|)) (-433 |#2|)) 116) (((-2 (|:| -2195 (-658 (-433 |#2|))) (|:| -3253 (-706 |#1|))) (-667 (-433 |#2|)) (-658 (-433 |#2|))) 111) (((-2 (|:| |particular| (-3 (-433 |#2|) "failed")) (|:| -2195 (-658 (-433 |#2|)))) (-667 (-433 |#2|)) (-433 |#2|)) 109)) (-1965 ((|#2| (-668 |#2| (-433 |#2|))) 77) ((|#2| (-667 (-433 |#2|))) 81))) 
+(((-832 |#1| |#2|) (-10 -7 (-15 -3952 ((-2 (|:| |particular| (-3 (-433 |#2|) "failed")) (|:| -2195 (-658 (-433 |#2|)))) (-667 (-433 |#2|)) (-433 |#2|))) (-15 -3952 ((-2 (|:| -2195 (-658 (-433 |#2|))) (|:| -3253 (-706 |#1|))) (-667 (-433 |#2|)) (-658 (-433 |#2|)))) (-15 -3952 ((-2 (|:| |particular| (-3 (-433 |#2|) "failed")) (|:| -2195 (-658 (-433 |#2|)))) (-668 |#2| (-433 |#2|)) (-433 |#2|))) (-15 -3952 ((-2 (|:| -2195 (-658 (-433 |#2|))) (|:| -3253 (-706 |#1|))) (-668 |#2| (-433 |#2|)) (-658 (-433 |#2|)))) (-15 -1965 (|#2| (-667 (-433 |#2|)))) (-15 -1965 (|#2| (-668 |#2| (-433 |#2|))))) (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592)))) (-1255 |#1|)) (T -832)) 
+((-1965 (*1 *2 *3) (-12 (-5 *3 (-668 *2 (-433 *2))) (-4 *2 (-1255 *4)) (-5 *1 (-832 *4 *2)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))))) (-1965 (*1 *2 *3) (-12 (-5 *3 (-667 (-433 *2))) (-4 *2 (-1255 *4)) (-5 *1 (-832 *4 *2)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))))) (-3952 (*1 *2 *3 *4) (-12 (-5 *3 (-668 *6 (-433 *6))) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-2 (|:| -2195 (-658 (-433 *6))) (|:| -3253 (-706 *5)))) (-5 *1 (-832 *5 *6)) (-5 *4 (-658 (-433 *6))))) (-3952 (*1 *2 *3 *4) (-12 (-5 *3 (-668 *6 (-433 *6))) (-5 *4 (-433 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-832 *5 *6)))) (-3952 (*1 *2 *3 *4) (-12 (-5 *3 (-667 (-433 *6))) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-2 (|:| -2195 (-658 (-433 *6))) (|:| -3253 (-706 *5)))) (-5 *1 (-832 *5 *6)) (-5 *4 (-658 (-433 *6))))) (-3952 (*1 *2 *3 *4) (-12 (-5 *3 (-667 (-433 *6))) (-5 *4 (-433 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-832 *5 *6))))) 
+(-10 -7 (-15 -3952 ((-2 (|:| |particular| (-3 (-433 |#2|) "failed")) (|:| -2195 (-658 (-433 |#2|)))) (-667 (-433 |#2|)) (-433 |#2|))) (-15 -3952 ((-2 (|:| -2195 (-658 (-433 |#2|))) (|:| -3253 (-706 |#1|))) (-667 (-433 |#2|)) (-658 (-433 |#2|)))) (-15 -3952 ((-2 (|:| |particular| (-3 (-433 |#2|) "failed")) (|:| -2195 (-658 (-433 |#2|)))) (-668 |#2| (-433 |#2|)) (-433 |#2|))) (-15 -3952 ((-2 (|:| -2195 (-658 (-433 |#2|))) (|:| -3253 (-706 |#1|))) (-668 |#2| (-433 |#2|)) (-658 (-433 |#2|)))) (-15 -1965 (|#2| (-667 (-433 |#2|)))) (-15 -1965 (|#2| (-668 |#2| (-433 |#2|))))) 
+((-1539 (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#1|))) |#5| |#4|) 47))) 
+(((-833 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1539 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#1|))) |#5| |#4|))) (-388) (-670 |#1|) (-1255 |#1|) (-741 |#1| |#3|) (-670 |#4|)) (T -833)) 
+((-1539 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *7 (-1255 *5)) (-4 *4 (-741 *5 *7)) (-5 *2 (-2 (|:| -3253 (-706 *6)) (|:| |vec| (-1280 *5)))) (-5 *1 (-833 *5 *6 *7 *4 *3)) (-4 *6 (-670 *5)) (-4 *3 (-670 *4))))) 
+(-10 -7 (-15 -1539 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#1|))) |#5| |#4|))) 
+((-1884 (((-658 (-2 (|:| |frac| (-433 |#2|)) (|:| -2042 (-668 |#2| (-433 |#2|))))) (-668 |#2| (-433 |#2|)) (-1 (-444 |#2|) |#2|)) 43)) (-4170 (((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-444 |#2|) |#2|)) 133 (|has| |#1| (-27))) (((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|))) 134 (|has| |#1| (-27))) (((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-444 |#2|) |#2|)) 135 (|has| |#1| (-27))) (((-658 (-433 |#2|)) (-667 (-433 |#2|))) 136 (|has| |#1| (-27))) (((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|) (-1 (-444 |#2|) |#2|)) 36) (((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|)) 37) (((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|) (-1 (-444 |#2|) |#2|)) 34) (((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|)) 35)) (-3111 (((-658 (-2 (|:| |poly| |#2|) (|:| -2042 (-668 |#2| (-433 |#2|))))) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|)) 80))) 
+(((-834 |#1| |#2|) (-10 -7 (-15 -4170 ((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|))) (-15 -4170 ((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|) (-1 (-444 |#2|) |#2|))) (-15 -4170 ((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|))) (-15 -4170 ((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|) (-1 (-444 |#2|) |#2|))) (-15 -1884 ((-658 (-2 (|:| |frac| (-433 |#2|)) (|:| -2042 (-668 |#2| (-433 |#2|))))) (-668 |#2| (-433 |#2|)) (-1 (-444 |#2|) |#2|))) (-15 -3111 ((-658 (-2 (|:| |poly| |#2|) (|:| -2042 (-668 |#2| (-433 |#2|))))) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -4170 ((-658 (-433 |#2|)) (-667 (-433 |#2|)))) (-15 -4170 ((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-444 |#2|) |#2|))) (-15 -4170 ((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)))) (-15 -4170 ((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-444 |#2|) |#2|)))) |noBranch|)) (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592)))) (-1255 |#1|)) (T -834)) 
+((-4170 (*1 *2 *3 *4) (-12 (-5 *3 (-668 *6 (-433 *6))) (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-433 *6))) (-5 *1 (-834 *5 *6)))) (-4170 (*1 *2 *3) (-12 (-5 *3 (-668 *5 (-433 *5))) (-4 *5 (-1255 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-433 *5))) (-5 *1 (-834 *4 *5)))) (-4170 (*1 *2 *3 *4) (-12 (-5 *3 (-667 (-433 *6))) (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-433 *6))) (-5 *1 (-834 *5 *6)))) (-4170 (*1 *2 *3) (-12 (-5 *3 (-667 (-433 *5))) (-4 *5 (-1255 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-433 *5))) (-5 *1 (-834 *4 *5)))) (-3111 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-2 (|:| |poly| *6) (|:| -2042 (-668 *6 (-433 *6)))))) (-5 *1 (-834 *5 *6)) (-5 *3 (-668 *6 (-433 *6))))) (-1884 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-2 (|:| |frac| (-433 *6)) (|:| -2042 (-668 *6 (-433 *6)))))) (-5 *1 (-834 *5 *6)) (-5 *3 (-668 *6 (-433 *6))))) (-4170 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-668 *7 (-433 *7))) (-5 *4 (-1 (-658 *6) *7)) (-5 *5 (-1 (-444 *7) *7)) (-4 *6 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *7 (-1255 *6)) (-5 *2 (-658 (-433 *7))) (-5 *1 (-834 *6 *7)))) (-4170 (*1 *2 *3 *4) (-12 (-5 *3 (-668 *6 (-433 *6))) (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-433 *6))) (-5 *1 (-834 *5 *6)))) (-4170 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-667 (-433 *7))) (-5 *4 (-1 (-658 *6) *7)) (-5 *5 (-1 (-444 *7) *7)) (-4 *6 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *7 (-1255 *6)) (-5 *2 (-658 (-433 *7))) (-5 *1 (-834 *6 *7)))) (-4170 (*1 *2 *3 *4) (-12 (-5 *3 (-667 (-433 *6))) (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-433 *6))) (-5 *1 (-834 *5 *6))))) 
+(-10 -7 (-15 -4170 ((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|))) (-15 -4170 ((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-658 |#1|) |#2|) (-1 (-444 |#2|) |#2|))) (-15 -4170 ((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|))) (-15 -4170 ((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|) (-1 (-444 |#2|) |#2|))) (-15 -1884 ((-658 (-2 (|:| |frac| (-433 |#2|)) (|:| -2042 (-668 |#2| (-433 |#2|))))) (-668 |#2| (-433 |#2|)) (-1 (-444 |#2|) |#2|))) (-15 -3111 ((-658 (-2 (|:| |poly| |#2|) (|:| -2042 (-668 |#2| (-433 |#2|))))) (-668 |#2| (-433 |#2|)) (-1 (-658 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -4170 ((-658 (-433 |#2|)) (-667 (-433 |#2|)))) (-15 -4170 ((-658 (-433 |#2|)) (-667 (-433 |#2|)) (-1 (-444 |#2|) |#2|))) (-15 -4170 ((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)))) (-15 -4170 ((-658 (-433 |#2|)) (-668 |#2| (-433 |#2|)) (-1 (-444 |#2|) |#2|)))) |noBranch|)) 
+((-3595 (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#1|))) (-706 |#2|) (-1280 |#1|)) 86) (((-2 (|:| A (-706 |#1|)) (|:| |eqs| (-658 (-2 (|:| C (-706 |#1|)) (|:| |g| (-1280 |#1|)) (|:| -2042 |#2|) (|:| |rh| |#1|))))) (-706 |#1|) (-1280 |#1|)) 14)) (-3407 (((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-706 |#2|) (-1280 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2195 (-658 |#1|))) |#2| |#1|)) 92)) (-4005 (((-3 (-2 (|:| |particular| (-1280 |#1|)) (|:| -2195 (-706 |#1|))) "failed") (-706 |#1|) (-1280 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2195 (-658 |#1|))) "failed") |#2| |#1|)) 45))) 
+(((-835 |#1| |#2|) (-10 -7 (-15 -3595 ((-2 (|:| A (-706 |#1|)) (|:| |eqs| (-658 (-2 (|:| C (-706 |#1|)) (|:| |g| (-1280 |#1|)) (|:| -2042 |#2|) (|:| |rh| |#1|))))) (-706 |#1|) (-1280 |#1|))) (-15 -3595 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#1|))) (-706 |#2|) (-1280 |#1|))) (-15 -4005 ((-3 (-2 (|:| |particular| (-1280 |#1|)) (|:| -2195 (-706 |#1|))) "failed") (-706 |#1|) (-1280 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2195 (-658 |#1|))) "failed") |#2| |#1|))) (-15 -3407 ((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-706 |#2|) (-1280 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2195 (-658 |#1|))) |#2| |#1|)))) (-388) (-670 |#1|)) (T -835)) 
+((-3407 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *7)) (-5 *5 (-1 (-2 (|:| |particular| (-3 *6 "failed")) (|:| -2195 (-658 *6))) *7 *6)) (-4 *6 (-388)) (-4 *7 (-670 *6)) (-5 *2 (-2 (|:| |particular| (-3 (-1280 *6) "failed")) (|:| -2195 (-658 (-1280 *6))))) (-5 *1 (-835 *6 *7)) (-5 *4 (-1280 *6)))) (-4005 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-2 (|:| |particular| *6) (|:| -2195 (-658 *6))) "failed") *7 *6)) (-4 *6 (-388)) (-4 *7 (-670 *6)) (-5 *2 (-2 (|:| |particular| (-1280 *6)) (|:| -2195 (-706 *6)))) (-5 *1 (-835 *6 *7)) (-5 *3 (-706 *6)) (-5 *4 (-1280 *6)))) (-3595 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-670 *5)) (-5 *2 (-2 (|:| -3253 (-706 *6)) (|:| |vec| (-1280 *5)))) (-5 *1 (-835 *5 *6)) (-5 *3 (-706 *6)) (-5 *4 (-1280 *5)))) (-3595 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-5 *2 (-2 (|:| A (-706 *5)) (|:| |eqs| (-658 (-2 (|:| C (-706 *5)) (|:| |g| (-1280 *5)) (|:| -2042 *6) (|:| |rh| *5)))))) (-5 *1 (-835 *5 *6)) (-5 *3 (-706 *5)) (-5 *4 (-1280 *5)) (-4 *6 (-670 *5))))) 
+(-10 -7 (-15 -3595 ((-2 (|:| A (-706 |#1|)) (|:| |eqs| (-658 (-2 (|:| C (-706 |#1|)) (|:| |g| (-1280 |#1|)) (|:| -2042 |#2|) (|:| |rh| |#1|))))) (-706 |#1|) (-1280 |#1|))) (-15 -3595 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#1|))) (-706 |#2|) (-1280 |#1|))) (-15 -4005 ((-3 (-2 (|:| |particular| (-1280 |#1|)) (|:| -2195 (-706 |#1|))) "failed") (-706 |#1|) (-1280 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2195 (-658 |#1|))) "failed") |#2| |#1|))) (-15 -3407 ((-2 (|:| |particular| (-3 (-1280 |#1|) "failed")) (|:| -2195 (-658 (-1280 |#1|)))) (-706 |#2|) (-1280 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2195 (-658 |#1|))) |#2| |#1|)))) 
+((-4524 (((-706 |#1|) (-658 |#1|) (-790)) 13) (((-706 |#1|) (-658 |#1|)) 14)) (-2361 (((-3 (-1280 |#1|) "failed") |#2| |#1| (-658 |#1|)) 34)) (-3993 (((-3 |#1| "failed") |#2| |#1| (-658 |#1|) (-1 |#1| |#1|)) 42))) 
+(((-836 |#1| |#2|) (-10 -7 (-15 -4524 ((-706 |#1|) (-658 |#1|))) (-15 -4524 ((-706 |#1|) (-658 |#1|) (-790))) (-15 -2361 ((-3 (-1280 |#1|) "failed") |#2| |#1| (-658 |#1|))) (-15 -3993 ((-3 |#1| "failed") |#2| |#1| (-658 |#1|) (-1 |#1| |#1|)))) (-388) (-670 |#1|)) (T -836)) 
+((-3993 (*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *4 (-658 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-388)) (-5 *1 (-836 *2 *3)) (-4 *3 (-670 *2)))) (-2361 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-658 *4)) (-4 *4 (-388)) (-5 *2 (-1280 *4)) (-5 *1 (-836 *4 *3)) (-4 *3 (-670 *4)))) (-4524 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-790)) (-4 *5 (-388)) (-5 *2 (-706 *5)) (-5 *1 (-836 *5 *6)) (-4 *6 (-670 *5)))) (-4524 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-5 *2 (-706 *4)) (-5 *1 (-836 *4 *5)) (-4 *5 (-670 *4))))) 
+(-10 -7 (-15 -4524 ((-706 |#1|) (-658 |#1|))) (-15 -4524 ((-706 |#1|) (-658 |#1|) (-790))) (-15 -2361 ((-3 (-1280 |#1|) "failed") |#2| |#1| (-658 |#1|))) (-15 -3993 ((-3 |#1| "failed") |#2| |#1| (-658 |#1|) (-1 |#1| |#1|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#2| (-1119)))) (-2272 (((-141) $) NIL (|has| |#2| (-158)))) (-2673 (($ (-944)) NIL (|has| |#2| (-1075)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4079 (($ $ $) NIL (|has| |#2| (-815)))) (-2350 (((-3 $ "failed") $ $) NIL (|has| |#2| (-158)))) (-2126 (((-141) $ (-790)) NIL)) (-1403 (((-790)) NIL (|has| |#2| (-394)))) (-3940 (((-592) $) NIL (|has| |#2| (-867)))) (-3932 ((|#2| $ (-592) |#2|) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) (((-3 |#2| "failed") $) NIL (|has| |#2| (-1119)))) (-2400 (((-592) $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119)))) (((-433 (-592)) $) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) ((|#2| $) NIL (|has| |#2| (-1119)))) (-3945 (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#2| (-1075)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL (|has| |#2| (-1075))) (((-706 |#2|) (-706 $)) NIL (|has| |#2| (-1075)))) (-3371 (((-3 $ "failed") $) NIL (|has| |#2| (-743)))) (-4290 (($) NIL (|has| |#2| (-394)))) (-1426 ((|#2| $ (-592) |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ (-592)) NIL)) (-1691 (((-141) $) NIL (|has| |#2| (-867)))) (-4004 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3558 (((-141) $) NIL (|has| |#2| (-743)))) (-1324 (((-141) $) NIL (|has| |#2| (-867)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-4467 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3987 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-3546 (((-944) $) NIL (|has| |#2| (-394)))) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#2| (-1119)))) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-1825 (($ (-944)) NIL (|has| |#2| (-394)))) (-2951 (((-1137) $) NIL (|has| |#2| (-1119)))) (-1918 ((|#2| $) NIL (|has| (-592) (-869)))) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1405 (((-658 $)) NIL (|has| |#2| (-394)))) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ (-592) |#2|) NIL) ((|#2| $ (-592)) NIL)) (-1729 ((|#2| $ $) NIL (|has| |#2| (-1075)))) (-4512 (($ (-1280 |#2|)) NIL)) (-1936 (((-160)) NIL (|has| |#2| (-388)))) (-3644 (($ $) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1 |#2| |#2|) (-790)) NIL (|has| |#2| (-1075))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1075)))) (-3452 (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-1280 |#2|) $) NIL) (((-877) $) NIL (|has| |#2| (-1119))) (($ (-592)) NIL (-3836 (-12 (|has| |#2| (-1065 (-592))) (|has| |#2| (-1119))) (|has| |#2| (-1075)))) (($ (-433 (-592))) NIL (-12 (|has| |#2| (-1065 (-433 (-592)))) (|has| |#2| (-1119)))) (($ |#2|) NIL (|has| |#2| (-1119)))) (-4010 (((-790)) NIL (|has| |#2| (-1075)))) (-3369 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-1392 (($ $) NIL (|has| |#2| (-867)))) (-1424 (($ $ (-790)) NIL (|has| |#2| (-743))) (($ $ (-944)) NIL (|has| |#2| (-743)))) (-3514 (($) NIL (|has| |#2| (-158)) CONST)) (-4257 (($) NIL (|has| |#2| (-743)) CONST)) (-1940 (($ $) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#2| (-247)) (|has| |#2| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#2| (-922 (-1191))) (|has| |#2| (-1075)))) (($ $ (-1 |#2| |#2|) (-790)) NIL (|has| |#2| (-1075))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1075)))) (-3286 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3273 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3255 (((-141) $ $) NIL (|has| |#2| (-1119)))) (-3279 (((-141) $ $) NIL (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3266 (((-141) $ $) 11 (-3836 (|has| |#2| (-815)) (|has| |#2| (-867))))) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $ $) NIL (|has| |#2| (-1075))) (($ $) NIL (|has| |#2| (-1075)))) (-3300 (($ $ $) NIL (|has| |#2| (-25)))) (** (($ $ (-790)) NIL (|has| |#2| (-743))) (($ $ (-944)) NIL (|has| |#2| (-743)))) (* (($ (-592) $) NIL (|has| |#2| (-1075))) (($ $ $) NIL (|has| |#2| (-743))) (($ $ |#2|) NIL (|has| |#2| (-743))) (($ |#2| $) NIL (|has| |#2| (-743))) (($ (-790) $) NIL (|has| |#2| (-158))) (($ (-944) $) NIL (|has| |#2| (-25)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-837 |#1| |#2| |#3|) (-252 |#1| |#2|) (-790) (-815) (-1 (-141) (-1280 |#2|) (-1280 |#2|))) (T -837)) 
+NIL 
+(-252 |#1| |#2|) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1399 (((-658 (-790)) $) NIL) (((-658 (-790)) $ (-1191)) NIL)) (-3775 (((-790) $) NIL) (((-790) $ (-1191)) NIL)) (-4085 (((-658 (-840 (-1191))) $) NIL)) (-4492 (((-1187 $) $ (-840 (-1191))) NIL) (((-1187 |#1|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-840 (-1191)))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-1885 (($ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-840 (-1191)) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL) (((-3 (-1142 |#1| (-1191)) "failed") $) NIL)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-840 (-1191)) $) NIL) (((-1191) $) NIL) (((-1142 |#1| (-1191)) $) NIL)) (-1544 (($ $ $ (-840 (-1191))) NIL (|has| |#1| (-194)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ (-840 (-1191))) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-558 (-840 (-1191))) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-840 (-1191)) (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-840 (-1191)) (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-4346 (((-790) $ (-1191)) NIL) (((-790) $) NIL)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-4533 (($ (-1187 |#1|) (-840 (-1191))) NIL) (($ (-1187 $) (-840 (-1191))) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-558 (-840 (-1191)))) NIL) (($ $ (-840 (-1191)) (-790)) NIL) (($ $ (-658 (-840 (-1191))) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-840 (-1191))) NIL)) (-4206 (((-558 (-840 (-1191))) $) NIL) (((-790) $ (-840 (-1191))) NIL) (((-658 (-790)) $ (-658 (-840 (-1191)))) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-558 (-840 (-1191))) (-558 (-840 (-1191)))) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3358 (((-1 $ (-790)) (-1191)) NIL) (((-1 $ (-790)) $) NIL (|has| |#1| (-247)))) (-3254 (((-3 (-840 (-1191)) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-1692 (((-840 (-1191)) $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-4401 (((-141) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-840 (-1191))) (|:| -3215 (-790))) "failed") $) NIL)) (-3198 (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-840 (-1191)) |#1|) NIL) (($ $ (-658 (-840 (-1191))) (-658 |#1|)) NIL) (($ $ (-840 (-1191)) $) NIL) (($ $ (-658 (-840 (-1191))) (-658 $)) NIL) (($ $ (-1191) $) NIL (|has| |#1| (-247))) (($ $ (-658 (-1191)) (-658 $)) NIL (|has| |#1| (-247))) (($ $ (-1191) |#1|) NIL (|has| |#1| (-247))) (($ $ (-658 (-1191)) (-658 |#1|)) NIL (|has| |#1| (-247)))) (-1482 (($ $ (-840 (-1191))) NIL (|has| |#1| (-194)))) (-3644 (($ $ (-840 (-1191))) NIL) (($ $ (-658 (-840 (-1191)))) NIL) (($ $ (-840 (-1191)) (-790)) NIL) (($ $ (-658 (-840 (-1191))) (-658 (-790))) NIL) (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2912 (((-658 (-1191)) $) NIL)) (-4525 (((-558 (-840 (-1191))) $) NIL) (((-790) $ (-840 (-1191))) NIL) (((-658 (-790)) $ (-658 (-840 (-1191)))) NIL) (((-790) $ (-1191)) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-840 (-1191)) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-840 (-1191)) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-840 (-1191)) (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) NIL (|has| |#1| (-477))) (($ $ (-840 (-1191))) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-840 (-1191))) NIL) (($ (-1191)) NIL) (($ (-1142 |#1| (-1191))) NIL) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-558 (-840 (-1191)))) NIL) (($ $ (-840 (-1191)) (-790)) NIL) (($ $ (-658 (-840 (-1191))) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-840 (-1191))) NIL) (($ $ (-658 (-840 (-1191)))) NIL) (($ $ (-840 (-1191)) (-790)) NIL) (($ $ (-658 (-840 (-1191))) (-658 (-790))) NIL) (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-838 |#1|) (-13 (-268 |#1| (-1191) (-840 (-1191)) (-558 (-840 (-1191)))) (-1065 (-1142 |#1| (-1191)))) (-1075)) (T -838)) 
+NIL 
+(-13 (-268 |#1| (-1191) (-840 (-1191)) (-558 (-840 (-1191)))) (-1065 (-1142 |#1| (-1191)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#2| (-388)))) (-1555 (($ $) NIL (|has| |#2| (-388)))) (-1313 (((-141) $) NIL (|has| |#2| (-388)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| |#2| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#2| (-388)))) (-3652 (((-141) $ $) NIL (|has| |#2| (-388)))) (-3001 (($) NIL T CONST)) (-1586 (($ $ $) NIL (|has| |#2| (-388)))) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#2| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#2| (-388)))) (-2802 (((-141) $) NIL (|has| |#2| (-388)))) (-3558 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#2| (-388)))) (-2750 (($ (-658 $)) NIL (|has| |#2| (-388))) (($ $ $) NIL (|has| |#2| (-388)))) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 20 (|has| |#2| (-388)))) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#2| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#2| (-388))) (($ $ $) NIL (|has| |#2| (-388)))) (-4500 (((-444 $) $) NIL (|has| |#2| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#2| (-388)))) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#2| (-388)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#2| (-388)))) (-2769 (((-790) $) NIL (|has| |#2| (-388)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-388)))) (-3644 (($ $ (-790)) NIL) (($ $) 13)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) 10) ((|#2| $) 11) (($ (-433 (-592))) NIL (|has| |#2| (-388))) (($ $) NIL (|has| |#2| (-388)))) (-4010 (((-790)) NIL)) (-2537 (((-141) $ $) NIL (|has| |#2| (-388)))) (-1424 (($ $ (-790)) NIL) (($ $ (-944)) NIL) (($ $ (-592)) NIL (|has| |#2| (-388)))) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) 15 (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-944)) NIL) (($ $ (-592)) 18 (|has| |#2| (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ $) NIL) (($ (-433 (-592)) $) NIL (|has| |#2| (-388))) (($ $ (-433 (-592))) NIL (|has| |#2| (-388))))) 
+(((-839 |#1| |#2| |#3|) (-13 (-140 $ $) (-247) (-10 -8 (IF (|has| |#2| (-388)) (-6 (-388)) |noBranch|) (-15 -1683 ($ |#2|)) (-15 -1683 (|#2| $)))) (-1119) (-922 |#1|) |#1|) (T -839)) 
+((-1683 (*1 *1 *2) (-12 (-4 *3 (-1119)) (-14 *4 *3) (-5 *1 (-839 *3 *2 *4)) (-4 *2 (-922 *3)))) (-1683 (*1 *2 *1) (-12 (-4 *2 (-922 *3)) (-5 *1 (-839 *3 *2 *4)) (-4 *3 (-1119)) (-14 *4 *3)))) 
+(-13 (-140 $ $) (-247) (-10 -8 (IF (|has| |#2| (-388)) (-6 (-388)) |noBranch|) (-15 -1683 ($ |#2|)) (-15 -1683 (|#2| $)))) 
+((-1641 (((-141) $ $) NIL)) (-3775 (((-790) $) NIL)) (-3983 ((|#1| $) 10)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-4346 (((-790) $) 11)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-3358 (($ |#1| (-790)) 9)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3644 (($ $) NIL) (($ $ (-790)) NIL)) (-1683 (((-877) $) NIL) (($ |#1|) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL))) 
+(((-840 |#1|) (-284 |#1|) (-869)) (T -840)) 
+NIL 
+(-284 |#1|) 
+((-1641 (((-141) $ $) NIL)) (-2692 (((-658 |#1|) $) 34)) (-1403 (((-790) $) NIL)) (-3001 (($) NIL T CONST)) (-3305 (((-3 $ "failed") $ $) 21) (((-3 $ "failed") $ |#1|) 19)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-1366 (($ $) 36)) (-3371 (((-3 $ "failed") $) NIL)) (-3949 (((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) NIL)) (-3558 (((-141) $) NIL)) (-4449 ((|#1| $ (-592)) NIL)) (-3888 (((-790) $ (-592)) NIL)) (-4103 (($ $) 40)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2141 (((-3 $ "failed") $ $) 20) (((-3 $ "failed") $ |#1|) 16)) (-3547 (((-141) $ $) 38)) (-4233 (((-790) $) 30)) (-2685 (((-1173) $) NIL)) (-4403 (($ $ $) NIL)) (-4041 (($ $ $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 ((|#1| $) 35)) (-2033 (((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-790)))) $) NIL)) (-4570 (((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $) 24)) (-1683 (((-877) $) NIL) (($ |#1|) NIL)) (-1424 (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (-4257 (($) 14 T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 39)) (** (($ $ (-790)) NIL) (($ $ (-944)) NIL) (($ |#1| (-790)) NIL)) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-841 |#1|) (-13 (-865) (-1065 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-790))) (-15 -1918 (|#1| $)) (-15 -1366 ($ $)) (-15 -4103 ($ $)) (-15 -3547 ((-141) $ $)) (-15 -4041 ($ $ $)) (-15 -4403 ($ $ $)) (-15 -2141 ((-3 $ "failed") $ $)) (-15 -3305 ((-3 $ "failed") $ $)) (-15 -2141 ((-3 $ "failed") $ |#1|)) (-15 -3305 ((-3 $ "failed") $ |#1|)) (-15 -4570 ((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $)) (-15 -3949 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -1403 ((-790) $)) (-15 -3888 ((-790) $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -2033 ((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-790)))) $)) (-15 -4233 ((-790) $)) (-15 -2692 ((-658 |#1|) $)))) (-869)) (T -841)) 
+((* (*1 *1 *2 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-1918 (*1 *2 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-1366 (*1 *1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-4103 (*1 *1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-3547 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-841 *3)) (-4 *3 (-869)))) (-4041 (*1 *1 *1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-4403 (*1 *1 *1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-2141 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-3305 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-2141 (*1 *1 *1 *2) (|partial| -12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-3305 (*1 *1 *1 *2) (|partial| -12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-4570 (*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-3 (-841 *3) "failed")) (|:| |rm| (-3 (-841 *3) "failed")))) (-5 *1 (-841 *3)) (-4 *3 (-869)))) (-3949 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-841 *3)) (|:| |mm| (-841 *3)) (|:| |rm| (-841 *3)))) (-5 *1 (-841 *3)) (-4 *3 (-869)))) (-1403 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-841 *3)) (-4 *3 (-869)))) (-3888 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-790)) (-5 *1 (-841 *4)) (-4 *4 (-869)))) (-4449 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-841 *2)) (-4 *2 (-869)))) (-2033 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 (-790))))) (-5 *1 (-841 *3)) (-4 *3 (-869)))) (-4233 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-841 *3)) (-4 *3 (-869)))) (-2692 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-841 *3)) (-4 *3 (-869))))) 
+(-13 (-865) (-1065 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-790))) (-15 -1918 (|#1| $)) (-15 -1366 ($ $)) (-15 -4103 ($ $)) (-15 -3547 ((-141) $ $)) (-15 -4041 ($ $ $)) (-15 -4403 ($ $ $)) (-15 -2141 ((-3 $ "failed") $ $)) (-15 -3305 ((-3 $ "failed") $ $)) (-15 -2141 ((-3 $ "failed") $ |#1|)) (-15 -3305 ((-3 $ "failed") $ |#1|)) (-15 -4570 ((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $)) (-15 -3949 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -1403 ((-790) $)) (-15 -3888 ((-790) $ (-592))) (-15 -4449 (|#1| $ (-592))) (-15 -2033 ((-658 (-2 (|:| |gen| |#1|) (|:| -1430 (-790)))) $)) (-15 -4233 ((-790) $)) (-15 -2692 ((-658 |#1|) $)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3940 (((-592) $) 52)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-1691 (((-141) $) 50)) (-3558 (((-141) $) 30)) (-1324 (((-141) $) 51)) (-1837 (($ $ $) 49)) (-3319 (($ $ $) 48)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ $) 41)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1392 (($ $) 53)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3286 (((-141) $ $) 46)) (-3273 (((-141) $ $) 45)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 47)) (-3266 (((-141) $ $) 44)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-842) (-1311)) (T -842)) 
+NIL 
+(-13 (-582) (-867)) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-582) . T) ((-661 $) . T) ((-734 $) . T) ((-743) . T) ((-813) . T) ((-814) . T) ((-816) . T) ((-817) . T) ((-867) . T) ((-869) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-2612 (($ (-1137)) 7)) (-4062 (((-141) $ (-1173) (-1137)) 15)) (-3353 (((-844) $) 12)) (-3835 (((-844) $) 11)) (-2217 (((-1285) $) 9)) (-4397 (((-141) $ (-1137)) 16))) 
+(((-843) (-10 -8 (-15 -2612 ($ (-1137))) (-15 -2217 ((-1285) $)) (-15 -3835 ((-844) $)) (-15 -3353 ((-844) $)) (-15 -4062 ((-141) $ (-1173) (-1137))) (-15 -4397 ((-141) $ (-1137))))) (T -843)) 
+((-4397 (*1 *2 *1 *3) (-12 (-5 *3 (-1137)) (-5 *2 (-141)) (-5 *1 (-843)))) (-4062 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-1137)) (-5 *2 (-141)) (-5 *1 (-843)))) (-3353 (*1 *2 *1) (-12 (-5 *2 (-844)) (-5 *1 (-843)))) (-3835 (*1 *2 *1) (-12 (-5 *2 (-844)) (-5 *1 (-843)))) (-2217 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-843)))) (-2612 (*1 *1 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-843))))) 
+(-10 -8 (-15 -2612 ($ (-1137))) (-15 -2217 ((-1285) $)) (-15 -3835 ((-844) $)) (-15 -3353 ((-844) $)) (-15 -4062 ((-141) $ (-1173) (-1137))) (-15 -4397 ((-141) $ (-1137)))) 
+((-1513 (((-1285) $ (-845)) 12)) (-2201 (((-1285) $ (-1191)) 32)) (-1580 (((-1285) $ (-1173) (-1173)) 34)) (-2355 (((-1285) $ (-1173)) 33)) (-2011 (((-1285) $) 19)) (-3009 (((-1285) $ (-592)) 28)) (-2499 (((-1285) $ (-237)) 30)) (-1418 (((-1285) $) 18)) (-4248 (((-1285) $) 26)) (-2897 (((-1285) $) 25)) (-2035 (((-1285) $) 23)) (-2594 (((-1285) $) 24)) (-4316 (((-1285) $) 22)) (-3146 (((-1285) $) 21)) (-4370 (((-1285) $) 20)) (-4356 (((-1285) $) 16)) (-2402 (((-1285) $) 17)) (-1607 (((-1285) $) 15)) (-2480 (((-1285) $) 14)) (-2887 (((-1285) $) 13)) (-2404 (($ (-1173) (-845)) 9)) (-3295 (($ (-1173) (-1173) (-845)) 8)) (-4340 (((-1191) $) 51)) (-1851 (((-1191) $) 55)) (-3088 (((-2 (|:| |cd| (-1173)) (|:| -4095 (-1173))) $) 54)) (-4444 (((-1173) $) 52)) (-4484 (((-1285) $) 41)) (-2983 (((-592) $) 49)) (-2414 (((-237) $) 50)) (-1944 (((-1285) $) 40)) (-3042 (((-1285) $) 48)) (-3661 (((-1285) $) 47)) (-1950 (((-1285) $) 45)) (-1895 (((-1285) $) 46)) (-3411 (((-1285) $) 44)) (-4513 (((-1285) $) 43)) (-2421 (((-1285) $) 42)) (-3140 (((-1285) $) 38)) (-4212 (((-1285) $) 39)) (-4502 (((-1285) $) 37)) (-1894 (((-1285) $) 36)) (-3329 (((-1285) $) 35)) (-2587 (((-1285) $) 11))) 
+(((-844) (-10 -8 (-15 -3295 ($ (-1173) (-1173) (-845))) (-15 -2404 ($ (-1173) (-845))) (-15 -2587 ((-1285) $)) (-15 -1513 ((-1285) $ (-845))) (-15 -2887 ((-1285) $)) (-15 -2480 ((-1285) $)) (-15 -1607 ((-1285) $)) (-15 -4356 ((-1285) $)) (-15 -2402 ((-1285) $)) (-15 -1418 ((-1285) $)) (-15 -2011 ((-1285) $)) (-15 -4370 ((-1285) $)) (-15 -3146 ((-1285) $)) (-15 -4316 ((-1285) $)) (-15 -2035 ((-1285) $)) (-15 -2594 ((-1285) $)) (-15 -2897 ((-1285) $)) (-15 -4248 ((-1285) $)) (-15 -3009 ((-1285) $ (-592))) (-15 -2499 ((-1285) $ (-237))) (-15 -2201 ((-1285) $ (-1191))) (-15 -2355 ((-1285) $ (-1173))) (-15 -1580 ((-1285) $ (-1173) (-1173))) (-15 -3329 ((-1285) $)) (-15 -1894 ((-1285) $)) (-15 -4502 ((-1285) $)) (-15 -3140 ((-1285) $)) (-15 -4212 ((-1285) $)) (-15 -1944 ((-1285) $)) (-15 -4484 ((-1285) $)) (-15 -2421 ((-1285) $)) (-15 -4513 ((-1285) $)) (-15 -3411 ((-1285) $)) (-15 -1950 ((-1285) $)) (-15 -1895 ((-1285) $)) (-15 -3661 ((-1285) $)) (-15 -3042 ((-1285) $)) (-15 -2983 ((-592) $)) (-15 -2414 ((-237) $)) (-15 -4340 ((-1191) $)) (-15 -4444 ((-1173) $)) (-15 -3088 ((-2 (|:| |cd| (-1173)) (|:| -4095 (-1173))) $)) (-15 -1851 ((-1191) $)))) (T -844)) 
+((-1851 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-844)))) (-3088 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |cd| (-1173)) (|:| -4095 (-1173)))) (-5 *1 (-844)))) (-4444 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-844)))) (-4340 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-844)))) (-2414 (*1 *2 *1) (-12 (-5 *2 (-237)) (-5 *1 (-844)))) (-2983 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-844)))) (-3042 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-3661 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-1895 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-1950 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-3411 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-4513 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2421 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-4484 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-1944 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-4212 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-3140 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-4502 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-1894 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-3329 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-1580 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-844)))) (-2355 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-844)))) (-2201 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-844)))) (-2499 (*1 *2 *1 *3) (-12 (-5 *3 (-237)) (-5 *2 (-1285)) (-5 *1 (-844)))) (-3009 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-844)))) (-4248 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2897 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2594 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2035 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-4316 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-3146 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-4370 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2011 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-1418 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2402 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-4356 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-1607 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2480 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2887 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-1513 (*1 *2 *1 *3) (-12 (-5 *3 (-845)) (-5 *2 (-1285)) (-5 *1 (-844)))) (-2587 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844)))) (-2404 (*1 *1 *2 *3) (-12 (-5 *2 (-1173)) (-5 *3 (-845)) (-5 *1 (-844)))) (-3295 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-1173)) (-5 *3 (-845)) (-5 *1 (-844))))) 
+(-10 -8 (-15 -3295 ($ (-1173) (-1173) (-845))) (-15 -2404 ($ (-1173) (-845))) (-15 -2587 ((-1285) $)) (-15 -1513 ((-1285) $ (-845))) (-15 -2887 ((-1285) $)) (-15 -2480 ((-1285) $)) (-15 -1607 ((-1285) $)) (-15 -4356 ((-1285) $)) (-15 -2402 ((-1285) $)) (-15 -1418 ((-1285) $)) (-15 -2011 ((-1285) $)) (-15 -4370 ((-1285) $)) (-15 -3146 ((-1285) $)) (-15 -4316 ((-1285) $)) (-15 -2035 ((-1285) $)) (-15 -2594 ((-1285) $)) (-15 -2897 ((-1285) $)) (-15 -4248 ((-1285) $)) (-15 -3009 ((-1285) $ (-592))) (-15 -2499 ((-1285) $ (-237))) (-15 -2201 ((-1285) $ (-1191))) (-15 -2355 ((-1285) $ (-1173))) (-15 -1580 ((-1285) $ (-1173) (-1173))) (-15 -3329 ((-1285) $)) (-15 -1894 ((-1285) $)) (-15 -4502 ((-1285) $)) (-15 -3140 ((-1285) $)) (-15 -4212 ((-1285) $)) (-15 -1944 ((-1285) $)) (-15 -4484 ((-1285) $)) (-15 -2421 ((-1285) $)) (-15 -4513 ((-1285) $)) (-15 -3411 ((-1285) $)) (-15 -1950 ((-1285) $)) (-15 -1895 ((-1285) $)) (-15 -3661 ((-1285) $)) (-15 -3042 ((-1285) $)) (-15 -2983 ((-592) $)) (-15 -2414 ((-237) $)) (-15 -4340 ((-1191) $)) (-15 -4444 ((-1173) $)) (-15 -3088 ((-2 (|:| |cd| (-1173)) (|:| -4095 (-1173))) $)) (-15 -1851 ((-1191) $))) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 12)) (-3236 (($) 15)) (-3998 (($) 13)) (-1583 (($) 16)) (-4303 (($) 14)) (-3255 (((-141) $ $) 8))) 
+(((-845) (-13 (-1119) (-10 -8 (-15 -3998 ($)) (-15 -3236 ($)) (-15 -1583 ($)) (-15 -4303 ($))))) (T -845)) 
+((-3998 (*1 *1) (-5 *1 (-845))) (-3236 (*1 *1) (-5 *1 (-845))) (-1583 (*1 *1) (-5 *1 (-845))) (-4303 (*1 *1) (-5 *1 (-845)))) 
+(-13 (-1119) (-10 -8 (-15 -3998 ($)) (-15 -3236 ($)) (-15 -1583 ($)) (-15 -4303 ($)))) 
+((-1641 (((-141) $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 21) (($ (-1191)) 17)) (-4413 (((-141) $) 10)) (-1315 (((-141) $) 9)) (-2471 (((-141) $) 11)) (-2028 (((-141) $) 8)) (-3255 (((-141) $ $) 19))) 
+(((-846) (-13 (-1119) (-10 -8 (-15 -1683 ($ (-1191))) (-15 -2028 ((-141) $)) (-15 -1315 ((-141) $)) (-15 -4413 ((-141) $)) (-15 -2471 ((-141) $))))) (T -846)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-846)))) (-2028 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-846)))) (-1315 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-846)))) (-4413 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-846)))) (-2471 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-846))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-1191))) (-15 -2028 ((-141) $)) (-15 -1315 ((-141) $)) (-15 -4413 ((-141) $)) (-15 -2471 ((-141) $)))) 
+((-1641 (((-141) $ $) NIL)) (-2158 (($ (-846) (-658 (-1191))) 24)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4411 (((-846) $) 25)) (-2855 (((-658 (-1191)) $) 26)) (-1683 (((-877) $) 23)) (-3255 (((-141) $ $) NIL))) 
+(((-847) (-13 (-1119) (-10 -8 (-15 -4411 ((-846) $)) (-15 -2855 ((-658 (-1191)) $)) (-15 -2158 ($ (-846) (-658 (-1191))))))) (T -847)) 
+((-4411 (*1 *2 *1) (-12 (-5 *2 (-846)) (-5 *1 (-847)))) (-2855 (*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-847)))) (-2158 (*1 *1 *2 *3) (-12 (-5 *2 (-846)) (-5 *3 (-658 (-1191))) (-5 *1 (-847))))) 
+(-13 (-1119) (-10 -8 (-15 -4411 ((-846) $)) (-15 -2855 ((-658 (-1191)) $)) (-15 -2158 ($ (-846) (-658 (-1191)))))) 
+((-1637 (((-1285) (-844) (-332 |#1|) (-141)) 22) (((-1285) (-844) (-332 |#1|)) 76) (((-1173) (-332 |#1|) (-141)) 75) (((-1173) (-332 |#1|)) 74))) 
+(((-848 |#1|) (-10 -7 (-15 -1637 ((-1173) (-332 |#1|))) (-15 -1637 ((-1173) (-332 |#1|) (-141))) (-15 -1637 ((-1285) (-844) (-332 |#1|))) (-15 -1637 ((-1285) (-844) (-332 |#1|) (-141)))) (-13 (-850) (-869) (-1075))) (T -848)) 
+((-1637 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-844)) (-5 *4 (-332 *6)) (-5 *5 (-141)) (-4 *6 (-13 (-850) (-869) (-1075))) (-5 *2 (-1285)) (-5 *1 (-848 *6)))) (-1637 (*1 *2 *3 *4) (-12 (-5 *3 (-844)) (-5 *4 (-332 *5)) (-4 *5 (-13 (-850) (-869) (-1075))) (-5 *2 (-1285)) (-5 *1 (-848 *5)))) (-1637 (*1 *2 *3 *4) (-12 (-5 *3 (-332 *5)) (-5 *4 (-141)) (-4 *5 (-13 (-850) (-869) (-1075))) (-5 *2 (-1173)) (-5 *1 (-848 *5)))) (-1637 (*1 *2 *3) (-12 (-5 *3 (-332 *4)) (-4 *4 (-13 (-850) (-869) (-1075))) (-5 *2 (-1173)) (-5 *1 (-848 *4))))) 
+(-10 -7 (-15 -1637 ((-1173) (-332 |#1|))) (-15 -1637 ((-1173) (-332 |#1|) (-141))) (-15 -1637 ((-1285) (-844) (-332 |#1|))) (-15 -1637 ((-1285) (-844) (-332 |#1|) (-141)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3864 ((|#1| $) 10)) (-1608 (($ |#1|) 9)) (-3558 (((-141) $) NIL)) (-4526 (($ |#2| (-790)) NIL)) (-4206 (((-790) $) NIL)) (-4579 ((|#2| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3644 (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $) NIL (|has| |#1| (-247)))) (-4525 (((-790) $) NIL)) (-1683 (((-877) $) 17) (($ (-592)) NIL) (($ |#2|) NIL (|has| |#2| (-194)))) (-1937 ((|#2| $ (-790)) NIL)) (-4010 (((-790)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $) NIL (|has| |#1| (-247)))) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 12) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
+(((-849 |#1| |#2|) (-13 (-725 |#2|) (-10 -8 (IF (|has| |#1| (-247)) (-6 (-247)) |noBranch|) (-15 -1608 ($ |#1|)) (-15 -3864 (|#1| $)))) (-725 |#2|) (-1075)) (T -849)) 
+((-1608 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-849 *2 *3)) (-4 *2 (-725 *3)))) (-3864 (*1 *2 *1) (-12 (-4 *2 (-725 *3)) (-5 *1 (-849 *2 *3)) (-4 *3 (-1075))))) 
+(-13 (-725 |#2|) (-10 -8 (IF (|has| |#1| (-247)) (-6 (-247)) |noBranch|) (-15 -1608 ($ |#1|)) (-15 -3864 (|#1| $)))) 
+((-1637 (((-1285) (-844) $ (-141)) 9) (((-1285) (-844) $) 8) (((-1173) $ (-141)) 7) (((-1173) $) 6))) 
+(((-850) (-1311)) (T -850)) 
+((-1637 (*1 *2 *3 *1 *4) (-12 (-4 *1 (-850)) (-5 *3 (-844)) (-5 *4 (-141)) (-5 *2 (-1285)))) (-1637 (*1 *2 *3 *1) (-12 (-4 *1 (-850)) (-5 *3 (-844)) (-5 *2 (-1285)))) (-1637 (*1 *2 *1 *3) (-12 (-4 *1 (-850)) (-5 *3 (-141)) (-5 *2 (-1173)))) (-1637 (*1 *2 *1) (-12 (-4 *1 (-850)) (-5 *2 (-1173))))) 
+(-13 (-10 -8 (-15 -1637 ((-1173) $)) (-15 -1637 ((-1173) $ (-141))) (-15 -1637 ((-1285) (-844) $)) (-15 -1637 ((-1285) (-844) $ (-141))))) 
+((-4605 (((-327) (-1173) (-1173)) 12)) (-3513 (((-141) (-1173) (-1173)) 33)) (-4311 (((-141) (-1173)) 32)) (-3197 (((-57) (-1173)) 25)) (-1384 (((-57) (-1173)) 23)) (-1913 (((-57) (-844)) 17)) (-3979 (((-658 (-1173)) (-1173)) 28)) (-2899 (((-658 (-1173))) 27))) 
+(((-851) (-10 -7 (-15 -1913 ((-57) (-844))) (-15 -1384 ((-57) (-1173))) (-15 -3197 ((-57) (-1173))) (-15 -2899 ((-658 (-1173)))) (-15 -3979 ((-658 (-1173)) (-1173))) (-15 -4311 ((-141) (-1173))) (-15 -3513 ((-141) (-1173) (-1173))) (-15 -4605 ((-327) (-1173) (-1173))))) (T -851)) 
+((-4605 (*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-327)) (-5 *1 (-851)))) (-3513 (*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-141)) (-5 *1 (-851)))) (-4311 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-141)) (-5 *1 (-851)))) (-3979 (*1 *2 *3) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-851)) (-5 *3 (-1173)))) (-2899 (*1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-851)))) (-3197 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-57)) (-5 *1 (-851)))) (-1384 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-57)) (-5 *1 (-851)))) (-1913 (*1 *2 *3) (-12 (-5 *3 (-844)) (-5 *2 (-57)) (-5 *1 (-851))))) 
+(-10 -7 (-15 -1913 ((-57) (-844))) (-15 -1384 ((-57) (-1173))) (-15 -3197 ((-57) (-1173))) (-15 -2899 ((-658 (-1173)))) (-15 -3979 ((-658 (-1173)) (-1173))) (-15 -4311 ((-141) (-1173))) (-15 -3513 ((-141) (-1173) (-1173))) (-15 -4605 ((-327) (-1173) (-1173)))) 
+((-1641 (((-141) $ $) 18)) (-4528 (($ |#1| $) 72) (($ $ |#1|) 71) (($ $ $) 70)) (-4471 (($ $ $) 68)) (-2461 (((-141) $ $) 69)) (-2126 (((-141) $ (-790)) 8)) (-2224 (($ (-658 |#1|)) 64) (($) 63)) (-4125 (($ (-1 (-141) |#1|) $) 42 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) 52 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-1461 (($ $) 58)) (-1360 (($ $) 55 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ |#1| $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) 43 (|has| $ (-6 -4625)))) (-4459 (($ |#1| $) 54 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 51 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4625)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-1837 ((|#1| $) 74)) (-2713 (($ $ $) 77)) (-4491 (($ $ $) 76)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3319 ((|#1| $) 75)) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22)) (-2852 (($ $ $) 65)) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37) (($ |#1| $ (-790)) 59)) (-2951 (((-1137) $) 21)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 48)) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-2043 (((-658 (-2 (|:| -3552 |#1|) (|:| -3452 (-790)))) $) 57)) (-4328 (($ $ |#1|) 67) (($ $ $) 66)) (-1653 (($) 46) (($ (-658 |#1|)) 45)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 47)) (-1683 (((-877) $) 20)) (-4586 (($ (-658 |#1|)) 62) (($) 61)) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19)) (-3266 (((-141) $ $) 60)) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-852 |#1|) (-1311) (-869)) (T -852)) 
+((-1837 (*1 *2 *1) (-12 (-4 *1 (-852 *2)) (-4 *2 (-869))))) 
+(-13 (-753 |t#1|) (-997 |t#1|) (-10 -8 (-15 -1837 (|t#1| $)))) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) . T) ((-632 (-877)) . T) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-249 |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-711 |#1|) . T) ((-753 |#1|) . T) ((-997 |#1|) . T) ((-1116 |#1|) . T) ((-1119) . T) ((-1225) . T)) 
+((-3737 (((-1285) (-1137) (-1137)) 47)) (-1656 (((-1285) (-843) (-57)) 44)) (-4183 (((-57) (-843)) 16))) 
+(((-853) (-10 -7 (-15 -4183 ((-57) (-843))) (-15 -1656 ((-1285) (-843) (-57))) (-15 -3737 ((-1285) (-1137) (-1137))))) (T -853)) 
+((-3737 (*1 *2 *3 *3) (-12 (-5 *3 (-1137)) (-5 *2 (-1285)) (-5 *1 (-853)))) (-1656 (*1 *2 *3 *4) (-12 (-5 *3 (-843)) (-5 *4 (-57)) (-5 *2 (-1285)) (-5 *1 (-853)))) (-4183 (*1 *2 *3) (-12 (-5 *3 (-843)) (-5 *2 (-57)) (-5 *1 (-853))))) 
+(-10 -7 (-15 -4183 ((-57) (-843))) (-15 -1656 ((-1285) (-843) (-57))) (-15 -3737 ((-1285) (-1137) (-1137)))) 
+((-2731 (((-855 |#2|) (-1 |#2| |#1|) (-855 |#1|) (-855 |#2|)) 12) (((-855 |#2|) (-1 |#2| |#1|) (-855 |#1|)) 13))) 
+(((-854 |#1| |#2|) (-10 -7 (-15 -2731 ((-855 |#2|) (-1 |#2| |#1|) (-855 |#1|))) (-15 -2731 ((-855 |#2|) (-1 |#2| |#1|) (-855 |#1|) (-855 |#2|)))) (-1119) (-1119)) (T -854)) 
+((-2731 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-855 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-855 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *1 (-854 *5 *6)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-855 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-855 *6)) (-5 *1 (-854 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-855 |#2|) (-1 |#2| |#1|) (-855 |#1|))) (-15 -2731 ((-855 |#2|) (-1 |#2| |#1|) (-855 |#1|) (-855 |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL (|has| |#1| (-21)))) (-2350 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-3940 (((-592) $) NIL (|has| |#1| (-867)))) (-3001 (($) NIL (|has| |#1| (-21)) CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 15)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 9)) (-3371 (((-3 $ "failed") $) 40 (|has| |#1| (-867)))) (-4182 (((-3 (-433 (-592)) "failed") $) 48 (|has| |#1| (-574)))) (-2435 (((-141) $) 43 (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) 45 (|has| |#1| (-574)))) (-1691 (((-141) $) NIL (|has| |#1| (-867)))) (-3558 (((-141) $) NIL (|has| |#1| (-867)))) (-1324 (((-141) $) NIL (|has| |#1| (-867)))) (-1837 (($ $ $) NIL (|has| |#1| (-867)))) (-3319 (($ $ $) NIL (|has| |#1| (-867)))) (-2685 (((-1173) $) NIL)) (-4109 (($) 13)) (-2349 (((-141) $) 12)) (-2951 (((-1137) $) NIL)) (-3561 (((-141) $) 11)) (-1683 (((-877) $) 18) (($ (-433 (-592))) NIL (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) 8) (($ (-592)) NIL (-3836 (|has| |#1| (-867)) (|has| |#1| (-1065 (-592)))))) (-4010 (((-790)) 34 (|has| |#1| (-867)))) (-1392 (($ $) NIL (|has| |#1| (-867)))) (-1424 (($ $ (-944)) NIL (|has| |#1| (-867))) (($ $ (-790)) NIL (|has| |#1| (-867)))) (-3514 (($) 22 (|has| |#1| (-21)) CONST)) (-4257 (($) 31 (|has| |#1| (-867)) CONST)) (-3286 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3255 (((-141) $ $) 20)) (-3279 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3266 (((-141) $ $) 42 (|has| |#1| (-867)))) (-3306 (($ $ $) NIL (|has| |#1| (-21))) (($ $) 27 (|has| |#1| (-21)))) (-3300 (($ $ $) 29 (|has| |#1| (-21)))) (** (($ $ (-944)) NIL (|has| |#1| (-867))) (($ $ (-790)) NIL (|has| |#1| (-867)))) (* (($ $ $) 37 (|has| |#1| (-867))) (($ (-592) $) 25 (|has| |#1| (-21))) (($ (-790) $) NIL (|has| |#1| (-21))) (($ (-944) $) NIL (|has| |#1| (-21))))) 
+(((-855 |#1|) (-13 (-1119) (-437 |#1|) (-10 -8 (-15 -4109 ($)) (-15 -3561 ((-141) $)) (-15 -2349 ((-141) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-867)) (-6 (-867)) |noBranch|) (IF (|has| |#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|))) (-1119)) (T -855)) 
+((-4109 (*1 *1) (-12 (-5 *1 (-855 *2)) (-4 *2 (-1119)))) (-3561 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-855 *3)) (-4 *3 (-1119)))) (-2349 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-855 *3)) (-4 *3 (-1119)))) (-2435 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-855 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) (-2270 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-855 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) (-4182 (*1 *2 *1) (|partial| -12 (-5 *2 (-433 (-592))) (-5 *1 (-855 *3)) (-4 *3 (-574)) (-4 *3 (-1119))))) 
+(-13 (-1119) (-437 |#1|) (-10 -8 (-15 -4109 ($)) (-15 -3561 ((-141) $)) (-15 -2349 ((-141) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-867)) (-6 (-867)) |noBranch|) (IF (|has| |#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-143) "failed") $) NIL)) (-2400 ((|#1| $) NIL) (((-143) $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4297 ((|#1| (-143) |#1|) NIL)) (-3558 (((-141) $) NIL)) (-4415 (($ |#1| (-386 (-143))) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3165 (($ $ (-1 |#1| |#1|)) NIL)) (-1646 (($ $ (-1 |#1| |#1|)) NIL)) (-3927 ((|#1| $ |#1|) NIL)) (-4454 ((|#1| |#1|) NIL (|has| |#1| (-194)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-143)) NIL)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2332 (($ $) NIL (|has| |#1| (-194))) (($ $ $) NIL (|has| |#1| (-194)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ (-143) (-592)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL (|has| |#1| (-194))) (($ $ |#1|) NIL (|has| |#1| (-194))))) 
+(((-856 |#1|) (-13 (-1075) (-1065 |#1|) (-1065 (-143)) (-303 |#1| |#1|) (-10 -8 (IF (|has| |#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |#1| (-194)) (PROGN (-6 (-43 |#1|)) (-15 -2332 ($ $)) (-15 -2332 ($ $ $)) (-15 -4454 (|#1| |#1|))) |noBranch|) (-15 -1646 ($ $ (-1 |#1| |#1|))) (-15 -3165 ($ $ (-1 |#1| |#1|))) (-15 ** ($ (-143) (-592))) (-15 ** ($ $ (-592))) (-15 -4297 (|#1| (-143) |#1|)) (-15 -4415 ($ |#1| (-386 (-143)))))) (-1075)) (T -856)) 
+((-2332 (*1 *1 *1) (-12 (-5 *1 (-856 *2)) (-4 *2 (-194)) (-4 *2 (-1075)))) (-2332 (*1 *1 *1 *1) (-12 (-5 *1 (-856 *2)) (-4 *2 (-194)) (-4 *2 (-1075)))) (-4454 (*1 *2 *2) (-12 (-5 *1 (-856 *2)) (-4 *2 (-194)) (-4 *2 (-1075)))) (-1646 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-856 *3)))) (-3165 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-856 *3)))) (** (*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-592)) (-5 *1 (-856 *4)) (-4 *4 (-1075)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-856 *3)) (-4 *3 (-1075)))) (-4297 (*1 *2 *3 *2) (-12 (-5 *3 (-143)) (-5 *1 (-856 *2)) (-4 *2 (-1075)))) (-4415 (*1 *1 *2 *3) (-12 (-5 *3 (-386 (-143))) (-5 *1 (-856 *2)) (-4 *2 (-1075))))) 
+(-13 (-1075) (-1065 |#1|) (-1065 (-143)) (-303 |#1| |#1|) (-10 -8 (IF (|has| |#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |#1| (-194)) (PROGN (-6 (-43 |#1|)) (-15 -2332 ($ $)) (-15 -2332 ($ $ $)) (-15 -4454 (|#1| |#1|))) |noBranch|) (-15 -1646 ($ $ (-1 |#1| |#1|))) (-15 -3165 ($ $ (-1 |#1| |#1|))) (-15 ** ($ (-143) (-592))) (-15 ** ($ $ (-592))) (-15 -4297 (|#1| (-143) |#1|)) (-15 -4415 ($ |#1| (-386 (-143)))))) 
+((-2293 (((-227 (-535)) (-1173)) 8))) 
+(((-857) (-10 -7 (-15 -2293 ((-227 (-535)) (-1173))))) (T -857)) 
+((-2293 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-227 (-535))) (-5 *1 (-857))))) 
+(-10 -7 (-15 -2293 ((-227 (-535)) (-1173)))) 
+((-1641 (((-141) $ $) 7)) (-1432 (((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 13) (((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 12)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 15) (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 14)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-858) (-1311)) (T -858)) 
+((-2617 (*1 *2 *3 *4) (-12 (-4 *1 (-858)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)))))) (-2617 (*1 *2 *3 *4) (-12 (-4 *1 (-858)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)))))) (-1432 (*1 *2 *3) (-12 (-4 *1 (-858)) (-5 *3 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *2 (-1063)))) (-1432 (*1 *2 *3) (-12 (-4 *1 (-858)) (-5 *3 (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (-5 *2 (-1063))))) 
+(-13 (-1119) (-10 -7 (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) (-15 -1432 ((-1063) (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) (-15 -1432 ((-1063) (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-3512 (((-1063) (-658 (-332 (-405))) (-658 (-405))) 143) (((-1063) (-332 (-405)) (-658 (-405))) 141) (((-1063) (-332 (-405)) (-658 (-405)) (-658 (-862 (-405))) (-658 (-862 (-405)))) 140) (((-1063) (-332 (-405)) (-658 (-405)) (-658 (-862 (-405))) (-658 (-332 (-405))) (-658 (-862 (-405)))) 139) (((-1063) (-860)) 112) (((-1063) (-860) (-1087)) 111)) (-2617 (((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-860) (-1087)) 76) (((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-860)) 78)) (-3222 (((-1063) (-658 (-332 (-405))) (-658 (-405))) 144) (((-1063) (-860)) 128))) 
+(((-859) (-10 -7 (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-860))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-860) (-1087))) (-15 -3512 ((-1063) (-860) (-1087))) (-15 -3512 ((-1063) (-860))) (-15 -3222 ((-1063) (-860))) (-15 -3512 ((-1063) (-332 (-405)) (-658 (-405)) (-658 (-862 (-405))) (-658 (-332 (-405))) (-658 (-862 (-405))))) (-15 -3512 ((-1063) (-332 (-405)) (-658 (-405)) (-658 (-862 (-405))) (-658 (-862 (-405))))) (-15 -3512 ((-1063) (-332 (-405)) (-658 (-405)))) (-15 -3512 ((-1063) (-658 (-332 (-405))) (-658 (-405)))) (-15 -3222 ((-1063) (-658 (-332 (-405))) (-658 (-405)))))) (T -859)) 
+((-3222 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-332 (-405)))) (-5 *4 (-658 (-405))) (-5 *2 (-1063)) (-5 *1 (-859)))) (-3512 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-332 (-405)))) (-5 *4 (-658 (-405))) (-5 *2 (-1063)) (-5 *1 (-859)))) (-3512 (*1 *2 *3 *4) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-405))) (-5 *2 (-1063)) (-5 *1 (-859)))) (-3512 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-405))) (-5 *5 (-658 (-862 (-405)))) (-5 *2 (-1063)) (-5 *1 (-859)))) (-3512 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-658 (-405))) (-5 *5 (-658 (-862 (-405)))) (-5 *6 (-658 (-332 (-405)))) (-5 *3 (-332 (-405))) (-5 *2 (-1063)) (-5 *1 (-859)))) (-3222 (*1 *2 *3) (-12 (-5 *3 (-860)) (-5 *2 (-1063)) (-5 *1 (-859)))) (-3512 (*1 *2 *3) (-12 (-5 *3 (-860)) (-5 *2 (-1063)) (-5 *1 (-859)))) (-3512 (*1 *2 *3 *4) (-12 (-5 *3 (-860)) (-5 *4 (-1087)) (-5 *2 (-1063)) (-5 *1 (-859)))) (-2617 (*1 *2 *3 *4) (-12 (-5 *3 (-860)) (-5 *4 (-1087)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-859)))) (-2617 (*1 *2 *3) (-12 (-5 *3 (-860)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-859))))) 
+(-10 -7 (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-860))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-860) (-1087))) (-15 -3512 ((-1063) (-860) (-1087))) (-15 -3512 ((-1063) (-860))) (-15 -3222 ((-1063) (-860))) (-15 -3512 ((-1063) (-332 (-405)) (-658 (-405)) (-658 (-862 (-405))) (-658 (-332 (-405))) (-658 (-862 (-405))))) (-15 -3512 ((-1063) (-332 (-405)) (-658 (-405)) (-658 (-862 (-405))) (-658 (-862 (-405))))) (-15 -3512 ((-1063) (-332 (-405)) (-658 (-405)))) (-15 -3512 ((-1063) (-658 (-332 (-405))) (-658 (-405)))) (-15 -3222 ((-1063) (-658 (-332 (-405))) (-658 (-405))))) 
+((-1641 (((-141) $ $) NIL)) (-2400 (((-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) $) 15)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 14) (($ (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) 8) (($ (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) 10) (($ (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))) 12)) (-3255 (((-141) $ $) NIL))) 
+(((-860) (-13 (-1119) (-10 -8 (-15 -1683 ($ (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))))) (-15 -1683 ($ (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) (-15 -1683 ($ (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))))) (-15 -1683 ((-877) $)) (-15 -2400 ((-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) $))))) (T -860)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-860)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (-5 *1 (-860)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *1 (-860)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))) (-5 *1 (-860)))) (-2400 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))) (-5 *1 (-860))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237))))))) (-15 -1683 ($ (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) (-15 -1683 ($ (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))))) (-15 -1683 ((-877) $)) (-15 -2400 ((-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237)))))) $)))) 
+((-2731 (((-862 |#2|) (-1 |#2| |#1|) (-862 |#1|) (-862 |#2|) (-862 |#2|)) 13) (((-862 |#2|) (-1 |#2| |#1|) (-862 |#1|)) 14))) 
+(((-861 |#1| |#2|) (-10 -7 (-15 -2731 ((-862 |#2|) (-1 |#2| |#1|) (-862 |#1|))) (-15 -2731 ((-862 |#2|) (-1 |#2| |#1|) (-862 |#1|) (-862 |#2|) (-862 |#2|)))) (-1119) (-1119)) (T -861)) 
+((-2731 (*1 *2 *3 *4 *2 *2) (-12 (-5 *2 (-862 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-862 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *1 (-861 *5 *6)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-862 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-862 *6)) (-5 *1 (-861 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-862 |#2|) (-1 |#2| |#1|) (-862 |#1|))) (-15 -2731 ((-862 |#2|) (-1 |#2| |#1|) (-862 |#1|) (-862 |#2|) (-862 |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL (|has| |#1| (-21)))) (-3801 (((-1137) $) 24)) (-2350 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-3940 (((-592) $) NIL (|has| |#1| (-867)))) (-3001 (($) NIL (|has| |#1| (-21)) CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 16)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 9)) (-3371 (((-3 $ "failed") $) 47 (|has| |#1| (-867)))) (-4182 (((-3 (-433 (-592)) "failed") $) 54 (|has| |#1| (-574)))) (-2435 (((-141) $) 49 (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) 52 (|has| |#1| (-574)))) (-1691 (((-141) $) NIL (|has| |#1| (-867)))) (-4374 (($) 13)) (-3558 (((-141) $) NIL (|has| |#1| (-867)))) (-1324 (((-141) $) NIL (|has| |#1| (-867)))) (-4366 (($) 14)) (-1837 (($ $ $) NIL (|has| |#1| (-867)))) (-3319 (($ $ $) NIL (|has| |#1| (-867)))) (-2685 (((-1173) $) NIL)) (-2349 (((-141) $) 12)) (-2951 (((-1137) $) NIL)) (-3561 (((-141) $) 11)) (-1683 (((-877) $) 22) (($ (-433 (-592))) NIL (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) 8) (($ (-592)) NIL (-3836 (|has| |#1| (-867)) (|has| |#1| (-1065 (-592)))))) (-4010 (((-790)) 41 (|has| |#1| (-867)))) (-1392 (($ $) NIL (|has| |#1| (-867)))) (-1424 (($ $ (-944)) NIL (|has| |#1| (-867))) (($ $ (-790)) NIL (|has| |#1| (-867)))) (-3514 (($) 29 (|has| |#1| (-21)) CONST)) (-4257 (($) 38 (|has| |#1| (-867)) CONST)) (-3286 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3255 (((-141) $ $) 27)) (-3279 (((-141) $ $) NIL (|has| |#1| (-867)))) (-3266 (((-141) $ $) 48 (|has| |#1| (-867)))) (-3306 (($ $ $) NIL (|has| |#1| (-21))) (($ $) 34 (|has| |#1| (-21)))) (-3300 (($ $ $) 36 (|has| |#1| (-21)))) (** (($ $ (-944)) NIL (|has| |#1| (-867))) (($ $ (-790)) NIL (|has| |#1| (-867)))) (* (($ $ $) 44 (|has| |#1| (-867))) (($ (-592) $) 32 (|has| |#1| (-21))) (($ (-790) $) NIL (|has| |#1| (-21))) (($ (-944) $) NIL (|has| |#1| (-21))))) 
+(((-862 |#1|) (-13 (-1119) (-437 |#1|) (-10 -8 (-15 -4374 ($)) (-15 -4366 ($)) (-15 -3561 ((-141) $)) (-15 -2349 ((-141) $)) (-15 -3801 ((-1137) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-867)) (-6 (-867)) |noBranch|) (IF (|has| |#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|))) (-1119)) (T -862)) 
+((-4374 (*1 *1) (-12 (-5 *1 (-862 *2)) (-4 *2 (-1119)))) (-4366 (*1 *1) (-12 (-5 *1 (-862 *2)) (-4 *2 (-1119)))) (-3561 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-862 *3)) (-4 *3 (-1119)))) (-2349 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-862 *3)) (-4 *3 (-1119)))) (-3801 (*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-862 *3)) (-4 *3 (-1119)))) (-2435 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-862 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) (-2270 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-862 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) (-4182 (*1 *2 *1) (|partial| -12 (-5 *2 (-433 (-592))) (-5 *1 (-862 *3)) (-4 *3 (-574)) (-4 *3 (-1119))))) 
+(-13 (-1119) (-437 |#1|) (-10 -8 (-15 -4374 ($)) (-15 -4366 ($)) (-15 -3561 ((-141) $)) (-15 -2349 ((-141) $)) (-15 -3801 ((-1137) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-867)) (-6 (-867)) |noBranch|) (IF (|has| |#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|))) 
+((-1641 (((-141) $ $) 7)) (-1403 (((-790)) 19)) (-4290 (($) 22)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-3546 (((-944) $) 21)) (-2685 (((-1173) $) 9)) (-1825 (($ (-944)) 20)) (-2951 (((-1137) $) 10)) (-1405 (((-658 $)) 23)) (-1683 (((-877) $) 11)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17))) 
+(((-863) (-1311)) (T -863)) 
+NIL 
+(-13 (-869) (-394)) 
+(((-125) . T) ((-632 (-877)) . T) ((-394) . T) ((-869) . T) ((-1119) . T)) 
+((-2437 (((-141) (-1280 |#2|) (-1280 |#2|)) 17)) (-3549 (((-141) (-1280 |#2|) (-1280 |#2|)) 18)) (-3541 (((-141) (-1280 |#2|) (-1280 |#2|)) 14))) 
+(((-864 |#1| |#2|) (-10 -7 (-15 -3541 ((-141) (-1280 |#2|) (-1280 |#2|))) (-15 -2437 ((-141) (-1280 |#2|) (-1280 |#2|))) (-15 -3549 ((-141) (-1280 |#2|) (-1280 |#2|)))) (-790) (-814)) (T -864)) 
+((-3549 (*1 *2 *3 *3) (-12 (-5 *3 (-1280 *5)) (-4 *5 (-814)) (-5 *2 (-141)) (-5 *1 (-864 *4 *5)) (-14 *4 (-790)))) (-2437 (*1 *2 *3 *3) (-12 (-5 *3 (-1280 *5)) (-4 *5 (-814)) (-5 *2 (-141)) (-5 *1 (-864 *4 *5)) (-14 *4 (-790)))) (-3541 (*1 *2 *3 *3) (-12 (-5 *3 (-1280 *5)) (-4 *5 (-814)) (-5 *2 (-141)) (-5 *1 (-864 *4 *5)) (-14 *4 (-790))))) 
+(-10 -7 (-15 -3541 ((-141) (-1280 |#2|) (-1280 |#2|))) (-15 -2437 ((-141) (-1280 |#2|) (-1280 |#2|))) (-15 -3549 ((-141) (-1280 |#2|) (-1280 |#2|)))) 
+((-1641 (((-141) $ $) 7)) (-3001 (($) 23 T CONST)) (-3371 (((-3 $ "failed") $) 27)) (-3558 (((-141) $) 24)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-1424 (($ $ (-790)) 26) (($ $ (-944)) 21)) (-4257 (($) 22 T CONST)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (** (($ $ (-790)) 25) (($ $ (-944)) 20)) (* (($ $ $) 19))) 
+(((-865) (-1311)) (T -865)) 
+NIL 
+(-13 (-869) (-743)) 
+(((-125) . T) ((-632 (-877)) . T) ((-743) . T) ((-869) . T) ((-1131) . T) ((-1119) . T)) 
+((-3940 (((-592) $) 17)) (-1691 (((-141) $) 10)) (-1324 (((-141) $) 11)) (-1392 (($ $) 19))) 
+(((-866 |#1|) (-10 -8 (-15 -1392 (|#1| |#1|)) (-15 -3940 ((-592) |#1|)) (-15 -1324 ((-141) |#1|)) (-15 -1691 ((-141) |#1|))) (-867)) (T -866)) 
+NIL 
+(-10 -8 (-15 -1392 (|#1| |#1|)) (-15 -3940 ((-592) |#1|)) (-15 -1324 ((-141) |#1|)) (-15 -1691 ((-141) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 23)) (-2350 (((-3 $ "failed") $ $) 25)) (-3940 (((-592) $) 32)) (-3001 (($) 22 T CONST)) (-3371 (((-3 $ "failed") $) 38)) (-1691 (((-141) $) 34)) (-3558 (((-141) $) 41)) (-1324 (((-141) $) 33)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 44)) (-4010 (((-790)) 43)) (-1392 (($ $) 31)) (-1424 (($ $ (-790)) 39) (($ $ (-944)) 35)) (-3514 (($) 21 T CONST)) (-4257 (($) 42 T CONST)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17)) (-3306 (($ $ $) 27) (($ $) 26)) (-3300 (($ $ $) 19)) (** (($ $ (-790)) 40) (($ $ (-944)) 36)) (* (($ (-790) $) 24) (($ (-944) $) 20) (($ (-592) $) 28) (($ $ $) 37))) 
+(((-867) (-1311)) (T -867)) 
+((-1691 (*1 *2 *1) (-12 (-4 *1 (-867)) (-5 *2 (-141)))) (-1324 (*1 *2 *1) (-12 (-4 *1 (-867)) (-5 *2 (-141)))) (-3940 (*1 *2 *1) (-12 (-4 *1 (-867)) (-5 *2 (-592)))) (-1392 (*1 *1 *1) (-4 *1 (-867)))) 
+(-13 (-813) (-1075) (-743) (-10 -8 (-15 -1691 ((-141) $)) (-15 -1324 ((-141) $)) (-15 -3940 ((-592) $)) (-15 -1392 ($ $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-813) . T) ((-814) . T) ((-816) . T) ((-817) . T) ((-869) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1837 (($ $ $) 10)) (-3319 (($ $ $) 9)) (-3286 (((-141) $ $) 12)) (-3273 (((-141) $ $) 11)) (-3279 (((-141) $ $) 13))) 
+(((-868 |#1|) (-10 -8 (-15 -1837 (|#1| |#1| |#1|)) (-15 -3319 (|#1| |#1| |#1|)) (-15 -3279 ((-141) |#1| |#1|)) (-15 -3286 ((-141) |#1| |#1|)) (-15 -3273 ((-141) |#1| |#1|))) (-869)) (T -868)) 
+NIL 
+(-10 -8 (-15 -1837 (|#1| |#1| |#1|)) (-15 -3319 (|#1| |#1| |#1|)) (-15 -3279 ((-141) |#1| |#1|)) (-15 -3286 ((-141) |#1| |#1|)) (-15 -3273 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-1837 (($ $ $) 12)) (-3319 (($ $ $) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3286 (((-141) $ $) 15)) (-3273 (((-141) $ $) 16)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 14)) (-3266 (((-141) $ $) 17))) 
+(((-869) (-1311)) (T -869)) 
+((-3266 (*1 *2 *1 *1) (-12 (-4 *1 (-869)) (-5 *2 (-141)))) (-3273 (*1 *2 *1 *1) (-12 (-4 *1 (-869)) (-5 *2 (-141)))) (-3286 (*1 *2 *1 *1) (-12 (-4 *1 (-869)) (-5 *2 (-141)))) (-3279 (*1 *2 *1 *1) (-12 (-4 *1 (-869)) (-5 *2 (-141)))) (-3319 (*1 *1 *1 *1) (-4 *1 (-869))) (-1837 (*1 *1 *1 *1) (-4 *1 (-869)))) 
+(-13 (-1119) (-10 -8 (-15 -3266 ((-141) $ $)) (-15 -3273 ((-141) $ $)) (-15 -3286 ((-141) $ $)) (-15 -3279 ((-141) $ $)) (-15 -3319 ($ $ $)) (-15 -1837 ($ $ $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-2484 (($ $ $) 45)) (-3883 (($ $ $) 44)) (-1956 (($ $ $) 42)) (-1819 (($ $ $) 51)) (-2423 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 46)) (-1477 (((-3 $ "failed") $ $) 49)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 |#2| "failed") $) 25)) (-3262 (($ $) 35)) (-1763 (($ $ $) 39)) (-4308 (($ $ $) 38)) (-3696 (($ $ $) 47)) (-4262 (($ $ $) 53)) (-1603 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 41)) (-4156 (((-3 $ "failed") $ $) 48)) (-3616 (((-3 $ "failed") $ |#2|) 28)) (-1554 ((|#2| $) 32)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 (-592))) NIL) (($ |#2|) 12)) (-1647 (((-658 |#2|) $) 18)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 22))) 
+(((-870 |#1| |#2|) (-10 -8 (-15 -3696 (|#1| |#1| |#1|)) (-15 -2423 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2934 |#1|)) |#1| |#1|)) (-15 -1819 (|#1| |#1| |#1|)) (-15 -1477 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2484 (|#1| |#1| |#1|)) (-15 -3883 (|#1| |#1| |#1|)) (-15 -1956 (|#1| |#1| |#1|)) (-15 -1603 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2934 |#1|)) |#1| |#1|)) (-15 -4262 (|#1| |#1| |#1|)) (-15 -4156 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1763 (|#1| |#1| |#1|)) (-15 -4308 (|#1| |#1| |#1|)) (-15 -3262 (|#1| |#1|)) (-15 -1554 (|#2| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#2|)) (-15 -1647 ((-658 |#2|) |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|)) (-15 -1683 ((-877) |#1|))) (-871 |#2|) (-1075)) (T -870)) 
+NIL 
+(-10 -8 (-15 -3696 (|#1| |#1| |#1|)) (-15 -2423 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2934 |#1|)) |#1| |#1|)) (-15 -1819 (|#1| |#1| |#1|)) (-15 -1477 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2484 (|#1| |#1| |#1|)) (-15 -3883 (|#1| |#1| |#1|)) (-15 -1956 (|#1| |#1| |#1|)) (-15 -1603 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2934 |#1|)) |#1| |#1|)) (-15 -4262 (|#1| |#1| |#1|)) (-15 -4156 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1763 (|#1| |#1| |#1|)) (-15 -4308 (|#1| |#1| |#1|)) (-15 -3262 (|#1| |#1|)) (-15 -1554 (|#2| |#1|)) (-15 -3616 ((-3 |#1| "failed") |#1| |#2|)) (-15 -1647 ((-658 |#2|) |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|)) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2484 (($ $ $) 44 (|has| |#1| (-388)))) (-3883 (($ $ $) 45 (|has| |#1| (-388)))) (-1956 (($ $ $) 47 (|has| |#1| (-388)))) (-1819 (($ $ $) 42 (|has| |#1| (-388)))) (-2423 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 41 (|has| |#1| (-388)))) (-1477 (((-3 $ "failed") $ $) 43 (|has| |#1| (-388)))) (-3172 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 46 (|has| |#1| (-388)))) (-4368 (((-3 (-592) "failed") $) 73 (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 71 (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 68)) (-2400 (((-592) $) 74 (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) 72 (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 67)) (-4593 (($ $) 63)) (-3371 (((-3 $ "failed") $) 33)) (-3262 (($ $) 54 (|has| |#1| (-477)))) (-3558 (((-141) $) 30)) (-4526 (($ |#1| (-790)) 61)) (-1844 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 56 (|has| |#1| (-582)))) (-2641 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 57 (|has| |#1| (-582)))) (-4206 (((-790) $) 65)) (-1763 (($ $ $) 51 (|has| |#1| (-388)))) (-4308 (($ $ $) 52 (|has| |#1| (-388)))) (-3696 (($ $ $) 40 (|has| |#1| (-388)))) (-4262 (($ $ $) 49 (|has| |#1| (-388)))) (-1603 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 48 (|has| |#1| (-388)))) (-4156 (((-3 $ "failed") $ $) 50 (|has| |#1| (-388)))) (-4084 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 53 (|has| |#1| (-388)))) (-4579 ((|#1| $) 64)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ |#1|) 58 (|has| |#1| (-582)))) (-4525 (((-790) $) 66)) (-1554 ((|#1| $) 55 (|has| |#1| (-477)))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 70 (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) 69)) (-1647 (((-658 |#1|) $) 60)) (-1937 ((|#1| $ (-790)) 62)) (-4010 (((-790)) 28)) (-4572 ((|#1| $ |#1| |#1|) 59)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 76) (($ |#1| $) 75))) 
+(((-871 |#1|) (-1311) (-1075)) (T -871)) 
+((-4525 (*1 *2 *1) (-12 (-4 *1 (-871 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) (-4206 (*1 *2 *1) (-12 (-4 *1 (-871 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) (-4579 (*1 *2 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)))) (-4593 (*1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)))) (-1937 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-871 *2)) (-4 *2 (-1075)))) (-4526 (*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-871 *2)) (-4 *2 (-1075)))) (-1647 (*1 *2 *1) (-12 (-4 *1 (-871 *3)) (-4 *3 (-1075)) (-5 *2 (-658 *3)))) (-4572 (*1 *2 *1 *2 *2) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)))) (-3616 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-582)))) (-2641 (*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-871 *3)))) (-1844 (*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-871 *3)))) (-1554 (*1 *2 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-477)))) (-3262 (*1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-477)))) (-4084 (*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-871 *3)))) (-4308 (*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-1763 (*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-4156 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-4262 (*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-1603 (*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2934 *1))) (-4 *1 (-871 *3)))) (-1956 (*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-3172 (*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-871 *3)))) (-3883 (*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-2484 (*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-1477 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-1819 (*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-2423 (*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2934 *1))) (-4 *1 (-871 *3)))) (-3696 (*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(-13 (-1075) (-140 |t#1| |t#1|) (-437 |t#1|) (-10 -8 (-15 -4525 ((-790) $)) (-15 -4206 ((-790) $)) (-15 -4579 (|t#1| $)) (-15 -4593 ($ $)) (-15 -1937 (|t#1| $ (-790))) (-15 -4526 ($ |t#1| (-790))) (-15 -1647 ((-658 |t#1|) $)) (-15 -4572 (|t#1| $ |t#1| |t#1|)) (IF (|has| |t#1| (-194)) (-6 (-43 |t#1|)) |noBranch|) (IF (|has| |t#1| (-582)) (PROGN (-15 -3616 ((-3 $ "failed") $ |t#1|)) (-15 -2641 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -1844 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $))) |noBranch|) (IF (|has| |t#1| (-477)) (PROGN (-15 -1554 (|t#1| $)) (-15 -3262 ($ $))) |noBranch|) (IF (|has| |t#1| (-388)) (PROGN (-15 -4084 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -4308 ($ $ $)) (-15 -1763 ($ $ $)) (-15 -4156 ((-3 $ "failed") $ $)) (-15 -4262 ($ $ $)) (-15 -1603 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $)) (-15 -1956 ($ $ $)) (-15 -3172 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -3883 ($ $ $)) (-15 -2484 ($ $ $)) (-15 -1477 ((-3 $ "failed") $ $)) (-15 -1819 ($ $ $)) (-15 -2423 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $)) (-15 -3696 ($ $ $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-194)) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-437 |#1|) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-734 |#1|) |has| |#1| (-194)) ((-743) . T) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1081 |#1|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-4090 ((|#2| |#2| |#2| (-121 |#1|) (-1 |#1| |#1|)) 20)) (-3172 (((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|)) 43 (|has| |#1| (-388)))) (-1844 (((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|)) 40 (|has| |#1| (-582)))) (-2641 (((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|)) 39 (|has| |#1| (-582)))) (-4084 (((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|)) 42 (|has| |#1| (-388)))) (-4572 ((|#1| |#2| |#1| |#1| (-121 |#1|) (-1 |#1| |#1|)) 31))) 
+(((-872 |#1| |#2|) (-10 -7 (-15 -4090 (|#2| |#2| |#2| (-121 |#1|) (-1 |#1| |#1|))) (-15 -4572 (|#1| |#2| |#1| |#1| (-121 |#1|) (-1 |#1| |#1|))) (IF (|has| |#1| (-582)) (PROGN (-15 -2641 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|))) (-15 -1844 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|)))) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-15 -4084 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|))) (-15 -3172 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|)))) |noBranch|)) (-1075) (-871 |#1|)) (T -872)) 
+((-3172 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121 *5)) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-872 *5 *3)) (-4 *3 (-871 *5)))) (-4084 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121 *5)) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-872 *5 *3)) (-4 *3 (-871 *5)))) (-1844 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121 *5)) (-4 *5 (-582)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-872 *5 *3)) (-4 *3 (-871 *5)))) (-2641 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121 *5)) (-4 *5 (-582)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-872 *5 *3)) (-4 *3 (-871 *5)))) (-4572 (*1 *2 *3 *2 *2 *4 *5) (-12 (-5 *4 (-121 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-1075)) (-5 *1 (-872 *2 *3)) (-4 *3 (-871 *2)))) (-4090 (*1 *2 *2 *2 *3 *4) (-12 (-5 *3 (-121 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-1075)) (-5 *1 (-872 *5 *2)) (-4 *2 (-871 *5))))) 
+(-10 -7 (-15 -4090 (|#2| |#2| |#2| (-121 |#1|) (-1 |#1| |#1|))) (-15 -4572 (|#1| |#2| |#1| |#1| (-121 |#1|) (-1 |#1| |#1|))) (IF (|has| |#1| (-582)) (PROGN (-15 -2641 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|))) (-15 -1844 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|)))) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-15 -4084 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|))) (-15 -3172 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2| (-121 |#1|)))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-2484 (($ $ $) NIL (|has| |#1| (-388)))) (-3883 (($ $ $) NIL (|has| |#1| (-388)))) (-1956 (($ $ $) NIL (|has| |#1| (-388)))) (-1819 (($ $ $) NIL (|has| |#1| (-388)))) (-2423 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-1477 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-3172 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 25 (|has| |#1| (-388)))) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477)))) (-4149 (((-877) $ (-877)) NIL)) (-3558 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) NIL)) (-1844 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 21 (|has| |#1| (-582)))) (-2641 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 19 (|has| |#1| (-582)))) (-4206 (((-790) $) NIL)) (-1763 (($ $ $) NIL (|has| |#1| (-388)))) (-4308 (($ $ $) NIL (|has| |#1| (-388)))) (-3696 (($ $ $) NIL (|has| |#1| (-388)))) (-4262 (($ $ $) NIL (|has| |#1| (-388)))) (-1603 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-4156 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-4084 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 23 (|has| |#1| (-388)))) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582)))) (-4525 (((-790) $) NIL)) (-1554 ((|#1| $) NIL (|has| |#1| (-477)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#1| (-1065 (-433 (-592))))) (($ |#1|) NIL)) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) NIL)) (-4010 (((-790)) NIL)) (-4572 ((|#1| $ |#1| |#1|) 15)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 13) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-873 |#1| |#2| |#3|) (-13 (-871 |#1|) (-10 -8 (-15 -4149 ((-877) $ (-877))))) (-1075) (-121 |#1|) (-1 |#1| |#1|)) (T -873)) 
+((-4149 (*1 *2 *1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-121 *3)) (-14 *5 (-1 *3 *3))))) 
+(-13 (-871 |#1|) (-10 -8 (-15 -4149 ((-877) $ (-877))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-2484 (($ $ $) NIL (|has| |#2| (-388)))) (-3883 (($ $ $) NIL (|has| |#2| (-388)))) (-1956 (($ $ $) NIL (|has| |#2| (-388)))) (-1819 (($ $ $) NIL (|has| |#2| (-388)))) (-2423 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#2| (-388)))) (-1477 (((-3 $ "failed") $ $) NIL (|has| |#2| (-388)))) (-3172 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-388)))) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 |#2| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) ((|#2| $) NIL)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#2| (-477)))) (-3558 (((-141) $) NIL)) (-4526 (($ |#2| (-790)) 16)) (-1844 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-582)))) (-2641 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-582)))) (-4206 (((-790) $) NIL)) (-1763 (($ $ $) NIL (|has| |#2| (-388)))) (-4308 (($ $ $) NIL (|has| |#2| (-388)))) (-3696 (($ $ $) NIL (|has| |#2| (-388)))) (-4262 (($ $ $) NIL (|has| |#2| (-388)))) (-1603 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#2| (-388)))) (-4156 (((-3 $ "failed") $ $) NIL (|has| |#2| (-388)))) (-4084 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-388)))) (-4579 ((|#2| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582)))) (-4525 (((-790) $) NIL)) (-1554 ((|#2| $) NIL (|has| |#2| (-477)))) (-1683 (((-877) $) 23) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#2| (-1065 (-433 (-592))))) (($ |#2|) NIL) (($ (-1276 |#1|)) 18)) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-790)) NIL)) (-4010 (((-790)) NIL)) (-4572 ((|#2| $ |#2| |#2|) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) 13 T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
+(((-874 |#1| |#2| |#3| |#4|) (-13 (-871 |#2|) (-10 -8 (-15 -1683 ($ (-1276 |#1|))))) (-1191) (-1075) (-121 |#2|) (-1 |#2| |#2|)) (T -874)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *3)) (-14 *3 (-1191)) (-5 *1 (-874 *3 *4 *5 *6)) (-4 *4 (-1075)) (-14 *5 (-121 *4)) (-14 *6 (-1 *4 *4))))) 
+(-13 (-871 |#2|) (-10 -8 (-15 -1683 ($ (-1276 |#1|))))) 
+((-3409 ((|#1| (-790) |#1|) 35 (|has| |#1| (-43 (-433 (-592)))))) (-3403 ((|#1| (-790) (-790) |#1|) 27) ((|#1| (-790) |#1|) 20)) (-3714 ((|#1| (-790) |#1|) 31)) (-1787 ((|#1| (-790) |#1|) 29)) (-1843 ((|#1| (-790) |#1|) 28))) 
+(((-875 |#1|) (-10 -7 (-15 -1843 (|#1| (-790) |#1|)) (-15 -1787 (|#1| (-790) |#1|)) (-15 -3714 (|#1| (-790) |#1|)) (-15 -3403 (|#1| (-790) |#1|)) (-15 -3403 (|#1| (-790) (-790) |#1|)) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3409 (|#1| (-790) |#1|)) |noBranch|)) (-194)) (T -875)) 
+((-3409 (*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-194)))) (-3403 (*1 *2 *3 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194)))) (-3403 (*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194)))) (-3714 (*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194)))) (-1787 (*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194)))) (-1843 (*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194))))) 
+(-10 -7 (-15 -1843 (|#1| (-790) |#1|)) (-15 -1787 (|#1| (-790) |#1|)) (-15 -3714 (|#1| (-790) |#1|)) (-15 -3403 (|#1| (-790) |#1|)) (-15 -3403 (|#1| (-790) (-790) |#1|)) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3409 (|#1| (-790) |#1|)) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-2324 (((-592) $) 12)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 18) (($ (-592)) 11)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 8)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 9))) 
+(((-876) (-13 (-869) (-10 -8 (-15 -1683 ($ (-592))) (-15 -2324 ((-592) $))))) (T -876)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-876)))) (-2324 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-876))))) 
+(-13 (-869) (-10 -8 (-15 -1683 ($ (-592))) (-15 -2324 ((-592) $)))) 
+((-1641 (((-141) $ $) NIL)) (-1985 (($ $ $) 115)) (-3515 (((-592) $) 30) (((-592)) 35)) (-3553 (($ (-592)) 44)) (-1460 (($ $ $) 45) (($ (-658 $)) 76)) (-4418 (($ $ (-658 $)) 74)) (-4407 (((-592) $) 33)) (-4477 (($ $ $) 63)) (-2090 (($ $) 128) (($ $ $) 129) (($ $ $ $) 130)) (-3025 (((-592) $) 32)) (-3220 (($ $ $) 62)) (-4574 (($ $) 105)) (-4291 (($ $ $) 119)) (-2928 (($ (-658 $)) 52)) (-4239 (($ $ (-658 $)) 69)) (-4114 (($ (-592) (-592)) 46)) (-2749 (($ $) 116) (($ $ $) 117)) (-1954 (($ $ (-592)) 40) (($ $) 43)) (-1586 (($ $ $) 89)) (-1547 (($ $ $) 122)) (-3645 (($ $) 106)) (-1599 (($ $ $) 90)) (-1975 (($ $) 131) (($ $ $) 132) (($ $ $ $) 133)) (-3029 (((-1285) $) 8)) (-1644 (($ $) 109) (($ $ (-790)) 112)) (-4070 (($ $ $) 65)) (-3589 (($ $ $) 64)) (-3989 (($ $ (-658 $)) 100)) (-4400 (($ $ $) 104)) (-2533 (($ (-658 $)) 50)) (-2243 (($ $) 60) (($ (-658 $)) 61)) (-1727 (($ $ $) 113)) (-3124 (($ $) 107)) (-3986 (($ $ $) 118)) (-4149 (($ (-592)) 20) (($ (-1191)) 22) (($ (-1173)) 29) (($ (-237)) 24)) (-3573 (($ $ $) 93)) (-3252 (($ $) 94)) (-2148 (((-1285) (-1173)) 14)) (-2074 (($ (-1173)) 13)) (-4186 (($ (-658 (-658 $))) 48)) (-1961 (($ $ (-592)) 39) (($ $) 42)) (-2685 (((-1173) $) NIL)) (-3190 (($ $ $) 121)) (-1749 (($ $) 134) (($ $ $) 135) (($ $ $ $) 136)) (-4278 (((-141) $) 98)) (-3686 (($ $ (-658 $)) 102) (($ $ $ $) 103)) (-4450 (($ (-592)) 36)) (-2535 (((-592) $) 31) (((-592)) 34)) (-3106 (($ $ $) 37) (($ (-658 $)) 75)) (-2951 (((-1137) $) NIL)) (-3616 (($ $ $) 91)) (-2890 (($) 12)) (-3927 (($ $ (-658 $)) 99)) (-1729 (($ $) 108) (($ $ (-790)) 111)) (-3623 (($ $ $) 88)) (-3644 (($ $ (-790)) 127)) (-3844 (($ (-658 $)) 51)) (-1683 (((-877) $) 18)) (-2838 (($ $ (-592)) 38) (($ $) 41)) (-3754 (($ $) 58) (($ (-658 $)) 59)) (-4586 (($ $) 56) (($ (-658 $)) 57)) (-3280 (($ $) 114)) (-3490 (($ (-658 $)) 55)) (-4042 (($ $ $) 97)) (-2733 (($ $ $) 120)) (-1732 (($ $ $) 92)) (-1858 (($ $ $) 77)) (-3766 (($ $ $) 95) (($ $) 96)) (-3286 (($ $ $) 81)) (-3273 (($ $ $) 79)) (-3255 (((-141) $ $) 15) (($ $ $) 16)) (-3279 (($ $ $) 80)) (-3266 (($ $ $) 78)) (-3313 (($ $ $) 86)) (-3306 (($ $ $) 83) (($ $) 84)) (-3300 (($ $ $) 82)) (** (($ $ $) 87)) (* (($ $ $) 85))) 
+(((-877) (-13 (-1119) (-10 -8 (-15 -3029 ((-1285) $)) (-15 -2074 ($ (-1173))) (-15 -2148 ((-1285) (-1173))) (-15 -4149 ($ (-592))) (-15 -4149 ($ (-1191))) (-15 -4149 ($ (-1173))) (-15 -4149 ($ (-237))) (-15 -2890 ($)) (-15 -3515 ((-592) $)) (-15 -2535 ((-592) $)) (-15 -3515 ((-592))) (-15 -2535 ((-592))) (-15 -3025 ((-592) $)) (-15 -4407 ((-592) $)) (-15 -4450 ($ (-592))) (-15 -3553 ($ (-592))) (-15 -4114 ($ (-592) (-592))) (-15 -1961 ($ $ (-592))) (-15 -1954 ($ $ (-592))) (-15 -2838 ($ $ (-592))) (-15 -1961 ($ $)) (-15 -1954 ($ $)) (-15 -2838 ($ $)) (-15 -3106 ($ $ $)) (-15 -1460 ($ $ $)) (-15 -3106 ($ (-658 $))) (-15 -1460 ($ (-658 $))) (-15 -3989 ($ $ (-658 $))) (-15 -3686 ($ $ (-658 $))) (-15 -3686 ($ $ $ $)) (-15 -4400 ($ $ $)) (-15 -4278 ((-141) $)) (-15 -3927 ($ $ (-658 $))) (-15 -4574 ($ $)) (-15 -3190 ($ $ $)) (-15 -3280 ($ $)) (-15 -4186 ($ (-658 (-658 $)))) (-15 -1985 ($ $ $)) (-15 -2749 ($ $)) (-15 -2749 ($ $ $)) (-15 -3986 ($ $ $)) (-15 -4291 ($ $ $)) (-15 -2733 ($ $ $)) (-15 -1547 ($ $ $)) (-15 -3644 ($ $ (-790))) (-15 -4042 ($ $ $)) (-15 -3220 ($ $ $)) (-15 -4477 ($ $ $)) (-15 -3589 ($ $ $)) (-15 -4070 ($ $ $)) (-15 -4239 ($ $ (-658 $))) (-15 -4418 ($ $ (-658 $))) (-15 -3645 ($ $)) (-15 -1729 ($ $)) (-15 -1729 ($ $ (-790))) (-15 -1644 ($ $)) (-15 -1644 ($ $ (-790))) (-15 -3124 ($ $)) (-15 -1727 ($ $ $)) (-15 -2090 ($ $)) (-15 -2090 ($ $ $)) (-15 -2090 ($ $ $ $)) (-15 -1975 ($ $)) (-15 -1975 ($ $ $)) (-15 -1975 ($ $ $ $)) (-15 -1749 ($ $)) (-15 -1749 ($ $ $)) (-15 -1749 ($ $ $ $)) (-15 -4586 ($ $)) (-15 -4586 ($ (-658 $))) (-15 -3754 ($ $)) (-15 -3754 ($ (-658 $))) (-15 -2243 ($ $)) (-15 -2243 ($ (-658 $))) (-15 -2533 ($ (-658 $))) (-15 -3844 ($ (-658 $))) (-15 -2928 ($ (-658 $))) (-15 -3490 ($ (-658 $))) (-15 -3255 ($ $ $)) (-15 -1858 ($ $ $)) (-15 -3266 ($ $ $)) (-15 -3273 ($ $ $)) (-15 -3279 ($ $ $)) (-15 -3286 ($ $ $)) (-15 -3300 ($ $ $)) (-15 -3306 ($ $ $)) (-15 -3306 ($ $)) (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3623 ($ $ $)) (-15 -1586 ($ $ $)) (-15 -1599 ($ $ $)) (-15 -3616 ($ $ $)) (-15 -1732 ($ $ $)) (-15 -3573 ($ $ $)) (-15 -3252 ($ $)) (-15 -3766 ($ $ $)) (-15 -3766 ($ $))))) (T -877)) 
+((-3029 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-877)))) (-2074 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-877)))) (-2148 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-877)))) (-4149 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-4149 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-877)))) (-4149 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-877)))) (-4149 (*1 *1 *2) (-12 (-5 *2 (-237)) (-5 *1 (-877)))) (-2890 (*1 *1) (-5 *1 (-877))) (-3515 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-2535 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-3515 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-2535 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-3025 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-4407 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-4450 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-3553 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-4114 (*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-1961 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-1954 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-2838 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) (-1961 (*1 *1 *1) (-5 *1 (-877))) (-1954 (*1 *1 *1) (-5 *1 (-877))) (-2838 (*1 *1 *1) (-5 *1 (-877))) (-3106 (*1 *1 *1 *1) (-5 *1 (-877))) (-1460 (*1 *1 *1 *1) (-5 *1 (-877))) (-3106 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-1460 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-3989 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-3686 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-3686 (*1 *1 *1 *1 *1) (-5 *1 (-877))) (-4400 (*1 *1 *1 *1) (-5 *1 (-877))) (-4278 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-877)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-4574 (*1 *1 *1) (-5 *1 (-877))) (-3190 (*1 *1 *1 *1) (-5 *1 (-877))) (-3280 (*1 *1 *1) (-5 *1 (-877))) (-4186 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-877)))) (-5 *1 (-877)))) (-1985 (*1 *1 *1 *1) (-5 *1 (-877))) (-2749 (*1 *1 *1) (-5 *1 (-877))) (-2749 (*1 *1 *1 *1) (-5 *1 (-877))) (-3986 (*1 *1 *1 *1) (-5 *1 (-877))) (-4291 (*1 *1 *1 *1) (-5 *1 (-877))) (-2733 (*1 *1 *1 *1) (-5 *1 (-877))) (-1547 (*1 *1 *1 *1) (-5 *1 (-877))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-877)))) (-4042 (*1 *1 *1 *1) (-5 *1 (-877))) (-3220 (*1 *1 *1 *1) (-5 *1 (-877))) (-4477 (*1 *1 *1 *1) (-5 *1 (-877))) (-3589 (*1 *1 *1 *1) (-5 *1 (-877))) (-4070 (*1 *1 *1 *1) (-5 *1 (-877))) (-4239 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-4418 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-3645 (*1 *1 *1) (-5 *1 (-877))) (-1729 (*1 *1 *1) (-5 *1 (-877))) (-1729 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-877)))) (-1644 (*1 *1 *1) (-5 *1 (-877))) (-1644 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-877)))) (-3124 (*1 *1 *1) (-5 *1 (-877))) (-1727 (*1 *1 *1 *1) (-5 *1 (-877))) (-2090 (*1 *1 *1) (-5 *1 (-877))) (-2090 (*1 *1 *1 *1) (-5 *1 (-877))) (-2090 (*1 *1 *1 *1 *1) (-5 *1 (-877))) (-1975 (*1 *1 *1) (-5 *1 (-877))) (-1975 (*1 *1 *1 *1) (-5 *1 (-877))) (-1975 (*1 *1 *1 *1 *1) (-5 *1 (-877))) (-1749 (*1 *1 *1) (-5 *1 (-877))) (-1749 (*1 *1 *1 *1) (-5 *1 (-877))) (-1749 (*1 *1 *1 *1 *1) (-5 *1 (-877))) (-4586 (*1 *1 *1) (-5 *1 (-877))) (-4586 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-3754 (*1 *1 *1) (-5 *1 (-877))) (-3754 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-2243 (*1 *1 *1) (-5 *1 (-877))) (-2243 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-2533 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-3844 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-2928 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-3490 (*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) (-3255 (*1 *1 *1 *1) (-5 *1 (-877))) (-1858 (*1 *1 *1 *1) (-5 *1 (-877))) (-3266 (*1 *1 *1 *1) (-5 *1 (-877))) (-3273 (*1 *1 *1 *1) (-5 *1 (-877))) (-3279 (*1 *1 *1 *1) (-5 *1 (-877))) (-3286 (*1 *1 *1 *1) (-5 *1 (-877))) (-3300 (*1 *1 *1 *1) (-5 *1 (-877))) (-3306 (*1 *1 *1 *1) (-5 *1 (-877))) (-3306 (*1 *1 *1) (-5 *1 (-877))) (* (*1 *1 *1 *1) (-5 *1 (-877))) (-3313 (*1 *1 *1 *1) (-5 *1 (-877))) (** (*1 *1 *1 *1) (-5 *1 (-877))) (-3623 (*1 *1 *1 *1) (-5 *1 (-877))) (-1586 (*1 *1 *1 *1) (-5 *1 (-877))) (-1599 (*1 *1 *1 *1) (-5 *1 (-877))) (-3616 (*1 *1 *1 *1) (-5 *1 (-877))) (-1732 (*1 *1 *1 *1) (-5 *1 (-877))) (-3573 (*1 *1 *1 *1) (-5 *1 (-877))) (-3252 (*1 *1 *1) (-5 *1 (-877))) (-3766 (*1 *1 *1 *1) (-5 *1 (-877))) (-3766 (*1 *1 *1) (-5 *1 (-877)))) 
+(-13 (-1119) (-10 -8 (-15 -3029 ((-1285) $)) (-15 -2074 ($ (-1173))) (-15 -2148 ((-1285) (-1173))) (-15 -4149 ($ (-592))) (-15 -4149 ($ (-1191))) (-15 -4149 ($ (-1173))) (-15 -4149 ($ (-237))) (-15 -2890 ($)) (-15 -3515 ((-592) $)) (-15 -2535 ((-592) $)) (-15 -3515 ((-592))) (-15 -2535 ((-592))) (-15 -3025 ((-592) $)) (-15 -4407 ((-592) $)) (-15 -4450 ($ (-592))) (-15 -3553 ($ (-592))) (-15 -4114 ($ (-592) (-592))) (-15 -1961 ($ $ (-592))) (-15 -1954 ($ $ (-592))) (-15 -2838 ($ $ (-592))) (-15 -1961 ($ $)) (-15 -1954 ($ $)) (-15 -2838 ($ $)) (-15 -3106 ($ $ $)) (-15 -1460 ($ $ $)) (-15 -3106 ($ (-658 $))) (-15 -1460 ($ (-658 $))) (-15 -3989 ($ $ (-658 $))) (-15 -3686 ($ $ (-658 $))) (-15 -3686 ($ $ $ $)) (-15 -4400 ($ $ $)) (-15 -4278 ((-141) $)) (-15 -3927 ($ $ (-658 $))) (-15 -4574 ($ $)) (-15 -3190 ($ $ $)) (-15 -3280 ($ $)) (-15 -4186 ($ (-658 (-658 $)))) (-15 -1985 ($ $ $)) (-15 -2749 ($ $)) (-15 -2749 ($ $ $)) (-15 -3986 ($ $ $)) (-15 -4291 ($ $ $)) (-15 -2733 ($ $ $)) (-15 -1547 ($ $ $)) (-15 -3644 ($ $ (-790))) (-15 -4042 ($ $ $)) (-15 -3220 ($ $ $)) (-15 -4477 ($ $ $)) (-15 -3589 ($ $ $)) (-15 -4070 ($ $ $)) (-15 -4239 ($ $ (-658 $))) (-15 -4418 ($ $ (-658 $))) (-15 -3645 ($ $)) (-15 -1729 ($ $)) (-15 -1729 ($ $ (-790))) (-15 -1644 ($ $)) (-15 -1644 ($ $ (-790))) (-15 -3124 ($ $)) (-15 -1727 ($ $ $)) (-15 -2090 ($ $)) (-15 -2090 ($ $ $)) (-15 -2090 ($ $ $ $)) (-15 -1975 ($ $)) (-15 -1975 ($ $ $)) (-15 -1975 ($ $ $ $)) (-15 -1749 ($ $)) (-15 -1749 ($ $ $)) (-15 -1749 ($ $ $ $)) (-15 -4586 ($ $)) (-15 -4586 ($ (-658 $))) (-15 -3754 ($ $)) (-15 -3754 ($ (-658 $))) (-15 -2243 ($ $)) (-15 -2243 ($ (-658 $))) (-15 -2533 ($ (-658 $))) (-15 -3844 ($ (-658 $))) (-15 -2928 ($ (-658 $))) (-15 -3490 ($ (-658 $))) (-15 -3255 ($ $ $)) (-15 -1858 ($ $ $)) (-15 -3266 ($ $ $)) (-15 -3273 ($ $ $)) (-15 -3279 ($ $ $)) (-15 -3286 ($ $ $)) (-15 -3300 ($ $ $)) (-15 -3306 ($ $ $)) (-15 -3306 ($ $)) (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3623 ($ $ $)) (-15 -1586 ($ $ $)) (-15 -1599 ($ $ $)) (-15 -3616 ($ $ $)) (-15 -1732 ($ $ $)) (-15 -3573 ($ $ $)) (-15 -3252 ($ $)) (-15 -3766 ($ $ $)) (-15 -3766 ($ $)))) 
+((-3930 (((-1285) (-658 (-57))) 24)) (-3087 (((-1285) (-1173) (-877)) 14) (((-1285) (-877)) 9) (((-1285) (-1173)) 11))) 
+(((-878) (-10 -7 (-15 -3087 ((-1285) (-1173))) (-15 -3087 ((-1285) (-877))) (-15 -3087 ((-1285) (-1173) (-877))) (-15 -3930 ((-1285) (-658 (-57)))))) (T -878)) 
+((-3930 (*1 *2 *3) (-12 (-5 *3 (-658 (-57))) (-5 *2 (-1285)) (-5 *1 (-878)))) (-3087 (*1 *2 *3 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-877)) (-5 *2 (-1285)) (-5 *1 (-878)))) (-3087 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-878)))) (-3087 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-878))))) 
+(-10 -7 (-15 -3087 ((-1285) (-1173))) (-15 -3087 ((-1285) (-877))) (-15 -3087 ((-1285) (-1173) (-877))) (-15 -3930 ((-1285) (-658 (-57))))) 
+((-1641 (((-141) $ $) NIL)) (-3983 (((-3 $ "failed") (-1191)) 32)) (-1403 (((-790)) 30)) (-4290 (($) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-3546 (((-944) $) 28)) (-2685 (((-1173) $) 38)) (-1825 (($ (-944)) 27)) (-2951 (((-1137) $) NIL)) (-1405 (((-658 $)) NIL)) (-1778 (((-1191) $) 13) (((-565) $) 19) (((-914 (-405)) $) 25) (((-914 (-592)) $) 22)) (-1683 (((-877) $) 16)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 35)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 34))) 
+(((-879 |#1|) (-13 (-863) (-633 (-1191)) (-633 (-565)) (-633 (-914 (-405))) (-633 (-914 (-592))) (-10 -8 (-15 -3983 ((-3 $ "failed") (-1191))))) (-658 (-1191))) (T -879)) 
+((-3983 (*1 *1 *2) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-879 *3)) (-14 *3 (-658 *2))))) 
+(-13 (-863) (-633 (-1191)) (-633 (-565)) (-633 (-914 (-405))) (-633 (-914 (-592))) (-10 -8 (-15 -3983 ((-3 $ "failed") (-1191))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (((-980 |#1|) $) NIL) (($ (-980 |#1|)) NIL) (($ |#1|) NIL (|has| |#1| (-194)))) (-4010 (((-790)) NIL)) (-3583 (((-1285) (-790)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3313 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL (|has| |#1| (-194))) (($ $ |#1|) NIL (|has| |#1| (-194))))) 
+(((-880 |#1| |#2| |#3| |#4|) (-13 (-1075) (-10 -8 (IF (|has| |#1| (-194)) (-6 (-43 |#1|)) |noBranch|) (-15 -1683 ((-980 |#1|) $)) (-15 -1683 ($ (-980 |#1|))) (IF (|has| |#1| (-388)) (-15 -3313 ((-3 $ "failed") $ $)) |noBranch|) (-15 -3583 ((-1285) (-790))))) (-1075) (-658 (-1191)) (-658 (-790)) (-790)) (T -880)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-980 *3)) (-5 *1 (-880 *3 *4 *5 *6)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))) (-14 *5 (-658 (-790))) (-14 *6 (-790)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-980 *3)) (-4 *3 (-1075)) (-5 *1 (-880 *3 *4 *5 *6)) (-14 *4 (-658 (-1191))) (-14 *5 (-658 (-790))) (-14 *6 (-790)))) (-3313 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-880 *2 *3 *4 *5)) (-4 *2 (-388)) (-4 *2 (-1075)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-790))) (-14 *5 (-790)))) (-3583 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-880 *4 *5 *6 *7)) (-4 *4 (-1075)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 *3)) (-14 *7 *3)))) 
+(-13 (-1075) (-10 -8 (IF (|has| |#1| (-194)) (-6 (-43 |#1|)) |noBranch|) (-15 -1683 ((-980 |#1|) $)) (-15 -1683 ($ (-980 |#1|))) (IF (|has| |#1| (-388)) (-15 -3313 ((-3 $ "failed") $ $)) |noBranch|) (-15 -3583 ((-1285) (-790))))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2651 (((-1280 $) $ $) 78)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-1917 (((-141) $) 111)) (-4424 (((-790)) 115)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-3925 (((-1285) $) 74)) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 122) (((-3 (-433 (-592)) "failed") $) 119) (((-3 (-433 (-592)) "failed") $) 104) (((-3 (-887) "failed") $) 136) (((-3 (-887) "failed") $) 130)) (-2400 (((-592) $) 121) (((-433 (-592)) $) 118) (((-433 (-592)) $) 105) (((-887) $) 135) (((-887) $) 131)) (-1586 (($ $ $) 53)) (-3657 (($ (-1187 $)) 84)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-1525 (($ $ (-790)) 102 (-3836 (|has| (-887) (-169)) (|has| (-887) (-394)) (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394)))) (($ $) 101 (-3836 (|has| (-887) (-169)) (|has| (-887) (-394)) (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-2802 (((-141) $) 69)) (-2837 (($ $) 79)) (-4346 (((-855 (-944)) $) 99 (-3836 (|has| (-887) (-169)) (|has| (-887) (-394)) (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-3558 (((-141) $) 30)) (-3613 (($ (-1187 $) $ (-1191)) 76) (($ (-1187 $) (-1191)) 75)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-1561 (($ (-658 $)) 81)) (-3650 (((-1187 $) $) 86) (((-1187 $) $ $) 85)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-2142 (((-141) $) 112)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 82)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3767 (((-877) $) 73)) (-4500 (((-444 $) $) 72)) (-3470 (((-855 (-944))) 114)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2378 (((-944) $) 80)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-4445 (((-658 $) (-1187 $) $) 83)) (-2177 (((-3 (-790) "failed") $ $) 100 (-3836 (|has| (-887) (-169)) (|has| (-887) (-394)) (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-1936 (((-160)) 106)) (-4525 (((-855 (-944)) $) 113)) (-3390 (((-1187 $)) 88) (((-1187 $) $) 87)) (-2227 (($ $) 77)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63) (($ (-592)) 123) (($ (-433 (-592))) 120) (($ (-433 (-592))) 103) (($ (-887)) 137) (($ (-887)) 129)) (-1517 (((-3 $ "failed") $) 98 (-3836 (|has| (-887) (-169)) (|has| (-887) (-394)) (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-3069 (((-141) $) 110)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3417 (($ $ (-790)) 117 (-3836 (|has| (-887) (-394)) (|has| (-433 (-592)) (-394)))) (($ $) 116 (-3836 (|has| (-887) (-394)) (|has| (-433 (-592)) (-394))))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62) (($ $ (-433 (-592))) 107) (($ $ (-887)) 132)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64) (($ (-433 (-592)) $) 109) (($ $ (-433 (-592))) 108) (($ (-887) $) 134) (($ $ (-887)) 133))) 
+(((-881) (-1311)) (T -881)) 
+NIL 
+(-13 (-886) (-1065 (-887)) (-1297 (-887))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 (-887) (-887)) . T) ((-140 $ $) . T) ((-158) . T) ((-169) -3836 (|has| (-887) (-394)) (|has| (-887) (-169)) (|has| (-433 (-592)) (-394)) (|has| (-433 (-592)) (-169))) ((-171) . T) ((-632 (-877)) . T) ((-194) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-1297 (-433 (-592))) . T) ((-1297 (-887)) . T) ((-388) . T) ((-428) -3836 (|has| (-887) (-394)) (|has| (-887) (-169)) (|has| (-433 (-592)) (-394)) (|has| (-433 (-592)) (-169))) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 (-887)) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 (-887)) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-885) . T) ((-886) . T) ((-1065 (-433 (-592))) . T) ((-1065 (-592)) . T) ((-1065 (-887)) . T) ((-1081 (-433 (-592))) . T) ((-1081 (-887)) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T) ((-1287 (-433 (-592))) . T) ((-1287 (-887)) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 47)) (-2651 (((-1280 $) $ $) 69)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3925 (((-1285) $) 78)) (-3001 (($) NIL T CONST)) (-3265 (((-887) $) 17)) (-4368 (((-3 (-592) "failed") $) 75) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 (-887) "failed") $) 72) (((-3 (-887) "failed") $) 72)) (-2400 (((-592) $) NIL) (((-433 (-592)) $) NIL) (((-433 (-592)) $) NIL) (((-887) $) 111) (((-887) $) 111)) (-1586 (($ $ $) NIL)) (-3657 (($ (-1187 $)) 59)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-1525 (($ $ (-790)) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394)) (|has| (-887) (-169)) (|has| (-887) (-394)))) (($ $) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394)) (|has| (-887) (-169)) (|has| (-887) (-394))))) (-2802 (((-141) $) NIL)) (-2837 (($ $) 63)) (-4346 (((-855 (-944)) $) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394)) (|has| (-887) (-169)) (|has| (-887) (-394))))) (-3558 (((-141) $) 117)) (-3613 (($ (-1187 $) $ (-1191)) 41) (($ (-1187 $) (-1191)) 94)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1561 (($ (-658 $)) 61)) (-3650 (((-1187 $) $) 55) (((-1187 $) $ $) 56)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 101)) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 62)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3767 (((-877) $) 124)) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2378 (((-944) $) 37)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4445 (((-658 $) (-1187 $) $) 96)) (-2177 (((-3 (-790) "failed") $ $) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394)) (|has| (-887) (-169)) (|has| (-887) (-394))))) (-1936 (((-160)) NIL)) (-4525 (((-855 (-944)) $) NIL)) (-3390 (((-1187 $)) 79) (((-1187 $) $) 64)) (-2227 (($ $) NIL)) (-1683 (((-877) $) 123) (($ (-592)) 44) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-592)) 44) (($ (-433 (-592))) NIL) (($ (-433 (-592))) NIL) (($ (-887)) 118) (($ (-887)) 118)) (-1517 (((-3 $ "failed") $) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394)) (|has| (-887) (-169)) (|has| (-887) (-394))))) (-4010 (((-790)) 126)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 48 T CONST)) (-4257 (($) 38 T CONST)) (-3417 (($ $ (-790)) NIL (-3836 (|has| (-433 (-592)) (-394)) (|has| (-887) (-394)))) (($ $) NIL (-3836 (|has| (-433 (-592)) (-394)) (|has| (-887) (-394))))) (-3255 (((-141) $ $) 114)) (-3313 (($ $ $) 102) (($ $ (-433 (-592))) NIL) (($ $ (-887)) NIL)) (-3306 (($ $) 35) (($ $ $) 105)) (-3300 (($ $ $) 81)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 53) (($ $ $) 31) (($ $ (-433 (-592))) 109) (($ (-433 (-592)) $) NIL) (($ (-433 (-592)) $) NIL) (($ $ (-433 (-592))) 109) (($ (-887) $) 103) (($ $ (-887)) 104))) 
+(((-882 |#1|) (-13 (-881) (-10 -8 (-15 -3767 ((-877) $)) (-15 -3265 ((-887) $)))) (-887)) (T -882)) 
+((-3767 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-882 *3)) (-14 *3 (-887)))) (-3265 (*1 *2 *1) (-12 (-5 *2 (-887)) (-5 *1 (-882 *3)) (-14 *3 *2)))) 
+(-13 (-881) (-10 -8 (-15 -3767 ((-877) $)) (-15 -3265 ((-887) $)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2651 (((-1280 $) $ $) 114)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-4217 (((-1199 (-944) (-790)) (-592)) 88)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-1403 (((-790)) 98)) (-3925 (((-1285) $) 118)) (-3001 (($) 16 T CONST)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 82)) (-1586 (($ $ $) 53)) (-3657 (($ (-1187 $)) 108)) (-3371 (((-3 $ "failed") $) 33)) (-4290 (($) 101)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2667 (($) 86)) (-3293 (((-141) $) 85)) (-1525 (($ $) 75) (($ $ (-790)) 74)) (-2802 (((-141) $) 69)) (-2837 (($ $) 113)) (-4346 (((-855 (-944)) $) 77) (((-944) $) 83)) (-3558 (((-141) $) 30)) (-3921 (((-3 $ "failed") $) 97)) (-3613 (($ (-1187 $) (-1191)) 117) (($ (-1187 $) $ (-1191)) 116)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-1561 (($ (-658 $)) 111)) (-3546 (((-944) $) 100)) (-3650 (((-1187 $) $ $) 107) (((-1187 $) $) 106)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-3703 (($) 96 T CONST)) (-1825 (($ (-944)) 99)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 110)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3767 (((-877) $) 119)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) 89)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2378 (((-944) $) 112)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-1405 (((-658 $)) 102)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-4445 (((-658 $) (-1187 $) $) 109)) (-2177 (((-3 (-790) "failed") $ $) 76) (((-790) $) 84)) (-3644 (($ $ (-790)) 94) (($ $) 92)) (-3390 (((-1187 $) $) 105) (((-1187 $)) 104)) (-3809 (($) 87)) (-2227 (($ $) 115)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 90)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63)) (-1517 (((-3 $ "failed") $) 78) (($ $) 91)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-790)) 95) (($ $) 93)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64))) 
+(((-883) (-1311)) (T -883)) 
+NIL 
+(-13 (-373) (-885)) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-169) . T) ((-632 (-877)) . T) ((-194) . T) ((-247) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-428) . T) ((-394) . T) ((-373) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-885) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) . T) ((-1235) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 29)) (-2651 (((-1280 $) $ $) 48)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 39)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4217 (((-1199 (-944) (-790)) (-592)) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) 52)) (-3925 (((-1285) $) 56)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 126)) (-2400 ((|#1| $) 85)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) 139)) (-1586 (($ $ $) NIL)) (-3657 (($ (-1187 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) 82)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL)) (-3293 (((-141) $) NIL)) (-1525 (($ $) NIL) (($ $ (-790)) NIL)) (-2802 (((-141) $) NIL)) (-2837 (($ $) 41)) (-4346 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3558 (((-141) $) 123)) (-3921 (((-3 $ "failed") $) NIL)) (-3613 (($ (-1187 $) (-1191)) 79) (($ (-1187 $) $ (-1191)) 99)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1561 (($ (-658 $)) 104)) (-3546 (((-944) $) 134)) (-3650 (((-1187 $) $ $) NIL) (((-1187 $) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 27)) (-3703 (($) NIL T CONST)) (-1825 (($ (-944)) 136)) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 40)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3767 (((-877) $) 132)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL)) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2378 (((-944) $) 14)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4445 (((-658 $) (-1187 $) $) 81)) (-2177 (((-3 (-790) "failed") $ $) NIL) (((-790) $) NIL)) (-1936 (((-160)) NIL)) (-3644 (($ $ (-790)) NIL) (($ $) NIL)) (-4525 (((-855 (-944)) $) 17)) (-3390 (((-1187 $) $) 20) (((-1187 $)) NIL)) (-3809 (($) NIL)) (-2227 (($ $) 90)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL)) (-1683 (((-877) $) 131) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) 124)) (-1517 (((-3 $ "failed") $) NIL) (($ $) 89)) (-4010 (((-790)) 140)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 30 T CONST)) (-4257 (($) 21 T CONST)) (-3417 (($ $ (-790)) NIL (|has| |#1| (-394))) (($ $) NIL (|has| |#1| (-394)))) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3255 (((-141) $ $) 120)) (-3313 (($ $ $) 96) (($ $ |#1|) NIL)) (-3306 (($ $) 97) (($ $ $) 107)) (-3300 (($ $ $) 63)) (** (($ $ (-944)) 33) (($ $ (-790)) 34) (($ $ (-592)) 37)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 111) (($ $ $) 65) (($ $ (-433 (-592))) 112) (($ (-433 (-592)) $) NIL) (($ |#1| $) 105) (($ $ |#1|) 106))) 
+(((-884 |#1|) (-13 (-883) (-1297 |#1|) (-10 -8 (-15 -3767 ((-877) $)))) (-373)) (T -884)) 
+((-3767 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-884 *3)) (-4 *3 (-373))))) 
+(-13 (-883) (-1297 |#1|) (-10 -8 (-15 -3767 ((-877) $)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2651 (((-1280 $) $ $) 78)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-3925 (((-1285) $) 74)) (-3001 (($) 16 T CONST)) (-1586 (($ $ $) 53)) (-3657 (($ (-1187 $)) 84)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-2802 (((-141) $) 69)) (-2837 (($ $) 79)) (-3558 (((-141) $) 30)) (-3613 (($ (-1187 $) $ (-1191)) 76) (($ (-1187 $) (-1191)) 75)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-1561 (($ (-658 $)) 81)) (-3650 (((-1187 $) $) 86) (((-1187 $) $ $) 85)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 82)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3767 (((-877) $) 73)) (-4500 (((-444 $) $) 72)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2378 (((-944) $) 80)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-4445 (((-658 $) (-1187 $) $) 83)) (-3390 (((-1187 $)) 88) (((-1187 $) $) 87)) (-2227 (($ $) 77)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64))) 
+(((-885) (-1311)) (T -885)) 
+((-3390 (*1 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) (-3390 (*1 *2 *1) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) (-3650 (*1 *2 *1) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) (-3650 (*1 *2 *1 *1) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) (-3657 (*1 *1 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) (-4445 (*1 *2 *3 *1) (-12 (-5 *3 (-1187 *1)) (-4 *1 (-885)) (-5 *2 (-658 *1)))) (-4559 (*1 *2 *1) (-12 (-4 *1 (-885)) (-5 *2 (-141)))) (-1561 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-885)))) (-2378 (*1 *2 *1) (-12 (-4 *1 (-885)) (-5 *2 (-944)))) (-2837 (*1 *1 *1) (-4 *1 (-885))) (-2651 (*1 *2 *1 *1) (-12 (-5 *2 (-1280 *1)) (-4 *1 (-885)))) (-2227 (*1 *1 *1) (-4 *1 (-885))) (-3613 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1187 *1)) (-5 *3 (-1191)) (-4 *1 (-885)))) (-3613 (*1 *1 *2 *3) (-12 (-5 *2 (-1187 *1)) (-5 *3 (-1191)) (-4 *1 (-885)))) (-3925 (*1 *2 *1) (-12 (-4 *1 (-885)) (-5 *2 (-1285)))) (-3767 (*1 *2 *1) (-12 (-4 *1 (-885)) (-5 *2 (-877))))) 
+(-13 (-388) (-10 -8 (-15 -3390 ((-1187 $))) (-15 -3390 ((-1187 $) $)) (-15 -3650 ((-1187 $) $)) (-15 -3650 ((-1187 $) $ $)) (-15 -3657 ($ (-1187 $))) (-15 -4445 ((-658 $) (-1187 $) $)) (-15 -4559 ((-141) $)) (-15 -1561 ($ (-658 $))) (-15 -2378 ((-944) $)) (-15 -2837 ($ $)) (-15 -2651 ((-1280 $) $ $)) (-15 -2227 ($ $)) (-15 -3613 ($ (-1187 $) $ (-1191))) (-15 -3613 ($ (-1187 $) (-1191))) (-15 -3925 ((-1285) $)) (-15 -3767 ((-877) $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T)) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2651 (((-1280 $) $ $) 78)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-1917 (((-141) $) 111)) (-4424 (((-790)) 115)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-3925 (((-1285) $) 74)) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 122) (((-3 (-433 (-592)) "failed") $) 119) (((-3 (-433 (-592)) "failed") $) 104)) (-2400 (((-592) $) 121) (((-433 (-592)) $) 118) (((-433 (-592)) $) 105)) (-1586 (($ $ $) 53)) (-3657 (($ (-1187 $)) 84)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-1525 (($ $ (-790)) 102 (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394)))) (($ $) 101 (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-2802 (((-141) $) 69)) (-2837 (($ $) 79)) (-4346 (((-855 (-944)) $) 99 (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-3558 (((-141) $) 30)) (-3613 (($ (-1187 $) $ (-1191)) 76) (($ (-1187 $) (-1191)) 75)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-1561 (($ (-658 $)) 81)) (-3650 (((-1187 $) $) 86) (((-1187 $) $ $) 85)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-2142 (((-141) $) 112)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 82)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3767 (((-877) $) 73)) (-4500 (((-444 $) $) 72)) (-3470 (((-855 (-944))) 114)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2378 (((-944) $) 80)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-4445 (((-658 $) (-1187 $) $) 83)) (-2177 (((-3 (-790) "failed") $ $) 100 (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-1936 (((-160)) 106)) (-4525 (((-855 (-944)) $) 113)) (-3390 (((-1187 $)) 88) (((-1187 $) $) 87)) (-2227 (($ $) 77)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63) (($ (-592)) 123) (($ (-433 (-592))) 120) (($ (-433 (-592))) 103)) (-1517 (((-3 $ "failed") $) 98 (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-3069 (((-141) $) 110)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3417 (($ $ (-790)) 117 (|has| (-433 (-592)) (-394))) (($ $) 116 (|has| (-433 (-592)) (-394)))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62) (($ $ (-433 (-592))) 107)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64) (($ (-433 (-592)) $) 109) (($ $ (-433 (-592))) 108))) 
+(((-886) (-1311)) (T -886)) 
+NIL 
+(-13 (-885) (-171) (-1065 (-592)) (-1065 (-433 (-592))) (-1297 (-433 (-592)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-169) -3836 (|has| (-433 (-592)) (-394)) (|has| (-433 (-592)) (-169))) ((-171) . T) ((-632 (-877)) . T) ((-194) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-1297 (-433 (-592))) . T) ((-388) . T) ((-428) -3836 (|has| (-433 (-592)) (-394)) (|has| (-433 (-592)) (-169))) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-885) . T) ((-1065 (-433 (-592))) . T) ((-1065 (-592)) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T) ((-1287 (-433 (-592))) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 16)) (-2651 (((-1280 $) $ $) 47)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3925 (((-1285) $) 51)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) 104) (((-3 (-433 (-592)) "failed") $) 106) (((-3 (-433 (-592)) "failed") $) 106)) (-2400 (((-592) $) NIL) (((-433 (-592)) $) 94) (((-433 (-592)) $) 94)) (-1586 (($ $ $) NIL)) (-3657 (($ (-1187 $)) 34)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-1525 (($ $ (-790)) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394)))) (($ $) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-2802 (((-141) $) NIL)) (-2837 (($ $) 40)) (-4346 (((-855 (-944)) $) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-3558 (((-141) $) 100)) (-3613 (($ (-1187 $) $ (-1191)) 79) (($ (-1187 $) (-1191)) 70) (($ (-1187 $) (-1187 $) (-944) $ (-1191)) 80)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1561 (($ (-658 $)) 38)) (-3650 (((-1187 $) $) 29) (((-1187 $) $ $) 31)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 86)) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 39)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3767 (((-877) $) 112)) (-4500 (((-444 $) $) NIL)) (-3470 (((-855 (-944))) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2378 (((-944) $) 30)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4445 (((-658 $) (-1187 $) $) 72)) (-2177 (((-3 (-790) "failed") $ $) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-1936 (((-160)) NIL)) (-4525 (((-855 (-944)) $) NIL)) (-3390 (((-1187 $)) 52) (((-1187 $) $) 41)) (-2227 (($ $) NIL)) (-1683 (((-877) $) 111) (($ (-592)) 14) (($ $) NIL) (($ (-433 (-592))) 101) (($ (-592)) 14) (($ (-433 (-592))) 101) (($ (-433 (-592))) 101)) (-1517 (((-3 $ "failed") $) NIL (-3836 (|has| (-433 (-592)) (-169)) (|has| (-433 (-592)) (-394))))) (-4010 (((-790)) 114)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 17 T CONST)) (-4257 (($) 73 T CONST)) (-3417 (($ $ (-790)) NIL (|has| (-433 (-592)) (-394))) (($ $) NIL (|has| (-433 (-592)) (-394)))) (-3255 (((-141) $ $) 97)) (-3313 (($ $ $) 78) (($ $ (-433 (-592))) NIL)) (-3306 (($ $) 19) (($ $ $) 89)) (-3300 (($ $ $) 54)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 18) (($ $ $) 57) (($ $ (-433 (-592))) 88) (($ (-433 (-592)) $) 87) (($ (-433 (-592)) $) 87) (($ $ (-433 (-592))) 88))) 
+(((-887) (-13 (-886) (-10 -8 (-15 -3767 ((-877) $)) (-15 -3613 ($ (-1187 $) (-1187 $) (-944) $ (-1191)))))) (T -887)) 
+((-3767 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-887)))) (-3613 (*1 *1 *2 *2 *3 *1 *4) (-12 (-5 *2 (-1187 (-887))) (-5 *3 (-944)) (-5 *4 (-1191)) (-5 *1 (-887))))) 
+(-13 (-886) (-10 -8 (-15 -3767 ((-877) $)) (-15 -3613 ($ (-1187 $) (-1187 $) (-944) $ (-1191))))) 
+((-4515 (((-3 (-195 |#3|) "failed") (-790) (-790) |#2| |#2|) 31)) (-4365 (((-3 (-433 |#3|) "failed") (-790) (-790) |#2| |#2|) 24))) 
+(((-888 |#1| |#2| |#3|) (-10 -7 (-15 -4365 ((-3 (-433 |#3|) "failed") (-790) (-790) |#2| |#2|)) (-15 -4515 ((-3 (-195 |#3|) "failed") (-790) (-790) |#2| |#2|))) (-388) (-1270 |#1|) (-1255 |#1|)) (T -888)) 
+((-4515 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-790)) (-4 *5 (-388)) (-5 *2 (-195 *6)) (-5 *1 (-888 *5 *4 *6)) (-4 *4 (-1270 *5)) (-4 *6 (-1255 *5)))) (-4365 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-790)) (-4 *5 (-388)) (-5 *2 (-433 *6)) (-5 *1 (-888 *5 *4 *6)) (-4 *4 (-1270 *5)) (-4 *6 (-1255 *5))))) 
+(-10 -7 (-15 -4365 ((-3 (-433 |#3|) "failed") (-790) (-790) |#2| |#2|)) (-15 -4515 ((-3 (-195 |#3|) "failed") (-790) (-790) |#2| |#2|))) 
+((-4365 (((-3 (-433 (-1252 |#2| |#1|)) "failed") (-790) (-790) (-1271 |#1| |#2| |#3|)) 28) (((-3 (-433 (-1252 |#2| |#1|)) "failed") (-790) (-790) (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|)) 26))) 
+(((-889 |#1| |#2| |#3|) (-10 -7 (-15 -4365 ((-3 (-433 (-1252 |#2| |#1|)) "failed") (-790) (-790) (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|))) (-15 -4365 ((-3 (-433 (-1252 |#2| |#1|)) "failed") (-790) (-790) (-1271 |#1| |#2| |#3|)))) (-388) (-1191) |#1|) (T -889)) 
+((-4365 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-790)) (-5 *4 (-1271 *5 *6 *7)) (-4 *5 (-388)) (-14 *6 (-1191)) (-14 *7 *5) (-5 *2 (-433 (-1252 *6 *5))) (-5 *1 (-889 *5 *6 *7)))) (-4365 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-790)) (-5 *4 (-1271 *5 *6 *7)) (-4 *5 (-388)) (-14 *6 (-1191)) (-14 *7 *5) (-5 *2 (-433 (-1252 *6 *5))) (-5 *1 (-889 *5 *6 *7))))) 
+(-10 -7 (-15 -4365 ((-3 (-433 (-1252 |#2| |#1|)) "failed") (-790) (-790) (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|))) (-15 -4365 ((-3 (-433 (-1252 |#2| |#1|)) "failed") (-790) (-790) (-1271 |#1| |#2| |#3|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-1442 (($ $ (-592)) 60)) (-3652 (((-141) $ $) 57)) (-3001 (($) 16 T CONST)) (-2749 (($ (-1187 (-592)) (-592)) 59)) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-3980 (($ $) 62)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-4346 (((-790) $) 67)) (-3558 (((-141) $) 30)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-1704 (((-592)) 64)) (-1518 (((-592) $) 63)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2807 (($ $ (-592)) 66)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-4406 (((-1171 (-592)) $) 68)) (-1700 (($ $) 65)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-2642 (((-592) $ (-592)) 61)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-890 |#1|) (-1311) (-592)) (T -890)) 
+((-4406 (*1 *2 *1) (-12 (-4 *1 (-890 *3)) (-5 *2 (-1171 (-592))))) (-4346 (*1 *2 *1) (-12 (-4 *1 (-890 *3)) (-5 *2 (-790)))) (-2807 (*1 *1 *1 *2) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592)))) (-1700 (*1 *1 *1) (-4 *1 (-890 *2))) (-1704 (*1 *2) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592)))) (-1518 (*1 *2 *1) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592)))) (-3980 (*1 *1 *1) (-4 *1 (-890 *2))) (-2642 (*1 *2 *1 *2) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592)))) (-1442 (*1 *1 *1 *2) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592)))) (-2749 (*1 *1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *3 (-592)) (-4 *1 (-890 *4))))) 
+(-13 (-323) (-171) (-10 -8 (-15 -4406 ((-1171 (-592)) $)) (-15 -4346 ((-790) $)) (-15 -2807 ($ $ (-592))) (-15 -1700 ($ $)) (-15 -1704 ((-592))) (-15 -1518 ((-592) $)) (-15 -3980 ($ $)) (-15 -2642 ((-592) $ (-592))) (-15 -1442 ($ $ (-592))) (-15 -2749 ($ (-1187 (-592)) (-592))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-171) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-323) . T) ((-477) . T) ((-582) . T) ((-661 $) . T) ((-678) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $ (-592)) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-2749 (($ (-1187 (-592)) (-592)) NIL)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3980 (($ $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-4346 (((-790) $) NIL)) (-3558 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1704 (((-592)) NIL)) (-1518 (((-592) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2807 (($ $ (-592)) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4406 (((-1171 (-592)) $) NIL)) (-1700 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL)) (-4010 (((-790)) NIL)) (-2537 (((-141) $ $) NIL)) (-2642 (((-592) $ (-592)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL))) 
+(((-891 |#1|) (-890 |#1|) (-592)) (T -891)) 
+NIL 
+(-890 |#1|) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 (((-891 |#1|) $) NIL (|has| (-891 |#1|) (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-891 |#1|) (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| (-891 |#1|) (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| (-891 |#1|) (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-891 |#1|) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL (|has| (-891 |#1|) (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-891 |#1|) (-1065 (-592)))) (((-3 (-592) "failed") $) NIL (|has| (-891 |#1|) (-1065 (-592))))) (-2400 (((-891 |#1|) $) NIL) (((-1191) $) NIL (|has| (-891 |#1|) (-1065 (-1191)))) (((-433 (-592)) $) NIL (|has| (-891 |#1|) (-1065 (-592)))) (((-592) $) NIL (|has| (-891 |#1|) (-1065 (-592))))) (-3792 (($ $) NIL) (($ (-592) $) NIL)) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-891 |#1|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-891 |#1|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-891 |#1|))) (|:| |vec| (-1280 (-891 |#1|)))) (-706 $) (-1280 $)) NIL) (((-706 (-891 |#1|)) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-891 |#1|) (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) NIL (|has| (-891 |#1|) (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| (-891 |#1|) (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| (-891 |#1|) (-908 (-405))))) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL)) (-1448 (((-891 |#1|) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| (-891 |#1|) (-1165)))) (-1324 (((-141) $) NIL (|has| (-891 |#1|) (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| (-891 |#1|) (-869)))) (-3319 (($ $ $) NIL (|has| (-891 |#1|) (-869)))) (-2731 (($ (-1 (-891 |#1|) (-891 |#1|)) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-891 |#1|) (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| (-891 |#1|) (-323)))) (-2039 (((-891 |#1|) $) NIL (|has| (-891 |#1|) (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-891 |#1|) (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-891 |#1|) (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 (-891 |#1|)) (-658 (-891 |#1|))) NIL (|has| (-891 |#1|) (-325 (-891 |#1|)))) (($ $ (-891 |#1|) (-891 |#1|)) NIL (|has| (-891 |#1|) (-325 (-891 |#1|)))) (($ $ (-310 (-891 |#1|))) NIL (|has| (-891 |#1|) (-325 (-891 |#1|)))) (($ $ (-658 (-310 (-891 |#1|)))) NIL (|has| (-891 |#1|) (-325 (-891 |#1|)))) (($ $ (-658 (-1191)) (-658 (-891 |#1|))) NIL (|has| (-891 |#1|) (-547 (-1191) (-891 |#1|)))) (($ $ (-1191) (-891 |#1|)) NIL (|has| (-891 |#1|) (-547 (-1191) (-891 |#1|))))) (-2769 (((-790) $) NIL)) (-3927 (($ $ (-891 |#1|)) NIL (|has| (-891 |#1|) (-303 (-891 |#1|) (-891 |#1|))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL (|has| (-891 |#1|) (-247))) (($ $ (-790)) NIL (|has| (-891 |#1|) (-247))) (($ $ (-1191)) NIL (|has| (-891 |#1|) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-891 |#1|) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-891 |#1|) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-891 |#1|) (-922 (-1191)))) (($ $ (-1 (-891 |#1|) (-891 |#1|)) (-790)) NIL) (($ $ (-1 (-891 |#1|) (-891 |#1|))) NIL)) (-2782 (($ $) NIL)) (-1456 (((-891 |#1|) $) NIL)) (-1778 (((-914 (-592)) $) NIL (|has| (-891 |#1|) (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| (-891 |#1|) (-633 (-914 (-405))))) (((-565) $) NIL (|has| (-891 |#1|) (-633 (-565)))) (((-405) $) NIL (|has| (-891 |#1|) (-1049))) (((-237) $) NIL (|has| (-891 |#1|) (-1049)))) (-2867 (((-195 (-433 (-592))) $) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-891 |#1|) (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL) (($ (-891 |#1|)) NIL) (($ (-1191)) NIL (|has| (-891 |#1|) (-1065 (-1191))))) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-891 |#1|) (-931))) (|has| (-891 |#1|) (-169))))) (-4010 (((-790)) NIL)) (-2744 (((-891 |#1|) $) NIL (|has| (-891 |#1|) (-574)))) (-2537 (((-141) $ $) NIL)) (-2642 (((-433 (-592)) $ (-592)) NIL)) (-1392 (($ $) NIL (|has| (-891 |#1|) (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $) NIL (|has| (-891 |#1|) (-247))) (($ $ (-790)) NIL (|has| (-891 |#1|) (-247))) (($ $ (-1191)) NIL (|has| (-891 |#1|) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-891 |#1|) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-891 |#1|) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-891 |#1|) (-922 (-1191)))) (($ $ (-1 (-891 |#1|) (-891 |#1|)) (-790)) NIL) (($ $ (-1 (-891 |#1|) (-891 |#1|))) NIL)) (-3286 (((-141) $ $) NIL (|has| (-891 |#1|) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-891 |#1|) (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| (-891 |#1|) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-891 |#1|) (-869)))) (-3313 (($ $ $) NIL) (($ (-891 |#1|) (-891 |#1|)) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ (-891 |#1|) $) NIL) (($ $ (-891 |#1|)) NIL))) 
+(((-892 |#1|) (-13 (-1021 (-891 |#1|)) (-10 -8 (-15 -2642 ((-433 (-592)) $ (-592))) (-15 -2867 ((-195 (-433 (-592))) $)) (-15 -3792 ($ $)) (-15 -3792 ($ (-592) $)))) (-592)) (T -892)) 
+((-2642 (*1 *2 *1 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-892 *4)) (-14 *4 *3) (-5 *3 (-592)))) (-2867 (*1 *2 *1) (-12 (-5 *2 (-195 (-433 (-592)))) (-5 *1 (-892 *3)) (-14 *3 (-592)))) (-3792 (*1 *1 *1) (-12 (-5 *1 (-892 *2)) (-14 *2 (-592)))) (-3792 (*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-892 *3)) (-14 *3 *2)))) 
+(-13 (-1021 (-891 |#1|)) (-10 -8 (-15 -2642 ((-433 (-592)) $ (-592))) (-15 -2867 ((-195 (-433 (-592))) $)) (-15 -3792 ($ $)) (-15 -3792 ($ (-592) $)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 ((|#2| $) NIL (|has| |#2| (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| |#2| (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-1191) "failed") $) NIL (|has| |#2| (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592))))) (-2400 ((|#2| $) NIL) (((-1191) $) NIL (|has| |#2| (-1065 (-1191)))) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-592)))) (((-592) $) NIL (|has| |#2| (-1065 (-592))))) (-3792 (($ $) 31) (($ (-592) $) 32)) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) 53)) (-4290 (($) NIL (|has| |#2| (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) NIL (|has| |#2| (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| |#2| (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| |#2| (-908 (-405))))) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL)) (-1448 ((|#2| $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| |#2| (-1165)))) (-1324 (((-141) $) NIL (|has| |#2| (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| |#2| (-869)))) (-3319 (($ $ $) NIL (|has| |#2| (-869)))) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 49)) (-3703 (($) NIL (|has| |#2| (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| |#2| (-323)))) (-2039 ((|#2| $) NIL (|has| |#2| (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 |#2|) (-658 |#2|)) NIL (|has| |#2| (-325 |#2|))) (($ $ |#2| |#2|) NIL (|has| |#2| (-325 |#2|))) (($ $ (-310 |#2|)) NIL (|has| |#2| (-325 |#2|))) (($ $ (-658 (-310 |#2|))) NIL (|has| |#2| (-325 |#2|))) (($ $ (-658 (-1191)) (-658 |#2|)) NIL (|has| |#2| (-547 (-1191) |#2|))) (($ $ (-1191) |#2|) NIL (|has| |#2| (-547 (-1191) |#2|)))) (-2769 (((-790) $) NIL)) (-3927 (($ $ |#2|) NIL (|has| |#2| (-303 |#2| |#2|)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) NIL (|has| |#2| (-247))) (($ $ (-790)) NIL (|has| |#2| (-247))) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-2782 (($ $) NIL)) (-1456 ((|#2| $) NIL)) (-1778 (((-914 (-592)) $) NIL (|has| |#2| (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| |#2| (-633 (-914 (-405))))) (((-565) $) NIL (|has| |#2| (-633 (-565)))) (((-405) $) NIL (|has| |#2| (-1049))) (((-237) $) NIL (|has| |#2| (-1049)))) (-2867 (((-195 (-433 (-592))) $) 68)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#2| (-931))))) (-1683 (((-877) $) 85) (($ (-592)) 19) (($ $) NIL) (($ (-433 (-592))) 24) (($ |#2|) 18) (($ (-1191)) NIL (|has| |#2| (-1065 (-1191))))) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#2| (-931))) (|has| |#2| (-169))))) (-4010 (((-790)) NIL)) (-2744 ((|#2| $) NIL (|has| |#2| (-574)))) (-2537 (((-141) $ $) NIL)) (-2642 (((-433 (-592)) $ (-592)) 60)) (-1392 (($ $) NIL (|has| |#2| (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 14 T CONST)) (-4257 (($) 16 T CONST)) (-1940 (($ $) NIL (|has| |#2| (-247))) (($ $ (-790)) NIL (|has| |#2| (-247))) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3255 (((-141) $ $) 35)) (-3279 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3313 (($ $ $) 23) (($ |#2| |#2|) 54)) (-3306 (($ $) 39) (($ $ $) 41)) (-3300 (($ $ $) 37)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) 50)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 42) (($ $ $) 44) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ |#2| $) 55) (($ $ |#2|) NIL))) 
+(((-893 |#1| |#2|) (-13 (-1021 |#2|) (-10 -8 (-15 -2642 ((-433 (-592)) $ (-592))) (-15 -2867 ((-195 (-433 (-592))) $)) (-15 -3792 ($ $)) (-15 -3792 ($ (-592) $)))) (-592) (-890 |#1|)) (T -893)) 
+((-2642 (*1 *2 *1 *3) (-12 (-14 *4 *3) (-5 *2 (-433 (-592))) (-5 *1 (-893 *4 *5)) (-5 *3 (-592)) (-4 *5 (-890 *4)))) (-2867 (*1 *2 *1) (-12 (-14 *3 (-592)) (-5 *2 (-195 (-433 (-592)))) (-5 *1 (-893 *3 *4)) (-4 *4 (-890 *3)))) (-3792 (*1 *1 *1) (-12 (-14 *2 (-592)) (-5 *1 (-893 *2 *3)) (-4 *3 (-890 *2)))) (-3792 (*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-14 *3 *2) (-5 *1 (-893 *3 *4)) (-4 *4 (-890 *3))))) 
+(-13 (-1021 |#2|) (-10 -8 (-15 -2642 ((-433 (-592)) $ (-592))) (-15 -2867 ((-195 (-433 (-592))) $)) (-15 -3792 ($ $)) (-15 -3792 ($ (-592) $)))) 
+((-4322 (((-264 |#2| (-884 |#1|)) (-264 |#2| |#1|) (-995 |#1|)) NIL)) (-3427 (((-264 |#2| |#1|)) 107)) (-2589 (((-658 (-995 |#1|))) 116)) (-2671 (((-658 (-995 |#1|)) (-658 (-995 |#1|))) 27)) (-3822 (((-264 |#2| |#1|) (-264 |#2| |#1|)) 35)) (-3969 (((-658 (-995 |#1|))) 60)) (-2463 (((-658 (-949 |#1|))) 58)) (-2117 (((-995 |#1|) (-658 (-884 |#1|))) 17)) (-3405 (((-995 |#1|) (-949 |#1|)) 21)) (-2742 (((-658 (-949 |#1|)) (-944)) 45 (|has| (-884 |#1|) (-394)))) (-3466 (((-658 (-949 |#1|)) (-995 |#1|)) 24)) (-1449 (((-801 (-884 |#1|)) (-264 |#2| |#1|) (-949 |#1|)) 119)) (-1595 (((-592) (-944)) 47 (|has| (-884 |#1|) (-394)))) (-4056 (((-592) (-944) (-944)) 49 (|has| (-884 |#1|) (-394)))) (-4530 (((-592) (-944)) 43 (|has| (-884 |#1|) (-394)))) (-2353 (((-2 (|:| |num| (-658 (-264 |#2| |#1|))) (|:| |den| (-264 |#2| |#1|))) (-258 (-949 |#1|))) 62) (((-658 (-433 (-264 |#2| |#1|))) (-258 (-949 |#1|)) (-790)) NIL)) (-1587 (((-258 (-949 |#1|)) (-264 |#2| |#1|)) 135)) (-2225 (((-658 (-264 |#2| (-884 |#1|))) (-258 (-949 |#1|)) (-658 (-264 |#2| |#1|))) 125)) (-4507 (((-658 (-264 |#2| |#1|)) (-258 (-949 |#1|)) (-790)) 123)) (-3315 (((-264 |#2| |#1|) (-264 |#2| |#1|) (-592)) 13)) (-2561 (((-706 |#1|) (-258 (-949 |#1|)) (-658 (-949 |#1|))) 67) (((-706 |#1|) (-258 (-949 |#1|)) (-258 (-949 |#1|))) 69)) (-3567 (((-592)) 105)) (-3918 (((-790)) 103)) (-3144 (((-1285)) 144)) (-1474 (((-1285)) 140)) (-4389 (((-2 (|:| -2016 (-592)) (|:| |num| (-264 |#2| |#1|)) (|:| |den| (-264 |#2| |#1|)) (|:| |upTo| (-592))) (-258 (-949 |#1|)) (-592) (-592)) 32)) (-4474 (((-3 |#1| "failed") (-433 (-264 |#2| |#1|)) (-949 |#1|)) 132) (((-3 |#1| "failed") (-264 |#2| |#1|) (-264 |#2| |#1|) (-949 |#1|)) 127) (((-3 |#1| "failed") (-264 |#2| |#1|) (-949 |#1|)) 96)) (-2806 ((|#1| (-433 (-264 |#2| |#1|)) (-949 |#1|)) 133) ((|#1| (-264 |#2| |#1|) (-264 |#2| |#1|) (-949 |#1|)) 63) ((|#1| (-264 |#2| |#1|) (-949 |#1|)) 98)) (-1488 (((-658 (-281 (-561 |#1| |#2| |#3|)))) 112)) (-3166 (((-658 (-281 (-561 |#1| |#2| |#3|)))) 110)) (-2825 (((-592)) 56 (|has| (-884 |#1|) (-394)))) (-2269 (((-258 (-949 |#1|))) 114)) (-2665 (((-1275 (-592) -4132) (-944)) 41 (|has| (-884 |#1|) (-394))) (((-1275 (-592) -4132)) 38 (|has| (-884 |#1|) (-394)))) (-2821 (((-1187 (-592)) (-944)) 54 (|has| (-884 |#1|) (-394))) (((-1187 (-592))) 52 (|has| (-884 |#1|) (-394))))) 
+(((-894 |#1| |#2| |#3|) (-10 -7 (-15 -3315 ((-264 |#2| |#1|) (-264 |#2| |#1|) (-592))) (-15 -1474 ((-1285))) (-15 -3144 ((-1285))) (-15 -3822 ((-264 |#2| |#1|) (-264 |#2| |#1|))) (-15 -4322 ((-264 |#2| (-884 |#1|)) (-264 |#2| |#1|) (-995 |#1|))) (-15 -2561 ((-706 |#1|) (-258 (-949 |#1|)) (-258 (-949 |#1|)))) (-15 -2561 ((-706 |#1|) (-258 (-949 |#1|)) (-658 (-949 |#1|)))) (-15 -3405 ((-995 |#1|) (-949 |#1|))) (-15 -3466 ((-658 (-949 |#1|)) (-995 |#1|))) (-15 -2117 ((-995 |#1|) (-658 (-884 |#1|)))) (-15 -2671 ((-658 (-995 |#1|)) (-658 (-995 |#1|)))) (-15 -2463 ((-658 (-949 |#1|)))) (-15 -3427 ((-264 |#2| |#1|))) (-15 -3918 ((-790))) (-15 -3567 ((-592))) (-15 -1488 ((-658 (-281 (-561 |#1| |#2| |#3|))))) (-15 -3166 ((-658 (-281 (-561 |#1| |#2| |#3|))))) (-15 -3969 ((-658 (-995 |#1|)))) (-15 -2589 ((-658 (-995 |#1|)))) (-15 -1449 ((-801 (-884 |#1|)) (-264 |#2| |#1|) (-949 |#1|))) (-15 -2353 ((-658 (-433 (-264 |#2| |#1|))) (-258 (-949 |#1|)) (-790))) (-15 -2353 ((-2 (|:| |num| (-658 (-264 |#2| |#1|))) (|:| |den| (-264 |#2| |#1|))) (-258 (-949 |#1|)))) (-15 -4389 ((-2 (|:| -2016 (-592)) (|:| |num| (-264 |#2| |#1|)) (|:| |den| (-264 |#2| |#1|)) (|:| |upTo| (-592))) (-258 (-949 |#1|)) (-592) (-592))) (-15 -2225 ((-658 (-264 |#2| (-884 |#1|))) (-258 (-949 |#1|)) (-658 (-264 |#2| |#1|)))) (-15 -4507 ((-658 (-264 |#2| |#1|)) (-258 (-949 |#1|)) (-790))) (-15 -2806 (|#1| (-264 |#2| |#1|) (-949 |#1|))) (-15 -2806 (|#1| (-264 |#2| |#1|) (-264 |#2| |#1|) (-949 |#1|))) (-15 -2806 (|#1| (-433 (-264 |#2| |#1|)) (-949 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-264 |#2| |#1|) (-949 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-264 |#2| |#1|) (-264 |#2| |#1|) (-949 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-433 (-264 |#2| |#1|)) (-949 |#1|))) (-15 -1587 ((-258 (-949 |#1|)) (-264 |#2| |#1|))) (-15 -2269 ((-258 (-949 |#1|)))) (IF (|has| (-884 |#1|) (-394)) (PROGN (-15 -2821 ((-1187 (-592)))) (-15 -2821 ((-1187 (-592)) (-944))) (-15 -2825 ((-592))) (-15 -2742 ((-658 (-949 |#1|)) (-944))) (-15 -4530 ((-592) (-944))) (-15 -1595 ((-592) (-944))) (-15 -4056 ((-592) (-944) (-944))) (-15 -2665 ((-1275 (-592) -4132))) (-15 -2665 ((-1275 (-592) -4132) (-944)))) |noBranch|)) (-373) (-658 (-1191)) (-137)) (T -894)) 
+((-2665 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2665 (*1 *2) (-12 (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-894 *3 *4 *5)) (-4 (-884 *3) (-394)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-4056 (*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-1595 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-4530 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2742 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-658 (-949 *4))) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2825 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-894 *3 *4 *5)) (-4 (-884 *3) (-394)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2821 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 (-592))) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2821 (*1 *2) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-894 *3 *4 *5)) (-4 (-884 *3) (-394)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2269 (*1 *2) (-12 (-5 *2 (-258 (-949 *3))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-1587 (*1 *2 *3) (-12 (-5 *3 (-264 *5 *4)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-5 *2 (-258 (-949 *4))) (-5 *1 (-894 *4 *5 *6)) (-4 *6 (-137)))) (-4474 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-264 *5 *2))) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) (-4474 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-264 *5 *2)) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) (-4474 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-264 *5 *2)) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) (-2806 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-264 *5 *2))) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) (-2806 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-264 *5 *2)) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) (-2806 (*1 *2 *3 *4) (-12 (-5 *3 (-264 *5 *2)) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) (-4507 (*1 *2 *3 *4) (-12 (-5 *3 (-258 (-949 *5))) (-5 *4 (-790)) (-4 *5 (-373)) (-5 *2 (-658 (-264 *6 *5))) (-5 *1 (-894 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) (-2225 (*1 *2 *3 *4) (-12 (-5 *3 (-258 (-949 *5))) (-5 *4 (-658 (-264 *6 *5))) (-4 *5 (-373)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-264 *6 (-884 *5)))) (-5 *1 (-894 *5 *6 *7)) (-4 *7 (-137)))) (-4389 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-258 (-949 *5))) (-4 *5 (-373)) (-5 *2 (-2 (|:| -2016 (-592)) (|:| |num| (-264 *6 *5)) (|:| |den| (-264 *6 *5)) (|:| |upTo| (-592)))) (-5 *1 (-894 *5 *6 *7)) (-5 *4 (-592)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) (-2353 (*1 *2 *3) (-12 (-5 *3 (-258 (-949 *4))) (-4 *4 (-373)) (-5 *2 (-2 (|:| |num| (-658 (-264 *5 *4))) (|:| |den| (-264 *5 *4)))) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2353 (*1 *2 *3 *4) (-12 (-5 *3 (-258 (-949 *5))) (-5 *4 (-790)) (-4 *5 (-373)) (-5 *2 (-658 (-433 (-264 *6 *5)))) (-5 *1 (-894 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) (-1449 (*1 *2 *3 *4) (-12 (-5 *3 (-264 *6 *5)) (-5 *4 (-949 *5)) (-4 *5 (-373)) (-14 *6 (-658 (-1191))) (-5 *2 (-801 (-884 *5))) (-5 *1 (-894 *5 *6 *7)) (-4 *7 (-137)))) (-2589 (*1 *2) (-12 (-5 *2 (-658 (-995 *3))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3969 (*1 *2) (-12 (-5 *2 (-658 (-995 *3))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3166 (*1 *2) (-12 (-5 *2 (-658 (-281 (-561 *3 *4 *5)))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-1488 (*1 *2) (-12 (-5 *2 (-658 (-281 (-561 *3 *4 *5)))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3567 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3918 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3427 (*1 *2) (-12 (-5 *2 (-264 *4 *3)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2463 (*1 *2) (-12 (-5 *2 (-658 (-949 *3))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2671 (*1 *2 *2) (-12 (-5 *2 (-658 (-995 *3))) (-4 *3 (-373)) (-5 *1 (-894 *3 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2117 (*1 *2 *3) (-12 (-5 *3 (-658 (-884 *4))) (-4 *4 (-373)) (-5 *2 (-995 *4)) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-3466 (*1 *2 *3) (-12 (-5 *3 (-995 *4)) (-4 *4 (-373)) (-5 *2 (-658 (-949 *4))) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-3405 (*1 *2 *3) (-12 (-5 *3 (-949 *4)) (-4 *4 (-373)) (-5 *2 (-995 *4)) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2561 (*1 *2 *3 *4) (-12 (-5 *3 (-258 (-949 *5))) (-5 *4 (-658 (-949 *5))) (-4 *5 (-373)) (-5 *2 (-706 *5)) (-5 *1 (-894 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) (-2561 (*1 *2 *3 *3) (-12 (-5 *3 (-258 (-949 *4))) (-4 *4 (-373)) (-5 *2 (-706 *4)) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-4322 (*1 *2 *3 *4) (-12 (-5 *3 (-264 *6 *5)) (-5 *4 (-995 *5)) (-4 *5 (-373)) (-14 *6 (-658 (-1191))) (-5 *2 (-264 *6 (-884 *5))) (-5 *1 (-894 *5 *6 *7)) (-4 *7 (-137)))) (-3822 (*1 *2 *2) (-12 (-5 *2 (-264 *4 *3)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-5 *1 (-894 *3 *4 *5)) (-4 *5 (-137)))) (-3144 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-1474 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3315 (*1 *2 *2 *3) (-12 (-5 *2 (-264 *5 *4)) (-5 *3 (-592)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-5 *1 (-894 *4 *5 *6)) (-4 *6 (-137))))) 
+(-10 -7 (-15 -3315 ((-264 |#2| |#1|) (-264 |#2| |#1|) (-592))) (-15 -1474 ((-1285))) (-15 -3144 ((-1285))) (-15 -3822 ((-264 |#2| |#1|) (-264 |#2| |#1|))) (-15 -4322 ((-264 |#2| (-884 |#1|)) (-264 |#2| |#1|) (-995 |#1|))) (-15 -2561 ((-706 |#1|) (-258 (-949 |#1|)) (-258 (-949 |#1|)))) (-15 -2561 ((-706 |#1|) (-258 (-949 |#1|)) (-658 (-949 |#1|)))) (-15 -3405 ((-995 |#1|) (-949 |#1|))) (-15 -3466 ((-658 (-949 |#1|)) (-995 |#1|))) (-15 -2117 ((-995 |#1|) (-658 (-884 |#1|)))) (-15 -2671 ((-658 (-995 |#1|)) (-658 (-995 |#1|)))) (-15 -2463 ((-658 (-949 |#1|)))) (-15 -3427 ((-264 |#2| |#1|))) (-15 -3918 ((-790))) (-15 -3567 ((-592))) (-15 -1488 ((-658 (-281 (-561 |#1| |#2| |#3|))))) (-15 -3166 ((-658 (-281 (-561 |#1| |#2| |#3|))))) (-15 -3969 ((-658 (-995 |#1|)))) (-15 -2589 ((-658 (-995 |#1|)))) (-15 -1449 ((-801 (-884 |#1|)) (-264 |#2| |#1|) (-949 |#1|))) (-15 -2353 ((-658 (-433 (-264 |#2| |#1|))) (-258 (-949 |#1|)) (-790))) (-15 -2353 ((-2 (|:| |num| (-658 (-264 |#2| |#1|))) (|:| |den| (-264 |#2| |#1|))) (-258 (-949 |#1|)))) (-15 -4389 ((-2 (|:| -2016 (-592)) (|:| |num| (-264 |#2| |#1|)) (|:| |den| (-264 |#2| |#1|)) (|:| |upTo| (-592))) (-258 (-949 |#1|)) (-592) (-592))) (-15 -2225 ((-658 (-264 |#2| (-884 |#1|))) (-258 (-949 |#1|)) (-658 (-264 |#2| |#1|)))) (-15 -4507 ((-658 (-264 |#2| |#1|)) (-258 (-949 |#1|)) (-790))) (-15 -2806 (|#1| (-264 |#2| |#1|) (-949 |#1|))) (-15 -2806 (|#1| (-264 |#2| |#1|) (-264 |#2| |#1|) (-949 |#1|))) (-15 -2806 (|#1| (-433 (-264 |#2| |#1|)) (-949 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-264 |#2| |#1|) (-949 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-264 |#2| |#1|) (-264 |#2| |#1|) (-949 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-433 (-264 |#2| |#1|)) (-949 |#1|))) (-15 -1587 ((-258 (-949 |#1|)) (-264 |#2| |#1|))) (-15 -2269 ((-258 (-949 |#1|)))) (IF (|has| (-884 |#1|) (-394)) (PROGN (-15 -2821 ((-1187 (-592)))) (-15 -2821 ((-1187 (-592)) (-944))) (-15 -2825 ((-592))) (-15 -2742 ((-658 (-949 |#1|)) (-944))) (-15 -4530 ((-592) (-944))) (-15 -1595 ((-592) (-944))) (-15 -4056 ((-592) (-944) (-944))) (-15 -2665 ((-1275 (-592) -4132))) (-15 -2665 ((-1275 (-592) -4132) (-944)))) |noBranch|)) 
+((-3427 (((-264 |#2| |#1|)) 83)) (-2589 (((-658 (-994 |#1|))) 92)) (-2671 (((-658 (-994 |#1|)) (-658 (-994 |#1|))) 24)) (-3822 (((-264 |#2| |#1|) (-264 |#2| |#1|)) 75)) (-3969 (((-658 (-994 |#1|))) 65)) (-2463 (((-658 (-948 |#1|))) 63)) (-2117 (((-994 |#1|) (-658 |#1|)) 27)) (-3405 (((-994 |#1|) (-948 |#1|)) 18)) (-2742 (((-658 (-948 |#1|)) (-944)) 50 (|has| |#1| (-394)))) (-3466 (((-658 (-948 |#1|)) (-994 |#1|)) 21)) (-1449 (((-801 |#1|) (-264 |#2| |#1|) (-948 |#1|)) 95)) (-1595 (((-592) (-944)) 52 (|has| |#1| (-394)))) (-4056 (((-592) (-944) (-944)) 54 (|has| |#1| (-394)))) (-4530 (((-592) (-944)) 48 (|has| |#1| (-394)))) (-2353 (((-2 (|:| |num| (-658 (-264 |#2| |#1|))) (|:| |den| (-264 |#2| |#1|))) (-258 (-948 |#1|))) 33) (((-658 (-433 (-264 |#2| |#1|))) (-258 (-948 |#1|)) (-790)) NIL)) (-1587 (((-258 (-948 |#1|)) (-264 |#2| |#1|)) 107)) (-2225 (((-658 (-264 |#2| |#1|)) (-258 (-948 |#1|)) (-658 (-264 |#2| |#1|))) 31)) (-4507 (((-658 (-264 |#2| |#1|)) (-258 (-948 |#1|)) (-790)) 97)) (-3315 (((-264 |#2| |#1|) (-264 |#2| |#1|) (-592)) 13)) (-2561 (((-706 |#1|) (-258 (-948 |#1|)) (-658 (-948 |#1|))) 38) (((-706 |#1|) (-258 (-948 |#1|)) (-258 (-948 |#1|))) 40)) (-3567 (((-592)) 81)) (-3918 (((-790)) 79)) (-3144 (((-1285)) 116)) (-1474 (((-1285)) 112)) (-4389 (((-2 (|:| -2016 (-592)) (|:| |num| (-264 |#2| |#1|)) (|:| |den| (-264 |#2| |#1|)) (|:| |upTo| (-592))) (-258 (-948 |#1|)) (-592) (-592)) NIL)) (-4474 (((-3 |#1| "failed") (-433 (-264 |#2| |#1|)) (-948 |#1|)) 105) (((-3 |#1| "failed") (-264 |#2| |#1|) (-264 |#2| |#1|) (-948 |#1|)) 104) (((-3 |#1| "failed") (-264 |#2| |#1|) (-948 |#1|)) 73)) (-2806 ((|#1| (-433 (-264 |#2| |#1|)) (-948 |#1|)) 102) ((|#1| (-264 |#2| |#1|) (-264 |#2| |#1|) (-948 |#1|)) 34) ((|#1| (-264 |#2| |#1|) (-948 |#1|)) 70)) (-1488 (((-658 (-281 (-537 |#1| |#2| |#3|)))) 88)) (-3166 (((-658 (-281 (-537 |#1| |#2| |#3|)))) 86)) (-2825 (((-592)) 61 (|has| |#1| (-394)))) (-2269 (((-258 (-948 |#1|))) 90)) (-2665 (((-1275 (-592) -4132) (-944)) 46 (|has| |#1| (-394))) (((-1275 (-592) -4132)) 43 (|has| |#1| (-394)))) (-2821 (((-1187 (-592)) (-944)) 59 (|has| |#1| (-394))) (((-1187 (-592))) 57 (|has| |#1| (-394))))) 
+(((-895 |#1| |#2| |#3|) (-10 -7 (-15 -3315 ((-264 |#2| |#1|) (-264 |#2| |#1|) (-592))) (-15 -2225 ((-658 (-264 |#2| |#1|)) (-258 (-948 |#1|)) (-658 (-264 |#2| |#1|)))) (-15 -1474 ((-1285))) (-15 -3144 ((-1285))) (-15 -3822 ((-264 |#2| |#1|) (-264 |#2| |#1|))) (-15 -2117 ((-994 |#1|) (-658 |#1|))) (-15 -3405 ((-994 |#1|) (-948 |#1|))) (-15 -3466 ((-658 (-948 |#1|)) (-994 |#1|))) (-15 -2671 ((-658 (-994 |#1|)) (-658 (-994 |#1|)))) (-15 -2561 ((-706 |#1|) (-258 (-948 |#1|)) (-258 (-948 |#1|)))) (-15 -2561 ((-706 |#1|) (-258 (-948 |#1|)) (-658 (-948 |#1|)))) (-15 -2463 ((-658 (-948 |#1|)))) (-15 -3427 ((-264 |#2| |#1|))) (-15 -3918 ((-790))) (-15 -3567 ((-592))) (-15 -1488 ((-658 (-281 (-537 |#1| |#2| |#3|))))) (-15 -3166 ((-658 (-281 (-537 |#1| |#2| |#3|))))) (-15 -3969 ((-658 (-994 |#1|)))) (-15 -2589 ((-658 (-994 |#1|)))) (-15 -1449 ((-801 |#1|) (-264 |#2| |#1|) (-948 |#1|))) (-15 -2353 ((-658 (-433 (-264 |#2| |#1|))) (-258 (-948 |#1|)) (-790))) (-15 -2353 ((-2 (|:| |num| (-658 (-264 |#2| |#1|))) (|:| |den| (-264 |#2| |#1|))) (-258 (-948 |#1|)))) (-15 -4389 ((-2 (|:| -2016 (-592)) (|:| |num| (-264 |#2| |#1|)) (|:| |den| (-264 |#2| |#1|)) (|:| |upTo| (-592))) (-258 (-948 |#1|)) (-592) (-592))) (-15 -4507 ((-658 (-264 |#2| |#1|)) (-258 (-948 |#1|)) (-790))) (-15 -2806 (|#1| (-264 |#2| |#1|) (-948 |#1|))) (-15 -2806 (|#1| (-264 |#2| |#1|) (-264 |#2| |#1|) (-948 |#1|))) (-15 -2806 (|#1| (-433 (-264 |#2| |#1|)) (-948 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-264 |#2| |#1|) (-948 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-264 |#2| |#1|) (-264 |#2| |#1|) (-948 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-433 (-264 |#2| |#1|)) (-948 |#1|))) (-15 -1587 ((-258 (-948 |#1|)) (-264 |#2| |#1|))) (-15 -2269 ((-258 (-948 |#1|)))) (IF (|has| |#1| (-394)) (PROGN (-15 -2821 ((-1187 (-592)))) (-15 -2821 ((-1187 (-592)) (-944))) (-15 -2825 ((-592))) (-15 -2742 ((-658 (-948 |#1|)) (-944))) (-15 -4530 ((-592) (-944))) (-15 -1595 ((-592) (-944))) (-15 -4056 ((-592) (-944) (-944))) (-15 -2665 ((-1275 (-592) -4132))) (-15 -2665 ((-1275 (-592) -4132) (-944)))) |noBranch|)) (-388) (-658 (-1191)) (-137)) (T -895)) 
+((-2665 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2665 (*1 *2) (-12 (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-4056 (*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-1595 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-4530 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2742 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-658 (-948 *4))) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2825 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2821 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 (-592))) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2821 (*1 *2) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2269 (*1 *2) (-12 (-5 *2 (-258 (-948 *3))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-1587 (*1 *2 *3) (-12 (-5 *3 (-264 *5 *4)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *2 (-258 (-948 *4))) (-5 *1 (-895 *4 *5 *6)) (-4 *6 (-137)))) (-4474 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-264 *5 *2))) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) (-4474 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-264 *5 *2)) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) (-4474 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-264 *5 *2)) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) (-2806 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-264 *5 *2))) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) (-2806 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-264 *5 *2)) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) (-2806 (*1 *2 *3 *4) (-12 (-5 *3 (-264 *5 *2)) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) (-4507 (*1 *2 *3 *4) (-12 (-5 *3 (-258 (-948 *5))) (-5 *4 (-790)) (-4 *5 (-388)) (-5 *2 (-658 (-264 *6 *5))) (-5 *1 (-895 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) (-4389 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-258 (-948 *5))) (-4 *5 (-388)) (-5 *2 (-2 (|:| -2016 (-592)) (|:| |num| (-264 *6 *5)) (|:| |den| (-264 *6 *5)) (|:| |upTo| (-592)))) (-5 *1 (-895 *5 *6 *7)) (-5 *4 (-592)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) (-2353 (*1 *2 *3) (-12 (-5 *3 (-258 (-948 *4))) (-4 *4 (-388)) (-5 *2 (-2 (|:| |num| (-658 (-264 *5 *4))) (|:| |den| (-264 *5 *4)))) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2353 (*1 *2 *3 *4) (-12 (-5 *3 (-258 (-948 *5))) (-5 *4 (-790)) (-4 *5 (-388)) (-5 *2 (-658 (-433 (-264 *6 *5)))) (-5 *1 (-895 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) (-1449 (*1 *2 *3 *4) (-12 (-5 *3 (-264 *6 *5)) (-5 *4 (-948 *5)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-5 *2 (-801 *5)) (-5 *1 (-895 *5 *6 *7)) (-4 *7 (-137)))) (-2589 (*1 *2) (-12 (-5 *2 (-658 (-994 *3))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3969 (*1 *2) (-12 (-5 *2 (-658 (-994 *3))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3166 (*1 *2) (-12 (-5 *2 (-658 (-281 (-537 *3 *4 *5)))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-1488 (*1 *2) (-12 (-5 *2 (-658 (-281 (-537 *3 *4 *5)))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3567 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3918 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3427 (*1 *2) (-12 (-5 *2 (-264 *4 *3)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2463 (*1 *2) (-12 (-5 *2 (-658 (-948 *3))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2561 (*1 *2 *3 *4) (-12 (-5 *3 (-258 (-948 *5))) (-5 *4 (-658 (-948 *5))) (-4 *5 (-388)) (-5 *2 (-706 *5)) (-5 *1 (-895 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) (-2561 (*1 *2 *3 *3) (-12 (-5 *3 (-258 (-948 *4))) (-4 *4 (-388)) (-5 *2 (-706 *4)) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2671 (*1 *2 *2) (-12 (-5 *2 (-658 (-994 *3))) (-4 *3 (-388)) (-5 *1 (-895 *3 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-3466 (*1 *2 *3) (-12 (-5 *3 (-994 *4)) (-4 *4 (-388)) (-5 *2 (-658 (-948 *4))) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-3405 (*1 *2 *3) (-12 (-5 *3 (-948 *4)) (-4 *4 (-388)) (-5 *2 (-994 *4)) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-2117 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-5 *2 (-994 *4)) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) (-3822 (*1 *2 *2) (-12 (-5 *2 (-264 *4 *3)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-5 *1 (-895 *3 *4 *5)) (-4 *5 (-137)))) (-3144 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-1474 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) (-2225 (*1 *2 *3 *2) (-12 (-5 *2 (-658 (-264 *5 *4))) (-5 *3 (-258 (-948 *4))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *1 (-895 *4 *5 *6)) (-4 *6 (-137)))) (-3315 (*1 *2 *2 *3) (-12 (-5 *2 (-264 *5 *4)) (-5 *3 (-592)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *1 (-895 *4 *5 *6)) (-4 *6 (-137))))) 
+(-10 -7 (-15 -3315 ((-264 |#2| |#1|) (-264 |#2| |#1|) (-592))) (-15 -2225 ((-658 (-264 |#2| |#1|)) (-258 (-948 |#1|)) (-658 (-264 |#2| |#1|)))) (-15 -1474 ((-1285))) (-15 -3144 ((-1285))) (-15 -3822 ((-264 |#2| |#1|) (-264 |#2| |#1|))) (-15 -2117 ((-994 |#1|) (-658 |#1|))) (-15 -3405 ((-994 |#1|) (-948 |#1|))) (-15 -3466 ((-658 (-948 |#1|)) (-994 |#1|))) (-15 -2671 ((-658 (-994 |#1|)) (-658 (-994 |#1|)))) (-15 -2561 ((-706 |#1|) (-258 (-948 |#1|)) (-258 (-948 |#1|)))) (-15 -2561 ((-706 |#1|) (-258 (-948 |#1|)) (-658 (-948 |#1|)))) (-15 -2463 ((-658 (-948 |#1|)))) (-15 -3427 ((-264 |#2| |#1|))) (-15 -3918 ((-790))) (-15 -3567 ((-592))) (-15 -1488 ((-658 (-281 (-537 |#1| |#2| |#3|))))) (-15 -3166 ((-658 (-281 (-537 |#1| |#2| |#3|))))) (-15 -3969 ((-658 (-994 |#1|)))) (-15 -2589 ((-658 (-994 |#1|)))) (-15 -1449 ((-801 |#1|) (-264 |#2| |#1|) (-948 |#1|))) (-15 -2353 ((-658 (-433 (-264 |#2| |#1|))) (-258 (-948 |#1|)) (-790))) (-15 -2353 ((-2 (|:| |num| (-658 (-264 |#2| |#1|))) (|:| |den| (-264 |#2| |#1|))) (-258 (-948 |#1|)))) (-15 -4389 ((-2 (|:| -2016 (-592)) (|:| |num| (-264 |#2| |#1|)) (|:| |den| (-264 |#2| |#1|)) (|:| |upTo| (-592))) (-258 (-948 |#1|)) (-592) (-592))) (-15 -4507 ((-658 (-264 |#2| |#1|)) (-258 (-948 |#1|)) (-790))) (-15 -2806 (|#1| (-264 |#2| |#1|) (-948 |#1|))) (-15 -2806 (|#1| (-264 |#2| |#1|) (-264 |#2| |#1|) (-948 |#1|))) (-15 -2806 (|#1| (-433 (-264 |#2| |#1|)) (-948 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-264 |#2| |#1|) (-948 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-264 |#2| |#1|) (-264 |#2| |#1|) (-948 |#1|))) (-15 -4474 ((-3 |#1| "failed") (-433 (-264 |#2| |#1|)) (-948 |#1|))) (-15 -1587 ((-258 (-948 |#1|)) (-264 |#2| |#1|))) (-15 -2269 ((-258 (-948 |#1|)))) (IF (|has| |#1| (-394)) (PROGN (-15 -2821 ((-1187 (-592)))) (-15 -2821 ((-1187 (-592)) (-944))) (-15 -2825 ((-592))) (-15 -2742 ((-658 (-948 |#1|)) (-944))) (-15 -4530 ((-592) (-944))) (-15 -1595 ((-592) (-944))) (-15 -4056 ((-592) (-944) (-944))) (-15 -2665 ((-1275 (-592) -4132))) (-15 -2665 ((-1275 (-592) -4132) (-944)))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-3150 (((-592) $) 15)) (-2003 (($ (-179)) 11)) (-3007 (($ (-179)) 12)) (-2685 (((-1173) $) NIL)) (-3850 (((-179) $) 13)) (-2951 (((-1137) $) NIL)) (-3832 (($ (-179)) 9)) (-3827 (($ (-179)) 8)) (-1683 (((-877) $) 23) (($ (-179)) 16)) (-3074 (($ (-179)) 10)) (-3255 (((-141) $ $) NIL))) 
+(((-896) (-13 (-1119) (-10 -8 (-15 -3827 ($ (-179))) (-15 -3832 ($ (-179))) (-15 -3074 ($ (-179))) (-15 -2003 ($ (-179))) (-15 -3007 ($ (-179))) (-15 -3850 ((-179) $)) (-15 -3150 ((-592) $)) (-15 -1683 ($ (-179)))))) (T -896)) 
+((-3827 (*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896)))) (-3832 (*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896)))) (-3074 (*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896)))) (-2003 (*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896)))) (-3007 (*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896)))) (-3850 (*1 *2 *1) (-12 (-5 *2 (-179)) (-5 *1 (-896)))) (-3150 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-896)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896))))) 
+(-13 (-1119) (-10 -8 (-15 -3827 ($ (-179))) (-15 -3832 ($ (-179))) (-15 -3074 ($ (-179))) (-15 -2003 ($ (-179))) (-15 -3007 ($ (-179))) (-15 -3850 ((-179) $)) (-15 -3150 ((-592) $)) (-15 -1683 ($ (-179))))) 
+((-1683 (((-332 (-592)) (-433 (-980 (-53)))) 21) (((-332 (-592)) (-980 (-53))) 16))) 
+(((-897) (-10 -7 (-15 -1683 ((-332 (-592)) (-980 (-53)))) (-15 -1683 ((-332 (-592)) (-433 (-980 (-53))))))) (T -897)) 
+((-1683 (*1 *2 *3) (-12 (-5 *3 (-433 (-980 (-53)))) (-5 *2 (-332 (-592))) (-5 *1 (-897)))) (-1683 (*1 *2 *3) (-12 (-5 *3 (-980 (-53))) (-5 *2 (-332 (-592))) (-5 *1 (-897))))) 
+(-10 -7 (-15 -1683 ((-332 (-592)) (-980 (-53)))) (-15 -1683 ((-332 (-592)) (-433 (-980 (-53)))))) 
+((-1449 ((|#6| |#3| |#7| (-592)) 36) ((|#6| |#3| |#3| |#7|) 33) ((|#6| |#3| |#7|) 31) ((|#6| |#3| (-658 |#6|)) 28))) 
+(((-898 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -1449 (|#6| |#3| (-658 |#6|))) (-15 -1449 (|#6| |#3| |#7|)) (-15 -1449 (|#6| |#3| |#3| |#7|)) (-15 -1449 (|#6| |#3| |#7| (-592)))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|) (-665 |#1|) (-947 |#1| |#6|)) (T -898)) 
+((-1449 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-592)) (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *2 (-665 *6)) (-5 *1 (-898 *6 *7 *3 *8 *9 *2 *4)) (-4 *3 (-977 *6 *8 (-879 *7))) (-4 *9 (-999 *6)) (-4 *4 (-947 *6 *2)))) (-1449 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *2 (-665 *5)) (-5 *1 (-898 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)) (-4 *4 (-947 *5 *2)))) (-1449 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *2 (-665 *5)) (-5 *1 (-898 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)) (-4 *4 (-947 *5 *2)))) (-1449 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *2)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *2 (-665 *5)) (-5 *1 (-898 *5 *6 *3 *7 *8 *2 *9)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)) (-4 *9 (-947 *5 *2))))) 
+(-10 -7 (-15 -1449 (|#6| |#3| (-658 |#6|))) (-15 -1449 (|#6| |#3| |#7|)) (-15 -1449 (|#6| |#3| |#3| |#7|)) (-15 -1449 (|#6| |#3| |#7| (-592)))) 
+((-2731 (((-900 |#2|) (-1 |#2| |#1|) (-900 |#1|)) 14))) 
+(((-899 |#1| |#2|) (-10 -7 (-15 -2731 ((-900 |#2|) (-1 |#2| |#1|) (-900 |#1|)))) (-1225) (-1225)) (T -899)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-900 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-900 *6)) (-5 *1 (-899 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-900 |#2|) (-1 |#2| |#1|) (-900 |#1|)))) 
+((-2354 (($ |#1| |#1|) 8)) (-1365 ((|#1| $ (-790)) 10))) 
+(((-900 |#1|) (-10 -8 (-15 -2354 ($ |#1| |#1|)) (-15 -1365 (|#1| $ (-790)))) (-1225)) (T -900)) 
+((-1365 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *1 (-900 *2)) (-4 *2 (-1225)))) (-2354 (*1 *1 *2 *2) (-12 (-5 *1 (-900 *2)) (-4 *2 (-1225))))) 
+(-10 -8 (-15 -2354 ($ |#1| |#1|)) (-15 -1365 (|#1| $ (-790)))) 
+((-2731 (((-902 |#2|) (-1 |#2| |#1|) (-902 |#1|)) 14))) 
+(((-901 |#1| |#2|) (-10 -7 (-15 -2731 ((-902 |#2|) (-1 |#2| |#1|) (-902 |#1|)))) (-1225) (-1225)) (T -901)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-902 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-902 *6)) (-5 *1 (-901 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-902 |#2|) (-1 |#2| |#1|) (-902 |#1|)))) 
+((-2354 (($ |#1| |#1| |#1|) 8)) (-1365 ((|#1| $ (-790)) 10))) 
+(((-902 |#1|) (-10 -8 (-15 -2354 ($ |#1| |#1| |#1|)) (-15 -1365 (|#1| $ (-790)))) (-1225)) (T -902)) 
+((-1365 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *1 (-902 *2)) (-4 *2 (-1225)))) (-2354 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-902 *2)) (-4 *2 (-1225))))) 
+(-10 -8 (-15 -2354 ($ |#1| |#1| |#1|)) (-15 -1365 (|#1| $ (-790)))) 
+((-2731 (((-904 |#2|) (-1 |#2| |#1|) (-904 |#1|)) 14))) 
+(((-903 |#1| |#2|) (-10 -7 (-15 -2731 ((-904 |#2|) (-1 |#2| |#1|) (-904 |#1|)))) (-1225) (-1225)) (T -903)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-904 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-904 *6)) (-5 *1 (-903 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-904 |#2|) (-1 |#2| |#1|) (-904 |#1|)))) 
+((-1374 (($ |#1| |#1| |#1|) 8)) (-1365 ((|#1| $ (-790)) 10))) 
+(((-904 |#1|) (-10 -8 (-15 -1374 ($ |#1| |#1| |#1|)) (-15 -1365 (|#1| $ (-790)))) (-1225)) (T -904)) 
+((-1365 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *1 (-904 *2)) (-4 *2 (-1225)))) (-1374 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-904 *2)) (-4 *2 (-1225))))) 
+(-10 -8 (-15 -1374 ($ |#1| |#1| |#1|)) (-15 -1365 (|#1| $ (-790)))) 
+((-3723 (((-1171 (-658 (-592))) (-658 (-592)) (-1171 (-658 (-592)))) 30)) (-1338 (((-1171 (-658 (-592))) (-658 (-592)) (-658 (-592))) 26)) (-1352 (((-1171 (-658 (-592))) (-658 (-592))) 39) (((-1171 (-658 (-592))) (-658 (-592)) (-658 (-592))) 38)) (-3048 (((-1171 (-658 (-592))) (-592)) 40)) (-2541 (((-1171 (-658 (-592))) (-592) (-592)) 22) (((-1171 (-658 (-592))) (-592)) 16) (((-1171 (-658 (-592))) (-592) (-592) (-592)) 12)) (-3290 (((-1171 (-658 (-592))) (-1171 (-658 (-592)))) 24)) (-2227 (((-658 (-592)) (-658 (-592))) 23))) 
+(((-905) (-10 -7 (-15 -2541 ((-1171 (-658 (-592))) (-592) (-592) (-592))) (-15 -2541 ((-1171 (-658 (-592))) (-592))) (-15 -2541 ((-1171 (-658 (-592))) (-592) (-592))) (-15 -2227 ((-658 (-592)) (-658 (-592)))) (-15 -3290 ((-1171 (-658 (-592))) (-1171 (-658 (-592))))) (-15 -1338 ((-1171 (-658 (-592))) (-658 (-592)) (-658 (-592)))) (-15 -3723 ((-1171 (-658 (-592))) (-658 (-592)) (-1171 (-658 (-592))))) (-15 -1352 ((-1171 (-658 (-592))) (-658 (-592)) (-658 (-592)))) (-15 -1352 ((-1171 (-658 (-592))) (-658 (-592)))) (-15 -3048 ((-1171 (-658 (-592))) (-592))))) (T -905)) 
+((-3048 (*1 *2 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-592)))) (-1352 (*1 *2 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-658 (-592))))) (-1352 (*1 *2 *3 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-658 (-592))))) (-3723 (*1 *2 *3 *2) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *3 (-658 (-592))) (-5 *1 (-905)))) (-1338 (*1 *2 *3 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-658 (-592))))) (-3290 (*1 *2 *2) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)))) (-2227 (*1 *2 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-905)))) (-2541 (*1 *2 *3 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-592)))) (-2541 (*1 *2 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-592)))) (-2541 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-592))))) 
+(-10 -7 (-15 -2541 ((-1171 (-658 (-592))) (-592) (-592) (-592))) (-15 -2541 ((-1171 (-658 (-592))) (-592))) (-15 -2541 ((-1171 (-658 (-592))) (-592) (-592))) (-15 -2227 ((-658 (-592)) (-658 (-592)))) (-15 -3290 ((-1171 (-658 (-592))) (-1171 (-658 (-592))))) (-15 -1338 ((-1171 (-658 (-592))) (-658 (-592)) (-658 (-592)))) (-15 -3723 ((-1171 (-658 (-592))) (-658 (-592)) (-1171 (-658 (-592))))) (-15 -1352 ((-1171 (-658 (-592))) (-658 (-592)) (-658 (-592)))) (-15 -1352 ((-1171 (-658 (-592))) (-658 (-592)))) (-15 -3048 ((-1171 (-658 (-592))) (-592)))) 
+((-1778 (((-914 (-405)) $) 9 (|has| |#1| (-633 (-914 (-405))))) (((-914 (-592)) $) 8 (|has| |#1| (-633 (-914 (-592))))))) 
+(((-906 |#1|) (-1311) (-1225)) (T -906)) 
+NIL 
+(-13 (-10 -7 (IF (|has| |t#1| (-633 (-914 (-592)))) (-6 (-633 (-914 (-592)))) |noBranch|) (IF (|has| |t#1| (-633 (-914 (-405)))) (-6 (-633 (-914 (-405)))) |noBranch|))) 
+(((-633 (-914 (-405))) |has| |#1| (-633 (-914 (-405)))) ((-633 (-914 (-592))) |has| |#1| (-633 (-914 (-592))))) 
+((-1641 (((-141) $ $) NIL)) (-3242 (($) 14)) (-2758 (($ (-911 |#1| |#2|) (-911 |#1| |#3|)) 27)) (-1668 (((-911 |#1| |#3|) $) 16)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4098 (((-141) $) 22)) (-3550 (($) 19)) (-1683 (((-877) $) 30)) (-3094 (((-911 |#1| |#2|) $) 15)) (-3255 (((-141) $ $) 25))) 
+(((-907 |#1| |#2| |#3|) (-13 (-1119) (-10 -8 (-15 -4098 ((-141) $)) (-15 -3550 ($)) (-15 -3242 ($)) (-15 -2758 ($ (-911 |#1| |#2|) (-911 |#1| |#3|))) (-15 -3094 ((-911 |#1| |#2|) $)) (-15 -1668 ((-911 |#1| |#3|) $)))) (-1119) (-1119) (-683 |#2|)) (T -907)) 
+((-4098 (*1 *2 *1) (-12 (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-907 *3 *4 *5)) (-4 *3 (-1119)) (-4 *5 (-683 *4)))) (-3550 (*1 *1) (-12 (-4 *3 (-1119)) (-5 *1 (-907 *2 *3 *4)) (-4 *2 (-1119)) (-4 *4 (-683 *3)))) (-3242 (*1 *1) (-12 (-4 *3 (-1119)) (-5 *1 (-907 *2 *3 *4)) (-4 *2 (-1119)) (-4 *4 (-683 *3)))) (-2758 (*1 *1 *2 *3) (-12 (-5 *2 (-911 *4 *5)) (-5 *3 (-911 *4 *6)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-683 *5)) (-5 *1 (-907 *4 *5 *6)))) (-3094 (*1 *2 *1) (-12 (-4 *4 (-1119)) (-5 *2 (-911 *3 *4)) (-5 *1 (-907 *3 *4 *5)) (-4 *3 (-1119)) (-4 *5 (-683 *4)))) (-1668 (*1 *2 *1) (-12 (-4 *4 (-1119)) (-5 *2 (-911 *3 *5)) (-5 *1 (-907 *3 *4 *5)) (-4 *3 (-1119)) (-4 *5 (-683 *4))))) 
+(-13 (-1119) (-10 -8 (-15 -4098 ((-141) $)) (-15 -3550 ($)) (-15 -3242 ($)) (-15 -2758 ($ (-911 |#1| |#2|) (-911 |#1| |#3|))) (-15 -3094 ((-911 |#1| |#2|) $)) (-15 -1668 ((-911 |#1| |#3|) $)))) 
+((-1641 (((-141) $ $) 7)) (-3412 (((-911 |#1| $) $ (-914 |#1|) (-911 |#1| $)) 12)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-908 |#1|) (-1311) (-1119)) (T -908)) 
+((-3412 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-911 *4 *1)) (-5 *3 (-914 *4)) (-4 *1 (-908 *4)) (-4 *4 (-1119))))) 
+(-13 (-1119) (-10 -8 (-15 -3412 ((-911 |t#1| $) $ (-914 |t#1|) (-911 |t#1| $))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-3013 (((-141) (-658 |#2|) |#3|) 22) (((-141) |#2| |#3|) 17)) (-3772 (((-911 |#1| |#2|) |#2| |#3|) 42 (-12 (-3252 (|has| |#2| (-1065 (-1191)))) (-3252 (|has| |#2| (-1075))))) (((-658 (-310 (-980 |#2|))) |#2| |#3|) 41 (-12 (|has| |#2| (-1075)) (-3252 (|has| |#2| (-1065 (-1191)))))) (((-658 (-310 |#2|)) |#2| |#3|) 34 (|has| |#2| (-1065 (-1191)))) (((-907 |#1| |#2| (-658 |#2|)) (-658 |#2|) |#3|) 20))) 
+(((-909 |#1| |#2| |#3|) (-10 -7 (-15 -3013 ((-141) |#2| |#3|)) (-15 -3013 ((-141) (-658 |#2|) |#3|)) (-15 -3772 ((-907 |#1| |#2| (-658 |#2|)) (-658 |#2|) |#3|)) (IF (|has| |#2| (-1065 (-1191))) (-15 -3772 ((-658 (-310 |#2|)) |#2| |#3|)) (IF (|has| |#2| (-1075)) (-15 -3772 ((-658 (-310 (-980 |#2|))) |#2| |#3|)) (-15 -3772 ((-911 |#1| |#2|) |#2| |#3|))))) (-1119) (-908 |#1|) (-633 (-914 |#1|))) (T -909)) 
+((-3772 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-5 *2 (-911 *5 *3)) (-5 *1 (-909 *5 *3 *4)) (-3252 (-4 *3 (-1065 (-1191)))) (-3252 (-4 *3 (-1075))) (-4 *3 (-908 *5)) (-4 *4 (-633 (-914 *5))))) (-3772 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-5 *2 (-658 (-310 (-980 *3)))) (-5 *1 (-909 *5 *3 *4)) (-4 *3 (-1075)) (-3252 (-4 *3 (-1065 (-1191)))) (-4 *3 (-908 *5)) (-4 *4 (-633 (-914 *5))))) (-3772 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-5 *2 (-658 (-310 *3))) (-5 *1 (-909 *5 *3 *4)) (-4 *3 (-1065 (-1191))) (-4 *3 (-908 *5)) (-4 *4 (-633 (-914 *5))))) (-3772 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *6 (-908 *5)) (-5 *2 (-907 *5 *6 (-658 *6))) (-5 *1 (-909 *5 *6 *4)) (-5 *3 (-658 *6)) (-4 *4 (-633 (-914 *5))))) (-3013 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-4 *6 (-908 *5)) (-4 *5 (-1119)) (-5 *2 (-141)) (-5 *1 (-909 *5 *6 *4)) (-4 *4 (-633 (-914 *5))))) (-3013 (*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-5 *2 (-141)) (-5 *1 (-909 *5 *3 *4)) (-4 *3 (-908 *5)) (-4 *4 (-633 (-914 *5)))))) 
+(-10 -7 (-15 -3013 ((-141) |#2| |#3|)) (-15 -3013 ((-141) (-658 |#2|) |#3|)) (-15 -3772 ((-907 |#1| |#2| (-658 |#2|)) (-658 |#2|) |#3|)) (IF (|has| |#2| (-1065 (-1191))) (-15 -3772 ((-658 (-310 |#2|)) |#2| |#3|)) (IF (|has| |#2| (-1075)) (-15 -3772 ((-658 (-310 (-980 |#2|))) |#2| |#3|)) (-15 -3772 ((-911 |#1| |#2|) |#2| |#3|))))) 
+((-2731 (((-911 |#1| |#3|) (-1 |#3| |#2|) (-911 |#1| |#2|)) 21))) 
+(((-910 |#1| |#2| |#3|) (-10 -7 (-15 -2731 ((-911 |#1| |#3|) (-1 |#3| |#2|) (-911 |#1| |#2|)))) (-1119) (-1119) (-1119)) (T -910)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-911 *5 *6)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-911 *5 *7)) (-5 *1 (-910 *5 *6 *7))))) 
+(-10 -7 (-15 -2731 ((-911 |#1| |#3|) (-1 |#3| |#2|) (-911 |#1| |#2|)))) 
+((-1641 (((-141) $ $) NIL)) (-4528 (($ $ $) 37)) (-2081 (((-3 (-141) "failed") $ (-914 |#1|)) 34)) (-3242 (($) 11)) (-2685 (((-1173) $) NIL)) (-3102 (($ (-914 |#1|) |#2| $) 20)) (-2951 (((-1137) $) NIL)) (-2875 (((-3 |#2| "failed") (-914 |#1|) $) 48)) (-4098 (((-141) $) 14)) (-3550 (($) 12)) (-4518 (((-658 (-2 (|:| -1350 (-1191)) (|:| -3552 |#2|))) $) 25)) (-4466 (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 |#2|)))) 23)) (-1683 (((-877) $) 42)) (-4231 (($ (-914 |#1|) |#2| $ |#2|) 46)) (-2087 (($ (-914 |#1|) |#2| $) 45)) (-3255 (((-141) $ $) 39))) 
+(((-911 |#1| |#2|) (-13 (-1119) (-10 -8 (-15 -4098 ((-141) $)) (-15 -3550 ($)) (-15 -3242 ($)) (-15 -4528 ($ $ $)) (-15 -2875 ((-3 |#2| "failed") (-914 |#1|) $)) (-15 -2087 ($ (-914 |#1|) |#2| $)) (-15 -3102 ($ (-914 |#1|) |#2| $)) (-15 -4231 ($ (-914 |#1|) |#2| $ |#2|)) (-15 -4518 ((-658 (-2 (|:| -1350 (-1191)) (|:| -3552 |#2|))) $)) (-15 -4466 ($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 |#2|))))) (-15 -2081 ((-3 (-141) "failed") $ (-914 |#1|))))) (-1119) (-1119)) (T -911)) 
+((-4098 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-911 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-3550 (*1 *1) (-12 (-5 *1 (-911 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) (-3242 (*1 *1) (-12 (-5 *1 (-911 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) (-4528 (*1 *1 *1 *1) (-12 (-5 *1 (-911 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) (-2875 (*1 *2 *3 *1) (|partial| -12 (-5 *3 (-914 *4)) (-4 *4 (-1119)) (-4 *2 (-1119)) (-5 *1 (-911 *4 *2)))) (-2087 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-914 *4)) (-4 *4 (-1119)) (-5 *1 (-911 *4 *3)) (-4 *3 (-1119)))) (-3102 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-914 *4)) (-4 *4 (-1119)) (-5 *1 (-911 *4 *3)) (-4 *3 (-1119)))) (-4231 (*1 *1 *2 *3 *1 *3) (-12 (-5 *2 (-914 *4)) (-4 *4 (-1119)) (-5 *1 (-911 *4 *3)) (-4 *3 (-1119)))) (-4518 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 *4)))) (-5 *1 (-911 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-4466 (*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 *4)))) (-4 *4 (-1119)) (-5 *1 (-911 *3 *4)) (-4 *3 (-1119)))) (-2081 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-914 *4)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-911 *4 *5)) (-4 *5 (-1119))))) 
+(-13 (-1119) (-10 -8 (-15 -4098 ((-141) $)) (-15 -3550 ($)) (-15 -3242 ($)) (-15 -4528 ($ $ $)) (-15 -2875 ((-3 |#2| "failed") (-914 |#1|) $)) (-15 -2087 ($ (-914 |#1|) |#2| $)) (-15 -3102 ($ (-914 |#1|) |#2| $)) (-15 -4231 ($ (-914 |#1|) |#2| $ |#2|)) (-15 -4518 ((-658 (-2 (|:| -1350 (-1191)) (|:| -3552 |#2|))) $)) (-15 -4466 ($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 |#2|))))) (-15 -2081 ((-3 (-141) "failed") $ (-914 |#1|))))) 
+((-4355 (((-914 |#1|) (-914 |#1|) (-658 (-1191)) (-1 (-141) (-658 |#2|))) 30) (((-914 |#1|) (-914 |#1|) (-658 (-1 (-141) |#2|))) 42) (((-914 |#1|) (-914 |#1|) (-1 (-141) |#2|)) 33)) (-2081 (((-141) (-658 |#2|) (-914 |#1|)) 39) (((-141) |#2| (-914 |#1|)) 35)) (-3499 (((-1 (-141) |#2|) (-914 |#1|)) 14)) (-2341 (((-658 |#2|) (-914 |#1|)) 23)) (-2518 (((-914 |#1|) (-914 |#1|) |#2|) 19))) 
+(((-912 |#1| |#2|) (-10 -7 (-15 -4355 ((-914 |#1|) (-914 |#1|) (-1 (-141) |#2|))) (-15 -4355 ((-914 |#1|) (-914 |#1|) (-658 (-1 (-141) |#2|)))) (-15 -4355 ((-914 |#1|) (-914 |#1|) (-658 (-1191)) (-1 (-141) (-658 |#2|)))) (-15 -3499 ((-1 (-141) |#2|) (-914 |#1|))) (-15 -2081 ((-141) |#2| (-914 |#1|))) (-15 -2081 ((-141) (-658 |#2|) (-914 |#1|))) (-15 -2518 ((-914 |#1|) (-914 |#1|) |#2|)) (-15 -2341 ((-658 |#2|) (-914 |#1|)))) (-1119) (-1225)) (T -912)) 
+((-2341 (*1 *2 *3) (-12 (-5 *3 (-914 *4)) (-4 *4 (-1119)) (-5 *2 (-658 *5)) (-5 *1 (-912 *4 *5)) (-4 *5 (-1225)))) (-2518 (*1 *2 *2 *3) (-12 (-5 *2 (-914 *4)) (-4 *4 (-1119)) (-5 *1 (-912 *4 *3)) (-4 *3 (-1225)))) (-2081 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *6 (-1225)) (-5 *2 (-141)) (-5 *1 (-912 *5 *6)))) (-2081 (*1 *2 *3 *4) (-12 (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-5 *2 (-141)) (-5 *1 (-912 *5 *3)) (-4 *3 (-1225)))) (-3499 (*1 *2 *3) (-12 (-5 *3 (-914 *4)) (-4 *4 (-1119)) (-5 *2 (-1 (-141) *5)) (-5 *1 (-912 *4 *5)) (-4 *5 (-1225)))) (-4355 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-914 *5)) (-5 *3 (-658 (-1191))) (-5 *4 (-1 (-141) (-658 *6))) (-4 *5 (-1119)) (-4 *6 (-1225)) (-5 *1 (-912 *5 *6)))) (-4355 (*1 *2 *2 *3) (-12 (-5 *2 (-914 *4)) (-5 *3 (-658 (-1 (-141) *5))) (-4 *4 (-1119)) (-4 *5 (-1225)) (-5 *1 (-912 *4 *5)))) (-4355 (*1 *2 *2 *3) (-12 (-5 *2 (-914 *4)) (-5 *3 (-1 (-141) *5)) (-4 *4 (-1119)) (-4 *5 (-1225)) (-5 *1 (-912 *4 *5))))) 
+(-10 -7 (-15 -4355 ((-914 |#1|) (-914 |#1|) (-1 (-141) |#2|))) (-15 -4355 ((-914 |#1|) (-914 |#1|) (-658 (-1 (-141) |#2|)))) (-15 -4355 ((-914 |#1|) (-914 |#1|) (-658 (-1191)) (-1 (-141) (-658 |#2|)))) (-15 -3499 ((-1 (-141) |#2|) (-914 |#1|))) (-15 -2081 ((-141) |#2| (-914 |#1|))) (-15 -2081 ((-141) (-658 |#2|) (-914 |#1|))) (-15 -2518 ((-914 |#1|) (-914 |#1|) |#2|)) (-15 -2341 ((-658 |#2|) (-914 |#1|)))) 
+((-2731 (((-914 |#2|) (-1 |#2| |#1|) (-914 |#1|)) 17))) 
+(((-913 |#1| |#2|) (-10 -7 (-15 -2731 ((-914 |#2|) (-1 |#2| |#1|) (-914 |#1|)))) (-1119) (-1119)) (T -913)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-914 *6)) (-5 *1 (-913 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-914 |#2|) (-1 |#2| |#1|) (-914 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2705 (($ $ (-658 (-57))) 62)) (-4085 (((-658 $) $) 116)) (-1687 (((-2 (|:| |var| (-658 (-1191))) (|:| |pred| (-57))) $) 22)) (-4188 (((-141) $) 29)) (-1717 (($ $ (-658 (-1191)) (-57)) 24)) (-3226 (($ $ (-658 (-57))) 61)) (-4368 (((-3 |#1| "failed") $) 59) (((-3 (-1191) "failed") $) 138)) (-2400 ((|#1| $) 55) (((-1191) $) NIL)) (-1982 (($ $) 106)) (-3381 (((-141) $) 45)) (-1681 (((-658 (-57)) $) 43)) (-1916 (($ (-1191) (-141) (-141) (-141)) 63)) (-3022 (((-3 (-658 $) "failed") (-658 $)) 70)) (-1604 (((-141) $) 48)) (-4402 (((-141) $) 47)) (-2685 (((-1173) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) 34)) (-1688 (((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $) 41)) (-2427 (((-3 (-2 (|:| |val| $) (|:| -3215 $)) "failed") $) 81)) (-2947 (((-3 (-658 $) "failed") $) 31)) (-2624 (((-3 (-658 $) "failed") $ (-143)) 105) (((-3 (-2 (|:| -1608 (-143)) (|:| |arg| (-658 $))) "failed") $) 93)) (-3813 (((-3 (-658 $) "failed") $) 35)) (-2257 (((-3 (-2 (|:| |val| $) (|:| -3215 (-790))) "failed") $) 38)) (-1773 (((-141) $) 28)) (-2951 (((-1137) $) NIL)) (-1361 (((-141) $) 20)) (-2368 (((-141) $) 44)) (-2367 (((-658 (-57)) $) 109)) (-2363 (((-141) $) 46)) (-3927 (($ (-143) (-658 $)) 90)) (-3439 (((-790) $) 27)) (-4599 (($ $) 60)) (-1778 (($ (-658 $)) 57)) (-2752 (((-141) $) 25)) (-1683 (((-877) $) 50) (($ |#1|) 18) (($ (-1191)) 64)) (-2518 (($ $ (-57)) 108)) (-3514 (($) 89 T CONST)) (-4257 (($) 71 T CONST)) (-3255 (((-141) $ $) 77)) (-3313 (($ $ $) 98)) (-3300 (($ $ $) 102)) (** (($ $ (-790)) 97) (($ $ $) 51)) (* (($ $ $) 103))) 
+(((-914 |#1|) (-13 (-1119) (-1065 |#1|) (-1065 (-1191)) (-10 -8 (-15 0 ($) -4249) (-15 1 ($) -4249) (-15 -2947 ((-3 (-658 $) "failed") $)) (-15 -4421 ((-3 (-658 $) "failed") $)) (-15 -2624 ((-3 (-658 $) "failed") $ (-143))) (-15 -2624 ((-3 (-2 (|:| -1608 (-143)) (|:| |arg| (-658 $))) "failed") $)) (-15 -2257 ((-3 (-2 (|:| |val| $) (|:| -3215 (-790))) "failed") $)) (-15 -1688 ((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $)) (-15 -3813 ((-3 (-658 $) "failed") $)) (-15 -2427 ((-3 (-2 (|:| |val| $) (|:| -3215 $)) "failed") $)) (-15 -3927 ($ (-143) (-658 $))) (-15 -3300 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-790))) (-15 ** ($ $ $)) (-15 -3313 ($ $ $)) (-15 -3439 ((-790) $)) (-15 -1778 ($ (-658 $))) (-15 -4599 ($ $)) (-15 -1773 ((-141) $)) (-15 -3381 ((-141) $)) (-15 -4188 ((-141) $)) (-15 -2752 ((-141) $)) (-15 -2363 ((-141) $)) (-15 -4402 ((-141) $)) (-15 -1604 ((-141) $)) (-15 -2368 ((-141) $)) (-15 -1681 ((-658 (-57)) $)) (-15 -3226 ($ $ (-658 (-57)))) (-15 -2705 ($ $ (-658 (-57)))) (-15 -1916 ($ (-1191) (-141) (-141) (-141))) (-15 -1717 ($ $ (-658 (-1191)) (-57))) (-15 -1687 ((-2 (|:| |var| (-658 (-1191))) (|:| |pred| (-57))) $)) (-15 -1361 ((-141) $)) (-15 -1982 ($ $)) (-15 -2518 ($ $ (-57))) (-15 -2367 ((-658 (-57)) $)) (-15 -4085 ((-658 $) $)) (-15 -3022 ((-3 (-658 $) "failed") (-658 $))))) (-1119)) (T -914)) 
+((-3514 (*1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) (-4257 (*1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) (-2947 (*1 *2 *1) (|partial| -12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-4421 (*1 *2 *1) (|partial| -12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-2624 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-143)) (-5 *2 (-658 (-914 *4))) (-5 *1 (-914 *4)) (-4 *4 (-1119)))) (-2624 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| -1608 (-143)) (|:| |arg| (-658 (-914 *3))))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-2257 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-914 *3)) (|:| -3215 (-790)))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-1688 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |num| (-914 *3)) (|:| |den| (-914 *3)))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-3813 (*1 *2 *1) (|partial| -12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-2427 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-914 *3)) (|:| -3215 (-914 *3)))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-3927 (*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-658 (-914 *4))) (-5 *1 (-914 *4)) (-4 *4 (-1119)))) (-3300 (*1 *1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (** (*1 *1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) (-3313 (*1 *1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) (-3439 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-4599 (*1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) (-1773 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-3381 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-4188 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-2752 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-2363 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-4402 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-1604 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-2368 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-1681 (*1 *2 *1) (-12 (-5 *2 (-658 (-57))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-3226 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-57))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-2705 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-57))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-1916 (*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-141)) (-5 *1 (-914 *4)) (-4 *4 (-1119)))) (-1717 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-57)) (-5 *1 (-914 *4)) (-4 *4 (-1119)))) (-1687 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |var| (-658 (-1191))) (|:| |pred| (-57)))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-1361 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-1982 (*1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) (-2518 (*1 *1 *1 *2) (-12 (-5 *2 (-57)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-2367 (*1 *2 *1) (-12 (-5 *2 (-658 (-57))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-4085 (*1 *2 *1) (-12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) (-3022 (*1 *2 *2) (|partial| -12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(-13 (-1119) (-1065 |#1|) (-1065 (-1191)) (-10 -8 (-15 (-3514) ($) -4249) (-15 (-4257) ($) -4249) (-15 -2947 ((-3 (-658 $) "failed") $)) (-15 -4421 ((-3 (-658 $) "failed") $)) (-15 -2624 ((-3 (-658 $) "failed") $ (-143))) (-15 -2624 ((-3 (-2 (|:| -1608 (-143)) (|:| |arg| (-658 $))) "failed") $)) (-15 -2257 ((-3 (-2 (|:| |val| $) (|:| -3215 (-790))) "failed") $)) (-15 -1688 ((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $)) (-15 -3813 ((-3 (-658 $) "failed") $)) (-15 -2427 ((-3 (-2 (|:| |val| $) (|:| -3215 $)) "failed") $)) (-15 -3927 ($ (-143) (-658 $))) (-15 -3300 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-790))) (-15 ** ($ $ $)) (-15 -3313 ($ $ $)) (-15 -3439 ((-790) $)) (-15 -1778 ($ (-658 $))) (-15 -4599 ($ $)) (-15 -1773 ((-141) $)) (-15 -3381 ((-141) $)) (-15 -4188 ((-141) $)) (-15 -2752 ((-141) $)) (-15 -2363 ((-141) $)) (-15 -4402 ((-141) $)) (-15 -1604 ((-141) $)) (-15 -2368 ((-141) $)) (-15 -1681 ((-658 (-57)) $)) (-15 -3226 ($ $ (-658 (-57)))) (-15 -2705 ($ $ (-658 (-57)))) (-15 -1916 ($ (-1191) (-141) (-141) (-141))) (-15 -1717 ($ $ (-658 (-1191)) (-57))) (-15 -1687 ((-2 (|:| |var| (-658 (-1191))) (|:| |pred| (-57))) $)) (-15 -1361 ((-141) $)) (-15 -1982 ($ $)) (-15 -2518 ($ $ (-57))) (-15 -2367 ((-658 (-57)) $)) (-15 -4085 ((-658 $) $)) (-15 -3022 ((-3 (-658 $) "failed") (-658 $))))) 
+((-1641 (((-141) $ $) NIL)) (-2692 (((-658 |#1|) $) 16)) (-3461 (((-141) $) 38)) (-4368 (((-3 (-688 |#1|) "failed") $) 41)) (-2400 (((-688 |#1|) $) 39)) (-1366 (($ $) 18)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-3725 (((-658 (-688 |#1|)) $) 23)) (-4233 (((-790) $) 45)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-688 |#1|) $) 17)) (-1683 (((-877) $) 37) (($ (-688 |#1|)) 21) (((-841 |#1|) $) 27) (($ |#1|) 20)) (-4257 (($) 8 T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 11)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 48))) 
+(((-915 |#1|) (-13 (-869) (-1065 (-688 |#1|)) (-10 -8 (-15 1 ($) -4249) (-15 -1683 ((-841 |#1|) $)) (-15 -1683 ($ |#1|)) (-15 -1918 ((-688 |#1|) $)) (-15 -4233 ((-790) $)) (-15 -3725 ((-658 (-688 |#1|)) $)) (-15 -1366 ($ $)) (-15 -3461 ((-141) $)) (-15 -2692 ((-658 |#1|) $)))) (-869)) (T -915)) 
+((-4257 (*1 *1) (-12 (-5 *1 (-915 *2)) (-4 *2 (-869)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-841 *3)) (-5 *1 (-915 *3)) (-4 *3 (-869)))) (-1683 (*1 *1 *2) (-12 (-5 *1 (-915 *2)) (-4 *2 (-869)))) (-1918 (*1 *2 *1) (-12 (-5 *2 (-688 *3)) (-5 *1 (-915 *3)) (-4 *3 (-869)))) (-4233 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-915 *3)) (-4 *3 (-869)))) (-3725 (*1 *2 *1) (-12 (-5 *2 (-658 (-688 *3))) (-5 *1 (-915 *3)) (-4 *3 (-869)))) (-1366 (*1 *1 *1) (-12 (-5 *1 (-915 *2)) (-4 *2 (-869)))) (-3461 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-915 *3)) (-4 *3 (-869)))) (-2692 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-915 *3)) (-4 *3 (-869))))) 
+(-13 (-869) (-1065 (-688 |#1|)) (-10 -8 (-15 (-4257) ($) -4249) (-15 -1683 ((-841 |#1|) $)) (-15 -1683 ($ |#1|)) (-15 -1918 ((-688 |#1|) $)) (-15 -4233 ((-790) $)) (-15 -3725 ((-658 (-688 |#1|)) $)) (-15 -1366 ($ $)) (-15 -3461 ((-141) $)) (-15 -2692 ((-658 |#1|) $)))) 
+((-4060 ((|#1| |#1| |#1|) 19))) 
+(((-916 |#1| |#2|) (-10 -7 (-15 -4060 (|#1| |#1| |#1|))) (-1255 |#2|) (-1075)) (T -916)) 
+((-4060 (*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-916 *2 *3)) (-4 *2 (-1255 *3))))) 
+(-10 -7 (-15 -4060 (|#1| |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2617 (((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) 13)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-4180 (((-1063) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) 12)) (-3255 (((-141) $ $) 6))) 
+(((-917) (-1311)) (T -917)) 
+((-2617 (*1 *2 *3 *4) (-12 (-4 *1 (-917)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)))))) (-4180 (*1 *2 *3) (-12 (-4 *1 (-917)) (-5 *3 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *2 (-1063))))) 
+(-13 (-1119) (-10 -7 (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| |explanations| (-1173))) (-1087) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237))))) (-15 -4180 ((-1063) (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237))))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-3695 ((|#1| |#1| (-790)) 23)) (-1380 (((-3 |#1| "failed") |#1| |#1|) 22)) (-1906 (((-3 (-2 (|:| -1961 |#1|) (|:| -1954 |#1|)) "failed") |#1| (-790) (-790)) 26) (((-658 |#1|) |#1|) 28))) 
+(((-918 |#1| |#2|) (-10 -7 (-15 -1906 ((-658 |#1|) |#1|)) (-15 -1906 ((-3 (-2 (|:| -1961 |#1|) (|:| -1954 |#1|)) "failed") |#1| (-790) (-790))) (-15 -1380 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3695 (|#1| |#1| (-790)))) (-1255 |#2|) (-388)) (T -918)) 
+((-3695 (*1 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-388)) (-5 *1 (-918 *2 *4)) (-4 *2 (-1255 *4)))) (-1380 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-388)) (-5 *1 (-918 *2 *3)) (-4 *2 (-1255 *3)))) (-1906 (*1 *2 *3 *4 *4) (|partial| -12 (-5 *4 (-790)) (-4 *5 (-388)) (-5 *2 (-2 (|:| -1961 *3) (|:| -1954 *3))) (-5 *1 (-918 *3 *5)) (-4 *3 (-1255 *5)))) (-1906 (*1 *2 *3) (-12 (-4 *4 (-388)) (-5 *2 (-658 *3)) (-5 *1 (-918 *3 *4)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -1906 ((-658 |#1|) |#1|)) (-15 -1906 ((-3 (-2 (|:| -1961 |#1|) (|:| -1954 |#1|)) "failed") |#1| (-790) (-790))) (-15 -1380 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3695 (|#1| |#1| (-790)))) 
+((-4005 (((-1063) (-405) (-405) (-405) (-405) (-790) (-790) (-658 (-332 (-405))) (-658 (-658 (-332 (-405)))) (-1173)) 92) (((-1063) (-405) (-405) (-405) (-405) (-790) (-790) (-658 (-332 (-405))) (-658 (-658 (-332 (-405)))) (-1173) (-237)) 87) (((-1063) (-920) (-1087)) 76) (((-1063) (-920)) 77)) (-2617 (((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-920) (-1087)) 50) (((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-920)) 52))) 
+(((-919) (-10 -7 (-15 -4005 ((-1063) (-920))) (-15 -4005 ((-1063) (-920) (-1087))) (-15 -4005 ((-1063) (-405) (-405) (-405) (-405) (-790) (-790) (-658 (-332 (-405))) (-658 (-658 (-332 (-405)))) (-1173) (-237))) (-15 -4005 ((-1063) (-405) (-405) (-405) (-405) (-790) (-790) (-658 (-332 (-405))) (-658 (-658 (-332 (-405)))) (-1173))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-920))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-920) (-1087))))) (T -919)) 
+((-2617 (*1 *2 *3 *4) (-12 (-5 *3 (-920)) (-5 *4 (-1087)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-919)))) (-2617 (*1 *2 *3) (-12 (-5 *3 (-920)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-919)))) (-4005 (*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (-12 (-5 *4 (-790)) (-5 *6 (-658 (-658 (-332 *3)))) (-5 *7 (-1173)) (-5 *5 (-658 (-332 (-405)))) (-5 *3 (-405)) (-5 *2 (-1063)) (-5 *1 (-919)))) (-4005 (*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (-12 (-5 *4 (-790)) (-5 *6 (-658 (-658 (-332 *3)))) (-5 *7 (-1173)) (-5 *8 (-237)) (-5 *5 (-658 (-332 (-405)))) (-5 *3 (-405)) (-5 *2 (-1063)) (-5 *1 (-919)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-920)) (-5 *4 (-1087)) (-5 *2 (-1063)) (-5 *1 (-919)))) (-4005 (*1 *2 *3) (-12 (-5 *3 (-920)) (-5 *2 (-1063)) (-5 *1 (-919))))) 
+(-10 -7 (-15 -4005 ((-1063) (-920))) (-15 -4005 ((-1063) (-920) (-1087))) (-15 -4005 ((-1063) (-405) (-405) (-405) (-405) (-790) (-790) (-658 (-332 (-405))) (-658 (-658 (-332 (-405)))) (-1173) (-237))) (-15 -4005 ((-1063) (-405) (-405) (-405) (-405) (-790) (-790) (-658 (-332 (-405))) (-658 (-658 (-332 (-405)))) (-1173))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-920))) (-15 -2617 ((-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173)))) (-920) (-1087)))) 
+((-1641 (((-141) $ $) NIL)) (-2400 (((-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237))) $) 10)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 12) (($ (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) 9)) (-3255 (((-141) $ $) NIL))) 
+(((-920) (-13 (-1119) (-10 -8 (-15 -1683 ($ (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237))))) (-15 -1683 ((-877) $)) (-15 -2400 ((-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237))) $))))) (T -920)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-920)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *1 (-920)))) (-2400 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *1 (-920))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237))))) (-15 -1683 ((-877) $)) (-15 -2400 ((-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237))) $)))) 
+((-3644 (($ $ |#2|) NIL) (($ $ (-658 |#2|)) 10) (($ $ |#2| (-790)) 12) (($ $ (-658 |#2|) (-658 (-790))) 15)) (-1940 (($ $ |#2|) 16) (($ $ (-658 |#2|)) 18) (($ $ |#2| (-790)) 19) (($ $ (-658 |#2|) (-658 (-790))) 21))) 
+(((-921 |#1| |#2|) (-10 -8 (-15 -1940 (|#1| |#1| (-658 |#2|) (-658 (-790)))) (-15 -1940 (|#1| |#1| |#2| (-790))) (-15 -1940 (|#1| |#1| (-658 |#2|))) (-15 -1940 (|#1| |#1| |#2|)) (-15 -3644 (|#1| |#1| (-658 |#2|) (-658 (-790)))) (-15 -3644 (|#1| |#1| |#2| (-790))) (-15 -3644 (|#1| |#1| (-658 |#2|))) (-15 -3644 (|#1| |#1| |#2|))) (-922 |#2|) (-1119)) (T -921)) 
+NIL 
+(-10 -8 (-15 -1940 (|#1| |#1| (-658 |#2|) (-658 (-790)))) (-15 -1940 (|#1| |#1| |#2| (-790))) (-15 -1940 (|#1| |#1| (-658 |#2|))) (-15 -1940 (|#1| |#1| |#2|)) (-15 -3644 (|#1| |#1| (-658 |#2|) (-658 (-790)))) (-15 -3644 (|#1| |#1| |#2| (-790))) (-15 -3644 (|#1| |#1| (-658 |#2|))) (-15 -3644 (|#1| |#1| |#2|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3644 (($ $ |#1|) 41) (($ $ (-658 |#1|)) 40) (($ $ |#1| (-790)) 39) (($ $ (-658 |#1|) (-658 (-790))) 38)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ |#1|) 37) (($ $ (-658 |#1|)) 36) (($ $ |#1| (-790)) 35) (($ $ (-658 |#1|) (-658 (-790))) 34)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-922 |#1|) (-1311) (-1119)) (T -922)) 
+((-3644 (*1 *1 *1 *2) (-12 (-4 *1 (-922 *2)) (-4 *2 (-1119)))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *1 (-922 *3)) (-4 *3 (-1119)))) (-3644 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-922 *2)) (-4 *2 (-1119)))) (-3644 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *4)) (-5 *3 (-658 (-790))) (-4 *1 (-922 *4)) (-4 *4 (-1119)))) (-1940 (*1 *1 *1 *2) (-12 (-4 *1 (-922 *2)) (-4 *2 (-1119)))) (-1940 (*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *1 (-922 *3)) (-4 *3 (-1119)))) (-1940 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-922 *2)) (-4 *2 (-1119)))) (-1940 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *4)) (-5 *3 (-658 (-790))) (-4 *1 (-922 *4)) (-4 *4 (-1119))))) 
+(-13 (-1075) (-10 -8 (-15 -3644 ($ $ |t#1|)) (-15 -3644 ($ $ (-658 |t#1|))) (-15 -3644 ($ $ |t#1| (-790))) (-15 -3644 ($ $ (-658 |t#1|) (-658 (-790)))) (-15 -1940 ($ $ |t#1|)) (-15 -1940 ($ $ (-658 |t#1|))) (-15 -1940 ($ $ |t#1| (-790))) (-15 -1940 ($ $ (-658 |t#1|) (-658 (-790)))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) 26)) (-2126 (((-141) $ (-790)) NIL)) (-3047 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-2949 (($ $ $) NIL (|has| $ (-6 -4626)))) (-1348 (($ $ $) NIL (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) (($ $ "left" $) NIL (|has| $ (-6 -4626))) (($ $ "right" $) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-1954 (($ $) 25)) (-1679 (($ |#1|) 12) (($ $ $) 17)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-1961 (($ $) 23)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) 20)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-2920 (((-592) $ $) NIL)) (-3228 (((-141) $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-877) $) 29 (|has| |#1| (-1119))) (((-1212 |#1|) $) 9)) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 21 (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-923 |#1|) (-13 (-148 |#1|) (-10 -8 (-15 -1679 ($ |#1|)) (-15 -1679 ($ $ $)) (-15 -1683 ((-1212 |#1|) $)))) (-1119)) (T -923)) 
+((-1679 (*1 *1 *2) (-12 (-5 *1 (-923 *2)) (-4 *2 (-1119)))) (-1679 (*1 *1 *1 *1) (-12 (-5 *1 (-923 *2)) (-4 *2 (-1119)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1212 *3)) (-5 *1 (-923 *3)) (-4 *3 (-1119))))) 
+(-13 (-148 |#1|) (-10 -8 (-15 -1679 ($ |#1|)) (-15 -1679 ($ $ $)) (-15 -1683 ((-1212 |#1|) $)))) 
+((-2632 ((|#2| (-1156 |#1| |#2|)) 39))) 
+(((-924 |#1| |#2|) (-10 -7 (-15 -2632 (|#2| (-1156 |#1| |#2|)))) (-944) (-13 (-1075) (-10 -7 (-6 (-4627 "*"))))) (T -924)) 
+((-2632 (*1 *2 *3) (-12 (-5 *3 (-1156 *4 *2)) (-14 *4 (-944)) (-4 *2 (-13 (-1075) (-10 -7 (-6 (-4627 "*"))))) (-5 *1 (-924 *4 *2))))) 
+(-10 -7 (-15 -2632 (|#2| (-1156 |#1| |#2|)))) 
+((-1641 (((-141) $ $) 7)) (-3001 (($) 19 T CONST)) (-3371 (((-3 $ "failed") $) 15)) (-1363 (((-1121 |#1|) $ |#1|) 34)) (-3558 (((-141) $) 18)) (-1837 (($ $ $) 32 (-3836 (|has| |#1| (-869)) (|has| |#1| (-394))))) (-3319 (($ $ $) 31 (-3836 (|has| |#1| (-869)) (|has| |#1| (-394))))) (-2685 (((-1173) $) 9)) (-4552 (($ $) 26)) (-2951 (((-1137) $) 10)) (-2806 ((|#1| $ |#1|) 36)) (-3927 ((|#1| $ |#1|) 35)) (-3999 (($ (-658 (-658 |#1|))) 37)) (-4523 (($ (-658 |#1|)) 38)) (-2227 (($ $ $) 22)) (-2131 (($ $ $) 21)) (-1683 (((-877) $) 11)) (-1424 (($ $ (-944)) 12) (($ $ (-790)) 16) (($ $ (-592)) 23)) (-4257 (($) 20 T CONST)) (-3286 (((-141) $ $) 29 (-3836 (|has| |#1| (-869)) (|has| |#1| (-394))))) (-3273 (((-141) $ $) 28 (-3836 (|has| |#1| (-869)) (|has| |#1| (-394))))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 30 (-3836 (|has| |#1| (-869)) (|has| |#1| (-394))))) (-3266 (((-141) $ $) 33)) (-3313 (($ $ $) 25)) (** (($ $ (-944)) 13) (($ $ (-790)) 17) (($ $ (-592)) 24)) (* (($ $ $) 14))) 
+(((-925 |#1|) (-1311) (-1119)) (T -925)) 
+((-4523 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-925 *3)))) (-3999 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-4 *1 (-925 *3)))) (-2806 (*1 *2 *1 *2) (-12 (-4 *1 (-925 *2)) (-4 *2 (-1119)))) (-3927 (*1 *2 *1 *2) (-12 (-4 *1 (-925 *2)) (-4 *2 (-1119)))) (-1363 (*1 *2 *1 *3) (-12 (-4 *1 (-925 *3)) (-4 *3 (-1119)) (-5 *2 (-1121 *3)))) (-3266 (*1 *2 *1 *1) (-12 (-4 *1 (-925 *3)) (-4 *3 (-1119)) (-5 *2 (-141))))) 
+(-13 (-502) (-10 -8 (-15 -4523 ($ (-658 |t#1|))) (-15 -3999 ($ (-658 (-658 |t#1|)))) (-15 -2806 (|t#1| $ |t#1|)) (-15 -3927 (|t#1| $ |t#1|)) (-15 -1363 ((-1121 |t#1|) $ |t#1|)) (-15 -3266 ((-141) $ $)) (IF (|has| |t#1| (-869)) (-6 (-869)) |noBranch|) (IF (|has| |t#1| (-394)) (-6 (-869)) |noBranch|))) 
+(((-125) . T) ((-632 (-877)) . T) ((-502) . T) ((-743) . T) ((-869) -3836 (|has| |#1| (-869)) (|has| |#1| (-394))) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-4343 (((-658 (-658 (-790))) $) 106)) (-2505 (((-658 (-790)) (-927 |#1|) $) 128)) (-2064 (((-658 (-790)) (-927 |#1|) $) 129)) (-2223 (((-658 (-927 |#1|)) $) 96)) (-4290 (((-927 |#1|) $ (-592)) 101) (((-927 |#1|) $) 102)) (-3432 (($ (-658 (-927 |#1|))) 108)) (-4346 (((-790) $) 103)) (-4562 (((-1121 (-1121 |#1|)) $) 126)) (-1363 (((-1121 |#1|) $ |#1|) 119) (((-1121 (-1121 |#1|)) $ (-1121 |#1|)) 137) (((-1121 (-658 |#1|)) $ (-658 |#1|)) 140)) (-1402 (((-1121 |#1|) $) 99)) (-3133 (((-141) (-927 |#1|) $) 90)) (-2685 (((-1173) $) NIL)) (-3924 (((-1285) $) 93) (((-1285) $ (-592) (-592)) 141)) (-2951 (((-1137) $) NIL)) (-1551 (((-658 (-927 |#1|)) $) 94)) (-3927 (((-927 |#1|) $ (-790)) 97)) (-4525 (((-790) $) 104)) (-1683 (((-877) $) 117) (((-658 (-927 |#1|)) $) 22) (($ (-658 (-927 |#1|))) 107)) (-4226 (((-658 |#1|) $) 105)) (-3255 (((-141) $ $) 134)) (-3279 (((-141) $ $) 132)) (-3266 (((-141) $ $) 131))) 
+(((-926 |#1|) (-13 (-1119) (-10 -8 (-15 -1683 ((-658 (-927 |#1|)) $)) (-15 -1551 ((-658 (-927 |#1|)) $)) (-15 -3927 ((-927 |#1|) $ (-790))) (-15 -4290 ((-927 |#1|) $ (-592))) (-15 -4290 ((-927 |#1|) $)) (-15 -4346 ((-790) $)) (-15 -4525 ((-790) $)) (-15 -4226 ((-658 |#1|) $)) (-15 -2223 ((-658 (-927 |#1|)) $)) (-15 -4343 ((-658 (-658 (-790))) $)) (-15 -1683 ($ (-658 (-927 |#1|)))) (-15 -3432 ($ (-658 (-927 |#1|)))) (-15 -1363 ((-1121 |#1|) $ |#1|)) (-15 -4562 ((-1121 (-1121 |#1|)) $)) (-15 -1363 ((-1121 (-1121 |#1|)) $ (-1121 |#1|))) (-15 -1363 ((-1121 (-658 |#1|)) $ (-658 |#1|))) (-15 -3133 ((-141) (-927 |#1|) $)) (-15 -2505 ((-658 (-790)) (-927 |#1|) $)) (-15 -2064 ((-658 (-790)) (-927 |#1|) $)) (-15 -1402 ((-1121 |#1|) $)) (-15 -3266 ((-141) $ $)) (-15 -3279 ((-141) $ $)) (-15 -3924 ((-1285) $)) (-15 -3924 ((-1285) $ (-592) (-592))))) (-1119)) (T -926)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-658 (-927 *3))) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-1551 (*1 *2 *1) (-12 (-5 *2 (-658 (-927 *3))) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-927 *4)) (-5 *1 (-926 *4)) (-4 *4 (-1119)))) (-4290 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-927 *4)) (-5 *1 (-926 *4)) (-4 *4 (-1119)))) (-4290 (*1 *2 *1) (-12 (-5 *2 (-927 *3)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-4346 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-4525 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-4226 (*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-2223 (*1 *2 *1) (-12 (-5 *2 (-658 (-927 *3))) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-4343 (*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-790)))) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-927 *3))) (-4 *3 (-1119)) (-5 *1 (-926 *3)))) (-3432 (*1 *1 *2) (-12 (-5 *2 (-658 (-927 *3))) (-4 *3 (-1119)) (-5 *1 (-926 *3)))) (-1363 (*1 *2 *1 *3) (-12 (-5 *2 (-1121 *3)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-4562 (*1 *2 *1) (-12 (-5 *2 (-1121 (-1121 *3))) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-1363 (*1 *2 *1 *3) (-12 (-4 *4 (-1119)) (-5 *2 (-1121 (-1121 *4))) (-5 *1 (-926 *4)) (-5 *3 (-1121 *4)))) (-1363 (*1 *2 *1 *3) (-12 (-4 *4 (-1119)) (-5 *2 (-1121 (-658 *4))) (-5 *1 (-926 *4)) (-5 *3 (-658 *4)))) (-3133 (*1 *2 *3 *1) (-12 (-5 *3 (-927 *4)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-926 *4)))) (-2505 (*1 *2 *3 *1) (-12 (-5 *3 (-927 *4)) (-4 *4 (-1119)) (-5 *2 (-658 (-790))) (-5 *1 (-926 *4)))) (-2064 (*1 *2 *3 *1) (-12 (-5 *3 (-927 *4)) (-4 *4 (-1119)) (-5 *2 (-658 (-790))) (-5 *1 (-926 *4)))) (-1402 (*1 *2 *1) (-12 (-5 *2 (-1121 *3)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-3266 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-3279 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-3924 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) (-3924 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-926 *4)) (-4 *4 (-1119))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ((-658 (-927 |#1|)) $)) (-15 -1551 ((-658 (-927 |#1|)) $)) (-15 -3927 ((-927 |#1|) $ (-790))) (-15 -4290 ((-927 |#1|) $ (-592))) (-15 -4290 ((-927 |#1|) $)) (-15 -4346 ((-790) $)) (-15 -4525 ((-790) $)) (-15 -4226 ((-658 |#1|) $)) (-15 -2223 ((-658 (-927 |#1|)) $)) (-15 -4343 ((-658 (-658 (-790))) $)) (-15 -1683 ($ (-658 (-927 |#1|)))) (-15 -3432 ($ (-658 (-927 |#1|)))) (-15 -1363 ((-1121 |#1|) $ |#1|)) (-15 -4562 ((-1121 (-1121 |#1|)) $)) (-15 -1363 ((-1121 (-1121 |#1|)) $ (-1121 |#1|))) (-15 -1363 ((-1121 (-658 |#1|)) $ (-658 |#1|))) (-15 -3133 ((-141) (-927 |#1|) $)) (-15 -2505 ((-658 (-790)) (-927 |#1|) $)) (-15 -2064 ((-658 (-790)) (-927 |#1|) $)) (-15 -1402 ((-1121 |#1|) $)) (-15 -3266 ((-141) $ $)) (-15 -3279 ((-141) $ $)) (-15 -3924 ((-1285) $)) (-15 -3924 ((-1285) $ (-592) (-592))))) 
+((-1641 (((-141) $ $) NIL)) (-3960 (((-658 $) (-658 $)) 76)) (-3940 (((-592) $) 59)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-4346 (((-790) $) 57)) (-1363 (((-1121 |#1|) $ |#1|) 48)) (-3558 (((-141) $) NIL)) (-3372 (((-141) $) 62)) (-2766 (((-790) $) 60)) (-1402 (((-1121 |#1|) $) 41)) (-1837 (($ $ $) NIL (-3836 (|has| |#1| (-394)) (|has| |#1| (-869))))) (-3319 (($ $ $) NIL (-3836 (|has| |#1| (-394)) (|has| |#1| (-869))))) (-3833 (((-2 (|:| |preimage| (-658 |#1|)) (|:| |image| (-658 |#1|))) $) 35)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 92)) (-2951 (((-1137) $) NIL)) (-2068 (((-1121 |#1|) $) 98 (|has| |#1| (-394)))) (-3554 (((-141) $) 58)) (-2806 ((|#1| $ |#1|) 46)) (-3927 ((|#1| $ |#1|) 93)) (-4525 (((-790) $) 43)) (-3999 (($ (-658 (-658 |#1|))) 84)) (-2123 (((-1000) $) 52)) (-4523 (($ (-658 |#1|)) 21)) (-2227 (($ $ $) NIL)) (-2131 (($ $ $) NIL)) (-2888 (($ (-658 (-658 |#1|))) 38)) (-2041 (($ (-658 (-658 |#1|))) 87)) (-1395 (($ (-658 |#1|)) 95)) (-1683 (((-877) $) 83) (($ (-658 (-658 |#1|))) 65) (($ (-658 |#1|)) 66)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-4257 (($) 16 T CONST)) (-3286 (((-141) $ $) NIL (-3836 (|has| |#1| (-394)) (|has| |#1| (-869))))) (-3273 (((-141) $ $) NIL (-3836 (|has| |#1| (-394)) (|has| |#1| (-869))))) (-3255 (((-141) $ $) 44)) (-3279 (((-141) $ $) NIL (-3836 (|has| |#1| (-394)) (|has| |#1| (-869))))) (-3266 (((-141) $ $) 64)) (-3313 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ $ $) 22))) 
+(((-927 |#1|) (-13 (-925 |#1|) (-10 -8 (-15 -3833 ((-2 (|:| |preimage| (-658 |#1|)) (|:| |image| (-658 |#1|))) $)) (-15 -2888 ($ (-658 (-658 |#1|)))) (-15 -1683 ($ (-658 (-658 |#1|)))) (-15 -1683 ($ (-658 |#1|))) (-15 -2041 ($ (-658 (-658 |#1|)))) (-15 -4525 ((-790) $)) (-15 -1402 ((-1121 |#1|) $)) (-15 -2123 ((-1000) $)) (-15 -4346 ((-790) $)) (-15 -2766 ((-790) $)) (-15 -3940 ((-592) $)) (-15 -3554 ((-141) $)) (-15 -3372 ((-141) $)) (-15 -3960 ((-658 $) (-658 $))) (IF (|has| |#1| (-394)) (-15 -2068 ((-1121 |#1|) $)) |noBranch|) (IF (|has| |#1| (-574)) (-15 -1395 ($ (-658 |#1|))) (IF (|has| |#1| (-394)) (-15 -1395 ($ (-658 |#1|))) |noBranch|)))) (-1119)) (T -927)) 
+((-3833 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |preimage| (-658 *3)) (|:| |image| (-658 *3)))) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-2888 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-5 *1 (-927 *3)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-5 *1 (-927 *3)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-927 *3)))) (-2041 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-5 *1 (-927 *3)))) (-4525 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-1402 (*1 *2 *1) (-12 (-5 *2 (-1121 *3)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-2123 (*1 *2 *1) (-12 (-5 *2 (-1000)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-4346 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-2766 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-3940 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-3554 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-3372 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-3960 (*1 *2 *2) (-12 (-5 *2 (-658 (-927 *3))) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) (-2068 (*1 *2 *1) (-12 (-5 *2 (-1121 *3)) (-5 *1 (-927 *3)) (-4 *3 (-394)) (-4 *3 (-1119)))) (-1395 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-927 *3))))) 
+(-13 (-925 |#1|) (-10 -8 (-15 -3833 ((-2 (|:| |preimage| (-658 |#1|)) (|:| |image| (-658 |#1|))) $)) (-15 -2888 ($ (-658 (-658 |#1|)))) (-15 -1683 ($ (-658 (-658 |#1|)))) (-15 -1683 ($ (-658 |#1|))) (-15 -2041 ($ (-658 (-658 |#1|)))) (-15 -4525 ((-790) $)) (-15 -1402 ((-1121 |#1|) $)) (-15 -2123 ((-1000) $)) (-15 -4346 ((-790) $)) (-15 -2766 ((-790) $)) (-15 -3940 ((-592) $)) (-15 -3554 ((-141) $)) (-15 -3372 ((-141) $)) (-15 -3960 ((-658 $) (-658 $))) (IF (|has| |#1| (-394)) (-15 -2068 ((-1121 |#1|) $)) |noBranch|) (IF (|has| |#1| (-574)) (-15 -1395 ($ (-658 |#1|))) (IF (|has| |#1| (-394)) (-15 -1395 ($ (-658 |#1|))) |noBranch|)))) 
+((-3454 (((-3 (-658 (-1187 |#4|)) "failed") (-658 (-1187 |#4|)) (-1187 |#4|)) 127)) (-2606 ((|#1|) 75)) (-3653 (((-444 (-1187 |#4|)) (-1187 |#4|)) 136)) (-2971 (((-444 (-1187 |#4|)) (-658 |#3|) (-1187 |#4|)) 67)) (-3081 (((-444 (-1187 |#4|)) (-1187 |#4|)) 146)) (-4214 (((-3 (-658 (-1187 |#4|)) "failed") (-658 (-1187 |#4|)) (-1187 |#4|) |#3|) 91))) 
+(((-928 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3454 ((-3 (-658 (-1187 |#4|)) "failed") (-658 (-1187 |#4|)) (-1187 |#4|))) (-15 -3081 ((-444 (-1187 |#4|)) (-1187 |#4|))) (-15 -3653 ((-444 (-1187 |#4|)) (-1187 |#4|))) (-15 -2606 (|#1|)) (-15 -4214 ((-3 (-658 (-1187 |#4|)) "failed") (-658 (-1187 |#4|)) (-1187 |#4|) |#3|)) (-15 -2971 ((-444 (-1187 |#4|)) (-658 |#3|) (-1187 |#4|)))) (-931) (-815) (-869) (-977 |#1| |#2| |#3|)) (T -928)) 
+((-2971 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *7)) (-4 *7 (-869)) (-4 *5 (-931)) (-4 *6 (-815)) (-4 *8 (-977 *5 *6 *7)) (-5 *2 (-444 (-1187 *8))) (-5 *1 (-928 *5 *6 *7 *8)) (-5 *4 (-1187 *8)))) (-4214 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *2 (-658 (-1187 *7))) (-5 *3 (-1187 *7)) (-4 *7 (-977 *5 *6 *4)) (-4 *5 (-931)) (-4 *6 (-815)) (-4 *4 (-869)) (-5 *1 (-928 *5 *6 *4 *7)))) (-2606 (*1 *2) (-12 (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-931)) (-5 *1 (-928 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) (-3653 (*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-928 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) (-3081 (*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-928 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) (-3454 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *7))) (-5 *3 (-1187 *7)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-931)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-928 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -3454 ((-3 (-658 (-1187 |#4|)) "failed") (-658 (-1187 |#4|)) (-1187 |#4|))) (-15 -3081 ((-444 (-1187 |#4|)) (-1187 |#4|))) (-15 -3653 ((-444 (-1187 |#4|)) (-1187 |#4|))) (-15 -2606 (|#1|)) (-15 -4214 ((-3 (-658 (-1187 |#4|)) "failed") (-658 (-1187 |#4|)) (-1187 |#4|) |#3|)) (-15 -2971 ((-444 (-1187 |#4|)) (-658 |#3|) (-1187 |#4|)))) 
+((-3454 (((-3 (-658 (-1187 |#2|)) "failed") (-658 (-1187 |#2|)) (-1187 |#2|)) 36)) (-2606 ((|#1|) 53)) (-3653 (((-444 (-1187 |#2|)) (-1187 |#2|)) 101)) (-2971 (((-444 (-1187 |#2|)) (-1187 |#2|)) 88)) (-3081 (((-444 (-1187 |#2|)) (-1187 |#2|)) 112))) 
+(((-929 |#1| |#2|) (-10 -7 (-15 -3454 ((-3 (-658 (-1187 |#2|)) "failed") (-658 (-1187 |#2|)) (-1187 |#2|))) (-15 -3081 ((-444 (-1187 |#2|)) (-1187 |#2|))) (-15 -3653 ((-444 (-1187 |#2|)) (-1187 |#2|))) (-15 -2606 (|#1|)) (-15 -2971 ((-444 (-1187 |#2|)) (-1187 |#2|)))) (-931) (-1255 |#1|)) (T -929)) 
+((-2971 (*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-1255 *4)) (-5 *2 (-444 (-1187 *5))) (-5 *1 (-929 *4 *5)) (-5 *3 (-1187 *5)))) (-2606 (*1 *2) (-12 (-4 *2 (-931)) (-5 *1 (-929 *2 *3)) (-4 *3 (-1255 *2)))) (-3653 (*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-1255 *4)) (-5 *2 (-444 (-1187 *5))) (-5 *1 (-929 *4 *5)) (-5 *3 (-1187 *5)))) (-3081 (*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-1255 *4)) (-5 *2 (-444 (-1187 *5))) (-5 *1 (-929 *4 *5)) (-5 *3 (-1187 *5)))) (-3454 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *5))) (-5 *3 (-1187 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-931)) (-5 *1 (-929 *4 *5))))) 
+(-10 -7 (-15 -3454 ((-3 (-658 (-1187 |#2|)) "failed") (-658 (-1187 |#2|)) (-1187 |#2|))) (-15 -3081 ((-444 (-1187 |#2|)) (-1187 |#2|))) (-15 -3653 ((-444 (-1187 |#2|)) (-1187 |#2|))) (-15 -2606 (|#1|)) (-15 -2971 ((-444 (-1187 |#2|)) (-1187 |#2|)))) 
+((-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 39)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 18)) (-1517 (((-3 $ "failed") $) 33))) 
+(((-930 |#1|) (-10 -8 (-15 -1517 ((-3 |#1| "failed") |#1|)) (-15 -3524 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|))) (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|)))) (-931)) (T -930)) 
+NIL 
+(-10 -8 (-15 -1517 ((-3 |#1| "failed") |#1|)) (-15 -3524 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|))) (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-4043 (((-444 (-1187 $)) (-1187 $)) 57)) (-3743 (($ $) 49)) (-3164 (((-444 $) $) 50)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 54)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-2802 (((-141) $) 51)) (-3558 (((-141) $) 30)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-1416 (((-444 (-1187 $)) (-1187 $)) 55)) (-3339 (((-444 (-1187 $)) (-1187 $)) 56)) (-4500 (((-444 $) $) 48)) (-3616 (((-3 $ "failed") $ $) 41)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 53 (|has| $ (-169)))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42)) (-1517 (((-3 $ "failed") $) 52 (|has| $ (-169)))) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-931) (-1311)) (T -931)) 
+((-2536 (*1 *2 *2 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-931)))) (-4043 (*1 *2 *3) (-12 (-4 *1 (-931)) (-5 *2 (-444 (-1187 *1))) (-5 *3 (-1187 *1)))) (-3339 (*1 *2 *3) (-12 (-4 *1 (-931)) (-5 *2 (-444 (-1187 *1))) (-5 *3 (-1187 *1)))) (-1416 (*1 *2 *3) (-12 (-4 *1 (-931)) (-5 *2 (-444 (-1187 *1))) (-5 *3 (-1187 *1)))) (-3524 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *1))) (-5 *3 (-1187 *1)) (-4 *1 (-931)))) (-2288 (*1 *2 *3) (|partial| -12 (-5 *3 (-706 *1)) (-4 *1 (-169)) (-4 *1 (-931)) (-5 *2 (-1280 *1)))) (-1517 (*1 *1 *1) (|partial| -12 (-4 *1 (-169)) (-4 *1 (-931))))) 
+(-13 (-1235) (-10 -8 (-15 -4043 ((-444 (-1187 $)) (-1187 $))) (-15 -3339 ((-444 (-1187 $)) (-1187 $))) (-15 -1416 ((-444 (-1187 $)) (-1187 $))) (-15 -2536 ((-1187 $) (-1187 $) (-1187 $))) (-15 -3524 ((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $))) (IF (|has| $ (-169)) (PROGN (-15 -2288 ((-3 (-1280 $) "failed") (-706 $))) (-15 -1517 ((-3 $ "failed") $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-477) . T) ((-582) . T) ((-661 $) . T) ((-678) . T) ((-734 $) . T) ((-743) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-1917 (((-141) $) NIL)) (-4424 (((-790)) NIL)) (-4529 (($ $ (-944)) NIL (|has| $ (-394))) (($ $) NIL)) (-4217 (((-1199 (-944) (-790)) (-592)) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-1403 (((-790)) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 $ "failed") $) NIL)) (-2400 (($ $) NIL)) (-1626 (($ (-1280 $)) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2667 (($) NIL)) (-3293 (((-141) $) NIL)) (-1525 (($ $) NIL) (($ $ (-790)) NIL)) (-2802 (((-141) $) NIL)) (-4346 (((-855 (-944)) $) NIL) (((-944) $) NIL)) (-3558 (((-141) $) NIL)) (-2834 (($) NIL (|has| $ (-394)))) (-2114 (((-141) $) NIL (|has| $ (-394)))) (-2793 (($ $ (-944)) NIL (|has| $ (-394))) (($ $) NIL)) (-3921 (((-3 $ "failed") $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3504 (((-1187 $) $ (-944)) NIL (|has| $ (-394))) (((-1187 $) $) NIL)) (-3546 (((-944) $) NIL)) (-2343 (((-1187 $) $) NIL (|has| $ (-394)))) (-1492 (((-3 (-1187 $) "failed") $ $) NIL (|has| $ (-394))) (((-1187 $) $) NIL (|has| $ (-394)))) (-2252 (($ $ (-1187 $)) NIL (|has| $ (-394)))) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL T CONST)) (-1825 (($ (-944)) NIL)) (-2142 (((-141) $) NIL)) (-2951 (((-1137) $) NIL)) (-2934 (($) NIL (|has| $ (-394)))) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL)) (-4500 (((-444 $) $) NIL)) (-3470 (((-944)) NIL) (((-855 (-944))) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-1405 (((-658 $)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-2177 (((-3 (-790) "failed") $ $) NIL) (((-790) $) NIL)) (-1936 (((-160)) NIL)) (-3644 (($ $ (-790)) NIL) (($ $) NIL)) (-4525 (((-944) $) NIL) (((-855 (-944)) $) NIL)) (-3390 (((-1187 $)) NIL)) (-3809 (($) NIL)) (-3342 (($) NIL (|has| $ (-394)))) (-2231 (((-706 $) (-1280 $)) NIL) (((-1280 $) $) NIL)) (-1778 (((-592) $) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL)) (-1517 (((-3 $ "failed") $) NIL) (($ $) NIL)) (-4010 (((-790)) NIL)) (-2195 (((-1280 $) (-944)) NIL) (((-1280 $)) NIL)) (-2537 (((-141) $ $) NIL)) (-3069 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-3417 (($ $ (-790)) NIL (|has| $ (-394))) (($ $) NIL (|has| $ (-394)))) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL))) 
+(((-932 |#1|) (-13 (-373) (-349 $) (-633 (-592))) (-944)) (T -932)) 
+NIL 
+(-13 (-373) (-349 $) (-633 (-592))) 
+((-2608 (((-3 (-2 (|:| -4346 (-790)) (|:| -1325 |#5|)) "failed") (-356 |#2| |#3| |#4| |#5|)) 76)) (-2303 (((-141) (-356 |#2| |#3| |#4| |#5|)) 16)) (-4346 (((-3 (-790) "failed") (-356 |#2| |#3| |#4| |#5|)) 14))) 
+(((-933 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4346 ((-3 (-790) "failed") (-356 |#2| |#3| |#4| |#5|))) (-15 -2303 ((-141) (-356 |#2| |#3| |#4| |#5|))) (-15 -2608 ((-3 (-2 (|:| -4346 (-790)) (|:| -1325 |#5|)) "failed") (-356 |#2| |#3| |#4| |#5|)))) (-13 (-869) (-582) (-1065 (-592))) (-456 |#1|) (-1255 |#2|) (-1255 (-433 |#3|)) (-362 |#2| |#3| |#4|)) (T -933)) 
+((-2608 (*1 *2 *3) (|partial| -12 (-5 *3 (-356 *5 *6 *7 *8)) (-4 *5 (-456 *4)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *8 (-362 *5 *6 *7)) (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-2 (|:| -4346 (-790)) (|:| -1325 *8))) (-5 *1 (-933 *4 *5 *6 *7 *8)))) (-2303 (*1 *2 *3) (-12 (-5 *3 (-356 *5 *6 *7 *8)) (-4 *5 (-456 *4)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *8 (-362 *5 *6 *7)) (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-141)) (-5 *1 (-933 *4 *5 *6 *7 *8)))) (-4346 (*1 *2 *3) (|partial| -12 (-5 *3 (-356 *5 *6 *7 *8)) (-4 *5 (-456 *4)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *8 (-362 *5 *6 *7)) (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-790)) (-5 *1 (-933 *4 *5 *6 *7 *8))))) 
+(-10 -7 (-15 -4346 ((-3 (-790) "failed") (-356 |#2| |#3| |#4| |#5|))) (-15 -2303 ((-141) (-356 |#2| |#3| |#4| |#5|))) (-15 -2608 ((-3 (-2 (|:| -4346 (-790)) (|:| -1325 |#5|)) "failed") (-356 |#2| |#3| |#4| |#5|)))) 
+((-2608 (((-3 (-2 (|:| -4346 (-790)) (|:| -1325 |#3|)) "failed") (-356 (-433 (-592)) |#1| |#2| |#3|)) 56)) (-2303 (((-141) (-356 (-433 (-592)) |#1| |#2| |#3|)) 13)) (-4346 (((-3 (-790) "failed") (-356 (-433 (-592)) |#1| |#2| |#3|)) 11))) 
+(((-934 |#1| |#2| |#3|) (-10 -7 (-15 -4346 ((-3 (-790) "failed") (-356 (-433 (-592)) |#1| |#2| |#3|))) (-15 -2303 ((-141) (-356 (-433 (-592)) |#1| |#2| |#3|))) (-15 -2608 ((-3 (-2 (|:| -4346 (-790)) (|:| -1325 |#3|)) "failed") (-356 (-433 (-592)) |#1| |#2| |#3|)))) (-1255 (-433 (-592))) (-1255 (-433 |#1|)) (-362 (-433 (-592)) |#1| |#2|)) (T -934)) 
+((-2608 (*1 *2 *3) (|partial| -12 (-5 *3 (-356 (-433 (-592)) *4 *5 *6)) (-4 *4 (-1255 (-433 (-592)))) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 (-433 (-592)) *4 *5)) (-5 *2 (-2 (|:| -4346 (-790)) (|:| -1325 *6))) (-5 *1 (-934 *4 *5 *6)))) (-2303 (*1 *2 *3) (-12 (-5 *3 (-356 (-433 (-592)) *4 *5 *6)) (-4 *4 (-1255 (-433 (-592)))) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 (-433 (-592)) *4 *5)) (-5 *2 (-141)) (-5 *1 (-934 *4 *5 *6)))) (-4346 (*1 *2 *3) (|partial| -12 (-5 *3 (-356 (-433 (-592)) *4 *5 *6)) (-4 *4 (-1255 (-433 (-592)))) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 (-433 (-592)) *4 *5)) (-5 *2 (-790)) (-5 *1 (-934 *4 *5 *6))))) 
+(-10 -7 (-15 -4346 ((-3 (-790) "failed") (-356 (-433 (-592)) |#1| |#2| |#3|))) (-15 -2303 ((-141) (-356 (-433 (-592)) |#1| |#2| |#3|))) (-15 -2608 ((-3 (-2 (|:| -4346 (-790)) (|:| -1325 |#3|)) "failed") (-356 (-433 (-592)) |#1| |#2| |#3|)))) 
+((-4492 (((-1187 |#1|) |#2|) 36)) (-3399 ((|#2| |#2| (-658 |#1|)) 59) ((|#2| |#2| (-658 |#1|) (-592)) 61)) (-2189 (((-790) |#2|) 70)) (-3374 ((|#2| |#2| |#2| (-592)) 51)) (-1770 ((|#2| |#2| |#2|) 49)) (-1920 ((|#2| |#2| |#2|) 48)) (-3882 ((|#2| |#2| (-592)) 64)) (-2356 ((|#2| |#2| (-592)) 60)) (-3108 (((-658 |#2|) |#2|) 15)) (-2701 ((|#2| |#2|) 82)) (-2976 ((|#2| (-1 |#3| |#3|) |#2|) 40)) (-4314 (((-658 |#2|)) 26)) (-3057 (((-658 |#3|) (-592)) 92)) (-3486 (((-658 |#2|) (-790)) 93)) (-3315 ((|#2| |#2| (-592)) 71)) (-1639 ((|#3| |#2|) NIL)) (-2409 (((-790) |#2|) 83)) (-4525 (((-790) |#2| (-592)) 67)) (-2286 ((|#1| |#2| (-944)) 80)) (-4249 ((|#1| |#2|) 81))) 
+(((-935 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2976 (|#2| (-1 |#3| |#3|) |#2|)) (-15 -4525 ((-790) |#2| (-592))) (-15 -4492 ((-1187 |#1|) |#2|)) (-15 -2189 ((-790) |#2|)) (-15 -1920 (|#2| |#2| |#2|)) (-15 -1770 (|#2| |#2| |#2|)) (-15 -3374 (|#2| |#2| |#2| (-592))) (-15 -2701 (|#2| |#2|)) (-15 -1639 (|#3| |#2|)) (-15 -3882 (|#2| |#2| (-592))) (-15 -2356 (|#2| |#2| (-592))) (-15 -3399 (|#2| |#2| (-658 |#1|) (-592))) (-15 -3399 (|#2| |#2| (-658 |#1|))) (-15 -2286 (|#1| |#2| (-944))) (-15 -4249 (|#1| |#2|)) (-15 -3315 (|#2| |#2| (-592))) (-15 -3057 ((-658 |#3|) (-592))) (-15 -3486 ((-658 |#2|) (-790))) (-15 -2409 ((-790) |#2|)) (-15 -4314 ((-658 |#2|))) (-15 -3108 ((-658 |#2|) |#2|))) (-1075) (-346 |#1| |#3|) (-252 |#4| (-790)) (-790)) (T -935)) 
+((-3108 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *2 (-658 *3)) (-5 *1 (-935 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) (-4314 (*1 *2) (-12 (-4 *3 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *2 (-658 *4)) (-5 *1 (-935 *3 *4 *5 *6)) (-4 *4 (-346 *3 *5)))) (-2409 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 *2)) (-14 *6 *2) (-5 *2 (-790)) (-5 *1 (-935 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) (-3486 (*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-1075)) (-4 *6 (-252 *7 *3)) (-14 *7 *3) (-5 *2 (-658 *5)) (-5 *1 (-935 *4 *5 *6 *7)) (-4 *5 (-346 *4 *6)))) (-3057 (*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-5 *2 (-658 *6)) (-5 *1 (-935 *4 *5 *6 *7)) (-4 *5 (-346 *4 *6)))) (-3315 (*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5)))) (-4249 (*1 *2 *3) (-12 (-4 *4 (-252 *5 (-790))) (-14 *5 (-790)) (-4 *2 (-1075)) (-5 *1 (-935 *2 *3 *4 *5)) (-4 *3 (-346 *2 *4)))) (-2286 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-4 *2 (-1075)) (-5 *1 (-935 *2 *3 *5 *6)) (-4 *3 (-346 *2 *5)))) (-3399 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5)))) (-3399 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-592)) (-4 *5 (-1075)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-5 *1 (-935 *5 *2 *6 *7)) (-4 *2 (-346 *5 *6)))) (-2356 (*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5)))) (-3882 (*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5)))) (-1639 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-252 *5 (-790))) (-5 *1 (-935 *4 *3 *2 *5)) (-4 *3 (-346 *4 *2)) (-14 *5 (-790)))) (-2701 (*1 *2 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-252 *5 (-790))) (-14 *5 (-790)) (-5 *1 (-935 *3 *2 *4 *5)) (-4 *2 (-346 *3 *4)))) (-3374 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5)))) (-1770 (*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-252 *5 (-790))) (-14 *5 (-790)) (-5 *1 (-935 *3 *2 *4 *5)) (-4 *2 (-346 *3 *4)))) (-1920 (*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-252 *5 (-790))) (-14 *5 (-790)) (-5 *1 (-935 *3 *2 *4 *5)) (-4 *2 (-346 *3 *4)))) (-2189 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 *2)) (-14 *6 *2) (-5 *2 (-790)) (-5 *1 (-935 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) (-4492 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *2 (-1187 *4)) (-5 *1 (-935 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) (-4525 (*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-1075)) (-4 *6 (-252 *7 *2)) (-14 *7 *2) (-5 *2 (-790)) (-5 *1 (-935 *5 *3 *6 *7)) (-4 *3 (-346 *5 *6)))) (-2976 (*1 *2 *3 *2) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-4 *4 (-1075)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5))))) 
+(-10 -7 (-15 -2976 (|#2| (-1 |#3| |#3|) |#2|)) (-15 -4525 ((-790) |#2| (-592))) (-15 -4492 ((-1187 |#1|) |#2|)) (-15 -2189 ((-790) |#2|)) (-15 -1920 (|#2| |#2| |#2|)) (-15 -1770 (|#2| |#2| |#2|)) (-15 -3374 (|#2| |#2| |#2| (-592))) (-15 -2701 (|#2| |#2|)) (-15 -1639 (|#3| |#2|)) (-15 -3882 (|#2| |#2| (-592))) (-15 -2356 (|#2| |#2| (-592))) (-15 -3399 (|#2| |#2| (-658 |#1|) (-592))) (-15 -3399 (|#2| |#2| (-658 |#1|))) (-15 -2286 (|#1| |#2| (-944))) (-15 -4249 (|#1| |#2|)) (-15 -3315 (|#2| |#2| (-592))) (-15 -3057 ((-658 |#3|) (-592))) (-15 -3486 ((-658 |#2|) (-790))) (-15 -2409 ((-790) |#2|)) (-15 -4314 ((-658 |#2|))) (-15 -3108 ((-658 |#2|) |#2|))) 
+((-2040 ((|#2| |#2|) 25)) (-3462 (((-592) (-658 (-2 (|:| |den| (-592)) (|:| |gcdnum| (-592))))) 15)) (-3415 (((-944) (-592)) 35)) (-1830 (((-592) |#2|) 42)) (-2025 (((-592) |#2|) 21) (((-2 (|:| |den| (-592)) (|:| |gcdnum| (-592))) |#1|) 20))) 
+(((-936 |#1| |#2|) (-10 -7 (-15 -3415 ((-944) (-592))) (-15 -2025 ((-2 (|:| |den| (-592)) (|:| |gcdnum| (-592))) |#1|)) (-15 -2025 ((-592) |#2|)) (-15 -3462 ((-592) (-658 (-2 (|:| |den| (-592)) (|:| |gcdnum| (-592)))))) (-15 -1830 ((-592) |#2|)) (-15 -2040 (|#2| |#2|))) (-1255 (-433 (-592))) (-1255 (-433 |#1|))) (T -936)) 
+((-2040 (*1 *2 *2) (-12 (-4 *3 (-1255 (-433 (-592)))) (-5 *1 (-936 *3 *2)) (-4 *2 (-1255 (-433 *3))))) (-1830 (*1 *2 *3) (-12 (-4 *4 (-1255 (-433 *2))) (-5 *2 (-592)) (-5 *1 (-936 *4 *3)) (-4 *3 (-1255 (-433 *4))))) (-3462 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| |den| (-592)) (|:| |gcdnum| (-592))))) (-4 *4 (-1255 (-433 *2))) (-5 *2 (-592)) (-5 *1 (-936 *4 *5)) (-4 *5 (-1255 (-433 *4))))) (-2025 (*1 *2 *3) (-12 (-4 *4 (-1255 (-433 *2))) (-5 *2 (-592)) (-5 *1 (-936 *4 *3)) (-4 *3 (-1255 (-433 *4))))) (-2025 (*1 *2 *3) (-12 (-4 *3 (-1255 (-433 (-592)))) (-5 *2 (-2 (|:| |den| (-592)) (|:| |gcdnum| (-592)))) (-5 *1 (-936 *3 *4)) (-4 *4 (-1255 (-433 *3))))) (-3415 (*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1255 (-433 *3))) (-5 *2 (-944)) (-5 *1 (-936 *4 *5)) (-4 *5 (-1255 (-433 *4)))))) 
+(-10 -7 (-15 -3415 ((-944) (-592))) (-15 -2025 ((-2 (|:| |den| (-592)) (|:| |gcdnum| (-592))) |#1|)) (-15 -2025 ((-592) |#2|)) (-15 -3462 ((-592) (-658 (-2 (|:| |den| (-592)) (|:| |gcdnum| (-592)))))) (-15 -1830 ((-592) |#2|)) (-15 -2040 (|#2| |#2|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 ((|#1| $) 80)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-1586 (($ $ $) NIL)) (-3371 (((-3 $ "failed") $) 74)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-3330 (($ |#1| (-444 |#1|)) 72)) (-1781 (((-1187 |#1|) |#1| |#1|) 40)) (-4417 (($ $) 48)) (-3558 (((-141) $) NIL)) (-2336 (((-592) $) 77)) (-1466 (($ $ (-592)) 79)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2234 ((|#1| $) 76)) (-4482 (((-444 |#1|) $) 75)) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) 73)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4184 (($ $) 38)) (-1683 (((-877) $) 98) (($ (-592)) 53) (($ $) NIL) (($ (-433 (-592))) NIL) (($ |#1|) 30) (((-433 |#1|) $) 58) (($ (-433 (-444 |#1|))) 66)) (-4010 (((-790)) 51)) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 23 T CONST)) (-4257 (($) 11 T CONST)) (-3255 (((-141) $ $) 67)) (-3313 (($ $ $) NIL)) (-3306 (($ $) 87) (($ $ $) NIL)) (-3300 (($ $ $) 37)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 89) (($ $ $) 36) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ |#1| $) 88) (($ $ |#1|) NIL))) 
+(((-937 |#1|) (-13 (-388) (-43 |#1|) (-10 -8 (-15 -1683 ((-433 |#1|) $)) (-15 -1683 ($ (-433 (-444 |#1|)))) (-15 -4184 ($ $)) (-15 -4482 ((-444 |#1|) $)) (-15 -2234 (|#1| $)) (-15 -1466 ($ $ (-592))) (-15 -2336 ((-592) $)) (-15 -1781 ((-1187 |#1|) |#1| |#1|)) (-15 -4417 ($ $)) (-15 -3330 ($ |#1| (-444 |#1|))) (-15 -1505 (|#1| $)))) (-323)) (T -937)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-433 *3)) (-5 *1 (-937 *3)) (-4 *3 (-323)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-433 (-444 *3))) (-4 *3 (-323)) (-5 *1 (-937 *3)))) (-4184 (*1 *1 *1) (-12 (-5 *1 (-937 *2)) (-4 *2 (-323)))) (-4482 (*1 *2 *1) (-12 (-5 *2 (-444 *3)) (-5 *1 (-937 *3)) (-4 *3 (-323)))) (-2234 (*1 *2 *1) (-12 (-5 *1 (-937 *2)) (-4 *2 (-323)))) (-1466 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-937 *3)) (-4 *3 (-323)))) (-2336 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-937 *3)) (-4 *3 (-323)))) (-1781 (*1 *2 *3 *3) (-12 (-5 *2 (-1187 *3)) (-5 *1 (-937 *3)) (-4 *3 (-323)))) (-4417 (*1 *1 *1) (-12 (-5 *1 (-937 *2)) (-4 *2 (-323)))) (-3330 (*1 *1 *2 *3) (-12 (-5 *3 (-444 *2)) (-4 *2 (-323)) (-5 *1 (-937 *2)))) (-1505 (*1 *2 *1) (-12 (-5 *1 (-937 *2)) (-4 *2 (-323))))) 
+(-13 (-388) (-43 |#1|) (-10 -8 (-15 -1683 ((-433 |#1|) $)) (-15 -1683 ($ (-433 (-444 |#1|)))) (-15 -4184 ($ $)) (-15 -4482 ((-444 |#1|) $)) (-15 -2234 (|#1| $)) (-15 -1466 ($ $ (-592))) (-15 -2336 ((-592) $)) (-15 -1781 ((-1187 |#1|) |#1| |#1|)) (-15 -4417 ($ $)) (-15 -3330 ($ |#1| (-444 |#1|))) (-15 -1505 (|#1| $)))) 
+((-3330 (((-57) (-980 |#1|) (-444 (-980 |#1|)) (-1191)) 16) (((-57) (-433 (-980 |#1|)) (-1191)) 17))) 
+(((-938 |#1|) (-10 -7 (-15 -3330 ((-57) (-433 (-980 |#1|)) (-1191))) (-15 -3330 ((-57) (-980 |#1|) (-444 (-980 |#1|)) (-1191)))) (-13 (-323) (-171))) (T -938)) 
+((-3330 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-444 (-980 *6))) (-5 *5 (-1191)) (-5 *3 (-980 *6)) (-4 *6 (-13 (-323) (-171))) (-5 *2 (-57)) (-5 *1 (-938 *6)))) (-3330 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-171))) (-5 *2 (-57)) (-5 *1 (-938 *5))))) 
+(-10 -7 (-15 -3330 ((-57) (-433 (-980 |#1|)) (-1191))) (-15 -3330 ((-57) (-980 |#1|) (-444 (-980 |#1|)) (-1191)))) 
+((-3122 ((|#4| (-658 |#4|)) 119) (((-1187 |#4|) (-1187 |#4|) (-1187 |#4|)) 65) ((|#4| |#4| |#4|) 118)) (-3548 (((-1187 |#4|) (-658 (-1187 |#4|))) 112) (((-1187 |#4|) (-1187 |#4|) (-1187 |#4|)) 48) ((|#4| (-658 |#4|)) 53) ((|#4| |#4| |#4|) 82))) 
+(((-939 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3548 (|#4| |#4| |#4|)) (-15 -3548 (|#4| (-658 |#4|))) (-15 -3548 ((-1187 |#4|) (-1187 |#4|) (-1187 |#4|))) (-15 -3548 ((-1187 |#4|) (-658 (-1187 |#4|)))) (-15 -3122 (|#4| |#4| |#4|)) (-15 -3122 ((-1187 |#4|) (-1187 |#4|) (-1187 |#4|))) (-15 -3122 (|#4| (-658 |#4|)))) (-815) (-869) (-323) (-977 |#3| |#1| |#2|)) (T -939)) 
+((-3122 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *6 *4 *5)) (-5 *1 (-939 *4 *5 *6 *2)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)))) (-3122 (*1 *2 *2 *2) (-12 (-5 *2 (-1187 *6)) (-4 *6 (-977 *5 *3 *4)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-323)) (-5 *1 (-939 *3 *4 *5 *6)))) (-3122 (*1 *2 *2 *2) (-12 (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-323)) (-5 *1 (-939 *3 *4 *5 *2)) (-4 *2 (-977 *5 *3 *4)))) (-3548 (*1 *2 *3) (-12 (-5 *3 (-658 (-1187 *7))) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-5 *2 (-1187 *7)) (-5 *1 (-939 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5)))) (-3548 (*1 *2 *2 *2) (-12 (-5 *2 (-1187 *6)) (-4 *6 (-977 *5 *3 *4)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-323)) (-5 *1 (-939 *3 *4 *5 *6)))) (-3548 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *6 *4 *5)) (-5 *1 (-939 *4 *5 *6 *2)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)))) (-3548 (*1 *2 *2 *2) (-12 (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-323)) (-5 *1 (-939 *3 *4 *5 *2)) (-4 *2 (-977 *5 *3 *4))))) 
+(-10 -7 (-15 -3548 (|#4| |#4| |#4|)) (-15 -3548 (|#4| (-658 |#4|))) (-15 -3548 ((-1187 |#4|) (-1187 |#4|) (-1187 |#4|))) (-15 -3548 ((-1187 |#4|) (-658 (-1187 |#4|)))) (-15 -3122 (|#4| |#4| |#4|)) (-15 -3122 ((-1187 |#4|) (-1187 |#4|) (-1187 |#4|))) (-15 -3122 (|#4| (-658 |#4|)))) 
+((-3928 (((-926 (-592)) (-1000)) 22) (((-926 (-592)) (-658 (-592))) 19)) (-3123 (((-926 (-592)) (-658 (-592))) 46) (((-926 (-592)) (-944)) 47)) (-3933 (((-926 (-592))) 23)) (-4241 (((-926 (-592))) 36) (((-926 (-592)) (-658 (-592))) 35)) (-4543 (((-926 (-592))) 34) (((-926 (-592)) (-658 (-592))) 33)) (-3045 (((-926 (-592))) 32) (((-926 (-592)) (-658 (-592))) 31)) (-3706 (((-926 (-592))) 30) (((-926 (-592)) (-658 (-592))) 29)) (-4074 (((-926 (-592))) 28) (((-926 (-592)) (-658 (-592))) 27)) (-3848 (((-926 (-592))) 38) (((-926 (-592)) (-658 (-592))) 37)) (-3177 (((-926 (-592)) (-658 (-592))) 50) (((-926 (-592)) (-944)) 51)) (-1705 (((-926 (-592)) (-658 (-592))) 48) (((-926 (-592)) (-944)) 49)) (-1790 (((-926 (-592)) (-658 (-592))) 43) (((-926 (-592)) (-944)) 45)) (-2097 (((-926 (-592)) (-658 (-944))) 40))) 
+(((-940) (-10 -7 (-15 -3123 ((-926 (-592)) (-944))) (-15 -3123 ((-926 (-592)) (-658 (-592)))) (-15 -1790 ((-926 (-592)) (-944))) (-15 -1790 ((-926 (-592)) (-658 (-592)))) (-15 -2097 ((-926 (-592)) (-658 (-944)))) (-15 -1705 ((-926 (-592)) (-944))) (-15 -1705 ((-926 (-592)) (-658 (-592)))) (-15 -3177 ((-926 (-592)) (-944))) (-15 -3177 ((-926 (-592)) (-658 (-592)))) (-15 -4074 ((-926 (-592)) (-658 (-592)))) (-15 -4074 ((-926 (-592)))) (-15 -3706 ((-926 (-592)) (-658 (-592)))) (-15 -3706 ((-926 (-592)))) (-15 -3045 ((-926 (-592)) (-658 (-592)))) (-15 -3045 ((-926 (-592)))) (-15 -4543 ((-926 (-592)) (-658 (-592)))) (-15 -4543 ((-926 (-592)))) (-15 -4241 ((-926 (-592)) (-658 (-592)))) (-15 -4241 ((-926 (-592)))) (-15 -3848 ((-926 (-592)) (-658 (-592)))) (-15 -3848 ((-926 (-592)))) (-15 -3933 ((-926 (-592)))) (-15 -3928 ((-926 (-592)) (-658 (-592)))) (-15 -3928 ((-926 (-592)) (-1000))))) (T -940)) 
+((-3928 (*1 *2 *3) (-12 (-5 *3 (-1000)) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3928 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3933 (*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3848 (*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3848 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-4241 (*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-4241 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-4543 (*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-4543 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3045 (*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3045 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3706 (*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3706 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-4074 (*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-4074 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3177 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3177 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-1705 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-2097 (*1 *2 *3) (-12 (-5 *3 (-658 (-944))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-1790 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-1790 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3123 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) (-3123 (*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(-10 -7 (-15 -3123 ((-926 (-592)) (-944))) (-15 -3123 ((-926 (-592)) (-658 (-592)))) (-15 -1790 ((-926 (-592)) (-944))) (-15 -1790 ((-926 (-592)) (-658 (-592)))) (-15 -2097 ((-926 (-592)) (-658 (-944)))) (-15 -1705 ((-926 (-592)) (-944))) (-15 -1705 ((-926 (-592)) (-658 (-592)))) (-15 -3177 ((-926 (-592)) (-944))) (-15 -3177 ((-926 (-592)) (-658 (-592)))) (-15 -4074 ((-926 (-592)) (-658 (-592)))) (-15 -4074 ((-926 (-592)))) (-15 -3706 ((-926 (-592)) (-658 (-592)))) (-15 -3706 ((-926 (-592)))) (-15 -3045 ((-926 (-592)) (-658 (-592)))) (-15 -3045 ((-926 (-592)))) (-15 -4543 ((-926 (-592)) (-658 (-592)))) (-15 -4543 ((-926 (-592)))) (-15 -4241 ((-926 (-592)) (-658 (-592)))) (-15 -4241 ((-926 (-592)))) (-15 -3848 ((-926 (-592)) (-658 (-592)))) (-15 -3848 ((-926 (-592)))) (-15 -3933 ((-926 (-592)))) (-15 -3928 ((-926 (-592)) (-658 (-592)))) (-15 -3928 ((-926 (-592)) (-1000)))) 
+((-1441 (((-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191))) 10)) (-2629 (((-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191))) 9))) 
+(((-941 |#1|) (-10 -7 (-15 -2629 ((-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191)))) (-15 -1441 ((-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191))))) (-477)) (T -941)) 
+((-1441 (*1 *2 *2 *3) (-12 (-5 *2 (-658 (-980 *4))) (-5 *3 (-658 (-1191))) (-4 *4 (-477)) (-5 *1 (-941 *4)))) (-2629 (*1 *2 *2 *3) (-12 (-5 *2 (-658 (-980 *4))) (-5 *3 (-658 (-1191))) (-4 *4 (-477)) (-5 *1 (-941 *4))))) 
+(-10 -7 (-15 -2629 ((-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191)))) (-15 -1441 ((-658 (-980 |#1|)) (-658 (-980 |#1|)) (-658 (-1191))))) 
+((-1683 (((-332 |#1|) (-513)) 15))) 
+(((-942 |#1|) (-10 -7 (-15 -1683 ((-332 |#1|) (-513)))) (-13 (-869) (-582))) (T -942)) 
+((-1683 (*1 *2 *3) (-12 (-5 *3 (-513)) (-5 *2 (-332 *4)) (-5 *1 (-942 *4)) (-4 *4 (-13 (-869) (-582)))))) 
+(-10 -7 (-15 -1683 ((-332 |#1|) (-513)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-3558 (((-141) $) 30)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-943) (-1311)) (T -943)) 
+((-1491 (*1 *2 *3) (-12 (-4 *1 (-943)) (-5 *2 (-2 (|:| -1487 (-658 *1)) (|:| -2934 *1))) (-5 *3 (-658 *1)))) (-4539 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-658 *1)) (-4 *1 (-943))))) 
+(-13 (-477) (-10 -8 (-15 -1491 ((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $))) (-15 -4539 ((-3 (-658 $) "failed") (-658 $) $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-477) . T) ((-582) . T) ((-661 $) . T) ((-678) . T) ((-734 $) . T) ((-743) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3548 (($ $ $) NIL)) (-1683 (((-877) $) NIL)) (-1424 (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (-4257 (($) NIL T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (* (($ (-944) $) NIL) (($ $ $) NIL))) 
+(((-944) (-13 (-25) (-869) (-743) (-10 -8 (-15 -3548 ($ $ $)) (-6 (-4627 "*"))))) (T -944)) 
+((-3548 (*1 *1 *1 *1) (-5 *1 (-944)))) 
+(-13 (-25) (-869) (-743) (-10 -8 (-15 -3548 ($ $ $)) (-6 (-4627 "*")))) 
+((-2526 ((|#2| (-658 |#1|) (-658 |#1|)) 22))) 
+(((-945 |#1| |#2|) (-10 -7 (-15 -2526 (|#2| (-658 |#1|) (-658 |#1|)))) (-388) (-1255 |#1|)) (T -945)) 
+((-2526 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-4 *2 (-1255 *4)) (-5 *1 (-945 *4 *2))))) 
+(-10 -7 (-15 -2526 (|#2| (-658 |#1|) (-658 |#1|)))) 
+((-3014 (((-1187 |#2|) (-658 |#2|) (-658 |#2|)) 17) (((-1252 |#1| |#2|) (-1252 |#1| |#2|) (-658 |#2|) (-658 |#2|)) 13))) 
+(((-946 |#1| |#2|) (-10 -7 (-15 -3014 ((-1252 |#1| |#2|) (-1252 |#1| |#2|) (-658 |#2|) (-658 |#2|))) (-15 -3014 ((-1187 |#2|) (-658 |#2|) (-658 |#2|)))) (-1191) (-388)) (T -946)) 
+((-3014 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *5)) (-4 *5 (-388)) (-5 *2 (-1187 *5)) (-5 *1 (-946 *4 *5)) (-14 *4 (-1191)))) (-3014 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1252 *4 *5)) (-5 *3 (-658 *5)) (-14 *4 (-1191)) (-4 *5 (-388)) (-5 *1 (-946 *4 *5))))) 
+(-10 -7 (-15 -3014 ((-1252 |#1| |#2|) (-1252 |#1| |#2|) (-658 |#2|) (-658 |#2|))) (-15 -3014 ((-1187 |#2|) (-658 |#2|) (-658 |#2|)))) 
+((-1641 (((-141) $ $) 7)) (-2340 (((-1285) $ (-658 |#2|)) 19)) (-3034 (((-658 $)) 14)) (-3251 (((-1285) $ (-944)) 18)) (-3657 (((-258 $) (-658 $)) 23)) (-3693 (((-658 |#2|) $) 20)) (-3683 (((-141) $) 17)) (-2685 (((-1173) $) 9)) (-1850 (((-1285) $) 16)) (-2951 (((-1137) $) 10)) (-1362 (((-658 $)) 15)) (-3927 ((|#1| $ (-592)) 13)) (-4525 (((-944) $) 12)) (-2443 (($ (-658 |#1|)) 22) (($ (-1191)) 21)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6)) (-3306 (((-258 $) $ $) 28) (((-258 $) (-258 $) $) 27) (((-258 $) $ (-258 $)) 26) (((-258 $) $) 25)) (-3300 (((-258 $) $ $) 31) (((-258 $) (-258 $) $) 30) (((-258 $) $ (-258 $)) 29)) (* (((-258 $) (-592) $) 24))) 
+(((-947 |#1| |#2|) (-1311) (-388) (-665 |t#1|)) (T -947)) 
+((-3300 (*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)))) (-3300 (*1 *2 *2 *1) (-12 (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)))) (-3300 (*1 *2 *1 *2) (-12 (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)))) (-3306 (*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)))) (-3306 (*1 *2 *2 *1) (-12 (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)))) (-3306 (*1 *2 *1 *2) (-12 (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)))) (-3306 (*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)))) (* (*1 *2 *3 *1) (-12 (-5 *3 (-592)) (-4 *4 (-388)) (-4 *5 (-665 *4)) (-5 *2 (-258 *1)) (-4 *1 (-947 *4 *5)))) (-3657 (*1 *2 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-947 *4 *5)) (-4 *4 (-388)) (-4 *5 (-665 *4)) (-5 *2 (-258 *1)))) (-2443 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-947 *3 *4)) (-4 *4 (-665 *3)))) (-2443 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-4 *3 (-388)) (-4 *1 (-947 *3 *4)) (-4 *4 (-665 *3)))) (-3693 (*1 *2 *1) (-12 (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-658 *4)))) (-2340 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *5)) (-4 *1 (-947 *4 *5)) (-4 *4 (-388)) (-4 *5 (-665 *4)) (-5 *2 (-1285)))) (-3251 (*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-4 *1 (-947 *4 *5)) (-4 *4 (-388)) (-4 *5 (-665 *4)) (-5 *2 (-1285)))) (-3683 (*1 *2 *1) (-12 (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-141)))) (-1850 (*1 *2 *1) (-12 (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-1285)))) (-1362 (*1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-658 *1)) (-4 *1 (-947 *3 *4)))) (-3034 (*1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-658 *1)) (-4 *1 (-947 *3 *4)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-947 *2 *4)) (-4 *4 (-665 *2)) (-4 *2 (-388))))) 
+(-13 (-1117) (-10 -8 (-15 -3300 ((-258 $) $ $)) (-15 -3300 ((-258 $) (-258 $) $)) (-15 -3300 ((-258 $) $ (-258 $))) (-15 -3306 ((-258 $) $ $)) (-15 -3306 ((-258 $) (-258 $) $)) (-15 -3306 ((-258 $) $ (-258 $))) (-15 -3306 ((-258 $) $)) (-15 * ((-258 $) (-592) $)) (-15 -3657 ((-258 $) (-658 $))) (-15 -2443 ($ (-658 |t#1|))) (-15 -2443 ($ (-1191))) (-15 -3693 ((-658 |t#2|) $)) (-15 -2340 ((-1285) $ (-658 |t#2|))) (-15 -3251 ((-1285) $ (-944))) (-15 -3683 ((-141) $)) (-15 -1850 ((-1285) $)) (-15 -1362 ((-658 $))) (-15 -3034 ((-658 $))) (-15 -3927 (|t#1| $ (-592))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T) ((-1117) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2340 (((-1285) $ (-658 (-801 |#1|))) NIL)) (-3034 (((-658 $)) NIL)) (-3251 (((-1285) $ (-944)) NIL)) (-3657 (((-258 $) (-658 $)) NIL)) (-3693 (((-658 (-801 |#1|)) $) NIL)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-1850 (((-1285) $) NIL)) (-2951 (((-1137) $) NIL)) (-1362 (((-658 $)) NIL)) (-3927 ((|#1| $ (-592)) NIL)) (-4525 (((-944) $) NIL)) (-2443 (($ (-658 |#1|)) NIL) (($ (-1191)) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL)) (-3306 (((-258 $) $ $) NIL) (((-258 $) (-258 $) $) NIL) (((-258 $) $ (-258 $)) NIL) (((-258 $) $) NIL)) (-3300 (((-258 $) $ $) NIL) (((-258 $) (-258 $) $) NIL) (((-258 $) $ (-258 $)) NIL)) (* (((-258 $) (-592) $) NIL))) 
+(((-948 |#1|) (-947 |#1| (-801 |#1|)) (-388)) (T -948)) 
+NIL 
+(-947 |#1| (-801 |#1|)) 
+((-1641 (((-141) $ $) NIL)) (-2340 (((-1285) $ (-658 (-801 (-884 |#1|)))) NIL)) (-3034 (((-658 $)) NIL)) (-3251 (((-1285) $ (-944)) NIL)) (-3657 (((-258 $) (-658 $)) NIL)) (-3693 (((-658 (-801 (-884 |#1|))) $) NIL)) (-3683 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-1850 (((-1285) $) NIL)) (-2951 (((-1137) $) NIL)) (-1362 (((-658 $)) NIL)) (-3927 (((-884 |#1|) $ (-592)) NIL)) (-4525 (((-944) $) NIL)) (-2443 (($ (-658 (-884 |#1|))) NIL) (($ (-1191)) NIL)) (-1683 (((-877) $) NIL)) (-3255 (((-141) $ $) NIL)) (-3306 (((-258 $) $ $) NIL) (((-258 $) (-258 $) $) NIL) (((-258 $) $ (-258 $)) NIL) (((-258 $) $) NIL)) (-3300 (((-258 $) $ $) NIL) (((-258 $) (-258 $) $) NIL) (((-258 $) $ (-258 $)) NIL)) (* (((-258 $) (-592) $) NIL))) 
+(((-949 |#1|) (-947 (-884 |#1|) (-801 (-884 |#1|))) (-373)) (T -949)) 
+NIL 
+(-947 (-884 |#1|) (-801 (-884 |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2340 (((-1285) $ (-658 |#2|)) 73)) (-3034 (((-658 $)) 62)) (-3251 (((-1285) $ (-944)) 71)) (-3657 (((-258 $) (-658 $)) 27)) (-3693 (((-658 |#2|) $) 74)) (-3683 (((-141) $) 54)) (-2685 (((-1173) $) NIL)) (-1850 (((-1285) $) 57)) (-2951 (((-1137) $) NIL)) (-1362 (((-658 $)) 59)) (-3927 ((|#1| $ (-592)) 53)) (-4525 (((-944) $) 42)) (-2443 (($ (-658 |#1|)) 69) (($ (-1191)) 70)) (-1683 (((-877) $) 45)) (-3255 (((-141) $ $) 50)) (-3306 (((-258 $) $ $) 18) (((-258 $) (-258 $) $) 30) (((-258 $) $ (-258 $)) 31) (((-258 $) $) 33)) (-3300 (((-258 $) $ $) 16) (((-258 $) (-258 $) $) 28) (((-258 $) $ (-258 $)) 29)) (* (((-258 $) (-592) $) 21))) 
+(((-950 |#1| |#2|) (-947 |#1| |#2|) (-388) (-665 |#1|)) (T -950)) 
+NIL 
+(-947 |#1| |#2|) 
+((-2729 (((-592) (-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-1173)) 137)) (-1506 ((|#4| |#4|) 153)) (-2711 (((-658 (-433 (-980 |#1|))) (-658 (-1191))) 116)) (-4097 (((-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))) (-706 |#4|) (-658 (-433 (-980 |#1|))) (-658 (-658 |#4|)) (-790) (-790) (-592)) 73)) (-3936 (((-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-658 |#4|)) 57)) (-2388 (((-706 |#4|) (-706 |#4|) (-658 |#4|)) 53)) (-1618 (((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-1173)) 149)) (-2008 (((-592) (-706 |#4|) (-944) (-1173)) 130) (((-592) (-706 |#4|) (-658 (-1191)) (-944) (-1173)) 129) (((-592) (-706 |#4|) (-658 |#4|) (-944) (-1173)) 128) (((-592) (-706 |#4|) (-1173)) 125) (((-592) (-706 |#4|) (-658 (-1191)) (-1173)) 124) (((-592) (-706 |#4|) (-658 |#4|) (-1173)) 123) (((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-944)) 122) (((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 (-1191)) (-944)) 121) (((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 |#4|) (-944)) 120) (((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|)) 118) (((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 (-1191))) 117) (((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 |#4|)) 114)) (-1935 ((|#4| (-980 |#1|)) 66)) (-2986 (((-141) (-658 |#4|) (-658 (-658 |#4|))) 150)) (-2187 (((-658 (-658 (-592))) (-592) (-592)) 127)) (-3257 (((-658 (-658 |#4|)) (-658 (-658 |#4|))) 85)) (-2379 (((-790) (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|))))) 83)) (-4404 (((-790) (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|))))) 82)) (-3186 (((-141) (-658 (-980 |#1|))) 17) (((-141) (-658 |#4|)) 13)) (-4485 (((-2 (|:| |sysok| (-141)) (|:| |z0| (-658 |#4|)) (|:| |n0| (-658 |#4|))) (-658 |#4|) (-658 |#4|)) 69)) (-2319 (((-658 |#4|) |#4|) 47)) (-3938 (((-658 (-433 (-980 |#1|))) (-658 |#4|)) 112) (((-706 (-433 (-980 |#1|))) (-706 |#4|)) 54) (((-433 (-980 |#1|)) |#4|) 109)) (-4348 (((-2 (|:| |rgl| (-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))))))) (|:| |rgsz| (-592))) (-706 |#4|) (-658 (-433 (-980 |#1|))) (-790) (-1173) (-592)) 89)) (-3051 (((-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|)))) (-706 |#4|) (-790)) 81)) (-2721 (((-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592))))) (-706 |#4|) (-790)) 98)) (-2741 (((-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-2 (|:| -3253 (-706 (-433 (-980 |#1|)))) (|:| |vec| (-658 (-433 (-980 |#1|)))) (|:| -4175 (-790)) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592))))) 46))) 
+(((-951 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 |#4|))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 (-1191)))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 |#4|) (-944))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 (-1191)) (-944))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-944))) (-15 -2008 ((-592) (-706 |#4|) (-658 |#4|) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-658 (-1191)) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-658 |#4|) (-944) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-658 (-1191)) (-944) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-944) (-1173))) (-15 -2729 ((-592) (-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-1173))) (-15 -1618 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-1173))) (-15 -4348 ((-2 (|:| |rgl| (-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))))))) (|:| |rgsz| (-592))) (-706 |#4|) (-658 (-433 (-980 |#1|))) (-790) (-1173) (-592))) (-15 -3938 ((-433 (-980 |#1|)) |#4|)) (-15 -3938 ((-706 (-433 (-980 |#1|))) (-706 |#4|))) (-15 -3938 ((-658 (-433 (-980 |#1|))) (-658 |#4|))) (-15 -2711 ((-658 (-433 (-980 |#1|))) (-658 (-1191)))) (-15 -1935 (|#4| (-980 |#1|))) (-15 -4485 ((-2 (|:| |sysok| (-141)) (|:| |z0| (-658 |#4|)) (|:| |n0| (-658 |#4|))) (-658 |#4|) (-658 |#4|))) (-15 -3051 ((-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|)))) (-706 |#4|) (-790))) (-15 -3936 ((-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-658 |#4|))) (-15 -2741 ((-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-2 (|:| -3253 (-706 (-433 (-980 |#1|)))) (|:| |vec| (-658 (-433 (-980 |#1|)))) (|:| -4175 (-790)) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (-15 -2319 ((-658 |#4|) |#4|)) (-15 -4404 ((-790) (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|)))))) (-15 -2379 ((-790) (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|)))))) (-15 -3257 ((-658 (-658 |#4|)) (-658 (-658 |#4|)))) (-15 -2187 ((-658 (-658 (-592))) (-592) (-592))) (-15 -2986 ((-141) (-658 |#4|) (-658 (-658 |#4|)))) (-15 -2721 ((-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592))))) (-706 |#4|) (-790))) (-15 -2388 ((-706 |#4|) (-706 |#4|) (-658 |#4|))) (-15 -4097 ((-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))) (-706 |#4|) (-658 (-433 (-980 |#1|))) (-658 (-658 |#4|)) (-790) (-790) (-592))) (-15 -1506 (|#4| |#4|)) (-15 -3186 ((-141) (-658 |#4|))) (-15 -3186 ((-141) (-658 (-980 |#1|))))) (-13 (-323) (-171)) (-13 (-869) (-633 (-1191))) (-815) (-977 |#1| |#3| |#2|)) (T -951)) 
+((-3186 (*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-141)) (-5 *1 (-951 *4 *5 *6 *7)) (-4 *7 (-977 *4 *6 *5)))) (-3186 (*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-141)) (-5 *1 (-951 *4 *5 *6 *7)))) (-1506 (*1 *2 *2) (-12 (-4 *3 (-13 (-323) (-171))) (-4 *4 (-13 (-869) (-633 (-1191)))) (-4 *5 (-815)) (-5 *1 (-951 *3 *4 *5 *2)) (-4 *2 (-977 *3 *5 *4)))) (-4097 (*1 *2 *3 *4 *5 *6 *7 *7 *8) (-12 (-5 *3 (-2 (|:| |det| *12) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592))))) (-5 *4 (-706 *12)) (-5 *5 (-658 (-433 (-980 *9)))) (-5 *6 (-658 (-658 *12))) (-5 *7 (-790)) (-5 *8 (-592)) (-4 *9 (-13 (-323) (-171))) (-4 *12 (-977 *9 *11 *10)) (-4 *10 (-13 (-869) (-633 (-1191)))) (-4 *11 (-815)) (-5 *2 (-2 (|:| |eqzro| (-658 *12)) (|:| |neqzro| (-658 *12)) (|:| |wcond| (-658 (-980 *9))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *9)))) (|:| -2195 (-658 (-1280 (-433 (-980 *9))))))))) (-5 *1 (-951 *9 *10 *11 *12)))) (-2388 (*1 *2 *2 *3) (-12 (-5 *2 (-706 *7)) (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *1 (-951 *4 *5 *6 *7)))) (-2721 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-5 *4 (-790)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| |det| *8) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (-5 *1 (-951 *5 *6 *7 *8)))) (-2986 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-658 *8))) (-5 *3 (-658 *8)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-141)) (-5 *1 (-951 *5 *6 *7 *8)))) (-2187 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-658 (-592)))) (-5 *1 (-951 *4 *5 *6 *7)) (-5 *3 (-592)) (-4 *7 (-977 *4 *6 *5)))) (-3257 (*1 *2 *2) (-12 (-5 *2 (-658 (-658 *6))) (-4 *6 (-977 *3 *5 *4)) (-4 *3 (-13 (-323) (-171))) (-4 *4 (-13 (-869) (-633 (-1191)))) (-4 *5 (-815)) (-5 *1 (-951 *3 *4 *5 *6)))) (-2379 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| *7) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 *7))))) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-790)) (-5 *1 (-951 *4 *5 *6 *7)))) (-4404 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| *7) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 *7))))) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-790)) (-5 *1 (-951 *4 *5 *6 *7)))) (-2319 (*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 *3)) (-5 *1 (-951 *4 *5 *6 *3)) (-4 *3 (-977 *4 *6 *5)))) (-2741 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3253 (-706 (-433 (-980 *4)))) (|:| |vec| (-658 (-433 (-980 *4)))) (|:| -4175 (-790)) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592))))) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-2 (|:| |partsol| (-1280 (-433 (-980 *4)))) (|:| -2195 (-658 (-1280 (-433 (-980 *4))))))) (-5 *1 (-951 *4 *5 *6 *7)) (-4 *7 (-977 *4 *6 *5)))) (-3936 (*1 *2 *2 *3) (-12 (-5 *2 (-2 (|:| |partsol| (-1280 (-433 (-980 *4)))) (|:| -2195 (-658 (-1280 (-433 (-980 *4))))))) (-5 *3 (-658 *7)) (-4 *4 (-13 (-323) (-171))) (-4 *7 (-977 *4 *6 *5)) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *1 (-951 *4 *5 *6 *7)))) (-3051 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| *8) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 *8))))) (-5 *1 (-951 *5 *6 *7 *8)) (-5 *4 (-790)))) (-4485 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-4 *7 (-977 *4 *6 *5)) (-5 *2 (-2 (|:| |sysok| (-141)) (|:| |z0| (-658 *7)) (|:| |n0| (-658 *7)))) (-5 *1 (-951 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) (-1935 (*1 *2 *3) (-12 (-5 *3 (-980 *4)) (-4 *4 (-13 (-323) (-171))) (-4 *2 (-977 *4 *6 *5)) (-5 *1 (-951 *4 *5 *6 *2)) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)))) (-2711 (*1 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-433 (-980 *4)))) (-5 *1 (-951 *4 *5 *6 *7)) (-4 *7 (-977 *4 *6 *5)))) (-3938 (*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-433 (-980 *4)))) (-5 *1 (-951 *4 *5 *6 *7)))) (-3938 (*1 *2 *3) (-12 (-5 *3 (-706 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-706 (-433 (-980 *4)))) (-5 *1 (-951 *4 *5 *6 *7)))) (-3938 (*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-433 (-980 *4))) (-5 *1 (-951 *4 *5 *6 *3)) (-4 *3 (-977 *4 *6 *5)))) (-4348 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-706 *11)) (-5 *4 (-658 (-433 (-980 *8)))) (-5 *5 (-790)) (-5 *6 (-1173)) (-4 *8 (-13 (-323) (-171))) (-4 *11 (-977 *8 *10 *9)) (-4 *9 (-13 (-869) (-633 (-1191)))) (-4 *10 (-815)) (-5 *2 (-2 (|:| |rgl| (-658 (-2 (|:| |eqzro| (-658 *11)) (|:| |neqzro| (-658 *11)) (|:| |wcond| (-658 (-980 *8))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *8)))) (|:| -2195 (-658 (-1280 (-433 (-980 *8)))))))))) (|:| |rgsz| (-592)))) (-5 *1 (-951 *8 *9 *10 *11)) (-5 *7 (-592)))) (-1618 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *7)) (|:| |neqzro| (-658 *7)) (|:| |wcond| (-658 (-980 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *4)))) (|:| -2195 (-658 (-1280 (-433 (-980 *4)))))))))) (-5 *1 (-951 *4 *5 *6 *7)) (-4 *7 (-977 *4 *6 *5)))) (-2729 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| |eqzro| (-658 *8)) (|:| |neqzro| (-658 *8)) (|:| |wcond| (-658 (-980 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *5)))) (|:| -2195 (-658 (-1280 (-433 (-980 *5)))))))))) (-5 *4 (-1173)) (-4 *5 (-13 (-323) (-171))) (-4 *8 (-977 *5 *7 *6)) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *5 *6 *7 *8)))) (-2008 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *4 (-944)) (-5 *5 (-1173)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *6 *7 *8 *9)))) (-2008 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-706 *10)) (-5 *4 (-658 (-1191))) (-5 *5 (-944)) (-5 *6 (-1173)) (-4 *10 (-977 *7 *9 *8)) (-4 *7 (-13 (-323) (-171))) (-4 *8 (-13 (-869) (-633 (-1191)))) (-4 *9 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *7 *8 *9 *10)))) (-2008 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-706 *10)) (-5 *4 (-658 *10)) (-5 *5 (-944)) (-5 *6 (-1173)) (-4 *10 (-977 *7 *9 *8)) (-4 *7 (-13 (-323) (-171))) (-4 *8 (-13 (-869) (-633 (-1191)))) (-4 *9 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *7 *8 *9 *10)))) (-2008 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-5 *4 (-1173)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *5 *6 *7 *8)))) (-2008 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *4 (-658 (-1191))) (-5 *5 (-1173)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *6 *7 *8 *9)))) (-2008 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *4 (-658 *9)) (-5 *5 (-1173)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *6 *7 *8 *9)))) (-2008 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-5 *4 (-944)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *8)) (|:| |neqzro| (-658 *8)) (|:| |wcond| (-658 (-980 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *5)))) (|:| -2195 (-658 (-1280 (-433 (-980 *5)))))))))) (-5 *1 (-951 *5 *6 *7 *8)))) (-2008 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *4 (-658 (-1191))) (-5 *5 (-944)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *9)) (|:| |neqzro| (-658 *9)) (|:| |wcond| (-658 (-980 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *6)))) (|:| -2195 (-658 (-1280 (-433 (-980 *6)))))))))) (-5 *1 (-951 *6 *7 *8 *9)))) (-2008 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *5 (-944)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *9)) (|:| |neqzro| (-658 *9)) (|:| |wcond| (-658 (-980 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *6)))) (|:| -2195 (-658 (-1280 (-433 (-980 *6)))))))))) (-5 *1 (-951 *6 *7 *8 *9)) (-5 *4 (-658 *9)))) (-2008 (*1 *2 *3) (-12 (-5 *3 (-706 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *7)) (|:| |neqzro| (-658 *7)) (|:| |wcond| (-658 (-980 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *4)))) (|:| -2195 (-658 (-1280 (-433 (-980 *4)))))))))) (-5 *1 (-951 *4 *5 *6 *7)))) (-2008 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-5 *4 (-658 (-1191))) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *8)) (|:| |neqzro| (-658 *8)) (|:| |wcond| (-658 (-980 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *5)))) (|:| -2195 (-658 (-1280 (-433 (-980 *5)))))))))) (-5 *1 (-951 *5 *6 *7 *8)))) (-2008 (*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *8)) (|:| |neqzro| (-658 *8)) (|:| |wcond| (-658 (-980 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *5)))) (|:| -2195 (-658 (-1280 (-433 (-980 *5)))))))))) (-5 *1 (-951 *5 *6 *7 *8)) (-5 *4 (-658 *8))))) 
+(-10 -7 (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 |#4|))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 (-1191)))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 |#4|) (-944))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-658 (-1191)) (-944))) (-15 -2008 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-706 |#4|) (-944))) (-15 -2008 ((-592) (-706 |#4|) (-658 |#4|) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-658 (-1191)) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-658 |#4|) (-944) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-658 (-1191)) (-944) (-1173))) (-15 -2008 ((-592) (-706 |#4|) (-944) (-1173))) (-15 -2729 ((-592) (-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-1173))) (-15 -1618 ((-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|))))))))) (-1173))) (-15 -4348 ((-2 (|:| |rgl| (-658 (-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))))))) (|:| |rgsz| (-592))) (-706 |#4|) (-658 (-433 (-980 |#1|))) (-790) (-1173) (-592))) (-15 -3938 ((-433 (-980 |#1|)) |#4|)) (-15 -3938 ((-706 (-433 (-980 |#1|))) (-706 |#4|))) (-15 -3938 ((-658 (-433 (-980 |#1|))) (-658 |#4|))) (-15 -2711 ((-658 (-433 (-980 |#1|))) (-658 (-1191)))) (-15 -1935 (|#4| (-980 |#1|))) (-15 -4485 ((-2 (|:| |sysok| (-141)) (|:| |z0| (-658 |#4|)) (|:| |n0| (-658 |#4|))) (-658 |#4|) (-658 |#4|))) (-15 -3051 ((-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|)))) (-706 |#4|) (-790))) (-15 -3936 ((-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-658 |#4|))) (-15 -2741 ((-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))) (-2 (|:| -3253 (-706 (-433 (-980 |#1|)))) (|:| |vec| (-658 (-433 (-980 |#1|)))) (|:| -4175 (-790)) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (-15 -2319 ((-658 |#4|) |#4|)) (-15 -4404 ((-790) (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|)))))) (-15 -2379 ((-790) (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 |#4|)))))) (-15 -3257 ((-658 (-658 |#4|)) (-658 (-658 |#4|)))) (-15 -2187 ((-658 (-658 (-592))) (-592) (-592))) (-15 -2986 ((-141) (-658 |#4|) (-658 (-658 |#4|)))) (-15 -2721 ((-658 (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592))))) (-706 |#4|) (-790))) (-15 -2388 ((-706 |#4|) (-706 |#4|) (-658 |#4|))) (-15 -4097 ((-2 (|:| |eqzro| (-658 |#4|)) (|:| |neqzro| (-658 |#4|)) (|:| |wcond| (-658 (-980 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 |#1|)))) (|:| -2195 (-658 (-1280 (-433 (-980 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))) (-706 |#4|) (-658 (-433 (-980 |#1|))) (-658 (-658 |#4|)) (-790) (-790) (-592))) (-15 -1506 (|#4| |#4|)) (-15 -3186 ((-141) (-658 |#4|))) (-15 -3186 ((-141) (-658 (-980 |#1|))))) 
+((-3606 (((-954) |#1| (-1191)) 16) (((-954) |#1| (-1191) (-1113 (-237))) 20)) (-1489 (((-954) |#1| |#1| (-1191) (-1113 (-237))) 18) (((-954) |#1| (-1191) (-1113 (-237))) 14))) 
+(((-952 |#1|) (-10 -7 (-15 -1489 ((-954) |#1| (-1191) (-1113 (-237)))) (-15 -1489 ((-954) |#1| |#1| (-1191) (-1113 (-237)))) (-15 -3606 ((-954) |#1| (-1191) (-1113 (-237)))) (-15 -3606 ((-954) |#1| (-1191)))) (-633 (-565))) (T -952)) 
+((-3606 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-954)) (-5 *1 (-952 *3)) (-4 *3 (-633 (-565))))) (-3606 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-1113 (-237))) (-5 *2 (-954)) (-5 *1 (-952 *3)) (-4 *3 (-633 (-565))))) (-1489 (*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-1113 (-237))) (-5 *2 (-954)) (-5 *1 (-952 *3)) (-4 *3 (-633 (-565))))) (-1489 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-1113 (-237))) (-5 *2 (-954)) (-5 *1 (-952 *3)) (-4 *3 (-633 (-565)))))) 
+(-10 -7 (-15 -1489 ((-954) |#1| (-1191) (-1113 (-237)))) (-15 -1489 ((-954) |#1| |#1| (-1191) (-1113 (-237)))) (-15 -3606 ((-954) |#1| (-1191) (-1113 (-237)))) (-15 -3606 ((-954) |#1| (-1191)))) 
+((-2570 (($ $ (-1113 (-237)) (-1113 (-237)) (-1113 (-237))) 68)) (-3331 (((-1113 (-237)) $) 40)) (-1413 (((-1113 (-237)) $) 39)) (-4254 (((-1113 (-237)) $) 38)) (-1412 (((-658 (-658 (-237))) $) 43)) (-3397 (((-1113 (-237)) $) 41)) (-2237 (((-592) (-592)) 32)) (-4111 (((-592) (-592)) 28)) (-2475 (((-592) (-592)) 30)) (-3068 (((-141) (-141)) 35)) (-2413 (((-592)) 31)) (-4028 (($ $ (-1113 (-237))) 71) (($ $) 72)) (-3843 (($ (-1 (-971 (-237)) (-237)) (-1113 (-237))) 76) (($ (-1 (-971 (-237)) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237))) 77)) (-1489 (($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237))) 79) (($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237))) 80) (($ $ (-1113 (-237))) 74)) (-1987 (((-592)) 36)) (-2968 (((-592)) 27)) (-2577 (((-592)) 29)) (-1613 (((-658 (-658 (-971 (-237)))) $) 92)) (-4101 (((-141) (-141)) 37)) (-1683 (((-877) $) 91)) (-2316 (((-141)) 34))) 
+(((-953) (-13 (-1003) (-10 -8 (-15 -3843 ($ (-1 (-971 (-237)) (-237)) (-1113 (-237)))) (-15 -3843 ($ (-1 (-971 (-237)) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -1489 ($ $ (-1113 (-237)))) (-15 -2570 ($ $ (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -4028 ($ $ (-1113 (-237)))) (-15 -4028 ($ $)) (-15 -3397 ((-1113 (-237)) $)) (-15 -1412 ((-658 (-658 (-237))) $)) (-15 -2968 ((-592))) (-15 -4111 ((-592) (-592))) (-15 -2577 ((-592))) (-15 -2475 ((-592) (-592))) (-15 -2413 ((-592))) (-15 -2237 ((-592) (-592))) (-15 -2316 ((-141))) (-15 -3068 ((-141) (-141))) (-15 -1987 ((-592))) (-15 -4101 ((-141) (-141)))))) (T -953)) 
+((-3843 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-953)))) (-3843 (*1 *1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-953)))) (-1489 (*1 *1 *2 *2 *2 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-953)))) (-1489 (*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-953)))) (-1489 (*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-953)))) (-2570 (*1 *1 *1 *2 *2 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-953)))) (-4028 (*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-953)))) (-4028 (*1 *1 *1) (-5 *1 (-953))) (-3397 (*1 *2 *1) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-953)))) (-1412 (*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-237)))) (-5 *1 (-953)))) (-2968 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953)))) (-4111 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953)))) (-2577 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953)))) (-2475 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953)))) (-2413 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953)))) (-2237 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953)))) (-2316 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-953)))) (-3068 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-953)))) (-1987 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953)))) (-4101 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-953))))) 
+(-13 (-1003) (-10 -8 (-15 -3843 ($ (-1 (-971 (-237)) (-237)) (-1113 (-237)))) (-15 -3843 ($ (-1 (-971 (-237)) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -1489 ($ $ (-1113 (-237)))) (-15 -2570 ($ $ (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -4028 ($ $ (-1113 (-237)))) (-15 -4028 ($ $)) (-15 -3397 ((-1113 (-237)) $)) (-15 -1412 ((-658 (-658 (-237))) $)) (-15 -2968 ((-592))) (-15 -4111 ((-592) (-592))) (-15 -2577 ((-592))) (-15 -2475 ((-592) (-592))) (-15 -2413 ((-592))) (-15 -2237 ((-592) (-592))) (-15 -2316 ((-141))) (-15 -3068 ((-141) (-141))) (-15 -1987 ((-592))) (-15 -4101 ((-141) (-141))))) 
+((-2570 (($ $ (-1113 (-237))) 69) (($ $ (-1113 (-237)) (-1113 (-237))) 70)) (-1413 (((-1113 (-237)) $) 43)) (-4254 (((-1113 (-237)) $) 42)) (-3397 (((-1113 (-237)) $) 44)) (-3975 (((-592) (-592)) 36)) (-1522 (((-592) (-592)) 32)) (-2699 (((-592) (-592)) 34)) (-1707 (((-141) (-141)) 38)) (-1793 (((-592)) 35)) (-4028 (($ $ (-1113 (-237))) 73) (($ $) 74)) (-3843 (($ (-1 (-971 (-237)) (-237)) (-1113 (-237))) 83) (($ (-1 (-971 (-237)) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237))) 84)) (-3606 (($ (-1 (-237) (-237)) (-1113 (-237))) 91) (($ (-1 (-237) (-237))) 94)) (-1489 (($ (-1 (-237) (-237)) (-1113 (-237))) 78) (($ (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237))) 79) (($ (-658 (-1 (-237) (-237))) (-1113 (-237))) 86) (($ (-658 (-1 (-237) (-237))) (-1113 (-237)) (-1113 (-237))) 87) (($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237))) 80) (($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237))) 81) (($ $ (-1113 (-237))) 75)) (-4236 (((-141) $) 39)) (-3901 (((-592)) 40)) (-2320 (((-592)) 31)) (-3866 (((-592)) 33)) (-1613 (((-658 (-658 (-971 (-237)))) $) 22)) (-4439 (((-141) (-141)) 41)) (-1683 (((-877) $) 105)) (-2560 (((-141)) 37))) 
+(((-954) (-13 (-983) (-10 -8 (-15 -1489 ($ (-1 (-237) (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -1489 ($ (-658 (-1 (-237) (-237))) (-1113 (-237)))) (-15 -1489 ($ (-658 (-1 (-237) (-237))) (-1113 (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -3843 ($ (-1 (-971 (-237)) (-237)) (-1113 (-237)))) (-15 -3843 ($ (-1 (-971 (-237)) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -3606 ($ (-1 (-237) (-237)) (-1113 (-237)))) (-15 -3606 ($ (-1 (-237) (-237)))) (-15 -1489 ($ $ (-1113 (-237)))) (-15 -4236 ((-141) $)) (-15 -2570 ($ $ (-1113 (-237)))) (-15 -2570 ($ $ (-1113 (-237)) (-1113 (-237)))) (-15 -4028 ($ $ (-1113 (-237)))) (-15 -4028 ($ $)) (-15 -3397 ((-1113 (-237)) $)) (-15 -2320 ((-592))) (-15 -1522 ((-592) (-592))) (-15 -3866 ((-592))) (-15 -2699 ((-592) (-592))) (-15 -1793 ((-592))) (-15 -3975 ((-592) (-592))) (-15 -2560 ((-141))) (-15 -1707 ((-141) (-141))) (-15 -3901 ((-592))) (-15 -4439 ((-141) (-141)))))) (T -954)) 
+((-1489 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-1489 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-1489 (*1 *1 *2 *3) (-12 (-5 *2 (-658 (-1 (-237) (-237)))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-1489 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-658 (-1 (-237) (-237)))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-1489 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-1489 (*1 *1 *2 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-3843 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-3843 (*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-3606 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) (-3606 (*1 *1 *2) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *1 (-954)))) (-1489 (*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) (-4236 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-954)))) (-2570 (*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) (-2570 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) (-4028 (*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) (-4028 (*1 *1 *1) (-5 *1 (-954))) (-3397 (*1 *2 *1) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) (-2320 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954)))) (-1522 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954)))) (-3866 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954)))) (-2699 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954)))) (-1793 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954)))) (-3975 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954)))) (-2560 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-954)))) (-1707 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-954)))) (-3901 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954)))) (-4439 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-954))))) 
+(-13 (-983) (-10 -8 (-15 -1489 ($ (-1 (-237) (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -1489 ($ (-658 (-1 (-237) (-237))) (-1113 (-237)))) (-15 -1489 ($ (-658 (-1 (-237) (-237))) (-1113 (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)))) (-15 -1489 ($ (-1 (-237) (-237)) (-1 (-237) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -3843 ($ (-1 (-971 (-237)) (-237)) (-1113 (-237)))) (-15 -3843 ($ (-1 (-971 (-237)) (-237)) (-1113 (-237)) (-1113 (-237)) (-1113 (-237)))) (-15 -3606 ($ (-1 (-237) (-237)) (-1113 (-237)))) (-15 -3606 ($ (-1 (-237) (-237)))) (-15 -1489 ($ $ (-1113 (-237)))) (-15 -4236 ((-141) $)) (-15 -2570 ($ $ (-1113 (-237)))) (-15 -2570 ($ $ (-1113 (-237)) (-1113 (-237)))) (-15 -4028 ($ $ (-1113 (-237)))) (-15 -4028 ($ $)) (-15 -3397 ((-1113 (-237)) $)) (-15 -2320 ((-592))) (-15 -1522 ((-592) (-592))) (-15 -3866 ((-592))) (-15 -2699 ((-592) (-592))) (-15 -1793 ((-592))) (-15 -3975 ((-592) (-592))) (-15 -2560 ((-141))) (-15 -1707 ((-141) (-141))) (-15 -3901 ((-592))) (-15 -4439 ((-141) (-141))))) 
+((-2161 (((-658 (-1113 (-237))) (-658 (-658 (-971 (-237))))) 23))) 
+(((-955) (-10 -7 (-15 -2161 ((-658 (-1113 (-237))) (-658 (-658 (-971 (-237)))))))) (T -955)) 
+((-2161 (*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *2 (-658 (-1113 (-237)))) (-5 *1 (-955))))) 
+(-10 -7 (-15 -2161 ((-658 (-1113 (-237))) (-658 (-658 (-971 (-237))))))) 
+((-4322 ((|#2| |#2| |#5|) 39) ((|#2| |#2| |#5| (-592)) 20)) (-1509 (((-141) (-658 |#2|) |#5|) 23)) (-1748 (((-790) |#2| |#5| (-592)) 42) (((-790) |#2| |#5|) 41)) (-2701 ((|#2| |#2| |#5| (-592)) 45) ((|#2| |#2| |#5|) 44)) (-2806 ((|#1| |#2| |#5|) 21))) 
+(((-956 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1509 ((-141) (-658 |#2|) |#5|)) (-15 -2806 (|#1| |#2| |#5|)) (-15 -4322 (|#2| |#2| |#5| (-592))) (-15 -4322 (|#2| |#2| |#5|)) (-15 -2701 (|#2| |#2| |#5|)) (-15 -2701 (|#2| |#2| |#5| (-592))) (-15 -1748 ((-790) |#2| |#5|)) (-15 -1748 ((-790) |#2| |#5| (-592)))) (-388) (-346 |#1| |#3|) (-252 |#4| (-790)) (-790) (-999 |#1|)) (T -956)) 
+((-1748 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-592)) (-4 *6 (-388)) (-4 *7 (-252 *8 *2)) (-14 *8 *2) (-5 *2 (-790)) (-5 *1 (-956 *6 *3 *7 *8 *4)) (-4 *3 (-346 *6 *7)) (-4 *4 (-999 *6)))) (-1748 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-252 *7 *2)) (-14 *7 *2) (-5 *2 (-790)) (-5 *1 (-956 *5 *3 *6 *7 *4)) (-4 *3 (-346 *5 *6)) (-4 *4 (-999 *5)))) (-2701 (*1 *2 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-388)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-5 *1 (-956 *5 *2 *6 *7 *3)) (-4 *2 (-346 *5 *6)) (-4 *3 (-999 *5)))) (-2701 (*1 *2 *2 *3) (-12 (-4 *4 (-388)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-956 *4 *2 *5 *6 *3)) (-4 *2 (-346 *4 *5)) (-4 *3 (-999 *4)))) (-4322 (*1 *2 *2 *3) (-12 (-4 *4 (-388)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-956 *4 *2 *5 *6 *3)) (-4 *2 (-346 *4 *5)) (-4 *3 (-999 *4)))) (-4322 (*1 *2 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-388)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-5 *1 (-956 *5 *2 *6 *7 *3)) (-4 *2 (-346 *5 *6)) (-4 *3 (-999 *5)))) (-2806 (*1 *2 *3 *4) (-12 (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-4 *2 (-388)) (-5 *1 (-956 *2 *3 *5 *6 *4)) (-4 *3 (-346 *2 *5)) (-4 *4 (-999 *2)))) (-1509 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-4 *6 (-346 *5 *7)) (-4 *7 (-252 *8 (-790))) (-14 *8 (-790)) (-4 *5 (-388)) (-5 *2 (-141)) (-5 *1 (-956 *5 *6 *7 *8 *4)) (-4 *4 (-999 *5))))) 
+(-10 -7 (-15 -1509 ((-141) (-658 |#2|) |#5|)) (-15 -2806 (|#1| |#2| |#5|)) (-15 -4322 (|#2| |#2| |#5| (-592))) (-15 -4322 (|#2| |#2| |#5|)) (-15 -2701 (|#2| |#2| |#5|)) (-15 -2701 (|#2| |#2| |#5| (-592))) (-15 -1748 ((-790) |#2| |#5|)) (-15 -1748 ((-790) |#2| |#5| (-592)))) 
+((-3243 ((|#2| |#2|) 25)) (-3237 ((|#2| |#2|) 26)) (-4249 ((|#2| |#2|) 24)) (-3366 ((|#2| |#2| (-1173)) 23))) 
+(((-957 |#1| |#2|) (-10 -7 (-15 -3366 (|#2| |#2| (-1173))) (-15 -4249 (|#2| |#2|)) (-15 -3243 (|#2| |#2|)) (-15 -3237 (|#2| |#2|))) (-869) (-456 |#1|)) (T -957)) 
+((-3237 (*1 *2 *2) (-12 (-4 *3 (-869)) (-5 *1 (-957 *3 *2)) (-4 *2 (-456 *3)))) (-3243 (*1 *2 *2) (-12 (-4 *3 (-869)) (-5 *1 (-957 *3 *2)) (-4 *2 (-456 *3)))) (-4249 (*1 *2 *2) (-12 (-4 *3 (-869)) (-5 *1 (-957 *3 *2)) (-4 *2 (-456 *3)))) (-3366 (*1 *2 *2 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-869)) (-5 *1 (-957 *4 *2)) (-4 *2 (-456 *4))))) 
+(-10 -7 (-15 -3366 (|#2| |#2| (-1173))) (-15 -4249 (|#2| |#2|)) (-15 -3243 (|#2| |#2|)) (-15 -3237 (|#2| |#2|))) 
+((-3243 (((-332 (-592)) (-1191)) 15)) (-3237 (((-332 (-592)) (-1191)) 13)) (-4249 (((-332 (-592)) (-1191)) 11)) (-3366 (((-332 (-592)) (-1191) (-1173)) 18))) 
+(((-958) (-10 -7 (-15 -3366 ((-332 (-592)) (-1191) (-1173))) (-15 -4249 ((-332 (-592)) (-1191))) (-15 -3243 ((-332 (-592)) (-1191))) (-15 -3237 ((-332 (-592)) (-1191))))) (T -958)) 
+((-3237 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-332 (-592))) (-5 *1 (-958)))) (-3243 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-332 (-592))) (-5 *1 (-958)))) (-4249 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-332 (-592))) (-5 *1 (-958)))) (-3366 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-1173)) (-5 *2 (-332 (-592))) (-5 *1 (-958))))) 
+(-10 -7 (-15 -3366 ((-332 (-592)) (-1191) (-1173))) (-15 -4249 ((-332 (-592)) (-1191))) (-15 -3243 ((-332 (-592)) (-1191))) (-15 -3237 ((-332 (-592)) (-1191)))) 
+((-3412 (((-911 |#1| |#3|) |#2| (-914 |#1|) (-911 |#1| |#3|)) 24)) (-3129 (((-1 (-141) |#2|) (-1 (-141) |#3|)) 12))) 
+(((-959 |#1| |#2| |#3|) (-10 -7 (-15 -3129 ((-1 (-141) |#2|) (-1 (-141) |#3|))) (-15 -3412 ((-911 |#1| |#3|) |#2| (-914 |#1|) (-911 |#1| |#3|)))) (-1119) (-908 |#1|) (-13 (-1119) (-1065 |#2|))) (T -959)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *6)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *6 (-13 (-1119) (-1065 *3))) (-4 *3 (-908 *5)) (-5 *1 (-959 *5 *3 *6)))) (-3129 (*1 *2 *3) (-12 (-5 *3 (-1 (-141) *6)) (-4 *6 (-13 (-1119) (-1065 *5))) (-4 *5 (-908 *4)) (-4 *4 (-1119)) (-5 *2 (-1 (-141) *5)) (-5 *1 (-959 *4 *5 *6))))) 
+(-10 -7 (-15 -3129 ((-1 (-141) |#2|) (-1 (-141) |#3|))) (-15 -3412 ((-911 |#1| |#3|) |#2| (-914 |#1|) (-911 |#1| |#3|)))) 
+((-3412 (((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)) 29))) 
+(((-960 |#1| |#2| |#3|) (-10 -7 (-15 -3412 ((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)))) (-1119) (-13 (-582) (-869) (-908 |#1|)) (-13 (-456 |#2|) (-633 (-914 |#1|)) (-908 |#1|) (-1065 (-631 $)))) (T -960)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *3)) (-4 *5 (-1119)) (-4 *3 (-13 (-456 *6) (-633 *4) (-908 *5) (-1065 (-631 $)))) (-5 *4 (-914 *5)) (-4 *6 (-13 (-582) (-869) (-908 *5))) (-5 *1 (-960 *5 *6 *3))))) 
+(-10 -7 (-15 -3412 ((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)))) 
+((-3412 (((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|)) 12))) 
+(((-961 |#1|) (-10 -7 (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|)))) (-574)) (T -961)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 (-592) *3)) (-5 *4 (-914 (-592))) (-4 *3 (-574)) (-5 *1 (-961 *3))))) 
+(-10 -7 (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|)))) 
+((-3412 (((-911 |#1| |#2|) (-631 |#2|) (-914 |#1|) (-911 |#1| |#2|)) 52))) 
+(((-962 |#1| |#2|) (-10 -7 (-15 -3412 ((-911 |#1| |#2|) (-631 |#2|) (-914 |#1|) (-911 |#1| |#2|)))) (-1119) (-13 (-869) (-1065 (-631 $)) (-633 (-914 |#1|)) (-908 |#1|))) (T -962)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *6)) (-5 *3 (-631 *6)) (-4 *5 (-1119)) (-4 *6 (-13 (-869) (-1065 (-631 $)) (-633 *4) (-908 *5))) (-5 *4 (-914 *5)) (-5 *1 (-962 *5 *6))))) 
+(-10 -7 (-15 -3412 ((-911 |#1| |#2|) (-631 |#2|) (-914 |#1|) (-911 |#1| |#2|)))) 
+((-3412 (((-907 |#1| |#2| |#3|) |#3| (-914 |#1|) (-907 |#1| |#2| |#3|)) 14))) 
+(((-963 |#1| |#2| |#3|) (-10 -7 (-15 -3412 ((-907 |#1| |#2| |#3|) |#3| (-914 |#1|) (-907 |#1| |#2| |#3|)))) (-1119) (-908 |#1|) (-683 |#2|)) (T -963)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-907 *5 *6 *3)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *6 (-908 *5)) (-4 *3 (-683 *6)) (-5 *1 (-963 *5 *6 *3))))) 
+(-10 -7 (-15 -3412 ((-907 |#1| |#2| |#3|) |#3| (-914 |#1|) (-907 |#1| |#2| |#3|)))) 
+((-3412 (((-911 |#1| |#5|) |#5| (-914 |#1|) (-911 |#1| |#5|)) 17 (|has| |#3| (-908 |#1|))) (((-911 |#1| |#5|) |#5| (-914 |#1|) (-911 |#1| |#5|) (-1 (-911 |#1| |#5|) |#3| (-914 |#1|) (-911 |#1| |#5|))) 16))) 
+(((-964 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3412 ((-911 |#1| |#5|) |#5| (-914 |#1|) (-911 |#1| |#5|) (-1 (-911 |#1| |#5|) |#3| (-914 |#1|) (-911 |#1| |#5|)))) (IF (|has| |#3| (-908 |#1|)) (-15 -3412 ((-911 |#1| |#5|) |#5| (-914 |#1|) (-911 |#1| |#5|))) |noBranch|)) (-1119) (-815) (-869) (-13 (-1075) (-869) (-908 |#1|)) (-13 (-977 |#4| |#2| |#3|) (-633 (-914 |#1|)))) (T -964)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *3)) (-4 *5 (-1119)) (-4 *3 (-13 (-977 *8 *6 *7) (-633 *4))) (-5 *4 (-914 *5)) (-4 *7 (-908 *5)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-13 (-1075) (-869) (-908 *5))) (-5 *1 (-964 *5 *6 *7 *8 *3)))) (-3412 (*1 *2 *3 *4 *2 *5) (-12 (-5 *5 (-1 (-911 *6 *3) *8 (-914 *6) (-911 *6 *3))) (-4 *8 (-869)) (-5 *2 (-911 *6 *3)) (-5 *4 (-914 *6)) (-4 *6 (-1119)) (-4 *3 (-13 (-977 *9 *7 *8) (-633 *4))) (-4 *7 (-815)) (-4 *9 (-13 (-1075) (-869) (-908 *6))) (-5 *1 (-964 *6 *7 *8 *9 *3))))) 
+(-10 -7 (-15 -3412 ((-911 |#1| |#5|) |#5| (-914 |#1|) (-911 |#1| |#5|) (-1 (-911 |#1| |#5|) |#3| (-914 |#1|) (-911 |#1| |#5|)))) (IF (|has| |#3| (-908 |#1|)) (-15 -3412 ((-911 |#1| |#5|) |#5| (-914 |#1|) (-911 |#1| |#5|))) |noBranch|)) 
+((-4355 ((|#2| |#2| (-658 (-1 (-141) |#3|))) 11) ((|#2| |#2| (-1 (-141) |#3|)) 12))) 
+(((-965 |#1| |#2| |#3|) (-10 -7 (-15 -4355 (|#2| |#2| (-1 (-141) |#3|))) (-15 -4355 (|#2| |#2| (-658 (-1 (-141) |#3|))))) (-869) (-456 |#1|) (-1225)) (T -965)) 
+((-4355 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-1 (-141) *5))) (-4 *5 (-1225)) (-4 *4 (-869)) (-5 *1 (-965 *4 *2 *5)) (-4 *2 (-456 *4)))) (-4355 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-141) *5)) (-4 *5 (-1225)) (-4 *4 (-869)) (-5 *1 (-965 *4 *2 *5)) (-4 *2 (-456 *4))))) 
+(-10 -7 (-15 -4355 (|#2| |#2| (-1 (-141) |#3|))) (-15 -4355 (|#2| |#2| (-658 (-1 (-141) |#3|))))) 
+((-4355 (((-332 (-592)) (-1191) (-658 (-1 (-141) |#1|))) 16) (((-332 (-592)) (-1191) (-1 (-141) |#1|)) 13))) 
+(((-966 |#1|) (-10 -7 (-15 -4355 ((-332 (-592)) (-1191) (-1 (-141) |#1|))) (-15 -4355 ((-332 (-592)) (-1191) (-658 (-1 (-141) |#1|))))) (-1225)) (T -966)) 
+((-4355 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-658 (-1 (-141) *5))) (-4 *5 (-1225)) (-5 *2 (-332 (-592))) (-5 *1 (-966 *5)))) (-4355 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-1 (-141) *5)) (-4 *5 (-1225)) (-5 *2 (-332 (-592))) (-5 *1 (-966 *5))))) 
+(-10 -7 (-15 -4355 ((-332 (-592)) (-1191) (-1 (-141) |#1|))) (-15 -4355 ((-332 (-592)) (-1191) (-658 (-1 (-141) |#1|))))) 
+((-3412 (((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)) 25))) 
+(((-967 |#1| |#2| |#3|) (-10 -7 (-15 -3412 ((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)))) (-1119) (-13 (-582) (-908 |#1|) (-633 (-914 |#1|))) (-1021 |#2|)) (T -967)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *3)) (-4 *5 (-1119)) (-4 *3 (-1021 *6)) (-4 *6 (-13 (-582) (-908 *5) (-633 *4))) (-5 *4 (-914 *5)) (-5 *1 (-967 *5 *6 *3))))) 
+(-10 -7 (-15 -3412 ((-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)))) 
+((-3412 (((-911 |#1| (-1191)) (-1191) (-914 |#1|) (-911 |#1| (-1191))) 17))) 
+(((-968 |#1|) (-10 -7 (-15 -3412 ((-911 |#1| (-1191)) (-1191) (-914 |#1|) (-911 |#1| (-1191))))) (-1119)) (T -968)) 
+((-3412 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 (-1191))) (-5 *3 (-1191)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-5 *1 (-968 *5))))) 
+(-10 -7 (-15 -3412 ((-911 |#1| (-1191)) (-1191) (-914 |#1|) (-911 |#1| (-1191))))) 
+((-3908 (((-911 |#1| |#3|) (-658 |#3|) (-658 (-914 |#1|)) (-911 |#1| |#3|) (-1 (-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|))) 33)) (-3412 (((-911 |#1| |#3|) (-658 |#3|) (-658 (-914 |#1|)) (-1 |#3| (-658 |#3|)) (-911 |#1| |#3|) (-1 (-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|))) 32))) 
+(((-969 |#1| |#2| |#3|) (-10 -7 (-15 -3412 ((-911 |#1| |#3|) (-658 |#3|) (-658 (-914 |#1|)) (-1 |#3| (-658 |#3|)) (-911 |#1| |#3|) (-1 (-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)))) (-15 -3908 ((-911 |#1| |#3|) (-658 |#3|) (-658 (-914 |#1|)) (-911 |#1| |#3|) (-1 (-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|))))) (-1119) (-13 (-1075) (-869)) (-13 (-1075) (-633 (-914 |#1|)) (-1065 |#2|))) (T -969)) 
+((-3908 (*1 *2 *3 *4 *2 *5) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 (-914 *6))) (-5 *5 (-1 (-911 *6 *8) *8 (-914 *6) (-911 *6 *8))) (-4 *6 (-1119)) (-4 *8 (-13 (-1075) (-633 (-914 *6)) (-1065 *7))) (-5 *2 (-911 *6 *8)) (-4 *7 (-13 (-1075) (-869))) (-5 *1 (-969 *6 *7 *8)))) (-3412 (*1 *2 *3 *4 *5 *2 *6) (-12 (-5 *4 (-658 (-914 *7))) (-5 *5 (-1 *9 (-658 *9))) (-5 *6 (-1 (-911 *7 *9) *9 (-914 *7) (-911 *7 *9))) (-4 *7 (-1119)) (-4 *9 (-13 (-1075) (-633 (-914 *7)) (-1065 *8))) (-5 *2 (-911 *7 *9)) (-5 *3 (-658 *9)) (-4 *8 (-13 (-1075) (-869))) (-5 *1 (-969 *7 *8 *9))))) 
+(-10 -7 (-15 -3412 ((-911 |#1| |#3|) (-658 |#3|) (-658 (-914 |#1|)) (-1 |#3| (-658 |#3|)) (-911 |#1| |#3|) (-1 (-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|)))) (-15 -3908 ((-911 |#1| |#3|) (-658 |#3|) (-658 (-914 |#1|)) (-911 |#1| |#3|) (-1 (-911 |#1| |#3|) |#3| (-914 |#1|) (-911 |#1| |#3|))))) 
+((-1880 (((-1187 (-433 (-592))) (-592)) 61)) (-1381 (((-1187 (-592)) (-592)) 64)) (-1893 (((-1187 (-592)) (-592)) 58)) (-4378 (((-592) (-1187 (-592))) 53)) (-3824 (((-1187 (-433 (-592))) (-592)) 47)) (-4446 (((-1187 (-592)) (-592)) 36)) (-1787 (((-1187 (-592)) (-592)) 66)) (-1843 (((-1187 (-592)) (-592)) 65)) (-4017 (((-1187 (-433 (-592))) (-592)) 49))) 
+(((-970) (-10 -7 (-15 -4017 ((-1187 (-433 (-592))) (-592))) (-15 -1843 ((-1187 (-592)) (-592))) (-15 -1787 ((-1187 (-592)) (-592))) (-15 -4446 ((-1187 (-592)) (-592))) (-15 -3824 ((-1187 (-433 (-592))) (-592))) (-15 -4378 ((-592) (-1187 (-592)))) (-15 -1893 ((-1187 (-592)) (-592))) (-15 -1381 ((-1187 (-592)) (-592))) (-15 -1880 ((-1187 (-433 (-592))) (-592))))) (T -970)) 
+((-1880 (*1 *2 *3) (-12 (-5 *2 (-1187 (-433 (-592)))) (-5 *1 (-970)) (-5 *3 (-592)))) (-1381 (*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592)))) (-1893 (*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592)))) (-4378 (*1 *2 *3) (-12 (-5 *3 (-1187 (-592))) (-5 *2 (-592)) (-5 *1 (-970)))) (-3824 (*1 *2 *3) (-12 (-5 *2 (-1187 (-433 (-592)))) (-5 *1 (-970)) (-5 *3 (-592)))) (-4446 (*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592)))) (-1787 (*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592)))) (-1843 (*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592)))) (-4017 (*1 *2 *3) (-12 (-5 *2 (-1187 (-433 (-592)))) (-5 *1 (-970)) (-5 *3 (-592))))) 
+(-10 -7 (-15 -4017 ((-1187 (-433 (-592))) (-592))) (-15 -1843 ((-1187 (-592)) (-592))) (-15 -1787 ((-1187 (-592)) (-592))) (-15 -4446 ((-1187 (-592)) (-592))) (-15 -3824 ((-1187 (-433 (-592))) (-592))) (-15 -4378 ((-592) (-1187 (-592)))) (-15 -1893 ((-1187 (-592)) (-592))) (-15 -1381 ((-1187 (-592)) (-592))) (-15 -1880 ((-1187 (-433 (-592))) (-592)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1417 (($ (-790)) NIL (|has| |#1| (-23)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) NIL) (((-141) $) NIL (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) |#1|) 11 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-1721 (((-592) (-1 (-141) |#1|) $) NIL) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119)))) (-1831 (($ (-658 |#1|)) 13)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-4363 (((-706 |#1|) $ $) NIL (|has| |#1| (-1075)))) (-3242 (($ (-790) |#1|) 8)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 10 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2311 ((|#1| $) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1075))))) (-2554 (((-141) $ (-790)) NIL)) (-4233 ((|#1| $) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1075))))) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) NIL (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-2807 (($ $ (-658 |#1|)) 24)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) |#1|) NIL) ((|#1| $ (-592)) 18) (($ $ (-1246 (-592))) NIL)) (-1729 ((|#1| $ $) NIL (|has| |#1| (-1075)))) (-1936 (((-944) $) 16)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-2746 (($ $ $) 22)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565)))) (($ (-658 |#1|)) 17)) (-4466 (($ (-658 |#1|)) NIL)) (-2266 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) 23) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3306 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-3300 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-592) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-743))) (($ $ |#1|) NIL (|has| |#1| (-743)))) (-1699 (((-790) $) 14 (|has| $ (-6 -4625))))) 
+(((-971 |#1|) (-1009 |#1|) (-1075)) (T -971)) 
+NIL 
+(-1009 |#1|) 
+((-2384 (((-516 |#1| |#2|) (-980 |#2|)) 17)) (-1942 (((-264 |#1| |#2|) (-980 |#2|)) 29)) (-3829 (((-980 |#2|) (-516 |#1| |#2|)) 22)) (-2763 (((-264 |#1| |#2|) (-516 |#1| |#2|)) 53)) (-4587 (((-980 |#2|) (-264 |#1| |#2|)) 26)) (-2694 (((-516 |#1| |#2|) (-264 |#1| |#2|)) 44))) 
+(((-972 |#1| |#2|) (-10 -7 (-15 -2694 ((-516 |#1| |#2|) (-264 |#1| |#2|))) (-15 -2763 ((-264 |#1| |#2|) (-516 |#1| |#2|))) (-15 -2384 ((-516 |#1| |#2|) (-980 |#2|))) (-15 -3829 ((-980 |#2|) (-516 |#1| |#2|))) (-15 -4587 ((-980 |#2|) (-264 |#1| |#2|))) (-15 -1942 ((-264 |#1| |#2|) (-980 |#2|)))) (-658 (-1191)) (-1075)) (T -972)) 
+((-1942 (*1 *2 *3) (-12 (-5 *3 (-980 *5)) (-4 *5 (-1075)) (-5 *2 (-264 *4 *5)) (-5 *1 (-972 *4 *5)) (-14 *4 (-658 (-1191))))) (-4587 (*1 *2 *3) (-12 (-5 *3 (-264 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-1075)) (-5 *2 (-980 *5)) (-5 *1 (-972 *4 *5)))) (-3829 (*1 *2 *3) (-12 (-5 *3 (-516 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-1075)) (-5 *2 (-980 *5)) (-5 *1 (-972 *4 *5)))) (-2384 (*1 *2 *3) (-12 (-5 *3 (-980 *5)) (-4 *5 (-1075)) (-5 *2 (-516 *4 *5)) (-5 *1 (-972 *4 *5)) (-14 *4 (-658 (-1191))))) (-2763 (*1 *2 *3) (-12 (-5 *3 (-516 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-1075)) (-5 *2 (-264 *4 *5)) (-5 *1 (-972 *4 *5)))) (-2694 (*1 *2 *3) (-12 (-5 *3 (-264 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-1075)) (-5 *2 (-516 *4 *5)) (-5 *1 (-972 *4 *5))))) 
+(-10 -7 (-15 -2694 ((-516 |#1| |#2|) (-264 |#1| |#2|))) (-15 -2763 ((-264 |#1| |#2|) (-516 |#1| |#2|))) (-15 -2384 ((-516 |#1| |#2|) (-980 |#2|))) (-15 -3829 ((-980 |#2|) (-516 |#1| |#2|))) (-15 -4587 ((-980 |#2|) (-264 |#1| |#2|))) (-15 -1942 ((-264 |#1| |#2|) (-980 |#2|)))) 
+((-2961 (((-658 |#2|) |#2| |#2|) 10)) (-3618 (((-790) (-658 |#1|)) 37 (|has| |#1| (-867)))) (-3689 (((-658 |#2|) |#2|) 11)) (-2431 (((-790) (-658 |#1|) (-592) (-592)) 36 (|has| |#1| (-867)))) (-3408 ((|#1| |#2|) 32 (|has| |#1| (-867))))) 
+(((-973 |#1| |#2|) (-10 -7 (-15 -2961 ((-658 |#2|) |#2| |#2|)) (-15 -3689 ((-658 |#2|) |#2|)) (IF (|has| |#1| (-867)) (PROGN (-15 -3408 (|#1| |#2|)) (-15 -3618 ((-790) (-658 |#1|))) (-15 -2431 ((-790) (-658 |#1|) (-592) (-592)))) |noBranch|)) (-388) (-1255 |#1|)) (T -973)) 
+((-2431 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-592)) (-4 *5 (-867)) (-4 *5 (-388)) (-5 *2 (-790)) (-5 *1 (-973 *5 *6)) (-4 *6 (-1255 *5)))) (-3618 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-867)) (-4 *4 (-388)) (-5 *2 (-790)) (-5 *1 (-973 *4 *5)) (-4 *5 (-1255 *4)))) (-3408 (*1 *2 *3) (-12 (-4 *2 (-388)) (-4 *2 (-867)) (-5 *1 (-973 *2 *3)) (-4 *3 (-1255 *2)))) (-3689 (*1 *2 *3) (-12 (-4 *4 (-388)) (-5 *2 (-658 *3)) (-5 *1 (-973 *4 *3)) (-4 *3 (-1255 *4)))) (-2961 (*1 *2 *3 *3) (-12 (-4 *4 (-388)) (-5 *2 (-658 *3)) (-5 *1 (-973 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -2961 ((-658 |#2|) |#2| |#2|)) (-15 -3689 ((-658 |#2|) |#2|)) (IF (|has| |#1| (-867)) (PROGN (-15 -3408 (|#1| |#2|)) (-15 -3618 ((-790) (-658 |#1|))) (-15 -2431 ((-790) (-658 |#1|) (-592) (-592)))) |noBranch|)) 
+((-2731 (((-980 |#2|) (-1 |#2| |#1|) (-980 |#1|)) 18))) 
+(((-974 |#1| |#2|) (-10 -7 (-15 -2731 ((-980 |#2|) (-1 |#2| |#1|) (-980 |#1|)))) (-1075) (-1075)) (T -974)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-980 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-980 *6)) (-5 *1 (-974 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-980 |#2|) (-1 |#2| |#1|) (-980 |#1|)))) 
+((-4492 (((-1252 |#1| (-980 |#2|)) (-980 |#2|) (-1276 |#1|)) 18))) 
+(((-975 |#1| |#2|) (-10 -7 (-15 -4492 ((-1252 |#1| (-980 |#2|)) (-980 |#2|) (-1276 |#1|)))) (-1191) (-1075)) (T -975)) 
+((-4492 (*1 *2 *3 *4) (-12 (-5 *4 (-1276 *5)) (-14 *5 (-1191)) (-4 *6 (-1075)) (-5 *2 (-1252 *5 (-980 *6))) (-5 *1 (-975 *5 *6)) (-5 *3 (-980 *6))))) 
+(-10 -7 (-15 -4492 ((-1252 |#1| (-980 |#2|)) (-980 |#2|) (-1276 |#1|)))) 
+((-2189 (((-790) $) 69) (((-790) $ (-658 |#4|)) 72)) (-3743 (($ $) 169)) (-3164 (((-444 $) $) 161)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 112)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 (-592) "failed") $) NIL) (((-3 |#4| "failed") $) 58)) (-2400 ((|#2| $) NIL) (((-433 (-592)) $) NIL) (((-592) $) NIL) ((|#4| $) 57)) (-1544 (($ $ $ |#4|) 74)) (-3945 (((-706 (-592)) (-706 $)) NIL) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) 102) (((-706 |#2|) (-706 $)) 95)) (-3262 (($ $) 177) (($ $ |#4|) 180)) (-4585 (((-658 $) $) 61)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 195) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 189)) (-3108 (((-658 $) $) 27)) (-4526 (($ |#2| |#3|) NIL) (($ $ |#4| (-790)) NIL) (($ $ (-658 |#4|) (-658 (-790))) 55)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ |#4|) 158)) (-4421 (((-3 (-658 $) "failed") $) 41)) (-2947 (((-3 (-658 $) "failed") $) 30)) (-2257 (((-3 (-2 (|:| |var| |#4|) (|:| -3215 (-790))) "failed") $) 45)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 105)) (-1416 (((-444 (-1187 $)) (-1187 $)) 118)) (-3339 (((-444 (-1187 $)) (-1187 $)) 116)) (-4500 (((-444 $) $) 136)) (-2806 (($ $ (-658 (-310 $))) 20) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ |#4| |#2|) NIL) (($ $ (-658 |#4|) (-658 |#2|)) NIL) (($ $ |#4| $) NIL) (($ $ (-658 |#4|) (-658 $)) NIL)) (-1482 (($ $ |#4|) 76)) (-1778 (((-914 (-405)) $) 209) (((-914 (-592)) $) 202) (((-565) $) 217)) (-1554 ((|#2| $) NIL) (($ $ |#4|) 171)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 150)) (-1937 ((|#2| $ |#3|) NIL) (($ $ |#4| (-790)) 50) (($ $ (-658 |#4|) (-658 (-790))) 53)) (-1517 (((-3 $ "failed") $) 152)) (-3266 (((-141) $ $) 183))) 
+(((-976 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|))) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -3743 (|#1| |#1|)) (-15 -1517 ((-3 |#1| "failed") |#1|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|))) (-15 -3412 ((-911 (-405) |#1|) |#1| (-914 (-405)) (-911 (-405) |#1|))) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3339 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -1416 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -3524 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|))) (-15 -2288 ((-3 (-1280 |#1|) "failed") (-706 |#1|))) (-15 -3262 (|#1| |#1| |#4|)) (-15 -1554 (|#1| |#1| |#4|)) (-15 -1482 (|#1| |#1| |#4|)) (-15 -1544 (|#1| |#1| |#1| |#4|)) (-15 -4585 ((-658 |#1|) |#1|)) (-15 -2189 ((-790) |#1| (-658 |#4|))) (-15 -2189 ((-790) |#1|)) (-15 -2257 ((-3 (-2 (|:| |var| |#4|) (|:| -3215 (-790))) "failed") |#1|)) (-15 -4421 ((-3 (-658 |#1|) "failed") |#1|)) (-15 -2947 ((-3 (-658 |#1|) "failed") |#1|)) (-15 -4526 (|#1| |#1| (-658 |#4|) (-658 (-790)))) (-15 -4526 (|#1| |#1| |#4| (-790))) (-15 -1446 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1| |#4|)) (-15 -3108 ((-658 |#1|) |#1|)) (-15 -1937 (|#1| |#1| (-658 |#4|) (-658 (-790)))) (-15 -1937 (|#1| |#1| |#4| (-790))) (-15 -3945 ((-706 |#2|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -2400 (|#4| |#1|)) (-15 -4368 ((-3 |#4| "failed") |#1|)) (-15 -2806 (|#1| |#1| (-658 |#4|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#4| |#1|)) (-15 -2806 (|#1| |#1| (-658 |#4|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#4| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -4526 (|#1| |#2| |#3|)) (-15 -1937 (|#2| |#1| |#3|)) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -1554 (|#2| |#1|)) (-15 -3262 (|#1| |#1|))) (-977 |#2| |#3| |#4|) (-1075) (-815) (-869)) (T -976)) 
+NIL 
+(-10 -8 (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|))) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -3743 (|#1| |#1|)) (-15 -1517 ((-3 |#1| "failed") |#1|)) (-15 -3266 ((-141) |#1| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|))) (-15 -3412 ((-911 (-405) |#1|) |#1| (-914 (-405)) (-911 (-405) |#1|))) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3339 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -1416 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -3524 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|))) (-15 -2288 ((-3 (-1280 |#1|) "failed") (-706 |#1|))) (-15 -3262 (|#1| |#1| |#4|)) (-15 -1554 (|#1| |#1| |#4|)) (-15 -1482 (|#1| |#1| |#4|)) (-15 -1544 (|#1| |#1| |#1| |#4|)) (-15 -4585 ((-658 |#1|) |#1|)) (-15 -2189 ((-790) |#1| (-658 |#4|))) (-15 -2189 ((-790) |#1|)) (-15 -2257 ((-3 (-2 (|:| |var| |#4|) (|:| -3215 (-790))) "failed") |#1|)) (-15 -4421 ((-3 (-658 |#1|) "failed") |#1|)) (-15 -2947 ((-3 (-658 |#1|) "failed") |#1|)) (-15 -4526 (|#1| |#1| (-658 |#4|) (-658 (-790)))) (-15 -4526 (|#1| |#1| |#4| (-790))) (-15 -1446 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1| |#4|)) (-15 -3108 ((-658 |#1|) |#1|)) (-15 -1937 (|#1| |#1| (-658 |#4|) (-658 (-790)))) (-15 -1937 (|#1| |#1| |#4| (-790))) (-15 -3945 ((-706 |#2|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -2400 (|#4| |#1|)) (-15 -4368 ((-3 |#4| "failed") |#1|)) (-15 -2806 (|#1| |#1| (-658 |#4|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#4| |#1|)) (-15 -2806 (|#1| |#1| (-658 |#4|) (-658 |#2|))) (-15 -2806 (|#1| |#1| |#4| |#2|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -4526 (|#1| |#2| |#3|)) (-15 -1937 (|#2| |#1| |#3|)) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -1554 (|#2| |#1|)) (-15 -3262 (|#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 |#3|) $) 109)) (-4492 (((-1187 $) $ |#3|) 124) (((-1187 |#1|) $) 123)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 85 (|has| |#1| (-582)))) (-1555 (($ $) 86 (|has| |#1| (-582)))) (-1313 (((-141) $) 88 (|has| |#1| (-582)))) (-2189 (((-790) $) 111) (((-790) $ (-658 |#3|)) 110)) (-2350 (((-3 $ "failed") $ $) 18)) (-4043 (((-444 (-1187 $)) (-1187 $)) 99 (|has| |#1| (-931)))) (-3743 (($ $) 97 (|has| |#1| (-477)))) (-3164 (((-444 $) $) 96 (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 102 (|has| |#1| (-931)))) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 163) (((-3 (-433 (-592)) "failed") $) 161 (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) 159 (|has| |#1| (-1065 (-592)))) (((-3 |#3| "failed") $) 135)) (-2400 ((|#1| $) 164) (((-433 (-592)) $) 160 (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) 158 (|has| |#1| (-1065 (-592)))) ((|#3| $) 134)) (-1544 (($ $ $ |#3|) 107 (|has| |#1| (-194)))) (-4593 (($ $) 153)) (-3945 (((-706 (-592)) (-706 $)) 133 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 132 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 131) (((-706 |#1|) (-706 $)) 130)) (-3371 (((-3 $ "failed") $) 33)) (-3262 (($ $) 175 (|has| |#1| (-477))) (($ $ |#3|) 104 (|has| |#1| (-477)))) (-4585 (((-658 $) $) 108)) (-2802 (((-141) $) 95 (|has| |#1| (-931)))) (-4209 (($ $ |#1| |#2| $) 171)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 82 (-12 (|has| |#3| (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 81 (-12 (|has| |#3| (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-3558 (((-141) $) 30)) (-4036 (((-790) $) 168)) (-4533 (($ (-1187 |#1|) |#3|) 116) (($ (-1187 $) |#3|) 115)) (-3108 (((-658 $) $) 125)) (-2027 (((-141) $) 151)) (-4526 (($ |#1| |#2|) 152) (($ $ |#3| (-790)) 118) (($ $ (-658 |#3|) (-658 (-790))) 117)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ |#3|) 119)) (-4206 ((|#2| $) 169) (((-790) $ |#3|) 121) (((-658 (-790)) $ (-658 |#3|)) 120)) (-1837 (($ $ $) 77 (|has| |#1| (-869)))) (-3319 (($ $ $) 76 (|has| |#1| (-869)))) (-2976 (($ (-1 |#2| |#2|) $) 170)) (-2731 (($ (-1 |#1| |#1|) $) 150)) (-3254 (((-3 |#3| "failed") $) 122)) (-4573 (($ $) 148)) (-4579 ((|#1| $) 147)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 89 (|has| |#1| (-477)))) (-2750 (($ (-658 $)) 93 (|has| |#1| (-477))) (($ $ $) 92 (|has| |#1| (-477)))) (-2685 (((-1173) $) 9)) (-4421 (((-3 (-658 $) "failed") $) 113)) (-2947 (((-3 (-658 $) "failed") $) 114)) (-2257 (((-3 (-2 (|:| |var| |#3|) (|:| -3215 (-790))) "failed") $) 112)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 165)) (-4565 ((|#1| $) 166)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 94 (|has| |#1| (-477)))) (-3548 (($ (-658 $)) 91 (|has| |#1| (-477))) (($ $ $) 90 (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) 101 (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) 100 (|has| |#1| (-931)))) (-4500 (((-444 $) $) 98 (|has| |#1| (-931)))) (-3616 (((-3 $ "failed") $ |#1|) 173 (|has| |#1| (-582))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) 144) (($ $ (-310 $)) 143) (($ $ $ $) 142) (($ $ (-658 $) (-658 $)) 141) (($ $ |#3| |#1|) 140) (($ $ (-658 |#3|) (-658 |#1|)) 139) (($ $ |#3| $) 138) (($ $ (-658 |#3|) (-658 $)) 137)) (-1482 (($ $ |#3|) 106 (|has| |#1| (-194)))) (-3644 (($ $ |#3|) 41) (($ $ (-658 |#3|)) 40) (($ $ |#3| (-790)) 39) (($ $ (-658 |#3|) (-658 (-790))) 38)) (-4525 ((|#2| $) 149) (((-790) $ |#3|) 129) (((-658 (-790)) $ (-658 |#3|)) 128)) (-1778 (((-914 (-405)) $) 80 (-12 (|has| |#3| (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) 79 (-12 (|has| |#3| (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) 78 (-12 (|has| |#3| (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) 174 (|has| |#1| (-477))) (($ $ |#3|) 105 (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 103 (-1732 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 162) (($ |#3|) 136) (($ $) 83 (|has| |#1| (-582))) (($ (-433 (-592))) 70 (-3836 (|has| |#1| (-1065 (-433 (-592)))) (|has| |#1| (-43 (-433 (-592))))))) (-1647 (((-658 |#1|) $) 167)) (-1937 ((|#1| $ |#2|) 154) (($ $ |#3| (-790)) 127) (($ $ (-658 |#3|) (-658 (-790))) 126)) (-1517 (((-3 $ "failed") $) 71 (-3836 (-1732 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) 28)) (-4064 (($ $ $ (-790)) 172 (|has| |#1| (-194)))) (-2537 (((-141) $ $) 87 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ |#3|) 37) (($ $ (-658 |#3|)) 36) (($ $ |#3| (-790)) 35) (($ $ (-658 |#3|) (-658 (-790))) 34)) (-3286 (((-141) $ $) 74 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 73 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 75 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 72 (|has| |#1| (-869)))) (-3313 (($ $ |#1|) 155 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 157 (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) 156 (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 146) (($ $ |#1|) 145))) 
+(((-977 |#1| |#2| |#3|) (-1311) (-1075) (-815) (-869)) (T -977)) 
+((-3262 (*1 *1 *1) (-12 (-4 *1 (-977 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477)))) (-4525 (*1 *2 *1 *3) (-12 (-4 *1 (-977 *4 *5 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-790)))) (-4525 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 (-790))))) (-1937 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-977 *4 *5 *2)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *2 (-869)))) (-1937 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *6)) (-5 *3 (-658 (-790))) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)))) (-3108 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-977 *3 *4 *5)))) (-4492 (*1 *2 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-1187 *1)) (-4 *1 (-977 *4 *5 *3)))) (-4492 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-1187 *3)))) (-3254 (*1 *2 *1) (|partial| -12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) (-4206 (*1 *2 *1 *3) (-12 (-4 *1 (-977 *4 *5 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-790)))) (-4206 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 (-790))))) (-1446 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-977 *4 *5 *3)))) (-4526 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-977 *4 *5 *2)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *2 (-869)))) (-4526 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *6)) (-5 *3 (-658 (-790))) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)))) (-4533 (*1 *1 *2 *3) (-12 (-5 *2 (-1187 *4)) (-4 *4 (-1075)) (-4 *1 (-977 *4 *5 *3)) (-4 *5 (-815)) (-4 *3 (-869)))) (-4533 (*1 *1 *2 *3) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-977 *4 *5 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)))) (-2947 (*1 *2 *1) (|partial| -12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-977 *3 *4 *5)))) (-4421 (*1 *2 *1) (|partial| -12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-977 *3 *4 *5)))) (-2257 (*1 *2 *1) (|partial| -12 (-4 *1 (-977 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| |var| *5) (|:| -3215 (-790)))))) (-2189 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-790)))) (-2189 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-790)))) (-4085 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *5)))) (-4585 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-977 *3 *4 *5)))) (-1544 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *3 (-194)))) (-1482 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *3 (-194)))) (-1554 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *3 (-477)))) (-3262 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *3 (-477)))) (-3743 (*1 *1 *1) (-12 (-4 *1 (-977 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477)))) (-3164 (*1 *2 *1) (-12 (-4 *3 (-477)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-444 *1)) (-4 *1 (-977 *3 *4 *5))))) 
+(-13 (-922 |t#3|) (-346 |t#1| |t#2|) (-325 $) (-547 |t#3| |t#1|) (-547 |t#3| $) (-1065 |t#3|) (-403 |t#1|) (-10 -8 (-15 -4525 ((-790) $ |t#3|)) (-15 -4525 ((-658 (-790)) $ (-658 |t#3|))) (-15 -1937 ($ $ |t#3| (-790))) (-15 -1937 ($ $ (-658 |t#3|) (-658 (-790)))) (-15 -3108 ((-658 $) $)) (-15 -4492 ((-1187 $) $ |t#3|)) (-15 -4492 ((-1187 |t#1|) $)) (-15 -3254 ((-3 |t#3| "failed") $)) (-15 -4206 ((-790) $ |t#3|)) (-15 -4206 ((-658 (-790)) $ (-658 |t#3|))) (-15 -1446 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $ |t#3|)) (-15 -4526 ($ $ |t#3| (-790))) (-15 -4526 ($ $ (-658 |t#3|) (-658 (-790)))) (-15 -4533 ($ (-1187 |t#1|) |t#3|)) (-15 -4533 ($ (-1187 $) |t#3|)) (-15 -2947 ((-3 (-658 $) "failed") $)) (-15 -4421 ((-3 (-658 $) "failed") $)) (-15 -2257 ((-3 (-2 (|:| |var| |t#3|) (|:| -3215 (-790))) "failed") $)) (-15 -2189 ((-790) $)) (-15 -2189 ((-790) $ (-658 |t#3|))) (-15 -4085 ((-658 |t#3|) $)) (-15 -4585 ((-658 $) $)) (IF (|has| |t#1| (-869)) (-6 (-869)) |noBranch|) (IF (|has| |t#1| (-633 (-565))) (IF (|has| |t#3| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-633 (-914 (-592)))) (IF (|has| |t#3| (-633 (-914 (-592)))) (-6 (-633 (-914 (-592)))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-633 (-914 (-405)))) (IF (|has| |t#3| (-633 (-914 (-405)))) (-6 (-633 (-914 (-405)))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-908 (-592))) (IF (|has| |t#3| (-908 (-592))) (-6 (-908 (-592))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-908 (-405))) (IF (|has| |t#3| (-908 (-405))) (-6 (-908 (-405))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-194)) (PROGN (-15 -1544 ($ $ $ |t#3|)) (-15 -1482 ($ $ |t#3|))) |noBranch|) (IF (|has| |t#1| (-477)) (PROGN (-6 (-477)) (-15 -1554 ($ $ |t#3|)) (-15 -3262 ($ $)) (-15 -3262 ($ $ |t#3|)) (-15 -3164 ((-444 $) $)) (-15 -3743 ($ $))) |noBranch|) (IF (|has| |t#1| (-6 -4623)) (-6 -4623) |noBranch|) (IF (|has| |t#1| (-931)) (-6 (-931)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-633 (-565)) -12 (|has| |#1| (-633 (-565))) (|has| |#3| (-633 (-565)))) ((-633 (-914 (-405))) -12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#3| (-633 (-914 (-405))))) ((-633 (-914 (-592))) -12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#3| (-633 (-914 (-592))))) ((-307) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-325 $) . T) ((-346 |#1| |#2|) . T) ((-403 |#1|) . T) ((-437 |#1|) . T) ((-477) -3836 (|has| |#1| (-931)) (|has| |#1| (-477))) ((-547 |#3| |#1|) . T) ((-547 |#3| $) . T) ((-547 $ $) . T) ((-582) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) -3836 (|has| |#1| (-931)) (|has| |#1| (-477))) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-743) . T) ((-869) |has| |#1| (-869)) ((-922 |#3|) . T) ((-908 (-405)) -12 (|has| |#1| (-908 (-405))) (|has| |#3| (-908 (-405)))) ((-908 (-592)) -12 (|has| |#1| (-908 (-592))) (|has| |#3| (-908 (-592)))) ((-931) |has| |#1| (-931)) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1065 |#3|) . T) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) |has| |#1| (-931))) 
+((-4085 (((-658 |#2|) |#5|) 36)) (-4492 (((-1187 |#5|) |#5| |#2| (-1187 |#5|)) 23) (((-433 (-1187 |#5|)) |#5| |#2|) 16)) (-4533 ((|#5| (-433 (-1187 |#5|)) |#2|) 30)) (-3254 (((-3 |#2| "failed") |#5|) 61)) (-4421 (((-3 (-658 |#5|) "failed") |#5|) 55)) (-2427 (((-3 (-2 (|:| |val| |#5|) (|:| -3215 (-592))) "failed") |#5|) 45)) (-2947 (((-3 (-658 |#5|) "failed") |#5|) 57)) (-2257 (((-3 (-2 (|:| |var| |#2|) (|:| -3215 (-592))) "failed") |#5|) 48))) 
+(((-978 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4085 ((-658 |#2|) |#5|)) (-15 -3254 ((-3 |#2| "failed") |#5|)) (-15 -4492 ((-433 (-1187 |#5|)) |#5| |#2|)) (-15 -4533 (|#5| (-433 (-1187 |#5|)) |#2|)) (-15 -4492 ((-1187 |#5|) |#5| |#2| (-1187 |#5|))) (-15 -2947 ((-3 (-658 |#5|) "failed") |#5|)) (-15 -4421 ((-3 (-658 |#5|) "failed") |#5|)) (-15 -2257 ((-3 (-2 (|:| |var| |#2|) (|:| -3215 (-592))) "failed") |#5|)) (-15 -2427 ((-3 (-2 (|:| |val| |#5|) (|:| -3215 (-592))) "failed") |#5|))) (-815) (-869) (-1075) (-977 |#3| |#1| |#2|) (-13 (-388) (-10 -8 (-15 -1683 ($ |#4|)) (-15 -1448 (|#4| $)) (-15 -1456 (|#4| $))))) (T -978)) 
+((-2427 (*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-2 (|:| |val| *3) (|:| -3215 (-592)))) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))))) (-2257 (*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-2 (|:| |var| *5) (|:| -3215 (-592)))) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))))) (-4421 (*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-658 *3)) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))))) (-2947 (*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-658 *3)) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))))) (-4492 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-1187 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))) (-4 *7 (-977 *6 *5 *4)) (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-1075)) (-5 *1 (-978 *5 *4 *6 *7 *3)))) (-4533 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-1187 *2))) (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-1075)) (-4 *2 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))) (-5 *1 (-978 *5 *4 *6 *7 *2)) (-4 *7 (-977 *6 *5 *4)))) (-4492 (*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *5 *4)) (-5 *2 (-433 (-1187 *3))) (-5 *1 (-978 *5 *4 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))))) (-3254 (*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-1075)) (-4 *6 (-977 *5 *4 *2)) (-4 *2 (-869)) (-5 *1 (-978 *4 *2 *5 *6 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *6)) (-15 -1448 (*6 $)) (-15 -1456 (*6 $))))))) (-4085 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-658 *5)) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $)))))))) 
+(-10 -7 (-15 -4085 ((-658 |#2|) |#5|)) (-15 -3254 ((-3 |#2| "failed") |#5|)) (-15 -4492 ((-433 (-1187 |#5|)) |#5| |#2|)) (-15 -4533 (|#5| (-433 (-1187 |#5|)) |#2|)) (-15 -4492 ((-1187 |#5|) |#5| |#2| (-1187 |#5|))) (-15 -2947 ((-3 (-658 |#5|) "failed") |#5|)) (-15 -4421 ((-3 (-658 |#5|) "failed") |#5|)) (-15 -2257 ((-3 (-2 (|:| |var| |#2|) (|:| -3215 (-592))) "failed") |#5|)) (-15 -2427 ((-3 (-2 (|:| |val| |#5|) (|:| -3215 (-592))) "failed") |#5|))) 
+((-2731 ((|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|) 23))) 
+(((-979 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2731 (|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|))) (-815) (-869) (-1075) (-977 |#3| |#1| |#2|) (-13 (-1119) (-10 -8 (-15 -3300 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-790)))))) (T -979)) 
+((-2731 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *7)) (-5 *4 (-1 *2 *8)) (-4 *7 (-869)) (-4 *8 (-1075)) (-4 *6 (-815)) (-4 *2 (-13 (-1119) (-10 -8 (-15 -3300 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-790)))))) (-5 *1 (-979 *6 *7 *8 *5 *2)) (-4 *5 (-977 *8 *6 *7))))) 
+(-10 -7 (-15 -2731 (|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1191)) $) 15)) (-4492 (((-1187 $) $ (-1191)) 21) (((-1187 |#1|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1191))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 8) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-1191) "failed") $) NIL)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-1191) $) NIL)) (-1544 (($ $ $ (-1191)) NIL (|has| |#1| (-194)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ (-1191)) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-558 (-1191)) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1191) (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1191) (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-4533 (($ (-1187 |#1|) (-1191)) NIL) (($ (-1187 $) (-1191)) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-558 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1191)) NIL)) (-4206 (((-558 (-1191)) $) NIL) (((-790) $ (-1191)) NIL) (((-658 (-790)) $ (-658 (-1191))) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-558 (-1191)) (-558 (-1191))) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3254 (((-3 (-1191) "failed") $) 19)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-1191)) (|:| -3215 (-790))) "failed") $) NIL)) (-3162 (($ $ (-1191)) 29 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1191) |#1|) NIL) (($ $ (-658 (-1191)) (-658 |#1|)) NIL) (($ $ (-1191) $) NIL) (($ $ (-658 (-1191)) (-658 $)) NIL)) (-1482 (($ $ (-1191)) NIL (|has| |#1| (-194)))) (-3644 (($ $ (-1191)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL)) (-4525 (((-558 (-1191)) $) NIL) (((-790) $ (-1191)) NIL) (((-658 (-790)) $ (-658 (-1191))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-1191) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-1191) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-1191) (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) NIL (|has| |#1| (-477))) (($ $ (-1191)) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) 25) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-1191)) 27) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-558 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-1191)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-980 |#1|) (-13 (-977 |#1| (-558 (-1191)) (-1191)) (-10 -8 (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1191))) |noBranch|))) (-1075)) (T -980)) 
+((-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-980 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075))))) 
+(-13 (-977 |#1| (-558 (-1191)) (-1191)) (-10 -8 (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1191))) |noBranch|))) 
+((-3359 (((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) |#3| (-790)) 37)) (-2593 (((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) (-433 (-592)) (-790)) 33)) (-3904 (((-2 (|:| -3215 (-790)) (|:| -1487 |#4|) (|:| |radicand| (-658 |#4|))) |#4| (-790)) 52)) (-4058 (((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) |#5| (-790)) 62 (|has| |#3| (-477))))) 
+(((-981 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3359 ((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) |#3| (-790))) (-15 -2593 ((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) (-433 (-592)) (-790))) (IF (|has| |#3| (-477)) (-15 -4058 ((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) |#5| (-790))) |noBranch|) (-15 -3904 ((-2 (|:| -3215 (-790)) (|:| -1487 |#4|) (|:| |radicand| (-658 |#4|))) |#4| (-790)))) (-815) (-869) (-582) (-977 |#3| |#1| |#2|) (-13 (-388) (-10 -8 (-15 -1448 (|#4| $)) (-15 -1456 (|#4| $)) (-15 -1683 ($ |#4|))))) (T -981)) 
+((-3904 (*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-582)) (-4 *3 (-977 *7 *5 *6)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *3) (|:| |radicand| (-658 *3)))) (-5 *1 (-981 *5 *6 *7 *3 *8)) (-5 *4 (-790)) (-4 *8 (-13 (-388) (-10 -8 (-15 -1448 (*3 $)) (-15 -1456 (*3 $)) (-15 -1683 ($ *3))))))) (-4058 (*1 *2 *3 *4) (-12 (-4 *7 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-582)) (-4 *8 (-977 *7 *5 *6)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *3) (|:| |radicand| *3))) (-5 *1 (-981 *5 *6 *7 *8 *3)) (-5 *4 (-790)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1448 (*8 $)) (-15 -1456 (*8 $)) (-15 -1683 ($ *8))))))) (-2593 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-592))) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-582)) (-4 *8 (-977 *7 *5 *6)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *9) (|:| |radicand| *9))) (-5 *1 (-981 *5 *6 *7 *8 *9)) (-5 *4 (-790)) (-4 *9 (-13 (-388) (-10 -8 (-15 -1448 (*8 $)) (-15 -1456 (*8 $)) (-15 -1683 ($ *8))))))) (-3359 (*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-582)) (-4 *7 (-977 *3 *5 *6)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *8) (|:| |radicand| *8))) (-5 *1 (-981 *5 *6 *3 *7 *8)) (-5 *4 (-790)) (-4 *8 (-13 (-388) (-10 -8 (-15 -1448 (*7 $)) (-15 -1456 (*7 $)) (-15 -1683 ($ *7)))))))) 
+(-10 -7 (-15 -3359 ((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) |#3| (-790))) (-15 -2593 ((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) (-433 (-592)) (-790))) (IF (|has| |#3| (-477)) (-15 -4058 ((-2 (|:| -3215 (-790)) (|:| -1487 |#5|) (|:| |radicand| |#5|)) |#5| (-790))) |noBranch|) (-15 -3904 ((-2 (|:| -3215 (-790)) (|:| -1487 |#4|) (|:| |radicand| (-658 |#4|))) |#4| (-790)))) 
+((-1973 (((-1285) (-1229) (-592) (-1229) (-592) (-592) (-592) (-592)) 33)) (-2415 (((-1285) (-1229) (-1229) (-592) (-592) (-592) (-592)) 27)) (-1321 (((-1229) (-1229) (-1229) (-592) (-592)) 45)) (-2726 (((-1285) (-1229) (-1229) (-1229) (-592) (-592)) 44)) (-2285 (((-1229) (-1187 (-592)) (-592)) 26)) (-1544 (((-592) (-1229) (-1229) (-592)) 54)) (-2373 (((-1285) (-1229) (-1229) (-592)) 36)) (-1777 (((-1229) (-1229) (-944) (-790) (-592)) 48)) (-2777 (((-1285) (-1229) (-592) (-592) (-592)) 31)) (-1358 (((-1285) (-1229) (-592) (-592) (-592)) 28) (((-1285) (-1229) (-592) (-592)) 30)) (-1524 (((-1229) (-1229) (-1229) (-592)) 41)) (-2750 (((-1229) (-986 (-1229)) (-592) (-592) (-592)) 42)) (-3548 (((-1229) (-986 (-1229)) (-592) (-592) (-592)) 40) (((-1229) (-1229) (-1229) (-592)) 38)) (-4150 (((-658 (-1229)) (-1229) (-1229) (-592)) 53)) (-3376 (((-592) (-1229) (-592) (-592) (-592)) 15)) (-2545 (((-1285) (-1229) (-1229) (-1229) (-592)) 35)) (-3644 (((-1229) (-1229) (-790) (-592)) 51) (((-1229) (-1229) (-592)) 50)) (-4525 (((-592) (-1229)) 32)) (-1907 (((-1285) (-1229) (-1229) (-592) (-592)) 12)) (-4099 (((-1285) (-1229) (-1229) (-592)) 11))) 
+(((-982) (-10 -7 (-15 -4099 ((-1285) (-1229) (-1229) (-592))) (-15 -1907 ((-1285) (-1229) (-1229) (-592) (-592))) (-15 -3376 ((-592) (-1229) (-592) (-592) (-592))) (-15 -2415 ((-1285) (-1229) (-1229) (-592) (-592) (-592) (-592))) (-15 -1358 ((-1285) (-1229) (-592) (-592))) (-15 -1358 ((-1285) (-1229) (-592) (-592) (-592))) (-15 -2777 ((-1285) (-1229) (-592) (-592) (-592))) (-15 -1524 ((-1229) (-1229) (-1229) (-592))) (-15 -1321 ((-1229) (-1229) (-1229) (-592) (-592))) (-15 -2726 ((-1285) (-1229) (-1229) (-1229) (-592) (-592))) (-15 -1777 ((-1229) (-1229) (-944) (-790) (-592))) (-15 -3644 ((-1229) (-1229) (-592))) (-15 -3644 ((-1229) (-1229) (-790) (-592))) (-15 -2545 ((-1285) (-1229) (-1229) (-1229) (-592))) (-15 -2373 ((-1285) (-1229) (-1229) (-592))) (-15 -1973 ((-1285) (-1229) (-592) (-1229) (-592) (-592) (-592) (-592))) (-15 -2285 ((-1229) (-1187 (-592)) (-592))) (-15 -3548 ((-1229) (-1229) (-1229) (-592))) (-15 -3548 ((-1229) (-986 (-1229)) (-592) (-592) (-592))) (-15 -2750 ((-1229) (-986 (-1229)) (-592) (-592) (-592))) (-15 -4525 ((-592) (-1229))) (-15 -4150 ((-658 (-1229)) (-1229) (-1229) (-592))) (-15 -1544 ((-592) (-1229) (-1229) (-592))))) (T -982)) 
+((-1544 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-592)) (-5 *3 (-1229)) (-5 *1 (-982)))) (-4150 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-592)) (-5 *2 (-658 (-1229))) (-5 *1 (-982)) (-5 *3 (-1229)))) (-4525 (*1 *2 *3) (-12 (-5 *3 (-1229)) (-5 *2 (-592)) (-5 *1 (-982)))) (-2750 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-986 (-1229))) (-5 *4 (-592)) (-5 *2 (-1229)) (-5 *1 (-982)))) (-3548 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-986 (-1229))) (-5 *4 (-592)) (-5 *2 (-1229)) (-5 *1 (-982)))) (-3548 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-1229)) (-5 *3 (-592)) (-5 *1 (-982)))) (-2285 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 (-592))) (-5 *4 (-592)) (-5 *2 (-1229)) (-5 *1 (-982)))) (-1973 (*1 *2 *3 *4 *3 *4 *4 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-2373 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-2545 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-3644 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-1229)) (-5 *3 (-790)) (-5 *4 (-592)) (-5 *1 (-982)))) (-3644 (*1 *2 *2 *3) (-12 (-5 *2 (-1229)) (-5 *3 (-592)) (-5 *1 (-982)))) (-1777 (*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-1229)) (-5 *3 (-944)) (-5 *4 (-790)) (-5 *5 (-592)) (-5 *1 (-982)))) (-2726 (*1 *2 *3 *3 *3 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-1321 (*1 *2 *2 *2 *3 *3) (-12 (-5 *2 (-1229)) (-5 *3 (-592)) (-5 *1 (-982)))) (-1524 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-1229)) (-5 *3 (-592)) (-5 *1 (-982)))) (-2777 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-1358 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-1358 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-2415 (*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-3376 (*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *3 (-1229)) (-5 *1 (-982)))) (-1907 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) (-4099 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(-10 -7 (-15 -4099 ((-1285) (-1229) (-1229) (-592))) (-15 -1907 ((-1285) (-1229) (-1229) (-592) (-592))) (-15 -3376 ((-592) (-1229) (-592) (-592) (-592))) (-15 -2415 ((-1285) (-1229) (-1229) (-592) (-592) (-592) (-592))) (-15 -1358 ((-1285) (-1229) (-592) (-592))) (-15 -1358 ((-1285) (-1229) (-592) (-592) (-592))) (-15 -2777 ((-1285) (-1229) (-592) (-592) (-592))) (-15 -1524 ((-1229) (-1229) (-1229) (-592))) (-15 -1321 ((-1229) (-1229) (-1229) (-592) (-592))) (-15 -2726 ((-1285) (-1229) (-1229) (-1229) (-592) (-592))) (-15 -1777 ((-1229) (-1229) (-944) (-790) (-592))) (-15 -3644 ((-1229) (-1229) (-592))) (-15 -3644 ((-1229) (-1229) (-790) (-592))) (-15 -2545 ((-1285) (-1229) (-1229) (-1229) (-592))) (-15 -2373 ((-1285) (-1229) (-1229) (-592))) (-15 -1973 ((-1285) (-1229) (-592) (-1229) (-592) (-592) (-592) (-592))) (-15 -2285 ((-1229) (-1187 (-592)) (-592))) (-15 -3548 ((-1229) (-1229) (-1229) (-592))) (-15 -3548 ((-1229) (-986 (-1229)) (-592) (-592) (-592))) (-15 -2750 ((-1229) (-986 (-1229)) (-592) (-592) (-592))) (-15 -4525 ((-592) (-1229))) (-15 -4150 ((-658 (-1229)) (-1229) (-1229) (-592))) (-15 -1544 ((-592) (-1229) (-1229) (-592)))) 
+((-1413 (((-1113 (-237)) $) 7)) (-4254 (((-1113 (-237)) $) 8)) (-1613 (((-658 (-658 (-971 (-237)))) $) 9)) (-1683 (((-877) $) 6))) 
+(((-983) (-1311)) (T -983)) 
+((-1613 (*1 *2 *1) (-12 (-4 *1 (-983)) (-5 *2 (-658 (-658 (-971 (-237))))))) (-4254 (*1 *2 *1) (-12 (-4 *1 (-983)) (-5 *2 (-1113 (-237))))) (-1413 (*1 *2 *1) (-12 (-4 *1 (-983)) (-5 *2 (-1113 (-237)))))) 
+(-13 (-632 (-877)) (-10 -8 (-15 -1613 ((-658 (-658 (-971 (-237)))) $)) (-15 -4254 ((-1113 (-237)) $)) (-15 -1413 ((-1113 (-237)) $)))) 
+(((-632 (-877)) . T)) 
+((-3028 (((-3 (-706 |#1|) "failed") |#2| (-944)) 14))) 
+(((-984 |#1| |#2|) (-10 -7 (-15 -3028 ((-3 (-706 |#1|) "failed") |#2| (-944)))) (-582) (-670 |#1|)) (T -984)) 
+((-3028 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-944)) (-4 *5 (-582)) (-5 *2 (-706 *5)) (-5 *1 (-984 *5 *3)) (-4 *3 (-670 *5))))) 
+(-10 -7 (-15 -3028 ((-3 (-706 |#1|) "failed") |#2| (-944)))) 
+((-1779 (((-986 |#2|) (-1 |#2| |#1| |#2|) (-986 |#1|) |#2|) 16)) (-3657 ((|#2| (-1 |#2| |#1| |#2|) (-986 |#1|) |#2|) 18)) (-2731 (((-986 |#2|) (-1 |#2| |#1|) (-986 |#1|)) 13))) 
+(((-985 |#1| |#2|) (-10 -7 (-15 -1779 ((-986 |#2|) (-1 |#2| |#1| |#2|) (-986 |#1|) |#2|)) (-15 -3657 (|#2| (-1 |#2| |#1| |#2|) (-986 |#1|) |#2|)) (-15 -2731 ((-986 |#2|) (-1 |#2| |#1|) (-986 |#1|)))) (-1225) (-1225)) (T -985)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-986 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-986 *6)) (-5 *1 (-985 *5 *6)))) (-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-986 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-985 *5 *2)))) (-1779 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-986 *6)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-5 *2 (-986 *5)) (-5 *1 (-985 *6 *5))))) 
+(-10 -7 (-15 -1779 ((-986 |#2|) (-1 |#2| |#1| |#2|) (-986 |#1|) |#2|)) (-15 -3657 (|#2| (-1 |#2| |#1| |#2|) (-986 |#1|) |#2|)) (-15 -2731 ((-986 |#2|) (-1 |#2| |#1|) (-986 |#1|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) NIL) (((-141) $) NIL (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) |#1|) 17 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) 16 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 14)) (-1721 (((-592) (-1 (-141) |#1|) $) NIL) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119)))) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) |#1|) 13)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 10 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) NIL (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) 12 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 11)) (-3927 ((|#1| $ (-592) |#1|) NIL) ((|#1| $ (-592)) 15) (($ $ (-1246 (-592))) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) NIL)) (-2266 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-1699 (((-790) $) 8 (|has| $ (-6 -4625))))) 
+(((-986 |#1|) (-19 |#1|) (-1225)) (T -986)) 
 NIL 
 (-19 |#1|) 
-((-4282 (($ $ (-1090 $)) 7) (($ $ (-1170)) 6))) 
-(((-966) (-1290)) (T -966)) 
-((-4282 (*1 *1 *1 *2) (-12 (-5 *2 (-1090 *1)) (-4 *1 (-966)))) (-4282 (*1 *1 *1 *2) (-12 (-4 *1 (-966)) (-5 *2 (-1170))))) 
-(-13 (-10 -8 (-15 -4282 ($ $ (-1170))) (-15 -4282 ($ $ (-1090 $))))) 
-((-2754 (((-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 |#1|))) (|:| |prim| (-1166 |#1|))) (-638 (-959 |#1|)) (-638 (-1170)) (-1170)) 23) (((-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 |#1|))) (|:| |prim| (-1166 |#1|))) (-638 (-959 |#1|)) (-638 (-1170))) 24) (((-2 (|:| |coef1| (-572)) (|:| |coef2| (-572)) (|:| |prim| (-1166 |#1|))) (-959 |#1|) (-1170) (-959 |#1|) (-1170)) 41))) 
-(((-967 |#1|) (-10 -7 (-15 -2754 ((-2 (|:| |coef1| (-572)) (|:| |coef2| (-572)) (|:| |prim| (-1166 |#1|))) (-959 |#1|) (-1170) (-959 |#1|) (-1170))) (-15 -2754 ((-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 |#1|))) (|:| |prim| (-1166 |#1|))) (-638 (-959 |#1|)) (-638 (-1170)))) (-15 -2754 ((-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 |#1|))) (|:| |prim| (-1166 |#1|))) (-638 (-959 |#1|)) (-638 (-1170)) (-1170)))) (-13 (-368) (-151))) (T -967)) 
-((-2754 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-959 *6))) (-5 *4 (-638 (-1170))) (-5 *5 (-1170)) (-4 *6 (-13 (-368) (-151))) (-5 *2 (-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 *6))) (|:| |prim| (-1166 *6)))) (-5 *1 (-967 *6)))) (-2754 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-368) (-151))) (-5 *2 (-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 *5))) (|:| |prim| (-1166 *5)))) (-5 *1 (-967 *5)))) (-2754 (*1 *2 *3 *4 *3 *4) (-12 (-5 *3 (-959 *5)) (-5 *4 (-1170)) (-4 *5 (-13 (-368) (-151))) (-5 *2 (-2 (|:| |coef1| (-572)) (|:| |coef2| (-572)) (|:| |prim| (-1166 *5)))) (-5 *1 (-967 *5))))) 
-(-10 -7 (-15 -2754 ((-2 (|:| |coef1| (-572)) (|:| |coef2| (-572)) (|:| |prim| (-1166 |#1|))) (-959 |#1|) (-1170) (-959 |#1|) (-1170))) (-15 -2754 ((-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 |#1|))) (|:| |prim| (-1166 |#1|))) (-638 (-959 |#1|)) (-638 (-1170)))) (-15 -2754 ((-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 |#1|))) (|:| |prim| (-1166 |#1|))) (-638 (-959 |#1|)) (-638 (-1170)) (-1170)))) 
-((-1835 (((-638 |#1|) |#1| |#1|) 42)) (-1526 (((-121) |#1|) 39)) (-1686 ((|#1| |#1|) 64)) (-3882 ((|#1| |#1|) 63))) 
-(((-968 |#1|) (-10 -7 (-15 -1526 ((-121) |#1|)) (-15 -3882 (|#1| |#1|)) (-15 -1686 (|#1| |#1|)) (-15 -1835 ((-638 |#1|) |#1| |#1|))) (-554)) (T -968)) 
-((-1835 (*1 *2 *3 *3) (-12 (-5 *2 (-638 *3)) (-5 *1 (-968 *3)) (-4 *3 (-554)))) (-1686 (*1 *2 *2) (-12 (-5 *1 (-968 *2)) (-4 *2 (-554)))) (-3882 (*1 *2 *2) (-12 (-5 *1 (-968 *2)) (-4 *2 (-554)))) (-1526 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-968 *3)) (-4 *3 (-554))))) 
-(-10 -7 (-15 -1526 ((-121) |#1|)) (-15 -3882 (|#1| |#1|)) (-15 -1686 (|#1| |#1|)) (-15 -1835 ((-638 |#1|) |#1| |#1|))) 
-((-1817 (((-1264) (-856)) 9))) 
-(((-969) (-10 -7 (-15 -1817 ((-1264) (-856))))) (T -969)) 
-((-1817 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-969))))) 
-(-10 -7 (-15 -1817 ((-1264) (-856)))) 
-((-2670 (((-638 |#5|) |#3| (-638 |#3|)) 70)) (-2194 (((-638 |#5|) |#3|) 45)) (-3356 (((-638 |#5|) |#3| (-923)) 58)) (-2568 (((-638 |#5|) (-638 |#3|)) 48))) 
-(((-970 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2670 ((-638 |#5|) |#3| (-638 |#3|))) (-15 -2194 ((-638 |#5|) |#3|)) (-15 -2568 ((-638 |#5|) (-638 |#3|))) (-15 -3356 ((-638 |#5|) |#3| (-923)))) (-368) (-638 (-1170)) (-956 |#1| |#4| (-858 |#2|)) (-232 (-4032 |#2|) (-769)) (-978 |#1|)) (T -970)) 
-((-3356 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-5 *2 (-638 *8)) (-5 *1 (-970 *5 *6 *3 *7 *8)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)))) (-2568 (*1 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *2 (-638 *8)) (-5 *1 (-970 *4 *5 *6 *7 *8)) (-4 *8 (-978 *4)))) (-2194 (*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *2 (-638 *7)) (-5 *1 (-970 *4 *5 *3 *6 *7)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *7 (-978 *4)))) (-2670 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 *8)) (-5 *1 (-970 *5 *6 *3 *7 *8)) (-4 *8 (-978 *5))))) 
-(-10 -7 (-15 -2670 ((-638 |#5|) |#3| (-638 |#3|))) (-15 -2194 ((-638 |#5|) |#3|)) (-15 -2568 ((-638 |#5|) (-638 |#3|))) (-15 -3356 ((-638 |#5|) |#3| (-923)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 62 (|has| |#1| (-562)))) (-3946 (($ $) 63 (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 28)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-4383 (($ $) 24)) (-1799 (((-3 $ "failed") $) 35)) (-3988 (($ $) NIL (|has| |#1| (-457)))) (-3977 (($ $ |#1| |#2| $) 47)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) 16)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| |#2|) NIL)) (-1784 ((|#2| $) 19)) (-3918 (($ (-1 |#2| |#2|) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-4368 (($ $) 23)) (-4373 ((|#1| $) 21)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 40)) (-4362 ((|#1| $) NIL)) (-3311 (($ $ |#2| |#1| $) 71 (-12 (|has| |#2| (-138)) (|has| |#1| (-562))))) (-1803 (((-3 $ "failed") $ $) 73 (|has| |#1| (-562))) (((-3 $ "failed") $ |#1|) 69 (|has| |#1| (-562)))) (-4316 ((|#2| $) 17)) (-3694 ((|#1| $) NIL (|has| |#1| (-457)))) (-3972 (((-856) $) NIL) (($ (-572)) 39) (($ $) NIL (|has| |#1| (-562))) (($ |#1|) 34) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572))))))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ |#2|) 31)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) 15)) (-2565 (($ $ $ (-769)) 58 (|has| |#1| (-174)))) (-3774 (((-121) $ $) 68 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 54) (($ $ (-769)) 55)) (-2378 (($) 22 T CONST)) (-3255 (($) 12 T CONST)) (-1324 (((-121) $ $) 67)) (-1379 (($ $ |#1|) 74 (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) 53) (($ $ (-769)) 51)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 50) (($ $ |#1|) 49) (($ |#1| $) 48) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-971 |#1| |#2|) (-13 (-326 |#1| |#2|) (-10 -8 (IF (|has| |#1| (-562)) (IF (|has| |#2| (-138)) (-15 -3311 ($ $ |#2| |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4600)) (-6 -4600) |noBranch|))) (-1054) (-793)) (T -971)) 
-((-3311 (*1 *1 *1 *2 *3 *1) (-12 (-5 *1 (-971 *3 *2)) (-4 *2 (-138)) (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *2 (-793))))) 
-(-13 (-326 |#1| |#2|) (-10 -8 (IF (|has| |#1| (-562)) (IF (|has| |#2| (-138)) (-15 -3311 ($ $ |#2| |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4600)) (-6 -4600) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL (-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794)))))) (-1614 (($ $ $) 63 (-12 (|has| |#1| (-794)) (|has| |#2| (-794))))) (-1572 (((-3 $ "failed") $ $) 50 (-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794)))))) (-1685 (((-769)) 34 (-12 (|has| |#1| (-374)) (|has| |#2| (-374))))) (-3196 ((|#2| $) 21)) (-2482 ((|#1| $) 20)) (-2211 (($) NIL (-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794)))) CONST)) (-1799 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722)))))) (-3286 (($) NIL (-12 (|has| |#1| (-374)) (|has| |#2| (-374))))) (-3893 (((-121) $) NIL (-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722)))))) (-1771 (($ $ $) NIL (-1841 (-12 (|has| |#1| (-794)) (|has| |#2| (-794))) (-12 (|has| |#1| (-848)) (|has| |#2| (-848)))))) (-4238 (($ $ $) NIL (-1841 (-12 (|has| |#1| (-794)) (|has| |#2| (-794))) (-12 (|has| |#1| (-848)) (|has| |#2| (-848)))))) (-4087 (($ |#1| |#2|) 19)) (-3633 (((-923) $) NIL (-12 (|has| |#1| (-374)) (|has| |#2| (-374))))) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 37 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))))) (-1763 (($ (-923)) NIL (-12 (|has| |#1| (-374)) (|has| |#2| (-374))))) (-2607 (((-1116) $) NIL)) (-3587 (((-638 $)) NIL (-12 (|has| |#1| (-374)) (|has| |#2| (-374))))) (-3018 (($ $ $) NIL (-12 (|has| |#1| (-482)) (|has| |#2| (-482))))) (-4056 (($ $ $) NIL (-12 (|has| |#1| (-482)) (|has| |#2| (-482))))) (-3972 (((-856) $) 14)) (-4174 (($ $ (-572)) NIL (-12 (|has| |#1| (-482)) (|has| |#2| (-482)))) (($ $ (-769)) NIL (-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722))))) (($ $ (-923)) NIL (-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722)))))) (-2378 (($) 40 (-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794)))) CONST)) (-3255 (($) 24 (-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722)))) CONST)) (-1349 (((-121) $ $) NIL (-1841 (-12 (|has| |#1| (-794)) (|has| |#2| (-794))) (-12 (|has| |#1| (-848)) (|has| |#2| (-848)))))) (-1338 (((-121) $ $) NIL (-1841 (-12 (|has| |#1| (-794)) (|has| |#2| (-794))) (-12 (|has| |#1| (-848)) (|has| |#2| (-848)))))) (-1324 (((-121) $ $) 18)) (-1343 (((-121) $ $) NIL (-1841 (-12 (|has| |#1| (-794)) (|has| |#2| (-794))) (-12 (|has| |#1| (-848)) (|has| |#2| (-848)))))) (-1334 (((-121) $ $) 66 (-1841 (-12 (|has| |#1| (-794)) (|has| |#2| (-794))) (-12 (|has| |#1| (-848)) (|has| |#2| (-848)))))) (-1379 (($ $ $) NIL (-12 (|has| |#1| (-482)) (|has| |#2| (-482))))) (-1373 (($ $ $) 56 (-12 (|has| |#1| (-21)) (|has| |#2| (-21)))) (($ $) 53 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))))) (-1367 (($ $ $) 43 (-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794)))))) (** (($ $ (-572)) NIL (-12 (|has| |#1| (-482)) (|has| |#2| (-482)))) (($ $ (-769)) 31 (-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722))))) (($ $ (-923)) NIL (-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722)))))) (* (($ (-572) $) 60 (-12 (|has| |#1| (-21)) (|has| |#2| (-21)))) (($ (-769) $) 46 (-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794))))) (($ (-923) $) NIL (-1841 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-138)) (|has| |#2| (-138))) (-12 (|has| |#1| (-794)) (|has| |#2| (-794))))) (($ $ $) 27 (-1841 (-12 (|has| |#1| (-482)) (|has| |#2| (-482))) (-12 (|has| |#1| (-722)) (|has| |#2| (-722))))))) 
-(((-972 |#1| |#2|) (-13 (-1098) (-10 -8 (IF (|has| |#1| (-374)) (IF (|has| |#2| (-374)) (-6 (-374)) |noBranch|) |noBranch|) (IF (|has| |#1| (-722)) (IF (|has| |#2| (-722)) (-6 (-722)) |noBranch|) |noBranch|) (IF (|has| |#1| (-23)) (IF (|has| |#2| (-23)) (-6 (-23)) |noBranch|) |noBranch|) (IF (|has| |#1| (-138)) (IF (|has| |#2| (-138)) (-6 (-138)) |noBranch|) |noBranch|) (IF (|has| |#1| (-482)) (IF (|has| |#2| (-482)) (-6 (-482)) |noBranch|) |noBranch|) (IF (|has| |#1| (-21)) (IF (|has| |#2| (-21)) (-6 (-21)) |noBranch|) |noBranch|) (IF (|has| |#1| (-794)) (IF (|has| |#2| (-794)) (-6 (-794)) |noBranch|) |noBranch|) (IF (|has| |#1| (-848)) (IF (|has| |#2| (-848)) (-6 (-848)) |noBranch|) |noBranch|) (-15 -4087 ($ |#1| |#2|)) (-15 -2482 (|#1| $)) (-15 -3196 (|#2| $)))) (-1098) (-1098)) (T -972)) 
-((-4087 (*1 *1 *2 *3) (-12 (-5 *1 (-972 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) (-2482 (*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-972 *2 *3)) (-4 *3 (-1098)))) (-3196 (*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-972 *3 *2)) (-4 *3 (-1098))))) 
-(-13 (-1098) (-10 -8 (IF (|has| |#1| (-374)) (IF (|has| |#2| (-374)) (-6 (-374)) |noBranch|) |noBranch|) (IF (|has| |#1| (-722)) (IF (|has| |#2| (-722)) (-6 (-722)) |noBranch|) |noBranch|) (IF (|has| |#1| (-23)) (IF (|has| |#2| (-23)) (-6 (-23)) |noBranch|) |noBranch|) (IF (|has| |#1| (-138)) (IF (|has| |#2| (-138)) (-6 (-138)) |noBranch|) |noBranch|) (IF (|has| |#1| (-482)) (IF (|has| |#2| (-482)) (-6 (-482)) |noBranch|) |noBranch|) (IF (|has| |#1| (-21)) (IF (|has| |#2| (-21)) (-6 (-21)) |noBranch|) |noBranch|) (IF (|has| |#1| (-794)) (IF (|has| |#2| (-794)) (-6 (-794)) |noBranch|) |noBranch|) (IF (|has| |#1| (-848)) (IF (|has| |#2| (-848)) (-6 (-848)) |noBranch|) |noBranch|) (-15 -4087 ($ |#1| |#2|)) (-15 -2482 (|#1| $)) (-15 -3196 (|#2| $)))) 
-((-2262 (((-121) $ $) NIL)) (-3283 ((|#1| $ (-572) |#1|) NIL)) (-1452 (((-638 $) (-638 $) (-769)) NIL) (((-638 $) (-638 $)) NIL)) (-3175 (((-121) $ (-769)) NIL) (((-121) $) NIL)) (-1413 (($ (-638 |#1|)) NIL)) (-1988 (((-638 |#1|) $) NIL)) (-3035 (((-638 $) $) NIL) (((-638 $) $ (-769)) NIL)) (-1624 (((-638 |#1|) $) NIL)) (-1658 (((-1152) $) NIL)) (-1620 (((-572) $) NIL)) (-4352 (((-572) $) NIL)) (-3991 (($ $ (-572)) NIL) (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-3277 ((|#1| $ (-572)) NIL)) (-4316 (((-923) $) NIL)) (-3105 ((|#1| $) NIL)) (-3018 (($ $ (-769)) NIL) (($ $) NIL)) (-3972 (((-856) $) NIL) (((-638 |#1|) $) NIL) (($ (-638 |#1|)) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-973 |#1|) (-978 |#1|) (-368)) (T -973)) 
-NIL 
-(-978 |#1|) 
-((-2262 (((-121) $ $) NIL)) (-3283 (((-863 |#1|) $ (-572) (-863 |#1|)) NIL)) (-1452 (((-638 $) (-638 $) (-769)) NIL) (((-638 $) (-638 $)) NIL)) (-3175 (((-121) $ (-769)) NIL) (((-121) $) NIL)) (-1413 (($ (-638 (-863 |#1|))) NIL)) (-1988 (((-638 (-863 |#1|)) $) NIL)) (-3035 (((-638 $) $) NIL) (((-638 $) $ (-769)) NIL)) (-1624 (((-638 (-863 |#1|)) $) NIL)) (-1658 (((-1152) $) NIL)) (-1620 (((-572) $) NIL)) (-4352 (((-572) $) NIL)) (-3991 (($ $ (-572)) NIL) (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-3277 (((-863 |#1|) $ (-572)) NIL)) (-4316 (((-923) $) NIL)) (-3105 (((-863 |#1|) $) NIL)) (-3018 (($ $ (-769)) NIL) (($ $) NIL)) (-3972 (((-856) $) NIL) (((-638 (-863 |#1|)) $) NIL) (($ (-638 (-863 |#1|))) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-974 |#1|) (-978 (-863 |#1|)) (-353)) (T -974)) 
-NIL 
-(-978 (-863 |#1|)) 
-((-2262 (((-121) $ $) NIL)) (-3283 ((|#2| $ (-572) |#2|) NIL)) (-1452 (((-638 $) (-638 $) (-769)) 41) (((-638 $) (-638 $)) 42)) (-3175 (((-121) $ (-769)) 38) (((-121) $) 40)) (-1413 (($ (-638 |#2|)) 25)) (-1988 (((-638 |#2|) $) 27)) (-3035 (((-638 $) $) 50) (((-638 $) $ (-769)) 47)) (-1624 (((-638 |#2|) $) 26)) (-1658 (((-1152) $) NIL)) (-1620 (((-572) $) 59)) (-4352 (((-572) $) 62)) (-3991 (($ $ (-572)) 36) (($ $) 52)) (-2607 (((-1116) $) NIL)) (-3277 ((|#2| $ (-572)) 32)) (-4316 (((-923) $) 16)) (-3105 ((|#2| $) 22)) (-3018 (($ $ (-769)) 30) (($ $) 49)) (-3972 (((-856) $) 19) (((-638 |#2|) $) 24) (($ (-638 |#2|)) 58)) (-1324 (((-121) $ $) 37))) 
-(((-975 |#1| |#2|) (-978 |#2|) (-769) (-368)) (T -975)) 
-NIL 
-(-978 |#2|) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-2211 (($) 7 T CONST)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-3279 (($ $ $) 40)) (-4475 (($ $ $) 41)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-4238 ((|#1| $) 42)) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-976 |#1|) (-1290) (-848)) (T -976)) 
-((-4238 (*1 *2 *1) (-12 (-4 *1 (-976 *2)) (-4 *2 (-848)))) (-4475 (*1 *1 *1 *1) (-12 (-4 *1 (-976 *2)) (-4 *2 (-848)))) (-3279 (*1 *1 *1 *1) (-12 (-4 *1 (-976 *2)) (-4 *2 (-848))))) 
-(-13 (-111 |t#1|) (-10 -8 (-6 -4602) (-15 -4238 (|t#1| $)) (-15 -4475 ($ $ $)) (-15 -3279 ($ $ $)))) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-4412 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3069 |#2|)) |#2| |#2|) 84)) (-2824 ((|#2| |#2| |#2|) 82)) (-3395 (((-2 (|:| |coef2| |#2|) (|:| -3069 |#2|)) |#2| |#2|) 86)) (-2485 (((-2 (|:| |coef1| |#2|) (|:| -3069 |#2|)) |#2| |#2|) 88)) (-1513 (((-2 (|:| |coef2| |#2|) (|:| -3462 |#1|)) |#2| |#2|) 106 (|has| |#1| (-457)))) (-2293 (((-2 (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|) 45)) (-1581 (((-2 (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|) 63)) (-2082 (((-2 (|:| |coef1| |#2|) (|:| -3190 |#1|)) |#2| |#2|) 65)) (-3902 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) 77)) (-2628 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769)) 70)) (-1731 (((-2 (|:| |coef2| |#2|) (|:| -2119 |#1|)) |#2|) 96)) (-2820 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769)) 73)) (-4226 (((-638 (-769)) |#2| |#2|) 81)) (-3427 ((|#1| |#2| |#2|) 41)) (-1999 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3462 |#1|)) |#2| |#2|) 104 (|has| |#1| (-457)))) (-3462 ((|#1| |#2| |#2|) 102 (|has| |#1| (-457)))) (-1563 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|) 43)) (-3511 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|) 62)) (-3190 ((|#1| |#2| |#2|) 60)) (-1449 (((-2 (|:| -4513 |#1|) (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2|) 35)) (-3109 ((|#2| |#2| |#2| |#2| |#1|) 52)) (-2217 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) 75)) (-4416 ((|#2| |#2| |#2|) 74)) (-3846 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769)) 68)) (-2694 ((|#2| |#2| |#2| (-769)) 66)) (-3069 ((|#2| |#2| |#2|) 110 (|has| |#1| (-457)))) (-1803 (((-1259 |#2|) (-1259 |#2|) |#1|) 21)) (-2541 (((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2|) 38)) (-2299 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2119 |#1|)) |#2|) 94)) (-2119 ((|#1| |#2|) 91)) (-4124 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769)) 72)) (-3655 ((|#2| |#2| |#2| (-769)) 71)) (-2068 (((-638 |#2|) |#2| |#2|) 79)) (-3454 ((|#2| |#2| |#1| |#1| (-769)) 49)) (-2193 ((|#1| |#1| |#1| (-769)) 48)) (* (((-1259 |#2|) |#1| (-1259 |#2|)) 16))) 
-(((-977 |#1| |#2|) (-10 -7 (-15 -3190 (|#1| |#2| |#2|)) (-15 -3511 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|)) (-15 -1581 ((-2 (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|)) (-15 -2082 ((-2 (|:| |coef1| |#2|) (|:| -3190 |#1|)) |#2| |#2|)) (-15 -2694 (|#2| |#2| |#2| (-769))) (-15 -3846 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769))) (-15 -2628 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769))) (-15 -3655 (|#2| |#2| |#2| (-769))) (-15 -4124 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769))) (-15 -2820 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769))) (-15 -4416 (|#2| |#2| |#2|)) (-15 -2217 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -3902 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -2824 (|#2| |#2| |#2|)) (-15 -4412 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3069 |#2|)) |#2| |#2|)) (-15 -3395 ((-2 (|:| |coef2| |#2|) (|:| -3069 |#2|)) |#2| |#2|)) (-15 -2485 ((-2 (|:| |coef1| |#2|) (|:| -3069 |#2|)) |#2| |#2|)) (-15 -2119 (|#1| |#2|)) (-15 -2299 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2119 |#1|)) |#2|)) (-15 -1731 ((-2 (|:| |coef2| |#2|) (|:| -2119 |#1|)) |#2|)) (-15 -2068 ((-638 |#2|) |#2| |#2|)) (-15 -4226 ((-638 (-769)) |#2| |#2|)) (IF (|has| |#1| (-457)) (PROGN (-15 -3462 (|#1| |#2| |#2|)) (-15 -1999 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3462 |#1|)) |#2| |#2|)) (-15 -1513 ((-2 (|:| |coef2| |#2|) (|:| -3462 |#1|)) |#2| |#2|)) (-15 -3069 (|#2| |#2| |#2|))) |noBranch|) (-15 * ((-1259 |#2|) |#1| (-1259 |#2|))) (-15 -1803 ((-1259 |#2|) (-1259 |#2|) |#1|)) (-15 -1449 ((-2 (|:| -4513 |#1|) (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2|)) (-15 -2541 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2|)) (-15 -2193 (|#1| |#1| |#1| (-769))) (-15 -3454 (|#2| |#2| |#1| |#1| (-769))) (-15 -3109 (|#2| |#2| |#2| |#2| |#1|)) (-15 -3427 (|#1| |#2| |#2|)) (-15 -1563 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|)) (-15 -2293 ((-2 (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|))) (-562) (-1234 |#1|)) (T -977)) 
-((-2293 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-1563 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-3427 (*1 *2 *3 *3) (-12 (-4 *2 (-562)) (-5 *1 (-977 *2 *3)) (-4 *3 (-1234 *2)))) (-3109 (*1 *2 *2 *2 *2 *3) (-12 (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3)))) (-3454 (*1 *2 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3)))) (-2193 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *2 (-562)) (-5 *1 (-977 *2 *4)) (-4 *4 (-1234 *2)))) (-2541 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-1449 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| -4513 *4) (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-1803 (*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-562)) (-5 *1 (-977 *3 *4)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-1259 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-562)) (-5 *1 (-977 *3 *4)))) (-3069 (*1 *2 *2 *2) (-12 (-4 *3 (-457)) (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3)))) (-1513 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3462 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-1999 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3462 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-3462 (*1 *2 *3 *3) (-12 (-4 *2 (-562)) (-4 *2 (-457)) (-5 *1 (-977 *2 *3)) (-4 *3 (-1234 *2)))) (-4226 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 (-769))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-2068 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 *3)) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-1731 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2119 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-2299 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2119 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-2119 (*1 *2 *3) (-12 (-4 *2 (-562)) (-5 *1 (-977 *2 *3)) (-4 *3 (-1234 *2)))) (-2485 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -3069 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-3395 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3069 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-4412 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3069 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-2824 (*1 *2 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3)))) (-3902 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-2217 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-4416 (*1 *2 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3)))) (-2820 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *5 *3)) (-4 *3 (-1234 *5)))) (-4124 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *5 *3)) (-4 *3 (-1234 *5)))) (-3655 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-562)) (-5 *1 (-977 *4 *2)) (-4 *2 (-1234 *4)))) (-2628 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *5 *3)) (-4 *3 (-1234 *5)))) (-3846 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *5 *3)) (-4 *3 (-1234 *5)))) (-2694 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-562)) (-5 *1 (-977 *4 *2)) (-4 *2 (-1234 *4)))) (-2082 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-1581 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-3511 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) (-3190 (*1 *2 *3 *3) (-12 (-4 *2 (-562)) (-5 *1 (-977 *2 *3)) (-4 *3 (-1234 *2))))) 
-(-10 -7 (-15 -3190 (|#1| |#2| |#2|)) (-15 -3511 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|)) (-15 -1581 ((-2 (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|)) (-15 -2082 ((-2 (|:| |coef1| |#2|) (|:| -3190 |#1|)) |#2| |#2|)) (-15 -2694 (|#2| |#2| |#2| (-769))) (-15 -3846 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769))) (-15 -2628 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769))) (-15 -3655 (|#2| |#2| |#2| (-769))) (-15 -4124 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769))) (-15 -2820 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-769))) (-15 -4416 (|#2| |#2| |#2|)) (-15 -2217 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -3902 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -2824 (|#2| |#2| |#2|)) (-15 -4412 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3069 |#2|)) |#2| |#2|)) (-15 -3395 ((-2 (|:| |coef2| |#2|) (|:| -3069 |#2|)) |#2| |#2|)) (-15 -2485 ((-2 (|:| |coef1| |#2|) (|:| -3069 |#2|)) |#2| |#2|)) (-15 -2119 (|#1| |#2|)) (-15 -2299 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2119 |#1|)) |#2|)) (-15 -1731 ((-2 (|:| |coef2| |#2|) (|:| -2119 |#1|)) |#2|)) (-15 -2068 ((-638 |#2|) |#2| |#2|)) (-15 -4226 ((-638 (-769)) |#2| |#2|)) (IF (|has| |#1| (-457)) (PROGN (-15 -3462 (|#1| |#2| |#2|)) (-15 -1999 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3462 |#1|)) |#2| |#2|)) (-15 -1513 ((-2 (|:| |coef2| |#2|) (|:| -3462 |#1|)) |#2| |#2|)) (-15 -3069 (|#2| |#2| |#2|))) |noBranch|) (-15 * ((-1259 |#2|) |#1| (-1259 |#2|))) (-15 -1803 ((-1259 |#2|) (-1259 |#2|) |#1|)) (-15 -1449 ((-2 (|:| -4513 |#1|) (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2|)) (-15 -2541 ((-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) |#2| |#2|)) (-15 -2193 (|#1| |#1| |#1| (-769))) (-15 -3454 (|#2| |#2| |#1| |#1| (-769))) (-15 -3109 (|#2| |#2| |#2| |#2| |#1|)) (-15 -3427 (|#1| |#2| |#2|)) (-15 -1563 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|)) (-15 -2293 ((-2 (|:| |coef2| |#2|) (|:| -3190 |#1|)) |#2| |#2|))) 
-((-2262 (((-121) $ $) 7)) (-3283 ((|#1| $ (-572) |#1|) 14)) (-1452 (((-638 $) (-638 $) (-769)) 22) (((-638 $) (-638 $)) 21)) (-3175 (((-121) $ (-769)) 20) (((-121) $) 19)) (-1413 (($ (-638 |#1|)) 30)) (-1988 (((-638 |#1|) $) 13)) (-3035 (((-638 $) $) 26) (((-638 $) $ (-769)) 25)) (-1624 (((-638 |#1|) $) 16)) (-1658 (((-1152) $) 9)) (-1620 (((-572) $) 17)) (-4352 (((-572) $) 32)) (-3991 (($ $ (-572)) 31) (($ $) 18)) (-2607 (((-1116) $) 10)) (-3277 ((|#1| $ (-572)) 15)) (-4316 (((-923) $) 12)) (-3105 ((|#1| $) 29)) (-3018 (($ $ (-769)) 24) (($ $) 23)) (-3972 (((-856) $) 11) (((-638 |#1|) $) 28) (($ (-638 |#1|)) 27)) (-1324 (((-121) $ $) 6))) 
-(((-978 |#1|) (-1290) (-368)) (T -978)) 
-((-4352 (*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-572)))) (-3991 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-978 *3)) (-4 *3 (-368)))) (-1413 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-978 *3)))) (-3105 (*1 *2 *1) (-12 (-4 *1 (-978 *2)) (-4 *2 (-368)))) (-3972 (*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-978 *3)))) (-3035 (*1 *2 *1) (-12 (-4 *3 (-368)) (-5 *2 (-638 *1)) (-4 *1 (-978 *3)))) (-3035 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *4 (-368)) (-5 *2 (-638 *1)) (-4 *1 (-978 *4)))) (-3018 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-978 *3)) (-4 *3 (-368)))) (-3018 (*1 *1 *1) (-12 (-4 *1 (-978 *2)) (-4 *2 (-368)))) (-1452 (*1 *2 *2 *3) (-12 (-5 *2 (-638 *1)) (-5 *3 (-769)) (-4 *1 (-978 *4)) (-4 *4 (-368)))) (-1452 (*1 *2 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-978 *3)) (-4 *3 (-368)))) (-3175 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-978 *4)) (-4 *4 (-368)) (-5 *2 (-121)))) (-3175 (*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-121)))) (-3991 (*1 *1 *1) (-12 (-4 *1 (-978 *2)) (-4 *2 (-368)))) (-1620 (*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-572)))) (-1624 (*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-978 *2)) (-4 *2 (-368)))) (-3283 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-978 *2)) (-4 *2 (-368)))) (-1988 (*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3))))) 
-(-13 (-1096) (-10 -8 (-15 -4352 ((-572) $)) (-15 -3991 ($ $ (-572))) (-15 -1413 ($ (-638 |t#1|))) (-15 -3105 (|t#1| $)) (-15 -3972 ((-638 |t#1|) $)) (-15 -3972 ($ (-638 |t#1|))) (-15 -3035 ((-638 $) $)) (-15 -3035 ((-638 $) $ (-769))) (-15 -3018 ($ $ (-769))) (-15 -3018 ($ $)) (-15 -1452 ((-638 $) (-638 $) (-769))) (-15 -1452 ((-638 $) (-638 $))) (-15 -3175 ((-121) $ (-769))) (-15 -3175 ((-121) $)) (-15 -3991 ($ $)) (-15 -1620 ((-572) $)) (-15 -1624 ((-638 |t#1|) $)) (-15 -3277 (|t#1| $ (-572))) (-15 -3283 (|t#1| $ (-572) |t#1|)) (-15 -1988 ((-638 |t#1|) $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T) ((-1096) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) 26)) (-2211 (($) NIL T CONST)) (-1383 (((-638 (-638 (-572))) (-638 (-572))) 28)) (-3709 (((-572) $) 44)) (-2276 (($ (-638 (-572))) 17)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4081 (((-638 (-572)) $) 11)) (-3018 (($ $) 31)) (-3972 (((-856) $) 42) (((-638 (-572)) $) 9)) (-2378 (($) 7 T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 19)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 18)) (-1367 (($ $ $) 20)) (* (($ (-769) $) 24) (($ (-923) $) NIL))) 
-(((-979) (-13 (-796) (-613 (-638 (-572))) (-10 -8 (-15 -2276 ($ (-638 (-572)))) (-15 -1383 ((-638 (-638 (-572))) (-638 (-572)))) (-15 -3709 ((-572) $)) (-15 -3018 ($ $)) (-15 -3972 ((-638 (-572)) $))))) (T -979)) 
-((-2276 (*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-979)))) (-1383 (*1 *2 *3) (-12 (-5 *2 (-638 (-638 (-572)))) (-5 *1 (-979)) (-5 *3 (-638 (-572))))) (-3709 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-979)))) (-3018 (*1 *1 *1) (-5 *1 (-979))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-979))))) 
-(-13 (-796) (-613 (-638 (-572))) (-10 -8 (-15 -2276 ($ (-638 (-572)))) (-15 -1383 ((-638 (-638 (-572))) (-638 (-572)))) (-15 -3709 ((-572) $)) (-15 -3018 ($ $)) (-15 -3972 ((-638 (-572)) $)))) 
-((-1379 (($ $ |#2|) 30)) (-1373 (($ $) 22) (($ $ $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 15) (($ $ $) NIL) (($ $ |#2|) 20) (($ |#2| $) 19) (($ (-413 (-572)) $) 26) (($ $ (-413 (-572))) 28))) 
-(((-980 |#1| |#2| |#3| |#4|) (-10 -8 (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 -1379 (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) (-981 |#2| |#3| |#4|) (-1054) (-793) (-848)) (T -980)) 
-NIL 
-(-10 -8 (-15 * (|#1| |#1| (-413 (-572)))) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 -1379 (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 * (|#1| (-923) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 |#3|) $) 70)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-4383 (($ $) 59)) (-1799 (((-3 $ "failed") $) 33)) (-1347 (((-121) $) 69)) (-3893 (((-121) $) 30)) (-4581 (((-121) $) 61)) (-4328 (($ |#1| |#2|) 60) (($ $ |#3| |#2|) 72) (($ $ (-638 |#3|) (-638 |#2|)) 71)) (-3828 (($ (-1 |#1| |#1|) $) 62)) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562)))) (-4316 ((|#2| $) 63)) (-2424 (($ $) 68)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 56 (|has| |#1| (-43 (-413 (-572))))) (($ $) 48 (|has| |#1| (-562))) (($ |#1|) 46 (|has| |#1| (-174)))) (-1958 ((|#1| $ |#2|) 58)) (-2779 (((-3 $ "failed") $) 47 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-981 |#1| |#2| |#3|) (-1290) (-1054) (-793) (-848)) (T -981)) 
-((-4373 (*1 *2 *1) (-12 (-4 *1 (-981 *2 *3 *4)) (-4 *3 (-793)) (-4 *4 (-848)) (-4 *2 (-1054)))) (-4368 (*1 *1 *1) (-12 (-4 *1 (-981 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *4 (-848)))) (-4316 (*1 *2 *1) (-12 (-4 *1 (-981 *3 *2 *4)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *2 (-793)))) (-4328 (*1 *1 *1 *2 *3) (-12 (-4 *1 (-981 *4 *3 *2)) (-4 *4 (-1054)) (-4 *3 (-793)) (-4 *2 (-848)))) (-4328 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *6)) (-5 *3 (-638 *5)) (-4 *1 (-981 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-793)) (-4 *6 (-848)))) (-3456 (*1 *2 *1) (-12 (-4 *1 (-981 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-793)) (-4 *5 (-848)) (-5 *2 (-638 *5)))) (-1347 (*1 *2 *1) (-12 (-4 *1 (-981 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-793)) (-4 *5 (-848)) (-5 *2 (-121)))) (-2424 (*1 *1 *1) (-12 (-4 *1 (-981 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *4 (-848))))) 
-(-13 (-52 |t#1| |t#2|) (-10 -8 (-15 -4328 ($ $ |t#3| |t#2|)) (-15 -4328 ($ $ (-638 |t#3|) (-638 |t#2|))) (-15 -4368 ($ $)) (-15 -4373 (|t#1| $)) (-15 -4316 (|t#2| $)) (-15 -3456 ((-638 |t#3|) $)) (-15 -1347 ((-121) $)) (-15 -2424 ($ $)))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) |has| |#1| (-562)) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-287) |has| |#1| (-562)) ((-562) |has| |#1| (-562)) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) |has| |#1| (-562)) ((-722) . T) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2721 (((-1092 (-217)) $) 7)) (-1497 (((-1092 (-217)) $) 8)) (-2153 (((-1092 (-217)) $) 9)) (-3192 (((-638 (-638 (-950 (-217)))) $) 10)) (-3972 (((-856) $) 6))) 
-(((-982) (-1290)) (T -982)) 
-((-3192 (*1 *2 *1) (-12 (-4 *1 (-982)) (-5 *2 (-638 (-638 (-950 (-217))))))) (-2153 (*1 *2 *1) (-12 (-4 *1 (-982)) (-5 *2 (-1092 (-217))))) (-1497 (*1 *2 *1) (-12 (-4 *1 (-982)) (-5 *2 (-1092 (-217))))) (-2721 (*1 *2 *1) (-12 (-4 *1 (-982)) (-5 *2 (-1092 (-217)))))) 
-(-13 (-612 (-856)) (-10 -8 (-15 -3192 ((-638 (-638 (-950 (-217)))) $)) (-15 -2153 ((-1092 (-217)) $)) (-15 -1497 ((-1092 (-217)) $)) (-15 -2721 ((-1092 (-217)) $)))) 
-(((-612 (-856)) . T)) 
-((-3456 (((-638 |#4|) $) 23)) (-3049 (((-121) $) 47)) (-3289 (((-121) $) 46)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#4|) 35)) (-3097 (((-121) $) 48)) (-3760 (((-121) $ $) 54)) (-3819 (((-121) $ $) 57)) (-4331 (((-121) $) 52)) (-3683 (((-638 |#5|) (-638 |#5|) $) 89)) (-2320 (((-638 |#5|) (-638 |#5|) $) 86)) (-2492 (((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| $) 80)) (-4062 (((-638 |#4|) $) 27)) (-1346 (((-121) |#4| $) 29)) (-2566 (((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| $) 72)) (-1826 (($ $ |#4|) 32)) (-2291 (($ $ |#4|) 31)) (-1650 (($ $ |#4|) 33)) (-1324 (((-121) $ $) 39))) 
-(((-983 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -3289 ((-121) |#1|)) (-15 -3683 ((-638 |#5|) (-638 |#5|) |#1|)) (-15 -2320 ((-638 |#5|) (-638 |#5|) |#1|)) (-15 -2492 ((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -2566 ((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -3097 ((-121) |#1|)) (-15 -3819 ((-121) |#1| |#1|)) (-15 -3760 ((-121) |#1| |#1|)) (-15 -4331 ((-121) |#1|)) (-15 -3049 ((-121) |#1|)) (-15 -3008 ((-2 (|:| |under| |#1|) (|:| -1716 |#1|) (|:| |upper| |#1|)) |#1| |#4|)) (-15 -1826 (|#1| |#1| |#4|)) (-15 -1650 (|#1| |#1| |#4|)) (-15 -2291 (|#1| |#1| |#4|)) (-15 -1346 ((-121) |#4| |#1|)) (-15 -4062 ((-638 |#4|) |#1|)) (-15 -3456 ((-638 |#4|) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) (-984 |#2| |#3| |#4| |#5|) (-1054) (-794) (-848) (-1068 |#2| |#3| |#4|)) (T -983)) 
-NIL 
-(-10 -8 (-15 -3289 ((-121) |#1|)) (-15 -3683 ((-638 |#5|) (-638 |#5|) |#1|)) (-15 -2320 ((-638 |#5|) (-638 |#5|) |#1|)) (-15 -2492 ((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -2566 ((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -3097 ((-121) |#1|)) (-15 -3819 ((-121) |#1| |#1|)) (-15 -3760 ((-121) |#1| |#1|)) (-15 -4331 ((-121) |#1|)) (-15 -3049 ((-121) |#1|)) (-15 -3008 ((-2 (|:| |under| |#1|) (|:| -1716 |#1|) (|:| |upper| |#1|)) |#1| |#4|)) (-15 -1826 (|#1| |#1| |#4|)) (-15 -1650 (|#1| |#1| |#4|)) (-15 -2291 (|#1| |#1| |#4|)) (-15 -1346 ((-121) |#4| |#1|)) (-15 -4062 ((-638 |#4|) |#1|)) (-15 -3456 ((-638 |#4|) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-3456 (((-638 |#3|) $) 32)) (-3049 (((-121) $) 25)) (-3289 (((-121) $) 16 (|has| |#1| (-562)))) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) 26)) (-1946 (((-121) $ (-769)) 43)) (-2561 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4602)))) (-2211 (($) 44 T CONST)) (-3097 (((-121) $) 21 (|has| |#1| (-562)))) (-3760 (((-121) $ $) 23 (|has| |#1| (-562)))) (-3819 (((-121) $ $) 22 (|has| |#1| (-562)))) (-4331 (((-121) $) 24 (|has| |#1| (-562)))) (-3683 (((-638 |#4|) (-638 |#4|) $) 17 (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) 18 (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) 35)) (-1318 (($ (-638 |#4|)) 34)) (-1643 (($ $) 67 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#4| $) 66 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-562)))) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4602)))) (-2010 (((-638 |#4|) $) 51 (|has| $ (-6 -4602)))) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) 42)) (-4467 (((-638 |#4|) $) 52 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 46)) (-4062 (((-638 |#3|) $) 31)) (-1346 (((-121) |#3| $) 30)) (-3524 (((-121) $ (-769)) 41)) (-1658 (((-1152) $) 9)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-562)))) (-2607 (((-1116) $) 10)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-2109 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) 58 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) 56 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) 55 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) 37)) (-4037 (((-121) $) 40)) (-1665 (($) 39)) (-1571 (((-769) |#4| $) 53 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4602)))) (-1607 (($ $) 38)) (-4081 (((-545) $) 68 (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 59)) (-1826 (($ $ |#3|) 27)) (-2291 (($ $ |#3|) 29)) (-1650 (($ $ |#3|) 28)) (-3972 (((-856) $) 11) (((-638 |#4|) $) 36)) (-3501 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 6)) (-4032 (((-769) $) 45 (|has| $ (-6 -4602))))) 
-(((-984 |#1| |#2| |#3| |#4|) (-1290) (-1054) (-794) (-848) (-1068 |t#1| |t#2| |t#3|)) (T -984)) 
-((-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *1 (-984 *3 *4 *5 *6)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *1 (-984 *3 *4 *5 *6)))) (-1792 (*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-1068 *3 *4 *2)) (-4 *2 (-848)))) (-3456 (*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-638 *5)))) (-4062 (*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-638 *5)))) (-1346 (*1 *2 *3 *1) (-12 (-4 *1 (-984 *4 *5 *3 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-4 *6 (-1068 *4 *5 *3)) (-5 *2 (-121)))) (-2291 (*1 *1 *1 *2) (-12 (-4 *1 (-984 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *5 (-1068 *3 *4 *2)))) (-1650 (*1 *1 *1 *2) (-12 (-4 *1 (-984 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *5 (-1068 *3 *4 *2)))) (-1826 (*1 *1 *1 *2) (-12 (-4 *1 (-984 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *5 (-1068 *3 *4 *2)))) (-3008 (*1 *2 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-4 *6 (-1068 *4 *5 *3)) (-5 *2 (-2 (|:| |under| *1) (|:| -1716 *1) (|:| |upper| *1))) (-4 *1 (-984 *4 *5 *3 *6)))) (-3049 (*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) (-4331 (*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121)))) (-3760 (*1 *2 *1 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121)))) (-3819 (*1 *2 *1 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121)))) (-3097 (*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121)))) (-2566 (*1 *2 *3 *1) (-12 (-4 *1 (-984 *4 *5 *6 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))))) (-2492 (*1 *2 *3 *1) (-12 (-4 *1 (-984 *4 *5 *6 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4))))) (-2320 (*1 *2 *2 *1) (-12 (-5 *2 (-638 *6)) (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)))) (-3683 (*1 *2 *2 *1) (-12 (-5 *2 (-638 *6)) (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)))) (-3289 (*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121))))) 
-(-13 (-1098) (-155 |t#4|) (-612 (-638 |t#4|)) (-10 -8 (-6 -4602) (-15 -3376 ((-3 $ "failed") (-638 |t#4|))) (-15 -1318 ($ (-638 |t#4|))) (-15 -1792 (|t#3| $)) (-15 -3456 ((-638 |t#3|) $)) (-15 -4062 ((-638 |t#3|) $)) (-15 -1346 ((-121) |t#3| $)) (-15 -2291 ($ $ |t#3|)) (-15 -1650 ($ $ |t#3|)) (-15 -1826 ($ $ |t#3|)) (-15 -3008 ((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |t#3|)) (-15 -3049 ((-121) $)) (IF (|has| |t#1| (-562)) (PROGN (-15 -4331 ((-121) $)) (-15 -3760 ((-121) $ $)) (-15 -3819 ((-121) $ $)) (-15 -3097 ((-121) $)) (-15 -2566 ((-2 (|:| |num| |t#4|) (|:| |den| |t#1|)) |t#4| $)) (-15 -2492 ((-2 (|:| |rnum| |t#1|) (|:| |polnum| |t#4|) (|:| |den| |t#1|)) |t#4| $)) (-15 -2320 ((-638 |t#4|) (-638 |t#4|) $)) (-15 -3683 ((-638 |t#4|) (-638 |t#4|) $)) (-15 -3289 ((-121) $))) |noBranch|))) 
-(((-39) . T) ((-105) . T) ((-612 (-638 |#4|)) . T) ((-612 (-856)) . T) ((-155 |#4|) . T) ((-613 (-545)) |has| |#4| (-613 (-545))) ((-305 |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-503 |#4|) . T) ((-527 |#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-1098) . T) ((-1204) . T)) 
-((-3869 (((-638 |#4|) |#4| |#4|) 114)) (-1320 (((-638 |#4|) (-638 |#4|) (-121)) 103 (|has| |#1| (-457))) (((-638 |#4|) (-638 |#4|)) 104 (|has| |#1| (-457)))) (-2313 (((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|)) 34)) (-2614 (((-121) |#4|) 33)) (-2405 (((-638 |#4|) |#4|) 100 (|has| |#1| (-457)))) (-2479 (((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-1 (-121) |#4|) (-638 |#4|)) 19)) (-3791 (((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 (-1 (-121) |#4|)) (-638 |#4|)) 21)) (-3798 (((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 (-1 (-121) |#4|)) (-638 |#4|)) 22)) (-1503 (((-3 (-2 (|:| |bas| (-485 |#1| |#2| |#3| |#4|)) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|)) 72)) (-4420 (((-638 |#4|) (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 84)) (-3471 (((-638 |#4|) (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 107)) (-1377 (((-638 |#4|) (-638 |#4|)) 106)) (-3789 (((-638 |#4|) (-638 |#4|) (-638 |#4|) (-121)) 47) (((-638 |#4|) (-638 |#4|) (-638 |#4|)) 49)) (-2758 ((|#4| |#4| (-638 |#4|)) 48)) (-3643 (((-638 |#4|) (-638 |#4|) (-638 |#4|)) 110 (|has| |#1| (-457)))) (-2445 (((-638 |#4|) (-638 |#4|) (-638 |#4|)) 113 (|has| |#1| (-457)))) (-3716 (((-638 |#4|) (-638 |#4|) (-638 |#4|)) 112 (|has| |#1| (-457)))) (-4375 (((-638 |#4|) (-638 |#4|) (-638 |#4|) (-1 (-638 |#4|) (-638 |#4|))) 86) (((-638 |#4|) (-638 |#4|) (-638 |#4|)) 88) (((-638 |#4|) (-638 |#4|) |#4|) 117) (((-638 |#4|) |#4| |#4|) 115) (((-638 |#4|) (-638 |#4|)) 87)) (-4016 (((-638 |#4|) (-638 |#4|) (-638 |#4|)) 97 (-12 (|has| |#1| (-151)) (|has| |#1| (-303))))) (-3684 (((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|)) 40)) (-2374 (((-121) (-638 |#4|)) 61)) (-4098 (((-121) (-638 |#4|) (-638 (-638 |#4|))) 52)) (-3886 (((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|)) 28)) (-3812 (((-121) |#4|) 27)) (-3352 (((-638 |#4|) (-638 |#4|)) 96 (-12 (|has| |#1| (-151)) (|has| |#1| (-303))))) (-4166 (((-638 |#4|) (-638 |#4|)) 95 (-12 (|has| |#1| (-151)) (|has| |#1| (-303))))) (-2024 (((-638 |#4|) (-638 |#4|)) 65)) (-2055 (((-638 |#4|) (-638 |#4|)) 78)) (-1433 (((-121) (-638 |#4|) (-638 |#4|)) 50)) (-1972 (((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|)) 38)) (-3581 (((-121) |#4|) 35))) 
-(((-985 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4375 ((-638 |#4|) (-638 |#4|))) (-15 -4375 ((-638 |#4|) |#4| |#4|)) (-15 -1377 ((-638 |#4|) (-638 |#4|))) (-15 -3869 ((-638 |#4|) |#4| |#4|)) (-15 -4375 ((-638 |#4|) (-638 |#4|) |#4|)) (-15 -4375 ((-638 |#4|) (-638 |#4|) (-638 |#4|))) (-15 -4375 ((-638 |#4|) (-638 |#4|) (-638 |#4|) (-1 (-638 |#4|) (-638 |#4|)))) (-15 -1433 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -4098 ((-121) (-638 |#4|) (-638 (-638 |#4|)))) (-15 -2374 ((-121) (-638 |#4|))) (-15 -2479 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-1 (-121) |#4|) (-638 |#4|))) (-15 -3791 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 (-1 (-121) |#4|)) (-638 |#4|))) (-15 -3798 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 (-1 (-121) |#4|)) (-638 |#4|))) (-15 -3684 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|))) (-15 -2614 ((-121) |#4|)) (-15 -2313 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|))) (-15 -3812 ((-121) |#4|)) (-15 -3886 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|))) (-15 -3581 ((-121) |#4|)) (-15 -1972 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|))) (-15 -3789 ((-638 |#4|) (-638 |#4|) (-638 |#4|))) (-15 -3789 ((-638 |#4|) (-638 |#4|) (-638 |#4|) (-121))) (-15 -2758 (|#4| |#4| (-638 |#4|))) (-15 -2024 ((-638 |#4|) (-638 |#4|))) (-15 -1503 ((-3 (-2 (|:| |bas| (-485 |#1| |#2| |#3| |#4|)) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|))) (-15 -2055 ((-638 |#4|) (-638 |#4|))) (-15 -4420 ((-638 |#4|) (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3471 ((-638 |#4|) (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (IF (|has| |#1| (-457)) (PROGN (-15 -2405 ((-638 |#4|) |#4|)) (-15 -1320 ((-638 |#4|) (-638 |#4|))) (-15 -1320 ((-638 |#4|) (-638 |#4|) (-121))) (-15 -3643 ((-638 |#4|) (-638 |#4|) (-638 |#4|))) (-15 -3716 ((-638 |#4|) (-638 |#4|) (-638 |#4|))) (-15 -2445 ((-638 |#4|) (-638 |#4|) (-638 |#4|)))) |noBranch|) (IF (|has| |#1| (-303)) (IF (|has| |#1| (-151)) (PROGN (-15 -4166 ((-638 |#4|) (-638 |#4|))) (-15 -3352 ((-638 |#4|) (-638 |#4|))) (-15 -4016 ((-638 |#4|) (-638 |#4|) (-638 |#4|)))) |noBranch|) |noBranch|)) (-562) (-794) (-848) (-1068 |#1| |#2| |#3|)) (T -985)) 
-((-4016 (*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-151)) (-4 *3 (-303)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-3352 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-151)) (-4 *3 (-303)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-4166 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-151)) (-4 *3 (-303)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-2445 (*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-457)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-3716 (*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-457)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-3643 (*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-457)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-1320 (*1 *2 *2 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-121)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *7)))) (-1320 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-457)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-2405 (*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *3)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6)))) (-3471 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-638 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-985 *5 *6 *7 *8)))) (-4420 (*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-638 *9)) (-5 *3 (-1 (-121) *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1068 *6 *7 *8)) (-4 *6 (-562)) (-4 *7 (-794)) (-4 *8 (-848)) (-5 *1 (-985 *6 *7 *8 *9)))) (-2055 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-1503 (*1 *2 *3) (|partial| -12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |bas| (-485 *4 *5 *6 *7)) (|:| -1615 (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) (-2024 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-2758 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *2)))) (-3789 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-121)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *7)))) (-3789 (*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-1972 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-638 *7)) (|:| |badPols| (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) (-3581 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6)))) (-3886 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-638 *7)) (|:| |badPols| (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) (-3812 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6)))) (-2313 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-638 *7)) (|:| |badPols| (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) (-2614 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6)))) (-3684 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-638 *7)) (|:| |badPols| (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) (-3798 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1 (-121) *8))) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |goodPols| (-638 *8)) (|:| |badPols| (-638 *8)))) (-5 *1 (-985 *5 *6 *7 *8)) (-5 *4 (-638 *8)))) (-3791 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1 (-121) *8))) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |goodPols| (-638 *8)) (|:| |badPols| (-638 *8)))) (-5 *1 (-985 *5 *6 *7 *8)) (-5 *4 (-638 *8)))) (-2479 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-121) *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |goodPols| (-638 *8)) (|:| |badPols| (-638 *8)))) (-5 *1 (-985 *5 *6 *7 *8)) (-5 *4 (-638 *8)))) (-2374 (*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *7)))) (-4098 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-638 *8))) (-5 *3 (-638 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *5 *6 *7 *8)))) (-1433 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *7)))) (-4375 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 (-638 *7) (-638 *7))) (-5 *2 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *7)))) (-4375 (*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-4375 (*1 *2 *2 *3) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *3)))) (-3869 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *3)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6)))) (-1377 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) (-4375 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *3)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6)))) (-4375 (*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(-10 -7 (-15 -4375 ((-638 |#4|) (-638 |#4|))) (-15 -4375 ((-638 |#4|) |#4| |#4|)) (-15 -1377 ((-638 |#4|) (-638 |#4|))) (-15 -3869 ((-638 |#4|) |#4| |#4|)) (-15 -4375 ((-638 |#4|) (-638 |#4|) |#4|)) (-15 -4375 ((-638 |#4|) (-638 |#4|) (-638 |#4|))) (-15 -4375 ((-638 |#4|) (-638 |#4|) (-638 |#4|) (-1 (-638 |#4|) (-638 |#4|)))) (-15 -1433 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -4098 ((-121) (-638 |#4|) (-638 (-638 |#4|)))) (-15 -2374 ((-121) (-638 |#4|))) (-15 -2479 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-1 (-121) |#4|) (-638 |#4|))) (-15 -3791 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 (-1 (-121) |#4|)) (-638 |#4|))) (-15 -3798 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 (-1 (-121) |#4|)) (-638 |#4|))) (-15 -3684 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|))) (-15 -2614 ((-121) |#4|)) (-15 -2313 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|))) (-15 -3812 ((-121) |#4|)) (-15 -3886 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|))) (-15 -3581 ((-121) |#4|)) (-15 -1972 ((-2 (|:| |goodPols| (-638 |#4|)) (|:| |badPols| (-638 |#4|))) (-638 |#4|))) (-15 -3789 ((-638 |#4|) (-638 |#4|) (-638 |#4|))) (-15 -3789 ((-638 |#4|) (-638 |#4|) (-638 |#4|) (-121))) (-15 -2758 (|#4| |#4| (-638 |#4|))) (-15 -2024 ((-638 |#4|) (-638 |#4|))) (-15 -1503 ((-3 (-2 (|:| |bas| (-485 |#1| |#2| |#3| |#4|)) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|))) (-15 -2055 ((-638 |#4|) (-638 |#4|))) (-15 -4420 ((-638 |#4|) (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3471 ((-638 |#4|) (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (IF (|has| |#1| (-457)) (PROGN (-15 -2405 ((-638 |#4|) |#4|)) (-15 -1320 ((-638 |#4|) (-638 |#4|))) (-15 -1320 ((-638 |#4|) (-638 |#4|) (-121))) (-15 -3643 ((-638 |#4|) (-638 |#4|) (-638 |#4|))) (-15 -3716 ((-638 |#4|) (-638 |#4|) (-638 |#4|))) (-15 -2445 ((-638 |#4|) (-638 |#4|) (-638 |#4|)))) |noBranch|) (IF (|has| |#1| (-303)) (IF (|has| |#1| (-151)) (PROGN (-15 -4166 ((-638 |#4|) (-638 |#4|))) (-15 -3352 ((-638 |#4|) (-638 |#4|))) (-15 -4016 ((-638 |#4|) (-638 |#4|) (-638 |#4|)))) |noBranch|) |noBranch|)) 
-((-2310 (((-2 (|:| R (-685 |#1|)) (|:| A (-685 |#1|)) (|:| |Ainv| (-685 |#1|))) (-685 |#1|) (-101 |#1|) (-1 |#1| |#1|)) 19)) (-2493 (((-638 (-2 (|:| C (-685 |#1|)) (|:| |g| (-1259 |#1|)))) (-685 |#1|) (-1259 |#1|)) 35)) (-4222 (((-685 |#1|) (-685 |#1|) (-685 |#1|) (-101 |#1|) (-1 |#1| |#1|)) 16))) 
-(((-986 |#1|) (-10 -7 (-15 -2310 ((-2 (|:| R (-685 |#1|)) (|:| A (-685 |#1|)) (|:| |Ainv| (-685 |#1|))) (-685 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -4222 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -2493 ((-638 (-2 (|:| C (-685 |#1|)) (|:| |g| (-1259 |#1|)))) (-685 |#1|) (-1259 |#1|)))) (-368)) (T -986)) 
-((-2493 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-5 *2 (-638 (-2 (|:| C (-685 *5)) (|:| |g| (-1259 *5))))) (-5 *1 (-986 *5)) (-5 *3 (-685 *5)) (-5 *4 (-1259 *5)))) (-4222 (*1 *2 *2 *2 *3 *4) (-12 (-5 *2 (-685 *5)) (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-368)) (-5 *1 (-986 *5)))) (-2310 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-101 *6)) (-5 *5 (-1 *6 *6)) (-4 *6 (-368)) (-5 *2 (-2 (|:| R (-685 *6)) (|:| A (-685 *6)) (|:| |Ainv| (-685 *6)))) (-5 *1 (-986 *6)) (-5 *3 (-685 *6))))) 
-(-10 -7 (-15 -2310 ((-2 (|:| R (-685 |#1|)) (|:| A (-685 |#1|)) (|:| |Ainv| (-685 |#1|))) (-685 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -4222 ((-685 |#1|) (-685 |#1|) (-685 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -2493 ((-638 (-2 (|:| C (-685 |#1|)) (|:| |g| (-1259 |#1|)))) (-685 |#1|) (-1259 |#1|)))) 
-((-1466 (((-424 |#4|) |#4|) 47))) 
-(((-987 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1466 ((-424 |#4|) |#4|))) (-848) (-794) (-457) (-956 |#3| |#2| |#1|)) (T -987)) 
-((-1466 (*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-457)) (-5 *2 (-424 *3)) (-5 *1 (-987 *4 *5 *6 *3)) (-4 *3 (-956 *6 *5 *4))))) 
-(-10 -7 (-15 -1466 ((-424 |#4|) |#4|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-4169 (($ (-769)) 105 (|has| |#1| (-23)))) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4603))) (($ $) 81 (-12 (|has| |#1| (-848)) (|has| $ (-6 -4603))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#1| $ (-572) |#1|) 49 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 53 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-2985 (($ $) 83 (|has| $ (-6 -4603)))) (-1656 (($ $) 93)) (-1643 (($ $) 73 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#1| $) 72 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) 50 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 48)) (-4014 (((-572) (-1 (-121) |#1|) $) 90) (((-572) |#1| $) 89 (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) 88 (|has| |#1| (-1098)))) (-1767 (($ (-638 |#1|)) 110)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-3349 (((-685 |#1|) $ $) 98 (|has| |#1| (-1054)))) (-1364 (($ (-769) |#1|) 64)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-1771 (($ $ $) 80 (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-4238 (($ $ $) 79 (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3169 ((|#1| $) 95 (-12 (|has| |#1| (-1054)) (|has| |#1| (-1009))))) (-3524 (((-121) $ (-769)) 10)) (-3200 ((|#1| $) 96 (-12 (|has| |#1| (-1054)) (|has| |#1| (-1009))))) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) 55) (($ $ $ (-572)) 54)) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 39 (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3299 (($ $ |#1|) 38 (|has| $ (-6 -4603)))) (-1977 (($ $ (-638 |#1|)) 107)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ (-572) |#1|) 47) ((|#1| $ (-572)) 46) (($ $ (-1225 (-572))) 58)) (-1436 ((|#1| $ $) 99 (|has| |#1| (-1054)))) (-2502 (((-923) $) 109)) (-1940 (($ $ (-572)) 57) (($ $ (-1225 (-572))) 56)) (-3780 (($ $ $) 97)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2907 (($ $ $ (-572)) 84 (|has| $ (-6 -4603)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 74 (|has| |#1| (-613 (-545)))) (($ (-638 |#1|)) 108)) (-3921 (($ (-638 |#1|)) 65)) (-4500 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-638 $)) 60)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) 77 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 76 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-1343 (((-121) $ $) 78 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 75 (|has| |#1| (-848)))) (-1373 (($ $) 104 (|has| |#1| (-21))) (($ $ $) 103 (|has| |#1| (-21)))) (-1367 (($ $ $) 106 (|has| |#1| (-25)))) (* (($ (-572) $) 102 (|has| |#1| (-21))) (($ |#1| $) 101 (|has| |#1| (-722))) (($ $ |#1|) 100 (|has| |#1| (-722)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-988 |#1|) (-1290) (-1054)) (T -988)) 
-((-1767 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1054)) (-4 *1 (-988 *3)))) (-2502 (*1 *2 *1) (-12 (-4 *1 (-988 *3)) (-4 *3 (-1054)) (-5 *2 (-923)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1054)) (-4 *1 (-988 *3)))) (-3780 (*1 *1 *1 *1) (-12 (-4 *1 (-988 *2)) (-4 *2 (-1054)))) (-1977 (*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *1 (-988 *3)) (-4 *3 (-1054))))) 
-(-13 (-1257 |t#1|) (-10 -8 (-15 -1767 ($ (-638 |t#1|))) (-15 -2502 ((-923) $)) (-15 -4081 ($ (-638 |t#1|))) (-15 -3780 ($ $ $)) (-15 -1977 ($ $ (-638 |t#1|))))) 
-(((-39) . T) ((-105) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-612 (-856)) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-379 |#1|) . T) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-644 |#1|) . T) ((-19 |#1|) . T) ((-848) |has| |#1| (-848)) ((-1098) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-1204) . T) ((-1257 |#1|) . T)) 
-((-3828 (((-950 |#2|) (-1 |#2| |#1|) (-950 |#1|)) 17))) 
-(((-989 |#1| |#2|) (-10 -7 (-15 -3828 ((-950 |#2|) (-1 |#2| |#1|) (-950 |#1|)))) (-1054) (-1054)) (T -989)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-950 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-950 *6)) (-5 *1 (-989 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-950 |#2|) (-1 |#2| |#1|) (-950 |#1|)))) 
-((-1307 ((|#1| (-950 |#1|)) 13)) (-1398 ((|#1| (-950 |#1|)) 12)) (-2690 ((|#1| (-950 |#1|)) 11)) (-2345 ((|#1| (-950 |#1|)) 15)) (-4143 ((|#1| (-950 |#1|)) 21)) (-3589 ((|#1| (-950 |#1|)) 14)) (-1764 ((|#1| (-950 |#1|)) 16)) (-2132 ((|#1| (-950 |#1|)) 20)) (-1980 ((|#1| (-950 |#1|)) 19))) 
-(((-990 |#1|) (-10 -7 (-15 -2690 (|#1| (-950 |#1|))) (-15 -1398 (|#1| (-950 |#1|))) (-15 -1307 (|#1| (-950 |#1|))) (-15 -3589 (|#1| (-950 |#1|))) (-15 -2345 (|#1| (-950 |#1|))) (-15 -1764 (|#1| (-950 |#1|))) (-15 -1980 (|#1| (-950 |#1|))) (-15 -2132 (|#1| (-950 |#1|))) (-15 -4143 (|#1| (-950 |#1|)))) (-1054)) (T -990)) 
-((-4143 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054)))) (-2132 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054)))) (-1980 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054)))) (-1764 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054)))) (-2345 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054)))) (-3589 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054)))) (-1307 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054)))) (-1398 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054)))) (-2690 (*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(-10 -7 (-15 -2690 (|#1| (-950 |#1|))) (-15 -1398 (|#1| (-950 |#1|))) (-15 -1307 (|#1| (-950 |#1|))) (-15 -3589 (|#1| (-950 |#1|))) (-15 -2345 (|#1| (-950 |#1|))) (-15 -1764 (|#1| (-950 |#1|))) (-15 -1980 (|#1| (-950 |#1|))) (-15 -2132 (|#1| (-950 |#1|))) (-15 -4143 (|#1| (-950 |#1|)))) 
-((-2857 (((-3 |#1| "failed") |#1|) 18)) (-2748 (((-3 |#1| "failed") |#1|) 6)) (-1580 (((-3 |#1| "failed") |#1|) 16)) (-3302 (((-3 |#1| "failed") |#1|) 4)) (-1326 (((-3 |#1| "failed") |#1|) 20)) (-2887 (((-3 |#1| "failed") |#1|) 8)) (-4345 (((-3 |#1| "failed") |#1| (-769)) 1)) (-2986 (((-3 |#1| "failed") |#1|) 3)) (-2290 (((-3 |#1| "failed") |#1|) 2)) (-3834 (((-3 |#1| "failed") |#1|) 21)) (-2323 (((-3 |#1| "failed") |#1|) 9)) (-2811 (((-3 |#1| "failed") |#1|) 19)) (-4460 (((-3 |#1| "failed") |#1|) 7)) (-1400 (((-3 |#1| "failed") |#1|) 17)) (-1935 (((-3 |#1| "failed") |#1|) 5)) (-4338 (((-3 |#1| "failed") |#1|) 24)) (-3096 (((-3 |#1| "failed") |#1|) 12)) (-4551 (((-3 |#1| "failed") |#1|) 22)) (-3983 (((-3 |#1| "failed") |#1|) 10)) (-3739 (((-3 |#1| "failed") |#1|) 26)) (-3402 (((-3 |#1| "failed") |#1|) 14)) (-3418 (((-3 |#1| "failed") |#1|) 27)) (-4359 (((-3 |#1| "failed") |#1|) 15)) (-4167 (((-3 |#1| "failed") |#1|) 25)) (-4163 (((-3 |#1| "failed") |#1|) 13)) (-1292 (((-3 |#1| "failed") |#1|) 23)) (-2234 (((-3 |#1| "failed") |#1|) 11))) 
-(((-991 |#1|) (-1290) (-1190)) (T -991)) 
-((-3418 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-3739 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-4167 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-4338 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-1292 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-4551 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-3834 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-1326 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-2811 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-2857 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-1400 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-1580 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-4359 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-3402 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-4163 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-3096 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-2234 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-3983 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-2323 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-2887 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-4460 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-2748 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-1935 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-3302 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-2986 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-2290 (*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190)))) (-4345 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-769)) (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(-13 (-10 -7 (-15 -4345 ((-3 |t#1| "failed") |t#1| (-769))) (-15 -2290 ((-3 |t#1| "failed") |t#1|)) (-15 -2986 ((-3 |t#1| "failed") |t#1|)) (-15 -3302 ((-3 |t#1| "failed") |t#1|)) (-15 -1935 ((-3 |t#1| "failed") |t#1|)) (-15 -2748 ((-3 |t#1| "failed") |t#1|)) (-15 -4460 ((-3 |t#1| "failed") |t#1|)) (-15 -2887 ((-3 |t#1| "failed") |t#1|)) (-15 -2323 ((-3 |t#1| "failed") |t#1|)) (-15 -3983 ((-3 |t#1| "failed") |t#1|)) (-15 -2234 ((-3 |t#1| "failed") |t#1|)) (-15 -3096 ((-3 |t#1| "failed") |t#1|)) (-15 -4163 ((-3 |t#1| "failed") |t#1|)) (-15 -3402 ((-3 |t#1| "failed") |t#1|)) (-15 -4359 ((-3 |t#1| "failed") |t#1|)) (-15 -1580 ((-3 |t#1| "failed") |t#1|)) (-15 -1400 ((-3 |t#1| "failed") |t#1|)) (-15 -2857 ((-3 |t#1| "failed") |t#1|)) (-15 -2811 ((-3 |t#1| "failed") |t#1|)) (-15 -1326 ((-3 |t#1| "failed") |t#1|)) (-15 -3834 ((-3 |t#1| "failed") |t#1|)) (-15 -4551 ((-3 |t#1| "failed") |t#1|)) (-15 -1292 ((-3 |t#1| "failed") |t#1|)) (-15 -4338 ((-3 |t#1| "failed") |t#1|)) (-15 -4167 ((-3 |t#1| "failed") |t#1|)) (-15 -3739 ((-3 |t#1| "failed") |t#1|)) (-15 -3418 ((-3 |t#1| "failed") |t#1|)))) 
-((-2164 ((|#4| |#4| (-638 |#3|)) 55) ((|#4| |#4| |#3|) 54)) (-4385 ((|#4| |#4| (-638 |#3|)) 23) ((|#4| |#4| |#3|) 19)) (-3828 ((|#4| (-1 |#4| (-959 |#1|)) |#4|) 30))) 
-(((-992 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4385 (|#4| |#4| |#3|)) (-15 -4385 (|#4| |#4| (-638 |#3|))) (-15 -2164 (|#4| |#4| |#3|)) (-15 -2164 (|#4| |#4| (-638 |#3|))) (-15 -3828 (|#4| (-1 |#4| (-959 |#1|)) |#4|))) (-1054) (-794) (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170))))) (-956 (-959 |#1|) |#2| |#3|)) (T -992)) 
-((-3828 (*1 *2 *3 *2) (-12 (-5 *3 (-1 *2 (-959 *4))) (-4 *4 (-1054)) (-4 *2 (-956 (-959 *4) *5 *6)) (-4 *5 (-794)) (-4 *6 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-5 *1 (-992 *4 *5 *6 *2)))) (-2164 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-4 *4 (-1054)) (-4 *5 (-794)) (-5 *1 (-992 *4 *5 *6 *2)) (-4 *2 (-956 (-959 *4) *5 *6)))) (-2164 (*1 *2 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-5 *1 (-992 *4 *5 *3 *2)) (-4 *2 (-956 (-959 *4) *5 *3)))) (-4385 (*1 *2 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-4 *4 (-1054)) (-4 *5 (-794)) (-5 *1 (-992 *4 *5 *6 *2)) (-4 *2 (-956 (-959 *4) *5 *6)))) (-4385 (*1 *2 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-5 *1 (-992 *4 *5 *3 *2)) (-4 *2 (-956 (-959 *4) *5 *3))))) 
-(-10 -7 (-15 -4385 (|#4| |#4| |#3|)) (-15 -4385 (|#4| |#4| (-638 |#3|))) (-15 -2164 (|#4| |#4| |#3|)) (-15 -2164 (|#4| |#4| (-638 |#3|))) (-15 -3828 (|#4| (-1 |#4| (-959 |#1|)) |#4|))) 
-((-3914 ((|#2| |#3|) 34)) (-4122 (((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) |#2|) 71)) (-1778 (((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|)))) 86))) 
-(((-993 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1778 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))))) (-15 -4122 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) |#2|)) (-15 -3914 (|#2| |#3|))) (-353) (-1234 |#1|) (-1234 |#2|) (-720 |#2| |#3|)) (T -993)) 
-((-3914 (*1 *2 *3) (-12 (-4 *3 (-1234 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-993 *4 *2 *3 *5)) (-4 *4 (-353)) (-4 *5 (-720 *2 *3)))) (-4122 (*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-993 *4 *3 *5 *6)) (-4 *6 (-720 *3 *5)))) (-1778 (*1 *2) (-12 (-4 *3 (-353)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -2237 (-685 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-685 *4)))) (-5 *1 (-993 *3 *4 *5 *6)) (-4 *6 (-720 *4 *5))))) 
-(-10 -7 (-15 -1778 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))))) (-15 -4122 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) |#2|)) (-15 -3914 (|#2| |#3|))) 
-((-2915 (((-995 (-413 (-572)) (-858 |#1|) (-234 |#2| (-769)) (-244 |#1| (-413 (-572)))) (-995 (-413 (-572)) (-858 |#1|) (-234 |#2| (-769)) (-244 |#1| (-413 (-572))))) 64))) 
-(((-994 |#1| |#2|) (-10 -7 (-15 -2915 ((-995 (-413 (-572)) (-858 |#1|) (-234 |#2| (-769)) (-244 |#1| (-413 (-572)))) (-995 (-413 (-572)) (-858 |#1|) (-234 |#2| (-769)) (-244 |#1| (-413 (-572))))))) (-638 (-1170)) (-769)) (T -994)) 
-((-2915 (*1 *2 *2) (-12 (-5 *2 (-995 (-413 (-572)) (-858 *3) (-234 *4 (-769)) (-244 *3 (-413 (-572))))) (-14 *3 (-638 (-1170))) (-14 *4 (-769)) (-5 *1 (-994 *3 *4))))) 
-(-10 -7 (-15 -2915 ((-995 (-413 (-572)) (-858 |#1|) (-234 |#2| (-769)) (-244 |#1| (-413 (-572)))) (-995 (-413 (-572)) (-858 |#1|) (-234 |#2| (-769)) (-244 |#1| (-413 (-572))))))) 
-((-2262 (((-121) $ $) NIL)) (-1541 (((-3 (-121) "failed") $) 67)) (-3925 (($ $) 35 (-12 (|has| |#1| (-151)) (|has| |#1| (-303))))) (-1374 (($ $ (-3 (-121) "failed")) 68)) (-4100 (($ (-638 |#4|) |#4|) 24)) (-1658 (((-1152) $) NIL)) (-2922 (($ $) 65)) (-2607 (((-1116) $) NIL)) (-4037 (((-121) $) 66)) (-1665 (($) 29)) (-3894 ((|#4| $) 70)) (-1971 (((-638 |#4|) $) 69)) (-3972 (((-856) $) 64)) (-1324 (((-121) $ $) NIL))) 
-(((-995 |#1| |#2| |#3| |#4|) (-13 (-1098) (-612 (-856)) (-10 -8 (-15 -1665 ($)) (-15 -4100 ($ (-638 |#4|) |#4|)) (-15 -1541 ((-3 (-121) "failed") $)) (-15 -1374 ($ $ (-3 (-121) "failed"))) (-15 -4037 ((-121) $)) (-15 -1971 ((-638 |#4|) $)) (-15 -3894 (|#4| $)) (-15 -2922 ($ $)) (IF (|has| |#1| (-303)) (IF (|has| |#1| (-151)) (-15 -3925 ($ $)) |noBranch|) |noBranch|))) (-457) (-848) (-794) (-956 |#1| |#3| |#2|)) (T -995)) 
-((-1665 (*1 *1) (-12 (-4 *2 (-457)) (-4 *3 (-848)) (-4 *4 (-794)) (-5 *1 (-995 *2 *3 *4 *5)) (-4 *5 (-956 *2 *4 *3)))) (-4100 (*1 *1 *2 *3) (-12 (-5 *2 (-638 *3)) (-4 *3 (-956 *4 *6 *5)) (-4 *4 (-457)) (-4 *5 (-848)) (-4 *6 (-794)) (-5 *1 (-995 *4 *5 *6 *3)))) (-1541 (*1 *2 *1) (|partial| -12 (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)) (-5 *2 (-121)) (-5 *1 (-995 *3 *4 *5 *6)) (-4 *6 (-956 *3 *5 *4)))) (-1374 (*1 *1 *1 *2) (-12 (-5 *2 (-3 (-121) "failed")) (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)) (-5 *1 (-995 *3 *4 *5 *6)) (-4 *6 (-956 *3 *5 *4)))) (-4037 (*1 *2 *1) (-12 (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)) (-5 *2 (-121)) (-5 *1 (-995 *3 *4 *5 *6)) (-4 *6 (-956 *3 *5 *4)))) (-1971 (*1 *2 *1) (-12 (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)) (-5 *2 (-638 *6)) (-5 *1 (-995 *3 *4 *5 *6)) (-4 *6 (-956 *3 *5 *4)))) (-3894 (*1 *2 *1) (-12 (-4 *2 (-956 *3 *5 *4)) (-5 *1 (-995 *3 *4 *5 *2)) (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)))) (-2922 (*1 *1 *1) (-12 (-4 *2 (-457)) (-4 *3 (-848)) (-4 *4 (-794)) (-5 *1 (-995 *2 *3 *4 *5)) (-4 *5 (-956 *2 *4 *3)))) (-3925 (*1 *1 *1) (-12 (-4 *2 (-151)) (-4 *2 (-303)) (-4 *2 (-457)) (-4 *3 (-848)) (-4 *4 (-794)) (-5 *1 (-995 *2 *3 *4 *5)) (-4 *5 (-956 *2 *4 *3))))) 
-(-13 (-1098) (-612 (-856)) (-10 -8 (-15 -1665 ($)) (-15 -4100 ($ (-638 |#4|) |#4|)) (-15 -1541 ((-3 (-121) "failed") $)) (-15 -1374 ($ $ (-3 (-121) "failed"))) (-15 -4037 ((-121) $)) (-15 -1971 ((-638 |#4|) $)) (-15 -3894 (|#4| $)) (-15 -2922 ($ $)) (IF (|has| |#1| (-303)) (IF (|has| |#1| (-151)) (-15 -3925 ($ $)) |noBranch|) |noBranch|))) 
-((-1382 (((-121) |#5| |#5|) 37)) (-2204 (((-121) |#5| |#5|) 51)) (-1776 (((-121) |#5| (-638 |#5|)) 73) (((-121) |#5| |#5|) 60)) (-1611 (((-121) (-638 |#4|) (-638 |#4|)) 57)) (-2331 (((-121) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) 62)) (-2344 (((-1264)) 33)) (-1735 (((-1264) (-1152) (-1152) (-1152)) 29)) (-2219 (((-638 |#5|) (-638 |#5|)) 80)) (-4552 (((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) 78)) (-3474 (((-638 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|)))) (-638 |#4|) (-638 |#5|) (-121) (-121)) 100)) (-2927 (((-121) |#5| |#5|) 46)) (-4024 (((-3 (-121) "failed") |#5| |#5|) 70)) (-2825 (((-121) (-638 |#4|) (-638 |#4|)) 56)) (-3999 (((-121) (-638 |#4|) (-638 |#4|)) 58)) (-1843 (((-121) (-638 |#4|) (-638 |#4|)) 59)) (-1589 (((-3 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|))) "failed") (-638 |#4|) |#5| (-638 |#4|) (-121) (-121) (-121) (-121) (-121)) 96)) (-2300 (((-638 |#5|) (-638 |#5|)) 42))) 
-(((-996 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1735 ((-1264) (-1152) (-1152) (-1152))) (-15 -2344 ((-1264))) (-15 -1382 ((-121) |#5| |#5|)) (-15 -2300 ((-638 |#5|) (-638 |#5|))) (-15 -2927 ((-121) |#5| |#5|)) (-15 -2204 ((-121) |#5| |#5|)) (-15 -1611 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -2825 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -3999 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -1843 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -4024 ((-3 (-121) "failed") |#5| |#5|)) (-15 -1776 ((-121) |#5| |#5|)) (-15 -1776 ((-121) |#5| (-638 |#5|))) (-15 -2219 ((-638 |#5|) (-638 |#5|))) (-15 -2331 ((-121) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) (-15 -4552 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-15 -3474 ((-638 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|)))) (-638 |#4|) (-638 |#5|) (-121) (-121))) (-15 -1589 ((-3 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|))) "failed") (-638 |#4|) |#5| (-638 |#4|) (-121) (-121) (-121) (-121) (-121)))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1073 |#1| |#2| |#3| |#4|)) (T -996)) 
-((-1589 (*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| -2352 (-638 *9)) (|:| -1337 *4) (|:| |ineq| (-638 *9)))) (-5 *1 (-996 *6 *7 *8 *9 *4)) (-5 *3 (-638 *9)) (-4 *4 (-1073 *6 *7 *8 *9)))) (-3474 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-638 *10)) (-5 *5 (-121)) (-4 *10 (-1073 *6 *7 *8 *9)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-1068 *6 *7 *8)) (-5 *2 (-638 (-2 (|:| -2352 (-638 *9)) (|:| -1337 *10) (|:| |ineq| (-638 *9))))) (-5 *1 (-996 *6 *7 *8 *9 *10)) (-5 *3 (-638 *9)))) (-4552 (*1 *2 *2) (-12 (-5 *2 (-638 (-2 (|:| |val| (-638 *6)) (|:| -1337 *7)))) (-4 *6 (-1068 *3 *4 *5)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-996 *3 *4 *5 *6 *7)))) (-2331 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-638 *7)) (|:| -1337 *8))) (-4 *7 (-1068 *4 *5 *6)) (-4 *8 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)))) (-2219 (*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-996 *3 *4 *5 *6 *7)))) (-1776 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-996 *5 *6 *7 *8 *3)))) (-1776 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-4024 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-1843 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-3999 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-2825 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-1611 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-2204 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-2927 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-2300 (*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-996 *3 *4 *5 *6 *7)))) (-1382 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-2344 (*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-996 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) (-1735 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -1735 ((-1264) (-1152) (-1152) (-1152))) (-15 -2344 ((-1264))) (-15 -1382 ((-121) |#5| |#5|)) (-15 -2300 ((-638 |#5|) (-638 |#5|))) (-15 -2927 ((-121) |#5| |#5|)) (-15 -2204 ((-121) |#5| |#5|)) (-15 -1611 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -2825 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -3999 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -1843 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -4024 ((-3 (-121) "failed") |#5| |#5|)) (-15 -1776 ((-121) |#5| |#5|)) (-15 -1776 ((-121) |#5| (-638 |#5|))) (-15 -2219 ((-638 |#5|) (-638 |#5|))) (-15 -2331 ((-121) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) (-15 -4552 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-15 -3474 ((-638 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|)))) (-638 |#4|) (-638 |#5|) (-121) (-121))) (-15 -1589 ((-3 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|))) "failed") (-638 |#4|) |#5| (-638 |#4|) (-121) (-121) (-121) (-121) (-121)))) 
-((-3342 (((-1170) $) 15)) (-2148 (((-1152) $) 16)) (-3821 (($ (-1170) (-1152)) 14)) (-3972 (((-856) $) 13))) 
-(((-997) (-13 (-612 (-856)) (-10 -8 (-15 -3821 ($ (-1170) (-1152))) (-15 -3342 ((-1170) $)) (-15 -2148 ((-1152) $))))) (T -997)) 
-((-3821 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1152)) (-5 *1 (-997)))) (-3342 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-997)))) (-2148 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-997))))) 
-(-13 (-612 (-856)) (-10 -8 (-15 -3821 ($ (-1170) (-1152))) (-15 -3342 ((-1170) $)) (-15 -2148 ((-1152) $)))) 
-((-3828 ((|#4| (-1 |#2| |#1|) |#3|) 14))) 
-(((-998 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#4| (-1 |#2| |#1|) |#3|))) (-562) (-562) (-1000 |#1|) (-1000 |#2|)) (T -998)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-562)) (-4 *6 (-562)) (-4 *2 (-1000 *6)) (-5 *1 (-998 *5 *6 *4 *2)) (-4 *4 (-1000 *5))))) 
-(-10 -7 (-15 -3828 (|#4| (-1 |#2| |#1|) |#3|))) 
-((-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-1170) "failed") $) 65) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 (-572) "failed") $) 95)) (-1318 ((|#2| $) NIL) (((-1170) $) 60) (((-413 (-572)) $) NIL) (((-572) $) 92)) (-2284 (((-685 (-572)) (-685 $)) NIL) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) 112) (((-685 |#2|) (-685 $)) 28)) (-3286 (($) 98)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 74) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 83)) (-4347 (($ $) 10)) (-3961 (((-3 $ "failed") $) 20)) (-3828 (($ (-1 |#2| |#2|) $) 22)) (-1773 (($) 16)) (-3346 (($ $) 54)) (-3139 (($ $) NIL) (($ $ (-769)) NIL) (($ $ (-1170)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) 36)) (-3425 (($ $) 12)) (-4081 (((-893 (-572)) $) 69) (((-893 (-385)) $) 78) (((-545) $) 40) (((-385) $) 44) (((-217) $) 47)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) 90) (($ |#2|) NIL) (($ (-1170)) 57)) (-2140 (((-769)) 31)) (-1334 (((-121) $ $) 50))) 
-(((-999 |#1| |#2|) (-10 -8 (-15 -1334 ((-121) |#1| |#1|)) (-15 -1773 (|#1|)) (-15 -3961 ((-3 |#1| "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4081 ((-217) |#1|)) (-15 -4081 ((-385) |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -1318 ((-1170) |#1|)) (-15 -3376 ((-3 (-1170) "failed") |#1|)) (-15 -3972 (|#1| (-1170))) (-15 -3286 (|#1|)) (-15 -3346 (|#1| |#1|)) (-15 -3425 (|#1| |#1|)) (-15 -4347 (|#1| |#1|)) (-15 -3103 ((-890 (-385) |#1|) |#1| (-893 (-385)) (-890 (-385) |#1|))) (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|))) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -2284 ((-685 |#2|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| |#1|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 -3972 ((-856) |#1|))) (-1000 |#2|) (-562)) (T -999)) 
-((-2140 (*1 *2) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-999 *3 *4)) (-4 *3 (-1000 *4))))) 
-(-10 -8 (-15 -1334 ((-121) |#1| |#1|)) (-15 -1773 (|#1|)) (-15 -3961 ((-3 |#1| "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4081 ((-217) |#1|)) (-15 -4081 ((-385) |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -1318 ((-1170) |#1|)) (-15 -3376 ((-3 (-1170) "failed") |#1|)) (-15 -3972 (|#1| (-1170))) (-15 -3286 (|#1|)) (-15 -3346 (|#1| |#1|)) (-15 -3425 (|#1| |#1|)) (-15 -4347 (|#1| |#1|)) (-15 -3103 ((-890 (-385) |#1|) |#1| (-893 (-385)) (-890 (-385) |#1|))) (-15 -3103 ((-890 (-572) |#1|) |#1| (-893 (-572)) (-890 (-572) |#1|))) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -2284 ((-685 |#2|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| |#1|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2551 ((|#1| $) 135 (|has| |#1| (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-4073 (((-424 (-1166 $)) (-1166 $)) 126 (|has| |#1| (-910)))) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 129 (|has| |#1| (-910)))) (-3112 (((-121) $ $) 57)) (-2433 (((-572) $) 116 (|has| |#1| (-821)))) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 174) (((-3 (-1170) "failed") $) 124 (|has| |#1| (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) 108 (|has| |#1| (-1044 (-572)))) (((-3 (-572) "failed") $) 106 (|has| |#1| (-1044 (-572))))) (-1318 ((|#1| $) 173) (((-1170) $) 123 (|has| |#1| (-1044 (-1170)))) (((-413 (-572)) $) 107 (|has| |#1| (-1044 (-572)))) (((-572) $) 105 (|has| |#1| (-1044 (-572))))) (-2190 (($ $ $) 53)) (-2284 (((-685 (-572)) (-685 $)) 148 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 147 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 146) (((-685 |#1|) (-685 $)) 145)) (-1799 (((-3 $ "failed") $) 33)) (-3286 (($) 133 (|has| |#1| (-554)))) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-1526 (((-121) $) 69)) (-1908 (((-121) $) 118 (|has| |#1| (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 142 (|has| |#1| (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 141 (|has| |#1| (-887 (-385))))) (-3893 (((-121) $) 30)) (-4347 (($ $) 137)) (-4487 ((|#1| $) 139)) (-3961 (((-3 $ "failed") $) 104 (|has| |#1| (-1144)))) (-4472 (((-121) $) 117 (|has| |#1| (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-1771 (($ $ $) 114 (|has| |#1| (-848)))) (-4238 (($ $ $) 113 (|has| |#1| (-848)))) (-3828 (($ (-1 |#1| |#1|) $) 165)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-1773 (($) 103 (|has| |#1| (-1144)) CONST)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-3346 (($ $) 134 (|has| |#1| (-303)))) (-1716 ((|#1| $) 131 (|has| |#1| (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) 128 (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) 127 (|has| |#1| (-910)))) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) 171 (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) 170 (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) 169 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) 168 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) 167 (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) 166 (|has| |#1| (-527 (-1170) |#1|)))) (-4029 (((-769) $) 56)) (-3277 (($ $ |#1|) 172 (|has| |#1| (-283 |#1| |#1|)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3139 (($ $) 164 (|has| |#1| (-227))) (($ $ (-769)) 162 (|has| |#1| (-227))) (($ $ (-1170)) 160 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 159 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 158 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) 157 (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) 150) (($ $ (-1 |#1| |#1|)) 149)) (-3425 (($ $) 136)) (-4492 ((|#1| $) 138)) (-4081 (((-893 (-572)) $) 144 (|has| |#1| (-613 (-893 (-572))))) (((-893 (-385)) $) 143 (|has| |#1| (-613 (-893 (-385))))) (((-545) $) 121 (|has| |#1| (-613 (-545)))) (((-385) $) 120 (|has| |#1| (-1028))) (((-217) $) 119 (|has| |#1| (-1028)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 130 (-4028 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ |#1|) 177) (($ (-1170)) 125 (|has| |#1| (-1044 (-1170))))) (-2779 (((-3 $ "failed") $) 122 (-1841 (|has| |#1| (-149)) (-4028 (|has| $ (-149)) (|has| |#1| (-910)))))) (-2140 (((-769)) 28)) (-2634 ((|#1| $) 132 (|has| |#1| (-554)))) (-3774 (((-121) $ $) 38)) (-2264 (($ $) 115 (|has| |#1| (-821)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $) 163 (|has| |#1| (-227))) (($ $ (-769)) 161 (|has| |#1| (-227))) (($ $ (-1170)) 156 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 155 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 154 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) 153 (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) 152) (($ $ (-1 |#1| |#1|)) 151)) (-1349 (((-121) $ $) 111 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 110 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 112 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 109 (|has| |#1| (-848)))) (-1379 (($ $ $) 62) (($ |#1| |#1|) 140)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64) (($ |#1| $) 176) (($ $ |#1|) 175))) 
-(((-1000 |#1|) (-1290) (-562)) (T -1000)) 
-((-1379 (*1 *1 *2 *2) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)))) (-4487 (*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)))) (-4492 (*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)))) (-4347 (*1 *1 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)))) (-3425 (*1 *1 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)))) (-2551 (*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)) (-4 *2 (-303)))) (-3346 (*1 *1 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)) (-4 *2 (-303)))) (-3286 (*1 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-554)) (-4 *2 (-562)))) (-2634 (*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)) (-4 *2 (-554)))) (-1716 (*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)) (-4 *2 (-554))))) 
-(-13 (-368) (-43 |t#1|) (-1044 |t#1|) (-338 |t#1|) (-225 |t#1|) (-383 |t#1|) (-885 |t#1|) (-406 |t#1|) (-10 -8 (-15 -1379 ($ |t#1| |t#1|)) (-15 -4487 (|t#1| $)) (-15 -4492 (|t#1| $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (IF (|has| |t#1| (-1144)) (-6 (-1144)) |noBranch|) (IF (|has| |t#1| (-1044 (-572))) (PROGN (-6 (-1044 (-572))) (-6 (-1044 (-413 (-572))))) |noBranch|) (IF (|has| |t#1| (-848)) (-6 (-848)) |noBranch|) (IF (|has| |t#1| (-821)) (-6 (-821)) |noBranch|) (IF (|has| |t#1| (-1028)) (-6 (-1028)) |noBranch|) (IF (|has| |t#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (IF (|has| |t#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |t#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |t#1| (-1044 (-1170))) (-6 (-1044 (-1170))) |noBranch|) (IF (|has| |t#1| (-303)) (PROGN (-15 -2551 (|t#1| $)) (-15 -3346 ($ $))) |noBranch|) (IF (|has| |t#1| (-554)) (PROGN (-15 -3286 ($)) (-15 -2634 (|t#1| $)) (-15 -1716 (|t#1| $))) |noBranch|) (IF (|has| |t#1| (-910)) (-6 (-910)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 |#1|) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) . T) ((-613 (-217)) |has| |#1| (-1028)) ((-613 (-385)) |has| |#1| (-1028)) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-613 (-893 (-385))) |has| |#1| (-613 (-893 (-385)))) ((-613 (-893 (-572))) |has| |#1| (-613 (-893 (-572)))) ((-225 |#1|) . T) ((-227) |has| |#1| (-227)) ((-240) . T) ((-283 |#1| $) |has| |#1| (-283 |#1| |#1|)) ((-287) . T) ((-303) . T) ((-305 |#1|) |has| |#1| (-305 |#1|)) ((-368) . T) ((-338 |#1|) . T) ((-383 |#1|) . T) ((-406 |#1|) . T) ((-457) . T) ((-527 (-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((-527 |#1| |#1|) |has| |#1| (-305 |#1|)) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-713 (-413 (-572))) . T) ((-713 |#1|) . T) ((-713 $) . T) ((-722) . T) ((-792) |has| |#1| (-821)) ((-793) |has| |#1| (-821)) ((-795) |has| |#1| (-821)) ((-796) |has| |#1| (-821)) ((-821) |has| |#1| (-821)) ((-846) |has| |#1| (-821)) ((-848) -1841 (|has| |#1| (-848)) (|has| |#1| (-821))) ((-901 (-1170)) |has| |#1| (-901 (-1170))) ((-887 (-385)) |has| |#1| (-887 (-385))) ((-887 (-572)) |has| |#1| (-887 (-572))) ((-885 |#1|) . T) ((-910) |has| |#1| (-910)) ((-922) . T) ((-1028) |has| |#1| (-1028)) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-572))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 (-1170)) |has| |#1| (-1044 (-1170))) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) . T) ((-1060 |#1|) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) |has| |#1| (-1144)) ((-1204) . T) ((-1214) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3504 (($ (-1135 |#1| |#2|)) 11)) (-3597 (((-1135 |#1| |#2|) $) 12)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3277 ((|#2| $ (-234 |#1| |#2|)) 16)) (-3972 (((-856) $) NIL)) (-2378 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL))) 
-(((-1001 |#1| |#2|) (-13 (-21) (-10 -8 (-15 -3504 ($ (-1135 |#1| |#2|))) (-15 -3597 ((-1135 |#1| |#2|) $)) (-15 -3277 (|#2| $ (-234 |#1| |#2|))))) (-923) (-368)) (T -1001)) 
-((-3504 (*1 *1 *2) (-12 (-5 *2 (-1135 *3 *4)) (-14 *3 (-923)) (-4 *4 (-368)) (-5 *1 (-1001 *3 *4)))) (-3597 (*1 *2 *1) (-12 (-5 *2 (-1135 *3 *4)) (-5 *1 (-1001 *3 *4)) (-14 *3 (-923)) (-4 *4 (-368)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 (-234 *4 *2)) (-14 *4 (-923)) (-4 *2 (-368)) (-5 *1 (-1001 *4 *2))))) 
-(-13 (-21) (-10 -8 (-15 -3504 ($ (-1135 |#1| |#2|))) (-15 -3597 ((-1135 |#1| |#2|) $)) (-15 -3277 (|#2| $ (-234 |#1| |#2|))))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) 8)) (-2211 (($) 7 T CONST)) (-4080 (($ $) 43)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-3200 (((-769) $) 42)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2011 ((|#1| $) 41)) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-2933 ((|#1| |#1| $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-4494 ((|#1| $) 44)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 39)) (-3782 ((|#1| $) 40)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1002 |#1|) (-1290) (-1204)) (T -1002)) 
-((-2933 (*1 *2 *2 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) (-4494 (*1 *2 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) (-4080 (*1 *1 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) (-3200 (*1 *2 *1) (-12 (-4 *1 (-1002 *3)) (-4 *3 (-1204)) (-5 *2 (-769)))) (-2011 (*1 *2 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) (-3782 (*1 *2 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204))))) 
-(-13 (-111 |t#1|) (-10 -8 (-6 -4602) (-15 -2933 (|t#1| |t#1| $)) (-15 -4494 (|t#1| $)) (-15 -4080 ($ $)) (-15 -3200 ((-769) $)) (-15 -2011 (|t#1| $)) (-15 -3782 (|t#1| $)))) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-1342 (((-121) $) 42)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 |#2| "failed") $) 45)) (-1318 (((-572) $) NIL) (((-413 (-572)) $) NIL) ((|#2| $) 43)) (-2956 (((-3 (-413 (-572)) "failed") $) 78)) (-3175 (((-121) $) 72)) (-4299 (((-413 (-572)) $) 76)) (-3893 (((-121) $) 41)) (-4429 ((|#2| $) 22)) (-3828 (($ (-1 |#2| |#2|) $) 19)) (-4350 (($ $) 61)) (-3139 (($ $) NIL) (($ $ (-769)) NIL) (($ $ (-1170)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) 34)) (-4081 (((-545) $) 67)) (-3018 (($ $) 17)) (-3972 (((-856) $) 56) (($ (-572)) 38) (($ |#2|) 36) (($ (-413 (-572))) NIL)) (-2140 (((-769)) 10)) (-2264 ((|#2| $) 71)) (-1324 (((-121) $ $) 25)) (-1334 (((-121) $ $) 69)) (-1373 (($ $) 29) (($ $ $) 28)) (-1367 (($ $ $) 26)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 33) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 30) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL))) 
-(((-1003 |#1| |#2|) (-10 -8 (-15 -3972 (|#1| (-413 (-572)))) (-15 -1334 ((-121) |#1| |#1|)) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 * (|#1| |#1| (-413 (-572)))) (-15 -4350 (|#1| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -2264 (|#2| |#1|)) (-15 -4429 (|#2| |#1|)) (-15 -3018 (|#1| |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3972 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 -3893 ((-121) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 -1342 ((-121) |#1|)) (-15 * (|#1| (-923) |#1|)) (-15 -1367 (|#1| |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) (-1004 |#2|) (-174)) (T -1003)) 
-((-2140 (*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-769)) (-5 *1 (-1003 *3 *4)) (-4 *3 (-1004 *4))))) 
-(-10 -8 (-15 -3972 (|#1| (-413 (-572)))) (-15 -1334 ((-121) |#1| |#1|)) (-15 * (|#1| (-413 (-572)) |#1|)) (-15 * (|#1| |#1| (-413 (-572)))) (-15 -4350 (|#1| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -2264 (|#2| |#1|)) (-15 -4429 (|#2| |#1|)) (-15 -3018 (|#1| |#1|)) (-15 -3828 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3972 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 -3893 ((-121) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 * (|#1| (-769) |#1|)) (-15 -1342 ((-121) |#1|)) (-15 * (|#1| (-923) |#1|)) (-15 -1367 (|#1| |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-3376 (((-3 (-572) "failed") $) 117 (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 115 (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) 114)) (-1318 (((-572) $) 118 (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) 116 (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) 113)) (-2284 (((-685 (-572)) (-685 $)) 88 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 87 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 86) (((-685 |#1|) (-685 $)) 85)) (-1799 (((-3 $ "failed") $) 33)) (-3359 ((|#1| $) 78)) (-2956 (((-3 (-413 (-572)) "failed") $) 74 (|has| |#1| (-554)))) (-3175 (((-121) $) 76 (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) 75 (|has| |#1| (-554)))) (-3491 (($ |#1| |#1| |#1| |#1|) 79)) (-3893 (((-121) $) 30)) (-4429 ((|#1| $) 80)) (-1771 (($ $ $) 66 (|has| |#1| (-848)))) (-4238 (($ $ $) 65 (|has| |#1| (-848)))) (-3828 (($ (-1 |#1| |#1|) $) 89)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 71 (|has| |#1| (-368)))) (-4425 ((|#1| $) 81)) (-4229 ((|#1| $) 82)) (-2789 ((|#1| $) 83)) (-2607 (((-1116) $) 10)) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) 95 (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) 94 (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) 93 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) 92 (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) 91 (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) 90 (|has| |#1| (-527 (-1170) |#1|)))) (-3277 (($ $ |#1|) 96 (|has| |#1| (-283 |#1| |#1|)))) (-3139 (($ $) 112 (|has| |#1| (-227))) (($ $ (-769)) 110 (|has| |#1| (-227))) (($ $ (-1170)) 108 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 107 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 106 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) 105 (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) 98) (($ $ (-1 |#1| |#1|)) 97)) (-4081 (((-545) $) 72 (|has| |#1| (-613 (-545))))) (-3018 (($ $) 84)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 36) (($ (-413 (-572))) 60 (-1841 (|has| |#1| (-368)) (|has| |#1| (-1044 (-413 (-572))))))) (-2779 (((-3 $ "failed") $) 73 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-2264 ((|#1| $) 77 (|has| |#1| (-1063)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 70 (|has| |#1| (-368)))) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $) 111 (|has| |#1| (-227))) (($ $ (-769)) 109 (|has| |#1| (-227))) (($ $ (-1170)) 104 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 103 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 102 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) 101 (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) 100) (($ $ (-1 |#1| |#1|)) 99)) (-1349 (((-121) $ $) 63 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 62 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 64 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 61 (|has| |#1| (-848)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 69 (|has| |#1| (-368)))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ $ (-413 (-572))) 68 (|has| |#1| (-368))) (($ (-413 (-572)) $) 67 (|has| |#1| (-368))))) 
-(((-1004 |#1|) (-1290) (-174)) (T -1004)) 
-((-3018 (*1 *1 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) (-2789 (*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) (-4229 (*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) (-4425 (*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) (-4429 (*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) (-3491 (*1 *1 *2 *2 *2 *2) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) (-3359 (*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) (-2264 (*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)) (-4 *2 (-1063)))) (-3175 (*1 *2 *1) (-12 (-4 *1 (-1004 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-121)))) (-4299 (*1 *2 *1) (-12 (-4 *1 (-1004 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) (-2956 (*1 *2 *1) (|partial| -12 (-4 *1 (-1004 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572)))))) 
-(-13 (-43 |t#1|) (-417 |t#1|) (-225 |t#1|) (-338 |t#1|) (-383 |t#1|) (-10 -8 (-15 -3018 ($ $)) (-15 -2789 (|t#1| $)) (-15 -4229 (|t#1| $)) (-15 -4425 (|t#1| $)) (-15 -4429 (|t#1| $)) (-15 -3491 ($ |t#1| |t#1| |t#1| |t#1|)) (-15 -3359 (|t#1| $)) (IF (|has| |t#1| (-287)) (-6 (-287)) |noBranch|) (IF (|has| |t#1| (-848)) (-6 (-848)) |noBranch|) (IF (|has| |t#1| (-368)) (-6 (-240)) |noBranch|) (IF (|has| |t#1| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (IF (|has| |t#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |t#1| (-149)) (-6 (-149)) |noBranch|) (IF (|has| |t#1| (-1063)) (-15 -2264 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-554)) (PROGN (-15 -3175 ((-121) $)) (-15 -4299 ((-413 (-572)) $)) (-15 -2956 ((-3 (-413 (-572)) "failed") $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-368)) ((-43 |#1|) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-368)) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-368)) (|has| |#1| (-287))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-225 |#1|) . T) ((-227) |has| |#1| (-227)) ((-240) |has| |#1| (-368)) ((-283 |#1| $) |has| |#1| (-283 |#1| |#1|)) ((-287) -1841 (|has| |#1| (-368)) (|has| |#1| (-287))) ((-305 |#1|) |has| |#1| (-305 |#1|)) ((-338 |#1|) . T) ((-383 |#1|) . T) ((-417 |#1|) . T) ((-527 (-1170) |#1|) |has| |#1| (-527 (-1170) |#1|)) ((-527 |#1| |#1|) |has| |#1| (-305 |#1|)) ((-641 (-413 (-572))) |has| |#1| (-368)) ((-641 |#1|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-713 (-413 (-572))) |has| |#1| (-368)) ((-713 |#1|) . T) ((-722) . T) ((-848) |has| |#1| (-848)) ((-901 (-1170)) |has| |#1| (-901 (-1170))) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) |has| |#1| (-368)) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-368)) (|has| |#1| (-287))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-3828 ((|#3| (-1 |#4| |#2|) |#1|) 16))) 
-(((-1005 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#3| (-1 |#4| |#2|) |#1|))) (-1004 |#2|) (-174) (-1004 |#4|) (-174)) (T -1005)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-174)) (-4 *6 (-174)) (-4 *2 (-1004 *6)) (-5 *1 (-1005 *4 *5 *2 *6)) (-4 *4 (-1004 *5))))) 
-(-10 -7 (-15 -3828 (|#3| (-1 |#4| |#2|) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3359 ((|#1| $) 12)) (-2956 (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-554)))) (-3175 (((-121) $) NIL (|has| |#1| (-554)))) (-4299 (((-413 (-572)) $) NIL (|has| |#1| (-554)))) (-3491 (($ |#1| |#1| |#1| |#1|) 16)) (-3893 (((-121) $) NIL)) (-4429 ((|#1| $) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-4425 ((|#1| $) 15)) (-4229 ((|#1| $) 14)) (-2789 ((|#1| $) 13)) (-2607 (((-1116) $) NIL)) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-305 |#1|))) (($ $ (-290 |#1|)) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-290 |#1|))) NIL (|has| |#1| (-305 |#1|))) (($ $ (-638 (-1170)) (-638 |#1|)) NIL (|has| |#1| (-527 (-1170) |#1|))) (($ $ (-1170) |#1|) NIL (|has| |#1| (-527 (-1170) |#1|)))) (-3277 (($ $ |#1|) NIL (|has| |#1| (-283 |#1| |#1|)))) (-3139 (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3018 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-368)) (|has| |#1| (-1044 (-413 (-572))))))) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-2264 ((|#1| $) NIL (|has| |#1| (-1063)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 8 T CONST)) (-3255 (($) 10 T CONST)) (-1557 (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 20) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-413 (-572))) NIL (|has| |#1| (-368))) (($ (-413 (-572)) $) NIL (|has| |#1| (-368))))) 
-(((-1006 |#1|) (-1004 |#1|) (-174)) (T -1006)) 
-NIL 
-(-1004 |#1|) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1946 (((-121) $ (-769)) NIL)) (-2211 (($) NIL T CONST)) (-4080 (($ $) 20)) (-3740 (($ (-638 |#1|)) 29)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-3200 (((-769) $) 22)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-4221 ((|#1| $) 24)) (-1335 (($ |#1| $) 15)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2011 ((|#1| $) 23)) (-2232 ((|#1| $) 19)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-2933 ((|#1| |#1| $) 14)) (-4037 (((-121) $) 17)) (-1665 (($) NIL)) (-4494 ((|#1| $) 18)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) NIL)) (-3782 ((|#1| $) 26)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1007 |#1|) (-13 (-1002 |#1|) (-10 -8 (-15 -3740 ($ (-638 |#1|))) (-15 -4494 (|#1| $)) (-15 -2232 (|#1| $)) (-15 -2933 (|#1| |#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -2011 (|#1| $)) (-15 -3782 (|#1| $)) (-15 -4080 ($ $)) (-15 -3200 ((-769) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -3058 ($ (-638 |#1|))) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -2211 ($)) (-15 -1607 ($ $)) (-15 -3598 ((-121) $ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) (-1098)) (T -1007)) 
-((-3598 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) (-1607 (*1 *1 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-1665 (*1 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-4037 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) (-3524 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1007 *4)) (-4 *4 (-1098)))) (-2157 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1007 *4)) (-4 *4 (-1098)))) (-1946 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1007 *4)) (-4 *4 (-1098)))) (-2211 (*1 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-4032 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-1007 *3)))) (-2435 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-1098)) (-5 *1 (-1007 *3)))) (-3501 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-1007 *4)))) (-2109 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-1007 *4)))) (-1571 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-1007 *4)))) (-2010 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) (-1571 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3002 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-1658 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-2607 (*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-1324 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-2262 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3058 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1007 *3)))) (-2232 (*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-1335 (*1 *1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-4221 (*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-2933 (*1 *2 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-4494 (*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-4080 (*1 *1 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-3200 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) (-2011 (*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-3782 (*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) (-3740 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1007 *3))))) 
-(-13 (-1002 |#1|) (-10 -8 (-15 -3740 ($ (-638 |#1|))) (-15 -4494 (|#1| $)) (-15 -2232 (|#1| $)) (-15 -2933 (|#1| |#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -2011 (|#1| $)) (-15 -3782 (|#1| $)) (-15 -4080 ($ $)) (-15 -3200 ((-769) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -3058 ($ (-638 |#1|))) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -2211 ($)) (-15 -1607 ($ $)) (-15 -3598 ((-121) $ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) 
-((-4190 (($ $) 12)) (-1451 (($ $ (-572)) 13))) 
-(((-1008 |#1|) (-10 -8 (-15 -4190 (|#1| |#1|)) (-15 -1451 (|#1| |#1| (-572)))) (-1009)) (T -1008)) 
-NIL 
-(-10 -8 (-15 -4190 (|#1| |#1|)) (-15 -1451 (|#1| |#1| (-572)))) 
-((-4190 (($ $) 6)) (-1451 (($ $ (-572)) 7)) (** (($ $ (-413 (-572))) 8))) 
-(((-1009) (-1290)) (T -1009)) 
-((** (*1 *1 *1 *2) (-12 (-4 *1 (-1009)) (-5 *2 (-413 (-572))))) (-1451 (*1 *1 *1 *2) (-12 (-4 *1 (-1009)) (-5 *2 (-572)))) (-4190 (*1 *1 *1) (-4 *1 (-1009)))) 
-(-13 (-10 -8 (-15 -4190 ($ $)) (-15 -1451 ($ $ (-572))) (-15 ** ($ $ (-413 (-572)))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3970 (((-2 (|:| |num| (-1259 |#2|)) (|:| |den| |#2|)) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| (-413 |#2|) (-368)))) (-3946 (($ $) NIL (|has| (-413 |#2|) (-368)))) (-3686 (((-121) $) NIL (|has| (-413 |#2|) (-368)))) (-1845 (((-685 (-413 |#2|)) (-1259 $)) NIL) (((-685 (-413 |#2|))) NIL)) (-3520 (((-413 |#2|) $) NIL)) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| (-413 |#2|) (-353)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| (-413 |#2|) (-368)))) (-1466 (((-424 $) $) NIL (|has| (-413 |#2|) (-368)))) (-3112 (((-121) $ $) NIL (|has| (-413 |#2|) (-368)))) (-1685 (((-769)) NIL (|has| (-413 |#2|) (-374)))) (-3182 (((-121)) NIL)) (-1688 (((-121) |#1|) 147) (((-121) |#2|) 152)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| (-413 |#2|) (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-413 |#2|) (-1044 (-413 (-572))))) (((-3 (-413 |#2|) "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| (-413 |#2|) (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| (-413 |#2|) (-1044 (-413 (-572))))) (((-413 |#2|) $) NIL)) (-4337 (($ (-1259 (-413 |#2|)) (-1259 $)) NIL) (($ (-1259 (-413 |#2|))) 70) (($ (-1259 |#2|) |#2|) NIL)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-413 |#2|) (-353)))) (-2190 (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-1741 (((-685 (-413 |#2|)) $ (-1259 $)) NIL) (((-685 (-413 |#2|)) $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-413 |#2|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-413 |#2|) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-413 |#2|))) (|:| |vec| (-1259 (-413 |#2|)))) (-685 $) (-1259 $)) NIL) (((-685 (-413 |#2|)) (-685 $)) NIL)) (-4442 (((-1259 $) (-1259 $)) NIL)) (-3116 (($ |#3|) 65) (((-3 $ "failed") (-413 |#3|)) NIL (|has| (-413 |#2|) (-368)))) (-1799 (((-3 $ "failed") $) NIL)) (-3356 (((-638 (-638 |#1|))) NIL (|has| |#1| (-374)))) (-2575 (((-121) |#1| |#1|) NIL)) (-2667 (((-923)) NIL)) (-3286 (($) NIL (|has| (-413 |#2|) (-374)))) (-1906 (((-121)) NIL)) (-1418 (((-121) |#1|) 56) (((-121) |#2|) 149)) (-2208 (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| (-413 |#2|) (-368)))) (-3988 (($ $) NIL)) (-2754 (($) NIL (|has| (-413 |#2|) (-353)))) (-1297 (((-121) $) NIL (|has| (-413 |#2|) (-353)))) (-4486 (($ $ (-769)) NIL (|has| (-413 |#2|) (-353))) (($ $) NIL (|has| (-413 |#2|) (-353)))) (-1526 (((-121) $) NIL (|has| (-413 |#2|) (-368)))) (-3377 (((-923) $) NIL (|has| (-413 |#2|) (-353))) (((-834 (-923)) $) NIL (|has| (-413 |#2|) (-353)))) (-3893 (((-121) $) NIL)) (-1602 (((-769)) NIL)) (-2077 (((-1259 $) (-1259 $)) NIL)) (-4429 (((-413 |#2|) $) NIL)) (-2380 (((-638 (-959 |#1|)) (-1170)) NIL (|has| |#1| (-368)))) (-3961 (((-3 $ "failed") $) NIL (|has| (-413 |#2|) (-353)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| (-413 |#2|) (-368)))) (-3251 ((|#3| $) NIL (|has| (-413 |#2|) (-368)))) (-3633 (((-923) $) NIL (|has| (-413 |#2|) (-374)))) (-3111 ((|#3| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| (-413 |#2|) (-368))) (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-1658 (((-1152) $) NIL)) (-3639 (((-685 (-413 |#2|))) 52)) (-4322 (((-685 (-413 |#2|))) 51)) (-4350 (($ $) NIL (|has| (-413 |#2|) (-368)))) (-2984 (($ (-1259 |#2|) |#2|) 71)) (-2488 (((-685 (-413 |#2|))) 50)) (-3378 (((-685 (-413 |#2|))) 49)) (-2457 (((-2 (|:| |num| (-685 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 86)) (-3697 (((-2 (|:| |num| (-1259 |#2|)) (|:| |den| |#2|)) $) 77)) (-4009 (((-1259 $)) 46)) (-1778 (((-1259 $)) 45)) (-4503 (((-121) $) NIL)) (-3829 (((-121) $) NIL) (((-121) $ |#1|) NIL) (((-121) $ |#2|) NIL)) (-1773 (($) NIL (|has| (-413 |#2|) (-353)) CONST)) (-1763 (($ (-923)) NIL (|has| (-413 |#2|) (-374)))) (-1380 (((-3 |#2| "failed")) 63)) (-2607 (((-1116) $) NIL)) (-1774 (((-769)) NIL)) (-2307 (($) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| (-413 |#2|) (-368)))) (-3069 (($ (-638 $)) NIL (|has| (-413 |#2|) (-368))) (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| (-413 |#2|) (-353)))) (-4304 (((-424 $) $) NIL (|has| (-413 |#2|) (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-413 |#2|) (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| (-413 |#2|) (-368)))) (-1803 (((-3 $ "failed") $ $) NIL (|has| (-413 |#2|) (-368)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| (-413 |#2|) (-368)))) (-4029 (((-769) $) NIL (|has| (-413 |#2|) (-368)))) (-3587 (((-638 $)) NIL (|has| (-413 |#2|) (-374)))) (-3277 ((|#1| $ |#1| |#1|) NIL)) (-2447 (((-3 |#2| "failed")) 62)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| (-413 |#2|) (-368)))) (-2119 (((-413 |#2|) (-1259 $)) NIL) (((-413 |#2|)) 42)) (-3158 (((-769) $) NIL (|has| (-413 |#2|) (-353))) (((-3 (-769) "failed") $ $) NIL (|has| (-413 |#2|) (-353)))) (-3139 (($ $ (-1 (-413 |#2|) (-413 |#2|)) (-769)) NIL (|has| (-413 |#2|) (-368))) (($ $ (-1 (-413 |#2|) (-413 |#2|))) NIL (|has| (-413 |#2|) (-368))) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-769)) NIL (-1841 (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353)))) (($ $) NIL (-1841 (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353))))) (-3482 (((-685 (-413 |#2|)) (-1259 $) (-1 (-413 |#2|) (-413 |#2|))) NIL (|has| (-413 |#2|) (-368)))) (-2830 ((|#3|) 53)) (-2278 (($) NIL (|has| (-413 |#2|) (-353)))) (-3160 (((-1259 (-413 |#2|)) $ (-1259 $)) NIL) (((-685 (-413 |#2|)) (-1259 $) (-1259 $)) NIL) (((-1259 (-413 |#2|)) $) 72) (((-685 (-413 |#2|)) (-1259 $)) NIL)) (-4081 (((-1259 (-413 |#2|)) $) NIL) (($ (-1259 (-413 |#2|))) NIL) ((|#3| $) NIL) (($ |#3|) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| (-413 |#2|) (-353)))) (-2139 (((-1259 $) (-1259 $)) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 |#2|)) NIL) (($ (-413 (-572))) NIL (-1841 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-1044 (-413 (-572)))))) (($ $) NIL (|has| (-413 |#2|) (-368)))) (-2779 (($ $) NIL (|has| (-413 |#2|) (-353))) (((-3 $ "failed") $) NIL (|has| (-413 |#2|) (-149)))) (-2707 ((|#3| $) NIL)) (-2140 (((-769)) NIL)) (-3640 (((-121)) 60)) (-1825 (((-121) |#1|) 153) (((-121) |#2|) 154)) (-2237 (((-1259 $)) 124)) (-3774 (((-121) $ $) NIL (|has| (-413 |#2|) (-368)))) (-3516 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) NIL)) (-3920 (((-121)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-413 |#2|) (-368)))) (-2378 (($) 94 T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-1 (-413 |#2|) (-413 |#2|)) (-769)) NIL (|has| (-413 |#2|) (-368))) (($ $ (-1 (-413 |#2|) (-413 |#2|))) NIL (|has| (-413 |#2|) (-368))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| (-413 |#2|) (-368)) (|has| (-413 |#2|) (-901 (-1170))))) (($ $ (-769)) NIL (-1841 (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353)))) (($ $) NIL (-1841 (-12 (|has| (-413 |#2|) (-227)) (|has| (-413 |#2|) (-368))) (|has| (-413 |#2|) (-353))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ $) NIL (|has| (-413 |#2|) (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-413 |#2|) (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 |#2|)) NIL) (($ (-413 |#2|) $) NIL) (($ (-413 (-572)) $) NIL (|has| (-413 |#2|) (-368))) (($ $ (-413 (-572))) NIL (|has| (-413 |#2|) (-368))))) 
-(((-1010 |#1| |#2| |#3| |#4| |#5|) (-342 |#1| |#2| |#3|) (-1214) (-1234 |#1|) (-1234 (-413 |#2|)) (-413 |#2|) (-769)) (T -1010)) 
-NIL 
-(-342 |#1| |#2| |#3|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3758 (((-638 (-572)) $) 54)) (-2178 (($ (-638 (-572))) 62)) (-2551 (((-572) $) 40 (|has| (-572) (-303)))) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL (|has| (-572) (-821)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) 49) (((-3 (-1170) "failed") $) NIL (|has| (-572) (-1044 (-1170)))) (((-3 (-413 (-572)) "failed") $) 47 (|has| (-572) (-1044 (-572)))) (((-3 (-572) "failed") $) 49 (|has| (-572) (-1044 (-572))))) (-1318 (((-572) $) NIL) (((-1170) $) NIL (|has| (-572) (-1044 (-1170)))) (((-413 (-572)) $) NIL (|has| (-572) (-1044 (-572)))) (((-572) $) NIL (|has| (-572) (-1044 (-572))))) (-2190 (($ $ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| (-572) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| (-572) (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-685 (-572)) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3286 (($) NIL (|has| (-572) (-554)))) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-2782 (((-638 (-572)) $) 60)) (-1908 (((-121) $) NIL (|has| (-572) (-821)))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (|has| (-572) (-887 (-572)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (|has| (-572) (-887 (-385))))) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL)) (-4487 (((-572) $) 37)) (-3961 (((-3 $ "failed") $) NIL (|has| (-572) (-1144)))) (-4472 (((-121) $) NIL (|has| (-572) (-821)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-572) (-848)))) (-3828 (($ (-1 (-572) (-572)) $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL)) (-1773 (($) NIL (|has| (-572) (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-3346 (($ $) NIL (|has| (-572) (-303))) (((-413 (-572)) $) 42)) (-2427 (((-1150 (-572)) $) 59)) (-1310 (($ (-638 (-572)) (-638 (-572))) 63)) (-1716 (((-572) $) 53 (|has| (-572) (-554)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| (-572) (-910)))) (-4304 (((-424 $) $) NIL)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4485 (($ $ (-638 (-572)) (-638 (-572))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-572) (-572)) NIL (|has| (-572) (-305 (-572)))) (($ $ (-290 (-572))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-638 (-290 (-572)))) NIL (|has| (-572) (-305 (-572)))) (($ $ (-638 (-1170)) (-638 (-572))) NIL (|has| (-572) (-527 (-1170) (-572)))) (($ $ (-1170) (-572)) NIL (|has| (-572) (-527 (-1170) (-572))))) (-4029 (((-769) $) NIL)) (-3277 (($ $ (-572)) NIL (|has| (-572) (-283 (-572) (-572))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $) 11 (|has| (-572) (-227))) (($ $ (-769)) NIL (|has| (-572) (-227))) (($ $ (-1170)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1 (-572) (-572)) (-769)) NIL) (($ $ (-1 (-572) (-572))) NIL)) (-3425 (($ $) NIL)) (-4492 (((-572) $) 39)) (-3891 (((-638 (-572)) $) 61)) (-4081 (((-893 (-572)) $) NIL (|has| (-572) (-613 (-893 (-572))))) (((-893 (-385)) $) NIL (|has| (-572) (-613 (-893 (-385))))) (((-545) $) NIL (|has| (-572) (-613 (-545)))) (((-385) $) NIL (|has| (-572) (-1028))) (((-217) $) NIL (|has| (-572) (-1028)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-572) (-910))))) (-3972 (((-856) $) 77) (($ (-572)) 43) (($ $) NIL) (($ (-413 (-572))) 19) (($ (-572)) 43) (($ (-1170)) NIL (|has| (-572) (-1044 (-1170)))) (((-413 (-572)) $) 17)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-572) (-910))) (|has| (-572) (-149))))) (-2140 (((-769)) 9)) (-2634 (((-572) $) 51 (|has| (-572) (-554)))) (-3774 (((-121) $ $) NIL)) (-2264 (($ $) NIL (|has| (-572) (-821)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 10 T CONST)) (-3255 (($) 12 T CONST)) (-1557 (($ $) NIL (|has| (-572) (-227))) (($ $ (-769)) NIL (|has| (-572) (-227))) (($ $ (-1170)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| (-572) (-901 (-1170)))) (($ $ (-1 (-572) (-572)) (-769)) NIL) (($ $ (-1 (-572) (-572))) NIL)) (-1349 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1324 (((-121) $ $) 14)) (-1343 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1334 (((-121) $ $) 33 (|has| (-572) (-848)))) (-1379 (($ $ $) 29) (($ (-572) (-572)) 31)) (-1373 (($ $) 15) (($ $ $) 22)) (-1367 (($ $ $) 20)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 25) (($ $ $) 27) (($ $ (-413 (-572))) NIL) (($ (-413 (-572)) $) NIL) (($ (-572) $) 25) (($ $ (-572)) NIL))) 
-(((-1011 |#1|) (-13 (-1000 (-572)) (-10 -8 (-15 -3972 ((-413 (-572)) $)) (-15 -3346 ((-413 (-572)) $)) (-15 -3758 ((-638 (-572)) $)) (-15 -2427 ((-1150 (-572)) $)) (-15 -2782 ((-638 (-572)) $)) (-15 -3891 ((-638 (-572)) $)) (-15 -2178 ($ (-638 (-572)))) (-15 -1310 ($ (-638 (-572)) (-638 (-572)))))) (-572)) (T -1011)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) (-3346 (*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) (-3758 (*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) (-2427 (*1 *2 *1) (-12 (-5 *2 (-1150 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) (-2782 (*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) (-3891 (*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) (-2178 (*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) (-1310 (*1 *1 *2 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572))))) 
-(-13 (-1000 (-572)) (-10 -8 (-15 -3972 ((-413 (-572)) $)) (-15 -3346 ((-413 (-572)) $)) (-15 -3758 ((-638 (-572)) $)) (-15 -2427 ((-1150 (-572)) $)) (-15 -2782 ((-638 (-572)) $)) (-15 -3891 ((-638 (-572)) $)) (-15 -2178 ($ (-638 (-572)))) (-15 -1310 ($ (-638 (-572)) (-638 (-572)))))) 
-((-2775 (((-57) (-413 (-572)) (-572)) 9))) 
-(((-1012) (-10 -7 (-15 -2775 ((-57) (-413 (-572)) (-572))))) (T -1012)) 
-((-2775 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-572))) (-5 *4 (-572)) (-5 *2 (-57)) (-5 *1 (-1012))))) 
-(-10 -7 (-15 -2775 ((-57) (-413 (-572)) (-572)))) 
-((-1685 (((-572)) 13)) (-1718 (((-572)) 16)) (-1704 (((-1264) (-572)) 15)) (-3312 (((-572) (-572)) 17) (((-572)) 12))) 
-(((-1013) (-10 -7 (-15 -3312 ((-572))) (-15 -1685 ((-572))) (-15 -3312 ((-572) (-572))) (-15 -1704 ((-1264) (-572))) (-15 -1718 ((-572))))) (T -1013)) 
-((-1718 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1013)))) (-1704 (*1 *2 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-1013)))) (-3312 (*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1013)))) (-1685 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1013)))) (-3312 (*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1013))))) 
-(-10 -7 (-15 -3312 ((-572))) (-15 -1685 ((-572))) (-15 -3312 ((-572) (-572))) (-15 -1704 ((-1264) (-572))) (-15 -1718 ((-572)))) 
-((-2602 (((-424 |#1|) |#1|) 40)) (-4304 (((-424 |#1|) |#1|) 39))) 
-(((-1014 |#1|) (-10 -7 (-15 -4304 ((-424 |#1|) |#1|)) (-15 -2602 ((-424 |#1|) |#1|))) (-1234 (-413 (-572)))) (T -1014)) 
-((-2602 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1014 *3)) (-4 *3 (-1234 (-413 (-572)))))) (-4304 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1014 *3)) (-4 *3 (-1234 (-413 (-572))))))) 
-(-10 -7 (-15 -4304 ((-424 |#1|) |#1|)) (-15 -2602 ((-424 |#1|) |#1|))) 
-((-2956 (((-3 (-413 (-572)) "failed") |#1|) 14)) (-3175 (((-121) |#1|) 13)) (-4299 (((-413 (-572)) |#1|) 9))) 
-(((-1015 |#1|) (-10 -7 (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|))) (-1044 (-413 (-572)))) (T -1015)) 
-((-2956 (*1 *2 *3) (|partial| -12 (-5 *2 (-413 (-572))) (-5 *1 (-1015 *3)) (-4 *3 (-1044 *2)))) (-3175 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1015 *3)) (-4 *3 (-1044 (-413 (-572)))))) (-4299 (*1 *2 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-1015 *3)) (-4 *3 (-1044 *2))))) 
-(-10 -7 (-15 -4299 ((-413 (-572)) |#1|)) (-15 -3175 ((-121) |#1|)) (-15 -2956 ((-3 (-413 (-572)) "failed") |#1|))) 
-((-3283 ((|#2| $ "value" |#2|) 12)) (-3277 ((|#2| $ "value") 10)) (-3432 (((-121) $ $) 18))) 
-(((-1016 |#1| |#2|) (-10 -8 (-15 -3283 (|#2| |#1| "value" |#2|)) (-15 -3432 ((-121) |#1| |#1|)) (-15 -3277 (|#2| |#1| "value"))) (-1017 |#2|) (-1204)) (T -1016)) 
-NIL 
-(-10 -8 (-15 -3283 (|#2| |#1| "value" |#2|)) (-15 -3432 ((-121) |#1| |#1|)) (-15 -3277 (|#2| |#1| "value"))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-2211 (($) 7 T CONST)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44)) (-3537 (((-572) $ $) 41)) (-1791 (((-121) $) 43)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1017 |#1|) (-1290) (-1204)) (T -1017)) 
-((-4118 (*1 *2 *1) (-12 (-4 *3 (-1204)) (-5 *2 (-638 *1)) (-4 *1 (-1017 *3)))) (-2202 (*1 *2 *1) (-12 (-4 *3 (-1204)) (-5 *2 (-638 *1)) (-4 *1 (-1017 *3)))) (-3113 (*1 *2 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-5 *2 (-121)))) (-2148 (*1 *2 *1) (-12 (-4 *1 (-1017 *2)) (-4 *2 (-1204)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 "value") (-4 *1 (-1017 *2)) (-4 *2 (-1204)))) (-1791 (*1 *2 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-5 *2 (-121)))) (-2699 (*1 *2 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-5 *2 (-638 *3)))) (-3537 (*1 *2 *1 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-5 *2 (-572)))) (-3432 (*1 *2 *1 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-121)))) (-1303 (*1 *2 *1 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-121)))) (-2155 (*1 *1 *1 *2) (-12 (-5 *2 (-638 *1)) (|has| *1 (-6 -4603)) (-4 *1 (-1017 *3)) (-4 *3 (-1204)))) (-3283 (*1 *2 *1 *3 *2) (-12 (-5 *3 "value") (|has| *1 (-6 -4603)) (-4 *1 (-1017 *2)) (-4 *2 (-1204)))) (-4436 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1017 *2)) (-4 *2 (-1204))))) 
-(-13 (-503 |t#1|) (-10 -8 (-15 -4118 ((-638 $) $)) (-15 -2202 ((-638 $) $)) (-15 -3113 ((-121) $)) (-15 -2148 (|t#1| $)) (-15 -3277 (|t#1| $ "value")) (-15 -1791 ((-121) $)) (-15 -2699 ((-638 |t#1|) $)) (-15 -3537 ((-572) $ $)) (IF (|has| |t#1| (-1098)) (PROGN (-15 -3432 ((-121) $ $)) (-15 -1303 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4603)) (PROGN (-15 -2155 ($ $ (-638 $))) (-15 -3283 (|t#1| $ "value" |t#1|)) (-15 -4436 (|t#1| $ |t#1|))) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-4190 (($ $) 9) (($ $ (-769)) 43) (($ (-413 (-572))) 12) (($ (-572)) 15)) (-3733 (((-3 $ "failed") (-1166 $) (-923) (-856)) 23) (((-3 $ "failed") (-1166 $) (-923)) 28)) (-1451 (($ $ (-572)) 49)) (-2140 (((-769)) 16)) (-4010 (((-638 $) (-1166 $)) NIL) (((-638 $) (-1166 (-413 (-572)))) 54) (((-638 $) (-1166 (-572))) 59) (((-638 $) (-959 $)) 63) (((-638 $) (-959 (-413 (-572)))) 67) (((-638 $) (-959 (-572))) 71)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL) (($ $ (-413 (-572))) 47))) 
-(((-1018 |#1|) (-10 -8 (-15 -4190 (|#1| (-572))) (-15 -4190 (|#1| (-413 (-572)))) (-15 -4190 (|#1| |#1| (-769))) (-15 -4010 ((-638 |#1|) (-959 (-572)))) (-15 -4010 ((-638 |#1|) (-959 (-413 (-572))))) (-15 -4010 ((-638 |#1|) (-959 |#1|))) (-15 -4010 ((-638 |#1|) (-1166 (-572)))) (-15 -4010 ((-638 |#1|) (-1166 (-413 (-572))))) (-15 -4010 ((-638 |#1|) (-1166 |#1|))) (-15 -3733 ((-3 |#1| "failed") (-1166 |#1|) (-923))) (-15 -3733 ((-3 |#1| "failed") (-1166 |#1|) (-923) (-856))) (-15 ** (|#1| |#1| (-413 (-572)))) (-15 -1451 (|#1| |#1| (-572))) (-15 -4190 (|#1| |#1|)) (-15 ** (|#1| |#1| (-572))) (-15 -2140 ((-769))) (-15 ** (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-923)))) (-1019)) (T -1018)) 
-((-2140 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1018 *3)) (-4 *3 (-1019))))) 
-(-10 -8 (-15 -4190 (|#1| (-572))) (-15 -4190 (|#1| (-413 (-572)))) (-15 -4190 (|#1| |#1| (-769))) (-15 -4010 ((-638 |#1|) (-959 (-572)))) (-15 -4010 ((-638 |#1|) (-959 (-413 (-572))))) (-15 -4010 ((-638 |#1|) (-959 |#1|))) (-15 -4010 ((-638 |#1|) (-1166 (-572)))) (-15 -4010 ((-638 |#1|) (-1166 (-413 (-572))))) (-15 -4010 ((-638 |#1|) (-1166 |#1|))) (-15 -3733 ((-3 |#1| "failed") (-1166 |#1|) (-923))) (-15 -3733 ((-3 |#1| "failed") (-1166 |#1|) (-923) (-856))) (-15 ** (|#1| |#1| (-413 (-572)))) (-15 -1451 (|#1| |#1| (-572))) (-15 -4190 (|#1| |#1|)) (-15 ** (|#1| |#1| (-572))) (-15 -2140 ((-769))) (-15 ** (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-923)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 88)) (-3946 (($ $) 89)) (-3686 (((-121) $) 91)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 108)) (-1466 (((-424 $) $) 109)) (-4190 (($ $) 72) (($ $ (-769)) 58) (($ (-413 (-572))) 57) (($ (-572)) 56)) (-3112 (((-121) $ $) 99)) (-2433 (((-572) $) 126)) (-2211 (($) 16 T CONST)) (-3733 (((-3 $ "failed") (-1166 $) (-923) (-856)) 66) (((-3 $ "failed") (-1166 $) (-923)) 65)) (-3376 (((-3 (-572) "failed") $) 84 (|has| (-413 (-572)) (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 82 (|has| (-413 (-572)) (-1044 (-413 (-572))))) (((-3 (-413 (-572)) "failed") $) 80)) (-1318 (((-572) $) 85 (|has| (-413 (-572)) (-1044 (-572)))) (((-413 (-572)) $) 83 (|has| (-413 (-572)) (-1044 (-413 (-572))))) (((-413 (-572)) $) 79)) (-3582 (($ $ (-856)) 55)) (-2403 (($ $ (-856)) 54)) (-2190 (($ $ $) 103)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 102)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 97)) (-1526 (((-121) $) 110)) (-1908 (((-121) $) 124)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 71)) (-4472 (((-121) $) 125)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 106)) (-1771 (($ $ $) 123)) (-4238 (($ $ $) 122)) (-1756 (((-3 (-1166 $) "failed") $) 67)) (-3857 (((-3 (-856) "failed") $) 69)) (-3939 (((-3 (-1166 $) "failed") $) 68)) (-1629 (($ (-638 $)) 95) (($ $ $) 94)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 111)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 96)) (-3069 (($ (-638 $)) 93) (($ $ $) 92)) (-4304 (((-424 $) $) 107)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 104)) (-1803 (((-3 $ "failed") $ $) 87)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 98)) (-4029 (((-769) $) 100)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 101)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 116) (($ $) 86) (($ (-413 (-572))) 81) (($ (-572)) 78) (($ (-413 (-572))) 75)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 90)) (-3410 (((-413 (-572)) $ $) 53)) (-4010 (((-638 $) (-1166 $)) 64) (((-638 $) (-1166 (-413 (-572)))) 63) (((-638 $) (-1166 (-572))) 62) (((-638 $) (-959 $)) 61) (((-638 $) (-959 (-413 (-572)))) 60) (((-638 $) (-959 (-572))) 59)) (-2264 (($ $) 127)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 112)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1349 (((-121) $ $) 120)) (-1338 (((-121) $ $) 119)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 121)) (-1334 (((-121) $ $) 118)) (-1379 (($ $ $) 117)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 113) (($ $ (-413 (-572))) 70)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ (-413 (-572)) $) 115) (($ $ (-413 (-572))) 114) (($ (-572) $) 77) (($ $ (-572)) 76) (($ (-413 (-572)) $) 74) (($ $ (-413 (-572))) 73))) 
-(((-1019) (-1290)) (T -1019)) 
-((-4190 (*1 *1 *1) (-4 *1 (-1019))) (-3857 (*1 *2 *1) (|partial| -12 (-4 *1 (-1019)) (-5 *2 (-856)))) (-3939 (*1 *2 *1) (|partial| -12 (-5 *2 (-1166 *1)) (-4 *1 (-1019)))) (-1756 (*1 *2 *1) (|partial| -12 (-5 *2 (-1166 *1)) (-4 *1 (-1019)))) (-3733 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-1166 *1)) (-5 *3 (-923)) (-5 *4 (-856)) (-4 *1 (-1019)))) (-3733 (*1 *1 *2 *3) (|partial| -12 (-5 *2 (-1166 *1)) (-5 *3 (-923)) (-4 *1 (-1019)))) (-4010 (*1 *2 *3) (-12 (-5 *3 (-1166 *1)) (-4 *1 (-1019)) (-5 *2 (-638 *1)))) (-4010 (*1 *2 *3) (-12 (-5 *3 (-1166 (-413 (-572)))) (-5 *2 (-638 *1)) (-4 *1 (-1019)))) (-4010 (*1 *2 *3) (-12 (-5 *3 (-1166 (-572))) (-5 *2 (-638 *1)) (-4 *1 (-1019)))) (-4010 (*1 *2 *3) (-12 (-5 *3 (-959 *1)) (-4 *1 (-1019)) (-5 *2 (-638 *1)))) (-4010 (*1 *2 *3) (-12 (-5 *3 (-959 (-413 (-572)))) (-5 *2 (-638 *1)) (-4 *1 (-1019)))) (-4010 (*1 *2 *3) (-12 (-5 *3 (-959 (-572))) (-5 *2 (-638 *1)) (-4 *1 (-1019)))) (-4190 (*1 *1 *1 *2) (-12 (-4 *1 (-1019)) (-5 *2 (-769)))) (-4190 (*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-4 *1 (-1019)))) (-4190 (*1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1019)))) (-3582 (*1 *1 *1 *2) (-12 (-4 *1 (-1019)) (-5 *2 (-856)))) (-2403 (*1 *1 *1 *2) (-12 (-4 *1 (-1019)) (-5 *2 (-856)))) (-3410 (*1 *2 *1 *1) (-12 (-4 *1 (-1019)) (-5 *2 (-413 (-572)))))) 
-(-13 (-151) (-846) (-174) (-368) (-417 (-413 (-572))) (-43 (-572)) (-43 (-413 (-572))) (-1009) (-10 -8 (-15 -3857 ((-3 (-856) "failed") $)) (-15 -3939 ((-3 (-1166 $) "failed") $)) (-15 -1756 ((-3 (-1166 $) "failed") $)) (-15 -3733 ((-3 $ "failed") (-1166 $) (-923) (-856))) (-15 -3733 ((-3 $ "failed") (-1166 $) (-923))) (-15 -4010 ((-638 $) (-1166 $))) (-15 -4010 ((-638 $) (-1166 (-413 (-572))))) (-15 -4010 ((-638 $) (-1166 (-572)))) (-15 -4010 ((-638 $) (-959 $))) (-15 -4010 ((-638 $) (-959 (-413 (-572))))) (-15 -4010 ((-638 $) (-959 (-572)))) (-15 -4190 ($ $ (-769))) (-15 -4190 ($ $)) (-15 -4190 ($ (-413 (-572)))) (-15 -4190 ($ (-572))) (-15 -3582 ($ $ (-856))) (-15 -2403 ($ $ (-856))) (-15 -3410 ((-413 (-572)) $ $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 (-572)) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 (-572) (-572)) . T) ((-120 $ $) . T) ((-138) . T) ((-151) . T) ((-612 (-856)) . T) ((-174) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-417 (-413 (-572))) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 (-572)) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 (-572)) . T) ((-713 $) . T) ((-722) . T) ((-792) . T) ((-793) . T) ((-795) . T) ((-796) . T) ((-846) . T) ((-848) . T) ((-922) . T) ((-1009) . T) ((-1044 (-413 (-572))) . T) ((-1044 (-572)) |has| (-413 (-572)) (-1044 (-572))) ((-1060 (-413 (-572))) . T) ((-1060 (-572)) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T)) 
-((-1822 (((-2 (|:| |ans| |#2|) (|:| -1862 |#2|) (|:| |sol?| (-121))) (-572) |#2| |#2| (-1170) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-638 |#2|)) (-1 (-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) 61))) 
-(((-1020 |#1| |#2|) (-10 -7 (-15 -1822 ((-2 (|:| |ans| |#2|) (|:| -1862 |#2|) (|:| |sol?| (-121))) (-572) |#2| |#2| (-1170) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-638 |#2|)) (-1 (-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572))) (-13 (-1190) (-27) (-436 |#1|))) (T -1020)) 
-((-1822 (*1 *2 *3 *4 *4 *5 *6 *7) (-12 (-5 *5 (-1170)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-638 *4))) (-5 *7 (-1 (-3 (-2 (|:| -3444 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1190) (-27) (-436 *8))) (-4 *8 (-13 (-457) (-848) (-151) (-1044 *3) (-634 *3))) (-5 *3 (-572)) (-5 *2 (-2 (|:| |ans| *4) (|:| -1862 *4) (|:| |sol?| (-121)))) (-5 *1 (-1020 *8 *4))))) 
-(-10 -7 (-15 -1822 ((-2 (|:| |ans| |#2|) (|:| -1862 |#2|) (|:| |sol?| (-121))) (-572) |#2| |#2| (-1170) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-638 |#2|)) (-1 (-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) 
-((-4053 (((-3 (-638 |#2|) "failed") (-572) |#2| |#2| |#2| (-1170) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-638 |#2|)) (-1 (-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) 47))) 
-(((-1021 |#1| |#2|) (-10 -7 (-15 -4053 ((-3 (-638 |#2|) "failed") (-572) |#2| |#2| |#2| (-1170) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-638 |#2|)) (-1 (-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572))) (-13 (-1190) (-27) (-436 |#1|))) (T -1021)) 
-((-4053 (*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| -12 (-5 *5 (-1170)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-638 *4))) (-5 *7 (-1 (-3 (-2 (|:| -3444 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1190) (-27) (-436 *8))) (-4 *8 (-13 (-457) (-848) (-151) (-1044 *3) (-634 *3))) (-5 *3 (-572)) (-5 *2 (-638 *4)) (-5 *1 (-1021 *8 *4))))) 
-(-10 -7 (-15 -4053 ((-3 (-638 |#2|) "failed") (-572) |#2| |#2| |#2| (-1170) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-638 |#2|)) (-1 (-3 (-2 (|:| -3444 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) 
-((-4090 (((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -2352 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-572)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-572) (-1 |#2| |#2|)) 30)) (-4358 (((-3 (-2 (|:| |a| |#2|) (|:| |b| (-413 |#2|)) (|:| |c| (-413 |#2|)) (|:| -3512 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-1 |#2| |#2|)) 56)) (-2878 (((-2 (|:| |ans| (-413 |#2|)) (|:| |nosol| (-121))) (-413 |#2|) (-413 |#2|)) 61))) 
-(((-1022 |#1| |#2|) (-10 -7 (-15 -4358 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-413 |#2|)) (|:| |c| (-413 |#2|)) (|:| -3512 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-1 |#2| |#2|))) (-15 -2878 ((-2 (|:| |ans| (-413 |#2|)) (|:| |nosol| (-121))) (-413 |#2|) (-413 |#2|))) (-15 -4090 ((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -2352 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-572)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-572) (-1 |#2| |#2|)))) (-13 (-368) (-151) (-1044 (-572))) (-1234 |#1|)) (T -1022)) 
-((-4090 (*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-1 *3 *3)) (-4 *3 (-1234 *6)) (-4 *6 (-13 (-368) (-151) (-1044 *4))) (-5 *4 (-572)) (-5 *2 (-3 (|:| |ans| (-2 (|:| |ans| *3) (|:| |nosol| (-121)))) (|:| -2352 (-2 (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (-5 *1 (-1022 *6 *3)))) (-2878 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-572)))) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| |ans| (-413 *5)) (|:| |nosol| (-121)))) (-5 *1 (-1022 *4 *5)) (-5 *3 (-413 *5)))) (-4358 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-413 *6)) (|:| |c| (-413 *6)) (|:| -3512 *6))) (-5 *1 (-1022 *5 *6)) (-5 *3 (-413 *6))))) 
-(-10 -7 (-15 -4358 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-413 |#2|)) (|:| |c| (-413 |#2|)) (|:| -3512 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-1 |#2| |#2|))) (-15 -2878 ((-2 (|:| |ans| (-413 |#2|)) (|:| |nosol| (-121))) (-413 |#2|) (-413 |#2|))) (-15 -4090 ((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -2352 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-572)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-572) (-1 |#2| |#2|)))) 
-((-2592 (((-3 (-2 (|:| |a| |#2|) (|:| |b| (-413 |#2|)) (|:| |h| |#2|) (|:| |c1| (-413 |#2|)) (|:| |c2| (-413 |#2|)) (|:| -3512 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|) (-1 |#2| |#2|)) 22)) (-2664 (((-3 (-638 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|)) 32))) 
-(((-1023 |#1| |#2|) (-10 -7 (-15 -2592 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-413 |#2|)) (|:| |h| |#2|) (|:| |c1| (-413 |#2|)) (|:| |c2| (-413 |#2|)) (|:| -3512 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|) (-1 |#2| |#2|))) (-15 -2664 ((-3 (-638 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|)))) (-13 (-368) (-151) (-1044 (-572))) (-1234 |#1|)) (T -1023)) 
-((-2664 (*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-368) (-151) (-1044 (-572)))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-413 *5))) (-5 *1 (-1023 *4 *5)) (-5 *3 (-413 *5)))) (-2592 (*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-413 *6)) (|:| |h| *6) (|:| |c1| (-413 *6)) (|:| |c2| (-413 *6)) (|:| -3512 *6))) (-5 *1 (-1023 *5 *6)) (-5 *3 (-413 *6))))) 
-(-10 -7 (-15 -2592 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-413 |#2|)) (|:| |h| |#2|) (|:| |c1| (-413 |#2|)) (|:| |c2| (-413 |#2|)) (|:| -3512 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|) (-1 |#2| |#2|))) (-15 -2664 ((-3 (-638 (-413 |#2|)) "failed") (-413 |#2|) (-413 |#2|) (-413 |#2|)))) 
-((-4571 (((-1 |#1|) (-638 (-2 (|:| -2148 |#1|) (|:| -3073 (-572))))) 37)) (-1350 (((-1 |#1|) (-1100 |#1|)) 45)) (-3472 (((-1 |#1|) (-1259 |#1|) (-1259 (-572)) (-572)) 34))) 
-(((-1024 |#1|) (-10 -7 (-15 -1350 ((-1 |#1|) (-1100 |#1|))) (-15 -4571 ((-1 |#1|) (-638 (-2 (|:| -2148 |#1|) (|:| -3073 (-572)))))) (-15 -3472 ((-1 |#1|) (-1259 |#1|) (-1259 (-572)) (-572)))) (-1098)) (T -1024)) 
-((-3472 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1259 *6)) (-5 *4 (-1259 (-572))) (-5 *5 (-572)) (-4 *6 (-1098)) (-5 *2 (-1 *6)) (-5 *1 (-1024 *6)))) (-4571 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -2148 *4) (|:| -3073 (-572))))) (-4 *4 (-1098)) (-5 *2 (-1 *4)) (-5 *1 (-1024 *4)))) (-1350 (*1 *2 *3) (-12 (-5 *3 (-1100 *4)) (-4 *4 (-1098)) (-5 *2 (-1 *4)) (-5 *1 (-1024 *4))))) 
-(-10 -7 (-15 -1350 ((-1 |#1|) (-1100 |#1|))) (-15 -4571 ((-1 |#1|) (-638 (-2 (|:| -2148 |#1|) (|:| -3073 (-572)))))) (-15 -3472 ((-1 |#1|) (-1259 |#1|) (-1259 (-572)) (-572)))) 
-((-3377 (((-769) (-336 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)) 23))) 
-(((-1025 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3377 ((-769) (-336 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)))) (-368) (-1234 |#1|) (-1234 (-413 |#2|)) (-342 |#1| |#2| |#3|) (-13 (-374) (-368))) (T -1025)) 
-((-3377 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-336 *6 *7 *4 *8)) (-5 *5 (-1 *9 *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-4 *4 (-1234 (-413 *7))) (-4 *8 (-342 *6 *7 *4)) (-4 *9 (-13 (-374) (-368))) (-5 *2 (-769)) (-5 *1 (-1025 *6 *7 *4 *8 *9))))) 
-(-10 -7 (-15 -3377 ((-769) (-336 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)))) 
-((-2436 (((-3 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) "failed") |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) 31) (((-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572))) 28)) (-2186 (((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572))) 33) (((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-413 (-572))) 29) (((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) 32) (((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1|) 27)) (-1967 (((-638 (-413 (-572))) (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) 19)) (-3186 (((-413 (-572)) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) 16))) 
-(((-1026 |#1|) (-10 -7 (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1|)) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-413 (-572)))) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572)))) (-15 -2436 ((-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572)))) (-15 -2436 ((-3 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) "failed") |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-15 -3186 ((-413 (-572)) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-15 -1967 ((-638 (-413 (-572))) (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))))) (-1234 (-572))) (T -1026)) 
-((-1967 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *2 (-638 (-413 (-572)))) (-5 *1 (-1026 *4)) (-4 *4 (-1234 (-572))))) (-3186 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *2 (-413 (-572))) (-5 *1 (-1026 *4)) (-4 *4 (-1234 (-572))))) (-2436 (*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))))) (-2436 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *4 (-413 (-572))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))))) (-2186 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-413 (-572))) (-5 *2 (-638 (-2 (|:| -1866 *5) (|:| -1862 *5)))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))) (-5 *4 (-2 (|:| -1866 *5) (|:| -1862 *5))))) (-2186 (*1 *2 *3 *4) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))) (-5 *4 (-413 (-572))))) (-2186 (*1 *2 *3 *4) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))) (-5 *4 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))))) (-2186 (*1 *2 *3) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572)))))) 
-(-10 -7 (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1|)) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-413 (-572)))) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572)))) (-15 -2436 ((-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572)))) (-15 -2436 ((-3 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) "failed") |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-15 -3186 ((-413 (-572)) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-15 -1967 ((-638 (-413 (-572))) (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))))) 
-((-2436 (((-3 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) "failed") |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) 35) (((-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572))) 32)) (-2186 (((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572))) 30) (((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-413 (-572))) 26) (((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) 28) (((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1|) 24))) 
-(((-1027 |#1|) (-10 -7 (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1|)) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-413 (-572)))) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572)))) (-15 -2436 ((-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572)))) (-15 -2436 ((-3 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) "failed") |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))))) (-1234 (-413 (-572)))) (T -1027)) 
-((-2436 (*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 (-413 (-572)))))) (-2436 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *4 (-413 (-572))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 *4)))) (-2186 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-413 (-572))) (-5 *2 (-638 (-2 (|:| -1866 *5) (|:| -1862 *5)))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 *5)) (-5 *4 (-2 (|:| -1866 *5) (|:| -1862 *5))))) (-2186 (*1 *2 *3 *4) (-12 (-5 *4 (-413 (-572))) (-5 *2 (-638 (-2 (|:| -1866 *4) (|:| -1862 *4)))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 *4)))) (-2186 (*1 *2 *3 *4) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 (-413 (-572)))) (-5 *4 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))))) (-2186 (*1 *2 *3) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 (-413 (-572))))))) 
-(-10 -7 (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1|)) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-413 (-572)))) (-15 -2186 ((-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572)))) (-15 -2436 ((-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-413 (-572)))) (-15 -2436 ((-3 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) "failed") |#1| (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))) (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))))) 
-((-4081 (((-217) $) 6) (((-385) $) 8))) 
-(((-1028) (-1290)) (T -1028)) 
-NIL 
-(-13 (-613 (-217)) (-613 (-385))) 
-(((-613 (-217)) . T) ((-613 (-385)) . T)) 
-((-2800 (((-638 (-385)) (-959 (-572)) (-385)) 27) (((-638 (-385)) (-959 (-413 (-572))) (-385)) 26)) (-2641 (((-638 (-638 (-385))) (-638 (-959 (-572))) (-638 (-1170)) (-385)) 36))) 
-(((-1029) (-10 -7 (-15 -2800 ((-638 (-385)) (-959 (-413 (-572))) (-385))) (-15 -2800 ((-638 (-385)) (-959 (-572)) (-385))) (-15 -2641 ((-638 (-638 (-385))) (-638 (-959 (-572))) (-638 (-1170)) (-385))))) (T -1029)) 
-((-2641 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-638 (-1170))) (-5 *2 (-638 (-638 (-385)))) (-5 *1 (-1029)) (-5 *5 (-385)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-959 (-572))) (-5 *2 (-638 (-385))) (-5 *1 (-1029)) (-5 *4 (-385)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-959 (-413 (-572)))) (-5 *2 (-638 (-385))) (-5 *1 (-1029)) (-5 *4 (-385))))) 
-(-10 -7 (-15 -2800 ((-638 (-385)) (-959 (-413 (-572))) (-385))) (-15 -2800 ((-638 (-385)) (-959 (-572)) (-385))) (-15 -2641 ((-638 (-638 (-385))) (-638 (-959 (-572))) (-638 (-1170)) (-385)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 70)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-4190 (($ $) NIL) (($ $ (-769)) NIL) (($ (-413 (-572))) NIL) (($ (-572)) NIL)) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) 65)) (-2211 (($) NIL T CONST)) (-3733 (((-3 $ "failed") (-1166 $) (-923) (-856)) NIL) (((-3 $ "failed") (-1166 $) (-923)) 49)) (-3376 (((-3 (-413 (-572)) "failed") $) NIL (|has| (-413 (-572)) (-1044 (-413 (-572))))) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 |#1| "failed") $) 108) (((-3 (-572) "failed") $) NIL (-1841 (|has| (-413 (-572)) (-1044 (-572))) (|has| |#1| (-1044 (-572)))))) (-1318 (((-413 (-572)) $) 14 (|has| (-413 (-572)) (-1044 (-413 (-572))))) (((-413 (-572)) $) 14) ((|#1| $) 109) (((-572) $) NIL (-1841 (|has| (-413 (-572)) (-1044 (-572))) (|has| |#1| (-1044 (-572)))))) (-3582 (($ $ (-856)) 40)) (-2403 (($ $ (-856)) 41)) (-2190 (($ $ $) NIL)) (-3089 (((-413 (-572)) $ $) 18)) (-1799 (((-3 $ "failed") $) 83)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1908 (((-121) $) 60)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL)) (-4472 (((-121) $) 63)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1756 (((-3 (-1166 $) "failed") $) 78)) (-3857 (((-3 (-856) "failed") $) 77)) (-3939 (((-3 (-1166 $) "failed") $) 75)) (-3172 (((-3 (-1064 $ (-1166 $)) "failed") $) 73)) (-1629 (($ (-638 $)) NIL) (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 84)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ (-638 $)) NIL) (($ $ $) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3972 (((-856) $) 82) (($ (-572)) NIL) (($ (-413 (-572))) NIL) (($ $) 57) (($ (-413 (-572))) NIL) (($ (-572)) NIL) (($ (-413 (-572))) NIL) (($ |#1|) 111)) (-2140 (((-769)) NIL)) (-3774 (((-121) $ $) NIL)) (-3410 (((-413 (-572)) $ $) 24)) (-4010 (((-638 $) (-1166 $)) 55) (((-638 $) (-1166 (-413 (-572)))) NIL) (((-638 $) (-1166 (-572))) NIL) (((-638 $) (-959 $)) NIL) (((-638 $) (-959 (-413 (-572)))) NIL) (((-638 $) (-959 (-572))) NIL)) (-3864 (($ (-1064 $ (-1166 $)) (-856)) 39)) (-2264 (($ $) 19)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL)) (-2378 (($) 28 T CONST)) (-3255 (($) 34 T CONST)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 71)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 21)) (-1379 (($ $ $) 32)) (-1373 (($ $) 33) (($ $ $) 69)) (-1367 (($ $ $) 104)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL) (($ $ (-413 (-572))) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 92) (($ $ $) 97) (($ (-413 (-572)) $) NIL) (($ $ (-413 (-572))) NIL) (($ (-572) $) 92) (($ $ (-572)) NIL) (($ (-413 (-572)) $) NIL) (($ $ (-413 (-572))) NIL) (($ |#1| $) 96) (($ $ |#1|) NIL))) 
-(((-1030 |#1|) (-13 (-1019) (-417 |#1|) (-43 |#1|) (-10 -8 (-15 -3864 ($ (-1064 $ (-1166 $)) (-856))) (-15 -3172 ((-3 (-1064 $ (-1166 $)) "failed") $)) (-15 -3089 ((-413 (-572)) $ $)))) (-13 (-846) (-368) (-1028))) (T -1030)) 
-((-3864 (*1 *1 *2 *3) (-12 (-5 *2 (-1064 (-1030 *4) (-1166 (-1030 *4)))) (-5 *3 (-856)) (-5 *1 (-1030 *4)) (-4 *4 (-13 (-846) (-368) (-1028))))) (-3172 (*1 *2 *1) (|partial| -12 (-5 *2 (-1064 (-1030 *3) (-1166 (-1030 *3)))) (-5 *1 (-1030 *3)) (-4 *3 (-13 (-846) (-368) (-1028))))) (-3089 (*1 *2 *1 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-1030 *3)) (-4 *3 (-13 (-846) (-368) (-1028)))))) 
-(-13 (-1019) (-417 |#1|) (-43 |#1|) (-10 -8 (-15 -3864 ($ (-1064 $ (-1166 $)) (-856))) (-15 -3172 ((-3 (-1064 $ (-1166 $)) "failed") $)) (-15 -3089 ((-413 (-572)) $ $)))) 
-((-2386 (((-2 (|:| -4238 (-3 (-572) "failed")) (|:| -3306 (-3 (-572) "failed")) (|:| |ker| (-611 |#2|))) (-123) (-1170) |#2|) 59 (|has| |#1| (-1054)))) (-2111 (((-572) (-572) (-123) (-1170) |#2|) 76)) (-4162 (((-3 (-572) "failed") (-123) (-611 |#2|) (-1170)) 56 (|has| |#1| (-1054)))) (-3492 (((-123) |#2|) 103)) (-2828 ((|#2| |#2|) 102)) (-3984 ((|#2| (-123) (-1170) |#2| |#2| |#2| (-638 |#2|)) 72)) (-1717 ((|#2| (-123) (-1170) |#2| |#2| |#2| (-638 |#2|)) 100))) 
-(((-1031 |#1| |#2|) (-10 -7 (-15 -3984 (|#2| (-123) (-1170) |#2| |#2| |#2| (-638 |#2|))) (-15 -1717 (|#2| (-123) (-1170) |#2| |#2| |#2| (-638 |#2|))) (-15 -2828 (|#2| |#2|)) (-15 -3492 ((-123) |#2|)) (-15 -2111 ((-572) (-572) (-123) (-1170) |#2|)) (IF (|has| |#1| (-1054)) (PROGN (-15 -4162 ((-3 (-572) "failed") (-123) (-611 |#2|) (-1170))) (-15 -2386 ((-2 (|:| -4238 (-3 (-572) "failed")) (|:| -3306 (-3 (-572) "failed")) (|:| |ker| (-611 |#2|))) (-123) (-1170) |#2|))) |noBranch|)) (-13 (-848) (-562) (-613 (-545))) (-13 (-436 |#1|) (-23) (-1044 (-572)) (-1044 (-1170)) (-901 (-1170)) (-162))) (T -1031)) 
-((-2386 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *4 (-1170)) (-4 *6 (-1054)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-2 (|:| -4238 (-3 (-572) "failed")) (|:| -3306 (-3 (-572) "failed")) (|:| |ker| (-611 *5)))) (-5 *1 (-1031 *6 *5)) (-4 *5 (-13 (-436 *6) (-23) (-1044 (-572)) (-1044 *4) (-901 *4) (-162))))) (-4162 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-611 *7)) (-4 *7 (-13 (-436 *6) (-23) (-1044 *2) (-1044 *5) (-901 *5) (-162))) (-5 *5 (-1170)) (-4 *6 (-1054)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-572)) (-5 *1 (-1031 *6 *7)))) (-2111 (*1 *2 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *2 (-572)) (-5 *4 (-1170)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *1 (-1031 *6 *5)) (-4 *5 (-13 (-436 *6) (-23) (-1044 *2) (-1044 *4) (-901 *4) (-162))))) (-3492 (*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-123)) (-5 *1 (-1031 *4 *3)) (-4 *3 (-13 (-436 *4) (-23) (-1044 (-572)) (-1044 (-1170)) (-901 (-1170)) (-162))))) (-2828 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562) (-613 (-545)))) (-5 *1 (-1031 *3 *2)) (-4 *2 (-13 (-436 *3) (-23) (-1044 (-572)) (-1044 (-1170)) (-901 (-1170)) (-162))))) (-1717 (*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-436 *6) (-23) (-1044 (-572)) (-1044 *4) (-901 *4) (-162))) (-5 *4 (-1170)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *1 (-1031 *6 *2)))) (-3984 (*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-436 *6) (-23) (-1044 (-572)) (-1044 *4) (-901 *4) (-162))) (-5 *4 (-1170)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *1 (-1031 *6 *2))))) 
-(-10 -7 (-15 -3984 (|#2| (-123) (-1170) |#2| |#2| |#2| (-638 |#2|))) (-15 -1717 (|#2| (-123) (-1170) |#2| |#2| |#2| (-638 |#2|))) (-15 -2828 (|#2| |#2|)) (-15 -3492 ((-123) |#2|)) (-15 -2111 ((-572) (-572) (-123) (-1170) |#2|)) (IF (|has| |#1| (-1054)) (PROGN (-15 -4162 ((-3 (-572) "failed") (-123) (-611 |#2|) (-1170))) (-15 -2386 ((-2 (|:| -4238 (-3 (-572) "failed")) (|:| -3306 (-3 (-572) "failed")) (|:| |ker| (-611 |#2|))) (-123) (-1170) |#2|))) |noBranch|)) 
-((-1944 (((-2 (|:| -2352 |#2|) (|:| -1824 (-638 |#1|))) |#2| (-638 |#1|)) 20) ((|#2| |#2| |#1|) 15))) 
-(((-1032 |#1| |#2|) (-10 -7 (-15 -1944 (|#2| |#2| |#1|)) (-15 -1944 ((-2 (|:| -2352 |#2|) (|:| -1824 (-638 |#1|))) |#2| (-638 |#1|)))) (-368) (-650 |#1|)) (T -1032)) 
-((-1944 (*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-5 *2 (-2 (|:| -2352 *3) (|:| -1824 (-638 *5)))) (-5 *1 (-1032 *5 *3)) (-5 *4 (-638 *5)) (-4 *3 (-650 *5)))) (-1944 (*1 *2 *2 *3) (-12 (-4 *3 (-368)) (-5 *1 (-1032 *3 *2)) (-4 *2 (-650 *3))))) 
-(-10 -7 (-15 -1944 (|#2| |#2| |#1|)) (-15 -1944 ((-2 (|:| -2352 |#2|) (|:| -1824 (-638 |#1|))) |#2| (-638 |#1|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2560 ((|#1| $ |#1|) 14)) (-3283 ((|#1| $ |#1|) 12)) (-2579 (($ |#1|) 10)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3277 ((|#1| $) 11)) (-1883 ((|#1| $) 13)) (-3972 (((-856) $) 21 (|has| |#1| (-1098)))) (-1324 (((-121) $ $) 9))) 
-(((-1033 |#1|) (-13 (-1204) (-10 -8 (-15 -2579 ($ |#1|)) (-15 -3277 (|#1| $)) (-15 -3283 (|#1| $ |#1|)) (-15 -1883 (|#1| $)) (-15 -2560 (|#1| $ |#1|)) (-15 -1324 ((-121) $ $)) (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|))) (-1204)) (T -1033)) 
-((-2579 (*1 *1 *2) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204)))) (-3277 (*1 *2 *1) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204)))) (-3283 (*1 *2 *1 *2) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204)))) (-1883 (*1 *2 *1) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204)))) (-2560 (*1 *2 *1 *2) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204)))) (-1324 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1033 *3)) (-4 *3 (-1204))))) 
-(-13 (-1204) (-10 -8 (-15 -2579 ($ |#1|)) (-15 -3277 (|#1| $)) (-15 -3283 (|#1| $ |#1|)) (-15 -1883 (|#1| $)) (-15 -2560 (|#1| $ |#1|)) (-15 -1324 ((-121) $ $)) (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) NIL)) (-4165 (((-638 $) (-638 |#4|)) 104) (((-638 $) (-638 |#4|) (-121)) 105) (((-638 $) (-638 |#4|) (-121) (-121)) 103) (((-638 $) (-638 |#4|) (-121) (-121) (-121) (-121)) 106)) (-3456 (((-638 |#3|) $) NIL)) (-3049 (((-121) $) NIL)) (-3289 (((-121) $) NIL (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1872 ((|#4| |#4| $) NIL)) (-2844 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| $) 98)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2561 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) 53)) (-2211 (($) NIL T CONST)) (-3097 (((-121) $) 26 (|has| |#1| (-562)))) (-3760 (((-121) $ $) NIL (|has| |#1| (-562)))) (-3819 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4331 (((-121) $) NIL (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3683 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) NIL)) (-1318 (($ (-638 |#4|)) NIL)) (-1651 (((-3 $ "failed") $) 39)) (-2242 ((|#4| |#4| $) 56)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-3445 (($ |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 72 (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-1673 ((|#4| |#4| $) NIL)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) NIL)) (-1706 (((-121) |#4| $) NIL)) (-2989 (((-121) |#4| $) NIL)) (-1366 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-3345 (((-2 (|:| |val| (-638 |#4|)) (|:| |towers| (-638 $))) (-638 |#4|) (-121) (-121)) 118)) (-2010 (((-638 |#4|) $) 16 (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#4|) $) 17 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-2435 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 21)) (-4062 (((-638 |#3|) $) NIL)) (-1346 (((-121) |#3| $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2550 (((-3 |#4| (-638 $)) |#4| |#4| $) NIL)) (-4416 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| |#4| $) 96)) (-3253 (((-3 |#4| "failed") $) 37)) (-2173 (((-638 $) |#4| $) 79)) (-2471 (((-3 (-121) (-638 $)) |#4| $) NIL)) (-2338 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 $))) |#4| $) 89) (((-121) |#4| $) 51)) (-1931 (((-638 $) |#4| $) 101) (((-638 $) (-638 |#4|) $) NIL) (((-638 $) (-638 |#4|) (-638 $)) 102) (((-638 $) |#4| (-638 $)) NIL)) (-1605 (((-638 $) (-638 |#4|) (-121) (-121) (-121)) 113)) (-3078 (($ |#4| $) 69) (($ (-638 |#4|) $) 70) (((-638 $) |#4| $ (-121) (-121) (-121) (-121) (-121)) 66)) (-3727 (((-638 |#4|) $) NIL)) (-1483 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2788 ((|#4| |#4| $) NIL)) (-1843 (((-121) $ $) NIL)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4498 ((|#4| |#4| $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-3 |#4| "failed") $) 35)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1928 (((-3 $ "failed") $ |#4|) 47)) (-1977 (($ $ |#4|) NIL) (((-638 $) |#4| $) 81) (((-638 $) |#4| (-638 $)) NIL) (((-638 $) (-638 |#4|) $) NIL) (((-638 $) (-638 |#4|) (-638 $)) 76)) (-2109 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 15)) (-1665 (($) 13)) (-4316 (((-769) $) NIL)) (-1571 (((-769) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (((-769) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) 12)) (-4081 (((-545) $) NIL (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 20)) (-1826 (($ $ |#3|) 42)) (-2291 (($ $ |#3|) 43)) (-3134 (($ $) NIL)) (-1650 (($ $ |#3|) NIL)) (-3972 (((-856) $) 31) (((-638 |#4|) $) 40)) (-2498 (((-769) $) NIL (|has| |#3| (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) NIL)) (-2589 (((-638 $) |#4| $) 78) (((-638 $) |#4| (-638 $)) NIL) (((-638 $) (-638 |#4|) $) NIL) (((-638 $) (-638 |#4|) (-638 $)) NIL)) (-3501 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) NIL)) (-4191 (((-121) |#4| $) NIL)) (-2213 (((-121) |#3| $) 52)) (-1324 (((-121) $ $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1034 |#1| |#2| |#3| |#4|) (-13 (-1073 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3078 ((-638 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -4165 ((-638 $) (-638 |#4|) (-121) (-121))) (-15 -4165 ((-638 $) (-638 |#4|) (-121) (-121) (-121) (-121))) (-15 -1605 ((-638 $) (-638 |#4|) (-121) (-121) (-121))) (-15 -3345 ((-2 (|:| |val| (-638 |#4|)) (|:| |towers| (-638 $))) (-638 |#4|) (-121) (-121))))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|)) (T -1034)) 
-((-3078 (*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1034 *5 *6 *7 *3))) (-5 *1 (-1034 *5 *6 *7 *3)) (-4 *3 (-1068 *5 *6 *7)))) (-4165 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1034 *5 *6 *7 *8))) (-5 *1 (-1034 *5 *6 *7 *8)))) (-4165 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1034 *5 *6 *7 *8))) (-5 *1 (-1034 *5 *6 *7 *8)))) (-1605 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1034 *5 *6 *7 *8))) (-5 *1 (-1034 *5 *6 *7 *8)))) (-3345 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-638 *8)) (|:| |towers| (-638 (-1034 *5 *6 *7 *8))))) (-5 *1 (-1034 *5 *6 *7 *8)) (-5 *3 (-638 *8))))) 
-(-13 (-1073 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3078 ((-638 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -4165 ((-638 $) (-638 |#4|) (-121) (-121))) (-15 -4165 ((-638 $) (-638 |#4|) (-121) (-121) (-121) (-121))) (-15 -1605 ((-638 $) (-638 |#4|) (-121) (-121) (-121))) (-15 -3345 ((-2 (|:| |val| (-638 |#4|)) (|:| |towers| (-638 $))) (-638 |#4|) (-121) (-121))))) 
-((-4532 (((-638 (-685 |#1|)) (-638 (-685 |#1|))) 56) (((-685 |#1|) (-685 |#1|)) 55) (((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-638 (-685 |#1|))) 54) (((-685 |#1|) (-685 |#1|) (-685 |#1|)) 51)) (-2200 (((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-923)) 50) (((-685 |#1|) (-685 |#1|) (-923)) 49)) (-3624 (((-638 (-685 (-572))) (-638 (-638 (-572)))) 66) (((-638 (-685 (-572))) (-638 (-906 (-572))) (-572)) 65) (((-685 (-572)) (-638 (-572))) 62) (((-685 (-572)) (-906 (-572)) (-572)) 61)) (-4215 (((-685 (-959 |#1|)) (-769)) 79)) (-3448 (((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-923)) 36 (|has| |#1| (-6 (-4604 "*")))) (((-685 |#1|) (-685 |#1|) (-923)) 34 (|has| |#1| (-6 (-4604 "*")))))) 
-(((-1035 |#1|) (-10 -7 (IF (|has| |#1| (-6 (-4604 "*"))) (-15 -3448 ((-685 |#1|) (-685 |#1|) (-923))) |noBranch|) (IF (|has| |#1| (-6 (-4604 "*"))) (-15 -3448 ((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-923))) |noBranch|) (-15 -4215 ((-685 (-959 |#1|)) (-769))) (-15 -2200 ((-685 |#1|) (-685 |#1|) (-923))) (-15 -2200 ((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-923))) (-15 -4532 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -4532 ((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-638 (-685 |#1|)))) (-15 -4532 ((-685 |#1|) (-685 |#1|))) (-15 -4532 ((-638 (-685 |#1|)) (-638 (-685 |#1|)))) (-15 -3624 ((-685 (-572)) (-906 (-572)) (-572))) (-15 -3624 ((-685 (-572)) (-638 (-572)))) (-15 -3624 ((-638 (-685 (-572))) (-638 (-906 (-572))) (-572))) (-15 -3624 ((-638 (-685 (-572))) (-638 (-638 (-572)))))) (-1054)) (T -1035)) 
-((-3624 (*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-572)))) (-5 *2 (-638 (-685 (-572)))) (-5 *1 (-1035 *4)) (-4 *4 (-1054)))) (-3624 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-906 (-572)))) (-5 *4 (-572)) (-5 *2 (-638 (-685 *4))) (-5 *1 (-1035 *5)) (-4 *5 (-1054)))) (-3624 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-685 (-572))) (-5 *1 (-1035 *4)) (-4 *4 (-1054)))) (-3624 (*1 *2 *3 *4) (-12 (-5 *3 (-906 (-572))) (-5 *4 (-572)) (-5 *2 (-685 *4)) (-5 *1 (-1035 *5)) (-4 *5 (-1054)))) (-4532 (*1 *2 *2) (-12 (-5 *2 (-638 (-685 *3))) (-4 *3 (-1054)) (-5 *1 (-1035 *3)))) (-4532 (*1 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-1035 *3)))) (-4532 (*1 *2 *2 *2) (-12 (-5 *2 (-638 (-685 *3))) (-4 *3 (-1054)) (-5 *1 (-1035 *3)))) (-4532 (*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-1035 *3)))) (-2200 (*1 *2 *2 *3) (-12 (-5 *2 (-638 (-685 *4))) (-5 *3 (-923)) (-4 *4 (-1054)) (-5 *1 (-1035 *4)))) (-2200 (*1 *2 *2 *3) (-12 (-5 *2 (-685 *4)) (-5 *3 (-923)) (-4 *4 (-1054)) (-5 *1 (-1035 *4)))) (-4215 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-685 (-959 *4))) (-5 *1 (-1035 *4)) (-4 *4 (-1054)))) (-3448 (*1 *2 *2 *3) (-12 (-5 *2 (-638 (-685 *4))) (-5 *3 (-923)) (|has| *4 (-6 (-4604 "*"))) (-4 *4 (-1054)) (-5 *1 (-1035 *4)))) (-3448 (*1 *2 *2 *3) (-12 (-5 *2 (-685 *4)) (-5 *3 (-923)) (|has| *4 (-6 (-4604 "*"))) (-4 *4 (-1054)) (-5 *1 (-1035 *4))))) 
-(-10 -7 (IF (|has| |#1| (-6 (-4604 "*"))) (-15 -3448 ((-685 |#1|) (-685 |#1|) (-923))) |noBranch|) (IF (|has| |#1| (-6 (-4604 "*"))) (-15 -3448 ((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-923))) |noBranch|) (-15 -4215 ((-685 (-959 |#1|)) (-769))) (-15 -2200 ((-685 |#1|) (-685 |#1|) (-923))) (-15 -2200 ((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-923))) (-15 -4532 ((-685 |#1|) (-685 |#1|) (-685 |#1|))) (-15 -4532 ((-638 (-685 |#1|)) (-638 (-685 |#1|)) (-638 (-685 |#1|)))) (-15 -4532 ((-685 |#1|) (-685 |#1|))) (-15 -4532 ((-638 (-685 |#1|)) (-638 (-685 |#1|)))) (-15 -3624 ((-685 (-572)) (-906 (-572)) (-572))) (-15 -3624 ((-685 (-572)) (-638 (-572)))) (-15 -3624 ((-638 (-685 (-572))) (-638 (-906 (-572))) (-572))) (-15 -3624 ((-638 (-685 (-572))) (-638 (-638 (-572)))))) 
-((-4132 (((-685 |#1|) (-638 (-685 |#1|)) (-1259 |#1|)) 48 (|has| |#1| (-303)))) (-1585 (((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-1259 (-1259 |#1|))) 71 (|has| |#1| (-368))) (((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-1259 |#1|)) 69 (|has| |#1| (-368)))) (-3258 (((-1259 |#1|) (-638 (-1259 |#1|)) (-572)) 73 (-12 (|has| |#1| (-368)) (|has| |#1| (-374))))) (-3934 (((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-923)) 78 (-12 (|has| |#1| (-368)) (|has| |#1| (-374)))) (((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-121)) 76 (-12 (|has| |#1| (-368)) (|has| |#1| (-374)))) (((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|))) 75 (-12 (|has| |#1| (-368)) (|has| |#1| (-374)))) (((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-121) (-572) (-572)) 74 (-12 (|has| |#1| (-368)) (|has| |#1| (-374))))) (-2835 (((-121) (-638 (-685 |#1|))) 67 (|has| |#1| (-368))) (((-121) (-638 (-685 |#1|)) (-572)) 66 (|has| |#1| (-368)))) (-1991 (((-1259 (-1259 |#1|)) (-638 (-685 |#1|)) (-1259 |#1|)) 46 (|has| |#1| (-303)))) (-3243 (((-685 |#1|) (-638 (-685 |#1|)) (-685 |#1|)) 32)) (-1574 (((-685 |#1|) (-1259 (-1259 |#1|))) 29)) (-1964 (((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|)) (-572)) 62 (|has| |#1| (-368))) (((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|))) 61 (|has| |#1| (-368))) (((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|)) (-121) (-572)) 60 (|has| |#1| (-368))))) 
-(((-1036 |#1|) (-10 -7 (-15 -1574 ((-685 |#1|) (-1259 (-1259 |#1|)))) (-15 -3243 ((-685 |#1|) (-638 (-685 |#1|)) (-685 |#1|))) (IF (|has| |#1| (-303)) (PROGN (-15 -1991 ((-1259 (-1259 |#1|)) (-638 (-685 |#1|)) (-1259 |#1|))) (-15 -4132 ((-685 |#1|) (-638 (-685 |#1|)) (-1259 |#1|)))) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-15 -1964 ((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|)) (-121) (-572))) (-15 -1964 ((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|)))) (-15 -1964 ((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|)) (-572))) (-15 -2835 ((-121) (-638 (-685 |#1|)) (-572))) (-15 -2835 ((-121) (-638 (-685 |#1|)))) (-15 -1585 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-1259 |#1|))) (-15 -1585 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-1259 (-1259 |#1|))))) |noBranch|) (IF (|has| |#1| (-374)) (IF (|has| |#1| (-368)) (PROGN (-15 -3934 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-121) (-572) (-572))) (-15 -3934 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)))) (-15 -3934 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-121))) (-15 -3934 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-923))) (-15 -3258 ((-1259 |#1|) (-638 (-1259 |#1|)) (-572)))) |noBranch|) |noBranch|)) (-1054)) (T -1036)) 
-((-3258 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1259 *5))) (-5 *4 (-572)) (-5 *2 (-1259 *5)) (-5 *1 (-1036 *5)) (-4 *5 (-368)) (-4 *5 (-374)) (-4 *5 (-1054)))) (-3934 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-4 *5 (-374)) (-4 *5 (-1054)) (-5 *2 (-638 (-638 (-685 *5)))) (-5 *1 (-1036 *5)) (-5 *3 (-638 (-685 *5))))) (-3934 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-368)) (-4 *5 (-374)) (-4 *5 (-1054)) (-5 *2 (-638 (-638 (-685 *5)))) (-5 *1 (-1036 *5)) (-5 *3 (-638 (-685 *5))))) (-3934 (*1 *2 *3) (-12 (-4 *4 (-368)) (-4 *4 (-374)) (-4 *4 (-1054)) (-5 *2 (-638 (-638 (-685 *4)))) (-5 *1 (-1036 *4)) (-5 *3 (-638 (-685 *4))))) (-3934 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-121)) (-5 *5 (-572)) (-4 *6 (-368)) (-4 *6 (-374)) (-4 *6 (-1054)) (-5 *2 (-638 (-638 (-685 *6)))) (-5 *1 (-1036 *6)) (-5 *3 (-638 (-685 *6))))) (-1585 (*1 *2 *3 *4) (-12 (-5 *4 (-1259 (-1259 *5))) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-638 (-638 (-685 *5)))) (-5 *1 (-1036 *5)) (-5 *3 (-638 (-685 *5))))) (-1585 (*1 *2 *3 *4) (-12 (-5 *4 (-1259 *5)) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-638 (-638 (-685 *5)))) (-5 *1 (-1036 *5)) (-5 *3 (-638 (-685 *5))))) (-2835 (*1 *2 *3) (-12 (-5 *3 (-638 (-685 *4))) (-4 *4 (-368)) (-4 *4 (-1054)) (-5 *2 (-121)) (-5 *1 (-1036 *4)))) (-2835 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-685 *5))) (-5 *4 (-572)) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-121)) (-5 *1 (-1036 *5)))) (-1964 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 (-685 *5))) (-5 *4 (-572)) (-5 *2 (-685 *5)) (-5 *1 (-1036 *5)) (-4 *5 (-368)) (-4 *5 (-1054)))) (-1964 (*1 *2 *3 *3) (-12 (-5 *3 (-638 (-685 *4))) (-5 *2 (-685 *4)) (-5 *1 (-1036 *4)) (-4 *4 (-368)) (-4 *4 (-1054)))) (-1964 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-638 (-685 *6))) (-5 *4 (-121)) (-5 *5 (-572)) (-5 *2 (-685 *6)) (-5 *1 (-1036 *6)) (-4 *6 (-368)) (-4 *6 (-1054)))) (-4132 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-685 *5))) (-5 *4 (-1259 *5)) (-4 *5 (-303)) (-4 *5 (-1054)) (-5 *2 (-685 *5)) (-5 *1 (-1036 *5)))) (-1991 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-685 *5))) (-4 *5 (-303)) (-4 *5 (-1054)) (-5 *2 (-1259 (-1259 *5))) (-5 *1 (-1036 *5)) (-5 *4 (-1259 *5)))) (-3243 (*1 *2 *3 *2) (-12 (-5 *3 (-638 (-685 *4))) (-5 *2 (-685 *4)) (-4 *4 (-1054)) (-5 *1 (-1036 *4)))) (-1574 (*1 *2 *3) (-12 (-5 *3 (-1259 (-1259 *4))) (-4 *4 (-1054)) (-5 *2 (-685 *4)) (-5 *1 (-1036 *4))))) 
-(-10 -7 (-15 -1574 ((-685 |#1|) (-1259 (-1259 |#1|)))) (-15 -3243 ((-685 |#1|) (-638 (-685 |#1|)) (-685 |#1|))) (IF (|has| |#1| (-303)) (PROGN (-15 -1991 ((-1259 (-1259 |#1|)) (-638 (-685 |#1|)) (-1259 |#1|))) (-15 -4132 ((-685 |#1|) (-638 (-685 |#1|)) (-1259 |#1|)))) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-15 -1964 ((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|)) (-121) (-572))) (-15 -1964 ((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|)))) (-15 -1964 ((-685 |#1|) (-638 (-685 |#1|)) (-638 (-685 |#1|)) (-572))) (-15 -2835 ((-121) (-638 (-685 |#1|)) (-572))) (-15 -2835 ((-121) (-638 (-685 |#1|)))) (-15 -1585 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-1259 |#1|))) (-15 -1585 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-1259 (-1259 |#1|))))) |noBranch|) (IF (|has| |#1| (-374)) (IF (|has| |#1| (-368)) (PROGN (-15 -3934 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-121) (-572) (-572))) (-15 -3934 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)))) (-15 -3934 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-121))) (-15 -3934 ((-638 (-638 (-685 |#1|))) (-638 (-685 |#1|)) (-923))) (-15 -3258 ((-1259 |#1|) (-638 (-1259 |#1|)) (-572)))) |noBranch|) |noBranch|)) 
-((-1332 ((|#1| (-923) |#1|) 9))) 
-(((-1037 |#1|) (-10 -7 (-15 -1332 (|#1| (-923) |#1|))) (-13 (-1098) (-10 -8 (-15 -1367 ($ $ $))))) (T -1037)) 
-((-1332 (*1 *2 *3 *2) (-12 (-5 *3 (-923)) (-5 *1 (-1037 *2)) (-4 *2 (-13 (-1098) (-10 -8 (-15 -1367 ($ $ $)))))))) 
-(-10 -7 (-15 -1332 (|#1| (-923) |#1|))) 
-((-4178 (((-638 (-2 (|:| |radval| (-312 (-572))) (|:| |radmult| (-572)) (|:| |radvect| (-638 (-685 (-312 (-572))))))) (-685 (-413 (-959 (-572))))) 58)) (-1407 (((-638 (-685 (-312 (-572)))) (-312 (-572)) (-685 (-413 (-959 (-572))))) 48)) (-2578 (((-638 (-312 (-572))) (-685 (-413 (-959 (-572))))) 41)) (-2673 (((-638 (-685 (-312 (-572)))) (-685 (-413 (-959 (-572))))) 67)) (-1403 (((-685 (-312 (-572))) (-685 (-312 (-572)))) 33)) (-3138 (((-638 (-685 (-312 (-572)))) (-638 (-685 (-312 (-572))))) 61)) (-3796 (((-3 (-685 (-312 (-572))) "failed") (-685 (-413 (-959 (-572))))) 65))) 
-(((-1038) (-10 -7 (-15 -4178 ((-638 (-2 (|:| |radval| (-312 (-572))) (|:| |radmult| (-572)) (|:| |radvect| (-638 (-685 (-312 (-572))))))) (-685 (-413 (-959 (-572)))))) (-15 -1407 ((-638 (-685 (-312 (-572)))) (-312 (-572)) (-685 (-413 (-959 (-572)))))) (-15 -2578 ((-638 (-312 (-572))) (-685 (-413 (-959 (-572)))))) (-15 -3796 ((-3 (-685 (-312 (-572))) "failed") (-685 (-413 (-959 (-572)))))) (-15 -1403 ((-685 (-312 (-572))) (-685 (-312 (-572))))) (-15 -3138 ((-638 (-685 (-312 (-572)))) (-638 (-685 (-312 (-572)))))) (-15 -2673 ((-638 (-685 (-312 (-572)))) (-685 (-413 (-959 (-572)))))))) (T -1038)) 
-((-2673 (*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 (-572))))) (-5 *2 (-638 (-685 (-312 (-572))))) (-5 *1 (-1038)))) (-3138 (*1 *2 *2) (-12 (-5 *2 (-638 (-685 (-312 (-572))))) (-5 *1 (-1038)))) (-1403 (*1 *2 *2) (-12 (-5 *2 (-685 (-312 (-572)))) (-5 *1 (-1038)))) (-3796 (*1 *2 *3) (|partial| -12 (-5 *3 (-685 (-413 (-959 (-572))))) (-5 *2 (-685 (-312 (-572)))) (-5 *1 (-1038)))) (-2578 (*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 (-572))))) (-5 *2 (-638 (-312 (-572)))) (-5 *1 (-1038)))) (-1407 (*1 *2 *3 *4) (-12 (-5 *4 (-685 (-413 (-959 (-572))))) (-5 *2 (-638 (-685 (-312 (-572))))) (-5 *1 (-1038)) (-5 *3 (-312 (-572))))) (-4178 (*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| |radval| (-312 (-572))) (|:| |radmult| (-572)) (|:| |radvect| (-638 (-685 (-312 (-572)))))))) (-5 *1 (-1038))))) 
-(-10 -7 (-15 -4178 ((-638 (-2 (|:| |radval| (-312 (-572))) (|:| |radmult| (-572)) (|:| |radvect| (-638 (-685 (-312 (-572))))))) (-685 (-413 (-959 (-572)))))) (-15 -1407 ((-638 (-685 (-312 (-572)))) (-312 (-572)) (-685 (-413 (-959 (-572)))))) (-15 -2578 ((-638 (-312 (-572))) (-685 (-413 (-959 (-572)))))) (-15 -3796 ((-3 (-685 (-312 (-572))) "failed") (-685 (-413 (-959 (-572)))))) (-15 -1403 ((-685 (-312 (-572))) (-685 (-312 (-572))))) (-15 -3138 ((-638 (-685 (-312 (-572)))) (-638 (-685 (-312 (-572)))))) (-15 -2673 ((-638 (-685 (-312 (-572)))) (-685 (-413 (-959 (-572))))))) 
-((-3755 ((|#1| |#1| (-923)) 9))) 
-(((-1039 |#1|) (-10 -7 (-15 -3755 (|#1| |#1| (-923)))) (-13 (-1098) (-10 -8 (-15 * ($ $ $))))) (T -1039)) 
-((-3755 (*1 *2 *2 *3) (-12 (-5 *3 (-923)) (-5 *1 (-1039 *2)) (-4 *2 (-13 (-1098) (-10 -8 (-15 * ($ $ $)))))))) 
-(-10 -7 (-15 -3755 (|#1| |#1| (-923)))) 
-((-3972 ((|#1| (-307)) 11) (((-1264) |#1|) 9))) 
-(((-1040 |#1|) (-10 -7 (-15 -3972 ((-1264) |#1|)) (-15 -3972 (|#1| (-307)))) (-1204)) (T -1040)) 
-((-3972 (*1 *2 *3) (-12 (-5 *3 (-307)) (-5 *1 (-1040 *2)) (-4 *2 (-1204)))) (-3972 (*1 *2 *3) (-12 (-5 *2 (-1264)) (-5 *1 (-1040 *3)) (-4 *3 (-1204))))) 
-(-10 -7 (-15 -3972 ((-1264) |#1|)) (-15 -3972 (|#1| (-307)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3116 (($ |#4|) 25)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-3111 ((|#4| $) 27)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 46) (($ (-572)) NIL) (($ |#1|) NIL) (($ |#4|) 26)) (-2140 (((-769)) 43)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 21 T CONST)) (-3255 (($) 23 T CONST)) (-1324 (((-121) $ $) 40)) (-1373 (($ $) 31) (($ $ $) NIL)) (-1367 (($ $ $) 29)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 36) (($ $ $) 33) (($ |#1| $) 38) (($ $ |#1|) NIL))) 
-(((-1041 |#1| |#2| |#3| |#4| |#5|) (-13 (-174) (-43 |#1|) (-10 -8 (-15 -3116 ($ |#4|)) (-15 -3972 ($ |#4|)) (-15 -3111 (|#4| $)))) (-368) (-794) (-848) (-956 |#1| |#2| |#3|) (-638 |#4|)) (T -1041)) 
-((-3116 (*1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1041 *3 *4 *5 *2 *6)) (-4 *2 (-956 *3 *4 *5)) (-14 *6 (-638 *2)))) (-3972 (*1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1041 *3 *4 *5 *2 *6)) (-4 *2 (-956 *3 *4 *5)) (-14 *6 (-638 *2)))) (-3111 (*1 *2 *1) (-12 (-4 *2 (-956 *3 *4 *5)) (-5 *1 (-1041 *3 *4 *5 *2 *6)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-14 *6 (-638 *2))))) 
-(-13 (-174) (-43 |#1|) (-10 -8 (-15 -3116 ($ |#4|)) (-15 -3972 ($ |#4|)) (-15 -3111 (|#4| $)))) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL)) (-2430 (((-1264) $ (-1170) (-1170)) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-1806 (((-121) (-121)) 39)) (-1491 (((-121) (-121)) 38)) (-3283 (((-57) $ (-1170) (-57)) NIL)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 (-57) "failed") (-1170) $) NIL)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-1544 (($ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-3 (-57) "failed") (-1170) $) NIL)) (-3445 (($ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-57) $ (-1170) (-57)) NIL (|has| $ (-6 -4603)))) (-4212 (((-57) $ (-1170)) NIL)) (-2010 (((-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-638 (-57)) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-1170) $) NIL (|has| (-1170) (-848)))) (-4467 (((-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-638 (-57)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098))))) (-2026 (((-1170) $) NIL (|has| (-1170) (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4603))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-2760 (((-638 (-1170)) $) 34)) (-2365 (((-121) (-1170) $) NIL)) (-4221 (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL)) (-1335 (($ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL)) (-2739 (((-638 (-1170)) $) NIL)) (-1601 (((-121) (-1170) $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-1837 (((-57) $) NIL (|has| (-1170) (-848)))) (-3361 (((-3 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) "failed") (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL)) (-3299 (($ $ (-57)) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))))) NIL (-12 (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ $ (-290 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL (-12 (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ $ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) NIL (-12 (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ $ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL (-12 (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ $ (-638 (-57)) (-638 (-57))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-290 (-57))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-638 (-290 (-57)))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098))))) (-2957 (((-638 (-57)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 (((-57) $ (-1170)) 35) (((-57) $ (-1170) (-57)) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (((-769) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098)))) (((-769) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL)) (-3972 (((-856) $) 37 (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1042) (-13 (-1181 (-1170) (-57)) (-10 -7 (-15 -1806 ((-121) (-121))) (-15 -1491 ((-121) (-121))) (-6 -4602)))) (T -1042)) 
-((-1806 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1042)))) (-1491 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1042))))) 
-(-13 (-1181 (-1170) (-57)) (-10 -7 (-15 -1806 ((-121) (-121))) (-15 -1491 ((-121) (-121))) (-6 -4602))) 
-((-1318 ((|#2| $) 10))) 
-(((-1043 |#1| |#2|) (-10 -8 (-15 -1318 (|#2| |#1|))) (-1044 |#2|) (-1204)) (T -1043)) 
-NIL 
-(-10 -8 (-15 -1318 (|#2| |#1|))) 
-((-3376 (((-3 |#1| "failed") $) 7)) (-1318 ((|#1| $) 8)) (-3972 (($ |#1|) 6))) 
-(((-1044 |#1|) (-1290) (-1204)) (T -1044)) 
-((-1318 (*1 *2 *1) (-12 (-4 *1 (-1044 *2)) (-4 *2 (-1204)))) (-3376 (*1 *2 *1) (|partial| -12 (-4 *1 (-1044 *2)) (-4 *2 (-1204)))) (-3972 (*1 *1 *2) (-12 (-4 *1 (-1044 *2)) (-4 *2 (-1204))))) 
-(-13 (-10 -8 (-15 -3972 ($ |t#1|)) (-15 -3376 ((-3 |t#1| "failed") $)) (-15 -1318 (|t#1| $)))) 
-((-2175 (((-638 (-638 (-290 (-413 (-959 |#2|))))) (-638 (-959 |#2|)) (-638 (-1170))) 35))) 
-(((-1045 |#1| |#2|) (-10 -7 (-15 -2175 ((-638 (-638 (-290 (-413 (-959 |#2|))))) (-638 (-959 |#2|)) (-638 (-1170))))) (-562) (-13 (-562) (-1044 |#1|))) (T -1045)) 
-((-2175 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *6))) (-5 *4 (-638 (-1170))) (-4 *6 (-13 (-562) (-1044 *5))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *6)))))) (-5 *1 (-1045 *5 *6))))) 
-(-10 -7 (-15 -2175 ((-638 (-638 (-290 (-413 (-959 |#2|))))) (-638 (-959 |#2|)) (-638 (-1170))))) 
-((-2615 (((-385)) 15)) (-1350 (((-1 (-385)) (-385) (-385)) 20)) (-3512 (((-1 (-385)) (-769)) 42)) (-1555 (((-385)) 33)) (-2071 (((-1 (-385)) (-385) (-385)) 34)) (-2168 (((-385)) 26)) (-3703 (((-1 (-385)) (-385)) 27)) (-1378 (((-385) (-769)) 37)) (-2006 (((-1 (-385)) (-769)) 38)) (-3313 (((-1 (-385)) (-769) (-769)) 41)) (-1869 (((-1 (-385)) (-769) (-769)) 39))) 
-(((-1046) (-10 -7 (-15 -2615 ((-385))) (-15 -1555 ((-385))) (-15 -2168 ((-385))) (-15 -1378 ((-385) (-769))) (-15 -1350 ((-1 (-385)) (-385) (-385))) (-15 -2071 ((-1 (-385)) (-385) (-385))) (-15 -3703 ((-1 (-385)) (-385))) (-15 -2006 ((-1 (-385)) (-769))) (-15 -1869 ((-1 (-385)) (-769) (-769))) (-15 -3313 ((-1 (-385)) (-769) (-769))) (-15 -3512 ((-1 (-385)) (-769))))) (T -1046)) 
-((-3512 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-385))) (-5 *1 (-1046)))) (-3313 (*1 *2 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-385))) (-5 *1 (-1046)))) (-1869 (*1 *2 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-385))) (-5 *1 (-1046)))) (-2006 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-385))) (-5 *1 (-1046)))) (-3703 (*1 *2 *3) (-12 (-5 *2 (-1 (-385))) (-5 *1 (-1046)) (-5 *3 (-385)))) (-2071 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-385))) (-5 *1 (-1046)) (-5 *3 (-385)))) (-1350 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-385))) (-5 *1 (-1046)) (-5 *3 (-385)))) (-1378 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-385)) (-5 *1 (-1046)))) (-2168 (*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1046)))) (-1555 (*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1046)))) (-2615 (*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1046))))) 
-(-10 -7 (-15 -2615 ((-385))) (-15 -1555 ((-385))) (-15 -2168 ((-385))) (-15 -1378 ((-385) (-769))) (-15 -1350 ((-1 (-385)) (-385) (-385))) (-15 -2071 ((-1 (-385)) (-385) (-385))) (-15 -3703 ((-1 (-385)) (-385))) (-15 -2006 ((-1 (-385)) (-769))) (-15 -1869 ((-1 (-385)) (-769) (-769))) (-15 -3313 ((-1 (-385)) (-769) (-769))) (-15 -3512 ((-1 (-385)) (-769)))) 
-((-4304 (((-424 |#1|) |#1|) 31))) 
-(((-1047 |#1|) (-10 -7 (-15 -4304 ((-424 |#1|) |#1|))) (-1234 (-413 (-959 (-572))))) (T -1047)) 
-((-4304 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1047 *3)) (-4 *3 (-1234 (-413 (-959 (-572)))))))) 
-(-10 -7 (-15 -4304 ((-424 |#1|) |#1|))) 
-((-2016 (((-413 (-424 (-959 |#1|))) (-413 (-959 |#1|))) 14))) 
-(((-1048 |#1|) (-10 -7 (-15 -2016 ((-413 (-424 (-959 |#1|))) (-413 (-959 |#1|))))) (-303)) (T -1048)) 
-((-2016 (*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-303)) (-5 *2 (-413 (-424 (-959 *4)))) (-5 *1 (-1048 *4))))) 
-(-10 -7 (-15 -2016 ((-413 (-424 (-959 |#1|))) (-413 (-959 |#1|))))) 
-((-3456 (((-638 (-1170)) (-413 (-959 |#1|))) 15)) (-4297 (((-413 (-1166 (-413 (-959 |#1|)))) (-413 (-959 |#1|)) (-1170)) 22)) (-4335 (((-413 (-959 |#1|)) (-413 (-1166 (-413 (-959 |#1|)))) (-1170)) 24)) (-1470 (((-3 (-1170) "failed") (-413 (-959 |#1|))) 18)) (-4485 (((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-638 (-290 (-413 (-959 |#1|))))) 29) (((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|)))) 31) (((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-638 (-1170)) (-638 (-413 (-959 |#1|)))) 26) (((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|))) 27)) (-3972 (((-413 (-959 |#1|)) |#1|) 11))) 
-(((-1049 |#1|) (-10 -7 (-15 -3456 ((-638 (-1170)) (-413 (-959 |#1|)))) (-15 -1470 ((-3 (-1170) "failed") (-413 (-959 |#1|)))) (-15 -4297 ((-413 (-1166 (-413 (-959 |#1|)))) (-413 (-959 |#1|)) (-1170))) (-15 -4335 ((-413 (-959 |#1|)) (-413 (-1166 (-413 (-959 |#1|)))) (-1170))) (-15 -4485 ((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|)))) (-15 -4485 ((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-638 (-1170)) (-638 (-413 (-959 |#1|))))) (-15 -4485 ((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))))) (-15 -4485 ((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-638 (-290 (-413 (-959 |#1|)))))) (-15 -3972 ((-413 (-959 |#1|)) |#1|))) (-562)) (T -1049)) 
-((-3972 (*1 *2 *3) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-1049 *3)) (-4 *3 (-562)))) (-4485 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-290 (-413 (-959 *4))))) (-5 *2 (-413 (-959 *4))) (-4 *4 (-562)) (-5 *1 (-1049 *4)))) (-4485 (*1 *2 *2 *3) (-12 (-5 *3 (-290 (-413 (-959 *4)))) (-5 *2 (-413 (-959 *4))) (-4 *4 (-562)) (-5 *1 (-1049 *4)))) (-4485 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-638 (-1170))) (-5 *4 (-638 (-413 (-959 *5)))) (-5 *2 (-413 (-959 *5))) (-4 *5 (-562)) (-5 *1 (-1049 *5)))) (-4485 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-413 (-959 *4))) (-5 *3 (-1170)) (-4 *4 (-562)) (-5 *1 (-1049 *4)))) (-4335 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-1166 (-413 (-959 *5))))) (-5 *4 (-1170)) (-5 *2 (-413 (-959 *5))) (-5 *1 (-1049 *5)) (-4 *5 (-562)))) (-4297 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-562)) (-5 *2 (-413 (-1166 (-413 (-959 *5))))) (-5 *1 (-1049 *5)) (-5 *3 (-413 (-959 *5))))) (-1470 (*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-5 *2 (-1170)) (-5 *1 (-1049 *4)))) (-3456 (*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-5 *2 (-638 (-1170))) (-5 *1 (-1049 *4))))) 
-(-10 -7 (-15 -3456 ((-638 (-1170)) (-413 (-959 |#1|)))) (-15 -1470 ((-3 (-1170) "failed") (-413 (-959 |#1|)))) (-15 -4297 ((-413 (-1166 (-413 (-959 |#1|)))) (-413 (-959 |#1|)) (-1170))) (-15 -4335 ((-413 (-959 |#1|)) (-413 (-1166 (-413 (-959 |#1|)))) (-1170))) (-15 -4485 ((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|)))) (-15 -4485 ((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-638 (-1170)) (-638 (-413 (-959 |#1|))))) (-15 -4485 ((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-290 (-413 (-959 |#1|))))) (-15 -4485 ((-413 (-959 |#1|)) (-413 (-959 |#1|)) (-638 (-290 (-413 (-959 |#1|)))))) (-15 -3972 ((-413 (-959 |#1|)) |#1|))) 
-((-3503 (((-638 |#1|) (-638 |#1|)) 45)) (-2233 (((-638 |#1|)) 9)) (-4311 (((-2 (|:| |zeros| (-638 |#1|)) (|:| -3818 (-572))) (-1166 |#1|) |#1|) 19)) (-2841 (((-2 (|:| |zeros| (-638 |#1|)) (|:| -3818 (-572))) (-638 (-1166 |#1|)) |#1|) 37))) 
-(((-1050 |#1|) (-10 -7 (-15 -4311 ((-2 (|:| |zeros| (-638 |#1|)) (|:| -3818 (-572))) (-1166 |#1|) |#1|)) (-15 -2841 ((-2 (|:| |zeros| (-638 |#1|)) (|:| -3818 (-572))) (-638 (-1166 |#1|)) |#1|)) (-15 -2233 ((-638 |#1|))) (-15 -3503 ((-638 |#1|) (-638 |#1|)))) (-368)) (T -1050)) 
-((-3503 (*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-5 *1 (-1050 *3)))) (-2233 (*1 *2) (-12 (-5 *2 (-638 *3)) (-5 *1 (-1050 *3)) (-4 *3 (-368)))) (-2841 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1166 *4))) (-4 *4 (-368)) (-5 *2 (-2 (|:| |zeros| (-638 *4)) (|:| -3818 (-572)))) (-5 *1 (-1050 *4)))) (-4311 (*1 *2 *3 *4) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-368)) (-5 *2 (-2 (|:| |zeros| (-638 *4)) (|:| -3818 (-572)))) (-5 *1 (-1050 *4))))) 
-(-10 -7 (-15 -4311 ((-2 (|:| |zeros| (-638 |#1|)) (|:| -3818 (-572))) (-1166 |#1|) |#1|)) (-15 -2841 ((-2 (|:| |zeros| (-638 |#1|)) (|:| -3818 (-572))) (-638 (-1166 |#1|)) |#1|)) (-15 -2233 ((-638 |#1|))) (-15 -3503 ((-638 |#1|) (-638 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 (-781 |#1| (-858 |#2|)))))) (-638 (-781 |#1| (-858 |#2|)))) NIL)) (-4165 (((-638 $) (-638 (-781 |#1| (-858 |#2|)))) NIL) (((-638 $) (-638 (-781 |#1| (-858 |#2|))) (-121)) NIL) (((-638 $) (-638 (-781 |#1| (-858 |#2|))) (-121) (-121)) NIL)) (-3456 (((-638 (-858 |#2|)) $) NIL)) (-3049 (((-121) $) NIL)) (-3289 (((-121) $) NIL (|has| |#1| (-562)))) (-3366 (((-121) (-781 |#1| (-858 |#2|)) $) NIL) (((-121) $) NIL)) (-1872 (((-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) $) NIL)) (-2844 (((-638 (-2 (|:| |val| (-781 |#1| (-858 |#2|))) (|:| -1337 $))) (-781 |#1| (-858 |#2|)) $) NIL)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ (-858 |#2|)) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2561 (($ (-1 (-121) (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-3 (-781 |#1| (-858 |#2|)) "failed") $ (-858 |#2|)) NIL)) (-2211 (($) NIL T CONST)) (-3097 (((-121) $) NIL (|has| |#1| (-562)))) (-3760 (((-121) $ $) NIL (|has| |#1| (-562)))) (-3819 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4331 (((-121) $) NIL (|has| |#1| (-562)))) (-4577 (((-638 (-781 |#1| (-858 |#2|))) (-638 (-781 |#1| (-858 |#2|))) $ (-1 (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) (-1 (-121) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)))) NIL)) (-3683 (((-638 (-781 |#1| (-858 |#2|))) (-638 (-781 |#1| (-858 |#2|))) $) NIL (|has| |#1| (-562)))) (-2320 (((-638 (-781 |#1| (-858 |#2|))) (-638 (-781 |#1| (-858 |#2|))) $) NIL (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 (-781 |#1| (-858 |#2|)))) NIL)) (-1318 (($ (-638 (-781 |#1| (-858 |#2|)))) NIL)) (-1651 (((-3 $ "failed") $) NIL)) (-2242 (((-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-781 |#1| (-858 |#2|)) (-1098))))) (-3445 (($ (-781 |#1| (-858 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-781 |#1| (-858 |#2|)) (-1098)))) (($ (-1 (-121) (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| (-781 |#1| (-858 |#2|))) (|:| |den| |#1|)) (-781 |#1| (-858 |#2|)) $) NIL (|has| |#1| (-562)))) (-2240 (((-121) (-781 |#1| (-858 |#2|)) $ (-1 (-121) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)))) NIL)) (-1673 (((-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) $) NIL)) (-3116 (((-781 |#1| (-858 |#2|)) (-1 (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) $ (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-781 |#1| (-858 |#2|)) (-1098)))) (((-781 |#1| (-858 |#2|)) (-1 (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) $ (-781 |#1| (-858 |#2|))) NIL (|has| $ (-6 -4602))) (((-781 |#1| (-858 |#2|)) (-1 (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) $ (-1 (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) (-1 (-121) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)))) NIL)) (-3725 (((-2 (|:| -2371 (-638 (-781 |#1| (-858 |#2|)))) (|:| -1428 (-638 (-781 |#1| (-858 |#2|))))) $) NIL)) (-1706 (((-121) (-781 |#1| (-858 |#2|)) $) NIL)) (-2989 (((-121) (-781 |#1| (-858 |#2|)) $) NIL)) (-1366 (((-121) (-781 |#1| (-858 |#2|)) $) NIL) (((-121) $) NIL)) (-2010 (((-638 (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3824 (((-121) (-781 |#1| (-858 |#2|)) $) NIL) (((-121) $) NIL)) (-1792 (((-858 |#2|) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-781 |#1| (-858 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-781 |#1| (-858 |#2|)) (-1098))))) (-2435 (($ (-1 (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) $) NIL)) (-4062 (((-638 (-858 |#2|)) $) NIL)) (-1346 (((-121) (-858 |#2|) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2550 (((-3 (-781 |#1| (-858 |#2|)) (-638 $)) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) $) NIL)) (-4416 (((-638 (-2 (|:| |val| (-781 |#1| (-858 |#2|))) (|:| -1337 $))) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) $) NIL)) (-3253 (((-3 (-781 |#1| (-858 |#2|)) "failed") $) NIL)) (-2173 (((-638 $) (-781 |#1| (-858 |#2|)) $) NIL)) (-2471 (((-3 (-121) (-638 $)) (-781 |#1| (-858 |#2|)) $) NIL)) (-2338 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 $))) (-781 |#1| (-858 |#2|)) $) NIL) (((-121) (-781 |#1| (-858 |#2|)) $) NIL)) (-1931 (((-638 $) (-781 |#1| (-858 |#2|)) $) NIL) (((-638 $) (-638 (-781 |#1| (-858 |#2|))) $) NIL) (((-638 $) (-638 (-781 |#1| (-858 |#2|))) (-638 $)) NIL) (((-638 $) (-781 |#1| (-858 |#2|)) (-638 $)) NIL)) (-3078 (($ (-781 |#1| (-858 |#2|)) $) NIL) (($ (-638 (-781 |#1| (-858 |#2|))) $) NIL)) (-3727 (((-638 (-781 |#1| (-858 |#2|))) $) NIL)) (-1483 (((-121) (-781 |#1| (-858 |#2|)) $) NIL) (((-121) $) NIL)) (-2788 (((-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) $) NIL)) (-1843 (((-121) $ $) NIL)) (-2566 (((-2 (|:| |num| (-781 |#1| (-858 |#2|))) (|:| |den| |#1|)) (-781 |#1| (-858 |#2|)) $) NIL (|has| |#1| (-562)))) (-1994 (((-121) (-781 |#1| (-858 |#2|)) $) NIL) (((-121) $) NIL)) (-4498 (((-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)) $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-3 (-781 |#1| (-858 |#2|)) "failed") $) NIL)) (-3361 (((-3 (-781 |#1| (-858 |#2|)) "failed") (-1 (-121) (-781 |#1| (-858 |#2|))) $) NIL)) (-1928 (((-3 $ "failed") $ (-781 |#1| (-858 |#2|))) NIL)) (-1977 (($ $ (-781 |#1| (-858 |#2|))) NIL) (((-638 $) (-781 |#1| (-858 |#2|)) $) NIL) (((-638 $) (-781 |#1| (-858 |#2|)) (-638 $)) NIL) (((-638 $) (-638 (-781 |#1| (-858 |#2|))) $) NIL) (((-638 $) (-638 (-781 |#1| (-858 |#2|))) (-638 $)) NIL)) (-2109 (((-121) (-1 (-121) (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-781 |#1| (-858 |#2|))) (-638 (-781 |#1| (-858 |#2|)))) NIL (-12 (|has| (-781 |#1| (-858 |#2|)) (-305 (-781 |#1| (-858 |#2|)))) (|has| (-781 |#1| (-858 |#2|)) (-1098)))) (($ $ (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|))) NIL (-12 (|has| (-781 |#1| (-858 |#2|)) (-305 (-781 |#1| (-858 |#2|)))) (|has| (-781 |#1| (-858 |#2|)) (-1098)))) (($ $ (-290 (-781 |#1| (-858 |#2|)))) NIL (-12 (|has| (-781 |#1| (-858 |#2|)) (-305 (-781 |#1| (-858 |#2|)))) (|has| (-781 |#1| (-858 |#2|)) (-1098)))) (($ $ (-638 (-290 (-781 |#1| (-858 |#2|))))) NIL (-12 (|has| (-781 |#1| (-858 |#2|)) (-305 (-781 |#1| (-858 |#2|)))) (|has| (-781 |#1| (-858 |#2|)) (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-4316 (((-769) $) NIL)) (-1571 (((-769) (-781 |#1| (-858 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-781 |#1| (-858 |#2|)) (-1098)))) (((-769) (-1 (-121) (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-781 |#1| (-858 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-781 |#1| (-858 |#2|)))) NIL)) (-1826 (($ $ (-858 |#2|)) NIL)) (-2291 (($ $ (-858 |#2|)) NIL)) (-3134 (($ $) NIL)) (-1650 (($ $ (-858 |#2|)) NIL)) (-3972 (((-856) $) NIL) (((-638 (-781 |#1| (-858 |#2|))) $) NIL)) (-2498 (((-769) $) NIL (|has| (-858 |#2|) (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 (-781 |#1| (-858 |#2|))))) "failed") (-638 (-781 |#1| (-858 |#2|))) (-1 (-121) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)))) NIL) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 (-781 |#1| (-858 |#2|))))) "failed") (-638 (-781 |#1| (-858 |#2|))) (-1 (-121) (-781 |#1| (-858 |#2|))) (-1 (-121) (-781 |#1| (-858 |#2|)) (-781 |#1| (-858 |#2|)))) NIL)) (-2057 (((-121) $ (-1 (-121) (-781 |#1| (-858 |#2|)) (-638 (-781 |#1| (-858 |#2|))))) NIL)) (-2589 (((-638 $) (-781 |#1| (-858 |#2|)) $) NIL) (((-638 $) (-781 |#1| (-858 |#2|)) (-638 $)) NIL) (((-638 $) (-638 (-781 |#1| (-858 |#2|))) $) NIL) (((-638 $) (-638 (-781 |#1| (-858 |#2|))) (-638 $)) NIL)) (-3501 (((-121) (-1 (-121) (-781 |#1| (-858 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1502 (((-638 (-858 |#2|)) $) NIL)) (-4191 (((-121) (-781 |#1| (-858 |#2|)) $) NIL)) (-2213 (((-121) (-858 |#2|) $) NIL)) (-1324 (((-121) $ $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1051 |#1| |#2|) (-13 (-1073 |#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|))) (-10 -8 (-15 -4165 ((-638 $) (-638 (-781 |#1| (-858 |#2|))) (-121) (-121))))) (-457) (-638 (-1170))) (T -1051)) 
-((-4165 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-1051 *5 *6))))) 
-(-13 (-1073 |#1| (-538 (-858 |#2|)) (-858 |#2|) (-781 |#1| (-858 |#2|))) (-10 -8 (-15 -4165 ((-638 $) (-638 (-781 |#1| (-858 |#2|))) (-121) (-121))))) 
-((-1350 (((-1 (-572)) (-1092 (-572))) 33)) (-4427 (((-572) (-572) (-572) (-572) (-572)) 30)) (-2431 (((-1 (-572)) |RationalNumber|) NIL)) (-3265 (((-1 (-572)) |RationalNumber|) NIL)) (-3610 (((-1 (-572)) (-572) |RationalNumber|) NIL))) 
-(((-1052) (-10 -7 (-15 -1350 ((-1 (-572)) (-1092 (-572)))) (-15 -3610 ((-1 (-572)) (-572) |RationalNumber|)) (-15 -2431 ((-1 (-572)) |RationalNumber|)) (-15 -3265 ((-1 (-572)) |RationalNumber|)) (-15 -4427 ((-572) (-572) (-572) (-572) (-572))))) (T -1052)) 
-((-4427 (*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1052)))) (-3265 (*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-572))) (-5 *1 (-1052)))) (-2431 (*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-572))) (-5 *1 (-1052)))) (-3610 (*1 *2 *3 *4) (-12 (-5 *4 |RationalNumber|) (-5 *2 (-1 (-572))) (-5 *1 (-1052)) (-5 *3 (-572)))) (-1350 (*1 *2 *3) (-12 (-5 *3 (-1092 (-572))) (-5 *2 (-1 (-572))) (-5 *1 (-1052))))) 
-(-10 -7 (-15 -1350 ((-1 (-572)) (-1092 (-572)))) (-15 -3610 ((-1 (-572)) (-572) |RationalNumber|)) (-15 -2431 ((-1 (-572)) |RationalNumber|)) (-15 -3265 ((-1 (-572)) |RationalNumber|)) (-15 -4427 ((-572) (-572) (-572) (-572) (-572)))) 
-((-3972 (((-856) $) NIL) (($ (-572)) 10))) 
-(((-1053 |#1|) (-10 -8 (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) (-1054)) (T -1053)) 
-NIL 
-(-10 -8 (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-1054) (-1290)) (T -1054)) 
-((-2140 (*1 *2) (-12 (-4 *1 (-1054)) (-5 *2 (-769)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1054))))) 
-(-13 (-1061) (-722) (-641 $) (-10 -8 (-15 -2140 ((-769))) (-15 -3972 ($ (-572))) (-6 -4599))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 $) . T) ((-722) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-4435 (((-413 (-959 |#2|)) (-638 |#2|) (-638 |#2|) (-769) (-769)) 45))) 
-(((-1055 |#1| |#2|) (-10 -7 (-15 -4435 ((-413 (-959 |#2|)) (-638 |#2|) (-638 |#2|) (-769) (-769)))) (-1170) (-368)) (T -1055)) 
-((-4435 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-769)) (-4 *6 (-368)) (-5 *2 (-413 (-959 *6))) (-5 *1 (-1055 *5 *6)) (-14 *5 (-1170))))) 
-(-10 -7 (-15 -4435 ((-413 (-959 |#2|)) (-638 |#2|) (-638 |#2|) (-769) (-769)))) 
-((-3083 (((-121) $) 27)) (-4044 (((-121) $) 16)) (-3704 (((-769) $) 13)) (-3712 (((-769) $) 14)) (-3785 (((-121) $) 25)) (-3354 (((-121) $) 29))) 
-(((-1056 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -8 (-15 -3712 ((-769) |#1|)) (-15 -3704 ((-769) |#1|)) (-15 -3354 ((-121) |#1|)) (-15 -3083 ((-121) |#1|)) (-15 -3785 ((-121) |#1|)) (-15 -4044 ((-121) |#1|))) (-1057 |#2| |#3| |#4| |#5| |#6|) (-769) (-769) (-1054) (-232 |#3| |#4|) (-232 |#2| |#4|)) (T -1056)) 
-NIL 
-(-10 -8 (-15 -3712 ((-769) |#1|)) (-15 -3704 ((-769) |#1|)) (-15 -3354 ((-121) |#1|)) (-15 -3083 ((-121) |#1|)) (-15 -3785 ((-121) |#1|)) (-15 -4044 ((-121) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3083 (((-121) $) 48)) (-1572 (((-3 $ "failed") $ $) 18)) (-4044 (((-121) $) 50)) (-1946 (((-121) $ (-769)) 58)) (-2211 (($) 16 T CONST)) (-3292 (($ $) 31 (|has| |#3| (-303)))) (-4267 ((|#4| $ (-572)) 36)) (-2667 (((-769) $) 30 (|has| |#3| (-562)))) (-4212 ((|#3| $ (-572) (-572)) 38)) (-2010 (((-638 |#3|) $) 65 (|has| $ (-6 -4602)))) (-3095 (((-769) $) 29 (|has| |#3| (-562)))) (-1301 (((-638 |#5|) $) 28 (|has| |#3| (-562)))) (-3704 (((-769) $) 42)) (-3712 (((-769) $) 41)) (-2157 (((-121) $ (-769)) 57)) (-2660 (((-572) $) 46)) (-3092 (((-572) $) 44)) (-4467 (((-638 |#3|) $) 66 (|has| $ (-6 -4602)))) (-3002 (((-121) |#3| $) 68 (-12 (|has| |#3| (-1098)) (|has| $ (-6 -4602))))) (-3927 (((-572) $) 45)) (-3227 (((-572) $) 43)) (-3597 (($ (-638 (-638 |#3|))) 51)) (-2435 (($ (-1 |#3| |#3|) $) 61 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#3| |#3|) $) 60) (($ (-1 |#3| |#3| |#3|) $ $) 34)) (-2259 (((-638 (-638 |#3|)) $) 40)) (-3524 (((-121) $ (-769)) 56)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ |#3|) 33 (|has| |#3| (-562)))) (-2109 (((-121) (-1 (-121) |#3|) $) 63 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#3|) (-638 |#3|)) 72 (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ |#3| |#3|) 71 (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ (-290 |#3|)) 70 (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ (-638 (-290 |#3|))) 69 (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098))))) (-3598 (((-121) $ $) 52)) (-4037 (((-121) $) 55)) (-1665 (($) 54)) (-3277 ((|#3| $ (-572) (-572)) 39) ((|#3| $ (-572) (-572) |#3|) 37)) (-3785 (((-121) $) 49)) (-1571 (((-769) |#3| $) 67 (-12 (|has| |#3| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#3|) $) 64 (|has| $ (-6 -4602)))) (-1607 (($ $) 53)) (-4580 ((|#5| $ (-572)) 35)) (-3972 (((-856) $) 11)) (-3501 (((-121) (-1 (-121) |#3|) $) 62 (|has| $ (-6 -4602)))) (-3354 (((-121) $) 47)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#3|) 32 (|has| |#3| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ |#3| $) 22) (($ $ |#3|) 24)) (-4032 (((-769) $) 59 (|has| $ (-6 -4602))))) 
-(((-1057 |#1| |#2| |#3| |#4| |#5|) (-1290) (-769) (-769) (-1054) (-232 |t#2| |t#3|) (-232 |t#1| |t#3|)) (T -1057)) 
-((-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *5 *5)) (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)))) (-3597 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 *5))) (-4 *5 (-1054)) (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)))) (-4044 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-121)))) (-3785 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-121)))) (-3083 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-121)))) (-3354 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-121)))) (-2660 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-572)))) (-3927 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-572)))) (-3092 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-572)))) (-3227 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-572)))) (-3704 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-769)))) (-3712 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-769)))) (-2259 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-638 (-638 *5))))) (-3277 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *2 *6 *7)) (-4 *6 (-232 *5 *2)) (-4 *7 (-232 *4 *2)) (-4 *2 (-1054)))) (-4212 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *2 *6 *7)) (-4 *6 (-232 *5 *2)) (-4 *7 (-232 *4 *2)) (-4 *2 (-1054)))) (-3277 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *2 *6 *7)) (-4 *2 (-1054)) (-4 *6 (-232 *5 *2)) (-4 *7 (-232 *4 *2)))) (-4267 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *6 *2 *7)) (-4 *6 (-1054)) (-4 *7 (-232 *4 *6)) (-4 *2 (-232 *5 *6)))) (-4580 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *6 *7 *2)) (-4 *6 (-1054)) (-4 *7 (-232 *5 *6)) (-4 *2 (-232 *4 *6)))) (-3828 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *5 *5 *5)) (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)))) (-1803 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1057 *3 *4 *2 *5 *6)) (-4 *2 (-1054)) (-4 *5 (-232 *4 *2)) (-4 *6 (-232 *3 *2)) (-4 *2 (-562)))) (-1379 (*1 *1 *1 *2) (-12 (-4 *1 (-1057 *3 *4 *2 *5 *6)) (-4 *2 (-1054)) (-4 *5 (-232 *4 *2)) (-4 *6 (-232 *3 *2)) (-4 *2 (-368)))) (-3292 (*1 *1 *1) (-12 (-4 *1 (-1057 *2 *3 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-232 *3 *4)) (-4 *6 (-232 *2 *4)) (-4 *4 (-303)))) (-2667 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-4 *5 (-562)) (-5 *2 (-769)))) (-3095 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-4 *5 (-562)) (-5 *2 (-769)))) (-1301 (*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-4 *5 (-562)) (-5 *2 (-638 *7))))) 
-(-13 (-120 |t#3| |t#3|) (-503 |t#3|) (-10 -8 (-6 -4602) (IF (|has| |t#3| (-174)) (-6 (-713 |t#3|)) |noBranch|) (-15 -3597 ($ (-638 (-638 |t#3|)))) (-15 -4044 ((-121) $)) (-15 -3785 ((-121) $)) (-15 -3083 ((-121) $)) (-15 -3354 ((-121) $)) (-15 -2660 ((-572) $)) (-15 -3927 ((-572) $)) (-15 -3092 ((-572) $)) (-15 -3227 ((-572) $)) (-15 -3704 ((-769) $)) (-15 -3712 ((-769) $)) (-15 -2259 ((-638 (-638 |t#3|)) $)) (-15 -3277 (|t#3| $ (-572) (-572))) (-15 -4212 (|t#3| $ (-572) (-572))) (-15 -3277 (|t#3| $ (-572) (-572) |t#3|)) (-15 -4267 (|t#4| $ (-572))) (-15 -4580 (|t#5| $ (-572))) (-15 -3828 ($ (-1 |t#3| |t#3|) $)) (-15 -3828 ($ (-1 |t#3| |t#3| |t#3|) $ $)) (IF (|has| |t#3| (-562)) (-15 -1803 ((-3 $ "failed") $ |t#3|)) |noBranch|) (IF (|has| |t#3| (-368)) (-15 -1379 ($ $ |t#3|)) |noBranch|) (IF (|has| |t#3| (-303)) (-15 -3292 ($ $)) |noBranch|) (IF (|has| |t#3| (-562)) (PROGN (-15 -2667 ((-769) $)) (-15 -3095 ((-769) $)) (-15 -1301 ((-638 |t#5|) $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-39) . T) ((-105) . T) ((-120 |#3| |#3|) . T) ((-138) . T) ((-612 (-856)) . T) ((-305 |#3|) -12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098))) ((-503 |#3|) . T) ((-527 |#3| |#3|) -12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098))) ((-641 |#3|) . T) ((-713 |#3|) |has| |#3| (-174)) ((-1060 |#3|) . T) ((-1098) . T) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3083 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) 40 (|has| |#3| (-303)))) (-4267 (((-234 |#2| |#3|) $ (-572)) 29)) (-2003 (($ (-685 |#3|)) 38)) (-2667 (((-769) $) 42 (|has| |#3| (-562)))) (-4212 ((|#3| $ (-572) (-572)) NIL)) (-2010 (((-638 |#3|) $) NIL (|has| $ (-6 -4602)))) (-3095 (((-769) $) 44 (|has| |#3| (-562)))) (-1301 (((-638 (-234 |#1| |#3|)) $) 48 (|has| |#3| (-562)))) (-3704 (((-769) $) NIL)) (-3712 (((-769) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-2660 (((-572) $) NIL)) (-3092 (((-572) $) NIL)) (-4467 (((-638 |#3|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#3| (-1098))))) (-3927 (((-572) $) NIL)) (-3227 (((-572) $) NIL)) (-3597 (($ (-638 (-638 |#3|))) 24)) (-2435 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#3| |#3|) $) NIL) (($ (-1 |#3| |#3| |#3|) $ $) NIL)) (-2259 (((-638 (-638 |#3|)) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ |#3|) NIL (|has| |#3| (-562)))) (-2109 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#3|) (-638 |#3|)) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ (-290 |#3|)) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ (-638 (-290 |#3|))) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#3| $ (-572) (-572)) NIL) ((|#3| $ (-572) (-572) |#3|) NIL)) (-2502 (((-140)) 51 (|has| |#3| (-368)))) (-3785 (((-121) $) NIL)) (-1571 (((-769) |#3| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#3| (-1098)))) (((-769) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) 60 (|has| |#3| (-613 (-545))))) (-4580 (((-234 |#1| |#3|) $ (-572)) 33)) (-3972 (((-856) $) 16) (((-685 |#3|) $) 35)) (-3501 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-2378 (($) 13 T CONST)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#3|) NIL (|has| |#3| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ |#3| $) NIL) (($ $ |#3|) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1058 |#1| |#2| |#3|) (-13 (-1057 |#1| |#2| |#3| (-234 |#2| |#3|) (-234 |#1| |#3|)) (-612 (-685 |#3|)) (-10 -8 (IF (|has| |#3| (-368)) (-6 (-1266 |#3|)) |noBranch|) (IF (|has| |#3| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (-15 -2003 ($ (-685 |#3|))) (-15 -3972 ((-685 |#3|) $)))) (-769) (-769) (-1054)) (T -1058)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-685 *5)) (-5 *1 (-1058 *3 *4 *5)) (-14 *3 (-769)) (-14 *4 (-769)) (-4 *5 (-1054)))) (-2003 (*1 *1 *2) (-12 (-5 *2 (-685 *5)) (-4 *5 (-1054)) (-5 *1 (-1058 *3 *4 *5)) (-14 *3 (-769)) (-14 *4 (-769))))) 
-(-13 (-1057 |#1| |#2| |#3| (-234 |#2| |#3|) (-234 |#1| |#3|)) (-612 (-685 |#3|)) (-10 -8 (IF (|has| |#3| (-368)) (-6 (-1266 |#3|)) |noBranch|) (IF (|has| |#3| (-613 (-545))) (-6 (-613 (-545))) |noBranch|) (-15 -2003 ($ (-685 |#3|))) (-15 -3972 ((-685 |#3|) $)))) 
-((-3116 ((|#7| (-1 |#7| |#3| |#7|) |#6| |#7|) 34)) (-3828 ((|#10| (-1 |#7| |#3|) |#6|) 32))) 
-(((-1059 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10|) (-10 -7 (-15 -3828 (|#10| (-1 |#7| |#3|) |#6|)) (-15 -3116 (|#7| (-1 |#7| |#3| |#7|) |#6| |#7|))) (-769) (-769) (-1054) (-232 |#2| |#3|) (-232 |#1| |#3|) (-1057 |#1| |#2| |#3| |#4| |#5|) (-1054) (-232 |#2| |#7|) (-232 |#1| |#7|) (-1057 |#1| |#2| |#7| |#8| |#9|)) (T -1059)) 
-((-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *7 *2)) (-4 *7 (-1054)) (-4 *2 (-1054)) (-14 *5 (-769)) (-14 *6 (-769)) (-4 *8 (-232 *6 *7)) (-4 *9 (-232 *5 *7)) (-4 *10 (-232 *6 *2)) (-4 *11 (-232 *5 *2)) (-5 *1 (-1059 *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (-4 *4 (-1057 *5 *6 *7 *8 *9)) (-4 *12 (-1057 *5 *6 *2 *10 *11)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *10 *7)) (-4 *7 (-1054)) (-4 *10 (-1054)) (-14 *5 (-769)) (-14 *6 (-769)) (-4 *8 (-232 *6 *7)) (-4 *9 (-232 *5 *7)) (-4 *2 (-1057 *5 *6 *10 *11 *12)) (-5 *1 (-1059 *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (-4 *4 (-1057 *5 *6 *7 *8 *9)) (-4 *11 (-232 *6 *10)) (-4 *12 (-232 *5 *10))))) 
-(-10 -7 (-15 -3828 (|#10| (-1 |#7| |#3|) |#6|)) (-15 -3116 (|#7| (-1 |#7| |#3| |#7|) |#6| |#7|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ |#1|) 22))) 
-(((-1060 |#1|) (-1290) (-1061)) (T -1060)) 
-((* (*1 *1 *1 *2) (-12 (-4 *1 (-1060 *2)) (-4 *2 (-1061))))) 
+((-1868 (($ $ (-1111 $)) 7) (($ $ (-1191)) 6))) 
+(((-987) (-1311)) (T -987)) 
+((-1868 (*1 *1 *1 *2) (-12 (-5 *2 (-1111 *1)) (-4 *1 (-987)))) (-1868 (*1 *1 *1 *2) (-12 (-4 *1 (-987)) (-5 *2 (-1191))))) 
+(-13 (-10 -8 (-15 -1868 ($ $ (-1191))) (-15 -1868 ($ $ (-1111 $))))) 
+((-2667 (((-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 |#1|))) (|:| |prim| (-1187 |#1|))) (-658 (-980 |#1|)) (-658 (-1191)) (-1191)) 23) (((-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 |#1|))) (|:| |prim| (-1187 |#1|))) (-658 (-980 |#1|)) (-658 (-1191))) 24) (((-2 (|:| |coef1| (-592)) (|:| |coef2| (-592)) (|:| |prim| (-1187 |#1|))) (-980 |#1|) (-1191) (-980 |#1|) (-1191)) 41))) 
+(((-988 |#1|) (-10 -7 (-15 -2667 ((-2 (|:| |coef1| (-592)) (|:| |coef2| (-592)) (|:| |prim| (-1187 |#1|))) (-980 |#1|) (-1191) (-980 |#1|) (-1191))) (-15 -2667 ((-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 |#1|))) (|:| |prim| (-1187 |#1|))) (-658 (-980 |#1|)) (-658 (-1191)))) (-15 -2667 ((-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 |#1|))) (|:| |prim| (-1187 |#1|))) (-658 (-980 |#1|)) (-658 (-1191)) (-1191)))) (-13 (-388) (-171))) (T -988)) 
+((-2667 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-980 *6))) (-5 *4 (-658 (-1191))) (-5 *5 (-1191)) (-4 *6 (-13 (-388) (-171))) (-5 *2 (-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 *6))) (|:| |prim| (-1187 *6)))) (-5 *1 (-988 *6)))) (-2667 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-388) (-171))) (-5 *2 (-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 *5))) (|:| |prim| (-1187 *5)))) (-5 *1 (-988 *5)))) (-2667 (*1 *2 *3 *4 *3 *4) (-12 (-5 *3 (-980 *5)) (-5 *4 (-1191)) (-4 *5 (-13 (-388) (-171))) (-5 *2 (-2 (|:| |coef1| (-592)) (|:| |coef2| (-592)) (|:| |prim| (-1187 *5)))) (-5 *1 (-988 *5))))) 
+(-10 -7 (-15 -2667 ((-2 (|:| |coef1| (-592)) (|:| |coef2| (-592)) (|:| |prim| (-1187 |#1|))) (-980 |#1|) (-1191) (-980 |#1|) (-1191))) (-15 -2667 ((-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 |#1|))) (|:| |prim| (-1187 |#1|))) (-658 (-980 |#1|)) (-658 (-1191)))) (-15 -2667 ((-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 |#1|))) (|:| |prim| (-1187 |#1|))) (-658 (-980 |#1|)) (-658 (-1191)) (-1191)))) 
+((-2918 (((-658 |#1|) |#1| |#1|) 42)) (-2802 (((-141) |#1|) 39)) (-2036 ((|#1| |#1|) 64)) (-2149 ((|#1| |#1|) 63))) 
+(((-989 |#1|) (-10 -7 (-15 -2802 ((-141) |#1|)) (-15 -2149 (|#1| |#1|)) (-15 -2036 (|#1| |#1|)) (-15 -2918 ((-658 |#1|) |#1| |#1|))) (-574)) (T -989)) 
+((-2918 (*1 *2 *3 *3) (-12 (-5 *2 (-658 *3)) (-5 *1 (-989 *3)) (-4 *3 (-574)))) (-2036 (*1 *2 *2) (-12 (-5 *1 (-989 *2)) (-4 *2 (-574)))) (-2149 (*1 *2 *2) (-12 (-5 *1 (-989 *2)) (-4 *2 (-574)))) (-2802 (*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-989 *3)) (-4 *3 (-574))))) 
+(-10 -7 (-15 -2802 ((-141) |#1|)) (-15 -2149 (|#1| |#1|)) (-15 -2036 (|#1| |#1|)) (-15 -2918 ((-658 |#1|) |#1| |#1|))) 
+((-3029 (((-1285) (-877)) 9))) 
+(((-990) (-10 -7 (-15 -3029 ((-1285) (-877))))) (T -990)) 
+((-3029 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-990))))) 
+(-10 -7 (-15 -3029 ((-1285) (-877)))) 
+((-1483 (((-658 |#5|) |#3| (-658 |#3|)) 70)) (-2589 (((-658 |#5|) |#3|) 45)) (-3969 (((-658 |#5|) |#3| (-944)) 58)) (-4213 (((-658 |#5|) (-658 |#3|)) 48))) 
+(((-991 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1483 ((-658 |#5|) |#3| (-658 |#3|))) (-15 -2589 ((-658 |#5|) |#3|)) (-15 -4213 ((-658 |#5|) (-658 |#3|))) (-15 -3969 ((-658 |#5|) |#3| (-944)))) (-388) (-658 (-1191)) (-977 |#1| |#4| (-879 |#2|)) (-252 (-1699 |#2|) (-790)) (-999 |#1|)) (T -991)) 
+((-3969 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-5 *2 (-658 *8)) (-5 *1 (-991 *5 *6 *3 *7 *8)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)))) (-4213 (*1 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *2 (-658 *8)) (-5 *1 (-991 *4 *5 *6 *7 *8)) (-4 *8 (-999 *4)))) (-2589 (*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *2 (-658 *7)) (-5 *1 (-991 *4 *5 *3 *6 *7)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *7 (-999 *4)))) (-1483 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 *8)) (-5 *1 (-991 *5 *6 *3 *7 *8)) (-4 *8 (-999 *5))))) 
+(-10 -7 (-15 -1483 ((-658 |#5|) |#3| (-658 |#3|))) (-15 -2589 ((-658 |#5|) |#3|)) (-15 -4213 ((-658 |#5|) (-658 |#3|))) (-15 -3969 ((-658 |#5|) |#3| (-944)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 62 (|has| |#1| (-582)))) (-1555 (($ $) 63 (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 28)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-4593 (($ $) 24)) (-3371 (((-3 $ "failed") $) 35)) (-3262 (($ $) NIL (|has| |#1| (-477)))) (-4209 (($ $ |#1| |#2| $) 47)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) 16)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| |#2|) NIL)) (-4206 ((|#2| $) 19)) (-2976 (($ (-1 |#2| |#2|) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4573 (($ $) 23)) (-4579 ((|#1| $) 21)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 40)) (-4565 ((|#1| $) NIL)) (-4550 (($ $ |#2| |#1| $) 71 (-12 (|has| |#2| (-158)) (|has| |#1| (-582))))) (-3616 (((-3 $ "failed") $ $) 73 (|has| |#1| (-582))) (((-3 $ "failed") $ |#1|) 69 (|has| |#1| (-582)))) (-4525 ((|#2| $) 17)) (-1554 ((|#1| $) NIL (|has| |#1| (-477)))) (-1683 (((-877) $) NIL) (($ (-592)) 39) (($ $) NIL (|has| |#1| (-582))) (($ |#1|) 34) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592))))))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ |#2|) 31)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) 15)) (-4064 (($ $ $ (-790)) 58 (|has| |#1| (-194)))) (-2537 (((-141) $ $) 68 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 54) (($ $ (-790)) 55)) (-3514 (($) 22 T CONST)) (-4257 (($) 12 T CONST)) (-3255 (((-141) $ $) 67)) (-3313 (($ $ |#1|) 74 (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) 53) (($ $ (-790)) 51)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 50) (($ $ |#1|) 49) (($ |#1| $) 48) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-992 |#1| |#2|) (-13 (-346 |#1| |#2|) (-10 -8 (IF (|has| |#1| (-582)) (IF (|has| |#2| (-158)) (-15 -4550 ($ $ |#2| |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4623)) (-6 -4623) |noBranch|))) (-1075) (-814)) (T -992)) 
+((-4550 (*1 *1 *1 *2 *3 *1) (-12 (-5 *1 (-992 *3 *2)) (-4 *2 (-158)) (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *2 (-814))))) 
+(-13 (-346 |#1| |#2|) (-10 -8 (IF (|has| |#1| (-582)) (IF (|has| |#2| (-158)) (-15 -4550 ($ $ |#2| |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4623)) (-6 -4623) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL (-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815)))))) (-4079 (($ $ $) 63 (-12 (|has| |#1| (-815)) (|has| |#2| (-815))))) (-2350 (((-3 $ "failed") $ $) 50 (-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815)))))) (-1403 (((-790)) 34 (-12 (|has| |#1| (-394)) (|has| |#2| (-394))))) (-1734 ((|#2| $) 21)) (-2696 ((|#1| $) 20)) (-3001 (($) NIL (-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815)))) CONST)) (-3371 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743)))))) (-4290 (($) NIL (-12 (|has| |#1| (-394)) (|has| |#2| (-394))))) (-3558 (((-141) $) NIL (-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743)))))) (-1837 (($ $ $) NIL (-3836 (-12 (|has| |#1| (-815)) (|has| |#2| (-815))) (-12 (|has| |#1| (-869)) (|has| |#2| (-869)))))) (-3319 (($ $ $) NIL (-3836 (-12 (|has| |#1| (-815)) (|has| |#2| (-815))) (-12 (|has| |#1| (-869)) (|has| |#2| (-869)))))) (-4287 (($ |#1| |#2|) 19)) (-3546 (((-944) $) NIL (-12 (|has| |#1| (-394)) (|has| |#2| (-394))))) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 37 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))))) (-1825 (($ (-944)) NIL (-12 (|has| |#1| (-394)) (|has| |#2| (-394))))) (-2951 (((-1137) $) NIL)) (-1405 (((-658 $)) NIL (-12 (|has| |#1| (-394)) (|has| |#2| (-394))))) (-2227 (($ $ $) NIL (-12 (|has| |#1| (-502)) (|has| |#2| (-502))))) (-2131 (($ $ $) NIL (-12 (|has| |#1| (-502)) (|has| |#2| (-502))))) (-1683 (((-877) $) 14)) (-1424 (($ $ (-592)) NIL (-12 (|has| |#1| (-502)) (|has| |#2| (-502)))) (($ $ (-790)) NIL (-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743))))) (($ $ (-944)) NIL (-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743)))))) (-3514 (($) 40 (-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815)))) CONST)) (-4257 (($) 24 (-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743)))) CONST)) (-3286 (((-141) $ $) NIL (-3836 (-12 (|has| |#1| (-815)) (|has| |#2| (-815))) (-12 (|has| |#1| (-869)) (|has| |#2| (-869)))))) (-3273 (((-141) $ $) NIL (-3836 (-12 (|has| |#1| (-815)) (|has| |#2| (-815))) (-12 (|has| |#1| (-869)) (|has| |#2| (-869)))))) (-3255 (((-141) $ $) 18)) (-3279 (((-141) $ $) NIL (-3836 (-12 (|has| |#1| (-815)) (|has| |#2| (-815))) (-12 (|has| |#1| (-869)) (|has| |#2| (-869)))))) (-3266 (((-141) $ $) 66 (-3836 (-12 (|has| |#1| (-815)) (|has| |#2| (-815))) (-12 (|has| |#1| (-869)) (|has| |#2| (-869)))))) (-3313 (($ $ $) NIL (-12 (|has| |#1| (-502)) (|has| |#2| (-502))))) (-3306 (($ $ $) 56 (-12 (|has| |#1| (-21)) (|has| |#2| (-21)))) (($ $) 53 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))))) (-3300 (($ $ $) 43 (-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815)))))) (** (($ $ (-592)) NIL (-12 (|has| |#1| (-502)) (|has| |#2| (-502)))) (($ $ (-790)) 31 (-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743))))) (($ $ (-944)) NIL (-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743)))))) (* (($ (-592) $) 60 (-12 (|has| |#1| (-21)) (|has| |#2| (-21)))) (($ (-790) $) 46 (-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815))))) (($ (-944) $) NIL (-3836 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-158)) (|has| |#2| (-158))) (-12 (|has| |#1| (-815)) (|has| |#2| (-815))))) (($ $ $) 27 (-3836 (-12 (|has| |#1| (-502)) (|has| |#2| (-502))) (-12 (|has| |#1| (-743)) (|has| |#2| (-743))))))) 
+(((-993 |#1| |#2|) (-13 (-1119) (-10 -8 (IF (|has| |#1| (-394)) (IF (|has| |#2| (-394)) (-6 (-394)) |noBranch|) |noBranch|) (IF (|has| |#1| (-743)) (IF (|has| |#2| (-743)) (-6 (-743)) |noBranch|) |noBranch|) (IF (|has| |#1| (-23)) (IF (|has| |#2| (-23)) (-6 (-23)) |noBranch|) |noBranch|) (IF (|has| |#1| (-158)) (IF (|has| |#2| (-158)) (-6 (-158)) |noBranch|) |noBranch|) (IF (|has| |#1| (-502)) (IF (|has| |#2| (-502)) (-6 (-502)) |noBranch|) |noBranch|) (IF (|has| |#1| (-21)) (IF (|has| |#2| (-21)) (-6 (-21)) |noBranch|) |noBranch|) (IF (|has| |#1| (-815)) (IF (|has| |#2| (-815)) (-6 (-815)) |noBranch|) |noBranch|) (IF (|has| |#1| (-869)) (IF (|has| |#2| (-869)) (-6 (-869)) |noBranch|) |noBranch|) (-15 -4287 ($ |#1| |#2|)) (-15 -2696 (|#1| $)) (-15 -1734 (|#2| $)))) (-1119) (-1119)) (T -993)) 
+((-4287 (*1 *1 *2 *3) (-12 (-5 *1 (-993 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) (-2696 (*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-993 *2 *3)) (-4 *3 (-1119)))) (-1734 (*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-993 *3 *2)) (-4 *3 (-1119))))) 
+(-13 (-1119) (-10 -8 (IF (|has| |#1| (-394)) (IF (|has| |#2| (-394)) (-6 (-394)) |noBranch|) |noBranch|) (IF (|has| |#1| (-743)) (IF (|has| |#2| (-743)) (-6 (-743)) |noBranch|) |noBranch|) (IF (|has| |#1| (-23)) (IF (|has| |#2| (-23)) (-6 (-23)) |noBranch|) |noBranch|) (IF (|has| |#1| (-158)) (IF (|has| |#2| (-158)) (-6 (-158)) |noBranch|) |noBranch|) (IF (|has| |#1| (-502)) (IF (|has| |#2| (-502)) (-6 (-502)) |noBranch|) |noBranch|) (IF (|has| |#1| (-21)) (IF (|has| |#2| (-21)) (-6 (-21)) |noBranch|) |noBranch|) (IF (|has| |#1| (-815)) (IF (|has| |#2| (-815)) (-6 (-815)) |noBranch|) |noBranch|) (IF (|has| |#1| (-869)) (IF (|has| |#2| (-869)) (-6 (-869)) |noBranch|) |noBranch|) (-15 -4287 ($ |#1| |#2|)) (-15 -2696 (|#1| $)) (-15 -1734 (|#2| $)))) 
+((-1641 (((-141) $ $) NIL)) (-3932 ((|#1| $ (-592) |#1|) NIL)) (-1328 (((-658 $) (-658 $) (-790)) NIL) (((-658 $) (-658 $)) NIL)) (-2435 (((-141) $ (-790)) NIL) (((-141) $) NIL)) (-2117 (($ (-658 |#1|)) NIL)) (-2382 (((-658 |#1|) $) NIL)) (-1363 (((-658 $) $) NIL) (((-658 $) $ (-790)) NIL)) (-1333 (((-658 |#1|) $) NIL)) (-2685 (((-1173) $) NIL)) (-4234 (((-592) $) NIL)) (-4475 (((-592) $) NIL)) (-3315 (($ $ (-592)) NIL) (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-3927 ((|#1| $ (-592)) NIL)) (-4525 (((-944) $) NIL)) (-3472 ((|#1| $) NIL)) (-2227 (($ $ (-790)) NIL) (($ $) NIL)) (-1683 (((-877) $) NIL) (((-658 |#1|) $) NIL) (($ (-658 |#1|)) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-994 |#1|) (-999 |#1|) (-388)) (T -994)) 
+NIL 
+(-999 |#1|) 
+((-1641 (((-141) $ $) NIL)) (-3932 (((-884 |#1|) $ (-592) (-884 |#1|)) NIL)) (-1328 (((-658 $) (-658 $) (-790)) NIL) (((-658 $) (-658 $)) NIL)) (-2435 (((-141) $ (-790)) NIL) (((-141) $) NIL)) (-2117 (($ (-658 (-884 |#1|))) NIL)) (-2382 (((-658 (-884 |#1|)) $) NIL)) (-1363 (((-658 $) $) NIL) (((-658 $) $ (-790)) NIL)) (-1333 (((-658 (-884 |#1|)) $) NIL)) (-2685 (((-1173) $) NIL)) (-4234 (((-592) $) NIL)) (-4475 (((-592) $) NIL)) (-3315 (($ $ (-592)) NIL) (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-3927 (((-884 |#1|) $ (-592)) NIL)) (-4525 (((-944) $) NIL)) (-3472 (((-884 |#1|) $) NIL)) (-2227 (($ $ (-790)) NIL) (($ $) NIL)) (-1683 (((-877) $) NIL) (((-658 (-884 |#1|)) $) NIL) (($ (-658 (-884 |#1|))) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-995 |#1|) (-999 (-884 |#1|)) (-373)) (T -995)) 
+NIL 
+(-999 (-884 |#1|)) 
+((-1641 (((-141) $ $) NIL)) (-3932 ((|#2| $ (-592) |#2|) NIL)) (-1328 (((-658 $) (-658 $) (-790)) 41) (((-658 $) (-658 $)) 42)) (-2435 (((-141) $ (-790)) 38) (((-141) $) 40)) (-2117 (($ (-658 |#2|)) 25)) (-2382 (((-658 |#2|) $) 27)) (-1363 (((-658 $) $) 50) (((-658 $) $ (-790)) 47)) (-1333 (((-658 |#2|) $) 26)) (-2685 (((-1173) $) NIL)) (-4234 (((-592) $) 59)) (-4475 (((-592) $) 62)) (-3315 (($ $ (-592)) 36) (($ $) 52)) (-2951 (((-1137) $) NIL)) (-3927 ((|#2| $ (-592)) 32)) (-4525 (((-944) $) 16)) (-3472 ((|#2| $) 22)) (-2227 (($ $ (-790)) 30) (($ $) 49)) (-1683 (((-877) $) 19) (((-658 |#2|) $) 24) (($ (-658 |#2|)) 58)) (-3255 (((-141) $ $) 37))) 
+(((-996 |#1| |#2|) (-999 |#2|) (-790) (-388)) (T -996)) 
+NIL 
+(-999 |#2|) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-3001 (($) 7 T CONST)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-2713 (($ $ $) 40)) (-4491 (($ $ $) 41)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3319 ((|#1| $) 42)) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-997 |#1|) (-1311) (-869)) (T -997)) 
+((-3319 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-869)))) (-4491 (*1 *1 *1 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-869)))) (-2713 (*1 *1 *1 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-869))))) 
+(-13 (-131 |t#1|) (-10 -8 (-6 -4625) (-15 -3319 (|t#1| $)) (-15 -4491 ($ $ $)) (-15 -2713 ($ $ $)))) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-3604 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3548 |#2|)) |#2| |#2|) 84)) (-3250 ((|#2| |#2| |#2|) 82)) (-3532 (((-2 (|:| |coef2| |#2|) (|:| -3548 |#2|)) |#2| |#2|) 86)) (-2815 (((-2 (|:| |coef1| |#2|) (|:| -3548 |#2|)) |#2| |#2|) 88)) (-3378 (((-2 (|:| |coef2| |#2|) (|:| -1801 |#1|)) |#2| |#2|) 106 (|has| |#1| (-477)))) (-4178 (((-2 (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|) 45)) (-4527 (((-2 (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|) 63)) (-3744 (((-2 (|:| |coef1| |#2|) (|:| -1544 |#1|)) |#2| |#2|) 65)) (-2460 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) 77)) (-2580 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790)) 70)) (-2344 (((-2 (|:| |coef2| |#2|) (|:| -1482 |#1|)) |#2|) 96)) (-3189 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790)) 73)) (-4260 (((-658 (-790)) |#2| |#2|) 81)) (-2848 ((|#1| |#2| |#2|) 41)) (-4569 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1801 |#1|)) |#2| |#2|) 104 (|has| |#1| (-477)))) (-1801 ((|#1| |#2| |#2|) 102 (|has| |#1| (-477)))) (-2167 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|) 43)) (-3641 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|) 62)) (-1544 ((|#1| |#2| |#2|) 60)) (-4369 (((-2 (|:| -1487 |#1|) (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2|) 35)) (-3593 ((|#2| |#2| |#2| |#2| |#1|) 52)) (-3156 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) 75)) (-3722 ((|#2| |#2| |#2|) 74)) (-1768 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790)) 68)) (-3981 ((|#2| |#2| |#2| (-790)) 66)) (-3548 ((|#2| |#2| |#2|) 110 (|has| |#1| (-477)))) (-3616 (((-1280 |#2|) (-1280 |#2|) |#1|) 21)) (-4570 (((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2|) 38)) (-4344 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1482 |#1|)) |#2|) 94)) (-1482 ((|#1| |#2|) 91)) (-2635 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790)) 72)) (-2991 ((|#2| |#2| |#2| (-790)) 71)) (-3438 (((-658 |#2|) |#2| |#2|) 79)) (-2095 ((|#2| |#2| |#1| |#1| (-790)) 49)) (-2572 ((|#1| |#1| |#1| (-790)) 48)) (* (((-1280 |#2|) |#1| (-1280 |#2|)) 16))) 
+(((-998 |#1| |#2|) (-10 -7 (-15 -1544 (|#1| |#2| |#2|)) (-15 -3641 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|)) (-15 -4527 ((-2 (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|)) (-15 -3744 ((-2 (|:| |coef1| |#2|) (|:| -1544 |#1|)) |#2| |#2|)) (-15 -3981 (|#2| |#2| |#2| (-790))) (-15 -1768 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790))) (-15 -2580 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790))) (-15 -2991 (|#2| |#2| |#2| (-790))) (-15 -2635 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790))) (-15 -3189 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790))) (-15 -3722 (|#2| |#2| |#2|)) (-15 -3156 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -2460 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -3250 (|#2| |#2| |#2|)) (-15 -3604 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3548 |#2|)) |#2| |#2|)) (-15 -3532 ((-2 (|:| |coef2| |#2|) (|:| -3548 |#2|)) |#2| |#2|)) (-15 -2815 ((-2 (|:| |coef1| |#2|) (|:| -3548 |#2|)) |#2| |#2|)) (-15 -1482 (|#1| |#2|)) (-15 -4344 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1482 |#1|)) |#2|)) (-15 -2344 ((-2 (|:| |coef2| |#2|) (|:| -1482 |#1|)) |#2|)) (-15 -3438 ((-658 |#2|) |#2| |#2|)) (-15 -4260 ((-658 (-790)) |#2| |#2|)) (IF (|has| |#1| (-477)) (PROGN (-15 -1801 (|#1| |#2| |#2|)) (-15 -4569 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1801 |#1|)) |#2| |#2|)) (-15 -3378 ((-2 (|:| |coef2| |#2|) (|:| -1801 |#1|)) |#2| |#2|)) (-15 -3548 (|#2| |#2| |#2|))) |noBranch|) (-15 * ((-1280 |#2|) |#1| (-1280 |#2|))) (-15 -3616 ((-1280 |#2|) (-1280 |#2|) |#1|)) (-15 -4369 ((-2 (|:| -1487 |#1|) (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2|)) (-15 -4570 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2|)) (-15 -2572 (|#1| |#1| |#1| (-790))) (-15 -2095 (|#2| |#2| |#1| |#1| (-790))) (-15 -3593 (|#2| |#2| |#2| |#2| |#1|)) (-15 -2848 (|#1| |#2| |#2|)) (-15 -2167 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|)) (-15 -4178 ((-2 (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|))) (-582) (-1255 |#1|)) (T -998)) 
+((-4178 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-2167 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-2848 (*1 *2 *3 *3) (-12 (-4 *2 (-582)) (-5 *1 (-998 *2 *3)) (-4 *3 (-1255 *2)))) (-3593 (*1 *2 *2 *2 *2 *3) (-12 (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3)))) (-2095 (*1 *2 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3)))) (-2572 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *2 (-582)) (-5 *1 (-998 *2 *4)) (-4 *4 (-1255 *2)))) (-4570 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-4369 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| -1487 *4) (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-3616 (*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-582)) (-5 *1 (-998 *3 *4)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-1280 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-582)) (-5 *1 (-998 *3 *4)))) (-3548 (*1 *2 *2 *2) (-12 (-4 *3 (-477)) (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3)))) (-3378 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1801 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-4569 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1801 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-1801 (*1 *2 *3 *3) (-12 (-4 *2 (-582)) (-4 *2 (-477)) (-5 *1 (-998 *2 *3)) (-4 *3 (-1255 *2)))) (-4260 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 (-790))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-3438 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 *3)) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-2344 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1482 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-4344 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1482 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-1482 (*1 *2 *3) (-12 (-4 *2 (-582)) (-5 *1 (-998 *2 *3)) (-4 *3 (-1255 *2)))) (-2815 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -3548 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-3532 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3548 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-3604 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3548 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-3250 (*1 *2 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3)))) (-2460 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-3156 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-3722 (*1 *2 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3)))) (-3189 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *5 *3)) (-4 *3 (-1255 *5)))) (-2635 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *5 *3)) (-4 *3 (-1255 *5)))) (-2991 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-582)) (-5 *1 (-998 *4 *2)) (-4 *2 (-1255 *4)))) (-2580 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *5 *3)) (-4 *3 (-1255 *5)))) (-1768 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *5 *3)) (-4 *3 (-1255 *5)))) (-3981 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-582)) (-5 *1 (-998 *4 *2)) (-4 *2 (-1255 *4)))) (-3744 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-4527 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-3641 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) (-1544 (*1 *2 *3 *3) (-12 (-4 *2 (-582)) (-5 *1 (-998 *2 *3)) (-4 *3 (-1255 *2))))) 
+(-10 -7 (-15 -1544 (|#1| |#2| |#2|)) (-15 -3641 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|)) (-15 -4527 ((-2 (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|)) (-15 -3744 ((-2 (|:| |coef1| |#2|) (|:| -1544 |#1|)) |#2| |#2|)) (-15 -3981 (|#2| |#2| |#2| (-790))) (-15 -1768 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790))) (-15 -2580 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790))) (-15 -2991 (|#2| |#2| |#2| (-790))) (-15 -2635 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790))) (-15 -3189 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-790))) (-15 -3722 (|#2| |#2| |#2|)) (-15 -3156 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -2460 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -3250 (|#2| |#2| |#2|)) (-15 -3604 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3548 |#2|)) |#2| |#2|)) (-15 -3532 ((-2 (|:| |coef2| |#2|) (|:| -3548 |#2|)) |#2| |#2|)) (-15 -2815 ((-2 (|:| |coef1| |#2|) (|:| -3548 |#2|)) |#2| |#2|)) (-15 -1482 (|#1| |#2|)) (-15 -4344 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1482 |#1|)) |#2|)) (-15 -2344 ((-2 (|:| |coef2| |#2|) (|:| -1482 |#1|)) |#2|)) (-15 -3438 ((-658 |#2|) |#2| |#2|)) (-15 -4260 ((-658 (-790)) |#2| |#2|)) (IF (|has| |#1| (-477)) (PROGN (-15 -1801 (|#1| |#2| |#2|)) (-15 -4569 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1801 |#1|)) |#2| |#2|)) (-15 -3378 ((-2 (|:| |coef2| |#2|) (|:| -1801 |#1|)) |#2| |#2|)) (-15 -3548 (|#2| |#2| |#2|))) |noBranch|) (-15 * ((-1280 |#2|) |#1| (-1280 |#2|))) (-15 -3616 ((-1280 |#2|) (-1280 |#2|) |#1|)) (-15 -4369 ((-2 (|:| -1487 |#1|) (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2|)) (-15 -4570 ((-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) |#2| |#2|)) (-15 -2572 (|#1| |#1| |#1| (-790))) (-15 -2095 (|#2| |#2| |#1| |#1| (-790))) (-15 -3593 (|#2| |#2| |#2| |#2| |#1|)) (-15 -2848 (|#1| |#2| |#2|)) (-15 -2167 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|)) (-15 -4178 ((-2 (|:| |coef2| |#2|) (|:| -1544 |#1|)) |#2| |#2|))) 
+((-1641 (((-141) $ $) 7)) (-3932 ((|#1| $ (-592) |#1|) 14)) (-1328 (((-658 $) (-658 $) (-790)) 22) (((-658 $) (-658 $)) 21)) (-2435 (((-141) $ (-790)) 20) (((-141) $) 19)) (-2117 (($ (-658 |#1|)) 30)) (-2382 (((-658 |#1|) $) 13)) (-1363 (((-658 $) $) 26) (((-658 $) $ (-790)) 25)) (-1333 (((-658 |#1|) $) 16)) (-2685 (((-1173) $) 9)) (-4234 (((-592) $) 17)) (-4475 (((-592) $) 32)) (-3315 (($ $ (-592)) 31) (($ $) 18)) (-2951 (((-1137) $) 10)) (-3927 ((|#1| $ (-592)) 15)) (-4525 (((-944) $) 12)) (-3472 ((|#1| $) 29)) (-2227 (($ $ (-790)) 24) (($ $) 23)) (-1683 (((-877) $) 11) (((-658 |#1|) $) 28) (($ (-658 |#1|)) 27)) (-3255 (((-141) $ $) 6))) 
+(((-999 |#1|) (-1311) (-388)) (T -999)) 
+((-4475 (*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-592)))) (-3315 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-999 *3)) (-4 *3 (-388)))) (-2117 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-999 *3)))) (-3472 (*1 *2 *1) (-12 (-4 *1 (-999 *2)) (-4 *2 (-388)))) (-1683 (*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-999 *3)))) (-1363 (*1 *2 *1) (-12 (-4 *3 (-388)) (-5 *2 (-658 *1)) (-4 *1 (-999 *3)))) (-1363 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *4 (-388)) (-5 *2 (-658 *1)) (-4 *1 (-999 *4)))) (-2227 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-999 *3)) (-4 *3 (-388)))) (-2227 (*1 *1 *1) (-12 (-4 *1 (-999 *2)) (-4 *2 (-388)))) (-1328 (*1 *2 *2 *3) (-12 (-5 *2 (-658 *1)) (-5 *3 (-790)) (-4 *1 (-999 *4)) (-4 *4 (-388)))) (-1328 (*1 *2 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-999 *3)) (-4 *3 (-388)))) (-2435 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-999 *4)) (-4 *4 (-388)) (-5 *2 (-141)))) (-2435 (*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-141)))) (-3315 (*1 *1 *1) (-12 (-4 *1 (-999 *2)) (-4 *2 (-388)))) (-4234 (*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-592)))) (-1333 (*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-999 *2)) (-4 *2 (-388)))) (-3932 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-999 *2)) (-4 *2 (-388)))) (-2382 (*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3))))) 
+(-13 (-1117) (-10 -8 (-15 -4475 ((-592) $)) (-15 -3315 ($ $ (-592))) (-15 -2117 ($ (-658 |t#1|))) (-15 -3472 (|t#1| $)) (-15 -1683 ((-658 |t#1|) $)) (-15 -1683 ($ (-658 |t#1|))) (-15 -1363 ((-658 $) $)) (-15 -1363 ((-658 $) $ (-790))) (-15 -2227 ($ $ (-790))) (-15 -2227 ($ $)) (-15 -1328 ((-658 $) (-658 $) (-790))) (-15 -1328 ((-658 $) (-658 $))) (-15 -2435 ((-141) $ (-790))) (-15 -2435 ((-141) $)) (-15 -3315 ($ $)) (-15 -4234 ((-592) $)) (-15 -1333 ((-658 |t#1|) $)) (-15 -3927 (|t#1| $ (-592))) (-15 -3932 (|t#1| $ (-592) |t#1|)) (-15 -2382 ((-658 |t#1|) $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T) ((-1117) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) 26)) (-3001 (($) NIL T CONST)) (-3672 (((-658 (-658 (-592))) (-658 (-592))) 28)) (-4443 (((-592) $) 44)) (-1744 (($ (-658 (-592))) 17)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1778 (((-658 (-592)) $) 11)) (-2227 (($ $) 31)) (-1683 (((-877) $) 42) (((-658 (-592)) $) 9)) (-3514 (($) 7 T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 19)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 18)) (-3300 (($ $ $) 20)) (* (($ (-790) $) 24) (($ (-944) $) NIL))) 
+(((-1000) (-13 (-817) (-633 (-658 (-592))) (-10 -8 (-15 -1744 ($ (-658 (-592)))) (-15 -3672 ((-658 (-658 (-592))) (-658 (-592)))) (-15 -4443 ((-592) $)) (-15 -2227 ($ $)) (-15 -1683 ((-658 (-592)) $))))) (T -1000)) 
+((-1744 (*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1000)))) (-3672 (*1 *2 *3) (-12 (-5 *2 (-658 (-658 (-592)))) (-5 *1 (-1000)) (-5 *3 (-658 (-592))))) (-4443 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1000)))) (-2227 (*1 *1 *1) (-5 *1 (-1000))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1000))))) 
+(-13 (-817) (-633 (-658 (-592))) (-10 -8 (-15 -1744 ($ (-658 (-592)))) (-15 -3672 ((-658 (-658 (-592))) (-658 (-592)))) (-15 -4443 ((-592) $)) (-15 -2227 ($ $)) (-15 -1683 ((-658 (-592)) $)))) 
+((-3313 (($ $ |#2|) 30)) (-3306 (($ $) 22) (($ $ $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 15) (($ $ $) NIL) (($ $ |#2|) 20) (($ |#2| $) 19) (($ (-433 (-592)) $) 26) (($ $ (-433 (-592))) 28))) 
+(((-1001 |#1| |#2| |#3| |#4|) (-10 -8 (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 -3313 (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) (-1002 |#2| |#3| |#4|) (-1075) (-814) (-869)) (T -1001)) 
+NIL 
+(-10 -8 (-15 * (|#1| |#1| (-433 (-592)))) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 -3313 (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 * (|#1| (-944) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 |#3|) $) 70)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-4593 (($ $) 59)) (-3371 (((-3 $ "failed") $) 33)) (-2273 (((-141) $) 69)) (-3558 (((-141) $) 30)) (-2027 (((-141) $) 61)) (-4526 (($ |#1| |#2|) 60) (($ $ |#3| |#2|) 72) (($ $ (-658 |#3|) (-658 |#2|)) 71)) (-2731 (($ (-1 |#1| |#1|) $) 62)) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582)))) (-4525 ((|#2| $) 63)) (-1700 (($ $) 68)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 56 (|has| |#1| (-43 (-433 (-592))))) (($ $) 48 (|has| |#1| (-582))) (($ |#1|) 46 (|has| |#1| (-194)))) (-1937 ((|#1| $ |#2|) 58)) (-1517 (((-3 $ "failed") $) 47 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1002 |#1| |#2| |#3|) (-1311) (-1075) (-814) (-869)) (T -1002)) 
+((-4579 (*1 *2 *1) (-12 (-4 *1 (-1002 *2 *3 *4)) (-4 *3 (-814)) (-4 *4 (-869)) (-4 *2 (-1075)))) (-4573 (*1 *1 *1) (-12 (-4 *1 (-1002 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *4 (-869)))) (-4525 (*1 *2 *1) (-12 (-4 *1 (-1002 *3 *2 *4)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *2 (-814)))) (-4526 (*1 *1 *1 *2 *3) (-12 (-4 *1 (-1002 *4 *3 *2)) (-4 *4 (-1075)) (-4 *3 (-814)) (-4 *2 (-869)))) (-4526 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *6)) (-5 *3 (-658 *5)) (-4 *1 (-1002 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-814)) (-4 *6 (-869)))) (-4085 (*1 *2 *1) (-12 (-4 *1 (-1002 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-814)) (-4 *5 (-869)) (-5 *2 (-658 *5)))) (-2273 (*1 *2 *1) (-12 (-4 *1 (-1002 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-814)) (-4 *5 (-869)) (-5 *2 (-141)))) (-1700 (*1 *1 *1) (-12 (-4 *1 (-1002 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *4 (-869))))) 
+(-13 (-52 |t#1| |t#2|) (-10 -8 (-15 -4526 ($ $ |t#3| |t#2|)) (-15 -4526 ($ $ (-658 |t#3|) (-658 |t#2|))) (-15 -4573 ($ $)) (-15 -4579 (|t#1| $)) (-15 -4525 (|t#2| $)) (-15 -4085 ((-658 |t#3|) $)) (-15 -2273 ((-141) $)) (-15 -1700 ($ $)))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) |has| |#1| (-582)) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-307) |has| |#1| (-582)) ((-582) |has| |#1| (-582)) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) |has| |#1| (-582)) ((-743) . T) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-3331 (((-1113 (-237)) $) 7)) (-1413 (((-1113 (-237)) $) 8)) (-4254 (((-1113 (-237)) $) 9)) (-1613 (((-658 (-658 (-971 (-237)))) $) 10)) (-1683 (((-877) $) 6))) 
+(((-1003) (-1311)) (T -1003)) 
+((-1613 (*1 *2 *1) (-12 (-4 *1 (-1003)) (-5 *2 (-658 (-658 (-971 (-237))))))) (-4254 (*1 *2 *1) (-12 (-4 *1 (-1003)) (-5 *2 (-1113 (-237))))) (-1413 (*1 *2 *1) (-12 (-4 *1 (-1003)) (-5 *2 (-1113 (-237))))) (-3331 (*1 *2 *1) (-12 (-4 *1 (-1003)) (-5 *2 (-1113 (-237)))))) 
+(-13 (-632 (-877)) (-10 -8 (-15 -1613 ((-658 (-658 (-971 (-237)))) $)) (-15 -4254 ((-1113 (-237)) $)) (-15 -1413 ((-1113 (-237)) $)) (-15 -3331 ((-1113 (-237)) $)))) 
+(((-632 (-877)) . T)) 
+((-4085 (((-658 |#4|) $) 23)) (-4325 (((-141) $) 47)) (-2988 (((-141) $) 46)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#4|) 35)) (-3239 (((-141) $) 48)) (-3478 (((-141) $ $) 54)) (-2398 (((-141) $ $) 57)) (-1529 (((-141) $) 52)) (-4521 (((-658 |#5|) (-658 |#5|) $) 89)) (-3718 (((-658 |#5|) (-658 |#5|) $) 86)) (-3027 (((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| $) 80)) (-2290 (((-658 |#4|) $) 27)) (-2645 (((-141) |#4| $) 29)) (-3480 (((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| $) 72)) (-2613 (($ $ |#4|) 32)) (-4152 (($ $ |#4|) 31)) (-2507 (($ $ |#4|) 33)) (-3255 (((-141) $ $) 39))) 
+(((-1004 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2988 ((-141) |#1|)) (-15 -4521 ((-658 |#5|) (-658 |#5|) |#1|)) (-15 -3718 ((-658 |#5|) (-658 |#5|) |#1|)) (-15 -3027 ((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -3480 ((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -3239 ((-141) |#1|)) (-15 -2398 ((-141) |#1| |#1|)) (-15 -3478 ((-141) |#1| |#1|)) (-15 -1529 ((-141) |#1|)) (-15 -4325 ((-141) |#1|)) (-15 -3960 ((-2 (|:| |under| |#1|) (|:| -2039 |#1|) (|:| |upper| |#1|)) |#1| |#4|)) (-15 -2613 (|#1| |#1| |#4|)) (-15 -2507 (|#1| |#1| |#4|)) (-15 -4152 (|#1| |#1| |#4|)) (-15 -2645 ((-141) |#4| |#1|)) (-15 -2290 ((-658 |#4|) |#1|)) (-15 -4085 ((-658 |#4|) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) (-1005 |#2| |#3| |#4| |#5|) (-1075) (-815) (-869) (-1089 |#2| |#3| |#4|)) (T -1004)) 
+NIL 
+(-10 -8 (-15 -2988 ((-141) |#1|)) (-15 -4521 ((-658 |#5|) (-658 |#5|) |#1|)) (-15 -3718 ((-658 |#5|) (-658 |#5|) |#1|)) (-15 -3027 ((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -3480 ((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -3239 ((-141) |#1|)) (-15 -2398 ((-141) |#1| |#1|)) (-15 -3478 ((-141) |#1| |#1|)) (-15 -1529 ((-141) |#1|)) (-15 -4325 ((-141) |#1|)) (-15 -3960 ((-2 (|:| |under| |#1|) (|:| -2039 |#1|) (|:| |upper| |#1|)) |#1| |#4|)) (-15 -2613 (|#1| |#1| |#4|)) (-15 -2507 (|#1| |#1| |#4|)) (-15 -4152 (|#1| |#1| |#4|)) (-15 -2645 ((-141) |#4| |#1|)) (-15 -2290 ((-658 |#4|) |#1|)) (-15 -4085 ((-658 |#4|) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-4085 (((-658 |#3|) $) 32)) (-4325 (((-141) $) 25)) (-2988 (((-141) $) 16 (|has| |#1| (-582)))) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) 26)) (-2126 (((-141) $ (-790)) 43)) (-3113 (($ (-1 (-141) |#4|) $) 64 (|has| $ (-6 -4625)))) (-3001 (($) 44 T CONST)) (-3239 (((-141) $) 21 (|has| |#1| (-582)))) (-3478 (((-141) $ $) 23 (|has| |#1| (-582)))) (-2398 (((-141) $ $) 22 (|has| |#1| (-582)))) (-1529 (((-141) $) 24 (|has| |#1| (-582)))) (-4521 (((-658 |#4|) (-658 |#4|) $) 17 (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) 18 (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) 35)) (-2400 (($ (-658 |#4|)) 34)) (-1360 (($ $) 67 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#4| $) 66 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#4|) $) 63 (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-582)))) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4625)))) (-4004 (((-658 |#4|) $) 51 (|has| $ (-6 -4625)))) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) 42)) (-4467 (((-658 |#4|) $) 52 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 54 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 46)) (-2290 (((-658 |#3|) $) 31)) (-2645 (((-141) |#3| $) 30)) (-2554 (((-141) $ (-790)) 41)) (-2685 (((-1173) $) 9)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-582)))) (-2951 (((-1137) $) 10)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) 60)) (-3002 (((-141) (-1 (-141) |#4|) $) 49 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) 58 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) 56 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) 55 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) 37)) (-2943 (((-141) $) 40)) (-2890 (($) 39)) (-3452 (((-790) |#4| $) 53 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#4|) $) 50 (|has| $ (-6 -4625)))) (-4599 (($ $) 38)) (-1778 (((-565) $) 68 (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 59)) (-2613 (($ $ |#3|) 27)) (-4152 (($ $ |#3|) 29)) (-2507 (($ $ |#3|) 28)) (-1683 (((-877) $) 11) (((-658 |#4|) $) 36)) (-3369 (((-141) (-1 (-141) |#4|) $) 48 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 6)) (-1699 (((-790) $) 45 (|has| $ (-6 -4625))))) 
+(((-1005 |#1| |#2| |#3| |#4|) (-1311) (-1075) (-815) (-869) (-1089 |t#1| |t#2| |t#3|)) (T -1005)) 
+((-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *1 (-1005 *3 *4 *5 *6)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *1 (-1005 *3 *4 *5 *6)))) (-3259 (*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-1089 *3 *4 *2)) (-4 *2 (-869)))) (-4085 (*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-658 *5)))) (-2290 (*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-658 *5)))) (-2645 (*1 *2 *3 *1) (-12 (-4 *1 (-1005 *4 *5 *3 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-4 *6 (-1089 *4 *5 *3)) (-5 *2 (-141)))) (-4152 (*1 *1 *1 *2) (-12 (-4 *1 (-1005 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *5 (-1089 *3 *4 *2)))) (-2507 (*1 *1 *1 *2) (-12 (-4 *1 (-1005 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *5 (-1089 *3 *4 *2)))) (-2613 (*1 *1 *1 *2) (-12 (-4 *1 (-1005 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *5 (-1089 *3 *4 *2)))) (-3960 (*1 *2 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-4 *6 (-1089 *4 *5 *3)) (-5 *2 (-2 (|:| |under| *1) (|:| -2039 *1) (|:| |upper| *1))) (-4 *1 (-1005 *4 *5 *3 *6)))) (-4325 (*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) (-1529 (*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141)))) (-3478 (*1 *2 *1 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141)))) (-2398 (*1 *2 *1 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141)))) (-3239 (*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141)))) (-3480 (*1 *2 *3 *1) (-12 (-4 *1 (-1005 *4 *5 *6 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))))) (-3027 (*1 *2 *3 *1) (-12 (-4 *1 (-1005 *4 *5 *6 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4))))) (-3718 (*1 *2 *2 *1) (-12 (-5 *2 (-658 *6)) (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)))) (-4521 (*1 *2 *2 *1) (-12 (-5 *2 (-658 *6)) (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)))) (-2988 (*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141))))) 
+(-13 (-1119) (-175 |t#4|) (-632 (-658 |t#4|)) (-10 -8 (-6 -4625) (-15 -4368 ((-3 $ "failed") (-658 |t#4|))) (-15 -2400 ($ (-658 |t#4|))) (-15 -3259 (|t#3| $)) (-15 -4085 ((-658 |t#3|) $)) (-15 -2290 ((-658 |t#3|) $)) (-15 -2645 ((-141) |t#3| $)) (-15 -4152 ($ $ |t#3|)) (-15 -2507 ($ $ |t#3|)) (-15 -2613 ($ $ |t#3|)) (-15 -3960 ((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |t#3|)) (-15 -4325 ((-141) $)) (IF (|has| |t#1| (-582)) (PROGN (-15 -1529 ((-141) $)) (-15 -3478 ((-141) $ $)) (-15 -2398 ((-141) $ $)) (-15 -3239 ((-141) $)) (-15 -3480 ((-2 (|:| |num| |t#4|) (|:| |den| |t#1|)) |t#4| $)) (-15 -3027 ((-2 (|:| |rnum| |t#1|) (|:| |polnum| |t#4|) (|:| |den| |t#1|)) |t#4| $)) (-15 -3718 ((-658 |t#4|) (-658 |t#4|) $)) (-15 -4521 ((-658 |t#4|) (-658 |t#4|) $)) (-15 -2988 ((-141) $))) |noBranch|))) 
+(((-39) . T) ((-125) . T) ((-632 (-658 |#4|)) . T) ((-632 (-877)) . T) ((-175 |#4|) . T) ((-633 (-565)) |has| |#4| (-633 (-565))) ((-325 |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-523 |#4|) . T) ((-547 |#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-1119) . T) ((-1225) . T)) 
+((-2945 (((-658 |#4|) |#4| |#4|) 114)) (-2582 (((-658 |#4|) (-658 |#4|) (-141)) 103 (|has| |#1| (-477))) (((-658 |#4|) (-658 |#4|)) 104 (|has| |#1| (-477)))) (-3500 (((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|)) 34)) (-1974 (((-141) |#4|) 33)) (-4519 (((-658 |#4|) |#4|) 100 (|has| |#1| (-477)))) (-2621 (((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-1 (-141) |#4|) (-658 |#4|)) 19)) (-1788 (((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 (-1 (-141) |#4|)) (-658 |#4|)) 21)) (-1979 (((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 (-1 (-141) |#4|)) (-658 |#4|)) 22)) (-1655 (((-3 (-2 (|:| |bas| (-505 |#1| |#2| |#3| |#4|)) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|)) 72)) (-2491 (((-658 |#4|) (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|)) 84)) (-3964 (((-658 |#4|) (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|)) 107)) (-3495 (((-658 |#4|) (-658 |#4|)) 106)) (-3073 (((-658 |#4|) (-658 |#4|) (-658 |#4|) (-141)) 47) (((-658 |#4|) (-658 |#4|) (-658 |#4|)) 49)) (-2789 ((|#4| |#4| (-658 |#4|)) 48)) (-2517 (((-658 |#4|) (-658 |#4|) (-658 |#4|)) 110 (|has| |#1| (-477)))) (-4275 (((-658 |#4|) (-658 |#4|) (-658 |#4|)) 113 (|has| |#1| (-477)))) (-1344 (((-658 |#4|) (-658 |#4|) (-658 |#4|)) 112 (|has| |#1| (-477)))) (-3771 (((-658 |#4|) (-658 |#4|) (-658 |#4|) (-1 (-658 |#4|) (-658 |#4|))) 86) (((-658 |#4|) (-658 |#4|) (-658 |#4|)) 88) (((-658 |#4|) (-658 |#4|) |#4|) 117) (((-658 |#4|) |#4| |#4|) 115) (((-658 |#4|) (-658 |#4|)) 87)) (-3815 (((-658 |#4|) (-658 |#4|) (-658 |#4|)) 97 (-12 (|has| |#1| (-171)) (|has| |#1| (-323))))) (-4556 (((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|)) 40)) (-4549 (((-141) (-658 |#4|)) 61)) (-3320 (((-141) (-658 |#4|) (-658 (-658 |#4|))) 52)) (-3131 (((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|)) 28)) (-2365 (((-141) |#4|) 27)) (-3917 (((-658 |#4|) (-658 |#4|)) 96 (-12 (|has| |#1| (-171)) (|has| |#1| (-323))))) (-2271 (((-658 |#4|) (-658 |#4|)) 95 (-12 (|has| |#1| (-171)) (|has| |#1| (-323))))) (-1767 (((-658 |#4|) (-658 |#4|)) 65)) (-4358 (((-658 |#4|) (-658 |#4|)) 78)) (-2924 (((-141) (-658 |#4|) (-658 |#4|)) 50)) (-2638 (((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|)) 38)) (-4514 (((-141) |#4|) 35))) 
+(((-1006 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3771 ((-658 |#4|) (-658 |#4|))) (-15 -3771 ((-658 |#4|) |#4| |#4|)) (-15 -3495 ((-658 |#4|) (-658 |#4|))) (-15 -2945 ((-658 |#4|) |#4| |#4|)) (-15 -3771 ((-658 |#4|) (-658 |#4|) |#4|)) (-15 -3771 ((-658 |#4|) (-658 |#4|) (-658 |#4|))) (-15 -3771 ((-658 |#4|) (-658 |#4|) (-658 |#4|) (-1 (-658 |#4|) (-658 |#4|)))) (-15 -2924 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3320 ((-141) (-658 |#4|) (-658 (-658 |#4|)))) (-15 -4549 ((-141) (-658 |#4|))) (-15 -2621 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-1 (-141) |#4|) (-658 |#4|))) (-15 -1788 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 (-1 (-141) |#4|)) (-658 |#4|))) (-15 -1979 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 (-1 (-141) |#4|)) (-658 |#4|))) (-15 -4556 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|))) (-15 -1974 ((-141) |#4|)) (-15 -3500 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|))) (-15 -2365 ((-141) |#4|)) (-15 -3131 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|))) (-15 -4514 ((-141) |#4|)) (-15 -2638 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|))) (-15 -3073 ((-658 |#4|) (-658 |#4|) (-658 |#4|))) (-15 -3073 ((-658 |#4|) (-658 |#4|) (-658 |#4|) (-141))) (-15 -2789 (|#4| |#4| (-658 |#4|))) (-15 -1767 ((-658 |#4|) (-658 |#4|))) (-15 -1655 ((-3 (-2 (|:| |bas| (-505 |#1| |#2| |#3| |#4|)) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|))) (-15 -4358 ((-658 |#4|) (-658 |#4|))) (-15 -2491 ((-658 |#4|) (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3964 ((-658 |#4|) (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (IF (|has| |#1| (-477)) (PROGN (-15 -4519 ((-658 |#4|) |#4|)) (-15 -2582 ((-658 |#4|) (-658 |#4|))) (-15 -2582 ((-658 |#4|) (-658 |#4|) (-141))) (-15 -2517 ((-658 |#4|) (-658 |#4|) (-658 |#4|))) (-15 -1344 ((-658 |#4|) (-658 |#4|) (-658 |#4|))) (-15 -4275 ((-658 |#4|) (-658 |#4|) (-658 |#4|)))) |noBranch|) (IF (|has| |#1| (-323)) (IF (|has| |#1| (-171)) (PROGN (-15 -2271 ((-658 |#4|) (-658 |#4|))) (-15 -3917 ((-658 |#4|) (-658 |#4|))) (-15 -3815 ((-658 |#4|) (-658 |#4|) (-658 |#4|)))) |noBranch|) |noBranch|)) (-582) (-815) (-869) (-1089 |#1| |#2| |#3|)) (T -1006)) 
+((-3815 (*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-171)) (-4 *3 (-323)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-3917 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-171)) (-4 *3 (-323)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-2271 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-171)) (-4 *3 (-323)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-4275 (*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-477)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-1344 (*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-477)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-2517 (*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-477)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-2582 (*1 *2 *2 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-141)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *7)))) (-2582 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-477)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-4519 (*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *3)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6)))) (-3964 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-658 *8)) (-5 *3 (-1 (-141) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1006 *5 *6 *7 *8)))) (-2491 (*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-658 *9)) (-5 *3 (-1 (-141) *9)) (-5 *4 (-1 (-141) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1089 *6 *7 *8)) (-4 *6 (-582)) (-4 *7 (-815)) (-4 *8 (-869)) (-5 *1 (-1006 *6 *7 *8 *9)))) (-4358 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-1655 (*1 *2 *3) (|partial| -12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |bas| (-505 *4 *5 *6 *7)) (|:| -3349 (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) (-1767 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-2789 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *2)))) (-3073 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-141)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *7)))) (-3073 (*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-2638 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-658 *7)) (|:| |badPols| (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) (-4514 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6)))) (-3131 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-658 *7)) (|:| |badPols| (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) (-2365 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6)))) (-3500 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-658 *7)) (|:| |badPols| (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) (-1974 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6)))) (-4556 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-658 *7)) (|:| |badPols| (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) (-1979 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1 (-141) *8))) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |goodPols| (-658 *8)) (|:| |badPols| (-658 *8)))) (-5 *1 (-1006 *5 *6 *7 *8)) (-5 *4 (-658 *8)))) (-1788 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1 (-141) *8))) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |goodPols| (-658 *8)) (|:| |badPols| (-658 *8)))) (-5 *1 (-1006 *5 *6 *7 *8)) (-5 *4 (-658 *8)))) (-2621 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-141) *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |goodPols| (-658 *8)) (|:| |badPols| (-658 *8)))) (-5 *1 (-1006 *5 *6 *7 *8)) (-5 *4 (-658 *8)))) (-4549 (*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *7)))) (-3320 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-658 *8))) (-5 *3 (-658 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *5 *6 *7 *8)))) (-2924 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *7)))) (-3771 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 (-658 *7) (-658 *7))) (-5 *2 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *7)))) (-3771 (*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-3771 (*1 *2 *2 *3) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *3)))) (-2945 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *3)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6)))) (-3495 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) (-3771 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *3)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6)))) (-3771 (*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(-10 -7 (-15 -3771 ((-658 |#4|) (-658 |#4|))) (-15 -3771 ((-658 |#4|) |#4| |#4|)) (-15 -3495 ((-658 |#4|) (-658 |#4|))) (-15 -2945 ((-658 |#4|) |#4| |#4|)) (-15 -3771 ((-658 |#4|) (-658 |#4|) |#4|)) (-15 -3771 ((-658 |#4|) (-658 |#4|) (-658 |#4|))) (-15 -3771 ((-658 |#4|) (-658 |#4|) (-658 |#4|) (-1 (-658 |#4|) (-658 |#4|)))) (-15 -2924 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3320 ((-141) (-658 |#4|) (-658 (-658 |#4|)))) (-15 -4549 ((-141) (-658 |#4|))) (-15 -2621 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-1 (-141) |#4|) (-658 |#4|))) (-15 -1788 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 (-1 (-141) |#4|)) (-658 |#4|))) (-15 -1979 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 (-1 (-141) |#4|)) (-658 |#4|))) (-15 -4556 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|))) (-15 -1974 ((-141) |#4|)) (-15 -3500 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|))) (-15 -2365 ((-141) |#4|)) (-15 -3131 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|))) (-15 -4514 ((-141) |#4|)) (-15 -2638 ((-2 (|:| |goodPols| (-658 |#4|)) (|:| |badPols| (-658 |#4|))) (-658 |#4|))) (-15 -3073 ((-658 |#4|) (-658 |#4|) (-658 |#4|))) (-15 -3073 ((-658 |#4|) (-658 |#4|) (-658 |#4|) (-141))) (-15 -2789 (|#4| |#4| (-658 |#4|))) (-15 -1767 ((-658 |#4|) (-658 |#4|))) (-15 -1655 ((-3 (-2 (|:| |bas| (-505 |#1| |#2| |#3| |#4|)) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|))) (-15 -4358 ((-658 |#4|) (-658 |#4|))) (-15 -2491 ((-658 |#4|) (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3964 ((-658 |#4|) (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (IF (|has| |#1| (-477)) (PROGN (-15 -4519 ((-658 |#4|) |#4|)) (-15 -2582 ((-658 |#4|) (-658 |#4|))) (-15 -2582 ((-658 |#4|) (-658 |#4|) (-141))) (-15 -2517 ((-658 |#4|) (-658 |#4|) (-658 |#4|))) (-15 -1344 ((-658 |#4|) (-658 |#4|) (-658 |#4|))) (-15 -4275 ((-658 |#4|) (-658 |#4|) (-658 |#4|)))) |noBranch|) (IF (|has| |#1| (-323)) (IF (|has| |#1| (-171)) (PROGN (-15 -2271 ((-658 |#4|) (-658 |#4|))) (-15 -3917 ((-658 |#4|) (-658 |#4|))) (-15 -3815 ((-658 |#4|) (-658 |#4|) (-658 |#4|)))) |noBranch|) |noBranch|)) 
+((-3389 (((-2 (|:| R (-706 |#1|)) (|:| A (-706 |#1|)) (|:| |Ainv| (-706 |#1|))) (-706 |#1|) (-121 |#1|) (-1 |#1| |#1|)) 19)) (-3060 (((-658 (-2 (|:| C (-706 |#1|)) (|:| |g| (-1280 |#1|)))) (-706 |#1|) (-1280 |#1|)) 35)) (-4164 (((-706 |#1|) (-706 |#1|) (-706 |#1|) (-121 |#1|) (-1 |#1| |#1|)) 16))) 
+(((-1007 |#1|) (-10 -7 (-15 -3389 ((-2 (|:| R (-706 |#1|)) (|:| A (-706 |#1|)) (|:| |Ainv| (-706 |#1|))) (-706 |#1|) (-121 |#1|) (-1 |#1| |#1|))) (-15 -4164 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-121 |#1|) (-1 |#1| |#1|))) (-15 -3060 ((-658 (-2 (|:| C (-706 |#1|)) (|:| |g| (-1280 |#1|)))) (-706 |#1|) (-1280 |#1|)))) (-388)) (T -1007)) 
+((-3060 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-5 *2 (-658 (-2 (|:| C (-706 *5)) (|:| |g| (-1280 *5))))) (-5 *1 (-1007 *5)) (-5 *3 (-706 *5)) (-5 *4 (-1280 *5)))) (-4164 (*1 *2 *2 *2 *3 *4) (-12 (-5 *2 (-706 *5)) (-5 *3 (-121 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-388)) (-5 *1 (-1007 *5)))) (-3389 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-121 *6)) (-5 *5 (-1 *6 *6)) (-4 *6 (-388)) (-5 *2 (-2 (|:| R (-706 *6)) (|:| A (-706 *6)) (|:| |Ainv| (-706 *6)))) (-5 *1 (-1007 *6)) (-5 *3 (-706 *6))))) 
+(-10 -7 (-15 -3389 ((-2 (|:| R (-706 |#1|)) (|:| A (-706 |#1|)) (|:| |Ainv| (-706 |#1|))) (-706 |#1|) (-121 |#1|) (-1 |#1| |#1|))) (-15 -4164 ((-706 |#1|) (-706 |#1|) (-706 |#1|) (-121 |#1|) (-1 |#1| |#1|))) (-15 -3060 ((-658 (-2 (|:| C (-706 |#1|)) (|:| |g| (-1280 |#1|)))) (-706 |#1|) (-1280 |#1|)))) 
+((-3164 (((-444 |#4|) |#4|) 47))) 
+(((-1008 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3164 ((-444 |#4|) |#4|))) (-869) (-815) (-477) (-977 |#3| |#2| |#1|)) (T -1008)) 
+((-3164 (*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-477)) (-5 *2 (-444 *3)) (-5 *1 (-1008 *4 *5 *6 *3)) (-4 *3 (-977 *6 *5 *4))))) 
+(-10 -7 (-15 -3164 ((-444 |#4|) |#4|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-1417 (($ (-790)) 105 (|has| |#1| (-23)))) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) 91) (((-141) $) 85 (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) 82 (|has| $ (-6 -4626))) (($ $) 81 (-12 (|has| |#1| (-869)) (|has| $ (-6 -4626))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#1| $ (-592) |#1|) 49 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 53 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) 70 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-2512 (($ $) 83 (|has| $ (-6 -4626)))) (-1373 (($ $) 93)) (-1360 (($ $) 73 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#1| $) 72 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 69 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) 50 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 48)) (-1721 (((-592) (-1 (-141) |#1|) $) 90) (((-592) |#1| $) 89 (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) 88 (|has| |#1| (-1119)))) (-1831 (($ (-658 |#1|)) 110)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4363 (((-706 |#1|) $ $) 98 (|has| |#1| (-1075)))) (-3242 (($ (-790) |#1|) 64)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-1837 (($ $ $) 80 (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3319 (($ $ $) 79 (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2311 ((|#1| $) 95 (-12 (|has| |#1| (-1075)) (|has| |#1| (-1030))))) (-2554 (((-141) $ (-790)) 10)) (-4233 ((|#1| $) 96 (-12 (|has| |#1| (-1075)) (|has| |#1| (-1030))))) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) 55) (($ $ $ (-592)) 54)) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 39 (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 66)) (-1892 (($ $ |#1|) 38 (|has| $ (-6 -4626)))) (-2807 (($ $ (-658 |#1|)) 107)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 42 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ (-592) |#1|) 47) ((|#1| $ (-592)) 46) (($ $ (-1246 (-592))) 58)) (-1729 ((|#1| $ $) 99 (|has| |#1| (-1075)))) (-1936 (((-944) $) 109)) (-3208 (($ $ (-592)) 57) (($ $ (-1246 (-592))) 56)) (-2746 (($ $ $) 97)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-2385 (($ $ $ (-592)) 84 (|has| $ (-6 -4626)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 74 (|has| |#1| (-633 (-565)))) (($ (-658 |#1|)) 108)) (-4466 (($ (-658 |#1|)) 65)) (-2266 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-658 $)) 60)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) 77 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 76 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-3279 (((-141) $ $) 78 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 75 (|has| |#1| (-869)))) (-3306 (($ $) 104 (|has| |#1| (-21))) (($ $ $) 103 (|has| |#1| (-21)))) (-3300 (($ $ $) 106 (|has| |#1| (-25)))) (* (($ (-592) $) 102 (|has| |#1| (-21))) (($ |#1| $) 101 (|has| |#1| (-743))) (($ $ |#1|) 100 (|has| |#1| (-743)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1009 |#1|) (-1311) (-1075)) (T -1009)) 
+((-1831 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1075)) (-4 *1 (-1009 *3)))) (-1936 (*1 *2 *1) (-12 (-4 *1 (-1009 *3)) (-4 *3 (-1075)) (-5 *2 (-944)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1075)) (-4 *1 (-1009 *3)))) (-2746 (*1 *1 *1 *1) (-12 (-4 *1 (-1009 *2)) (-4 *2 (-1075)))) (-2807 (*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *1 (-1009 *3)) (-4 *3 (-1075))))) 
+(-13 (-1278 |t#1|) (-10 -8 (-15 -1831 ($ (-658 |t#1|))) (-15 -1936 ((-944) $)) (-15 -1778 ($ (-658 |t#1|))) (-15 -2746 ($ $ $)) (-15 -2807 ($ $ (-658 |t#1|))))) 
+(((-39) . T) ((-125) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-632 (-877)) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-399 |#1|) . T) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-664 |#1|) . T) ((-19 |#1|) . T) ((-869) |has| |#1| (-869)) ((-1119) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-1225) . T) ((-1278 |#1|) . T)) 
+((-2731 (((-971 |#2|) (-1 |#2| |#1|) (-971 |#1|)) 17))) 
+(((-1010 |#1| |#2|) (-10 -7 (-15 -2731 ((-971 |#2|) (-1 |#2| |#1|) (-971 |#1|)))) (-1075) (-1075)) (T -1010)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-971 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-971 *6)) (-5 *1 (-1010 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-971 |#2|) (-1 |#2| |#1|) (-971 |#1|)))) 
+((-1612 ((|#1| (-971 |#1|)) 13)) (-2883 ((|#1| (-971 |#1|)) 12)) (-3913 ((|#1| (-971 |#1|)) 11)) (-1821 ((|#1| (-971 |#1|)) 15)) (-3150 ((|#1| (-971 |#1|)) 21)) (-1467 ((|#1| (-971 |#1|)) 14)) (-1694 ((|#1| (-971 |#1|)) 16)) (-3850 ((|#1| (-971 |#1|)) 20)) (-2932 ((|#1| (-971 |#1|)) 19))) 
+(((-1011 |#1|) (-10 -7 (-15 -3913 (|#1| (-971 |#1|))) (-15 -2883 (|#1| (-971 |#1|))) (-15 -1612 (|#1| (-971 |#1|))) (-15 -1467 (|#1| (-971 |#1|))) (-15 -1821 (|#1| (-971 |#1|))) (-15 -1694 (|#1| (-971 |#1|))) (-15 -2932 (|#1| (-971 |#1|))) (-15 -3850 (|#1| (-971 |#1|))) (-15 -3150 (|#1| (-971 |#1|)))) (-1075)) (T -1011)) 
+((-3150 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075)))) (-3850 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075)))) (-2932 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075)))) (-1694 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075)))) (-1821 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075)))) (-1467 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075)))) (-1612 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075)))) (-2883 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075)))) (-3913 (*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(-10 -7 (-15 -3913 (|#1| (-971 |#1|))) (-15 -2883 (|#1| (-971 |#1|))) (-15 -1612 (|#1| (-971 |#1|))) (-15 -1467 (|#1| (-971 |#1|))) (-15 -1821 (|#1| (-971 |#1|))) (-15 -1694 (|#1| (-971 |#1|))) (-15 -2932 (|#1| (-971 |#1|))) (-15 -3850 (|#1| (-971 |#1|))) (-15 -3150 (|#1| (-971 |#1|)))) 
+((-2698 (((-3 |#1| "failed") |#1|) 18)) (-2540 (((-3 |#1| "failed") |#1|) 6)) (-4494 (((-3 |#1| "failed") |#1|) 16)) (-1923 (((-3 |#1| "failed") |#1|) 4)) (-1890 (((-3 |#1| "failed") |#1|) 20)) (-2063 (((-3 |#1| "failed") |#1|) 8)) (-1784 (((-3 |#1| "failed") |#1| (-790)) 1)) (-2548 (((-3 |#1| "failed") |#1|) 3)) (-4122 (((-3 |#1| "failed") |#1|) 2)) (-1415 (((-3 |#1| "failed") |#1|) 21)) (-2478 (((-3 |#1| "failed") |#1|) 9)) (-4208 (((-3 |#1| "failed") |#1|) 19)) (-2345 (((-3 |#1| "failed") |#1|) 7)) (-2966 (((-3 |#1| "failed") |#1|) 17)) (-2989 (((-3 |#1| "failed") |#1|) 5)) (-1650 (((-3 |#1| "failed") |#1|) 24)) (-3209 (((-3 |#1| "failed") |#1|) 12)) (-2416 (((-3 |#1| "failed") |#1|) 22)) (-4352 (((-3 |#1| "failed") |#1|) 10)) (-4069 (((-3 |#1| "failed") |#1|) 26)) (-3691 (((-3 |#1| "failed") |#1|) 14)) (-2590 (((-3 |#1| "failed") |#1|) 27)) (-1349 (((-3 |#1| "failed") |#1|) 15)) (-2295 (((-3 |#1| "failed") |#1|) 25)) (-2233 (((-3 |#1| "failed") |#1|) 13)) (-1510 (((-3 |#1| "failed") |#1|) 23)) (-2153 (((-3 |#1| "failed") |#1|) 11))) 
+(((-1012 |#1|) (-1311) (-1211)) (T -1012)) 
+((-2590 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-4069 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2295 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-1650 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-1510 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2416 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-1415 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-1890 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-4208 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2698 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2966 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-4494 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-1349 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-3691 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2233 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-3209 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2153 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-4352 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2478 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2063 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2345 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2540 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2989 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-1923 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-2548 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-4122 (*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211)))) (-1784 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-790)) (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(-13 (-10 -7 (-15 -1784 ((-3 |t#1| "failed") |t#1| (-790))) (-15 -4122 ((-3 |t#1| "failed") |t#1|)) (-15 -2548 ((-3 |t#1| "failed") |t#1|)) (-15 -1923 ((-3 |t#1| "failed") |t#1|)) (-15 -2989 ((-3 |t#1| "failed") |t#1|)) (-15 -2540 ((-3 |t#1| "failed") |t#1|)) (-15 -2345 ((-3 |t#1| "failed") |t#1|)) (-15 -2063 ((-3 |t#1| "failed") |t#1|)) (-15 -2478 ((-3 |t#1| "failed") |t#1|)) (-15 -4352 ((-3 |t#1| "failed") |t#1|)) (-15 -2153 ((-3 |t#1| "failed") |t#1|)) (-15 -3209 ((-3 |t#1| "failed") |t#1|)) (-15 -2233 ((-3 |t#1| "failed") |t#1|)) (-15 -3691 ((-3 |t#1| "failed") |t#1|)) (-15 -1349 ((-3 |t#1| "failed") |t#1|)) (-15 -4494 ((-3 |t#1| "failed") |t#1|)) (-15 -2966 ((-3 |t#1| "failed") |t#1|)) (-15 -2698 ((-3 |t#1| "failed") |t#1|)) (-15 -4208 ((-3 |t#1| "failed") |t#1|)) (-15 -1890 ((-3 |t#1| "failed") |t#1|)) (-15 -1415 ((-3 |t#1| "failed") |t#1|)) (-15 -2416 ((-3 |t#1| "failed") |t#1|)) (-15 -1510 ((-3 |t#1| "failed") |t#1|)) (-15 -1650 ((-3 |t#1| "failed") |t#1|)) (-15 -2295 ((-3 |t#1| "failed") |t#1|)) (-15 -4069 ((-3 |t#1| "failed") |t#1|)) (-15 -2590 ((-3 |t#1| "failed") |t#1|)))) 
+((-3292 ((|#4| |#4| (-658 |#3|)) 55) ((|#4| |#4| |#3|) 54)) (-3978 ((|#4| |#4| (-658 |#3|)) 23) ((|#4| |#4| |#3|) 19)) (-2731 ((|#4| (-1 |#4| (-980 |#1|)) |#4|) 30))) 
+(((-1013 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3978 (|#4| |#4| |#3|)) (-15 -3978 (|#4| |#4| (-658 |#3|))) (-15 -3292 (|#4| |#4| |#3|)) (-15 -3292 (|#4| |#4| (-658 |#3|))) (-15 -2731 (|#4| (-1 |#4| (-980 |#1|)) |#4|))) (-1075) (-815) (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191))))) (-977 (-980 |#1|) |#2| |#3|)) (T -1013)) 
+((-2731 (*1 *2 *3 *2) (-12 (-5 *3 (-1 *2 (-980 *4))) (-4 *4 (-1075)) (-4 *2 (-977 (-980 *4) *5 *6)) (-4 *5 (-815)) (-4 *6 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-5 *1 (-1013 *4 *5 *6 *2)))) (-3292 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-4 *4 (-1075)) (-4 *5 (-815)) (-5 *1 (-1013 *4 *5 *6 *2)) (-4 *2 (-977 (-980 *4) *5 *6)))) (-3292 (*1 *2 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-5 *1 (-1013 *4 *5 *3 *2)) (-4 *2 (-977 (-980 *4) *5 *3)))) (-3978 (*1 *2 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-4 *4 (-1075)) (-4 *5 (-815)) (-5 *1 (-1013 *4 *5 *6 *2)) (-4 *2 (-977 (-980 *4) *5 *6)))) (-3978 (*1 *2 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-5 *1 (-1013 *4 *5 *3 *2)) (-4 *2 (-977 (-980 *4) *5 *3))))) 
+(-10 -7 (-15 -3978 (|#4| |#4| |#3|)) (-15 -3978 (|#4| |#4| (-658 |#3|))) (-15 -3292 (|#4| |#4| |#3|)) (-15 -3292 (|#4| |#4| (-658 |#3|))) (-15 -2731 (|#4| (-1 |#4| (-980 |#1|)) |#4|))) 
+((-2813 ((|#2| |#3|) 34)) (-2583 (((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) |#2|) 71)) (-4023 (((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|)))) 86))) 
+(((-1014 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4023 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))))) (-15 -2583 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) |#2|)) (-15 -2813 (|#2| |#3|))) (-373) (-1255 |#1|) (-1255 |#2|) (-741 |#2| |#3|)) (T -1014)) 
+((-2813 (*1 *2 *3) (-12 (-4 *3 (-1255 *2)) (-4 *2 (-1255 *4)) (-5 *1 (-1014 *4 *2 *3 *5)) (-4 *4 (-373)) (-4 *5 (-741 *2 *3)))) (-2583 (*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-1014 *4 *3 *5 *6)) (-4 *6 (-741 *3 *5)))) (-4023 (*1 *2) (-12 (-4 *3 (-373)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -2195 (-706 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-706 *4)))) (-5 *1 (-1014 *3 *4 *5 *6)) (-4 *6 (-741 *4 *5))))) 
+(-10 -7 (-15 -4023 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))))) (-15 -2583 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) |#2|)) (-15 -2813 (|#2| |#3|))) 
+((-4508 (((-1016 (-433 (-592)) (-879 |#1|) (-254 |#2| (-790)) (-264 |#1| (-433 (-592)))) (-1016 (-433 (-592)) (-879 |#1|) (-254 |#2| (-790)) (-264 |#1| (-433 (-592))))) 64))) 
+(((-1015 |#1| |#2|) (-10 -7 (-15 -4508 ((-1016 (-433 (-592)) (-879 |#1|) (-254 |#2| (-790)) (-264 |#1| (-433 (-592)))) (-1016 (-433 (-592)) (-879 |#1|) (-254 |#2| (-790)) (-264 |#1| (-433 (-592))))))) (-658 (-1191)) (-790)) (T -1015)) 
+((-4508 (*1 *2 *2) (-12 (-5 *2 (-1016 (-433 (-592)) (-879 *3) (-254 *4 (-790)) (-264 *3 (-433 (-592))))) (-14 *3 (-658 (-1191))) (-14 *4 (-790)) (-5 *1 (-1015 *3 *4))))) 
+(-10 -7 (-15 -4508 ((-1016 (-433 (-592)) (-879 |#1|) (-254 |#2| (-790)) (-264 |#1| (-433 (-592)))) (-1016 (-433 (-592)) (-879 |#1|) (-254 |#2| (-790)) (-264 |#1| (-433 (-592))))))) 
+((-1641 (((-141) $ $) NIL)) (-4499 (((-3 (-141) "failed") $) 67)) (-1849 (($ $) 35 (-12 (|has| |#1| (-171)) (|has| |#1| (-323))))) (-3377 (($ $ (-3 (-141) "failed")) 68)) (-3373 (($ (-658 |#4|) |#4|) 24)) (-2685 (((-1173) $) NIL)) (-1368 (($ $) 65)) (-2951 (((-1137) $) NIL)) (-2943 (((-141) $) 66)) (-2890 (($) 29)) (-1910 ((|#4| $) 70)) (-2605 (((-658 |#4|) $) 69)) (-1683 (((-877) $) 64)) (-3255 (((-141) $ $) NIL))) 
+(((-1016 |#1| |#2| |#3| |#4|) (-13 (-1119) (-632 (-877)) (-10 -8 (-15 -2890 ($)) (-15 -3373 ($ (-658 |#4|) |#4|)) (-15 -4499 ((-3 (-141) "failed") $)) (-15 -3377 ($ $ (-3 (-141) "failed"))) (-15 -2943 ((-141) $)) (-15 -2605 ((-658 |#4|) $)) (-15 -1910 (|#4| $)) (-15 -1368 ($ $)) (IF (|has| |#1| (-323)) (IF (|has| |#1| (-171)) (-15 -1849 ($ $)) |noBranch|) |noBranch|))) (-477) (-869) (-815) (-977 |#1| |#3| |#2|)) (T -1016)) 
+((-2890 (*1 *1) (-12 (-4 *2 (-477)) (-4 *3 (-869)) (-4 *4 (-815)) (-5 *1 (-1016 *2 *3 *4 *5)) (-4 *5 (-977 *2 *4 *3)))) (-3373 (*1 *1 *2 *3) (-12 (-5 *2 (-658 *3)) (-4 *3 (-977 *4 *6 *5)) (-4 *4 (-477)) (-4 *5 (-869)) (-4 *6 (-815)) (-5 *1 (-1016 *4 *5 *6 *3)))) (-4499 (*1 *2 *1) (|partial| -12 (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)) (-5 *2 (-141)) (-5 *1 (-1016 *3 *4 *5 *6)) (-4 *6 (-977 *3 *5 *4)))) (-3377 (*1 *1 *1 *2) (-12 (-5 *2 (-3 (-141) "failed")) (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)) (-5 *1 (-1016 *3 *4 *5 *6)) (-4 *6 (-977 *3 *5 *4)))) (-2943 (*1 *2 *1) (-12 (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)) (-5 *2 (-141)) (-5 *1 (-1016 *3 *4 *5 *6)) (-4 *6 (-977 *3 *5 *4)))) (-2605 (*1 *2 *1) (-12 (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)) (-5 *2 (-658 *6)) (-5 *1 (-1016 *3 *4 *5 *6)) (-4 *6 (-977 *3 *5 *4)))) (-1910 (*1 *2 *1) (-12 (-4 *2 (-977 *3 *5 *4)) (-5 *1 (-1016 *3 *4 *5 *2)) (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)))) (-1368 (*1 *1 *1) (-12 (-4 *2 (-477)) (-4 *3 (-869)) (-4 *4 (-815)) (-5 *1 (-1016 *2 *3 *4 *5)) (-4 *5 (-977 *2 *4 *3)))) (-1849 (*1 *1 *1) (-12 (-4 *2 (-171)) (-4 *2 (-323)) (-4 *2 (-477)) (-4 *3 (-869)) (-4 *4 (-815)) (-5 *1 (-1016 *2 *3 *4 *5)) (-4 *5 (-977 *2 *4 *3))))) 
+(-13 (-1119) (-632 (-877)) (-10 -8 (-15 -2890 ($)) (-15 -3373 ($ (-658 |#4|) |#4|)) (-15 -4499 ((-3 (-141) "failed") $)) (-15 -3377 ($ $ (-3 (-141) "failed"))) (-15 -2943 ((-141) $)) (-15 -2605 ((-658 |#4|) $)) (-15 -1910 (|#4| $)) (-15 -1368 ($ $)) (IF (|has| |#1| (-323)) (IF (|has| |#1| (-171)) (-15 -1849 ($ $)) |noBranch|) |noBranch|))) 
+((-3635 (((-141) |#5| |#5|) 37)) (-2846 (((-141) |#5| |#5|) 51)) (-3962 (((-141) |#5| (-658 |#5|)) 73) (((-141) |#5| |#5|) 60)) (-3988 (((-141) (-658 |#4|) (-658 |#4|)) 57)) (-2728 (((-141) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) 62)) (-3128 (((-1285)) 33)) (-4376 (((-1285) (-1173) (-1173) (-1173)) 29)) (-1859 (((-658 |#5|) (-658 |#5|)) 80)) (-2441 (((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) 78)) (-4015 (((-658 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|)))) (-658 |#4|) (-658 |#5|) (-141) (-141)) 100)) (-1496 (((-141) |#5| |#5|) 46)) (-2655 (((-3 (-141) "failed") |#5| |#5|) 70)) (-3274 (((-141) (-658 |#4|) (-658 |#4|)) 56)) (-3481 (((-141) (-658 |#4|) (-658 |#4|)) 58)) (-3085 (((-141) (-658 |#4|) (-658 |#4|)) 59)) (-1481 (((-3 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|))) "failed") (-658 |#4|) |#5| (-658 |#4|) (-141) (-141) (-141) (-141) (-141)) 96)) (-3174 (((-658 |#5|) (-658 |#5|)) 42))) 
+(((-1017 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4376 ((-1285) (-1173) (-1173) (-1173))) (-15 -3128 ((-1285))) (-15 -3635 ((-141) |#5| |#5|)) (-15 -3174 ((-658 |#5|) (-658 |#5|))) (-15 -1496 ((-141) |#5| |#5|)) (-15 -2846 ((-141) |#5| |#5|)) (-15 -3988 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3274 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3481 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3085 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -2655 ((-3 (-141) "failed") |#5| |#5|)) (-15 -3962 ((-141) |#5| |#5|)) (-15 -3962 ((-141) |#5| (-658 |#5|))) (-15 -1859 ((-658 |#5|) (-658 |#5|))) (-15 -2728 ((-141) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) (-15 -2441 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-15 -4015 ((-658 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|)))) (-658 |#4|) (-658 |#5|) (-141) (-141))) (-15 -1481 ((-3 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|))) "failed") (-658 |#4|) |#5| (-658 |#4|) (-141) (-141) (-141) (-141) (-141)))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1094 |#1| |#2| |#3| |#4|)) (T -1017)) 
+((-1481 (*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| -2042 (-658 *9)) (|:| -2165 *4) (|:| |ineq| (-658 *9)))) (-5 *1 (-1017 *6 *7 *8 *9 *4)) (-5 *3 (-658 *9)) (-4 *4 (-1094 *6 *7 *8 *9)))) (-4015 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-658 *10)) (-5 *5 (-141)) (-4 *10 (-1094 *6 *7 *8 *9)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-1089 *6 *7 *8)) (-5 *2 (-658 (-2 (|:| -2042 (-658 *9)) (|:| -2165 *10) (|:| |ineq| (-658 *9))))) (-5 *1 (-1017 *6 *7 *8 *9 *10)) (-5 *3 (-658 *9)))) (-2441 (*1 *2 *2) (-12 (-5 *2 (-658 (-2 (|:| |val| (-658 *6)) (|:| -2165 *7)))) (-4 *6 (-1089 *3 *4 *5)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1017 *3 *4 *5 *6 *7)))) (-2728 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-658 *7)) (|:| -2165 *8))) (-4 *7 (-1089 *4 *5 *6)) (-4 *8 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)))) (-1859 (*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-1017 *3 *4 *5 *6 *7)))) (-3962 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-1017 *5 *6 *7 *8 *3)))) (-3962 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-2655 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-3085 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-3481 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-3274 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-3988 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-2846 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-1496 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-3174 (*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-1017 *3 *4 *5 *6 *7)))) (-3635 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-3128 (*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1017 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) (-4376 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -4376 ((-1285) (-1173) (-1173) (-1173))) (-15 -3128 ((-1285))) (-15 -3635 ((-141) |#5| |#5|)) (-15 -3174 ((-658 |#5|) (-658 |#5|))) (-15 -1496 ((-141) |#5| |#5|)) (-15 -2846 ((-141) |#5| |#5|)) (-15 -3988 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3274 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3481 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3085 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -2655 ((-3 (-141) "failed") |#5| |#5|)) (-15 -3962 ((-141) |#5| |#5|)) (-15 -3962 ((-141) |#5| (-658 |#5|))) (-15 -1859 ((-658 |#5|) (-658 |#5|))) (-15 -2728 ((-141) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) (-15 -2441 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-15 -4015 ((-658 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|)))) (-658 |#4|) (-658 |#5|) (-141) (-141))) (-15 -1481 ((-3 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|))) "failed") (-658 |#4|) |#5| (-658 |#4|) (-141) (-141) (-141) (-141) (-141)))) 
+((-3983 (((-1191) $) 15)) (-2324 (((-1173) $) 16)) (-2724 (($ (-1191) (-1173)) 14)) (-1683 (((-877) $) 13))) 
+(((-1018) (-13 (-632 (-877)) (-10 -8 (-15 -2724 ($ (-1191) (-1173))) (-15 -3983 ((-1191) $)) (-15 -2324 ((-1173) $))))) (T -1018)) 
+((-2724 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1173)) (-5 *1 (-1018)))) (-3983 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1018)))) (-2324 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1018))))) 
+(-13 (-632 (-877)) (-10 -8 (-15 -2724 ($ (-1191) (-1173))) (-15 -3983 ((-1191) $)) (-15 -2324 ((-1173) $)))) 
+((-2731 ((|#4| (-1 |#2| |#1|) |#3|) 14))) 
+(((-1019 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#4| (-1 |#2| |#1|) |#3|))) (-582) (-582) (-1021 |#1|) (-1021 |#2|)) (T -1019)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-582)) (-4 *6 (-582)) (-4 *2 (-1021 *6)) (-5 *1 (-1019 *5 *6 *4 *2)) (-4 *4 (-1021 *5))))) 
+(-10 -7 (-15 -2731 (|#4| (-1 |#2| |#1|) |#3|))) 
+((-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-1191) "failed") $) 65) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 (-592) "failed") $) 95)) (-2400 ((|#2| $) NIL) (((-1191) $) 60) (((-433 (-592)) $) NIL) (((-592) $) 92)) (-3945 (((-706 (-592)) (-706 $)) NIL) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) 112) (((-706 |#2|) (-706 $)) 28)) (-4290 (($) 98)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 74) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 83)) (-3838 (($ $) 10)) (-3921 (((-3 $ "failed") $) 20)) (-2731 (($ (-1 |#2| |#2|) $) 22)) (-3703 (($) 16)) (-3856 (($ $) 54)) (-3644 (($ $) NIL) (($ $ (-790)) NIL) (($ $ (-1191)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) 36)) (-2782 (($ $) 12)) (-1778 (((-914 (-592)) $) 69) (((-914 (-405)) $) 78) (((-565) $) 40) (((-405) $) 44) (((-237) $) 47)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) 90) (($ |#2|) NIL) (($ (-1191)) 57)) (-4010 (((-790)) 31)) (-3266 (((-141) $ $) 50))) 
+(((-1020 |#1| |#2|) (-10 -8 (-15 -3266 ((-141) |#1| |#1|)) (-15 -3703 (|#1|)) (-15 -3921 ((-3 |#1| "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1778 ((-237) |#1|)) (-15 -1778 ((-405) |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -2400 ((-1191) |#1|)) (-15 -4368 ((-3 (-1191) "failed") |#1|)) (-15 -1683 (|#1| (-1191))) (-15 -4290 (|#1|)) (-15 -3856 (|#1| |#1|)) (-15 -2782 (|#1| |#1|)) (-15 -3838 (|#1| |#1|)) (-15 -3412 ((-911 (-405) |#1|) |#1| (-914 (-405)) (-911 (-405) |#1|))) (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|))) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -3945 ((-706 |#2|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| |#1|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 -1683 ((-877) |#1|))) (-1021 |#2|) (-582)) (T -1020)) 
+((-4010 (*1 *2) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-1020 *3 *4)) (-4 *3 (-1021 *4))))) 
+(-10 -8 (-15 -3266 ((-141) |#1| |#1|)) (-15 -3703 (|#1|)) (-15 -3921 ((-3 |#1| "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1778 ((-237) |#1|)) (-15 -1778 ((-405) |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -2400 ((-1191) |#1|)) (-15 -4368 ((-3 (-1191) "failed") |#1|)) (-15 -1683 (|#1| (-1191))) (-15 -4290 (|#1|)) (-15 -3856 (|#1| |#1|)) (-15 -2782 (|#1| |#1|)) (-15 -3838 (|#1| |#1|)) (-15 -3412 ((-911 (-405) |#1|) |#1| (-914 (-405)) (-911 (-405) |#1|))) (-15 -3412 ((-911 (-592) |#1|) |#1| (-914 (-592)) (-911 (-592) |#1|))) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -3945 ((-706 |#2|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| |#1|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-1505 ((|#1| $) 137 (|has| |#1| (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-4043 (((-444 (-1187 $)) (-1187 $)) 128 (|has| |#1| (-931)))) (-3743 (($ $) 73)) (-3164 (((-444 $) $) 72)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 131 (|has| |#1| (-931)))) (-3652 (((-141) $ $) 58)) (-3940 (((-592) $) 118 (|has| |#1| (-842)))) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 176) (((-3 (-1191) "failed") $) 126 (|has| |#1| (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) 110 (|has| |#1| (-1065 (-592)))) (((-3 (-592) "failed") $) 108 (|has| |#1| (-1065 (-592))))) (-2400 ((|#1| $) 175) (((-1191) $) 125 (|has| |#1| (-1065 (-1191)))) (((-433 (-592)) $) 109 (|has| |#1| (-1065 (-592)))) (((-592) $) 107 (|has| |#1| (-1065 (-592))))) (-1586 (($ $ $) 54)) (-3945 (((-706 (-592)) (-706 $)) 150 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 149 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 148) (((-706 |#1|) (-706 $)) 147)) (-3371 (((-3 $ "failed") $) 33)) (-4290 (($) 135 (|has| |#1| (-574)))) (-1599 (($ $ $) 55)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 50)) (-2802 (((-141) $) 71)) (-1691 (((-141) $) 120 (|has| |#1| (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 144 (|has| |#1| (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 143 (|has| |#1| (-908 (-405))))) (-3558 (((-141) $) 30)) (-3838 (($ $) 139)) (-1448 ((|#1| $) 141)) (-3921 (((-3 $ "failed") $) 106 (|has| |#1| (-1165)))) (-1324 (((-141) $) 119 (|has| |#1| (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 51)) (-1837 (($ $ $) 116 (|has| |#1| (-869)))) (-3319 (($ $ $) 115 (|has| |#1| (-869)))) (-2731 (($ (-1 |#1| |#1|) $) 167)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 48)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 70)) (-3703 (($) 105 (|has| |#1| (-1165)) CONST)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3856 (($ $) 136 (|has| |#1| (-323)))) (-2039 ((|#1| $) 133 (|has| |#1| (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) 130 (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) 129 (|has| |#1| (-931)))) (-4500 (((-444 $) $) 74)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 53) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 52)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 49)) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) 173 (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) 172 (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) 171 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) 170 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) 169 (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) 168 (|has| |#1| (-547 (-1191) |#1|)))) (-2769 (((-790) $) 57)) (-3927 (($ $ |#1|) 174 (|has| |#1| (-303 |#1| |#1|)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 56)) (-3644 (($ $) 166 (|has| |#1| (-247))) (($ $ (-790)) 164 (|has| |#1| (-247))) (($ $ (-1191)) 162 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 161 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 160 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) 159 (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) 152) (($ $ (-1 |#1| |#1|)) 151)) (-2782 (($ $) 138)) (-1456 ((|#1| $) 140)) (-1778 (((-914 (-592)) $) 146 (|has| |#1| (-633 (-914 (-592))))) (((-914 (-405)) $) 145 (|has| |#1| (-633 (-914 (-405))))) (((-565) $) 123 (|has| |#1| (-633 (-565)))) (((-405) $) 122 (|has| |#1| (-1049))) (((-237) $) 121 (|has| |#1| (-1049)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 132 (-1732 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 65) (($ |#1|) 179) (($ (-1191)) 127 (|has| |#1| (-1065 (-1191))))) (-1517 (((-3 $ "failed") $) 124 (-3836 (|has| |#1| (-169)) (-1732 (|has| $ (-169)) (|has| |#1| (-931)))))) (-4010 (((-790)) 28)) (-2744 ((|#1| $) 134 (|has| |#1| (-574)))) (-2537 (((-141) $ $) 38)) (-1392 (($ $) 117 (|has| |#1| (-842)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 69)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $) 165 (|has| |#1| (-247))) (($ $ (-790)) 163 (|has| |#1| (-247))) (($ $ (-1191)) 158 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 157 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 156 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) 155 (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) 154) (($ $ (-1 |#1| |#1|)) 153)) (-3286 (((-141) $ $) 113 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 112 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 114 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 111 (|has| |#1| (-869)))) (-3313 (($ $ $) 64) (($ |#1| |#1|) 142)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 68)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 67) (($ (-433 (-592)) $) 66) (($ |#1| $) 178) (($ $ |#1|) 177))) 
+(((-1021 |#1|) (-1311) (-582)) (T -1021)) 
+((-3313 (*1 *1 *2 *2) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)))) (-1448 (*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)))) (-1456 (*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)))) (-3838 (*1 *1 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)))) (-2782 (*1 *1 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)))) (-1505 (*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)) (-4 *2 (-323)))) (-3856 (*1 *1 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)) (-4 *2 (-323)))) (-4290 (*1 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-574)) (-4 *2 (-582)))) (-2744 (*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)) (-4 *2 (-574)))) (-2039 (*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)) (-4 *2 (-574))))) 
+(-13 (-388) (-43 |t#1|) (-1065 |t#1|) (-358 |t#1|) (-245 |t#1|) (-403 |t#1|) (-906 |t#1|) (-426 |t#1|) (-10 -8 (-15 -3313 ($ |t#1| |t#1|)) (-15 -1448 (|t#1| $)) (-15 -1456 (|t#1| $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (IF (|has| |t#1| (-1165)) (-6 (-1165)) |noBranch|) (IF (|has| |t#1| (-1065 (-592))) (PROGN (-6 (-1065 (-592))) (-6 (-1065 (-433 (-592))))) |noBranch|) (IF (|has| |t#1| (-869)) (-6 (-869)) |noBranch|) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-1049)) (-6 (-1049)) |noBranch|) (IF (|has| |t#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (IF (|has| |t#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |t#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |t#1| (-1065 (-1191))) (-6 (-1065 (-1191))) |noBranch|) (IF (|has| |t#1| (-323)) (PROGN (-15 -1505 (|t#1| $)) (-15 -3856 ($ $))) |noBranch|) (IF (|has| |t#1| (-574)) (PROGN (-15 -4290 ($)) (-15 -2744 (|t#1| $)) (-15 -2039 (|t#1| $))) |noBranch|) (IF (|has| |t#1| (-931)) (-6 (-931)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 |#1|) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 |#1| |#1|) . T) ((-140 $ $) . T) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) . T) ((-633 (-237)) |has| |#1| (-1049)) ((-633 (-405)) |has| |#1| (-1049)) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-633 (-914 (-405))) |has| |#1| (-633 (-914 (-405)))) ((-633 (-914 (-592))) |has| |#1| (-633 (-914 (-592)))) ((-245 |#1|) . T) ((-247) |has| |#1| (-247)) ((-260) . T) ((-303 |#1| $) |has| |#1| (-303 |#1| |#1|)) ((-307) . T) ((-323) . T) ((-325 |#1|) |has| |#1| (-325 |#1|)) ((-388) . T) ((-358 |#1|) . T) ((-403 |#1|) . T) ((-426 |#1|) . T) ((-477) . T) ((-547 (-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((-547 |#1| |#1|) |has| |#1| (-325 |#1|)) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-678) . T) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-734 (-433 (-592))) . T) ((-734 |#1|) . T) ((-734 $) . T) ((-743) . T) ((-813) |has| |#1| (-842)) ((-814) |has| |#1| (-842)) ((-816) |has| |#1| (-842)) ((-817) |has| |#1| (-842)) ((-842) |has| |#1| (-842)) ((-867) |has| |#1| (-842)) ((-869) -3836 (|has| |#1| (-869)) (|has| |#1| (-842))) ((-922 (-1191)) |has| |#1| (-922 (-1191))) ((-908 (-405)) |has| |#1| (-908 (-405))) ((-908 (-592)) |has| |#1| (-908 (-592))) ((-906 |#1|) . T) ((-931) |has| |#1| (-931)) ((-943) . T) ((-1049) |has| |#1| (-1049)) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-592))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 (-1191)) |has| |#1| (-1065 (-1191))) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) . T) ((-1081 |#1|) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) |has| |#1| (-1165)) ((-1225) . T) ((-1235) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3451 (($ (-1156 |#1| |#2|)) 11)) (-4186 (((-1156 |#1| |#2|) $) 12)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3927 ((|#2| $ (-254 |#1| |#2|)) 16)) (-1683 (((-877) $) NIL)) (-3514 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL))) 
+(((-1022 |#1| |#2|) (-13 (-21) (-10 -8 (-15 -3451 ($ (-1156 |#1| |#2|))) (-15 -4186 ((-1156 |#1| |#2|) $)) (-15 -3927 (|#2| $ (-254 |#1| |#2|))))) (-944) (-388)) (T -1022)) 
+((-3451 (*1 *1 *2) (-12 (-5 *2 (-1156 *3 *4)) (-14 *3 (-944)) (-4 *4 (-388)) (-5 *1 (-1022 *3 *4)))) (-4186 (*1 *2 *1) (-12 (-5 *2 (-1156 *3 *4)) (-5 *1 (-1022 *3 *4)) (-14 *3 (-944)) (-4 *4 (-388)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 (-254 *4 *2)) (-14 *4 (-944)) (-4 *2 (-388)) (-5 *1 (-1022 *4 *2))))) 
+(-13 (-21) (-10 -8 (-15 -3451 ($ (-1156 |#1| |#2|))) (-15 -4186 ((-1156 |#1| |#2|) $)) (-15 -3927 (|#2| $ (-254 |#1| |#2|))))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) 8)) (-3001 (($) 7 T CONST)) (-4179 (($ $) 43)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-4233 (((-790) $) 42)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1476 ((|#1| $) 41)) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-1659 ((|#1| |#1| $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-1716 ((|#1| $) 44)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 39)) (-2829 ((|#1| $) 40)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1023 |#1|) (-1311) (-1225)) (T -1023)) 
+((-1659 (*1 *2 *2 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) (-1716 (*1 *2 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) (-4179 (*1 *1 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) (-4233 (*1 *2 *1) (-12 (-4 *1 (-1023 *3)) (-4 *3 (-1225)) (-5 *2 (-790)))) (-1476 (*1 *2 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) (-2829 (*1 *2 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225))))) 
+(-13 (-131 |t#1|) (-10 -8 (-6 -4625) (-15 -1659 (|t#1| |t#1| $)) (-15 -1716 (|t#1| $)) (-15 -4179 ($ $)) (-15 -4233 ((-790) $)) (-15 -1476 (|t#1| $)) (-15 -2829 (|t#1| $)))) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-2272 (((-141) $) 42)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 |#2| "failed") $) 45)) (-2400 (((-592) $) NIL) (((-433 (-592)) $) NIL) ((|#2| $) 43)) (-4182 (((-3 (-433 (-592)) "failed") $) 78)) (-2435 (((-141) $) 72)) (-2270 (((-433 (-592)) $) 76)) (-3558 (((-141) $) 41)) (-2793 ((|#2| $) 22)) (-2731 (($ (-1 |#2| |#2|) $) 19)) (-4552 (($ $) 61)) (-3644 (($ $) NIL) (($ $ (-790)) NIL) (($ $ (-1191)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) 34)) (-1778 (((-565) $) 67)) (-2227 (($ $) 17)) (-1683 (((-877) $) 56) (($ (-592)) 38) (($ |#2|) 36) (($ (-433 (-592))) NIL)) (-4010 (((-790)) 10)) (-1392 ((|#2| $) 71)) (-3255 (((-141) $ $) 25)) (-3266 (((-141) $ $) 69)) (-3306 (($ $) 29) (($ $ $) 28)) (-3300 (($ $ $) 26)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 33) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 30) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL))) 
+(((-1024 |#1| |#2|) (-10 -8 (-15 -1683 (|#1| (-433 (-592)))) (-15 -3266 ((-141) |#1| |#1|)) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 * (|#1| |#1| (-433 (-592)))) (-15 -4552 (|#1| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -1392 (|#2| |#1|)) (-15 -2793 (|#2| |#1|)) (-15 -2227 (|#1| |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1683 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 -3558 ((-141) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 -2272 ((-141) |#1|)) (-15 * (|#1| (-944) |#1|)) (-15 -3300 (|#1| |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) (-1025 |#2|) (-194)) (T -1024)) 
+((-4010 (*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-790)) (-5 *1 (-1024 *3 *4)) (-4 *3 (-1025 *4))))) 
+(-10 -8 (-15 -1683 (|#1| (-433 (-592)))) (-15 -3266 ((-141) |#1| |#1|)) (-15 * (|#1| (-433 (-592)) |#1|)) (-15 * (|#1| |#1| (-433 (-592)))) (-15 -4552 (|#1| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -1392 (|#2| |#1|)) (-15 -2793 (|#2| |#1|)) (-15 -2227 (|#1| |#1|)) (-15 -2731 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -1683 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 -3558 ((-141) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 * (|#1| (-790) |#1|)) (-15 -2272 ((-141) |#1|)) (-15 * (|#1| (-944) |#1|)) (-15 -3300 (|#1| |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-4368 (((-3 (-592) "failed") $) 117 (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 115 (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) 114)) (-2400 (((-592) $) 118 (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) 116 (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) 113)) (-3945 (((-706 (-592)) (-706 $)) 88 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 87 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 86) (((-706 |#1|) (-706 $)) 85)) (-3371 (((-3 $ "failed") $) 33)) (-3996 ((|#1| $) 78)) (-4182 (((-3 (-433 (-592)) "failed") $) 74 (|has| |#1| (-574)))) (-2435 (((-141) $) 76 (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) 75 (|has| |#1| (-574)))) (-4383 (($ |#1| |#1| |#1| |#1|) 79)) (-3558 (((-141) $) 30)) (-2793 ((|#1| $) 80)) (-1837 (($ $ $) 66 (|has| |#1| (-869)))) (-3319 (($ $ $) 65 (|has| |#1| (-869)))) (-2731 (($ (-1 |#1| |#1|) $) 89)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 71 (|has| |#1| (-388)))) (-2640 ((|#1| $) 81)) (-4326 ((|#1| $) 82)) (-1771 ((|#1| $) 83)) (-2951 (((-1137) $) 10)) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) 95 (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) 94 (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) 93 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) 92 (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) 91 (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) 90 (|has| |#1| (-547 (-1191) |#1|)))) (-3927 (($ $ |#1|) 96 (|has| |#1| (-303 |#1| |#1|)))) (-3644 (($ $) 112 (|has| |#1| (-247))) (($ $ (-790)) 110 (|has| |#1| (-247))) (($ $ (-1191)) 108 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 107 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 106 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) 105 (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) 98) (($ $ (-1 |#1| |#1|)) 97)) (-1778 (((-565) $) 72 (|has| |#1| (-633 (-565))))) (-2227 (($ $) 84)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 36) (($ (-433 (-592))) 60 (-3836 (|has| |#1| (-388)) (|has| |#1| (-1065 (-433 (-592))))))) (-1517 (((-3 $ "failed") $) 73 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-1392 ((|#1| $) 77 (|has| |#1| (-1084)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 70 (|has| |#1| (-388)))) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $) 111 (|has| |#1| (-247))) (($ $ (-790)) 109 (|has| |#1| (-247))) (($ $ (-1191)) 104 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 103 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 102 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) 101 (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) 100) (($ $ (-1 |#1| |#1|)) 99)) (-3286 (((-141) $ $) 63 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 62 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 64 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 61 (|has| |#1| (-869)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 69 (|has| |#1| (-388)))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ $ (-433 (-592))) 68 (|has| |#1| (-388))) (($ (-433 (-592)) $) 67 (|has| |#1| (-388))))) 
+(((-1025 |#1|) (-1311) (-194)) (T -1025)) 
+((-2227 (*1 *1 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) (-1771 (*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) (-4326 (*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) (-2640 (*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) (-2793 (*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) (-4383 (*1 *1 *2 *2 *2 *2) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) (-3996 (*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) (-1392 (*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)) (-4 *2 (-1084)))) (-2435 (*1 *2 *1) (-12 (-4 *1 (-1025 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-141)))) (-2270 (*1 *2 *1) (-12 (-4 *1 (-1025 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) (-4182 (*1 *2 *1) (|partial| -12 (-4 *1 (-1025 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592)))))) 
+(-13 (-43 |t#1|) (-437 |t#1|) (-245 |t#1|) (-358 |t#1|) (-403 |t#1|) (-10 -8 (-15 -2227 ($ $)) (-15 -1771 (|t#1| $)) (-15 -4326 (|t#1| $)) (-15 -2640 (|t#1| $)) (-15 -2793 (|t#1| $)) (-15 -4383 ($ |t#1| |t#1| |t#1| |t#1|)) (-15 -3996 (|t#1| $)) (IF (|has| |t#1| (-307)) (-6 (-307)) |noBranch|) (IF (|has| |t#1| (-869)) (-6 (-869)) |noBranch|) (IF (|has| |t#1| (-388)) (-6 (-260)) |noBranch|) (IF (|has| |t#1| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (IF (|has| |t#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |t#1| (-169)) (-6 (-169)) |noBranch|) (IF (|has| |t#1| (-1084)) (-15 -1392 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-574)) (PROGN (-15 -2435 ((-141) $)) (-15 -2270 ((-433 (-592)) $)) (-15 -4182 ((-3 (-433 (-592)) "failed") $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-388)) ((-43 |#1|) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-388)) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-388)) (|has| |#1| (-307))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-245 |#1|) . T) ((-247) |has| |#1| (-247)) ((-260) |has| |#1| (-388)) ((-303 |#1| $) |has| |#1| (-303 |#1| |#1|)) ((-307) -3836 (|has| |#1| (-388)) (|has| |#1| (-307))) ((-325 |#1|) |has| |#1| (-325 |#1|)) ((-358 |#1|) . T) ((-403 |#1|) . T) ((-437 |#1|) . T) ((-547 (-1191) |#1|) |has| |#1| (-547 (-1191) |#1|)) ((-547 |#1| |#1|) |has| |#1| (-325 |#1|)) ((-661 (-433 (-592))) |has| |#1| (-388)) ((-661 |#1|) . T) ((-661 $) . T) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-734 (-433 (-592))) |has| |#1| (-388)) ((-734 |#1|) . T) ((-743) . T) ((-869) |has| |#1| (-869)) ((-922 (-1191)) |has| |#1| (-922 (-1191))) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) |has| |#1| (-388)) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-388)) (|has| |#1| (-307))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-2731 ((|#3| (-1 |#4| |#2|) |#1|) 16))) 
+(((-1026 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#3| (-1 |#4| |#2|) |#1|))) (-1025 |#2|) (-194) (-1025 |#4|) (-194)) (T -1026)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-194)) (-4 *6 (-194)) (-4 *2 (-1025 *6)) (-5 *1 (-1026 *4 *5 *2 *6)) (-4 *4 (-1025 *5))))) 
+(-10 -7 (-15 -2731 (|#3| (-1 |#4| |#2|) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3996 ((|#1| $) 12)) (-4182 (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-574)))) (-2435 (((-141) $) NIL (|has| |#1| (-574)))) (-2270 (((-433 (-592)) $) NIL (|has| |#1| (-574)))) (-4383 (($ |#1| |#1| |#1| |#1|) 16)) (-3558 (((-141) $) NIL)) (-2793 ((|#1| $) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-2640 ((|#1| $) 15)) (-4326 ((|#1| $) 14)) (-1771 ((|#1| $) 13)) (-2951 (((-1137) $) NIL)) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-325 |#1|))) (($ $ (-310 |#1|)) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-310 |#1|))) NIL (|has| |#1| (-325 |#1|))) (($ $ (-658 (-1191)) (-658 |#1|)) NIL (|has| |#1| (-547 (-1191) |#1|))) (($ $ (-1191) |#1|) NIL (|has| |#1| (-547 (-1191) |#1|)))) (-3927 (($ $ |#1|) NIL (|has| |#1| (-303 |#1| |#1|)))) (-3644 (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-2227 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-388)) (|has| |#1| (-1065 (-433 (-592))))))) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-1392 ((|#1| $) NIL (|has| |#1| (-1084)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 8 T CONST)) (-4257 (($) 10 T CONST)) (-1940 (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 20) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-433 (-592))) NIL (|has| |#1| (-388))) (($ (-433 (-592)) $) NIL (|has| |#1| (-388))))) 
+(((-1027 |#1|) (-1025 |#1|) (-194)) (T -1027)) 
+NIL 
+(-1025 |#1|) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2126 (((-141) $ (-790)) NIL)) (-3001 (($) NIL T CONST)) (-4179 (($ $) 20)) (-4105 (($ (-658 |#1|)) 29)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-4233 (((-790) $) 22)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4137 ((|#1| $) 24)) (-2113 (($ |#1| $) 15)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1476 ((|#1| $) 23)) (-2106 ((|#1| $) 19)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1659 ((|#1| |#1| $) 14)) (-2943 (((-141) $) 17)) (-2890 (($) NIL)) (-1716 ((|#1| $) 18)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) NIL)) (-2829 ((|#1| $) 26)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1028 |#1|) (-13 (-1023 |#1|) (-10 -8 (-15 -4105 ($ (-658 |#1|))) (-15 -1716 (|#1| $)) (-15 -2106 (|#1| $)) (-15 -1659 (|#1| |#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -1476 (|#1| $)) (-15 -2829 (|#1| $)) (-15 -4179 ($ $)) (-15 -4233 ((-790) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -4560 ($ (-658 |#1|))) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -3001 ($)) (-15 -4599 ($ $)) (-15 -1724 ((-141) $ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) (-1119)) (T -1028)) 
+((-1724 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) (-4599 (*1 *1 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-2890 (*1 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-2943 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) (-2554 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1028 *4)) (-4 *4 (-1119)))) (-4345 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1028 *4)) (-4 *4 (-1119)))) (-2126 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1028 *4)) (-4 *4 (-1119)))) (-3001 (*1 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-1028 *3)))) (-3987 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-1119)) (-5 *1 (-1028 *3)))) (-3369 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-1028 *4)))) (-3002 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-1028 *4)))) (-3452 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-1028 *4)))) (-4004 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) (-3452 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-3133 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-2685 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-2951 (*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-3255 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-1641 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-4560 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1028 *3)))) (-2106 (*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-2113 (*1 *1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-4137 (*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-1659 (*1 *2 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-1716 (*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-4179 (*1 *1 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-4233 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) (-1476 (*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-2829 (*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) (-4105 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1028 *3))))) 
+(-13 (-1023 |#1|) (-10 -8 (-15 -4105 ($ (-658 |#1|))) (-15 -1716 (|#1| $)) (-15 -2106 (|#1| $)) (-15 -1659 (|#1| |#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -1476 (|#1| $)) (-15 -2829 (|#1| $)) (-15 -4179 ($ $)) (-15 -4233 ((-790) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -4560 ($ (-658 |#1|))) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -3001 ($)) (-15 -4599 ($ $)) (-15 -1724 ((-141) $ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) 
+((-1442 (($ $) 12)) (-4422 (($ $ (-592)) 13))) 
+(((-1029 |#1|) (-10 -8 (-15 -1442 (|#1| |#1|)) (-15 -4422 (|#1| |#1| (-592)))) (-1030)) (T -1029)) 
+NIL 
+(-10 -8 (-15 -1442 (|#1| |#1|)) (-15 -4422 (|#1| |#1| (-592)))) 
+((-1442 (($ $) 6)) (-4422 (($ $ (-592)) 7)) (** (($ $ (-433 (-592))) 8))) 
+(((-1030) (-1311)) (T -1030)) 
+((** (*1 *1 *1 *2) (-12 (-4 *1 (-1030)) (-5 *2 (-433 (-592))))) (-4422 (*1 *1 *1 *2) (-12 (-4 *1 (-1030)) (-5 *2 (-592)))) (-1442 (*1 *1 *1) (-4 *1 (-1030)))) 
+(-13 (-10 -8 (-15 -1442 ($ $)) (-15 -4422 ($ $ (-592))) (-15 ** ($ $ (-433 (-592)))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4094 (((-2 (|:| |num| (-1280 |#2|)) (|:| |den| |#2|)) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| (-433 |#2|) (-388)))) (-1555 (($ $) NIL (|has| (-433 |#2|) (-388)))) (-1313 (((-141) $) NIL (|has| (-433 |#2|) (-388)))) (-1800 (((-706 (-433 |#2|)) (-1280 $)) NIL) (((-706 (-433 |#2|))) NIL)) (-4529 (((-433 |#2|) $) NIL)) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| (-433 |#2|) (-373)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| (-433 |#2|) (-388)))) (-3164 (((-444 $) $) NIL (|has| (-433 |#2|) (-388)))) (-3652 (((-141) $ $) NIL (|has| (-433 |#2|) (-388)))) (-1403 (((-790)) NIL (|has| (-433 |#2|) (-394)))) (-4578 (((-141)) NIL)) (-2105 (((-141) |#1|) 147) (((-141) |#2|) 152)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| (-433 |#2|) (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-433 |#2|) (-1065 (-433 (-592))))) (((-3 (-433 |#2|) "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| (-433 |#2|) (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| (-433 |#2|) (-1065 (-433 (-592))))) (((-433 |#2|) $) NIL)) (-1626 (($ (-1280 (-433 |#2|)) (-1280 $)) NIL) (($ (-1280 (-433 |#2|))) 70) (($ (-1280 |#2|) |#2|) NIL)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-433 |#2|) (-373)))) (-1586 (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-4493 (((-706 (-433 |#2|)) $ (-1280 $)) NIL) (((-706 (-433 |#2|)) $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-433 |#2|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-433 |#2|) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-433 |#2|))) (|:| |vec| (-1280 (-433 |#2|)))) (-706 $) (-1280 $)) NIL) (((-706 (-433 |#2|)) (-706 $)) NIL)) (-1872 (((-1280 $) (-1280 $)) NIL)) (-3657 (($ |#3|) 65) (((-3 $ "failed") (-433 |#3|)) NIL (|has| (-433 |#2|) (-388)))) (-3371 (((-3 $ "failed") $) NIL)) (-3969 (((-658 (-658 |#1|))) NIL (|has| |#1| (-394)))) (-2619 (((-141) |#1| |#1|) NIL)) (-4175 (((-944)) NIL)) (-4290 (($) NIL (|has| (-433 |#2|) (-394)))) (-1634 (((-141)) NIL)) (-2282 (((-141) |#1|) 56) (((-141) |#2|) 149)) (-1599 (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| (-433 |#2|) (-388)))) (-3262 (($ $) NIL)) (-2667 (($) NIL (|has| (-433 |#2|) (-373)))) (-3293 (((-141) $) NIL (|has| (-433 |#2|) (-373)))) (-1525 (($ $ (-790)) NIL (|has| (-433 |#2|) (-373))) (($ $) NIL (|has| (-433 |#2|) (-373)))) (-2802 (((-141) $) NIL (|has| (-433 |#2|) (-388)))) (-4346 (((-944) $) NIL (|has| (-433 |#2|) (-373))) (((-855 (-944)) $) NIL (|has| (-433 |#2|) (-373)))) (-3558 (((-141) $) NIL)) (-3804 (((-790)) NIL)) (-3655 (((-1280 $) (-1280 $)) NIL)) (-2793 (((-433 |#2|) $) NIL)) (-2010 (((-658 (-980 |#1|)) (-1191)) NIL (|has| |#1| (-388)))) (-3921 (((-3 $ "failed") $) NIL (|has| (-433 |#2|) (-373)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| (-433 |#2|) (-388)))) (-3504 ((|#3| $) NIL (|has| (-433 |#2|) (-388)))) (-3546 (((-944) $) NIL (|has| (-433 |#2|) (-394)))) (-3650 ((|#3| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| (-433 |#2|) (-388))) (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-2685 (((-1173) $) NIL)) (-3757 (((-706 (-433 |#2|))) 52)) (-1346 (((-706 (-433 |#2|))) 51)) (-4552 (($ $) NIL (|has| (-433 |#2|) (-388)))) (-2482 (($ (-1280 |#2|) |#2|) 71)) (-2925 (((-706 (-433 |#2|))) 50)) (-4373 (((-706 (-433 |#2|))) 49)) (-3406 (((-2 (|:| |num| (-706 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 86)) (-1645 (((-2 (|:| |num| (-1280 |#2|)) (|:| |den| |#2|)) $) 77)) (-3720 (((-1280 $)) 46)) (-4023 (((-1280 $)) 45)) (-3717 (((-141) $) NIL)) (-4551 (((-141) $) NIL) (((-141) $ |#1|) NIL) (((-141) $ |#2|) NIL)) (-3703 (($) NIL (|has| (-433 |#2|) (-373)) CONST)) (-1825 (($ (-944)) NIL (|has| (-433 |#2|) (-394)))) (-3560 (((-3 |#2| "failed")) 63)) (-2951 (((-1137) $) NIL)) (-3918 (((-790)) NIL)) (-2934 (($) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| (-433 |#2|) (-388)))) (-3548 (($ (-658 $)) NIL (|has| (-433 |#2|) (-388))) (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| (-433 |#2|) (-373)))) (-4500 (((-444 $) $) NIL (|has| (-433 |#2|) (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-433 |#2|) (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| (-433 |#2|) (-388)))) (-3616 (((-3 $ "failed") $ $) NIL (|has| (-433 |#2|) (-388)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| (-433 |#2|) (-388)))) (-2769 (((-790) $) NIL (|has| (-433 |#2|) (-388)))) (-1405 (((-658 $)) NIL (|has| (-433 |#2|) (-394)))) (-3927 ((|#1| $ |#1| |#1|) NIL)) (-3143 (((-3 |#2| "failed")) 62)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| (-433 |#2|) (-388)))) (-1482 (((-433 |#2|) (-1280 $)) NIL) (((-433 |#2|)) 42)) (-2177 (((-790) $) NIL (|has| (-433 |#2|) (-373))) (((-3 (-790) "failed") $ $) NIL (|has| (-433 |#2|) (-373)))) (-3644 (($ $ (-1 (-433 |#2|) (-433 |#2|)) (-790)) NIL (|has| (-433 |#2|) (-388))) (($ $ (-1 (-433 |#2|) (-433 |#2|))) NIL (|has| (-433 |#2|) (-388))) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-790)) NIL (-3836 (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373)))) (($ $) NIL (-3836 (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373))))) (-4174 (((-706 (-433 |#2|)) (-1280 $) (-1 (-433 |#2|) (-433 |#2|))) NIL (|has| (-433 |#2|) (-388)))) (-3390 ((|#3|) 53)) (-3809 (($) NIL (|has| (-433 |#2|) (-373)))) (-2231 (((-1280 (-433 |#2|)) $ (-1280 $)) NIL) (((-706 (-433 |#2|)) (-1280 $) (-1280 $)) NIL) (((-1280 (-433 |#2|)) $) 72) (((-706 (-433 |#2|)) (-1280 $)) NIL)) (-1778 (((-1280 (-433 |#2|)) $) NIL) (($ (-1280 (-433 |#2|))) NIL) ((|#3| $) NIL) (($ |#3|) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| (-433 |#2|) (-373)))) (-3985 (((-1280 $) (-1280 $)) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 |#2|)) NIL) (($ (-433 (-592))) NIL (-3836 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-1065 (-433 (-592)))))) (($ $) NIL (|has| (-433 |#2|) (-388)))) (-1517 (($ $) NIL (|has| (-433 |#2|) (-373))) (((-3 $ "failed") $) NIL (|has| (-433 |#2|) (-169)))) (-4198 ((|#3| $) NIL)) (-4010 (((-790)) NIL)) (-2457 (((-141)) 60)) (-2576 (((-141) |#1|) 153) (((-141) |#2|) 154)) (-2195 (((-1280 $)) 124)) (-2537 (((-141) $ $) NIL (|has| (-433 |#2|) (-388)))) (-3748 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) NIL)) (-3059 (((-141)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-433 |#2|) (-388)))) (-3514 (($) 94 T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-1 (-433 |#2|) (-433 |#2|)) (-790)) NIL (|has| (-433 |#2|) (-388))) (($ $ (-1 (-433 |#2|) (-433 |#2|))) NIL (|has| (-433 |#2|) (-388))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| (-433 |#2|) (-388)) (|has| (-433 |#2|) (-922 (-1191))))) (($ $ (-790)) NIL (-3836 (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373)))) (($ $) NIL (-3836 (-12 (|has| (-433 |#2|) (-247)) (|has| (-433 |#2|) (-388))) (|has| (-433 |#2|) (-373))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ $) NIL (|has| (-433 |#2|) (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-433 |#2|) (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 |#2|)) NIL) (($ (-433 |#2|) $) NIL) (($ (-433 (-592)) $) NIL (|has| (-433 |#2|) (-388))) (($ $ (-433 (-592))) NIL (|has| (-433 |#2|) (-388))))) 
+(((-1031 |#1| |#2| |#3| |#4| |#5|) (-362 |#1| |#2| |#3|) (-1235) (-1255 |#1|) (-1255 (-433 |#2|)) (-433 |#2|) (-790)) (T -1031)) 
+NIL 
+(-362 |#1| |#2| |#3|) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3419 (((-658 (-592)) $) 54)) (-3601 (($ (-658 (-592))) 62)) (-1505 (((-592) $) 40 (|has| (-592) (-323)))) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL (|has| (-592) (-842)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) 49) (((-3 (-1191) "failed") $) NIL (|has| (-592) (-1065 (-1191)))) (((-3 (-433 (-592)) "failed") $) 47 (|has| (-592) (-1065 (-592)))) (((-3 (-592) "failed") $) 49 (|has| (-592) (-1065 (-592))))) (-2400 (((-592) $) NIL) (((-1191) $) NIL (|has| (-592) (-1065 (-1191)))) (((-433 (-592)) $) NIL (|has| (-592) (-1065 (-592)))) (((-592) $) NIL (|has| (-592) (-1065 (-592))))) (-1586 (($ $ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| (-592) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| (-592) (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-706 (-592)) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4290 (($) NIL (|has| (-592) (-574)))) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1611 (((-658 (-592)) $) 60)) (-1691 (((-141) $) NIL (|has| (-592) (-842)))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (|has| (-592) (-908 (-592)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (|has| (-592) (-908 (-405))))) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL)) (-1448 (((-592) $) 37)) (-3921 (((-3 $ "failed") $) NIL (|has| (-592) (-1165)))) (-1324 (((-141) $) NIL (|has| (-592) (-842)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-592) (-869)))) (-2731 (($ (-1 (-592) (-592)) $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL)) (-3703 (($) NIL (|has| (-592) (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-3856 (($ $) NIL (|has| (-592) (-323))) (((-433 (-592)) $) 42)) (-3812 (((-1171 (-592)) $) 59)) (-4419 (($ (-658 (-592)) (-658 (-592))) 63)) (-2039 (((-592) $) 53 (|has| (-592) (-574)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| (-592) (-931)))) (-4500 (((-444 $) $) NIL)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2806 (($ $ (-658 (-592)) (-658 (-592))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-592) (-592)) NIL (|has| (-592) (-325 (-592)))) (($ $ (-310 (-592))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-658 (-310 (-592)))) NIL (|has| (-592) (-325 (-592)))) (($ $ (-658 (-1191)) (-658 (-592))) NIL (|has| (-592) (-547 (-1191) (-592)))) (($ $ (-1191) (-592)) NIL (|has| (-592) (-547 (-1191) (-592))))) (-2769 (((-790) $) NIL)) (-3927 (($ $ (-592)) NIL (|has| (-592) (-303 (-592) (-592))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $) 11 (|has| (-592) (-247))) (($ $ (-790)) NIL (|has| (-592) (-247))) (($ $ (-1191)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1 (-592) (-592)) (-790)) NIL) (($ $ (-1 (-592) (-592))) NIL)) (-2782 (($ $) NIL)) (-1456 (((-592) $) 39)) (-3393 (((-658 (-592)) $) 61)) (-1778 (((-914 (-592)) $) NIL (|has| (-592) (-633 (-914 (-592))))) (((-914 (-405)) $) NIL (|has| (-592) (-633 (-914 (-405))))) (((-565) $) NIL (|has| (-592) (-633 (-565)))) (((-405) $) NIL (|has| (-592) (-1049))) (((-237) $) NIL (|has| (-592) (-1049)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-592) (-931))))) (-1683 (((-877) $) 77) (($ (-592)) 43) (($ $) NIL) (($ (-433 (-592))) 19) (($ (-592)) 43) (($ (-1191)) NIL (|has| (-592) (-1065 (-1191)))) (((-433 (-592)) $) 17)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-592) (-931))) (|has| (-592) (-169))))) (-4010 (((-790)) 9)) (-2744 (((-592) $) 51 (|has| (-592) (-574)))) (-2537 (((-141) $ $) NIL)) (-1392 (($ $) NIL (|has| (-592) (-842)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 10 T CONST)) (-4257 (($) 12 T CONST)) (-1940 (($ $) NIL (|has| (-592) (-247))) (($ $ (-790)) NIL (|has| (-592) (-247))) (($ $ (-1191)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| (-592) (-922 (-1191)))) (($ $ (-1 (-592) (-592)) (-790)) NIL) (($ $ (-1 (-592) (-592))) NIL)) (-3286 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3255 (((-141) $ $) 14)) (-3279 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3266 (((-141) $ $) 33 (|has| (-592) (-869)))) (-3313 (($ $ $) 29) (($ (-592) (-592)) 31)) (-3306 (($ $) 15) (($ $ $) 22)) (-3300 (($ $ $) 20)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 25) (($ $ $) 27) (($ $ (-433 (-592))) NIL) (($ (-433 (-592)) $) NIL) (($ (-592) $) 25) (($ $ (-592)) NIL))) 
+(((-1032 |#1|) (-13 (-1021 (-592)) (-10 -8 (-15 -1683 ((-433 (-592)) $)) (-15 -3856 ((-433 (-592)) $)) (-15 -3419 ((-658 (-592)) $)) (-15 -3812 ((-1171 (-592)) $)) (-15 -1611 ((-658 (-592)) $)) (-15 -3393 ((-658 (-592)) $)) (-15 -3601 ($ (-658 (-592)))) (-15 -4419 ($ (-658 (-592)) (-658 (-592)))))) (-592)) (T -1032)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) (-3856 (*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) (-3419 (*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) (-3812 (*1 *2 *1) (-12 (-5 *2 (-1171 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) (-1611 (*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) (-3393 (*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) (-3601 (*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) (-4419 (*1 *1 *2 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592))))) 
+(-13 (-1021 (-592)) (-10 -8 (-15 -1683 ((-433 (-592)) $)) (-15 -3856 ((-433 (-592)) $)) (-15 -3419 ((-658 (-592)) $)) (-15 -3812 ((-1171 (-592)) $)) (-15 -1611 ((-658 (-592)) $)) (-15 -3393 ((-658 (-592)) $)) (-15 -3601 ($ (-658 (-592)))) (-15 -4419 ($ (-658 (-592)) (-658 (-592)))))) 
+((-3185 (((-57) (-433 (-592)) (-592)) 9))) 
+(((-1033) (-10 -7 (-15 -3185 ((-57) (-433 (-592)) (-592))))) (T -1033)) 
+((-3185 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-592))) (-5 *4 (-592)) (-5 *2 (-57)) (-5 *1 (-1033))))) 
+(-10 -7 (-15 -3185 ((-57) (-433 (-592)) (-592)))) 
+((-1403 (((-592)) 13)) (-2103 (((-592)) 16)) (-1769 (((-1285) (-592)) 15)) (-4583 (((-592) (-592)) 17) (((-592)) 12))) 
+(((-1034) (-10 -7 (-15 -4583 ((-592))) (-15 -1403 ((-592))) (-15 -4583 ((-592) (-592))) (-15 -1769 ((-1285) (-592))) (-15 -2103 ((-592))))) (T -1034)) 
+((-2103 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1034)))) (-1769 (*1 *2 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-1034)))) (-4583 (*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1034)))) (-1403 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1034)))) (-4583 (*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1034))))) 
+(-10 -7 (-15 -4583 ((-592))) (-15 -1403 ((-592))) (-15 -4583 ((-592) (-592))) (-15 -1769 ((-1285) (-592))) (-15 -2103 ((-592)))) 
+((-3082 (((-444 |#1|) |#1|) 40)) (-4500 (((-444 |#1|) |#1|) 39))) 
+(((-1035 |#1|) (-10 -7 (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3082 ((-444 |#1|) |#1|))) (-1255 (-433 (-592)))) (T -1035)) 
+((-3082 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1035 *3)) (-4 *3 (-1255 (-433 (-592)))))) (-4500 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1035 *3)) (-4 *3 (-1255 (-433 (-592))))))) 
+(-10 -7 (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3082 ((-444 |#1|) |#1|))) 
+((-4182 (((-3 (-433 (-592)) "failed") |#1|) 14)) (-2435 (((-141) |#1|) 13)) (-2270 (((-433 (-592)) |#1|) 9))) 
+(((-1036 |#1|) (-10 -7 (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|))) (-1065 (-433 (-592)))) (T -1036)) 
+((-4182 (*1 *2 *3) (|partial| -12 (-5 *2 (-433 (-592))) (-5 *1 (-1036 *3)) (-4 *3 (-1065 *2)))) (-2435 (*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-1036 *3)) (-4 *3 (-1065 (-433 (-592)))))) (-2270 (*1 *2 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-1036 *3)) (-4 *3 (-1065 *2))))) 
+(-10 -7 (-15 -2270 ((-433 (-592)) |#1|)) (-15 -2435 ((-141) |#1|)) (-15 -4182 ((-3 (-433 (-592)) "failed") |#1|))) 
+((-3932 ((|#2| $ "value" |#2|) 12)) (-3927 ((|#2| $ "value") 10)) (-2936 (((-141) $ $) 18))) 
+(((-1037 |#1| |#2|) (-10 -8 (-15 -3932 (|#2| |#1| "value" |#2|)) (-15 -2936 ((-141) |#1| |#1|)) (-15 -3927 (|#2| |#1| "value"))) (-1038 |#2|) (-1225)) (T -1037)) 
+NIL 
+(-10 -8 (-15 -3932 (|#2| |#1| "value" |#2|)) (-15 -2936 ((-141) |#1| |#1|)) (-15 -3927 (|#2| |#1| "value"))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-3001 (($) 7 T CONST)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44)) (-2920 (((-592) $ $) 41)) (-3228 (((-141) $) 43)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1038 |#1|) (-1311) (-1225)) (T -1038)) 
+((-2493 (*1 *2 *1) (-12 (-4 *3 (-1225)) (-5 *2 (-658 *1)) (-4 *1 (-1038 *3)))) (-2774 (*1 *2 *1) (-12 (-4 *3 (-1225)) (-5 *2 (-658 *1)) (-4 *1 (-1038 *3)))) (-3683 (*1 *2 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-5 *2 (-141)))) (-2324 (*1 *2 *1) (-12 (-4 *1 (-1038 *2)) (-4 *2 (-1225)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 "value") (-4 *1 (-1038 *2)) (-4 *2 (-1225)))) (-3228 (*1 *2 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-5 *2 (-141)))) (-4063 (*1 *2 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-5 *2 (-658 *3)))) (-2920 (*1 *2 *1 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-5 *2 (-592)))) (-2936 (*1 *2 *1 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-141)))) (-3055 (*1 *2 *1 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-141)))) (-4294 (*1 *1 *1 *2) (-12 (-5 *2 (-658 *1)) (|has| *1 (-6 -4626)) (-4 *1 (-1038 *3)) (-4 *3 (-1225)))) (-3932 (*1 *2 *1 *3 *2) (-12 (-5 *3 "value") (|has| *1 (-6 -4626)) (-4 *1 (-1038 *2)) (-4 *2 (-1225)))) (-3047 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1038 *2)) (-4 *2 (-1225))))) 
+(-13 (-523 |t#1|) (-10 -8 (-15 -2493 ((-658 $) $)) (-15 -2774 ((-658 $) $)) (-15 -3683 ((-141) $)) (-15 -2324 (|t#1| $)) (-15 -3927 (|t#1| $ "value")) (-15 -3228 ((-141) $)) (-15 -4063 ((-658 |t#1|) $)) (-15 -2920 ((-592) $ $)) (IF (|has| |t#1| (-1119)) (PROGN (-15 -2936 ((-141) $ $)) (-15 -3055 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4626)) (PROGN (-15 -4294 ($ $ (-658 $))) (-15 -3932 (|t#1| $ "value" |t#1|)) (-15 -3047 (|t#1| $ |t#1|))) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-1442 (($ $) 9) (($ $ (-790)) 43) (($ (-433 (-592))) 12) (($ (-592)) 15)) (-3906 (((-3 $ "failed") (-1187 $) (-944) (-877)) 23) (((-3 $ "failed") (-1187 $) (-944)) 28)) (-4422 (($ $ (-592)) 49)) (-4010 (((-790)) 16)) (-3740 (((-658 $) (-1187 $)) NIL) (((-658 $) (-1187 (-433 (-592)))) 54) (((-658 $) (-1187 (-592))) 59) (((-658 $) (-980 $)) 63) (((-658 $) (-980 (-433 (-592)))) 67) (((-658 $) (-980 (-592))) 71)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL) (($ $ (-433 (-592))) 47))) 
+(((-1039 |#1|) (-10 -8 (-15 -1442 (|#1| (-592))) (-15 -1442 (|#1| (-433 (-592)))) (-15 -1442 (|#1| |#1| (-790))) (-15 -3740 ((-658 |#1|) (-980 (-592)))) (-15 -3740 ((-658 |#1|) (-980 (-433 (-592))))) (-15 -3740 ((-658 |#1|) (-980 |#1|))) (-15 -3740 ((-658 |#1|) (-1187 (-592)))) (-15 -3740 ((-658 |#1|) (-1187 (-433 (-592))))) (-15 -3740 ((-658 |#1|) (-1187 |#1|))) (-15 -3906 ((-3 |#1| "failed") (-1187 |#1|) (-944))) (-15 -3906 ((-3 |#1| "failed") (-1187 |#1|) (-944) (-877))) (-15 ** (|#1| |#1| (-433 (-592)))) (-15 -4422 (|#1| |#1| (-592))) (-15 -1442 (|#1| |#1|)) (-15 ** (|#1| |#1| (-592))) (-15 -4010 ((-790))) (-15 ** (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-944)))) (-1040)) (T -1039)) 
+((-4010 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1039 *3)) (-4 *3 (-1040))))) 
+(-10 -8 (-15 -1442 (|#1| (-592))) (-15 -1442 (|#1| (-433 (-592)))) (-15 -1442 (|#1| |#1| (-790))) (-15 -3740 ((-658 |#1|) (-980 (-592)))) (-15 -3740 ((-658 |#1|) (-980 (-433 (-592))))) (-15 -3740 ((-658 |#1|) (-980 |#1|))) (-15 -3740 ((-658 |#1|) (-1187 (-592)))) (-15 -3740 ((-658 |#1|) (-1187 (-433 (-592))))) (-15 -3740 ((-658 |#1|) (-1187 |#1|))) (-15 -3906 ((-3 |#1| "failed") (-1187 |#1|) (-944))) (-15 -3906 ((-3 |#1| "failed") (-1187 |#1|) (-944) (-877))) (-15 ** (|#1| |#1| (-433 (-592)))) (-15 -4422 (|#1| |#1| (-592))) (-15 -1442 (|#1| |#1|)) (-15 ** (|#1| |#1| (-592))) (-15 -4010 ((-790))) (-15 ** (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-944)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 88)) (-1555 (($ $) 89)) (-1313 (((-141) $) 91)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 108)) (-3164 (((-444 $) $) 109)) (-1442 (($ $) 72) (($ $ (-790)) 58) (($ (-433 (-592))) 57) (($ (-592)) 56)) (-3652 (((-141) $ $) 99)) (-3940 (((-592) $) 126)) (-3001 (($) 16 T CONST)) (-3906 (((-3 $ "failed") (-1187 $) (-944) (-877)) 66) (((-3 $ "failed") (-1187 $) (-944)) 65)) (-4368 (((-3 (-592) "failed") $) 84 (|has| (-433 (-592)) (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 82 (|has| (-433 (-592)) (-1065 (-433 (-592))))) (((-3 (-433 (-592)) "failed") $) 80)) (-2400 (((-592) $) 85 (|has| (-433 (-592)) (-1065 (-592)))) (((-433 (-592)) $) 83 (|has| (-433 (-592)) (-1065 (-433 (-592))))) (((-433 (-592)) $) 79)) (-4548 (($ $ (-877)) 55)) (-4460 (($ $ (-877)) 54)) (-1586 (($ $ $) 103)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 102)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 97)) (-2802 (((-141) $) 110)) (-1691 (((-141) $) 124)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 71)) (-1324 (((-141) $) 125)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 106)) (-1837 (($ $ $) 123)) (-3319 (($ $ $) 122)) (-1514 (((-3 (-1187 $) "failed") $) 67)) (-4385 (((-3 (-877) "failed") $) 69)) (-2235 (((-3 (-1187 $) "failed") $) 68)) (-2750 (($ (-658 $)) 95) (($ $ $) 94)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 111)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 96)) (-3548 (($ (-658 $)) 93) (($ $ $) 92)) (-4500 (((-444 $) $) 107)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 104)) (-3616 (((-3 $ "failed") $ $) 87)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 98)) (-2769 (((-790) $) 100)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 101)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 116) (($ $) 86) (($ (-433 (-592))) 81) (($ (-592)) 78) (($ (-433 (-592))) 75)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 90)) (-2642 (((-433 (-592)) $ $) 53)) (-3740 (((-658 $) (-1187 $)) 64) (((-658 $) (-1187 (-433 (-592)))) 63) (((-658 $) (-1187 (-592))) 62) (((-658 $) (-980 $)) 61) (((-658 $) (-980 (-433 (-592)))) 60) (((-658 $) (-980 (-592))) 59)) (-1392 (($ $) 127)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 112)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3286 (((-141) $ $) 120)) (-3273 (((-141) $ $) 119)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 121)) (-3266 (((-141) $ $) 118)) (-3313 (($ $ $) 117)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 113) (($ $ (-433 (-592))) 70)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ (-433 (-592)) $) 115) (($ $ (-433 (-592))) 114) (($ (-592) $) 77) (($ $ (-592)) 76) (($ (-433 (-592)) $) 74) (($ $ (-433 (-592))) 73))) 
+(((-1040) (-1311)) (T -1040)) 
+((-1442 (*1 *1 *1) (-4 *1 (-1040))) (-4385 (*1 *2 *1) (|partial| -12 (-4 *1 (-1040)) (-5 *2 (-877)))) (-2235 (*1 *2 *1) (|partial| -12 (-5 *2 (-1187 *1)) (-4 *1 (-1040)))) (-1514 (*1 *2 *1) (|partial| -12 (-5 *2 (-1187 *1)) (-4 *1 (-1040)))) (-3906 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-1187 *1)) (-5 *3 (-944)) (-5 *4 (-877)) (-4 *1 (-1040)))) (-3906 (*1 *1 *2 *3) (|partial| -12 (-5 *2 (-1187 *1)) (-5 *3 (-944)) (-4 *1 (-1040)))) (-3740 (*1 *2 *3) (-12 (-5 *3 (-1187 *1)) (-4 *1 (-1040)) (-5 *2 (-658 *1)))) (-3740 (*1 *2 *3) (-12 (-5 *3 (-1187 (-433 (-592)))) (-5 *2 (-658 *1)) (-4 *1 (-1040)))) (-3740 (*1 *2 *3) (-12 (-5 *3 (-1187 (-592))) (-5 *2 (-658 *1)) (-4 *1 (-1040)))) (-3740 (*1 *2 *3) (-12 (-5 *3 (-980 *1)) (-4 *1 (-1040)) (-5 *2 (-658 *1)))) (-3740 (*1 *2 *3) (-12 (-5 *3 (-980 (-433 (-592)))) (-5 *2 (-658 *1)) (-4 *1 (-1040)))) (-3740 (*1 *2 *3) (-12 (-5 *3 (-980 (-592))) (-5 *2 (-658 *1)) (-4 *1 (-1040)))) (-1442 (*1 *1 *1 *2) (-12 (-4 *1 (-1040)) (-5 *2 (-790)))) (-1442 (*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-4 *1 (-1040)))) (-1442 (*1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1040)))) (-4548 (*1 *1 *1 *2) (-12 (-4 *1 (-1040)) (-5 *2 (-877)))) (-4460 (*1 *1 *1 *2) (-12 (-4 *1 (-1040)) (-5 *2 (-877)))) (-2642 (*1 *2 *1 *1) (-12 (-4 *1 (-1040)) (-5 *2 (-433 (-592)))))) 
+(-13 (-171) (-867) (-194) (-388) (-437 (-433 (-592))) (-43 (-592)) (-43 (-433 (-592))) (-1030) (-10 -8 (-15 -4385 ((-3 (-877) "failed") $)) (-15 -2235 ((-3 (-1187 $) "failed") $)) (-15 -1514 ((-3 (-1187 $) "failed") $)) (-15 -3906 ((-3 $ "failed") (-1187 $) (-944) (-877))) (-15 -3906 ((-3 $ "failed") (-1187 $) (-944))) (-15 -3740 ((-658 $) (-1187 $))) (-15 -3740 ((-658 $) (-1187 (-433 (-592))))) (-15 -3740 ((-658 $) (-1187 (-592)))) (-15 -3740 ((-658 $) (-980 $))) (-15 -3740 ((-658 $) (-980 (-433 (-592))))) (-15 -3740 ((-658 $) (-980 (-592)))) (-15 -1442 ($ $ (-790))) (-15 -1442 ($ $)) (-15 -1442 ($ (-433 (-592)))) (-15 -1442 ($ (-592))) (-15 -4548 ($ $ (-877))) (-15 -4460 ($ $ (-877))) (-15 -2642 ((-433 (-592)) $ $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 (-592)) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 (-592) (-592)) . T) ((-140 $ $) . T) ((-158) . T) ((-171) . T) ((-632 (-877)) . T) ((-194) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-437 (-433 (-592))) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 (-592)) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 (-592)) . T) ((-734 $) . T) ((-743) . T) ((-813) . T) ((-814) . T) ((-816) . T) ((-817) . T) ((-867) . T) ((-869) . T) ((-943) . T) ((-1030) . T) ((-1065 (-433 (-592))) . T) ((-1065 (-592)) |has| (-433 (-592)) (-1065 (-592))) ((-1081 (-433 (-592))) . T) ((-1081 (-592)) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T)) 
+((-2521 (((-2 (|:| |ans| |#2|) (|:| -1954 |#2|) (|:| |sol?| (-141))) (-592) |#2| |#2| (-1191) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-658 |#2|)) (-1 (-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) 61))) 
+(((-1041 |#1| |#2|) (-10 -7 (-15 -2521 ((-2 (|:| |ans| |#2|) (|:| -1954 |#2|) (|:| |sol?| (-141))) (-592) |#2| |#2| (-1191) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-658 |#2|)) (-1 (-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592))) (-13 (-1211) (-27) (-456 |#1|))) (T -1041)) 
+((-2521 (*1 *2 *3 *4 *4 *5 *6 *7) (-12 (-5 *5 (-1191)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-658 *4))) (-5 *7 (-1 (-3 (-2 (|:| -3191 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1211) (-27) (-456 *8))) (-4 *8 (-13 (-477) (-869) (-171) (-1065 *3) (-654 *3))) (-5 *3 (-592)) (-5 *2 (-2 (|:| |ans| *4) (|:| -1954 *4) (|:| |sol?| (-141)))) (-5 *1 (-1041 *8 *4))))) 
+(-10 -7 (-15 -2521 ((-2 (|:| |ans| |#2|) (|:| -1954 |#2|) (|:| |sol?| (-141))) (-592) |#2| |#2| (-1191) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-658 |#2|)) (-1 (-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) 
+((-2038 (((-3 (-658 |#2|) "failed") (-592) |#2| |#2| |#2| (-1191) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-658 |#2|)) (-1 (-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) 47))) 
+(((-1042 |#1| |#2|) (-10 -7 (-15 -2038 ((-3 (-658 |#2|) "failed") (-592) |#2| |#2| |#2| (-1191) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-658 |#2|)) (-1 (-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592))) (-13 (-1211) (-27) (-456 |#1|))) (T -1042)) 
+((-2038 (*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| -12 (-5 *5 (-1191)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-658 *4))) (-5 *7 (-1 (-3 (-2 (|:| -3191 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1211) (-27) (-456 *8))) (-4 *8 (-13 (-477) (-869) (-171) (-1065 *3) (-654 *3))) (-5 *3 (-592)) (-5 *2 (-658 *4)) (-5 *1 (-1042 *8 *4))))) 
+(-10 -7 (-15 -2038 ((-3 (-658 |#2|) "failed") (-592) |#2| |#2| |#2| (-1191) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-658 |#2|)) (-1 (-3 (-2 (|:| -3191 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) 
+((-4357 (((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-141)))) (|:| -2042 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-592)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-592) (-1 |#2| |#2|)) 30)) (-1317 (((-3 (-2 (|:| |a| |#2|) (|:| |b| (-433 |#2|)) (|:| |c| (-433 |#2|)) (|:| -4132 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-1 |#2| |#2|)) 56)) (-1864 (((-2 (|:| |ans| (-433 |#2|)) (|:| |nosol| (-141))) (-433 |#2|) (-433 |#2|)) 61))) 
+(((-1043 |#1| |#2|) (-10 -7 (-15 -1317 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-433 |#2|)) (|:| |c| (-433 |#2|)) (|:| -4132 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-1 |#2| |#2|))) (-15 -1864 ((-2 (|:| |ans| (-433 |#2|)) (|:| |nosol| (-141))) (-433 |#2|) (-433 |#2|))) (-15 -4357 ((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-141)))) (|:| -2042 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-592)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-592) (-1 |#2| |#2|)))) (-13 (-388) (-171) (-1065 (-592))) (-1255 |#1|)) (T -1043)) 
+((-4357 (*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-1 *3 *3)) (-4 *3 (-1255 *6)) (-4 *6 (-13 (-388) (-171) (-1065 *4))) (-5 *4 (-592)) (-5 *2 (-3 (|:| |ans| (-2 (|:| |ans| *3) (|:| |nosol| (-141)))) (|:| -2042 (-2 (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (-5 *1 (-1043 *6 *3)))) (-1864 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-592)))) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| |ans| (-433 *5)) (|:| |nosol| (-141)))) (-5 *1 (-1043 *4 *5)) (-5 *3 (-433 *5)))) (-1317 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-433 *6)) (|:| |c| (-433 *6)) (|:| -4132 *6))) (-5 *1 (-1043 *5 *6)) (-5 *3 (-433 *6))))) 
+(-10 -7 (-15 -1317 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-433 |#2|)) (|:| |c| (-433 |#2|)) (|:| -4132 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-1 |#2| |#2|))) (-15 -1864 ((-2 (|:| |ans| (-433 |#2|)) (|:| |nosol| (-141))) (-433 |#2|) (-433 |#2|))) (-15 -4357 ((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-141)))) (|:| -2042 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-592)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-592) (-1 |#2| |#2|)))) 
+((-1711 (((-3 (-2 (|:| |a| |#2|) (|:| |b| (-433 |#2|)) (|:| |h| |#2|) (|:| |c1| (-433 |#2|)) (|:| |c2| (-433 |#2|)) (|:| -4132 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|) (-1 |#2| |#2|)) 22)) (-1377 (((-3 (-658 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|)) 32))) 
+(((-1044 |#1| |#2|) (-10 -7 (-15 -1711 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-433 |#2|)) (|:| |h| |#2|) (|:| |c1| (-433 |#2|)) (|:| |c2| (-433 |#2|)) (|:| -4132 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|) (-1 |#2| |#2|))) (-15 -1377 ((-3 (-658 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|)))) (-13 (-388) (-171) (-1065 (-592))) (-1255 |#1|)) (T -1044)) 
+((-1377 (*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-388) (-171) (-1065 (-592)))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-433 *5))) (-5 *1 (-1044 *4 *5)) (-5 *3 (-433 *5)))) (-1711 (*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-433 *6)) (|:| |h| *6) (|:| |c1| (-433 *6)) (|:| |c2| (-433 *6)) (|:| -4132 *6))) (-5 *1 (-1044 *5 *6)) (-5 *3 (-433 *6))))) 
+(-10 -7 (-15 -1711 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-433 |#2|)) (|:| |h| |#2|) (|:| |c1| (-433 |#2|)) (|:| |c2| (-433 |#2|)) (|:| -4132 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|) (-1 |#2| |#2|))) (-15 -1377 ((-3 (-658 (-433 |#2|)) "failed") (-433 |#2|) (-433 |#2|) (-433 |#2|)))) 
+((-3065 (((-1 |#1|) (-658 (-2 (|:| -2324 |#1|) (|:| -3775 (-592))))) 37)) (-3941 (((-1 |#1|) (-1121 |#1|)) 45)) (-3976 (((-1 |#1|) (-1280 |#1|) (-1280 (-592)) (-592)) 34))) 
+(((-1045 |#1|) (-10 -7 (-15 -3941 ((-1 |#1|) (-1121 |#1|))) (-15 -3065 ((-1 |#1|) (-658 (-2 (|:| -2324 |#1|) (|:| -3775 (-592)))))) (-15 -3976 ((-1 |#1|) (-1280 |#1|) (-1280 (-592)) (-592)))) (-1119)) (T -1045)) 
+((-3976 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1280 *6)) (-5 *4 (-1280 (-592))) (-5 *5 (-592)) (-4 *6 (-1119)) (-5 *2 (-1 *6)) (-5 *1 (-1045 *6)))) (-3065 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -2324 *4) (|:| -3775 (-592))))) (-4 *4 (-1119)) (-5 *2 (-1 *4)) (-5 *1 (-1045 *4)))) (-3941 (*1 *2 *3) (-12 (-5 *3 (-1121 *4)) (-4 *4 (-1119)) (-5 *2 (-1 *4)) (-5 *1 (-1045 *4))))) 
+(-10 -7 (-15 -3941 ((-1 |#1|) (-1121 |#1|))) (-15 -3065 ((-1 |#1|) (-658 (-2 (|:| -2324 |#1|) (|:| -3775 (-592)))))) (-15 -3976 ((-1 |#1|) (-1280 |#1|) (-1280 (-592)) (-592)))) 
+((-4346 (((-790) (-356 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)) 23))) 
+(((-1046 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4346 ((-790) (-356 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)))) (-388) (-1255 |#1|) (-1255 (-433 |#2|)) (-362 |#1| |#2| |#3|) (-13 (-394) (-388))) (T -1046)) 
+((-4346 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-356 *6 *7 *4 *8)) (-5 *5 (-1 *9 *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-4 *4 (-1255 (-433 *7))) (-4 *8 (-362 *6 *7 *4)) (-4 *9 (-13 (-394) (-388))) (-5 *2 (-790)) (-5 *1 (-1046 *6 *7 *4 *8 *9))))) 
+(-10 -7 (-15 -4346 ((-790) (-356 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)))) 
+((-4028 (((-3 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) "failed") |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) 31) (((-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592))) 28)) (-3785 (((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592))) 33) (((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-433 (-592))) 29) (((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) 32) (((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1|) 27)) (-2495 (((-658 (-433 (-592))) (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) 19)) (-1408 (((-433 (-592)) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) 16))) 
+(((-1047 |#1|) (-10 -7 (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1|)) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-433 (-592)))) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592)))) (-15 -4028 ((-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592)))) (-15 -4028 ((-3 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) "failed") |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-15 -1408 ((-433 (-592)) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-15 -2495 ((-658 (-433 (-592))) (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))))) (-1255 (-592))) (T -1047)) 
+((-2495 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *2 (-658 (-433 (-592)))) (-5 *1 (-1047 *4)) (-4 *4 (-1255 (-592))))) (-1408 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *2 (-433 (-592))) (-5 *1 (-1047 *4)) (-4 *4 (-1255 (-592))))) (-4028 (*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))))) (-4028 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *4 (-433 (-592))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))))) (-3785 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-433 (-592))) (-5 *2 (-658 (-2 (|:| -1961 *5) (|:| -1954 *5)))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))) (-5 *4 (-2 (|:| -1961 *5) (|:| -1954 *5))))) (-3785 (*1 *2 *3 *4) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))) (-5 *4 (-433 (-592))))) (-3785 (*1 *2 *3 *4) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))) (-5 *4 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))))) (-3785 (*1 *2 *3) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592)))))) 
+(-10 -7 (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1|)) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-433 (-592)))) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592)))) (-15 -4028 ((-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592)))) (-15 -4028 ((-3 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) "failed") |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-15 -1408 ((-433 (-592)) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-15 -2495 ((-658 (-433 (-592))) (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))))) 
+((-4028 (((-3 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) "failed") |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) 35) (((-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592))) 32)) (-3785 (((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592))) 30) (((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-433 (-592))) 26) (((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) 28) (((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1|) 24))) 
+(((-1048 |#1|) (-10 -7 (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1|)) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-433 (-592)))) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592)))) (-15 -4028 ((-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592)))) (-15 -4028 ((-3 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) "failed") |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))))) (-1255 (-433 (-592)))) (T -1048)) 
+((-4028 (*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 (-433 (-592)))))) (-4028 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *4 (-433 (-592))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 *4)))) (-3785 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-433 (-592))) (-5 *2 (-658 (-2 (|:| -1961 *5) (|:| -1954 *5)))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 *5)) (-5 *4 (-2 (|:| -1961 *5) (|:| -1954 *5))))) (-3785 (*1 *2 *3 *4) (-12 (-5 *4 (-433 (-592))) (-5 *2 (-658 (-2 (|:| -1961 *4) (|:| -1954 *4)))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 *4)))) (-3785 (*1 *2 *3 *4) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 (-433 (-592)))) (-5 *4 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))))) (-3785 (*1 *2 *3) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 (-433 (-592))))))) 
+(-10 -7 (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1|)) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-433 (-592)))) (-15 -3785 ((-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592)))) (-15 -4028 ((-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-433 (-592)))) (-15 -4028 ((-3 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) "failed") |#1| (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))) (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))))) 
+((-1778 (((-237) $) 6) (((-405) $) 8))) 
+(((-1049) (-1311)) (T -1049)) 
+NIL 
+(-13 (-633 (-237)) (-633 (-405))) 
+(((-633 (-237)) . T) ((-633 (-405)) . T)) 
+((-4005 (((-658 (-405)) (-980 (-592)) (-405)) 27) (((-658 (-405)) (-980 (-433 (-592))) (-405)) 26)) (-3006 (((-658 (-658 (-405))) (-658 (-980 (-592))) (-658 (-1191)) (-405)) 36))) 
+(((-1050) (-10 -7 (-15 -4005 ((-658 (-405)) (-980 (-433 (-592))) (-405))) (-15 -4005 ((-658 (-405)) (-980 (-592)) (-405))) (-15 -3006 ((-658 (-658 (-405))) (-658 (-980 (-592))) (-658 (-1191)) (-405))))) (T -1050)) 
+((-3006 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-658 (-1191))) (-5 *2 (-658 (-658 (-405)))) (-5 *1 (-1050)) (-5 *5 (-405)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-980 (-592))) (-5 *2 (-658 (-405))) (-5 *1 (-1050)) (-5 *4 (-405)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-980 (-433 (-592)))) (-5 *2 (-658 (-405))) (-5 *1 (-1050)) (-5 *4 (-405))))) 
+(-10 -7 (-15 -4005 ((-658 (-405)) (-980 (-433 (-592))) (-405))) (-15 -4005 ((-658 (-405)) (-980 (-592)) (-405))) (-15 -3006 ((-658 (-658 (-405))) (-658 (-980 (-592))) (-658 (-1191)) (-405)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 70)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-1442 (($ $) NIL) (($ $ (-790)) NIL) (($ (-433 (-592))) NIL) (($ (-592)) NIL)) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) 65)) (-3001 (($) NIL T CONST)) (-3906 (((-3 $ "failed") (-1187 $) (-944) (-877)) NIL) (((-3 $ "failed") (-1187 $) (-944)) 49)) (-4368 (((-3 (-433 (-592)) "failed") $) NIL (|has| (-433 (-592)) (-1065 (-433 (-592))))) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 |#1| "failed") $) 108) (((-3 (-592) "failed") $) NIL (-3836 (|has| (-433 (-592)) (-1065 (-592))) (|has| |#1| (-1065 (-592)))))) (-2400 (((-433 (-592)) $) 14 (|has| (-433 (-592)) (-1065 (-433 (-592))))) (((-433 (-592)) $) 14) ((|#1| $) 109) (((-592) $) NIL (-3836 (|has| (-433 (-592)) (-1065 (-592))) (|has| |#1| (-1065 (-592)))))) (-4548 (($ $ (-877)) 40)) (-4460 (($ $ (-877)) 41)) (-1586 (($ $ $) NIL)) (-4216 (((-433 (-592)) $ $) 18)) (-3371 (((-3 $ "failed") $) 83)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-1691 (((-141) $) 60)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL)) (-1324 (((-141) $) 63)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-1514 (((-3 (-1187 $) "failed") $) 78)) (-4385 (((-3 (-877) "failed") $) 77)) (-2235 (((-3 (-1187 $) "failed") $) 75)) (-2372 (((-3 (-1085 $ (-1187 $)) "failed") $) 73)) (-2750 (($ (-658 $)) NIL) (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 84)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ (-658 $)) NIL) (($ $ $) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-1683 (((-877) $) 82) (($ (-592)) NIL) (($ (-433 (-592))) NIL) (($ $) 57) (($ (-433 (-592))) NIL) (($ (-592)) NIL) (($ (-433 (-592))) NIL) (($ |#1|) 111)) (-4010 (((-790)) NIL)) (-2537 (((-141) $ $) NIL)) (-2642 (((-433 (-592)) $ $) 24)) (-3740 (((-658 $) (-1187 $)) 55) (((-658 $) (-1187 (-433 (-592)))) NIL) (((-658 $) (-1187 (-592))) NIL) (((-658 $) (-980 $)) NIL) (((-658 $) (-980 (-433 (-592)))) NIL) (((-658 $) (-980 (-592))) NIL)) (-2765 (($ (-1085 $ (-1187 $)) (-877)) 39)) (-1392 (($ $) 19)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL)) (-3514 (($) 28 T CONST)) (-4257 (($) 34 T CONST)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 71)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 21)) (-3313 (($ $ $) 32)) (-3306 (($ $) 33) (($ $ $) 69)) (-3300 (($ $ $) 104)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL) (($ $ (-433 (-592))) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 92) (($ $ $) 97) (($ (-433 (-592)) $) NIL) (($ $ (-433 (-592))) NIL) (($ (-592) $) 92) (($ $ (-592)) NIL) (($ (-433 (-592)) $) NIL) (($ $ (-433 (-592))) NIL) (($ |#1| $) 96) (($ $ |#1|) NIL))) 
+(((-1051 |#1|) (-13 (-1040) (-437 |#1|) (-43 |#1|) (-10 -8 (-15 -2765 ($ (-1085 $ (-1187 $)) (-877))) (-15 -2372 ((-3 (-1085 $ (-1187 $)) "failed") $)) (-15 -4216 ((-433 (-592)) $ $)))) (-13 (-867) (-388) (-1049))) (T -1051)) 
+((-2765 (*1 *1 *2 *3) (-12 (-5 *2 (-1085 (-1051 *4) (-1187 (-1051 *4)))) (-5 *3 (-877)) (-5 *1 (-1051 *4)) (-4 *4 (-13 (-867) (-388) (-1049))))) (-2372 (*1 *2 *1) (|partial| -12 (-5 *2 (-1085 (-1051 *3) (-1187 (-1051 *3)))) (-5 *1 (-1051 *3)) (-4 *3 (-13 (-867) (-388) (-1049))))) (-4216 (*1 *2 *1 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-1051 *3)) (-4 *3 (-13 (-867) (-388) (-1049)))))) 
+(-13 (-1040) (-437 |#1|) (-43 |#1|) (-10 -8 (-15 -2765 ($ (-1085 $ (-1187 $)) (-877))) (-15 -2372 ((-3 (-1085 $ (-1187 $)) "failed") $)) (-15 -4216 ((-433 (-592)) $ $)))) 
+((-2150 (((-2 (|:| -3319 (-3 (-592) "failed")) (|:| -2016 (-3 (-592) "failed")) (|:| |ker| (-631 |#2|))) (-143) (-1191) |#2|) 59 (|has| |#1| (-1075)))) (-3056 (((-592) (-592) (-143) (-1191) |#2|) 76)) (-2212 (((-3 (-592) "failed") (-143) (-631 |#2|) (-1191)) 56 (|has| |#1| (-1075)))) (-3196 (((-143) |#2|) 103)) (-3343 ((|#2| |#2|) 102)) (-4379 ((|#2| (-143) (-1191) |#2| |#2| |#2| (-658 |#2|)) 72)) (-2079 ((|#2| (-143) (-1191) |#2| |#2| |#2| (-658 |#2|)) 100))) 
+(((-1052 |#1| |#2|) (-10 -7 (-15 -4379 (|#2| (-143) (-1191) |#2| |#2| |#2| (-658 |#2|))) (-15 -2079 (|#2| (-143) (-1191) |#2| |#2| |#2| (-658 |#2|))) (-15 -3343 (|#2| |#2|)) (-15 -3196 ((-143) |#2|)) (-15 -3056 ((-592) (-592) (-143) (-1191) |#2|)) (IF (|has| |#1| (-1075)) (PROGN (-15 -2212 ((-3 (-592) "failed") (-143) (-631 |#2|) (-1191))) (-15 -2150 ((-2 (|:| -3319 (-3 (-592) "failed")) (|:| -2016 (-3 (-592) "failed")) (|:| |ker| (-631 |#2|))) (-143) (-1191) |#2|))) |noBranch|)) (-13 (-869) (-582) (-633 (-565))) (-13 (-456 |#1|) (-23) (-1065 (-592)) (-1065 (-1191)) (-922 (-1191)) (-182))) (T -1052)) 
+((-2150 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-143)) (-5 *4 (-1191)) (-4 *6 (-1075)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-2 (|:| -3319 (-3 (-592) "failed")) (|:| -2016 (-3 (-592) "failed")) (|:| |ker| (-631 *5)))) (-5 *1 (-1052 *6 *5)) (-4 *5 (-13 (-456 *6) (-23) (-1065 (-592)) (-1065 *4) (-922 *4) (-182))))) (-2212 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-143)) (-5 *4 (-631 *7)) (-4 *7 (-13 (-456 *6) (-23) (-1065 *2) (-1065 *5) (-922 *5) (-182))) (-5 *5 (-1191)) (-4 *6 (-1075)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-592)) (-5 *1 (-1052 *6 *7)))) (-3056 (*1 *2 *2 *3 *4 *5) (-12 (-5 *3 (-143)) (-5 *2 (-592)) (-5 *4 (-1191)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *1 (-1052 *6 *5)) (-4 *5 (-13 (-456 *6) (-23) (-1065 *2) (-1065 *4) (-922 *4) (-182))))) (-3196 (*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-143)) (-5 *1 (-1052 *4 *3)) (-4 *3 (-13 (-456 *4) (-23) (-1065 (-592)) (-1065 (-1191)) (-922 (-1191)) (-182))))) (-3343 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582) (-633 (-565)))) (-5 *1 (-1052 *3 *2)) (-4 *2 (-13 (-456 *3) (-23) (-1065 (-592)) (-1065 (-1191)) (-922 (-1191)) (-182))))) (-2079 (*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-143)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-456 *6) (-23) (-1065 (-592)) (-1065 *4) (-922 *4) (-182))) (-5 *4 (-1191)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *1 (-1052 *6 *2)))) (-4379 (*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-143)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-456 *6) (-23) (-1065 (-592)) (-1065 *4) (-922 *4) (-182))) (-5 *4 (-1191)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *1 (-1052 *6 *2))))) 
+(-10 -7 (-15 -4379 (|#2| (-143) (-1191) |#2| |#2| |#2| (-658 |#2|))) (-15 -2079 (|#2| (-143) (-1191) |#2| |#2| |#2| (-658 |#2|))) (-15 -3343 (|#2| |#2|)) (-15 -3196 ((-143) |#2|)) (-15 -3056 ((-592) (-592) (-143) (-1191) |#2|)) (IF (|has| |#1| (-1075)) (PROGN (-15 -2212 ((-3 (-592) "failed") (-143) (-631 |#2|) (-1191))) (-15 -2150 ((-2 (|:| -3319 (-3 (-592) "failed")) (|:| -2016 (-3 (-592) "failed")) (|:| |ker| (-631 |#2|))) (-143) (-1191) |#2|))) |noBranch|)) 
+((-1977 (((-2 (|:| -2042 |#2|) (|:| -1608 (-658 |#1|))) |#2| (-658 |#1|)) 20) ((|#2| |#2| |#1|) 15))) 
+(((-1053 |#1| |#2|) (-10 -7 (-15 -1977 (|#2| |#2| |#1|)) (-15 -1977 ((-2 (|:| -2042 |#2|) (|:| -1608 (-658 |#1|))) |#2| (-658 |#1|)))) (-388) (-670 |#1|)) (T -1053)) 
+((-1977 (*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-5 *2 (-2 (|:| -2042 *3) (|:| -1608 (-658 *5)))) (-5 *1 (-1053 *5 *3)) (-5 *4 (-658 *5)) (-4 *3 (-670 *5)))) (-1977 (*1 *2 *2 *3) (-12 (-4 *3 (-388)) (-5 *1 (-1053 *3 *2)) (-4 *2 (-670 *3))))) 
+(-10 -7 (-15 -1977 (|#2| |#2| |#1|)) (-15 -1977 ((-2 (|:| -2042 |#2|) (|:| -1608 (-658 |#1|))) |#2| (-658 |#1|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1758 ((|#1| $ |#1|) 14)) (-3932 ((|#1| $ |#1|) 12)) (-2718 (($ |#1|) 10)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3927 ((|#1| $) 11)) (-2425 ((|#1| $) 13)) (-1683 (((-877) $) 21 (|has| |#1| (-1119)))) (-3255 (((-141) $ $) 9))) 
+(((-1054 |#1|) (-13 (-1225) (-10 -8 (-15 -2718 ($ |#1|)) (-15 -3927 (|#1| $)) (-15 -3932 (|#1| $ |#1|)) (-15 -2425 (|#1| $)) (-15 -1758 (|#1| $ |#1|)) (-15 -3255 ((-141) $ $)) (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|))) (-1225)) (T -1054)) 
+((-2718 (*1 *1 *2) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225)))) (-3927 (*1 *2 *1) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225)))) (-3932 (*1 *2 *1 *2) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225)))) (-2425 (*1 *2 *1) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225)))) (-1758 (*1 *2 *1 *2) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225)))) (-3255 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1054 *3)) (-4 *3 (-1225))))) 
+(-13 (-1225) (-10 -8 (-15 -2718 ($ |#1|)) (-15 -3927 (|#1| $)) (-15 -3932 (|#1| $ |#1|)) (-15 -2425 (|#1| $)) (-15 -1758 (|#1| $ |#1|)) (-15 -3255 ((-141) $ $)) (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) NIL)) (-2248 (((-658 $) (-658 |#4|)) 104) (((-658 $) (-658 |#4|) (-141)) 105) (((-658 $) (-658 |#4|) (-141) (-141)) 103) (((-658 $) (-658 |#4|) (-141) (-141) (-141) (-141)) 106)) (-4085 (((-658 |#3|) $) NIL)) (-4325 (((-141) $) NIL)) (-2988 (((-141) $) NIL (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-2244 ((|#4| |#4| $) NIL)) (-3743 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| $) 98)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3113 (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) 53)) (-3001 (($) NIL T CONST)) (-3239 (((-141) $) 26 (|has| |#1| (-582)))) (-3478 (((-141) $ $) NIL (|has| |#1| (-582)))) (-2398 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1529 (((-141) $) NIL (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-4521 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) NIL)) (-2400 (($ (-658 |#4|)) NIL)) (-1366 (((-3 $ "failed") $) 39)) (-2226 ((|#4| |#4| $) 56)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-4459 (($ |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 72 (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) NIL)) (-3092 ((|#4| |#4| $) NIL)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) NIL)) (-1836 (((-141) |#4| $) NIL)) (-2659 (((-141) |#4| $) NIL)) (-3195 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1822 (((-2 (|:| |val| (-658 |#4|)) (|:| |towers| (-658 $))) (-658 |#4|) (-141) (-141)) 118)) (-4004 (((-658 |#4|) $) 16 (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#4|) $) 17 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 25 (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-3987 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 21)) (-2290 (((-658 |#3|) $) NIL)) (-2645 (((-141) |#3| $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-1470 (((-3 |#4| (-658 $)) |#4| |#4| $) NIL)) (-3722 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| |#4| $) 96)) (-4255 (((-3 |#4| "failed") $) 37)) (-3501 (((-658 $) |#4| $) 79)) (-3732 (((-3 (-141) (-658 $)) |#4| $) NIL)) (-2978 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 $))) |#4| $) 89) (((-141) |#4| $) 51)) (-2852 (((-658 $) |#4| $) 101) (((-658 $) (-658 |#4|) $) NIL) (((-658 $) (-658 |#4|) (-658 $)) 102) (((-658 $) |#4| (-658 $)) NIL)) (-3859 (((-658 $) (-658 |#4|) (-141) (-141) (-141)) 113)) (-3902 (($ |#4| $) 69) (($ (-658 |#4|) $) 70) (((-658 $) |#4| $ (-141) (-141) (-141) (-141) (-141)) 66)) (-1712 (((-658 |#4|) $) NIL)) (-2346 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1751 ((|#4| |#4| $) NIL)) (-3085 (((-141) $ $) NIL)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1803 ((|#4| |#4| $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-3 |#4| "failed") $) 35)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) NIL)) (-2778 (((-3 $ "failed") $ |#4|) 47)) (-2807 (($ $ |#4|) NIL) (((-658 $) |#4| $) 81) (((-658 $) |#4| (-658 $)) NIL) (((-658 $) (-658 |#4|) $) NIL) (((-658 $) (-658 |#4|) (-658 $)) 76)) (-3002 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 15)) (-2890 (($) 13)) (-4525 (((-790) $) NIL)) (-3452 (((-790) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (((-790) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) 12)) (-1778 (((-565) $) NIL (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 20)) (-2613 (($ $ |#3|) 42)) (-4152 (($ $ |#3|) 43)) (-2965 (($ $) NIL)) (-2507 (($ $ |#3|) NIL)) (-1683 (((-877) $) 31) (((-658 |#4|) $) 40)) (-1857 (((-790) $) NIL (|has| |#3| (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) NIL)) (-3032 (((-658 $) |#4| $) 78) (((-658 $) |#4| (-658 $)) NIL) (((-658 $) (-658 |#4|) $) NIL) (((-658 $) (-658 |#4|) (-658 $)) NIL)) (-3369 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) NIL)) (-1437 (((-141) |#4| $) NIL)) (-3069 (((-141) |#3| $) 52)) (-3255 (((-141) $ $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1055 |#1| |#2| |#3| |#4|) (-13 (-1094 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3902 ((-658 $) |#4| $ (-141) (-141) (-141) (-141) (-141))) (-15 -2248 ((-658 $) (-658 |#4|) (-141) (-141))) (-15 -2248 ((-658 $) (-658 |#4|) (-141) (-141) (-141) (-141))) (-15 -3859 ((-658 $) (-658 |#4|) (-141) (-141) (-141))) (-15 -1822 ((-2 (|:| |val| (-658 |#4|)) (|:| |towers| (-658 $))) (-658 |#4|) (-141) (-141))))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|)) (T -1055)) 
+((-3902 (*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1055 *5 *6 *7 *3))) (-5 *1 (-1055 *5 *6 *7 *3)) (-4 *3 (-1089 *5 *6 *7)))) (-2248 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1055 *5 *6 *7 *8))) (-5 *1 (-1055 *5 *6 *7 *8)))) (-2248 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1055 *5 *6 *7 *8))) (-5 *1 (-1055 *5 *6 *7 *8)))) (-3859 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1055 *5 *6 *7 *8))) (-5 *1 (-1055 *5 *6 *7 *8)))) (-1822 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-658 *8)) (|:| |towers| (-658 (-1055 *5 *6 *7 *8))))) (-5 *1 (-1055 *5 *6 *7 *8)) (-5 *3 (-658 *8))))) 
+(-13 (-1094 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3902 ((-658 $) |#4| $ (-141) (-141) (-141) (-141) (-141))) (-15 -2248 ((-658 $) (-658 |#4|) (-141) (-141))) (-15 -2248 ((-658 $) (-658 |#4|) (-141) (-141) (-141) (-141))) (-15 -3859 ((-658 $) (-658 |#4|) (-141) (-141) (-141))) (-15 -1822 ((-2 (|:| |val| (-658 |#4|)) (|:| |towers| (-658 $))) (-658 |#4|) (-141) (-141))))) 
+((-1870 (((-658 (-706 |#1|)) (-658 (-706 |#1|))) 56) (((-706 |#1|) (-706 |#1|)) 55) (((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-658 (-706 |#1|))) 54) (((-706 |#1|) (-706 |#1|) (-706 |#1|)) 51)) (-2722 (((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-944)) 50) (((-706 |#1|) (-706 |#1|) (-944)) 49)) (-3245 (((-658 (-706 (-592))) (-658 (-658 (-592)))) 66) (((-658 (-706 (-592))) (-658 (-927 (-592))) (-592)) 65) (((-706 (-592)) (-658 (-592))) 62) (((-706 (-592)) (-927 (-592)) (-592)) 61)) (-4014 (((-706 (-980 |#1|)) (-790)) 79)) (-1939 (((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-944)) 36 (|has| |#1| (-6 (-4627 "*")))) (((-706 |#1|) (-706 |#1|) (-944)) 34 (|has| |#1| (-6 (-4627 "*")))))) 
+(((-1056 |#1|) (-10 -7 (IF (|has| |#1| (-6 (-4627 "*"))) (-15 -1939 ((-706 |#1|) (-706 |#1|) (-944))) |noBranch|) (IF (|has| |#1| (-6 (-4627 "*"))) (-15 -1939 ((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-944))) |noBranch|) (-15 -4014 ((-706 (-980 |#1|)) (-790))) (-15 -2722 ((-706 |#1|) (-706 |#1|) (-944))) (-15 -2722 ((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-944))) (-15 -1870 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -1870 ((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-658 (-706 |#1|)))) (-15 -1870 ((-706 |#1|) (-706 |#1|))) (-15 -1870 ((-658 (-706 |#1|)) (-658 (-706 |#1|)))) (-15 -3245 ((-706 (-592)) (-927 (-592)) (-592))) (-15 -3245 ((-706 (-592)) (-658 (-592)))) (-15 -3245 ((-658 (-706 (-592))) (-658 (-927 (-592))) (-592))) (-15 -3245 ((-658 (-706 (-592))) (-658 (-658 (-592)))))) (-1075)) (T -1056)) 
+((-3245 (*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-592)))) (-5 *2 (-658 (-706 (-592)))) (-5 *1 (-1056 *4)) (-4 *4 (-1075)))) (-3245 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-927 (-592)))) (-5 *4 (-592)) (-5 *2 (-658 (-706 *4))) (-5 *1 (-1056 *5)) (-4 *5 (-1075)))) (-3245 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-706 (-592))) (-5 *1 (-1056 *4)) (-4 *4 (-1075)))) (-3245 (*1 *2 *3 *4) (-12 (-5 *3 (-927 (-592))) (-5 *4 (-592)) (-5 *2 (-706 *4)) (-5 *1 (-1056 *5)) (-4 *5 (-1075)))) (-1870 (*1 *2 *2) (-12 (-5 *2 (-658 (-706 *3))) (-4 *3 (-1075)) (-5 *1 (-1056 *3)))) (-1870 (*1 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-1056 *3)))) (-1870 (*1 *2 *2 *2) (-12 (-5 *2 (-658 (-706 *3))) (-4 *3 (-1075)) (-5 *1 (-1056 *3)))) (-1870 (*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-1056 *3)))) (-2722 (*1 *2 *2 *3) (-12 (-5 *2 (-658 (-706 *4))) (-5 *3 (-944)) (-4 *4 (-1075)) (-5 *1 (-1056 *4)))) (-2722 (*1 *2 *2 *3) (-12 (-5 *2 (-706 *4)) (-5 *3 (-944)) (-4 *4 (-1075)) (-5 *1 (-1056 *4)))) (-4014 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-706 (-980 *4))) (-5 *1 (-1056 *4)) (-4 *4 (-1075)))) (-1939 (*1 *2 *2 *3) (-12 (-5 *2 (-658 (-706 *4))) (-5 *3 (-944)) (|has| *4 (-6 (-4627 "*"))) (-4 *4 (-1075)) (-5 *1 (-1056 *4)))) (-1939 (*1 *2 *2 *3) (-12 (-5 *2 (-706 *4)) (-5 *3 (-944)) (|has| *4 (-6 (-4627 "*"))) (-4 *4 (-1075)) (-5 *1 (-1056 *4))))) 
+(-10 -7 (IF (|has| |#1| (-6 (-4627 "*"))) (-15 -1939 ((-706 |#1|) (-706 |#1|) (-944))) |noBranch|) (IF (|has| |#1| (-6 (-4627 "*"))) (-15 -1939 ((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-944))) |noBranch|) (-15 -4014 ((-706 (-980 |#1|)) (-790))) (-15 -2722 ((-706 |#1|) (-706 |#1|) (-944))) (-15 -2722 ((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-944))) (-15 -1870 ((-706 |#1|) (-706 |#1|) (-706 |#1|))) (-15 -1870 ((-658 (-706 |#1|)) (-658 (-706 |#1|)) (-658 (-706 |#1|)))) (-15 -1870 ((-706 |#1|) (-706 |#1|))) (-15 -1870 ((-658 (-706 |#1|)) (-658 (-706 |#1|)))) (-15 -3245 ((-706 (-592)) (-927 (-592)) (-592))) (-15 -3245 ((-706 (-592)) (-658 (-592)))) (-15 -3245 ((-658 (-706 (-592))) (-658 (-927 (-592))) (-592))) (-15 -3245 ((-658 (-706 (-592))) (-658 (-658 (-592)))))) 
+((-2870 (((-706 |#1|) (-658 (-706 |#1|)) (-1280 |#1|)) 48 (|has| |#1| (-323)))) (-1356 (((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-1280 (-1280 |#1|))) 71 (|has| |#1| (-388))) (((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-1280 |#1|)) 69 (|has| |#1| (-388)))) (-2055 (((-1280 |#1|) (-658 (-1280 |#1|)) (-592)) 73 (-12 (|has| |#1| (-388)) (|has| |#1| (-394))))) (-2115 (((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-944)) 78 (-12 (|has| |#1| (-388)) (|has| |#1| (-394)))) (((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-141)) 76 (-12 (|has| |#1| (-388)) (|has| |#1| (-394)))) (((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|))) 75 (-12 (|has| |#1| (-388)) (|has| |#1| (-394)))) (((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-141) (-592) (-592)) 74 (-12 (|has| |#1| (-388)) (|has| |#1| (-394))))) (-3526 (((-141) (-658 (-706 |#1|))) 67 (|has| |#1| (-388))) (((-141) (-658 (-706 |#1|)) (-592)) 66 (|has| |#1| (-388)))) (-2439 (((-1280 (-1280 |#1|)) (-658 (-706 |#1|)) (-1280 |#1|)) 46 (|has| |#1| (-323)))) (-3044 (((-706 |#1|) (-658 (-706 |#1|)) (-706 |#1|)) 32)) (-2401 (((-706 |#1|) (-1280 (-1280 |#1|))) 29)) (-2445 (((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|)) (-592)) 62 (|has| |#1| (-388))) (((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|))) 61 (|has| |#1| (-388))) (((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|)) (-141) (-592)) 60 (|has| |#1| (-388))))) 
+(((-1057 |#1|) (-10 -7 (-15 -2401 ((-706 |#1|) (-1280 (-1280 |#1|)))) (-15 -3044 ((-706 |#1|) (-658 (-706 |#1|)) (-706 |#1|))) (IF (|has| |#1| (-323)) (PROGN (-15 -2439 ((-1280 (-1280 |#1|)) (-658 (-706 |#1|)) (-1280 |#1|))) (-15 -2870 ((-706 |#1|) (-658 (-706 |#1|)) (-1280 |#1|)))) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-15 -2445 ((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|)) (-141) (-592))) (-15 -2445 ((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|)))) (-15 -2445 ((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|)) (-592))) (-15 -3526 ((-141) (-658 (-706 |#1|)) (-592))) (-15 -3526 ((-141) (-658 (-706 |#1|)))) (-15 -1356 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-1280 |#1|))) (-15 -1356 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-1280 (-1280 |#1|))))) |noBranch|) (IF (|has| |#1| (-394)) (IF (|has| |#1| (-388)) (PROGN (-15 -2115 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-141) (-592) (-592))) (-15 -2115 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)))) (-15 -2115 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-141))) (-15 -2115 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-944))) (-15 -2055 ((-1280 |#1|) (-658 (-1280 |#1|)) (-592)))) |noBranch|) |noBranch|)) (-1075)) (T -1057)) 
+((-2055 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1280 *5))) (-5 *4 (-592)) (-5 *2 (-1280 *5)) (-5 *1 (-1057 *5)) (-4 *5 (-388)) (-4 *5 (-394)) (-4 *5 (-1075)))) (-2115 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-4 *5 (-394)) (-4 *5 (-1075)) (-5 *2 (-658 (-658 (-706 *5)))) (-5 *1 (-1057 *5)) (-5 *3 (-658 (-706 *5))))) (-2115 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-388)) (-4 *5 (-394)) (-4 *5 (-1075)) (-5 *2 (-658 (-658 (-706 *5)))) (-5 *1 (-1057 *5)) (-5 *3 (-658 (-706 *5))))) (-2115 (*1 *2 *3) (-12 (-4 *4 (-388)) (-4 *4 (-394)) (-4 *4 (-1075)) (-5 *2 (-658 (-658 (-706 *4)))) (-5 *1 (-1057 *4)) (-5 *3 (-658 (-706 *4))))) (-2115 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-141)) (-5 *5 (-592)) (-4 *6 (-388)) (-4 *6 (-394)) (-4 *6 (-1075)) (-5 *2 (-658 (-658 (-706 *6)))) (-5 *1 (-1057 *6)) (-5 *3 (-658 (-706 *6))))) (-1356 (*1 *2 *3 *4) (-12 (-5 *4 (-1280 (-1280 *5))) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-658 (-658 (-706 *5)))) (-5 *1 (-1057 *5)) (-5 *3 (-658 (-706 *5))))) (-1356 (*1 *2 *3 *4) (-12 (-5 *4 (-1280 *5)) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-658 (-658 (-706 *5)))) (-5 *1 (-1057 *5)) (-5 *3 (-658 (-706 *5))))) (-3526 (*1 *2 *3) (-12 (-5 *3 (-658 (-706 *4))) (-4 *4 (-388)) (-4 *4 (-1075)) (-5 *2 (-141)) (-5 *1 (-1057 *4)))) (-3526 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-706 *5))) (-5 *4 (-592)) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-141)) (-5 *1 (-1057 *5)))) (-2445 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 (-706 *5))) (-5 *4 (-592)) (-5 *2 (-706 *5)) (-5 *1 (-1057 *5)) (-4 *5 (-388)) (-4 *5 (-1075)))) (-2445 (*1 *2 *3 *3) (-12 (-5 *3 (-658 (-706 *4))) (-5 *2 (-706 *4)) (-5 *1 (-1057 *4)) (-4 *4 (-388)) (-4 *4 (-1075)))) (-2445 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-658 (-706 *6))) (-5 *4 (-141)) (-5 *5 (-592)) (-5 *2 (-706 *6)) (-5 *1 (-1057 *6)) (-4 *6 (-388)) (-4 *6 (-1075)))) (-2870 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-706 *5))) (-5 *4 (-1280 *5)) (-4 *5 (-323)) (-4 *5 (-1075)) (-5 *2 (-706 *5)) (-5 *1 (-1057 *5)))) (-2439 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-706 *5))) (-4 *5 (-323)) (-4 *5 (-1075)) (-5 *2 (-1280 (-1280 *5))) (-5 *1 (-1057 *5)) (-5 *4 (-1280 *5)))) (-3044 (*1 *2 *3 *2) (-12 (-5 *3 (-658 (-706 *4))) (-5 *2 (-706 *4)) (-4 *4 (-1075)) (-5 *1 (-1057 *4)))) (-2401 (*1 *2 *3) (-12 (-5 *3 (-1280 (-1280 *4))) (-4 *4 (-1075)) (-5 *2 (-706 *4)) (-5 *1 (-1057 *4))))) 
+(-10 -7 (-15 -2401 ((-706 |#1|) (-1280 (-1280 |#1|)))) (-15 -3044 ((-706 |#1|) (-658 (-706 |#1|)) (-706 |#1|))) (IF (|has| |#1| (-323)) (PROGN (-15 -2439 ((-1280 (-1280 |#1|)) (-658 (-706 |#1|)) (-1280 |#1|))) (-15 -2870 ((-706 |#1|) (-658 (-706 |#1|)) (-1280 |#1|)))) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-15 -2445 ((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|)) (-141) (-592))) (-15 -2445 ((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|)))) (-15 -2445 ((-706 |#1|) (-658 (-706 |#1|)) (-658 (-706 |#1|)) (-592))) (-15 -3526 ((-141) (-658 (-706 |#1|)) (-592))) (-15 -3526 ((-141) (-658 (-706 |#1|)))) (-15 -1356 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-1280 |#1|))) (-15 -1356 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-1280 (-1280 |#1|))))) |noBranch|) (IF (|has| |#1| (-394)) (IF (|has| |#1| (-388)) (PROGN (-15 -2115 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-141) (-592) (-592))) (-15 -2115 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)))) (-15 -2115 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-141))) (-15 -2115 ((-658 (-658 (-706 |#1|))) (-658 (-706 |#1|)) (-944))) (-15 -2055 ((-1280 |#1|) (-658 (-1280 |#1|)) (-592)))) |noBranch|) |noBranch|)) 
+((-3886 ((|#1| (-944) |#1|) 9))) 
+(((-1058 |#1|) (-10 -7 (-15 -3886 (|#1| (-944) |#1|))) (-13 (-1119) (-10 -8 (-15 -3300 ($ $ $))))) (T -1058)) 
+((-3886 (*1 *2 *3 *2) (-12 (-5 *3 (-944)) (-5 *1 (-1058 *2)) (-4 *2 (-13 (-1119) (-10 -8 (-15 -3300 ($ $ $)))))))) 
+(-10 -7 (-15 -3886 (|#1| (-944) |#1|))) 
+((-2474 (((-658 (-2 (|:| |radval| (-332 (-592))) (|:| |radmult| (-592)) (|:| |radvect| (-658 (-706 (-332 (-592))))))) (-706 (-433 (-980 (-592))))) 58)) (-1878 (((-658 (-706 (-332 (-592)))) (-332 (-592)) (-706 (-433 (-980 (-592))))) 48)) (-2689 (((-658 (-332 (-592))) (-706 (-433 (-980 (-592))))) 41)) (-1571 (((-658 (-706 (-332 (-592)))) (-706 (-433 (-980 (-592))))) 67)) (-3084 (((-706 (-332 (-592))) (-706 (-332 (-592)))) 33)) (-3097 (((-658 (-706 (-332 (-592)))) (-658 (-706 (-332 (-592))))) 61)) (-1924 (((-3 (-706 (-332 (-592))) "failed") (-706 (-433 (-980 (-592))))) 65))) 
+(((-1059) (-10 -7 (-15 -2474 ((-658 (-2 (|:| |radval| (-332 (-592))) (|:| |radmult| (-592)) (|:| |radvect| (-658 (-706 (-332 (-592))))))) (-706 (-433 (-980 (-592)))))) (-15 -1878 ((-658 (-706 (-332 (-592)))) (-332 (-592)) (-706 (-433 (-980 (-592)))))) (-15 -2689 ((-658 (-332 (-592))) (-706 (-433 (-980 (-592)))))) (-15 -1924 ((-3 (-706 (-332 (-592))) "failed") (-706 (-433 (-980 (-592)))))) (-15 -3084 ((-706 (-332 (-592))) (-706 (-332 (-592))))) (-15 -3097 ((-658 (-706 (-332 (-592)))) (-658 (-706 (-332 (-592)))))) (-15 -1571 ((-658 (-706 (-332 (-592)))) (-706 (-433 (-980 (-592)))))))) (T -1059)) 
+((-1571 (*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 (-592))))) (-5 *2 (-658 (-706 (-332 (-592))))) (-5 *1 (-1059)))) (-3097 (*1 *2 *2) (-12 (-5 *2 (-658 (-706 (-332 (-592))))) (-5 *1 (-1059)))) (-3084 (*1 *2 *2) (-12 (-5 *2 (-706 (-332 (-592)))) (-5 *1 (-1059)))) (-1924 (*1 *2 *3) (|partial| -12 (-5 *3 (-706 (-433 (-980 (-592))))) (-5 *2 (-706 (-332 (-592)))) (-5 *1 (-1059)))) (-2689 (*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 (-592))))) (-5 *2 (-658 (-332 (-592)))) (-5 *1 (-1059)))) (-1878 (*1 *2 *3 *4) (-12 (-5 *4 (-706 (-433 (-980 (-592))))) (-5 *2 (-658 (-706 (-332 (-592))))) (-5 *1 (-1059)) (-5 *3 (-332 (-592))))) (-2474 (*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| |radval| (-332 (-592))) (|:| |radmult| (-592)) (|:| |radvect| (-658 (-706 (-332 (-592)))))))) (-5 *1 (-1059))))) 
+(-10 -7 (-15 -2474 ((-658 (-2 (|:| |radval| (-332 (-592))) (|:| |radmult| (-592)) (|:| |radvect| (-658 (-706 (-332 (-592))))))) (-706 (-433 (-980 (-592)))))) (-15 -1878 ((-658 (-706 (-332 (-592)))) (-332 (-592)) (-706 (-433 (-980 (-592)))))) (-15 -2689 ((-658 (-332 (-592))) (-706 (-433 (-980 (-592)))))) (-15 -1924 ((-3 (-706 (-332 (-592))) "failed") (-706 (-433 (-980 (-592)))))) (-15 -3084 ((-706 (-332 (-592))) (-706 (-332 (-592))))) (-15 -3097 ((-658 (-706 (-332 (-592)))) (-658 (-706 (-332 (-592)))))) (-15 -1571 ((-658 (-706 (-332 (-592)))) (-706 (-433 (-980 (-592))))))) 
+((-3336 ((|#1| |#1| (-944)) 9))) 
+(((-1060 |#1|) (-10 -7 (-15 -3336 (|#1| |#1| (-944)))) (-13 (-1119) (-10 -8 (-15 * ($ $ $))))) (T -1060)) 
+((-3336 (*1 *2 *2 *3) (-12 (-5 *3 (-944)) (-5 *1 (-1060 *2)) (-4 *2 (-13 (-1119) (-10 -8 (-15 * ($ $ $)))))))) 
+(-10 -7 (-15 -3336 (|#1| |#1| (-944)))) 
+((-1683 ((|#1| (-327)) 11) (((-1285) |#1|) 9))) 
+(((-1061 |#1|) (-10 -7 (-15 -1683 ((-1285) |#1|)) (-15 -1683 (|#1| (-327)))) (-1225)) (T -1061)) 
+((-1683 (*1 *2 *3) (-12 (-5 *3 (-327)) (-5 *1 (-1061 *2)) (-4 *2 (-1225)))) (-1683 (*1 *2 *3) (-12 (-5 *2 (-1285)) (-5 *1 (-1061 *3)) (-4 *3 (-1225))))) 
+(-10 -7 (-15 -1683 ((-1285) |#1|)) (-15 -1683 (|#1| (-327)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3657 (($ |#4|) 25)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-3650 ((|#4| $) 27)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 46) (($ (-592)) NIL) (($ |#1|) NIL) (($ |#4|) 26)) (-4010 (((-790)) 43)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 21 T CONST)) (-4257 (($) 23 T CONST)) (-3255 (((-141) $ $) 40)) (-3306 (($ $) 31) (($ $ $) NIL)) (-3300 (($ $ $) 29)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 36) (($ $ $) 33) (($ |#1| $) 38) (($ $ |#1|) NIL))) 
+(((-1062 |#1| |#2| |#3| |#4| |#5|) (-13 (-194) (-43 |#1|) (-10 -8 (-15 -3657 ($ |#4|)) (-15 -1683 ($ |#4|)) (-15 -3650 (|#4| $)))) (-388) (-815) (-869) (-977 |#1| |#2| |#3|) (-658 |#4|)) (T -1062)) 
+((-3657 (*1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1062 *3 *4 *5 *2 *6)) (-4 *2 (-977 *3 *4 *5)) (-14 *6 (-658 *2)))) (-1683 (*1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1062 *3 *4 *5 *2 *6)) (-4 *2 (-977 *3 *4 *5)) (-14 *6 (-658 *2)))) (-3650 (*1 *2 *1) (-12 (-4 *2 (-977 *3 *4 *5)) (-5 *1 (-1062 *3 *4 *5 *2 *6)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-14 *6 (-658 *2))))) 
+(-13 (-194) (-43 |#1|) (-10 -8 (-15 -3657 ($ |#4|)) (-15 -1683 ($ |#4|)) (-15 -3650 (|#4| $)))) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL)) (-3898 (((-1285) $ (-1191) (-1191)) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3519 (((-141) (-141)) 39)) (-4589 (((-141) (-141)) 38)) (-3932 (((-57) $ (-1191) (-57)) NIL)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 (-57) "failed") (-1191) $) NIL)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-4065 (($ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-3 (-57) "failed") (-1191) $) NIL)) (-4459 (($ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-57) $ (-1191) (-57)) NIL (|has| $ (-6 -4626)))) (-3959 (((-57) $ (-1191)) NIL)) (-4004 (((-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-658 (-57)) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-1191) $) NIL (|has| (-1191) (-869)))) (-4467 (((-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-658 (-57)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (((-141) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119))))) (-1813 (((-1191) $) NIL (|has| (-1191) (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4626))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-2840 (((-658 (-1191)) $) 34)) (-2396 (((-141) (-1191) $) NIL)) (-4137 (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL)) (-2113 (($ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL)) (-3708 (((-658 (-1191)) $) NIL)) (-3780 (((-141) (-1191) $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-1918 (((-57) $) NIL (|has| (-1191) (-869)))) (-4050 (((-3 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) "failed") (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL)) (-1892 (($ $ (-57)) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))))) NIL (-12 (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ $ (-310 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL (-12 (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ $ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) NIL (-12 (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ $ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL (-12 (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ $ (-658 (-57)) (-658 (-57))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-310 (-57))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-658 (-310 (-57)))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119))))) (-4210 (((-658 (-57)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 (((-57) $ (-1191)) 35) (((-57) $ (-1191) (-57)) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (((-790) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119)))) (((-790) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL)) (-1683 (((-877) $) 37 (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1063) (-13 (-1202 (-1191) (-57)) (-10 -7 (-15 -3519 ((-141) (-141))) (-15 -4589 ((-141) (-141))) (-6 -4625)))) (T -1063)) 
+((-3519 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1063)))) (-4589 (*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1063))))) 
+(-13 (-1202 (-1191) (-57)) (-10 -7 (-15 -3519 ((-141) (-141))) (-15 -4589 ((-141) (-141))) (-6 -4625))) 
+((-2400 ((|#2| $) 10))) 
+(((-1064 |#1| |#2|) (-10 -8 (-15 -2400 (|#2| |#1|))) (-1065 |#2|) (-1225)) (T -1064)) 
+NIL 
+(-10 -8 (-15 -2400 (|#2| |#1|))) 
+((-4368 (((-3 |#1| "failed") $) 7)) (-2400 ((|#1| $) 8)) (-1683 (($ |#1|) 6))) 
+(((-1065 |#1|) (-1311) (-1225)) (T -1065)) 
+((-2400 (*1 *2 *1) (-12 (-4 *1 (-1065 *2)) (-4 *2 (-1225)))) (-4368 (*1 *2 *1) (|partial| -12 (-4 *1 (-1065 *2)) (-4 *2 (-1225)))) (-1683 (*1 *1 *2) (-12 (-4 *1 (-1065 *2)) (-4 *2 (-1225))))) 
+(-13 (-10 -8 (-15 -1683 ($ |t#1|)) (-15 -4368 ((-3 |t#1| "failed") $)) (-15 -2400 (|t#1| $)))) 
+((-3521 (((-658 (-658 (-310 (-433 (-980 |#2|))))) (-658 (-980 |#2|)) (-658 (-1191))) 35))) 
+(((-1066 |#1| |#2|) (-10 -7 (-15 -3521 ((-658 (-658 (-310 (-433 (-980 |#2|))))) (-658 (-980 |#2|)) (-658 (-1191))))) (-582) (-13 (-582) (-1065 |#1|))) (T -1066)) 
+((-3521 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *6))) (-5 *4 (-658 (-1191))) (-4 *6 (-13 (-582) (-1065 *5))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *6)))))) (-5 *1 (-1066 *5 *6))))) 
+(-10 -7 (-15 -3521 ((-658 (-658 (-310 (-433 (-980 |#2|))))) (-658 (-980 |#2|)) (-658 (-1191))))) 
+((-2047 (((-405)) 15)) (-3941 (((-1 (-405)) (-405) (-405)) 20)) (-4132 (((-1 (-405)) (-790)) 42)) (-1960 (((-405)) 33)) (-1947 (((-1 (-405)) (-405) (-405)) 34)) (-3384 (((-405)) 26)) (-4331 (((-1 (-405)) (-405)) 27)) (-3530 (((-405) (-790)) 37)) (-1370 (((-1 (-405)) (-790)) 38)) (-3958 (((-1 (-405)) (-790) (-790)) 41)) (-2170 (((-1 (-405)) (-790) (-790)) 39))) 
+(((-1067) (-10 -7 (-15 -2047 ((-405))) (-15 -1960 ((-405))) (-15 -3384 ((-405))) (-15 -3530 ((-405) (-790))) (-15 -3941 ((-1 (-405)) (-405) (-405))) (-15 -1947 ((-1 (-405)) (-405) (-405))) (-15 -4331 ((-1 (-405)) (-405))) (-15 -1370 ((-1 (-405)) (-790))) (-15 -2170 ((-1 (-405)) (-790) (-790))) (-15 -3958 ((-1 (-405)) (-790) (-790))) (-15 -4132 ((-1 (-405)) (-790))))) (T -1067)) 
+((-4132 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-405))) (-5 *1 (-1067)))) (-3958 (*1 *2 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-405))) (-5 *1 (-1067)))) (-2170 (*1 *2 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-405))) (-5 *1 (-1067)))) (-1370 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-405))) (-5 *1 (-1067)))) (-4331 (*1 *2 *3) (-12 (-5 *2 (-1 (-405))) (-5 *1 (-1067)) (-5 *3 (-405)))) (-1947 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-405))) (-5 *1 (-1067)) (-5 *3 (-405)))) (-3941 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-405))) (-5 *1 (-1067)) (-5 *3 (-405)))) (-3530 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-405)) (-5 *1 (-1067)))) (-3384 (*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1067)))) (-1960 (*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1067)))) (-2047 (*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1067))))) 
+(-10 -7 (-15 -2047 ((-405))) (-15 -1960 ((-405))) (-15 -3384 ((-405))) (-15 -3530 ((-405) (-790))) (-15 -3941 ((-1 (-405)) (-405) (-405))) (-15 -1947 ((-1 (-405)) (-405) (-405))) (-15 -4331 ((-1 (-405)) (-405))) (-15 -1370 ((-1 (-405)) (-790))) (-15 -2170 ((-1 (-405)) (-790) (-790))) (-15 -3958 ((-1 (-405)) (-790) (-790))) (-15 -4132 ((-1 (-405)) (-790)))) 
+((-4500 (((-444 |#1|) |#1|) 31))) 
+(((-1068 |#1|) (-10 -7 (-15 -4500 ((-444 |#1|) |#1|))) (-1255 (-433 (-980 (-592))))) (T -1068)) 
+((-4500 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1068 *3)) (-4 *3 (-1255 (-433 (-980 (-592)))))))) 
+(-10 -7 (-15 -4500 ((-444 |#1|) |#1|))) 
+((-1562 (((-433 (-444 (-980 |#1|))) (-433 (-980 |#1|))) 14))) 
+(((-1069 |#1|) (-10 -7 (-15 -1562 ((-433 (-444 (-980 |#1|))) (-433 (-980 |#1|))))) (-323)) (T -1069)) 
+((-1562 (*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-323)) (-5 *2 (-433 (-444 (-980 *4)))) (-5 *1 (-1069 *4))))) 
+(-10 -7 (-15 -1562 ((-433 (-444 (-980 |#1|))) (-433 (-980 |#1|))))) 
+((-4085 (((-658 (-1191)) (-433 (-980 |#1|))) 15)) (-4492 (((-433 (-1187 (-433 (-980 |#1|)))) (-433 (-980 |#1|)) (-1191)) 22)) (-4533 (((-433 (-980 |#1|)) (-433 (-1187 (-433 (-980 |#1|)))) (-1191)) 24)) (-3254 (((-3 (-1191) "failed") (-433 (-980 |#1|))) 18)) (-2806 (((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-658 (-310 (-433 (-980 |#1|))))) 29) (((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|)))) 31) (((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-658 (-1191)) (-658 (-433 (-980 |#1|)))) 26) (((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|))) 27)) (-1683 (((-433 (-980 |#1|)) |#1|) 11))) 
+(((-1070 |#1|) (-10 -7 (-15 -4085 ((-658 (-1191)) (-433 (-980 |#1|)))) (-15 -3254 ((-3 (-1191) "failed") (-433 (-980 |#1|)))) (-15 -4492 ((-433 (-1187 (-433 (-980 |#1|)))) (-433 (-980 |#1|)) (-1191))) (-15 -4533 ((-433 (-980 |#1|)) (-433 (-1187 (-433 (-980 |#1|)))) (-1191))) (-15 -2806 ((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|)))) (-15 -2806 ((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-658 (-1191)) (-658 (-433 (-980 |#1|))))) (-15 -2806 ((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))))) (-15 -2806 ((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-658 (-310 (-433 (-980 |#1|)))))) (-15 -1683 ((-433 (-980 |#1|)) |#1|))) (-582)) (T -1070)) 
+((-1683 (*1 *2 *3) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-1070 *3)) (-4 *3 (-582)))) (-2806 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-310 (-433 (-980 *4))))) (-5 *2 (-433 (-980 *4))) (-4 *4 (-582)) (-5 *1 (-1070 *4)))) (-2806 (*1 *2 *2 *3) (-12 (-5 *3 (-310 (-433 (-980 *4)))) (-5 *2 (-433 (-980 *4))) (-4 *4 (-582)) (-5 *1 (-1070 *4)))) (-2806 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-658 (-1191))) (-5 *4 (-658 (-433 (-980 *5)))) (-5 *2 (-433 (-980 *5))) (-4 *5 (-582)) (-5 *1 (-1070 *5)))) (-2806 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-433 (-980 *4))) (-5 *3 (-1191)) (-4 *4 (-582)) (-5 *1 (-1070 *4)))) (-4533 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-1187 (-433 (-980 *5))))) (-5 *4 (-1191)) (-5 *2 (-433 (-980 *5))) (-5 *1 (-1070 *5)) (-4 *5 (-582)))) (-4492 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-582)) (-5 *2 (-433 (-1187 (-433 (-980 *5))))) (-5 *1 (-1070 *5)) (-5 *3 (-433 (-980 *5))))) (-3254 (*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-5 *2 (-1191)) (-5 *1 (-1070 *4)))) (-4085 (*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-5 *2 (-658 (-1191))) (-5 *1 (-1070 *4))))) 
+(-10 -7 (-15 -4085 ((-658 (-1191)) (-433 (-980 |#1|)))) (-15 -3254 ((-3 (-1191) "failed") (-433 (-980 |#1|)))) (-15 -4492 ((-433 (-1187 (-433 (-980 |#1|)))) (-433 (-980 |#1|)) (-1191))) (-15 -4533 ((-433 (-980 |#1|)) (-433 (-1187 (-433 (-980 |#1|)))) (-1191))) (-15 -2806 ((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|)))) (-15 -2806 ((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-658 (-1191)) (-658 (-433 (-980 |#1|))))) (-15 -2806 ((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-310 (-433 (-980 |#1|))))) (-15 -2806 ((-433 (-980 |#1|)) (-433 (-980 |#1|)) (-658 (-310 (-433 (-980 |#1|)))))) (-15 -1683 ((-433 (-980 |#1|)) |#1|))) 
+((-3421 (((-658 |#1|) (-658 |#1|)) 45)) (-2130 (((-658 |#1|)) 9)) (-4445 (((-2 (|:| |zeros| (-658 |#1|)) (|:| -2378 (-592))) (-1187 |#1|) |#1|) 19)) (-3668 (((-2 (|:| |zeros| (-658 |#1|)) (|:| -2378 (-592))) (-658 (-1187 |#1|)) |#1|) 37))) 
+(((-1071 |#1|) (-10 -7 (-15 -4445 ((-2 (|:| |zeros| (-658 |#1|)) (|:| -2378 (-592))) (-1187 |#1|) |#1|)) (-15 -3668 ((-2 (|:| |zeros| (-658 |#1|)) (|:| -2378 (-592))) (-658 (-1187 |#1|)) |#1|)) (-15 -2130 ((-658 |#1|))) (-15 -3421 ((-658 |#1|) (-658 |#1|)))) (-388)) (T -1071)) 
+((-3421 (*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-5 *1 (-1071 *3)))) (-2130 (*1 *2) (-12 (-5 *2 (-658 *3)) (-5 *1 (-1071 *3)) (-4 *3 (-388)))) (-3668 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1187 *4))) (-4 *4 (-388)) (-5 *2 (-2 (|:| |zeros| (-658 *4)) (|:| -2378 (-592)))) (-5 *1 (-1071 *4)))) (-4445 (*1 *2 *3 *4) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-388)) (-5 *2 (-2 (|:| |zeros| (-658 *4)) (|:| -2378 (-592)))) (-5 *1 (-1071 *4))))) 
+(-10 -7 (-15 -4445 ((-2 (|:| |zeros| (-658 |#1|)) (|:| -2378 (-592))) (-1187 |#1|) |#1|)) (-15 -3668 ((-2 (|:| |zeros| (-658 |#1|)) (|:| -2378 (-592))) (-658 (-1187 |#1|)) |#1|)) (-15 -2130 ((-658 |#1|))) (-15 -3421 ((-658 |#1|) (-658 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 (-802 |#1| (-879 |#2|)))))) (-658 (-802 |#1| (-879 |#2|)))) NIL)) (-2248 (((-658 $) (-658 (-802 |#1| (-879 |#2|)))) NIL) (((-658 $) (-658 (-802 |#1| (-879 |#2|))) (-141)) NIL) (((-658 $) (-658 (-802 |#1| (-879 |#2|))) (-141) (-141)) NIL)) (-4085 (((-658 (-879 |#2|)) $) NIL)) (-4325 (((-141) $) NIL)) (-2988 (((-141) $) NIL (|has| |#1| (-582)))) (-4135 (((-141) (-802 |#1| (-879 |#2|)) $) NIL) (((-141) $) NIL)) (-2244 (((-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) $) NIL)) (-3743 (((-658 (-2 (|:| |val| (-802 |#1| (-879 |#2|))) (|:| -2165 $))) (-802 |#1| (-879 |#2|)) $) NIL)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ (-879 |#2|)) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3113 (($ (-1 (-141) (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-3 (-802 |#1| (-879 |#2|)) "failed") $ (-879 |#2|)) NIL)) (-3001 (($) NIL T CONST)) (-3239 (((-141) $) NIL (|has| |#1| (-582)))) (-3478 (((-141) $ $) NIL (|has| |#1| (-582)))) (-2398 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1529 (((-141) $) NIL (|has| |#1| (-582)))) (-1903 (((-658 (-802 |#1| (-879 |#2|))) (-658 (-802 |#1| (-879 |#2|))) $ (-1 (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) (-1 (-141) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)))) NIL)) (-4521 (((-658 (-802 |#1| (-879 |#2|))) (-658 (-802 |#1| (-879 |#2|))) $) NIL (|has| |#1| (-582)))) (-3718 (((-658 (-802 |#1| (-879 |#2|))) (-658 (-802 |#1| (-879 |#2|))) $) NIL (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 (-802 |#1| (-879 |#2|)))) NIL)) (-2400 (($ (-658 (-802 |#1| (-879 |#2|)))) NIL)) (-1366 (((-3 $ "failed") $) NIL)) (-2226 (((-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-802 |#1| (-879 |#2|)) (-1119))))) (-4459 (($ (-802 |#1| (-879 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-802 |#1| (-879 |#2|)) (-1119)))) (($ (-1 (-141) (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| (-802 |#1| (-879 |#2|))) (|:| |den| |#1|)) (-802 |#1| (-879 |#2|)) $) NIL (|has| |#1| (-582)))) (-2172 (((-141) (-802 |#1| (-879 |#2|)) $ (-1 (-141) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)))) NIL)) (-3092 (((-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) $) NIL)) (-3657 (((-802 |#1| (-879 |#2|)) (-1 (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) $ (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-802 |#1| (-879 |#2|)) (-1119)))) (((-802 |#1| (-879 |#2|)) (-1 (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) $ (-802 |#1| (-879 |#2|))) NIL (|has| $ (-6 -4625))) (((-802 |#1| (-879 |#2|)) (-1 (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) $ (-1 (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) (-1 (-141) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)))) NIL)) (-1643 (((-2 (|:| -3511 (-658 (-802 |#1| (-879 |#2|)))) (|:| -1774 (-658 (-802 |#1| (-879 |#2|))))) $) NIL)) (-1836 (((-141) (-802 |#1| (-879 |#2|)) $) NIL)) (-2659 (((-141) (-802 |#1| (-879 |#2|)) $) NIL)) (-3195 (((-141) (-802 |#1| (-879 |#2|)) $) NIL) (((-141) $) NIL)) (-4004 (((-658 (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2479 (((-141) (-802 |#1| (-879 |#2|)) $) NIL) (((-141) $) NIL)) (-3259 (((-879 |#2|) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-802 |#1| (-879 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-802 |#1| (-879 |#2|)) (-1119))))) (-3987 (($ (-1 (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) $) NIL)) (-2290 (((-658 (-879 |#2|)) $) NIL)) (-2645 (((-141) (-879 |#2|) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-1470 (((-3 (-802 |#1| (-879 |#2|)) (-658 $)) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) $) NIL)) (-3722 (((-658 (-2 (|:| |val| (-802 |#1| (-879 |#2|))) (|:| -2165 $))) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) $) NIL)) (-4255 (((-3 (-802 |#1| (-879 |#2|)) "failed") $) NIL)) (-3501 (((-658 $) (-802 |#1| (-879 |#2|)) $) NIL)) (-3732 (((-3 (-141) (-658 $)) (-802 |#1| (-879 |#2|)) $) NIL)) (-2978 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 $))) (-802 |#1| (-879 |#2|)) $) NIL) (((-141) (-802 |#1| (-879 |#2|)) $) NIL)) (-2852 (((-658 $) (-802 |#1| (-879 |#2|)) $) NIL) (((-658 $) (-658 (-802 |#1| (-879 |#2|))) $) NIL) (((-658 $) (-658 (-802 |#1| (-879 |#2|))) (-658 $)) NIL) (((-658 $) (-802 |#1| (-879 |#2|)) (-658 $)) NIL)) (-3902 (($ (-802 |#1| (-879 |#2|)) $) NIL) (($ (-658 (-802 |#1| (-879 |#2|))) $) NIL)) (-1712 (((-658 (-802 |#1| (-879 |#2|))) $) NIL)) (-2346 (((-141) (-802 |#1| (-879 |#2|)) $) NIL) (((-141) $) NIL)) (-1751 (((-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) $) NIL)) (-3085 (((-141) $ $) NIL)) (-3480 (((-2 (|:| |num| (-802 |#1| (-879 |#2|))) (|:| |den| |#1|)) (-802 |#1| (-879 |#2|)) $) NIL (|has| |#1| (-582)))) (-4442 (((-141) (-802 |#1| (-879 |#2|)) $) NIL) (((-141) $) NIL)) (-1803 (((-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)) $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-3 (-802 |#1| (-879 |#2|)) "failed") $) NIL)) (-4050 (((-3 (-802 |#1| (-879 |#2|)) "failed") (-1 (-141) (-802 |#1| (-879 |#2|))) $) NIL)) (-2778 (((-3 $ "failed") $ (-802 |#1| (-879 |#2|))) NIL)) (-2807 (($ $ (-802 |#1| (-879 |#2|))) NIL) (((-658 $) (-802 |#1| (-879 |#2|)) $) NIL) (((-658 $) (-802 |#1| (-879 |#2|)) (-658 $)) NIL) (((-658 $) (-658 (-802 |#1| (-879 |#2|))) $) NIL) (((-658 $) (-658 (-802 |#1| (-879 |#2|))) (-658 $)) NIL)) (-3002 (((-141) (-1 (-141) (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-802 |#1| (-879 |#2|))) (-658 (-802 |#1| (-879 |#2|)))) NIL (-12 (|has| (-802 |#1| (-879 |#2|)) (-325 (-802 |#1| (-879 |#2|)))) (|has| (-802 |#1| (-879 |#2|)) (-1119)))) (($ $ (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|))) NIL (-12 (|has| (-802 |#1| (-879 |#2|)) (-325 (-802 |#1| (-879 |#2|)))) (|has| (-802 |#1| (-879 |#2|)) (-1119)))) (($ $ (-310 (-802 |#1| (-879 |#2|)))) NIL (-12 (|has| (-802 |#1| (-879 |#2|)) (-325 (-802 |#1| (-879 |#2|)))) (|has| (-802 |#1| (-879 |#2|)) (-1119)))) (($ $ (-658 (-310 (-802 |#1| (-879 |#2|))))) NIL (-12 (|has| (-802 |#1| (-879 |#2|)) (-325 (-802 |#1| (-879 |#2|)))) (|has| (-802 |#1| (-879 |#2|)) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-4525 (((-790) $) NIL)) (-3452 (((-790) (-802 |#1| (-879 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-802 |#1| (-879 |#2|)) (-1119)))) (((-790) (-1 (-141) (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-802 |#1| (-879 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-802 |#1| (-879 |#2|)))) NIL)) (-2613 (($ $ (-879 |#2|)) NIL)) (-4152 (($ $ (-879 |#2|)) NIL)) (-2965 (($ $) NIL)) (-2507 (($ $ (-879 |#2|)) NIL)) (-1683 (((-877) $) NIL) (((-658 (-802 |#1| (-879 |#2|))) $) NIL)) (-1857 (((-790) $) NIL (|has| (-879 |#2|) (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 (-802 |#1| (-879 |#2|))))) "failed") (-658 (-802 |#1| (-879 |#2|))) (-1 (-141) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)))) NIL) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 (-802 |#1| (-879 |#2|))))) "failed") (-658 (-802 |#1| (-879 |#2|))) (-1 (-141) (-802 |#1| (-879 |#2|))) (-1 (-141) (-802 |#1| (-879 |#2|)) (-802 |#1| (-879 |#2|)))) NIL)) (-4408 (((-141) $ (-1 (-141) (-802 |#1| (-879 |#2|)) (-658 (-802 |#1| (-879 |#2|))))) NIL)) (-3032 (((-658 $) (-802 |#1| (-879 |#2|)) $) NIL) (((-658 $) (-802 |#1| (-879 |#2|)) (-658 $)) NIL) (((-658 $) (-658 (-802 |#1| (-879 |#2|))) $) NIL) (((-658 $) (-658 (-802 |#1| (-879 |#2|))) (-658 $)) NIL)) (-3369 (((-141) (-1 (-141) (-802 |#1| (-879 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1596 (((-658 (-879 |#2|)) $) NIL)) (-1437 (((-141) (-802 |#1| (-879 |#2|)) $) NIL)) (-3069 (((-141) (-879 |#2|) $) NIL)) (-3255 (((-141) $ $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1072 |#1| |#2|) (-13 (-1094 |#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|))) (-10 -8 (-15 -2248 ((-658 $) (-658 (-802 |#1| (-879 |#2|))) (-141) (-141))))) (-477) (-658 (-1191))) (T -1072)) 
+((-2248 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-1072 *5 *6))))) 
+(-13 (-1094 |#1| (-558 (-879 |#2|)) (-879 |#2|) (-802 |#1| (-879 |#2|))) (-10 -8 (-15 -2248 ((-658 $) (-658 (-802 |#1| (-879 |#2|))) (-141) (-141))))) 
+((-3941 (((-1 (-592)) (-1113 (-592))) 33)) (-2714 (((-592) (-592) (-592) (-592) (-592)) 30)) (-3922 (((-1 (-592)) |RationalNumber|) NIL)) (-2455 (((-1 (-592)) |RationalNumber|) NIL)) (-4042 (((-1 (-592)) (-592) |RationalNumber|) NIL))) 
+(((-1073) (-10 -7 (-15 -3941 ((-1 (-592)) (-1113 (-592)))) (-15 -4042 ((-1 (-592)) (-592) |RationalNumber|)) (-15 -3922 ((-1 (-592)) |RationalNumber|)) (-15 -2455 ((-1 (-592)) |RationalNumber|)) (-15 -2714 ((-592) (-592) (-592) (-592) (-592))))) (T -1073)) 
+((-2714 (*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1073)))) (-2455 (*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-592))) (-5 *1 (-1073)))) (-3922 (*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-592))) (-5 *1 (-1073)))) (-4042 (*1 *2 *3 *4) (-12 (-5 *4 |RationalNumber|) (-5 *2 (-1 (-592))) (-5 *1 (-1073)) (-5 *3 (-592)))) (-3941 (*1 *2 *3) (-12 (-5 *3 (-1113 (-592))) (-5 *2 (-1 (-592))) (-5 *1 (-1073))))) 
+(-10 -7 (-15 -3941 ((-1 (-592)) (-1113 (-592)))) (-15 -4042 ((-1 (-592)) (-592) |RationalNumber|)) (-15 -3922 ((-1 (-592)) |RationalNumber|)) (-15 -2455 ((-1 (-592)) |RationalNumber|)) (-15 -2714 ((-592) (-592) (-592) (-592) (-592)))) 
+((-1683 (((-877) $) NIL) (($ (-592)) 10))) 
+(((-1074 |#1|) (-10 -8 (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) (-1075)) (T -1074)) 
+NIL 
+(-10 -8 (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-1075) (-1311)) (T -1075)) 
+((-4010 (*1 *2) (-12 (-4 *1 (-1075)) (-5 *2 (-790)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1075))))) 
+(-13 (-1082) (-743) (-661 $) (-10 -8 (-15 -4010 ((-790))) (-15 -1683 ($ (-592))) (-6 -4622))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 $) . T) ((-743) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-3014 (((-433 (-980 |#2|)) (-658 |#2|) (-658 |#2|) (-790) (-790)) 45))) 
+(((-1076 |#1| |#2|) (-10 -7 (-15 -3014 ((-433 (-980 |#2|)) (-658 |#2|) (-658 |#2|) (-790) (-790)))) (-1191) (-388)) (T -1076)) 
+((-3014 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-790)) (-4 *6 (-388)) (-5 *2 (-433 (-980 *6))) (-5 *1 (-1076 *5 *6)) (-14 *5 (-1191))))) 
+(-10 -7 (-15 -3014 ((-433 (-980 |#2|)) (-658 |#2|) (-658 |#2|) (-790) (-790)))) 
+((-4034 (((-141) $) 27)) (-3120 (((-141) $) 16)) (-4292 (((-790) $) 13)) (-4298 (((-790) $) 14)) (-2940 (((-141) $) 25)) (-3951 (((-141) $) 29))) 
+(((-1077 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -8 (-15 -4298 ((-790) |#1|)) (-15 -4292 ((-790) |#1|)) (-15 -3951 ((-141) |#1|)) (-15 -4034 ((-141) |#1|)) (-15 -2940 ((-141) |#1|)) (-15 -3120 ((-141) |#1|))) (-1078 |#2| |#3| |#4| |#5| |#6|) (-790) (-790) (-1075) (-252 |#3| |#4|) (-252 |#2| |#4|)) (T -1077)) 
+NIL 
+(-10 -8 (-15 -4298 ((-790) |#1|)) (-15 -4292 ((-790) |#1|)) (-15 -3951 ((-141) |#1|)) (-15 -4034 ((-141) |#1|)) (-15 -2940 ((-141) |#1|)) (-15 -3120 ((-141) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4034 (((-141) $) 48)) (-2350 (((-3 $ "failed") $ $) 18)) (-3120 (((-141) $) 50)) (-2126 (((-141) $ (-790)) 58)) (-3001 (($) 16 T CONST)) (-3052 (($ $) 31 (|has| |#3| (-323)))) (-2747 ((|#4| $ (-592)) 36)) (-4175 (((-790) $) 30 (|has| |#3| (-582)))) (-3959 ((|#3| $ (-592) (-592)) 38)) (-4004 (((-658 |#3|) $) 65 (|has| $ (-6 -4625)))) (-3178 (((-790) $) 29 (|has| |#3| (-582)))) (-3555 (((-658 |#5|) $) 28 (|has| |#3| (-582)))) (-4292 (((-790) $) 42)) (-4298 (((-790) $) 41)) (-4345 (((-141) $ (-790)) 57)) (-4577 (((-592) $) 46)) (-4280 (((-592) $) 44)) (-4467 (((-658 |#3|) $) 66 (|has| $ (-6 -4625)))) (-3133 (((-141) |#3| $) 68 (-12 (|has| |#3| (-1119)) (|has| $ (-6 -4625))))) (-1898 (((-592) $) 45)) (-3005 (((-592) $) 43)) (-4186 (($ (-658 (-658 |#3|))) 51)) (-3987 (($ (-1 |#3| |#3|) $) 61 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#3| |#3|) $) 60) (($ (-1 |#3| |#3| |#3|) $ $) 34)) (-4601 (((-658 (-658 |#3|)) $) 40)) (-2554 (((-141) $ (-790)) 56)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ |#3|) 33 (|has| |#3| (-582)))) (-3002 (((-141) (-1 (-141) |#3|) $) 63 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#3|) (-658 |#3|)) 72 (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ |#3| |#3|) 71 (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ (-310 |#3|)) 70 (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ (-658 (-310 |#3|))) 69 (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119))))) (-1724 (((-141) $ $) 52)) (-2943 (((-141) $) 55)) (-2890 (($) 54)) (-3927 ((|#3| $ (-592) (-592)) 39) ((|#3| $ (-592) (-592) |#3|) 37)) (-2940 (((-141) $) 49)) (-3452 (((-790) |#3| $) 67 (-12 (|has| |#3| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#3|) $) 64 (|has| $ (-6 -4625)))) (-4599 (($ $) 53)) (-2000 ((|#5| $ (-592)) 35)) (-1683 (((-877) $) 11)) (-3369 (((-141) (-1 (-141) |#3|) $) 62 (|has| $ (-6 -4625)))) (-3951 (((-141) $) 47)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#3|) 32 (|has| |#3| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ |#3| $) 22) (($ $ |#3|) 24)) (-1699 (((-790) $) 59 (|has| $ (-6 -4625))))) 
+(((-1078 |#1| |#2| |#3| |#4| |#5|) (-1311) (-790) (-790) (-1075) (-252 |t#2| |t#3|) (-252 |t#1| |t#3|)) (T -1078)) 
+((-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *5 *5)) (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)))) (-4186 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 *5))) (-4 *5 (-1075)) (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)))) (-3120 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-141)))) (-2940 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-141)))) (-4034 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-141)))) (-3951 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-141)))) (-4577 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-592)))) (-1898 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-592)))) (-4280 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-592)))) (-3005 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-592)))) (-4292 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-790)))) (-4298 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-790)))) (-4601 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-658 (-658 *5))))) (-3927 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *2 *6 *7)) (-4 *6 (-252 *5 *2)) (-4 *7 (-252 *4 *2)) (-4 *2 (-1075)))) (-3959 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *2 *6 *7)) (-4 *6 (-252 *5 *2)) (-4 *7 (-252 *4 *2)) (-4 *2 (-1075)))) (-3927 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *2 *6 *7)) (-4 *2 (-1075)) (-4 *6 (-252 *5 *2)) (-4 *7 (-252 *4 *2)))) (-2747 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *6 *2 *7)) (-4 *6 (-1075)) (-4 *7 (-252 *4 *6)) (-4 *2 (-252 *5 *6)))) (-2000 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *6 *7 *2)) (-4 *6 (-1075)) (-4 *7 (-252 *5 *6)) (-4 *2 (-252 *4 *6)))) (-2731 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *5 *5 *5)) (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)))) (-3616 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1078 *3 *4 *2 *5 *6)) (-4 *2 (-1075)) (-4 *5 (-252 *4 *2)) (-4 *6 (-252 *3 *2)) (-4 *2 (-582)))) (-3313 (*1 *1 *1 *2) (-12 (-4 *1 (-1078 *3 *4 *2 *5 *6)) (-4 *2 (-1075)) (-4 *5 (-252 *4 *2)) (-4 *6 (-252 *3 *2)) (-4 *2 (-388)))) (-3052 (*1 *1 *1) (-12 (-4 *1 (-1078 *2 *3 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-252 *3 *4)) (-4 *6 (-252 *2 *4)) (-4 *4 (-323)))) (-4175 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-4 *5 (-582)) (-5 *2 (-790)))) (-3178 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-4 *5 (-582)) (-5 *2 (-790)))) (-3555 (*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-4 *5 (-582)) (-5 *2 (-658 *7))))) 
+(-13 (-140 |t#3| |t#3|) (-523 |t#3|) (-10 -8 (-6 -4625) (IF (|has| |t#3| (-194)) (-6 (-734 |t#3|)) |noBranch|) (-15 -4186 ($ (-658 (-658 |t#3|)))) (-15 -3120 ((-141) $)) (-15 -2940 ((-141) $)) (-15 -4034 ((-141) $)) (-15 -3951 ((-141) $)) (-15 -4577 ((-592) $)) (-15 -1898 ((-592) $)) (-15 -4280 ((-592) $)) (-15 -3005 ((-592) $)) (-15 -4292 ((-790) $)) (-15 -4298 ((-790) $)) (-15 -4601 ((-658 (-658 |t#3|)) $)) (-15 -3927 (|t#3| $ (-592) (-592))) (-15 -3959 (|t#3| $ (-592) (-592))) (-15 -3927 (|t#3| $ (-592) (-592) |t#3|)) (-15 -2747 (|t#4| $ (-592))) (-15 -2000 (|t#5| $ (-592))) (-15 -2731 ($ (-1 |t#3| |t#3|) $)) (-15 -2731 ($ (-1 |t#3| |t#3| |t#3|) $ $)) (IF (|has| |t#3| (-582)) (-15 -3616 ((-3 $ "failed") $ |t#3|)) |noBranch|) (IF (|has| |t#3| (-388)) (-15 -3313 ($ $ |t#3|)) |noBranch|) (IF (|has| |t#3| (-323)) (-15 -3052 ($ $)) |noBranch|) (IF (|has| |t#3| (-582)) (PROGN (-15 -4175 ((-790) $)) (-15 -3178 ((-790) $)) (-15 -3555 ((-658 |t#5|) $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-39) . T) ((-125) . T) ((-140 |#3| |#3|) . T) ((-158) . T) ((-632 (-877)) . T) ((-325 |#3|) -12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119))) ((-523 |#3|) . T) ((-547 |#3| |#3|) -12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119))) ((-661 |#3|) . T) ((-734 |#3|) |has| |#3| (-194)) ((-1081 |#3|) . T) ((-1119) . T) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4034 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) 40 (|has| |#3| (-323)))) (-2747 (((-254 |#2| |#3|) $ (-592)) 29)) (-1326 (($ (-706 |#3|)) 38)) (-4175 (((-790) $) 42 (|has| |#3| (-582)))) (-3959 ((|#3| $ (-592) (-592)) NIL)) (-4004 (((-658 |#3|) $) NIL (|has| $ (-6 -4625)))) (-3178 (((-790) $) 44 (|has| |#3| (-582)))) (-3555 (((-658 (-254 |#1| |#3|)) $) 48 (|has| |#3| (-582)))) (-4292 (((-790) $) NIL)) (-4298 (((-790) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-4577 (((-592) $) NIL)) (-4280 (((-592) $) NIL)) (-4467 (((-658 |#3|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#3| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#3| (-1119))))) (-1898 (((-592) $) NIL)) (-3005 (((-592) $) NIL)) (-4186 (($ (-658 (-658 |#3|))) 24)) (-3987 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#3| |#3|) $) NIL) (($ (-1 |#3| |#3| |#3|) $ $) NIL)) (-4601 (((-658 (-658 |#3|)) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ |#3|) NIL (|has| |#3| (-582)))) (-3002 (((-141) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#3|) (-658 |#3|)) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ (-310 |#3|)) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ (-658 (-310 |#3|))) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#3| $ (-592) (-592)) NIL) ((|#3| $ (-592) (-592) |#3|) NIL)) (-1936 (((-160)) 51 (|has| |#3| (-388)))) (-2940 (((-141) $) NIL)) (-3452 (((-790) |#3| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#3| (-1119)))) (((-790) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) 60 (|has| |#3| (-633 (-565))))) (-2000 (((-254 |#1| |#3|) $ (-592)) 33)) (-1683 (((-877) $) 16) (((-706 |#3|) $) 35)) (-3369 (((-141) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3514 (($) 13 T CONST)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#3|) NIL (|has| |#3| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ |#3| $) NIL) (($ $ |#3|) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1079 |#1| |#2| |#3|) (-13 (-1078 |#1| |#2| |#3| (-254 |#2| |#3|) (-254 |#1| |#3|)) (-632 (-706 |#3|)) (-10 -8 (IF (|has| |#3| (-388)) (-6 (-1287 |#3|)) |noBranch|) (IF (|has| |#3| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (-15 -1326 ($ (-706 |#3|))) (-15 -1683 ((-706 |#3|) $)))) (-790) (-790) (-1075)) (T -1079)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-706 *5)) (-5 *1 (-1079 *3 *4 *5)) (-14 *3 (-790)) (-14 *4 (-790)) (-4 *5 (-1075)))) (-1326 (*1 *1 *2) (-12 (-5 *2 (-706 *5)) (-4 *5 (-1075)) (-5 *1 (-1079 *3 *4 *5)) (-14 *3 (-790)) (-14 *4 (-790))))) 
+(-13 (-1078 |#1| |#2| |#3| (-254 |#2| |#3|) (-254 |#1| |#3|)) (-632 (-706 |#3|)) (-10 -8 (IF (|has| |#3| (-388)) (-6 (-1287 |#3|)) |noBranch|) (IF (|has| |#3| (-633 (-565))) (-6 (-633 (-565))) |noBranch|) (-15 -1326 ($ (-706 |#3|))) (-15 -1683 ((-706 |#3|) $)))) 
+((-3657 ((|#7| (-1 |#7| |#3| |#7|) |#6| |#7|) 34)) (-2731 ((|#10| (-1 |#7| |#3|) |#6|) 32))) 
+(((-1080 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10|) (-10 -7 (-15 -2731 (|#10| (-1 |#7| |#3|) |#6|)) (-15 -3657 (|#7| (-1 |#7| |#3| |#7|) |#6| |#7|))) (-790) (-790) (-1075) (-252 |#2| |#3|) (-252 |#1| |#3|) (-1078 |#1| |#2| |#3| |#4| |#5|) (-1075) (-252 |#2| |#7|) (-252 |#1| |#7|) (-1078 |#1| |#2| |#7| |#8| |#9|)) (T -1080)) 
+((-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *7 *2)) (-4 *7 (-1075)) (-4 *2 (-1075)) (-14 *5 (-790)) (-14 *6 (-790)) (-4 *8 (-252 *6 *7)) (-4 *9 (-252 *5 *7)) (-4 *10 (-252 *6 *2)) (-4 *11 (-252 *5 *2)) (-5 *1 (-1080 *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (-4 *4 (-1078 *5 *6 *7 *8 *9)) (-4 *12 (-1078 *5 *6 *2 *10 *11)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *10 *7)) (-4 *7 (-1075)) (-4 *10 (-1075)) (-14 *5 (-790)) (-14 *6 (-790)) (-4 *8 (-252 *6 *7)) (-4 *9 (-252 *5 *7)) (-4 *2 (-1078 *5 *6 *10 *11 *12)) (-5 *1 (-1080 *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (-4 *4 (-1078 *5 *6 *7 *8 *9)) (-4 *11 (-252 *6 *10)) (-4 *12 (-252 *5 *10))))) 
+(-10 -7 (-15 -2731 (|#10| (-1 |#7| |#3|) |#6|)) (-15 -3657 (|#7| (-1 |#7| |#3| |#7|) |#6| |#7|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ |#1|) 22))) 
+(((-1081 |#1|) (-1311) (-1082)) (T -1081)) 
+((* (*1 *1 *1 *2) (-12 (-4 *1 (-1081 *2)) (-4 *2 (-1082))))) 
 (-13 (-21) (-10 -8 (-15 * ($ $ |t#1|)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-4174 (($ $ (-923)) 25)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-1061) (-1290)) (T -1061)) 
-NIL 
-(-13 (-21) (-1110)) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-138) . T) ((-612 (-856)) . T) ((-1110) . T) ((-1098) . T)) 
-((-2525 (($ $) 16)) (-3599 (($ $) 22)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 49)) (-4429 (($ $) 24)) (-3346 (($ $) 11)) (-1716 (($ $) 38)) (-4081 (((-385) $) NIL) (((-217) $) NIL) (((-893 (-385)) $) 33)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL) (($ (-413 (-572))) 28) (($ (-572)) NIL) (($ (-413 (-572))) 28)) (-2140 (((-769)) 8)) (-2634 (($ $) 39))) 
-(((-1062 |#1|) (-10 -8 (-15 -3599 (|#1| |#1|)) (-15 -2525 (|#1| |#1|)) (-15 -3346 (|#1| |#1|)) (-15 -1716 (|#1| |#1|)) (-15 -2634 (|#1| |#1|)) (-15 -4429 (|#1| |#1|)) (-15 -3103 ((-890 (-385) |#1|) |#1| (-893 (-385)) (-890 (-385) |#1|))) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| (-572))) (-15 -4081 ((-217) |#1|)) (-15 -4081 ((-385) |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| |#1|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 -3972 ((-856) |#1|))) (-1063)) (T -1062)) 
-((-2140 (*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1062 *3)) (-4 *3 (-1063))))) 
-(-10 -8 (-15 -3599 (|#1| |#1|)) (-15 -2525 (|#1| |#1|)) (-15 -3346 (|#1| |#1|)) (-15 -1716 (|#1| |#1|)) (-15 -2634 (|#1| |#1|)) (-15 -4429 (|#1| |#1|)) (-15 -3103 ((-890 (-385) |#1|) |#1| (-893 (-385)) (-890 (-385) |#1|))) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| (-572))) (-15 -4081 ((-217) |#1|)) (-15 -4081 ((-385) |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| |#1|)) (-15 -3972 (|#1| (-572))) (-15 -2140 ((-769))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2551 (((-572) $) 85)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-2525 (($ $) 83)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-4190 (($ $) 93)) (-3112 (((-121) $ $) 57)) (-2433 (((-572) $) 110)) (-2211 (($) 16 T CONST)) (-3599 (($ $) 82)) (-3376 (((-3 (-572) "failed") $) 98) (((-3 (-413 (-572)) "failed") $) 95)) (-1318 (((-572) $) 97) (((-413 (-572)) $) 94)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-1526 (((-121) $) 69)) (-1908 (((-121) $) 108)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 89)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 92)) (-4429 (($ $) 88)) (-4472 (((-121) $) 109)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-1771 (($ $ $) 107)) (-4238 (($ $ $) 106)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-3346 (($ $) 84)) (-1716 (($ $) 86)) (-4304 (((-424 $) $) 72)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-4081 (((-385) $) 101) (((-217) $) 100) (((-893 (-385)) $) 90)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ (-572)) 99) (($ (-413 (-572))) 96)) (-2140 (((-769)) 28)) (-2634 (($ $) 87)) (-3774 (((-121) $ $) 38)) (-2264 (($ $) 111)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1349 (((-121) $ $) 104)) (-1338 (((-121) $ $) 103)) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 105)) (-1334 (((-121) $ $) 102)) (-1379 (($ $ $) 62)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66) (($ $ (-413 (-572))) 91)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64))) 
-(((-1063) (-1290)) (T -1063)) 
-((-2264 (*1 *1 *1) (-4 *1 (-1063))) (-4429 (*1 *1 *1) (-4 *1 (-1063))) (-2634 (*1 *1 *1) (-4 *1 (-1063))) (-1716 (*1 *1 *1) (-4 *1 (-1063))) (-2551 (*1 *2 *1) (-12 (-4 *1 (-1063)) (-5 *2 (-572)))) (-3346 (*1 *1 *1) (-4 *1 (-1063))) (-2525 (*1 *1 *1) (-4 *1 (-1063))) (-3599 (*1 *1 *1) (-4 *1 (-1063)))) 
-(-13 (-368) (-846) (-1028) (-1044 (-572)) (-1044 (-413 (-572))) (-1009) (-613 (-893 (-385))) (-887 (-385)) (-151) (-10 -8 (-15 -4429 ($ $)) (-15 -2634 ($ $)) (-15 -1716 ($ $)) (-15 -2551 ((-572) $)) (-15 -3346 ($ $)) (-15 -2525 ($ $)) (-15 -3599 ($ $)) (-15 -2264 ($ $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 $ $) . T) ((-138) . T) ((-151) . T) ((-612 (-856)) . T) ((-174) . T) ((-613 (-217)) . T) ((-613 (-385)) . T) ((-613 (-893 (-385))) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 $) . T) ((-722) . T) ((-792) . T) ((-793) . T) ((-795) . T) ((-796) . T) ((-846) . T) ((-848) . T) ((-887 (-385)) . T) ((-922) . T) ((-1009) . T) ((-1028) . T) ((-1044 (-413 (-572))) . T) ((-1044 (-572)) . T) ((-1060 (-413 (-572))) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) |#2| $) 23)) (-1685 ((|#1| $) 10)) (-2433 (((-572) |#2| $) 88)) (-3733 (((-3 $ "failed") |#2| (-923)) 58)) (-1862 ((|#1| $) 28)) (-3089 ((|#1| |#2| $ |#1|) 37)) (-2436 (($ $) 25)) (-1799 (((-3 |#2| "failed") |#2| $) 87)) (-1908 (((-121) |#2| $) NIL)) (-4472 (((-121) |#2| $) NIL)) (-2843 (((-121) |#2| $) 24)) (-1365 ((|#1| $) 89)) (-1866 ((|#1| $) 27)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2830 ((|#2| $) 79)) (-3972 (((-856) $) 71)) (-3410 ((|#1| |#2| $ |#1|) 38)) (-4010 (((-638 $) |#2|) 60)) (-1324 (((-121) $ $) 74))) 
-(((-1064 |#1| |#2|) (-13 (-1070 |#1| |#2|) (-10 -8 (-15 -1866 (|#1| $)) (-15 -1862 (|#1| $)) (-15 -1685 (|#1| $)) (-15 -1365 (|#1| $)) (-15 -2436 ($ $)) (-15 -2843 ((-121) |#2| $)) (-15 -3089 (|#1| |#2| $ |#1|)))) (-13 (-846) (-368)) (-1234 |#1|)) (T -1064)) 
-((-3089 (*1 *2 *3 *1 *2) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2)))) (-1866 (*1 *2 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2)))) (-1862 (*1 *2 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2)))) (-1685 (*1 *2 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2)))) (-1365 (*1 *2 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2)))) (-2436 (*1 *1 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2)))) (-2843 (*1 *2 *3 *1) (-12 (-4 *4 (-13 (-846) (-368))) (-5 *2 (-121)) (-5 *1 (-1064 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-13 (-1070 |#1| |#2|) (-10 -8 (-15 -1866 (|#1| $)) (-15 -1862 (|#1| $)) (-15 -1685 (|#1| $)) (-15 -1365 (|#1| $)) (-15 -2436 ($ $)) (-15 -2843 ((-121) |#2| $)) (-15 -3089 (|#1| |#2| $ |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1481 (($ $ $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2934 (($ $ $ $) NIL)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL)) (-3351 (($ $ $) NIL)) (-2211 (($) NIL T CONST)) (-2385 (($ (-1170)) 10) (($ (-572)) 7)) (-3376 (((-3 (-572) "failed") $) NIL)) (-1318 (((-572) $) NIL)) (-2190 (($ $ $) NIL)) (-2284 (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-685 (-572)) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2956 (((-3 (-413 (-572)) "failed") $) NIL)) (-3175 (((-121) $) NIL)) (-4299 (((-413 (-572)) $) NIL)) (-3286 (($) NIL) (($ $) NIL)) (-2208 (($ $ $) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1968 (($ $ $ $) NIL)) (-4489 (($ $ $) NIL)) (-1908 (((-121) $) NIL)) (-2133 (($ $ $) NIL)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL)) (-3893 (((-121) $) NIL)) (-4240 (((-121) $) NIL)) (-3961 (((-3 $ "failed") $) NIL)) (-4472 (((-121) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1628 (($ $ $ $) NIL)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1582 (($ $) NIL)) (-3200 (($ $) NIL)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-2144 (($ $ $) NIL)) (-1773 (($) NIL T CONST)) (-3088 (($ $) NIL)) (-2607 (((-1116) $) NIL) (($ $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) NIL) (($ (-638 $)) NIL)) (-2900 (($ $) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4247 (((-121) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-3139 (($ $ (-769)) NIL) (($ $) NIL)) (-4340 (($ $) NIL)) (-1607 (($ $) NIL)) (-4081 (((-572) $) 16) (((-545) $) NIL) (((-893 (-572)) $) NIL) (((-385) $) NIL) (((-217) $) NIL) (($ (-1170)) 9)) (-3972 (((-856) $) 20) (($ (-572)) 6) (($ $) NIL) (($ (-572)) 6)) (-2140 (((-769)) NIL)) (-1348 (((-121) $ $) NIL)) (-3610 (($ $ $) NIL)) (-4393 (($) NIL)) (-3774 (((-121) $ $) NIL)) (-1498 (($ $ $ $) NIL)) (-2264 (($ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) NIL)) (-1373 (($ $) 19) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL))) 
-(((-1065) (-13 (-554) (-10 -8 (-6 -4589) (-6 -4594) (-6 -4590) (-15 -4081 ($ (-1170))) (-15 -2385 ($ (-1170))) (-15 -2385 ($ (-572)))))) (T -1065)) 
-((-4081 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1065)))) (-2385 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1065)))) (-2385 (*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1065))))) 
-(-13 (-554) (-10 -8 (-6 -4589) (-6 -4594) (-6 -4590) (-15 -4081 ($ (-1170))) (-15 -2385 ($ (-1170))) (-15 -2385 ($ (-572))))) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL)) (-2430 (((-1264) $ (-1170) (-1170)) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3778 (($) 9)) (-3283 (((-57) $ (-1170) (-57)) NIL)) (-2608 (($ $) 23)) (-4187 (($ $) 21)) (-4089 (($ $) 20)) (-3626 (($ $) 22)) (-1608 (($ $) 25)) (-1768 (($ $) 26)) (-3320 (($ $) 19)) (-3922 (($ $) 24)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) 18 (|has| $ (-6 -4602)))) (-1750 (((-3 (-57) "failed") (-1170) $) 34)) (-2211 (($) NIL T CONST)) (-4276 (($) 7)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-1544 (($ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) 46 (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-3 (-57) "failed") (-1170) $) NIL)) (-3445 (($ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602)))) (-2919 (((-3 (-1152) "failed") $ (-1152) (-572)) 59)) (-3037 (((-57) $ (-1170) (-57)) NIL (|has| $ (-6 -4603)))) (-4212 (((-57) $ (-1170)) NIL)) (-2010 (((-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-638 (-57)) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-1170) $) NIL (|has| (-1170) (-848)))) (-4467 (((-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) 28 (|has| $ (-6 -4602))) (((-638 (-57)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098))))) (-2026 (((-1170) $) NIL (|has| (-1170) (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4603))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-2760 (((-638 (-1170)) $) NIL)) (-2365 (((-121) (-1170) $) NIL)) (-4221 (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL)) (-1335 (($ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) 37)) (-2739 (((-638 (-1170)) $) NIL)) (-1601 (((-121) (-1170) $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-3866 (((-385) $ (-1170)) 45)) (-4023 (((-638 (-1152)) $ (-1152)) 60)) (-1837 (((-57) $) NIL (|has| (-1170) (-848)))) (-3361 (((-3 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) "failed") (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL)) (-3299 (($ $ (-57)) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))))) NIL (-12 (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ $ (-290 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL (-12 (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ $ (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) NIL (-12 (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ $ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL (-12 (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-305 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (($ $ (-638 (-57)) (-638 (-57))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-290 (-57))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098)))) (($ $ (-638 (-290 (-57)))) NIL (-12 (|has| (-57) (-305 (-57))) (|has| (-57) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098))))) (-2957 (((-638 (-57)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 (((-57) $ (-1170)) NIL) (((-57) $ (-1170) (-57)) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL)) (-1308 (($ $ (-1170)) 47)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098)))) (((-769) (-57) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-57) (-1098)))) (((-769) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) 30)) (-4500 (($ $ $) 31)) (-3972 (((-856) $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-2916 (($ $ (-1170) (-385)) 43)) (-2512 (($ $ (-1170) (-385)) 44)) (-3058 (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 (-1170)) (|:| -4320 (-57)))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-57) (-1098)) (|has| (-2 (|:| -4111 (-1170)) (|:| -4320 (-57))) (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1066) (-13 (-1181 (-1170) (-57)) (-10 -8 (-15 -4500 ($ $ $)) (-15 -4276 ($)) (-15 -3320 ($ $)) (-15 -4089 ($ $)) (-15 -4187 ($ $)) (-15 -3626 ($ $)) (-15 -3922 ($ $)) (-15 -2608 ($ $)) (-15 -1608 ($ $)) (-15 -1768 ($ $)) (-15 -2916 ($ $ (-1170) (-385))) (-15 -2512 ($ $ (-1170) (-385))) (-15 -3866 ((-385) $ (-1170))) (-15 -4023 ((-638 (-1152)) $ (-1152))) (-15 -1308 ($ $ (-1170))) (-15 -3778 ($)) (-15 -2919 ((-3 (-1152) "failed") $ (-1152) (-572))) (-6 -4602)))) (T -1066)) 
-((-4500 (*1 *1 *1 *1) (-5 *1 (-1066))) (-4276 (*1 *1) (-5 *1 (-1066))) (-3320 (*1 *1 *1) (-5 *1 (-1066))) (-4089 (*1 *1 *1) (-5 *1 (-1066))) (-4187 (*1 *1 *1) (-5 *1 (-1066))) (-3626 (*1 *1 *1) (-5 *1 (-1066))) (-3922 (*1 *1 *1) (-5 *1 (-1066))) (-2608 (*1 *1 *1) (-5 *1 (-1066))) (-1608 (*1 *1 *1) (-5 *1 (-1066))) (-1768 (*1 *1 *1) (-5 *1 (-1066))) (-2916 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-385)) (-5 *1 (-1066)))) (-2512 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-385)) (-5 *1 (-1066)))) (-3866 (*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-385)) (-5 *1 (-1066)))) (-4023 (*1 *2 *1 *3) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1066)) (-5 *3 (-1152)))) (-1308 (*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1066)))) (-3778 (*1 *1) (-5 *1 (-1066))) (-2919 (*1 *2 *1 *2 *3) (|partial| -12 (-5 *2 (-1152)) (-5 *3 (-572)) (-5 *1 (-1066))))) 
-(-13 (-1181 (-1170) (-57)) (-10 -8 (-15 -4500 ($ $ $)) (-15 -4276 ($)) (-15 -3320 ($ $)) (-15 -4089 ($ $)) (-15 -4187 ($ $)) (-15 -3626 ($ $)) (-15 -3922 ($ $)) (-15 -2608 ($ $)) (-15 -1608 ($ $)) (-15 -1768 ($ $)) (-15 -2916 ($ $ (-1170) (-385))) (-15 -2512 ($ $ (-1170) (-385))) (-15 -3866 ((-385) $ (-1170))) (-15 -4023 ((-638 (-1152)) $ (-1152))) (-15 -1308 ($ $ (-1170))) (-15 -3778 ($)) (-15 -2919 ((-3 (-1152) "failed") $ (-1152) (-572))) (-6 -4602))) 
-((-4232 (($ $) 45)) (-4437 (((-121) $ $) 74)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 (-572) "failed") $) NIL) (((-3 |#4| "failed") $) NIL) (((-3 $ "failed") (-959 (-413 (-572)))) 226) (((-3 $ "failed") (-959 (-572))) 225) (((-3 $ "failed") (-959 |#2|)) 228)) (-1318 ((|#2| $) NIL) (((-413 (-572)) $) NIL) (((-572) $) NIL) ((|#4| $) NIL) (($ (-959 (-413 (-572)))) 214) (($ (-959 (-572))) 210) (($ (-959 |#2|)) 230)) (-4383 (($ $) NIL) (($ $ |#4|) 43)) (-2240 (((-121) $ $) 111) (((-121) $ (-638 $)) 112)) (-1439 (((-121) $) 56)) (-1449 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 106)) (-3181 (($ $) 137)) (-4188 (($ $) 133)) (-3119 (($ $) 132)) (-1633 (($ $ $) 79) (($ $ $ |#4|) 84)) (-1851 (($ $ $) 82) (($ $ $ |#4|) 86)) (-3824 (((-121) $ $) 120) (((-121) $ (-638 $)) 121)) (-1792 ((|#4| $) 33)) (-3853 (($ $ $) 109)) (-3897 (((-121) $) 55)) (-3924 (((-769) $) 35)) (-3246 (($ $) 151)) (-3031 (($ $) 148)) (-3737 (((-638 $) $) 68)) (-4312 (($ $) 57)) (-2944 (($ $) 144)) (-1936 (((-638 $) $) 65)) (-4194 (($ $) 59)) (-4373 ((|#2| $) NIL) (($ $ |#4|) 38)) (-2767 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -1951 (-769))) $ $) 110)) (-2241 (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $) 107) (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $ |#4|) 108)) (-3827 (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -2492 $)) $ $) 103) (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -2492 $)) $ $ |#4|) 104)) (-1901 (($ $ $) 89) (($ $ $ |#4|) 94)) (-3720 (($ $ $) 90) (($ $ $ |#4|) 95)) (-4176 (((-638 $) $) 51)) (-1483 (((-121) $ $) 117) (((-121) $ (-638 $)) 118)) (-2788 (($ $ $) 102)) (-1773 (($ $) 37)) (-1843 (((-121) $ $) 72)) (-1994 (((-121) $ $) 113) (((-121) $ (-638 $)) 115)) (-4498 (($ $ $) 100)) (-2826 (($ $) 40)) (-3069 ((|#2| |#2| $) 141) (($ (-638 $)) NIL) (($ $ $) NIL)) (-3916 (($ $ |#2|) NIL) (($ $ $) 130)) (-1467 (($ $ |#2|) 125) (($ $ $) 128)) (-4426 (($ $) 48)) (-3065 (($ $) 52)) (-4081 (((-893 (-385)) $) NIL) (((-893 (-572)) $) NIL) (((-545) $) NIL) (($ (-959 (-413 (-572)))) 216) (($ (-959 (-572))) 212) (($ (-959 |#2|)) 227) (((-1152) $) 249) (((-959 |#2|) $) 161)) (-3972 (((-856) $) 30) (($ (-572)) NIL) (($ |#2|) NIL) (($ |#4|) NIL) (((-959 |#2|) $) 162) (($ (-413 (-572))) NIL) (($ $) NIL)) (-1926 (((-3 (-121) "failed") $ $) 71))) 
-(((-1067 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3972 (|#1| |#1|)) (-15 -3069 (|#1| |#1| |#1|)) (-15 -3069 (|#1| (-638 |#1|))) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 ((-959 |#2|) |#1|)) (-15 -4081 ((-959 |#2|) |#1|)) (-15 -4081 ((-1152) |#1|)) (-15 -3246 (|#1| |#1|)) (-15 -3031 (|#1| |#1|)) (-15 -2944 (|#1| |#1|)) (-15 -3181 (|#1| |#1|)) (-15 -3069 (|#2| |#2| |#1|)) (-15 -3916 (|#1| |#1| |#1|)) (-15 -1467 (|#1| |#1| |#1|)) (-15 -3916 (|#1| |#1| |#2|)) (-15 -1467 (|#1| |#1| |#2|)) (-15 -4188 (|#1| |#1|)) (-15 -3119 (|#1| |#1|)) (-15 -4081 (|#1| (-959 |#2|))) (-15 -1318 (|#1| (-959 |#2|))) (-15 -3376 ((-3 |#1| "failed") (-959 |#2|))) (-15 -4081 (|#1| (-959 (-572)))) (-15 -1318 (|#1| (-959 (-572)))) (-15 -3376 ((-3 |#1| "failed") (-959 (-572)))) (-15 -4081 (|#1| (-959 (-413 (-572))))) (-15 -1318 (|#1| (-959 (-413 (-572))))) (-15 -3376 ((-3 |#1| "failed") (-959 (-413 (-572))))) (-15 -2788 (|#1| |#1| |#1|)) (-15 -4498 (|#1| |#1| |#1|)) (-15 -2767 ((-2 (|:| |polnum| |#1|) (|:| |polden| |#1|) (|:| -1951 (-769))) |#1| |#1|)) (-15 -3853 (|#1| |#1| |#1|)) (-15 -1449 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -2241 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1| |#4|)) (-15 -2241 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -3827 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -2492 |#1|)) |#1| |#1| |#4|)) (-15 -3827 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -3720 (|#1| |#1| |#1| |#4|)) (-15 -1901 (|#1| |#1| |#1| |#4|)) (-15 -3720 (|#1| |#1| |#1|)) (-15 -1901 (|#1| |#1| |#1|)) (-15 -1851 (|#1| |#1| |#1| |#4|)) (-15 -1633 (|#1| |#1| |#1| |#4|)) (-15 -1851 (|#1| |#1| |#1|)) (-15 -1633 (|#1| |#1| |#1|)) (-15 -3824 ((-121) |#1| (-638 |#1|))) (-15 -3824 ((-121) |#1| |#1|)) (-15 -1483 ((-121) |#1| (-638 |#1|))) (-15 -1483 ((-121) |#1| |#1|)) (-15 -1994 ((-121) |#1| (-638 |#1|))) (-15 -1994 ((-121) |#1| |#1|)) (-15 -2240 ((-121) |#1| (-638 |#1|))) (-15 -2240 ((-121) |#1| |#1|)) (-15 -4437 ((-121) |#1| |#1|)) (-15 -1843 ((-121) |#1| |#1|)) (-15 -1926 ((-3 (-121) "failed") |#1| |#1|)) (-15 -3737 ((-638 |#1|) |#1|)) (-15 -1936 ((-638 |#1|) |#1|)) (-15 -4194 (|#1| |#1|)) (-15 -4312 (|#1| |#1|)) (-15 -1439 ((-121) |#1|)) (-15 -3897 ((-121) |#1|)) (-15 -4383 (|#1| |#1| |#4|)) (-15 -4373 (|#1| |#1| |#4|)) (-15 -3065 (|#1| |#1|)) (-15 -4176 ((-638 |#1|) |#1|)) (-15 -4426 (|#1| |#1|)) (-15 -4232 (|#1| |#1|)) (-15 -2826 (|#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 -3924 ((-769) |#1|)) (-15 -1792 (|#4| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -1318 (|#4| |#1|)) (-15 -3376 ((-3 |#4| "failed") |#1|)) (-15 -3972 (|#1| |#4|)) (-15 -4373 (|#2| |#1|)) (-15 -4383 (|#1| |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) (-1068 |#2| |#3| |#4|) (-1054) (-794) (-848)) (T -1067)) 
-NIL 
-(-10 -8 (-15 -3972 (|#1| |#1|)) (-15 -3069 (|#1| |#1| |#1|)) (-15 -3069 (|#1| (-638 |#1|))) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 ((-959 |#2|) |#1|)) (-15 -4081 ((-959 |#2|) |#1|)) (-15 -4081 ((-1152) |#1|)) (-15 -3246 (|#1| |#1|)) (-15 -3031 (|#1| |#1|)) (-15 -2944 (|#1| |#1|)) (-15 -3181 (|#1| |#1|)) (-15 -3069 (|#2| |#2| |#1|)) (-15 -3916 (|#1| |#1| |#1|)) (-15 -1467 (|#1| |#1| |#1|)) (-15 -3916 (|#1| |#1| |#2|)) (-15 -1467 (|#1| |#1| |#2|)) (-15 -4188 (|#1| |#1|)) (-15 -3119 (|#1| |#1|)) (-15 -4081 (|#1| (-959 |#2|))) (-15 -1318 (|#1| (-959 |#2|))) (-15 -3376 ((-3 |#1| "failed") (-959 |#2|))) (-15 -4081 (|#1| (-959 (-572)))) (-15 -1318 (|#1| (-959 (-572)))) (-15 -3376 ((-3 |#1| "failed") (-959 (-572)))) (-15 -4081 (|#1| (-959 (-413 (-572))))) (-15 -1318 (|#1| (-959 (-413 (-572))))) (-15 -3376 ((-3 |#1| "failed") (-959 (-413 (-572))))) (-15 -2788 (|#1| |#1| |#1|)) (-15 -4498 (|#1| |#1| |#1|)) (-15 -2767 ((-2 (|:| |polnum| |#1|) (|:| |polden| |#1|) (|:| -1951 (-769))) |#1| |#1|)) (-15 -3853 (|#1| |#1| |#1|)) (-15 -1449 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -2241 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1| |#4|)) (-15 -2241 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -3827 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -2492 |#1|)) |#1| |#1| |#4|)) (-15 -3827 ((-2 (|:| -4513 |#1|) (|:| |gap| (-769)) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -3720 (|#1| |#1| |#1| |#4|)) (-15 -1901 (|#1| |#1| |#1| |#4|)) (-15 -3720 (|#1| |#1| |#1|)) (-15 -1901 (|#1| |#1| |#1|)) (-15 -1851 (|#1| |#1| |#1| |#4|)) (-15 -1633 (|#1| |#1| |#1| |#4|)) (-15 -1851 (|#1| |#1| |#1|)) (-15 -1633 (|#1| |#1| |#1|)) (-15 -3824 ((-121) |#1| (-638 |#1|))) (-15 -3824 ((-121) |#1| |#1|)) (-15 -1483 ((-121) |#1| (-638 |#1|))) (-15 -1483 ((-121) |#1| |#1|)) (-15 -1994 ((-121) |#1| (-638 |#1|))) (-15 -1994 ((-121) |#1| |#1|)) (-15 -2240 ((-121) |#1| (-638 |#1|))) (-15 -2240 ((-121) |#1| |#1|)) (-15 -4437 ((-121) |#1| |#1|)) (-15 -1843 ((-121) |#1| |#1|)) (-15 -1926 ((-3 (-121) "failed") |#1| |#1|)) (-15 -3737 ((-638 |#1|) |#1|)) (-15 -1936 ((-638 |#1|) |#1|)) (-15 -4194 (|#1| |#1|)) (-15 -4312 (|#1| |#1|)) (-15 -1439 ((-121) |#1|)) (-15 -3897 ((-121) |#1|)) (-15 -4383 (|#1| |#1| |#4|)) (-15 -4373 (|#1| |#1| |#4|)) (-15 -3065 (|#1| |#1|)) (-15 -4176 ((-638 |#1|) |#1|)) (-15 -4426 (|#1| |#1|)) (-15 -4232 (|#1| |#1|)) (-15 -2826 (|#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 -3924 ((-769) |#1|)) (-15 -1792 (|#4| |#1|)) (-15 -4081 ((-545) |#1|)) (-15 -4081 ((-893 (-572)) |#1|)) (-15 -4081 ((-893 (-385)) |#1|)) (-15 -1318 (|#4| |#1|)) (-15 -3376 ((-3 |#4| "failed") |#1|)) (-15 -3972 (|#1| |#4|)) (-15 -4373 (|#2| |#1|)) (-15 -4383 (|#1| |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 |#3|) $) 108)) (-4297 (((-1166 $) $ |#3|) 123) (((-1166 |#1|) $) 122)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 85 (|has| |#1| (-562)))) (-3946 (($ $) 86 (|has| |#1| (-562)))) (-3686 (((-121) $) 88 (|has| |#1| (-562)))) (-2357 (((-769) $) 110) (((-769) $ (-638 |#3|)) 109)) (-4232 (($ $) 250)) (-4437 (((-121) $ $) 236)) (-1572 (((-3 $ "failed") $ $) 18)) (-2824 (($ $ $) 195 (|has| |#1| (-562)))) (-1323 (((-638 $) $ $) 190 (|has| |#1| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) 98 (|has| |#1| (-910)))) (-2844 (($ $) 96 (|has| |#1| (-457)))) (-1466 (((-424 $) $) 95 (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 101 (|has| |#1| (-910)))) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 162) (((-3 (-413 (-572)) "failed") $) 160 (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) 158 (|has| |#1| (-1044 (-572)))) (((-3 |#3| "failed") $) 134) (((-3 $ "failed") (-959 (-413 (-572)))) 210 (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#3| (-613 (-1170))))) (((-3 $ "failed") (-959 (-572))) 207 (-1841 (-12 (-2959 (|has| |#1| (-43 (-413 (-572))))) (|has| |#1| (-43 (-572))) (|has| |#3| (-613 (-1170)))) (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#3| (-613 (-1170)))))) (((-3 $ "failed") (-959 |#1|)) 204 (-1841 (-12 (-2959 (|has| |#1| (-43 (-413 (-572))))) (-2959 (|has| |#1| (-43 (-572)))) (|has| |#3| (-613 (-1170)))) (-12 (-2959 (|has| |#1| (-554))) (-2959 (|has| |#1| (-43 (-413 (-572))))) (|has| |#1| (-43 (-572))) (|has| |#3| (-613 (-1170)))) (-12 (-2959 (|has| |#1| (-1000 (-572)))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#3| (-613 (-1170))))))) (-1318 ((|#1| $) 163) (((-413 (-572)) $) 159 (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) 157 (|has| |#1| (-1044 (-572)))) ((|#3| $) 133) (($ (-959 (-413 (-572)))) 209 (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#3| (-613 (-1170))))) (($ (-959 (-572))) 206 (-1841 (-12 (-2959 (|has| |#1| (-43 (-413 (-572))))) (|has| |#1| (-43 (-572))) (|has| |#3| (-613 (-1170)))) (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#3| (-613 (-1170)))))) (($ (-959 |#1|)) 203 (-1841 (-12 (-2959 (|has| |#1| (-43 (-413 (-572))))) (-2959 (|has| |#1| (-43 (-572)))) (|has| |#3| (-613 (-1170)))) (-12 (-2959 (|has| |#1| (-554))) (-2959 (|has| |#1| (-43 (-413 (-572))))) (|has| |#1| (-43 (-572))) (|has| |#3| (-613 (-1170)))) (-12 (-2959 (|has| |#1| (-1000 (-572)))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#3| (-613 (-1170))))))) (-3190 (($ $ $ |#3|) 106 (|has| |#1| (-174))) (($ $ $) 191 (|has| |#1| (-562)))) (-4383 (($ $) 152) (($ $ |#3|) 245)) (-2284 (((-685 (-572)) (-685 $)) 132 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 131 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 130) (((-685 |#1|) (-685 $)) 129)) (-2240 (((-121) $ $) 235) (((-121) $ (-638 $)) 234)) (-1799 (((-3 $ "failed") $) 33)) (-1439 (((-121) $) 243)) (-1449 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 215)) (-3181 (($ $) 184 (|has| |#1| (-457)))) (-3988 (($ $) 174 (|has| |#1| (-457))) (($ $ |#3|) 103 (|has| |#1| (-457)))) (-4378 (((-638 $) $) 107)) (-1526 (((-121) $) 94 (|has| |#1| (-910)))) (-4188 (($ $) 200 (|has| |#1| (-562)))) (-3119 (($ $) 201 (|has| |#1| (-562)))) (-1633 (($ $ $) 227) (($ $ $ |#3|) 225)) (-1851 (($ $ $) 226) (($ $ $ |#3|) 224)) (-3977 (($ $ |#1| |#2| $) 170)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 82 (-12 (|has| |#3| (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 81 (-12 (|has| |#3| (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3893 (((-121) $) 30)) (-3475 (((-769) $) 167)) (-3824 (((-121) $ $) 229) (((-121) $ (-638 $)) 228)) (-2633 (($ $ $ $ $) 186 (|has| |#1| (-562)))) (-1792 ((|#3| $) 254)) (-4335 (($ (-1166 |#1|) |#3|) 115) (($ (-1166 $) |#3|) 114)) (-3658 (((-638 $) $) 124)) (-4581 (((-121) $) 150)) (-4328 (($ |#1| |#2|) 151) (($ $ |#3| (-769)) 117) (($ $ (-638 |#3|) (-638 (-769))) 116)) (-3853 (($ $ $) 214)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ |#3|) 118)) (-3897 (((-121) $) 244)) (-1784 ((|#2| $) 168) (((-769) $ |#3|) 120) (((-638 (-769)) $ (-638 |#3|)) 119)) (-1771 (($ $ $) 77 (|has| |#1| (-848)))) (-3924 (((-769) $) 253)) (-4238 (($ $ $) 76 (|has| |#1| (-848)))) (-3918 (($ (-1 |#2| |#2|) $) 169)) (-3828 (($ (-1 |#1| |#1|) $) 149)) (-1470 (((-3 |#3| "failed") $) 121)) (-3246 (($ $) 181 (|has| |#1| (-457)))) (-3031 (($ $) 182 (|has| |#1| (-457)))) (-3737 (((-638 $) $) 239)) (-4312 (($ $) 242)) (-2944 (($ $) 183 (|has| |#1| (-457)))) (-1936 (((-638 $) $) 240)) (-4194 (($ $) 241)) (-4368 (($ $) 147)) (-4373 ((|#1| $) 146) (($ $ |#3|) 246)) (-1629 (($ (-638 $)) 92 (|has| |#1| (-457))) (($ $ $) 91 (|has| |#1| (-457)))) (-2767 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -1951 (-769))) $ $) 213)) (-2241 (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $) 217) (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $ |#3|) 216)) (-3827 (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -2492 $)) $ $) 219) (((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -2492 $)) $ $ |#3|) 218)) (-1901 (($ $ $) 223) (($ $ $ |#3|) 221)) (-3720 (($ $ $) 222) (($ $ $ |#3|) 220)) (-1658 (((-1152) $) 9)) (-4416 (($ $ $) 189 (|has| |#1| (-562)))) (-4176 (((-638 $) $) 248)) (-1921 (((-3 (-638 $) "failed") $) 112)) (-2336 (((-3 (-638 $) "failed") $) 113)) (-3019 (((-3 (-2 (|:| |var| |#3|) (|:| -3751 (-769))) "failed") $) 111)) (-1483 (((-121) $ $) 231) (((-121) $ (-638 $)) 230)) (-2788 (($ $ $) 211)) (-1773 (($ $) 252)) (-1843 (((-121) $ $) 237)) (-1994 (((-121) $ $) 233) (((-121) $ (-638 $)) 232)) (-4498 (($ $ $) 212)) (-2826 (($ $) 251)) (-2607 (((-1116) $) 10)) (-4483 (((-2 (|:| -3069 $) (|:| |coef2| $)) $ $) 192 (|has| |#1| (-562)))) (-1833 (((-2 (|:| -3069 $) (|:| |coef1| $)) $ $) 193 (|has| |#1| (-562)))) (-4357 (((-121) $) 164)) (-4362 ((|#1| $) 165)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 93 (|has| |#1| (-457)))) (-3069 ((|#1| |#1| $) 185 (|has| |#1| (-457))) (($ (-638 $)) 90 (|has| |#1| (-457))) (($ $ $) 89 (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) 100 (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) 99 (|has| |#1| (-910)))) (-4304 (((-424 $) $) 97 (|has| |#1| (-910)))) (-3666 (((-2 (|:| -3069 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 194 (|has| |#1| (-562)))) (-1803 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-562))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-562)))) (-3916 (($ $ |#1|) 198 (|has| |#1| (-562))) (($ $ $) 196 (|has| |#1| (-562)))) (-1467 (($ $ |#1|) 199 (|has| |#1| (-562))) (($ $ $) 197 (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) 143) (($ $ (-290 $)) 142) (($ $ $ $) 141) (($ $ (-638 $) (-638 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-638 |#3|) (-638 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-638 |#3|) (-638 $)) 136)) (-2119 (($ $ |#3|) 105 (|has| |#1| (-174)))) (-3139 (($ $ |#3|) 41) (($ $ (-638 |#3|)) 40) (($ $ |#3| (-769)) 39) (($ $ (-638 |#3|) (-638 (-769))) 38)) (-4316 ((|#2| $) 148) (((-769) $ |#3|) 128) (((-638 (-769)) $ (-638 |#3|)) 127)) (-4426 (($ $) 249)) (-3065 (($ $) 247)) (-4081 (((-893 (-385)) $) 80 (-12 (|has| |#3| (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) 79 (-12 (|has| |#3| (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) 78 (-12 (|has| |#3| (-613 (-545))) (|has| |#1| (-613 (-545))))) (($ (-959 (-413 (-572)))) 208 (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#3| (-613 (-1170))))) (($ (-959 (-572))) 205 (-1841 (-12 (-2959 (|has| |#1| (-43 (-413 (-572))))) (|has| |#1| (-43 (-572))) (|has| |#3| (-613 (-1170)))) (-12 (|has| |#1| (-43 (-413 (-572)))) (|has| |#3| (-613 (-1170)))))) (($ (-959 |#1|)) 202 (|has| |#3| (-613 (-1170)))) (((-1152) $) 180 (-12 (|has| |#1| (-1044 (-572))) (|has| |#3| (-613 (-1170))))) (((-959 |#1|) $) 179 (|has| |#3| (-613 (-1170))))) (-3694 ((|#1| $) 173 (|has| |#1| (-457))) (($ $ |#3|) 104 (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 102 (-4028 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 161) (($ |#3|) 135) (((-959 |#1|) $) 178 (|has| |#3| (-613 (-1170)))) (($ (-413 (-572))) 70 (-1841 (|has| |#1| (-1044 (-413 (-572)))) (|has| |#1| (-43 (-413 (-572)))))) (($ $) 83 (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) 166)) (-1958 ((|#1| $ |#2|) 153) (($ $ |#3| (-769)) 126) (($ $ (-638 |#3|) (-638 (-769))) 125)) (-2779 (((-3 $ "failed") $) 71 (-1841 (-4028 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) 28)) (-2565 (($ $ $ (-769)) 171 (|has| |#1| (-174)))) (-3774 (((-121) $ $) 87 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-1926 (((-3 (-121) "failed") $ $) 238)) (-3255 (($) 29 T CONST)) (-2407 (($ $ $ $ (-769)) 187 (|has| |#1| (-562)))) (-1923 (($ $ $ (-769)) 188 (|has| |#1| (-562)))) (-1557 (($ $ |#3|) 37) (($ $ (-638 |#3|)) 36) (($ $ |#3| (-769)) 35) (($ $ (-638 |#3|) (-638 (-769))) 34)) (-1349 (((-121) $ $) 74 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 73 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 75 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 72 (|has| |#1| (-848)))) (-1379 (($ $ |#1|) 154 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 156 (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) 155 (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
-(((-1068 |#1| |#2| |#3|) (-1290) (-1054) (-794) (-848)) (T -1068)) 
-((-1792 (*1 *2 *1) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) (-3924 (*1 *2 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-769)))) (-1773 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-2826 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-4232 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-4426 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-4176 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1068 *3 *4 *5)))) (-3065 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-4373 (*1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) (-4383 (*1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) (-3897 (*1 *2 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-1439 (*1 *2 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-4312 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-4194 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-1936 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1068 *3 *4 *5)))) (-3737 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1068 *3 *4 *5)))) (-1926 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-1843 (*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-4437 (*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-2240 (*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-2240 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1068 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)))) (-1994 (*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-1994 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1068 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)))) (-1483 (*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-1483 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1068 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)))) (-3824 (*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) (-3824 (*1 *2 *1 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1068 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)))) (-1633 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-1851 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-1633 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) (-1851 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) (-1901 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-3720 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-1901 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) (-3720 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) (-3827 (*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -4513 *1) (|:| |gap| (-769)) (|:| -2492 *1))) (-4 *1 (-1068 *3 *4 *5)))) (-3827 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-2 (|:| -4513 *1) (|:| |gap| (-769)) (|:| -2492 *1))) (-4 *1 (-1068 *4 *5 *3)))) (-2241 (*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -4513 *1) (|:| |gap| (-769)) (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1068 *3 *4 *5)))) (-2241 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-2 (|:| -4513 *1) (|:| |gap| (-769)) (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1068 *4 *5 *3)))) (-1449 (*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1068 *3 *4 *5)))) (-3853 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-2767 (*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| |polnum| *1) (|:| |polden| *1) (|:| -1951 (-769)))) (-4 *1 (-1068 *3 *4 *5)))) (-4498 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-2788 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) (-3376 (*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-413 (-572)))) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)))) (-1318 (*1 *1 *2) (-12 (-5 *2 (-959 (-413 (-572)))) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-959 (-413 (-572)))) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)))) (-3376 (*1 *1 *2) (|partial| -1841 (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))))) (-1318 (*1 *1 *2) (-1841 (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))))) (-4081 (*1 *1 *2) (-1841 (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))))) (-3376 (*1 *1 *2) (|partial| -1841 (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-2959 (-4 *3 (-43 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-554))) (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-1000 (-572)))) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))))) (-1318 (*1 *1 *2) (-1841 (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-2959 (-4 *3 (-43 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-554))) (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-1000 (-572)))) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-959 *3)) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *5 (-613 (-1170))) (-4 *4 (-794)) (-4 *5 (-848)))) (-3119 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-4188 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-1467 (*1 *1 *1 *2) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-3916 (*1 *1 *1 *2) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-1467 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-3916 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-2824 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-3666 (*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -3069 *1) (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-1068 *3 *4 *5)))) (-1833 (*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -3069 *1) (|:| |coef1| *1))) (-4 *1 (-1068 *3 *4 *5)))) (-4483 (*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -3069 *1) (|:| |coef2| *1))) (-4 *1 (-1068 *3 *4 *5)))) (-3190 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-1323 (*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1068 *3 *4 *5)))) (-4416 (*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-1923 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *3 (-562)))) (-2407 (*1 *1 *1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *3 (-562)))) (-2633 (*1 *1 *1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) (-3069 (*1 *2 *2 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457)))) (-3181 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457)))) (-2944 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457)))) (-3031 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457)))) (-3246 (*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457))))) 
-(-13 (-956 |t#1| |t#2| |t#3|) (-10 -8 (-15 -1792 (|t#3| $)) (-15 -3924 ((-769) $)) (-15 -1773 ($ $)) (-15 -2826 ($ $)) (-15 -4232 ($ $)) (-15 -4426 ($ $)) (-15 -4176 ((-638 $) $)) (-15 -3065 ($ $)) (-15 -4373 ($ $ |t#3|)) (-15 -4383 ($ $ |t#3|)) (-15 -3897 ((-121) $)) (-15 -1439 ((-121) $)) (-15 -4312 ($ $)) (-15 -4194 ($ $)) (-15 -1936 ((-638 $) $)) (-15 -3737 ((-638 $) $)) (-15 -1926 ((-3 (-121) "failed") $ $)) (-15 -1843 ((-121) $ $)) (-15 -4437 ((-121) $ $)) (-15 -2240 ((-121) $ $)) (-15 -2240 ((-121) $ (-638 $))) (-15 -1994 ((-121) $ $)) (-15 -1994 ((-121) $ (-638 $))) (-15 -1483 ((-121) $ $)) (-15 -1483 ((-121) $ (-638 $))) (-15 -3824 ((-121) $ $)) (-15 -3824 ((-121) $ (-638 $))) (-15 -1633 ($ $ $)) (-15 -1851 ($ $ $)) (-15 -1633 ($ $ $ |t#3|)) (-15 -1851 ($ $ $ |t#3|)) (-15 -1901 ($ $ $)) (-15 -3720 ($ $ $)) (-15 -1901 ($ $ $ |t#3|)) (-15 -3720 ($ $ $ |t#3|)) (-15 -3827 ((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -2492 $)) $ $)) (-15 -3827 ((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -2492 $)) $ $ |t#3|)) (-15 -2241 ((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -2241 ((-2 (|:| -4513 $) (|:| |gap| (-769)) (|:| -3043 $) (|:| -2492 $)) $ $ |t#3|)) (-15 -1449 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -3853 ($ $ $)) (-15 -2767 ((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -1951 (-769))) $ $)) (-15 -4498 ($ $ $)) (-15 -2788 ($ $ $)) (IF (|has| |t#3| (-613 (-1170))) (PROGN (-6 (-612 (-959 |t#1|))) (-6 (-613 (-959 |t#1|))) (IF (|has| |t#1| (-43 (-413 (-572)))) (PROGN (-15 -3376 ((-3 $ "failed") (-959 (-413 (-572))))) (-15 -1318 ($ (-959 (-413 (-572))))) (-15 -4081 ($ (-959 (-413 (-572))))) (-15 -3376 ((-3 $ "failed") (-959 (-572)))) (-15 -1318 ($ (-959 (-572)))) (-15 -4081 ($ (-959 (-572)))) (IF (|has| |t#1| (-1000 (-572))) |noBranch| (PROGN (-15 -3376 ((-3 $ "failed") (-959 |t#1|))) (-15 -1318 ($ (-959 |t#1|)))))) |noBranch|) (IF (|has| |t#1| (-43 (-572))) (IF (|has| |t#1| (-43 (-413 (-572)))) |noBranch| (PROGN (-15 -3376 ((-3 $ "failed") (-959 (-572)))) (-15 -1318 ($ (-959 (-572)))) (-15 -4081 ($ (-959 (-572)))) (IF (|has| |t#1| (-554)) |noBranch| (PROGN (-15 -3376 ((-3 $ "failed") (-959 |t#1|))) (-15 -1318 ($ (-959 |t#1|))))))) |noBranch|) (IF (|has| |t#1| (-43 (-572))) |noBranch| (IF (|has| |t#1| (-43 (-413 (-572)))) |noBranch| (PROGN (-15 -3376 ((-3 $ "failed") (-959 |t#1|))) (-15 -1318 ($ (-959 |t#1|)))))) (-15 -4081 ($ (-959 |t#1|))) (IF (|has| |t#1| (-1044 (-572))) (-6 (-613 (-1152))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-562)) (PROGN (-15 -3119 ($ $)) (-15 -4188 ($ $)) (-15 -1467 ($ $ |t#1|)) (-15 -3916 ($ $ |t#1|)) (-15 -1467 ($ $ $)) (-15 -3916 ($ $ $)) (-15 -2824 ($ $ $)) (-15 -3666 ((-2 (|:| -3069 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1833 ((-2 (|:| -3069 $) (|:| |coef1| $)) $ $)) (-15 -4483 ((-2 (|:| -3069 $) (|:| |coef2| $)) $ $)) (-15 -3190 ($ $ $)) (-15 -1323 ((-638 $) $ $)) (-15 -4416 ($ $ $)) (-15 -1923 ($ $ $ (-769))) (-15 -2407 ($ $ $ $ (-769))) (-15 -2633 ($ $ $ $ $))) |noBranch|) (IF (|has| |t#1| (-457)) (PROGN (-15 -3069 (|t#1| |t#1| $)) (-15 -3181 ($ $)) (-15 -2944 ($ $)) (-15 -3031 ($ $)) (-15 -3246 ($ $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-612 (-959 |#1|)) |has| |#3| (-613 (-1170))) ((-174) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-613 (-545)) -12 (|has| |#1| (-613 (-545))) (|has| |#3| (-613 (-545)))) ((-613 (-893 (-385))) -12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#3| (-613 (-893 (-385))))) ((-613 (-893 (-572))) -12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#3| (-613 (-893 (-572))))) ((-613 (-959 |#1|)) |has| |#3| (-613 (-1170))) ((-613 (-1152)) -12 (|has| |#1| (-1044 (-572))) (|has| |#3| (-613 (-1170)))) ((-287) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-305 $) . T) ((-326 |#1| |#2|) . T) ((-383 |#1|) . T) ((-417 |#1|) . T) ((-457) -1841 (|has| |#1| (-910)) (|has| |#1| (-457))) ((-527 |#3| |#1|) . T) ((-527 |#3| $) . T) ((-527 $ $) . T) ((-562) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457))) ((-722) . T) ((-848) |has| |#1| (-848)) ((-901 |#3|) . T) ((-887 (-385)) -12 (|has| |#1| (-887 (-385))) (|has| |#3| (-887 (-385)))) ((-887 (-572)) -12 (|has| |#1| (-887 (-572))) (|has| |#3| (-887 (-572)))) ((-956 |#1| |#2| |#3|) . T) ((-910) |has| |#1| (-910)) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 |#1|) . T) ((-1044 |#3|) . T) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) |has| |#1| (-910))) 
-((-1342 (((-121) |#3| $) 13)) (-3733 (((-3 $ "failed") |#3| (-923)) 23)) (-1799 (((-3 |#3| "failed") |#3| $) 37)) (-1908 (((-121) |#3| $) 16)) (-4472 (((-121) |#3| $) 14))) 
-(((-1069 |#1| |#2| |#3|) (-10 -8 (-15 -3733 ((-3 |#1| "failed") |#3| (-923))) (-15 -1799 ((-3 |#3| "failed") |#3| |#1|)) (-15 -1908 ((-121) |#3| |#1|)) (-15 -4472 ((-121) |#3| |#1|)) (-15 -1342 ((-121) |#3| |#1|))) (-1070 |#2| |#3|) (-13 (-846) (-368)) (-1234 |#2|)) (T -1069)) 
-NIL 
-(-10 -8 (-15 -3733 ((-3 |#1| "failed") |#3| (-923))) (-15 -1799 ((-3 |#3| "failed") |#3| |#1|)) (-15 -1908 ((-121) |#3| |#1|)) (-15 -4472 ((-121) |#3| |#1|)) (-15 -1342 ((-121) |#3| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) |#2| $) 20)) (-2433 (((-572) |#2| $) 21)) (-3733 (((-3 $ "failed") |#2| (-923)) 14)) (-3089 ((|#1| |#2| $ |#1|) 12)) (-1799 (((-3 |#2| "failed") |#2| $) 17)) (-1908 (((-121) |#2| $) 18)) (-4472 (((-121) |#2| $) 19)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-2830 ((|#2| $) 16)) (-3972 (((-856) $) 11)) (-3410 ((|#1| |#2| $ |#1|) 13)) (-4010 (((-638 $) |#2|) 15)) (-1324 (((-121) $ $) 6))) 
-(((-1070 |#1| |#2|) (-1290) (-13 (-846) (-368)) (-1234 |t#1|)) (T -1070)) 
-((-2433 (*1 *2 *3 *1) (-12 (-4 *1 (-1070 *4 *3)) (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-572)))) (-1342 (*1 *2 *3 *1) (-12 (-4 *1 (-1070 *4 *3)) (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-121)))) (-4472 (*1 *2 *3 *1) (-12 (-4 *1 (-1070 *4 *3)) (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-121)))) (-1908 (*1 *2 *3 *1) (-12 (-4 *1 (-1070 *4 *3)) (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-121)))) (-1799 (*1 *2 *2 *1) (|partial| -12 (-4 *1 (-1070 *3 *2)) (-4 *3 (-13 (-846) (-368))) (-4 *2 (-1234 *3)))) (-2830 (*1 *2 *1) (-12 (-4 *1 (-1070 *3 *2)) (-4 *3 (-13 (-846) (-368))) (-4 *2 (-1234 *3)))) (-4010 (*1 *2 *3) (-12 (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-638 *1)) (-4 *1 (-1070 *4 *3)))) (-3733 (*1 *1 *2 *3) (|partial| -12 (-5 *3 (-923)) (-4 *4 (-13 (-846) (-368))) (-4 *1 (-1070 *4 *2)) (-4 *2 (-1234 *4)))) (-3410 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1070 *2 *3)) (-4 *2 (-13 (-846) (-368))) (-4 *3 (-1234 *2)))) (-3089 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1070 *2 *3)) (-4 *2 (-13 (-846) (-368))) (-4 *3 (-1234 *2))))) 
-(-13 (-1098) (-10 -8 (-15 -2433 ((-572) |t#2| $)) (-15 -1342 ((-121) |t#2| $)) (-15 -4472 ((-121) |t#2| $)) (-15 -1908 ((-121) |t#2| $)) (-15 -1799 ((-3 |t#2| "failed") |t#2| $)) (-15 -2830 (|t#2| $)) (-15 -4010 ((-638 $) |t#2|)) (-15 -3733 ((-3 $ "failed") |t#2| (-923))) (-15 -3410 (|t#1| |t#2| $ |t#1|)) (-15 -3089 (|t#1| |t#2| $ |t#1|)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-3734 (((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 |#4|) (-638 |#5|) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-769)) 95)) (-1362 (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|) 56) (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769)) 55)) (-2936 (((-1264) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-769)) 87)) (-3094 (((-769) (-638 |#4|) (-638 |#5|)) 27)) (-4033 (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|) 58) (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769)) 57) (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769) (-121)) 59)) (-2880 (((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121) (-121) (-121) (-121)) 78) (((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121)) 79)) (-4081 (((-1152) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) 82)) (-4444 (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-121)) 54)) (-2154 (((-769) (-638 |#4|) (-638 |#5|)) 19))) 
-(((-1071 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2154 ((-769) (-638 |#4|) (-638 |#5|))) (-15 -3094 ((-769) (-638 |#4|) (-638 |#5|))) (-15 -4444 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-121))) (-15 -1362 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769))) (-15 -1362 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769) (-121))) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769))) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -2880 ((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121))) (-15 -2880 ((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -3734 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 |#4|) (-638 |#5|) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-769))) (-15 -4081 ((-1152) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) (-15 -2936 ((-1264) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-769)))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1073 |#1| |#2| |#3| |#4|)) (T -1071)) 
-((-2936 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| |val| (-638 *8)) (|:| -1337 *9)))) (-5 *4 (-769)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-1264)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) (-4081 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-638 *7)) (|:| -1337 *8))) (-4 *7 (-1068 *4 *5 *6)) (-4 *8 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1152)) (-5 *1 (-1071 *4 *5 *6 *7 *8)))) (-3734 (*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-638 *11)) (|:| |todo| (-638 (-2 (|:| |val| *3) (|:| -1337 *11)))))) (-5 *6 (-769)) (-5 *2 (-638 (-2 (|:| |val| (-638 *10)) (|:| -1337 *11)))) (-5 *3 (-638 *10)) (-5 *4 (-638 *11)) (-4 *10 (-1068 *7 *8 *9)) (-4 *11 (-1073 *7 *8 *9 *10)) (-4 *7 (-457)) (-4 *8 (-794)) (-4 *9 (-848)) (-5 *1 (-1071 *7 *8 *9 *10 *11)))) (-2880 (*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-638 *9)) (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) (-2880 (*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-638 *9)) (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) (-4033 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-4033 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) (-4033 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-769)) (-5 *6 (-121)) (-4 *7 (-457)) (-4 *8 (-794)) (-4 *9 (-848)) (-4 *3 (-1068 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *7 *8 *9 *3 *4)) (-4 *4 (-1073 *7 *8 *9 *3)))) (-1362 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-1362 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) (-4444 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) (-3094 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *9)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-769)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) (-2154 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *9)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-769)) (-5 *1 (-1071 *5 *6 *7 *8 *9))))) 
-(-10 -7 (-15 -2154 ((-769) (-638 |#4|) (-638 |#5|))) (-15 -3094 ((-769) (-638 |#4|) (-638 |#5|))) (-15 -4444 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-121))) (-15 -1362 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769))) (-15 -1362 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769) (-121))) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769))) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -2880 ((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121))) (-15 -2880 ((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -3734 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 |#4|) (-638 |#5|) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-769))) (-15 -4081 ((-1152) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) (-15 -2936 ((-1264) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-769)))) 
-((-1706 (((-121) |#5| $) 20)) (-2989 (((-121) |#5| $) 23)) (-1366 (((-121) |#5| $) 16) (((-121) $) 44)) (-1931 (((-638 $) |#5| $) NIL) (((-638 $) (-638 |#5|) $) 76) (((-638 $) (-638 |#5|) (-638 $)) 74) (((-638 $) |#5| (-638 $)) 77)) (-1977 (($ $ |#5|) NIL) (((-638 $) |#5| $) NIL) (((-638 $) |#5| (-638 $)) 59) (((-638 $) (-638 |#5|) $) 61) (((-638 $) (-638 |#5|) (-638 $)) 63)) (-2589 (((-638 $) |#5| $) NIL) (((-638 $) |#5| (-638 $)) 53) (((-638 $) (-638 |#5|) $) 55) (((-638 $) (-638 |#5|) (-638 $)) 57)) (-4191 (((-121) |#5| $) 26))) 
-(((-1072 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -1977 ((-638 |#1|) (-638 |#5|) (-638 |#1|))) (-15 -1977 ((-638 |#1|) (-638 |#5|) |#1|)) (-15 -1977 ((-638 |#1|) |#5| (-638 |#1|))) (-15 -1977 ((-638 |#1|) |#5| |#1|)) (-15 -2589 ((-638 |#1|) (-638 |#5|) (-638 |#1|))) (-15 -2589 ((-638 |#1|) (-638 |#5|) |#1|)) (-15 -2589 ((-638 |#1|) |#5| (-638 |#1|))) (-15 -2589 ((-638 |#1|) |#5| |#1|)) (-15 -1931 ((-638 |#1|) |#5| (-638 |#1|))) (-15 -1931 ((-638 |#1|) (-638 |#5|) (-638 |#1|))) (-15 -1931 ((-638 |#1|) (-638 |#5|) |#1|)) (-15 -1931 ((-638 |#1|) |#5| |#1|)) (-15 -2989 ((-121) |#5| |#1|)) (-15 -1366 ((-121) |#1|)) (-15 -4191 ((-121) |#5| |#1|)) (-15 -1706 ((-121) |#5| |#1|)) (-15 -1366 ((-121) |#5| |#1|)) (-15 -1977 (|#1| |#1| |#5|))) (-1073 |#2| |#3| |#4| |#5|) (-457) (-794) (-848) (-1068 |#2| |#3| |#4|)) (T -1072)) 
-NIL 
-(-10 -8 (-15 -1977 ((-638 |#1|) (-638 |#5|) (-638 |#1|))) (-15 -1977 ((-638 |#1|) (-638 |#5|) |#1|)) (-15 -1977 ((-638 |#1|) |#5| (-638 |#1|))) (-15 -1977 ((-638 |#1|) |#5| |#1|)) (-15 -2589 ((-638 |#1|) (-638 |#5|) (-638 |#1|))) (-15 -2589 ((-638 |#1|) (-638 |#5|) |#1|)) (-15 -2589 ((-638 |#1|) |#5| (-638 |#1|))) (-15 -2589 ((-638 |#1|) |#5| |#1|)) (-15 -1931 ((-638 |#1|) |#5| (-638 |#1|))) (-15 -1931 ((-638 |#1|) (-638 |#5|) (-638 |#1|))) (-15 -1931 ((-638 |#1|) (-638 |#5|) |#1|)) (-15 -1931 ((-638 |#1|) |#5| |#1|)) (-15 -2989 ((-121) |#5| |#1|)) (-15 -1366 ((-121) |#1|)) (-15 -4191 ((-121) |#5| |#1|)) (-15 -1706 ((-121) |#5| |#1|)) (-15 -1366 ((-121) |#5| |#1|)) (-15 -1977 (|#1| |#1| |#5|))) 
-((-2262 (((-121) $ $) 7)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) 78)) (-4165 (((-638 $) (-638 |#4|)) 79) (((-638 $) (-638 |#4|) (-121)) 104)) (-3456 (((-638 |#3|) $) 32)) (-3049 (((-121) $) 25)) (-3289 (((-121) $) 16 (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) 94) (((-121) $) 90)) (-1872 ((|#4| |#4| $) 85)) (-2844 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| $) 119)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) 26)) (-1946 (((-121) $ (-769)) 43)) (-2561 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) 72)) (-2211 (($) 44 T CONST)) (-3097 (((-121) $) 21 (|has| |#1| (-562)))) (-3760 (((-121) $ $) 23 (|has| |#1| (-562)))) (-3819 (((-121) $ $) 22 (|has| |#1| (-562)))) (-4331 (((-121) $) 24 (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3683 (((-638 |#4|) (-638 |#4|) $) 17 (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) 18 (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) 35)) (-1318 (($ (-638 |#4|)) 34)) (-1651 (((-3 $ "failed") $) 75)) (-2242 ((|#4| |#4| $) 82)) (-1643 (($ $) 67 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#4| $) 66 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-1673 ((|#4| |#4| $) 80)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) 98)) (-1706 (((-121) |#4| $) 129)) (-2989 (((-121) |#4| $) 126)) (-1366 (((-121) |#4| $) 130) (((-121) $) 127)) (-2010 (((-638 |#4|) $) 51 (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) 97) (((-121) $) 96)) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) 42)) (-4467 (((-638 |#4|) $) 52 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 46)) (-4062 (((-638 |#3|) $) 31)) (-1346 (((-121) |#3| $) 30)) (-3524 (((-121) $ (-769)) 41)) (-1658 (((-1152) $) 9)) (-2550 (((-3 |#4| (-638 $)) |#4| |#4| $) 121)) (-4416 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| |#4| $) 120)) (-3253 (((-3 |#4| "failed") $) 76)) (-2173 (((-638 $) |#4| $) 122)) (-2471 (((-3 (-121) (-638 $)) |#4| $) 125)) (-2338 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-1931 (((-638 $) |#4| $) 118) (((-638 $) (-638 |#4|) $) 117) (((-638 $) (-638 |#4|) (-638 $)) 116) (((-638 $) |#4| (-638 $)) 115)) (-3078 (($ |#4| $) 110) (($ (-638 |#4|) $) 109)) (-3727 (((-638 |#4|) $) 100)) (-1483 (((-121) |#4| $) 92) (((-121) $) 88)) (-2788 ((|#4| |#4| $) 83)) (-1843 (((-121) $ $) 103)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) 93) (((-121) $) 89)) (-4498 ((|#4| |#4| $) 84)) (-2607 (((-1116) $) 10)) (-1837 (((-3 |#4| "failed") $) 77)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1928 (((-3 $ "failed") $ |#4|) 71)) (-1977 (($ $ |#4|) 70) (((-638 $) |#4| $) 108) (((-638 $) |#4| (-638 $)) 107) (((-638 $) (-638 |#4|) $) 106) (((-638 $) (-638 |#4|) (-638 $)) 105)) (-2109 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) 58 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) 56 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) 55 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) 37)) (-4037 (((-121) $) 40)) (-1665 (($) 39)) (-4316 (((-769) $) 99)) (-1571 (((-769) |#4| $) 53 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4602)))) (-1607 (($ $) 38)) (-4081 (((-545) $) 68 (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 59)) (-1826 (($ $ |#3|) 27)) (-2291 (($ $ |#3|) 29)) (-3134 (($ $) 81)) (-1650 (($ $ |#3|) 28)) (-3972 (((-856) $) 11) (((-638 |#4|) $) 36)) (-2498 (((-769) $) 69 (|has| |#3| (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) 91)) (-2589 (((-638 $) |#4| $) 114) (((-638 $) |#4| (-638 $)) 113) (((-638 $) (-638 |#4|) $) 112) (((-638 $) (-638 |#4|) (-638 $)) 111)) (-3501 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) 74)) (-4191 (((-121) |#4| $) 128)) (-2213 (((-121) |#3| $) 73)) (-1324 (((-121) $ $) 6)) (-4032 (((-769) $) 45 (|has| $ (-6 -4602))))) 
-(((-1073 |#1| |#2| |#3| |#4|) (-1290) (-457) (-794) (-848) (-1068 |t#1| |t#2| |t#3|)) (T -1073)) 
-((-1366 (*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-1706 (*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-4191 (*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-1366 (*1 *2 *1) (-12 (-4 *1 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) (-2989 (*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-2471 (*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-3 (-121) (-638 *1))) (-4 *1 (-1073 *4 *5 *6 *3)))) (-2338 (*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *1)))) (-4 *1 (-1073 *4 *5 *6 *3)))) (-2338 (*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-2173 (*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)))) (-2550 (*1 *2 *3 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-3 *3 (-638 *1))) (-4 *1 (-1073 *4 *5 *6 *3)))) (-4416 (*1 *2 *3 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *1)))) (-4 *1 (-1073 *4 *5 *6 *3)))) (-2844 (*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *1)))) (-4 *1 (-1073 *4 *5 *6 *3)))) (-1931 (*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)))) (-1931 (*1 *2 *3 *1) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *7)))) (-1931 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-5 *3 (-638 *7)) (-4 *1 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)))) (-1931 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)))) (-2589 (*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)))) (-2589 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)))) (-2589 (*1 *2 *3 *1) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *7)))) (-2589 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-5 *3 (-638 *7)) (-4 *1 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)))) (-3078 (*1 *1 *2 *1) (-12 (-4 *1 (-1073 *3 *4 *5 *2)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-3078 (*1 *1 *2 *1) (-12 (-5 *2 (-638 *6)) (-4 *1 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)))) (-1977 (*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)))) (-1977 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)))) (-1977 (*1 *2 *3 *1) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *7)))) (-1977 (*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-5 *3 (-638 *7)) (-4 *1 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)))) (-4165 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *5 *6 *7 *8))))) 
-(-13 (-1198 |t#1| |t#2| |t#3| |t#4|) (-10 -8 (-15 -1366 ((-121) |t#4| $)) (-15 -1706 ((-121) |t#4| $)) (-15 -4191 ((-121) |t#4| $)) (-15 -1366 ((-121) $)) (-15 -2989 ((-121) |t#4| $)) (-15 -2471 ((-3 (-121) (-638 $)) |t#4| $)) (-15 -2338 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 $))) |t#4| $)) (-15 -2338 ((-121) |t#4| $)) (-15 -2173 ((-638 $) |t#4| $)) (-15 -2550 ((-3 |t#4| (-638 $)) |t#4| |t#4| $)) (-15 -4416 ((-638 (-2 (|:| |val| |t#4|) (|:| -1337 $))) |t#4| |t#4| $)) (-15 -2844 ((-638 (-2 (|:| |val| |t#4|) (|:| -1337 $))) |t#4| $)) (-15 -1931 ((-638 $) |t#4| $)) (-15 -1931 ((-638 $) (-638 |t#4|) $)) (-15 -1931 ((-638 $) (-638 |t#4|) (-638 $))) (-15 -1931 ((-638 $) |t#4| (-638 $))) (-15 -2589 ((-638 $) |t#4| $)) (-15 -2589 ((-638 $) |t#4| (-638 $))) (-15 -2589 ((-638 $) (-638 |t#4|) $)) (-15 -2589 ((-638 $) (-638 |t#4|) (-638 $))) (-15 -3078 ($ |t#4| $)) (-15 -3078 ($ (-638 |t#4|) $)) (-15 -1977 ((-638 $) |t#4| $)) (-15 -1977 ((-638 $) |t#4| (-638 $))) (-15 -1977 ((-638 $) (-638 |t#4|) $)) (-15 -1977 ((-638 $) (-638 |t#4|) (-638 $))) (-15 -4165 ((-638 $) (-638 |t#4|) (-121))))) 
-(((-39) . T) ((-105) . T) ((-612 (-638 |#4|)) . T) ((-612 (-856)) . T) ((-155 |#4|) . T) ((-613 (-545)) |has| |#4| (-613 (-545))) ((-305 |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-503 |#4|) . T) ((-527 |#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-984 |#1| |#2| |#3| |#4|) . T) ((-1098) . T) ((-1198 |#1| |#2| |#3| |#4|) . T) ((-1204) . T)) 
-((-3766 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|) 81)) (-2341 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|) 112)) (-4434 (((-638 |#5|) |#4| |#5|) 70)) (-3108 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|) 44) (((-121) |#4| |#5|) 52)) (-2672 (((-1264)) 35)) (-1811 (((-1264)) 25)) (-4424 (((-1264) (-1152) (-1152) (-1152)) 31)) (-3553 (((-1264) (-1152) (-1152) (-1152)) 20)) (-2750 (((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#4| |#4| |#5|) 95)) (-3858 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#3| (-121)) 106) (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5| (-121) (-121)) 49)) (-4512 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|) 101))) 
-(((-1074 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3553 ((-1264) (-1152) (-1152) (-1152))) (-15 -1811 ((-1264))) (-15 -4424 ((-1264) (-1152) (-1152) (-1152))) (-15 -2672 ((-1264))) (-15 -2750 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -3858 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -3858 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#3| (-121))) (-15 -4512 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -2341 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -3108 ((-121) |#4| |#5|)) (-15 -3108 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -4434 ((-638 |#5|) |#4| |#5|)) (-15 -3766 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1073 |#1| |#2| |#3| |#4|)) (T -1074)) 
-((-3766 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-4434 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 *4)) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-3108 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-3108 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-2341 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-4512 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-3858 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-2 (|:| |val| (-638 *8)) (|:| -1337 *9)))) (-5 *5 (-121)) (-4 *8 (-1068 *6 *7 *4)) (-4 *9 (-1073 *6 *7 *4 *8)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *4 (-848)) (-5 *2 (-638 (-2 (|:| |val| *8) (|:| -1337 *9)))) (-5 *1 (-1074 *6 *7 *4 *8 *9)))) (-3858 (*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1074 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) (-2750 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-2672 (*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1074 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) (-4424 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1074 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-1811 (*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1074 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) (-3553 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1074 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -3553 ((-1264) (-1152) (-1152) (-1152))) (-15 -1811 ((-1264))) (-15 -4424 ((-1264) (-1152) (-1152) (-1152))) (-15 -2672 ((-1264))) (-15 -2750 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -3858 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -3858 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#3| (-121))) (-15 -4512 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -2341 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -3108 ((-121) |#4| |#5|)) (-15 -3108 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -4434 ((-638 |#5|) |#4| |#5|)) (-15 -3766 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|))) 
-((-2262 (((-121) $ $) NIL)) (-3201 (((-1170) $) 8)) (-1658 (((-1152) $) 16)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 13))) 
-(((-1075 |#1|) (-13 (-1098) (-10 -8 (-15 -3201 ((-1170) $)))) (-1170)) (T -1075)) 
-((-3201 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-1075 *3)) (-14 *3 *2)))) 
-(-13 (-1098) (-10 -8 (-15 -3201 ((-1170) $)))) 
-((-2262 (((-121) $ $) NIL)) (-3405 (($ $ (-638 (-1170)) (-1 (-121) (-638 |#3|))) 29)) (-3133 (($ |#3| |#3|) 21) (($ |#3| |#3| (-638 (-1170))) 19)) (-3194 ((|#3| $) 13)) (-3376 (((-3 (-290 |#3|) "failed") $) 56)) (-1318 (((-290 |#3|) $) NIL)) (-3569 (((-638 (-1170)) $) 15)) (-2821 (((-893 |#1|) $) 11)) (-4413 ((|#3| $) 12)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3277 ((|#3| $ |#3|) 25) ((|#3| $ |#3| (-923)) 36)) (-3972 (((-856) $) 84) (($ (-290 |#3|)) 20)) (-1324 (((-121) $ $) 33))) 
-(((-1076 |#1| |#2| |#3|) (-13 (-1098) (-283 |#3| |#3|) (-1044 (-290 |#3|)) (-10 -8 (-15 -3133 ($ |#3| |#3|)) (-15 -3133 ($ |#3| |#3| (-638 (-1170)))) (-15 -3405 ($ $ (-638 (-1170)) (-1 (-121) (-638 |#3|)))) (-15 -2821 ((-893 |#1|) $)) (-15 -4413 (|#3| $)) (-15 -3194 (|#3| $)) (-15 -3277 (|#3| $ |#3| (-923))) (-15 -3569 ((-638 (-1170)) $)))) (-1098) (-13 (-1054) (-887 |#1|) (-848) (-613 (-893 |#1|))) (-13 (-436 |#2|) (-887 |#1|) (-613 (-893 |#1|)))) (T -1076)) 
-((-3133 (*1 *1 *2 *2) (-12 (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))) (-5 *1 (-1076 *3 *4 *2)) (-4 *2 (-13 (-436 *4) (-887 *3) (-613 (-893 *3)))))) (-3133 (*1 *1 *2 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-1076 *4 *5 *2)) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))))) (-3405 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-1 (-121) (-638 *6))) (-4 *6 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-1076 *4 *5 *6)))) (-2821 (*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 *2))) (-5 *2 (-893 *3)) (-5 *1 (-1076 *3 *4 *5)) (-4 *5 (-13 (-436 *4) (-887 *3) (-613 *2))))) (-4413 (*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *2 (-13 (-436 *4) (-887 *3) (-613 (-893 *3)))) (-5 *1 (-1076 *3 *4 *2)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))))) (-3194 (*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *2 (-13 (-436 *4) (-887 *3) (-613 (-893 *3)))) (-5 *1 (-1076 *3 *4 *2)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))))) (-3277 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-1076 *4 *5 *2)) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))))) (-3569 (*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))) (-5 *2 (-638 (-1170))) (-5 *1 (-1076 *3 *4 *5)) (-4 *5 (-13 (-436 *4) (-887 *3) (-613 (-893 *3))))))) 
-(-13 (-1098) (-283 |#3| |#3|) (-1044 (-290 |#3|)) (-10 -8 (-15 -3133 ($ |#3| |#3|)) (-15 -3133 ($ |#3| |#3| (-638 (-1170)))) (-15 -3405 ($ $ (-638 (-1170)) (-1 (-121) (-638 |#3|)))) (-15 -2821 ((-893 |#1|) $)) (-15 -4413 (|#3| $)) (-15 -3194 (|#3| $)) (-15 -3277 (|#3| $ |#3| (-923))) (-15 -3569 ((-638 (-1170)) $)))) 
-((-2262 (((-121) $ $) NIL)) (-3147 (($ (-638 (-1076 |#1| |#2| |#3|))) 12)) (-1677 (((-638 (-1076 |#1| |#2| |#3|)) $) 19)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3277 ((|#3| $ |#3|) 22) ((|#3| $ |#3| (-923)) 25)) (-3972 (((-856) $) 15)) (-1324 (((-121) $ $) 18))) 
-(((-1077 |#1| |#2| |#3|) (-13 (-1098) (-283 |#3| |#3|) (-10 -8 (-15 -3147 ($ (-638 (-1076 |#1| |#2| |#3|)))) (-15 -1677 ((-638 (-1076 |#1| |#2| |#3|)) $)) (-15 -3277 (|#3| $ |#3| (-923))))) (-1098) (-13 (-1054) (-887 |#1|) (-848) (-613 (-893 |#1|))) (-13 (-436 |#2|) (-887 |#1|) (-613 (-893 |#1|)))) (T -1077)) 
-((-3147 (*1 *1 *2) (-12 (-5 *2 (-638 (-1076 *3 *4 *5))) (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))) (-4 *5 (-13 (-436 *4) (-887 *3) (-613 (-893 *3)))) (-5 *1 (-1077 *3 *4 *5)))) (-1677 (*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))) (-5 *2 (-638 (-1076 *3 *4 *5))) (-5 *1 (-1077 *3 *4 *5)) (-4 *5 (-13 (-436 *4) (-887 *3) (-613 (-893 *3)))))) (-3277 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-1077 *4 *5 *2)) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4))))))) 
-(-13 (-1098) (-283 |#3| |#3|) (-10 -8 (-15 -3147 ($ (-638 (-1076 |#1| |#2| |#3|)))) (-15 -1677 ((-638 (-1076 |#1| |#2| |#3|)) $)) (-15 -3277 (|#3| $ |#3| (-923))))) 
-((-4052 (((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121)) 73) (((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|))) 75) (((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121)) 74))) 
-(((-1078 |#1| |#2|) (-10 -7 (-15 -4052 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121))) (-15 -4052 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)))) (-15 -4052 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121)))) (-13 (-303) (-151)) (-638 (-1170))) (T -1078)) 
-((-4052 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1078 *5 *6)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170))))) (-4052 (*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *4)) (|:| -3160 (-638 (-959 *4)))))) (-5 *1 (-1078 *4 *5)) (-5 *3 (-638 (-959 *4))) (-14 *5 (-638 (-1170))))) (-4052 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1078 *5 *6)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170)))))) 
-(-10 -7 (-15 -4052 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121))) (-15 -4052 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)))) (-15 -4052 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121)))) 
-((-4304 (((-424 |#3|) |#3|) 16))) 
-(((-1079 |#1| |#2| |#3|) (-10 -7 (-15 -4304 ((-424 |#3|) |#3|))) (-1234 (-413 (-572))) (-13 (-368) (-151) (-720 (-413 (-572)) |#1|)) (-1234 |#2|)) (T -1079)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-1234 (-413 (-572)))) (-4 *5 (-13 (-368) (-151) (-720 (-413 (-572)) *4))) (-5 *2 (-424 *3)) (-5 *1 (-1079 *4 *5 *3)) (-4 *3 (-1234 *5))))) 
-(-10 -7 (-15 -4304 ((-424 |#3|) |#3|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 125)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-368)))) (-3946 (($ $) NIL (|has| |#1| (-368)))) (-3686 (((-121) $) NIL (|has| |#1| (-368)))) (-1845 (((-685 |#1|) (-1259 $)) NIL) (((-685 |#1|)) 115)) (-3520 ((|#1| $) 119)) (-3617 (((-1178 (-923) (-769)) (-572)) NIL (|has| |#1| (-353)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-1685 (((-769)) 40 (|has| |#1| (-374)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-4337 (($ (-1259 |#1|) (-1259 $)) NIL) (($ (-1259 |#1|)) 43)) (-1317 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-353)))) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-1741 (((-685 |#1|) $ (-1259 $)) NIL) (((-685 |#1|) $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 106) (((-685 |#1|) (-685 $)) 100)) (-3116 (($ |#2|) 61) (((-3 $ "failed") (-413 |#2|)) NIL (|has| |#1| (-368)))) (-1799 (((-3 $ "failed") $) NIL)) (-2667 (((-923)) 77)) (-3286 (($) 44 (|has| |#1| (-374)))) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-2754 (($) NIL (|has| |#1| (-353)))) (-1297 (((-121) $) NIL (|has| |#1| (-353)))) (-4486 (($ $ (-769)) NIL (|has| |#1| (-353))) (($ $) NIL (|has| |#1| (-353)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-3377 (((-923) $) NIL (|has| |#1| (-353))) (((-834 (-923)) $) NIL (|has| |#1| (-353)))) (-3893 (((-121) $) NIL)) (-4429 ((|#1| $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-353)))) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-3251 ((|#2| $) 84 (|has| |#1| (-368)))) (-3633 (((-923) $) 129 (|has| |#1| (-374)))) (-3111 ((|#2| $) 58)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-1773 (($) NIL (|has| |#1| (-353)) CONST)) (-1763 (($ (-923)) 124 (|has| |#1| (-374)))) (-2607 (((-1116) $) NIL)) (-2307 (($) 121)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-2503 (((-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572))))) NIL (|has| |#1| (-353)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-2119 ((|#1| (-1259 $)) NIL) ((|#1|) 109)) (-3158 (((-769) $) NIL (|has| |#1| (-353))) (((-3 (-769) "failed") $ $) NIL (|has| |#1| (-353)))) (-3139 (($ $) NIL (-1841 (-12 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353)))) (($ $ (-769)) NIL (-1841 (-12 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353)))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) (($ $ (-1 |#1| |#1|) (-769)) NIL (|has| |#1| (-368))) (($ $ (-1 |#1| |#1|)) NIL (|has| |#1| (-368)))) (-3482 (((-685 |#1|) (-1259 $) (-1 |#1| |#1|)) NIL (|has| |#1| (-368)))) (-2830 ((|#2|) 73)) (-2278 (($) NIL (|has| |#1| (-353)))) (-3160 (((-1259 |#1|) $ (-1259 $)) 89) (((-685 |#1|) (-1259 $) (-1259 $)) NIL) (((-1259 |#1|) $) 71) (((-685 |#1|) (-1259 $)) 85)) (-4081 (((-1259 |#1|) $) NIL) (($ (-1259 |#1|)) NIL) ((|#2| $) NIL) (($ |#2|) NIL)) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (|has| |#1| (-353)))) (-3972 (((-856) $) 57) (($ (-572)) 53) (($ |#1|) 54) (($ $) NIL (|has| |#1| (-368))) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-368)) (|has| |#1| (-1044 (-413 (-572))))))) (-2779 (($ $) NIL (|has| |#1| (-353))) (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2707 ((|#2| $) 82)) (-2140 (((-769)) 75)) (-2237 (((-1259 $)) 81)) (-3774 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 30 T CONST)) (-3255 (($) 19 T CONST)) (-1557 (($ $) NIL (-1841 (-12 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353)))) (($ $ (-769)) NIL (-1841 (-12 (|has| |#1| (-227)) (|has| |#1| (-368))) (|has| |#1| (-353)))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-368)) (|has| |#1| (-901 (-1170))))) (($ $ (-1 |#1| |#1|) (-769)) NIL (|has| |#1| (-368))) (($ $ (-1 |#1| |#1|)) NIL (|has| |#1| (-368)))) (-1324 (((-121) $ $) 63)) (-1379 (($ $ $) NIL (|has| |#1| (-368)))) (-1373 (($ $) 67) (($ $ $) NIL)) (-1367 (($ $ $) 65)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 51) (($ $ $) 69) (($ $ |#1|) NIL) (($ |#1| $) 48) (($ (-413 (-572)) $) NIL (|has| |#1| (-368))) (($ $ (-413 (-572))) NIL (|has| |#1| (-368))))) 
-(((-1080 |#1| |#2| |#3|) (-720 |#1| |#2|) (-174) (-1234 |#1|) |#2|) (T -1080)) 
-NIL 
-(-720 |#1| |#2|) 
-((-4304 (((-424 |#3|) |#3|) 16))) 
-(((-1081 |#1| |#2| |#3|) (-10 -7 (-15 -4304 ((-424 |#3|) |#3|))) (-1234 (-413 (-959 (-572)))) (-13 (-368) (-151) (-720 (-413 (-959 (-572))) |#1|)) (-1234 |#2|)) (T -1081)) 
-((-4304 (*1 *2 *3) (-12 (-4 *4 (-1234 (-413 (-959 (-572))))) (-4 *5 (-13 (-368) (-151) (-720 (-413 (-959 (-572))) *4))) (-5 *2 (-424 *3)) (-5 *1 (-1081 *4 *5 *3)) (-4 *3 (-1234 *5))))) 
-(-10 -7 (-15 -4304 ((-424 |#3|) |#3|))) 
-((-2262 (((-121) $ $) NIL)) (-1771 (($ $ $) 14)) (-4238 (($ $ $) 15)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2652 (($) 6)) (-4081 (((-1170) $) 18)) (-3972 (((-856) $) 12)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 13)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 8))) 
-(((-1082) (-13 (-848) (-10 -8 (-15 -2652 ($)) (-15 -4081 ((-1170) $))))) (T -1082)) 
-((-2652 (*1 *1) (-5 *1 (-1082))) (-4081 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-1082))))) 
-(-13 (-848) (-10 -8 (-15 -2652 ($)) (-15 -4081 ((-1170) $)))) 
-((-4432 ((|#1| |#1| (-1 (-572) |#1| |#1|)) 21) ((|#1| |#1| (-1 (-121) |#1|)) 18)) (-3150 (((-1264)) 15)) (-1492 (((-638 |#1|)) 9))) 
-(((-1083 |#1|) (-10 -7 (-15 -3150 ((-1264))) (-15 -1492 ((-638 |#1|))) (-15 -4432 (|#1| |#1| (-1 (-121) |#1|))) (-15 -4432 (|#1| |#1| (-1 (-572) |#1| |#1|)))) (-139)) (T -1083)) 
-((-4432 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-572) *2 *2)) (-4 *2 (-139)) (-5 *1 (-1083 *2)))) (-4432 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *2)) (-4 *2 (-139)) (-5 *1 (-1083 *2)))) (-1492 (*1 *2) (-12 (-5 *2 (-638 *3)) (-5 *1 (-1083 *3)) (-4 *3 (-139)))) (-3150 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1083 *3)) (-4 *3 (-139))))) 
-(-10 -7 (-15 -3150 ((-1264))) (-15 -1492 ((-638 |#1|))) (-15 -4432 (|#1| |#1| (-1 (-121) |#1|))) (-15 -4432 (|#1| |#1| (-1 (-572) |#1| |#1|)))) 
-((-1354 (((-1259 (-685 |#1|)) (-638 (-685 |#1|))) 41) (((-1259 (-685 (-959 |#1|))) (-638 (-1170)) (-685 (-959 |#1|))) 60) (((-1259 (-685 (-413 (-959 |#1|)))) (-638 (-1170)) (-685 (-413 (-959 |#1|)))) 76)) (-3160 (((-1259 |#1|) (-685 |#1|) (-638 (-685 |#1|))) 35))) 
-(((-1084 |#1|) (-10 -7 (-15 -1354 ((-1259 (-685 (-413 (-959 |#1|)))) (-638 (-1170)) (-685 (-413 (-959 |#1|))))) (-15 -1354 ((-1259 (-685 (-959 |#1|))) (-638 (-1170)) (-685 (-959 |#1|)))) (-15 -1354 ((-1259 (-685 |#1|)) (-638 (-685 |#1|)))) (-15 -3160 ((-1259 |#1|) (-685 |#1|) (-638 (-685 |#1|))))) (-368)) (T -1084)) 
-((-3160 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-685 *5))) (-5 *3 (-685 *5)) (-4 *5 (-368)) (-5 *2 (-1259 *5)) (-5 *1 (-1084 *5)))) (-1354 (*1 *2 *3) (-12 (-5 *3 (-638 (-685 *4))) (-4 *4 (-368)) (-5 *2 (-1259 (-685 *4))) (-5 *1 (-1084 *4)))) (-1354 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1170))) (-4 *5 (-368)) (-5 *2 (-1259 (-685 (-959 *5)))) (-5 *1 (-1084 *5)) (-5 *4 (-685 (-959 *5))))) (-1354 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1170))) (-4 *5 (-368)) (-5 *2 (-1259 (-685 (-413 (-959 *5))))) (-5 *1 (-1084 *5)) (-5 *4 (-685 (-413 (-959 *5))))))) 
-(-10 -7 (-15 -1354 ((-1259 (-685 (-413 (-959 |#1|)))) (-638 (-1170)) (-685 (-413 (-959 |#1|))))) (-15 -1354 ((-1259 (-685 (-959 |#1|))) (-638 (-1170)) (-685 (-959 |#1|)))) (-15 -1354 ((-1259 (-685 |#1|)) (-638 (-685 |#1|)))) (-15 -3160 ((-1259 |#1|) (-685 |#1|) (-638 (-685 |#1|))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3701 (((-121) $ $) 89) (((-121) (-638 $) (-638 $)) 94) (((-121) (-638 (-638 $))) 97)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2258 (((-856)) 88)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-130) "failed") $) NIL)) (-1318 (((-130) $) 68)) (-2397 (((-638 (-130)) $) 70)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4319 (((-121) $ (-130)) 64)) (-3821 (((-3 (-290 $) "failed") $ |#1|) 75) (((-3 (-290 $) "failed") |#1| $) 76)) (-3371 (($ $) 62)) (-4405 (((-1178 $ $)) 79)) (-2938 (((-1178 $ $)) 78)) (-3972 (((-856) $) 47) (($ (-130)) 35)) (-1958 (((-312 |#1|) $ (-130)) 66)) (-4210 (((-3 $ "failed") (-130) (-130) $) 39)) (-1402 (((-3 $ "failed") (-130) $) 40)) (-4174 (($ $ (-923)) 61)) (-2378 (($) 21 T CONST)) (-1324 (((-121) $ $) 33)) (-1379 (($ $ (-312 |#1|)) 11)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 56)) (** (($ $ (-923)) 60)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 32) (($ $ (-312 |#1|)) NIL) (($ (-312 |#1|) $) 10))) 
-(((-1085 |#1|) (-13 (-1061) (-713 (-312 |#1|)) (-10 -8 (-6 (-1044 (-130))) (-15 -4210 ((-3 $ "failed") (-130) (-130) $)) (-15 -1402 ((-3 $ "failed") (-130) $)) (-15 -3371 ($ $)) (-15 -4319 ((-121) $ (-130))) (-15 -1958 ((-312 |#1|) $ (-130))) (-15 -2397 ((-638 (-130)) $)) (-15 -3821 ((-3 (-290 $) "failed") $ |#1|)) (-15 -3821 ((-3 (-290 $) "failed") |#1| $)) (-15 -2938 ((-1178 $ $))) (-15 -4405 ((-1178 $ $))) (-15 -1379 ($ $ (-312 |#1|))) (-15 ** ($ $ (-923))) (-15 -4174 ($ $ (-923))) (-15 -2258 ((-856))) (-15 -3701 ((-121) $ $)) (-15 -3701 ((-121) (-638 $) (-638 $))) (-15 -3701 ((-121) (-638 (-638 $)))))) (-13 (-848) (-562))) (T -1085)) 
-((-4174 (*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-4210 (*1 *1 *2 *2 *1) (|partial| -12 (-5 *2 (-130)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-1402 (*1 *1 *2 *1) (|partial| -12 (-5 *2 (-130)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-3371 (*1 *1 *1) (-12 (-5 *1 (-1085 *2)) (-4 *2 (-13 (-848) (-562))))) (-4319 (*1 *2 *1 *3) (-12 (-5 *3 (-130)) (-5 *2 (-121)) (-5 *1 (-1085 *4)) (-4 *4 (-13 (-848) (-562))))) (-1958 (*1 *2 *1 *3) (-12 (-5 *3 (-130)) (-5 *2 (-312 *4)) (-5 *1 (-1085 *4)) (-4 *4 (-13 (-848) (-562))))) (-2397 (*1 *2 *1) (-12 (-5 *2 (-638 (-130))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-3821 (*1 *2 *1 *3) (|partial| -12 (-5 *2 (-290 (-1085 *3))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-3821 (*1 *2 *3 *1) (|partial| -12 (-5 *2 (-290 (-1085 *3))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-2938 (*1 *2) (-12 (-5 *2 (-1178 (-1085 *3) (-1085 *3))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-4405 (*1 *2) (-12 (-5 *2 (-1178 (-1085 *3) (-1085 *3))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-1379 (*1 *1 *1 *2) (-12 (-5 *2 (-312 *3)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-1085 *3)))) (-2258 (*1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-3701 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) (-3701 (*1 *2 *3 *3) (-12 (-5 *3 (-638 (-1085 *4))) (-5 *2 (-121)) (-5 *1 (-1085 *4)) (-4 *4 (-13 (-848) (-562))))) (-3701 (*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-1085 *4)))) (-5 *2 (-121)) (-5 *1 (-1085 *4)) (-4 *4 (-13 (-848) (-562)))))) 
-(-13 (-1061) (-713 (-312 |#1|)) (-10 -8 (-6 (-1044 (-130))) (-15 -4210 ((-3 $ "failed") (-130) (-130) $)) (-15 -1402 ((-3 $ "failed") (-130) $)) (-15 -3371 ($ $)) (-15 -4319 ((-121) $ (-130))) (-15 -1958 ((-312 |#1|) $ (-130))) (-15 -2397 ((-638 (-130)) $)) (-15 -3821 ((-3 (-290 $) "failed") $ |#1|)) (-15 -3821 ((-3 (-290 $) "failed") |#1| $)) (-15 -2938 ((-1178 $ $))) (-15 -4405 ((-1178 $ $))) (-15 -1379 ($ $ (-312 |#1|))) (-15 ** ($ $ (-923))) (-15 -4174 ($ $ (-923))) (-15 -2258 ((-856))) (-15 -3701 ((-121) $ $)) (-15 -3701 ((-121) (-638 $) (-638 $))) (-15 -3701 ((-121) (-638 (-638 $)))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2923 (((-638 (-769)) $) NIL) (((-638 (-769)) $ (-1170)) NIL)) (-3073 (((-769) $) NIL) (((-769) $ (-1170)) NIL)) (-3456 (((-638 (-1087 (-1170))) $) NIL)) (-4297 (((-1166 $) $ (-1087 (-1170))) NIL) (((-1166 |#1|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1087 (-1170)))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4048 (($ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-1087 (-1170)) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL) (((-3 (-1121 |#1| (-1170)) "failed") $) NIL)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-1087 (-1170)) $) NIL) (((-1170) $) NIL) (((-1121 |#1| (-1170)) $) NIL)) (-3190 (($ $ $ (-1087 (-1170))) NIL (|has| |#1| (-174)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ (-1087 (-1170))) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-538 (-1087 (-1170))) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1087 (-1170)) (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1087 (-1170)) (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3377 (((-769) $ (-1170)) NIL) (((-769) $) NIL)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-4335 (($ (-1166 |#1|) (-1087 (-1170))) NIL) (($ (-1166 $) (-1087 (-1170))) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-538 (-1087 (-1170)))) NIL) (($ $ (-1087 (-1170)) (-769)) NIL) (($ $ (-638 (-1087 (-1170))) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1087 (-1170))) NIL)) (-1784 (((-538 (-1087 (-1170))) $) NIL) (((-769) $ (-1087 (-1170))) NIL) (((-638 (-769)) $ (-638 (-1087 (-1170)))) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-538 (-1087 (-1170))) (-538 (-1087 (-1170)))) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3101 (((-1 $ (-769)) (-1170)) NIL) (((-1 $ (-769)) $) NIL (|has| |#1| (-227)))) (-1470 (((-3 (-1087 (-1170)) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-4021 (((-1087 (-1170)) $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-3815 (((-121) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-1087 (-1170))) (|:| -3751 (-769))) "failed") $) NIL)) (-2106 (($ $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1087 (-1170)) |#1|) NIL) (($ $ (-638 (-1087 (-1170))) (-638 |#1|)) NIL) (($ $ (-1087 (-1170)) $) NIL) (($ $ (-638 (-1087 (-1170))) (-638 $)) NIL) (($ $ (-1170) $) NIL (|has| |#1| (-227))) (($ $ (-638 (-1170)) (-638 $)) NIL (|has| |#1| (-227))) (($ $ (-1170) |#1|) NIL (|has| |#1| (-227))) (($ $ (-638 (-1170)) (-638 |#1|)) NIL (|has| |#1| (-227)))) (-2119 (($ $ (-1087 (-1170))) NIL (|has| |#1| (-174)))) (-3139 (($ $ (-1087 (-1170))) NIL) (($ $ (-638 (-1087 (-1170)))) NIL) (($ $ (-1087 (-1170)) (-769)) NIL) (($ $ (-638 (-1087 (-1170))) (-638 (-769))) NIL) (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2866 (((-638 (-1170)) $) NIL)) (-4316 (((-538 (-1087 (-1170))) $) NIL) (((-769) $ (-1087 (-1170))) NIL) (((-638 (-769)) $ (-638 (-1087 (-1170)))) NIL) (((-769) $ (-1170)) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-1087 (-1170)) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-1087 (-1170)) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-1087 (-1170)) (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) NIL (|has| |#1| (-457))) (($ $ (-1087 (-1170))) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-1087 (-1170))) NIL) (($ (-1170)) NIL) (($ (-1121 |#1| (-1170))) NIL) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-538 (-1087 (-1170)))) NIL) (($ $ (-1087 (-1170)) (-769)) NIL) (($ $ (-638 (-1087 (-1170))) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-1087 (-1170))) NIL) (($ $ (-638 (-1087 (-1170)))) NIL) (($ $ (-1087 (-1170)) (-769)) NIL) (($ $ (-638 (-1087 (-1170))) (-638 (-769))) NIL) (($ $) NIL (|has| |#1| (-227))) (($ $ (-769)) NIL (|has| |#1| (-227))) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-1086 |#1|) (-13 (-248 |#1| (-1170) (-1087 (-1170)) (-538 (-1087 (-1170)))) (-1044 (-1121 |#1| (-1170)))) (-1054)) (T -1086)) 
-NIL 
-(-13 (-248 |#1| (-1170) (-1087 (-1170)) (-538 (-1087 (-1170)))) (-1044 (-1121 |#1| (-1170)))) 
-((-2262 (((-121) $ $) NIL)) (-3073 (((-769) $) NIL)) (-3342 ((|#1| $) 10)) (-3376 (((-3 |#1| "failed") $) NIL)) (-1318 ((|#1| $) NIL)) (-3377 (((-769) $) 11)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-3101 (($ |#1| (-769)) 9)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3139 (($ $) NIL) (($ $ (-769)) NIL)) (-3972 (((-856) $) NIL) (($ |#1|) NIL)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 15))) 
-(((-1087 |#1|) (-264 |#1|) (-848)) (T -1087)) 
-NIL 
-(-264 |#1|) 
-((-3828 (((-638 |#2|) (-1 |#2| |#1|) (-1092 |#1|)) 23 (|has| |#1| (-846))) (((-1092 |#2|) (-1 |#2| |#1|) (-1092 |#1|)) 14))) 
-(((-1088 |#1| |#2|) (-10 -7 (-15 -3828 ((-1092 |#2|) (-1 |#2| |#1|) (-1092 |#1|))) (IF (|has| |#1| (-846)) (-15 -3828 ((-638 |#2|) (-1 |#2| |#1|) (-1092 |#1|))) |noBranch|)) (-1204) (-1204)) (T -1088)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1092 *5)) (-4 *5 (-846)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-638 *6)) (-5 *1 (-1088 *5 *6)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1092 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1092 *6)) (-5 *1 (-1088 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-1092 |#2|) (-1 |#2| |#1|) (-1092 |#1|))) (IF (|has| |#1| (-846)) (-15 -3828 ((-638 |#2|) (-1 |#2| |#1|) (-1092 |#1|))) |noBranch|)) 
-((-3828 (((-1090 |#2|) (-1 |#2| |#1|) (-1090 |#1|)) 19))) 
-(((-1089 |#1| |#2|) (-10 -7 (-15 -3828 ((-1090 |#2|) (-1 |#2| |#1|) (-1090 |#1|)))) (-1204) (-1204)) (T -1089)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1090 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1090 *6)) (-5 *1 (-1089 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-1090 |#2|) (-1 |#2| |#1|) (-1090 |#1|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3342 (((-1170) $) 11)) (-4199 (((-1092 |#1|) $) 12)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3821 (($ (-1170) (-1092 |#1|)) 10)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-1324 (((-121) $ $) 15 (|has| |#1| (-1098))))) 
-(((-1090 |#1|) (-13 (-1204) (-10 -8 (-15 -3821 ($ (-1170) (-1092 |#1|))) (-15 -3342 ((-1170) $)) (-15 -4199 ((-1092 |#1|) $)) (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|))) (-1204)) (T -1090)) 
-((-3821 (*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1092 *4)) (-4 *4 (-1204)) (-5 *1 (-1090 *4)))) (-3342 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-1090 *3)) (-4 *3 (-1204)))) (-4199 (*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-1090 *3)) (-4 *3 (-1204))))) 
-(-13 (-1204) (-10 -8 (-15 -3821 ($ (-1170) (-1092 |#1|))) (-15 -3342 ((-1170) $)) (-15 -4199 ((-1092 |#1|) $)) (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|))) 
-((-4199 (($ |#1| |#1|) 7)) (-2861 ((|#1| $) 10)) (-2399 ((|#1| $) 12)) (-2408 (((-572) $) 8)) (-4461 ((|#1| $) 9)) (-2417 ((|#1| $) 11)) (-4081 (($ |#1|) 6)) (-2770 (($ |#1| |#1|) 14)) (-3887 (($ $ (-572)) 13))) 
-(((-1091 |#1|) (-1290) (-1204)) (T -1091)) 
-((-2770 (*1 *1 *2 *2) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) (-3887 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1091 *3)) (-4 *3 (-1204)))) (-2399 (*1 *2 *1) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) (-2417 (*1 *2 *1) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) (-2861 (*1 *2 *1) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) (-4461 (*1 *2 *1) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) (-2408 (*1 *2 *1) (-12 (-4 *1 (-1091 *3)) (-4 *3 (-1204)) (-5 *2 (-572)))) (-4199 (*1 *1 *2 *2) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) (-4081 (*1 *1 *2) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204))))) 
-(-13 (-1204) (-10 -8 (-15 -2770 ($ |t#1| |t#1|)) (-15 -3887 ($ $ (-572))) (-15 -2399 (|t#1| $)) (-15 -2417 (|t#1| $)) (-15 -2861 (|t#1| $)) (-15 -4461 (|t#1| $)) (-15 -2408 ((-572) $)) (-15 -4199 ($ |t#1| |t#1|)) (-15 -4081 ($ |t#1|)))) 
-(((-1204) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4199 (($ |#1| |#1|) 15)) (-3828 (((-638 |#1|) (-1 |#1| |#1|) $) 37 (|has| |#1| (-846)))) (-2861 ((|#1| $) 10)) (-2399 ((|#1| $) 9)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2408 (((-572) $) 14)) (-4461 ((|#1| $) 12)) (-2417 ((|#1| $) 11)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2534 (((-638 |#1|) $) 35 (|has| |#1| (-846))) (((-638 |#1|) (-638 $)) 34 (|has| |#1| (-846)))) (-4081 (($ |#1|) 26)) (-3972 (((-856) $) 25 (|has| |#1| (-1098)))) (-2770 (($ |#1| |#1|) 8)) (-3887 (($ $ (-572)) 16)) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098))))) 
-(((-1092 |#1|) (-13 (-1091 |#1|) (-10 -7 (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|) (IF (|has| |#1| (-846)) (-6 (-1093 |#1| (-638 |#1|))) |noBranch|))) (-1204)) (T -1092)) 
-NIL 
-(-13 (-1091 |#1|) (-10 -7 (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|) (IF (|has| |#1| (-846)) (-6 (-1093 |#1| (-638 |#1|))) |noBranch|))) 
-((-4199 (($ |#1| |#1|) 7)) (-3828 ((|#2| (-1 |#1| |#1|) $) 15)) (-2861 ((|#1| $) 10)) (-2399 ((|#1| $) 12)) (-2408 (((-572) $) 8)) (-4461 ((|#1| $) 9)) (-2417 ((|#1| $) 11)) (-2534 ((|#2| (-638 $)) 17) ((|#2| $) 16)) (-4081 (($ |#1|) 6)) (-2770 (($ |#1| |#1|) 14)) (-3887 (($ $ (-572)) 13))) 
-(((-1093 |#1| |#2|) (-1290) (-846) (-1142 |t#1|)) (T -1093)) 
-((-2534 (*1 *2 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1093 *4 *2)) (-4 *4 (-846)) (-4 *2 (-1142 *4)))) (-2534 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *2)) (-4 *3 (-846)) (-4 *2 (-1142 *3)))) (-3828 (*1 *2 *3 *1) (-12 (-5 *3 (-1 *4 *4)) (-4 *1 (-1093 *4 *2)) (-4 *4 (-846)) (-4 *2 (-1142 *4))))) 
-(-13 (-1091 |t#1|) (-10 -8 (-15 -2534 (|t#2| (-638 $))) (-15 -2534 (|t#2| $)) (-15 -3828 (|t#2| (-1 |t#1| |t#1|) $)))) 
-(((-1091 |#1|) . T) ((-1204) . T)) 
-((-3518 (($ $ $) NIL) (($ $ |#2|) 13) (($ |#2| $) 14)) (-3710 (($ $ $) 10)) (-3982 (($ $ $) NIL) (($ $ |#2|) 15))) 
-(((-1094 |#1| |#2|) (-10 -8 (-15 -3518 (|#1| |#2| |#1|)) (-15 -3518 (|#1| |#1| |#2|)) (-15 -3518 (|#1| |#1| |#1|)) (-15 -3710 (|#1| |#1| |#1|)) (-15 -3982 (|#1| |#1| |#2|)) (-15 -3982 (|#1| |#1| |#1|))) (-1095 |#2|) (-1098)) (T -1094)) 
-NIL 
-(-10 -8 (-15 -3518 (|#1| |#2| |#1|)) (-15 -3518 (|#1| |#1| |#2|)) (-15 -3518 (|#1| |#1| |#1|)) (-15 -3710 (|#1| |#1| |#1|)) (-15 -3982 (|#1| |#1| |#2|)) (-15 -3982 (|#1| |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-3518 (($ $ $) 17) (($ $ |#1|) 16) (($ |#1| $) 15)) (-3710 (($ $ $) 19)) (-3771 (((-121) $ $) 18)) (-1946 (((-121) $ (-769)) 34)) (-4462 (($) 24) (($ (-638 |#1|)) 23)) (-2561 (($ (-1 (-121) |#1|) $) 55 (|has| $ (-6 -4602)))) (-2211 (($) 35 T CONST)) (-1643 (($ $) 58 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#1| $) 57 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 54 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 56 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 53 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 52 (|has| $ (-6 -4602)))) (-2010 (((-638 |#1|) $) 42 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 33)) (-4467 (((-638 |#1|) $) 43 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 45 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 38 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 37)) (-3524 (((-121) $ (-769)) 32)) (-1658 (((-1152) $) 9)) (-1931 (($ $ $) 22)) (-2607 (((-1116) $) 10)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 51)) (-2109 (((-121) (-1 (-121) |#1|) $) 40 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#1|) (-638 |#1|)) 49 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 48 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 47 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 (-290 |#1|))) 46 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 28)) (-4037 (((-121) $) 31)) (-1665 (($) 30)) (-3982 (($ $ $) 21) (($ $ |#1|) 20)) (-1571 (((-769) |#1| $) 44 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#1|) $) 41 (|has| $ (-6 -4602)))) (-1607 (($ $) 29)) (-4081 (((-545) $) 59 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 50)) (-3972 (((-856) $) 11)) (-1599 (($) 26) (($ (-638 |#1|)) 25)) (-3501 (((-121) (-1 (-121) |#1|) $) 39 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 6)) (-1334 (((-121) $ $) 27)) (-4032 (((-769) $) 36 (|has| $ (-6 -4602))))) 
-(((-1095 |#1|) (-1290) (-1098)) (T -1095)) 
-((-1334 (*1 *2 *1 *1) (-12 (-4 *1 (-1095 *3)) (-4 *3 (-1098)) (-5 *2 (-121)))) (-1599 (*1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) (-1599 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-1095 *3)))) (-4462 (*1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) (-4462 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-1095 *3)))) (-1931 (*1 *1 *1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) (-3982 (*1 *1 *1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) (-3982 (*1 *1 *1 *2) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) (-3710 (*1 *1 *1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) (-3771 (*1 *2 *1 *1) (-12 (-4 *1 (-1095 *3)) (-4 *3 (-1098)) (-5 *2 (-121)))) (-3518 (*1 *1 *1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) (-3518 (*1 *1 *1 *2) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) (-3518 (*1 *1 *2 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098))))) 
-(-13 (-1098) (-155 |t#1|) (-10 -8 (-6 -4592) (-15 -1334 ((-121) $ $)) (-15 -1599 ($)) (-15 -1599 ($ (-638 |t#1|))) (-15 -4462 ($)) (-15 -4462 ($ (-638 |t#1|))) (-15 -1931 ($ $ $)) (-15 -3982 ($ $ $)) (-15 -3982 ($ $ |t#1|)) (-15 -3710 ($ $ $)) (-15 -3771 ((-121) $ $)) (-15 -3518 ($ $ $)) (-15 -3518 ($ $ |t#1|)) (-15 -3518 ($ |t#1| $)))) 
-(((-39) . T) ((-105) . T) ((-612 (-856)) . T) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) . T) ((-1204) . T)) 
-((-2262 (((-121) $ $) 7)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4316 (((-923) $) 12)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-1096) (-1290)) (T -1096)) 
-((-4316 (*1 *2 *1) (-12 (-4 *1 (-1096)) (-5 *2 (-923))))) 
-(-13 (-1098) (-10 -8 (-15 -4316 ((-923) $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-1658 (((-1152) $) 10)) (-2607 (((-1116) $) 8))) 
-(((-1097 |#1|) (-10 -8 (-15 -1658 ((-1152) |#1|)) (-15 -2607 ((-1116) |#1|))) (-1098)) (T -1097)) 
-NIL 
-(-10 -8 (-15 -1658 ((-1152) |#1|)) (-15 -2607 ((-1116) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-1098) (-1290)) (T -1098)) 
-((-2607 (*1 *2 *1) (-12 (-4 *1 (-1098)) (-5 *2 (-1116)))) (-1658 (*1 *2 *1) (-12 (-4 *1 (-1098)) (-5 *2 (-1152))))) 
-(-13 (-105) (-612 (-856)) (-10 -8 (-15 -2607 ((-1116) $)) (-15 -1658 ((-1152) $)))) 
-(((-105) . T) ((-612 (-856)) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1685 (((-769)) 30)) (-1300 (($ (-638 (-923))) 52)) (-3236 (((-3 $ "failed") $ (-923) (-923)) 57)) (-3286 (($) 32)) (-3002 (((-121) (-923) $) 35)) (-3633 (((-923) $) 50)) (-1658 (((-1152) $) NIL)) (-1763 (($ (-923)) 31)) (-3688 (((-3 $ "failed") $ (-923)) 55)) (-2607 (((-1116) $) NIL)) (-3587 (((-638 $)) NIL) (((-1259 $)) 40)) (-4043 (((-638 (-923)) $) 23)) (-4363 (((-769) $ (-923) (-923)) 56)) (-3972 (((-856) $) 29)) (-1324 (((-121) $ $) 21))) 
-(((-1099 |#1| |#2|) (-13 (-374) (-10 -8 (-15 -3688 ((-3 $ "failed") $ (-923))) (-15 -3236 ((-3 $ "failed") $ (-923) (-923))) (-15 -4043 ((-638 (-923)) $)) (-15 -1300 ($ (-638 (-923)))) (-15 -3587 ((-1259 $))) (-15 -3002 ((-121) (-923) $)) (-15 -4363 ((-769) $ (-923) (-923))))) (-923) (-923)) (T -1099)) 
-((-3688 (*1 *1 *1 *2) (|partial| -12 (-5 *2 (-923)) (-5 *1 (-1099 *3 *4)) (-14 *3 *2) (-14 *4 *2))) (-3236 (*1 *1 *1 *2 *2) (|partial| -12 (-5 *2 (-923)) (-5 *1 (-1099 *3 *4)) (-14 *3 *2) (-14 *4 *2))) (-4043 (*1 *2 *1) (-12 (-5 *2 (-638 (-923))) (-5 *1 (-1099 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) (-1300 (*1 *1 *2) (-12 (-5 *2 (-638 (-923))) (-5 *1 (-1099 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) (-3587 (*1 *2) (-12 (-5 *2 (-1259 (-1099 *3 *4))) (-5 *1 (-1099 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) (-3002 (*1 *2 *3 *1) (-12 (-5 *3 (-923)) (-5 *2 (-121)) (-5 *1 (-1099 *4 *5)) (-14 *4 *3) (-14 *5 *3))) (-4363 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-769)) (-5 *1 (-1099 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
-(-13 (-374) (-10 -8 (-15 -3688 ((-3 $ "failed") $ (-923))) (-15 -3236 ((-3 $ "failed") $ (-923) (-923))) (-15 -4043 ((-638 (-923)) $)) (-15 -1300 ($ (-638 (-923)))) (-15 -3587 ((-1259 $))) (-15 -3002 ((-121) (-923) $)) (-15 -4363 ((-769) $ (-923) (-923))))) 
-((-2262 (((-121) $ $) NIL)) (-1554 (($) NIL (|has| |#1| (-374)))) (-3518 (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ $ $) 73)) (-3710 (($ $ $) 71)) (-3771 (((-121) $ $) 72)) (-1946 (((-121) $ (-769)) NIL)) (-1685 (((-769)) NIL (|has| |#1| (-374)))) (-4462 (($ (-638 |#1|)) NIL) (($) 13)) (-1550 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1544 (($ |#1| $) 67 (|has| $ (-6 -4602))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 43 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 41 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 39 (|has| $ (-6 -4602)))) (-3286 (($) NIL (|has| |#1| (-374)))) (-2010 (((-638 |#1|) $) 19 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-1771 ((|#1| $) 57 (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 66 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-4238 ((|#1| $) 55 (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 33 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 34)) (-3633 (((-923) $) NIL (|has| |#1| (-374)))) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-1931 (($ $ $) 69)) (-4221 ((|#1| $) 25)) (-1335 (($ |#1| $) 65)) (-1763 (($ (-923)) NIL (|has| |#1| (-374)))) (-2607 (((-1116) $) NIL)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 31)) (-2232 ((|#1| $) 27)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3587 (((-638 $)) NIL (|has| |#1| (-374)))) (-4037 (((-121) $) 21)) (-1665 (($) 11)) (-3982 (($ $ |#1|) NIL) (($ $ $) 70)) (-1535 (($) NIL) (($ (-638 |#1|)) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) 16)) (-4081 (((-545) $) 52 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 61)) (-3563 (($ $) NIL (|has| |#1| (-374)))) (-3972 (((-856) $) NIL)) (-1961 (((-769) $) NIL)) (-1599 (($ (-638 |#1|)) NIL) (($) 12)) (-3058 (($ (-638 |#1|)) NIL)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 54)) (-1334 (((-121) $ $) NIL)) (-4032 (((-769) $) 10 (|has| $ (-6 -4602))))) 
-(((-1100 |#1|) (-431 |#1|) (-1098)) (T -1100)) 
-NIL 
-(-431 |#1|) 
-((-2262 (((-121) $ $) 7)) (-2150 (((-121) $) 31)) (-4154 ((|#2| $) 26)) (-3032 (((-121) $) 32)) (-4035 ((|#1| $) 27)) (-3330 (((-121) $) 34)) (-4270 (((-121) $) 36)) (-3664 (((-121) $) 33)) (-1658 (((-1152) $) 9)) (-2814 (((-121) $) 30)) (-4012 ((|#3| $) 25)) (-2607 (((-1116) $) 10)) (-2661 (((-121) $) 29)) (-3997 ((|#4| $) 24)) (-1793 ((|#5| $) 23)) (-2352 (((-121) $ $) 37)) (-3277 (($ $ (-572)) 13) (($ $ (-638 (-572))) 12)) (-4323 (((-638 $) $) 28)) (-4081 (($ (-638 $)) 22) (($ |#1|) 21) (($ |#2|) 20) (($ |#3|) 19) (($ |#4|) 18) (($ |#5|) 17)) (-3972 (((-856) $) 11)) (-3856 (($ $) 15)) (-3849 (($ $) 16)) (-2332 (((-121) $) 35)) (-1324 (((-121) $ $) 6)) (-4032 (((-572) $) 14))) 
-(((-1101 |#1| |#2| |#3| |#4| |#5|) (-1290) (-1098) (-1098) (-1098) (-1098) (-1098)) (T -1101)) 
-((-2352 (*1 *2 *1 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-4270 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-2332 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-3330 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-3664 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-3032 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-2150 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-2814 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-2661 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121)))) (-4323 (*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-638 *1)) (-4 *1 (-1101 *3 *4 *5 *6 *7)))) (-4035 (*1 *2 *1) (-12 (-4 *1 (-1101 *2 *3 *4 *5 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)))) (-4154 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *2 *4 *5 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)))) (-4012 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *2 *5 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)))) (-3997 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *2 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)))) (-1793 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *2)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)))) (-4081 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)))) (-4081 (*1 *1 *2) (-12 (-4 *1 (-1101 *2 *3 *4 *5 *6)) (-4 *2 (-1098)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)))) (-4081 (*1 *1 *2) (-12 (-4 *1 (-1101 *3 *2 *4 *5 *6)) (-4 *3 (-1098)) (-4 *2 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)))) (-4081 (*1 *1 *2) (-12 (-4 *1 (-1101 *3 *4 *2 *5 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *2 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)))) (-4081 (*1 *1 *2) (-12 (-4 *1 (-1101 *3 *4 *5 *2 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *2 (-1098)) (-4 *6 (-1098)))) (-4081 (*1 *1 *2) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *2)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)))) (-3849 (*1 *1 *1) (-12 (-4 *1 (-1101 *2 *3 *4 *5 *6)) (-4 *2 (-1098)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)))) (-3856 (*1 *1 *1) (-12 (-4 *1 (-1101 *2 *3 *4 *5 *6)) (-4 *2 (-1098)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)))) (-4032 (*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-572)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098))))) 
-(-13 (-1098) (-10 -8 (-15 -2352 ((-121) $ $)) (-15 -4270 ((-121) $)) (-15 -2332 ((-121) $)) (-15 -3330 ((-121) $)) (-15 -3664 ((-121) $)) (-15 -3032 ((-121) $)) (-15 -2150 ((-121) $)) (-15 -2814 ((-121) $)) (-15 -2661 ((-121) $)) (-15 -4323 ((-638 $) $)) (-15 -4035 (|t#1| $)) (-15 -4154 (|t#2| $)) (-15 -4012 (|t#3| $)) (-15 -3997 (|t#4| $)) (-15 -1793 (|t#5| $)) (-15 -4081 ($ (-638 $))) (-15 -4081 ($ |t#1|)) (-15 -4081 ($ |t#2|)) (-15 -4081 ($ |t#3|)) (-15 -4081 ($ |t#4|)) (-15 -4081 ($ |t#5|)) (-15 -3849 ($ $)) (-15 -3856 ($ $)) (-15 -4032 ((-572) $)) (-15 -3277 ($ $ (-572))) (-15 -3277 ($ $ (-638 (-572)))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-2150 (((-121) $) NIL)) (-4154 (((-1170) $) NIL)) (-3032 (((-121) $) NIL)) (-4035 (((-1152) $) NIL)) (-3330 (((-121) $) NIL)) (-4270 (((-121) $) NIL)) (-3664 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-2814 (((-121) $) NIL)) (-4012 (((-572) $) NIL)) (-2607 (((-1116) $) NIL)) (-2661 (((-121) $) NIL)) (-3997 (((-217) $) NIL)) (-1793 (((-856) $) NIL)) (-2352 (((-121) $ $) NIL)) (-3277 (($ $ (-572)) NIL) (($ $ (-638 (-572))) NIL)) (-4323 (((-638 $) $) NIL)) (-4081 (($ (-638 $)) NIL) (($ (-1152)) NIL) (($ (-1170)) NIL) (($ (-572)) NIL) (($ (-217)) NIL) (($ (-856)) NIL)) (-3972 (((-856) $) NIL)) (-3856 (($ $) NIL)) (-3849 (($ $) NIL)) (-2332 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL)) (-4032 (((-572) $) NIL))) 
-(((-1102) (-1101 (-1152) (-1170) (-572) (-217) (-856))) (T -1102)) 
-NIL 
-(-1101 (-1152) (-1170) (-572) (-217) (-856)) 
-((-2262 (((-121) $ $) NIL)) (-2150 (((-121) $) 37)) (-4154 ((|#2| $) 41)) (-3032 (((-121) $) 36)) (-4035 ((|#1| $) 40)) (-3330 (((-121) $) 34)) (-4270 (((-121) $) 14)) (-3664 (((-121) $) 35)) (-1658 (((-1152) $) NIL)) (-2814 (((-121) $) 38)) (-4012 ((|#3| $) 43)) (-2607 (((-1116) $) NIL)) (-2661 (((-121) $) 39)) (-3997 ((|#4| $) 42)) (-1793 ((|#5| $) 44)) (-2352 (((-121) $ $) 33)) (-3277 (($ $ (-572)) 55) (($ $ (-638 (-572))) 57)) (-4323 (((-638 $) $) 21)) (-4081 (($ (-638 $)) 45) (($ |#1|) 46) (($ |#2|) 47) (($ |#3|) 48) (($ |#4|) 49) (($ |#5|) 50)) (-3972 (((-856) $) 22)) (-3856 (($ $) 20)) (-3849 (($ $) 51)) (-2332 (((-121) $) 18)) (-1324 (((-121) $ $) 32)) (-4032 (((-572) $) 53))) 
-(((-1103 |#1| |#2| |#3| |#4| |#5|) (-1101 |#1| |#2| |#3| |#4| |#5|) (-1098) (-1098) (-1098) (-1098) (-1098)) (T -1103)) 
-NIL 
-(-1101 |#1| |#2| |#3| |#4| |#5|) 
-((-4355 (((-1264) $) 23)) (-1950 (($ (-1170) (-440) |#2|) 11)) (-3972 (((-856) $) 16))) 
-(((-1104 |#1| |#2|) (-13 (-401) (-10 -8 (-15 -1950 ($ (-1170) (-440) |#2|)))) (-848) (-436 |#1|)) (T -1104)) 
-((-1950 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-440)) (-4 *5 (-848)) (-5 *1 (-1104 *5 *4)) (-4 *4 (-436 *5))))) 
-(-13 (-401) (-10 -8 (-15 -1950 ($ (-1170) (-440) |#2|)))) 
-((-1382 (((-121) |#5| |#5|) 37)) (-2204 (((-121) |#5| |#5|) 51)) (-1776 (((-121) |#5| (-638 |#5|)) 74) (((-121) |#5| |#5|) 60)) (-1611 (((-121) (-638 |#4|) (-638 |#4|)) 57)) (-2331 (((-121) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) 62)) (-2344 (((-1264)) 33)) (-1735 (((-1264) (-1152) (-1152) (-1152)) 29)) (-2219 (((-638 |#5|) (-638 |#5|)) 81)) (-4552 (((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) 79)) (-3474 (((-638 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|)))) (-638 |#4|) (-638 |#5|) (-121) (-121)) 101)) (-2927 (((-121) |#5| |#5|) 46)) (-4024 (((-3 (-121) "failed") |#5| |#5|) 70)) (-2825 (((-121) (-638 |#4|) (-638 |#4|)) 56)) (-3999 (((-121) (-638 |#4|) (-638 |#4|)) 58)) (-1843 (((-121) (-638 |#4|) (-638 |#4|)) 59)) (-1589 (((-3 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|))) "failed") (-638 |#4|) |#5| (-638 |#4|) (-121) (-121) (-121) (-121) (-121)) 97)) (-2300 (((-638 |#5|) (-638 |#5|)) 42))) 
-(((-1105 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1735 ((-1264) (-1152) (-1152) (-1152))) (-15 -2344 ((-1264))) (-15 -1382 ((-121) |#5| |#5|)) (-15 -2300 ((-638 |#5|) (-638 |#5|))) (-15 -2927 ((-121) |#5| |#5|)) (-15 -2204 ((-121) |#5| |#5|)) (-15 -1611 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -2825 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -3999 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -1843 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -4024 ((-3 (-121) "failed") |#5| |#5|)) (-15 -1776 ((-121) |#5| |#5|)) (-15 -1776 ((-121) |#5| (-638 |#5|))) (-15 -2219 ((-638 |#5|) (-638 |#5|))) (-15 -2331 ((-121) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) (-15 -4552 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-15 -3474 ((-638 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|)))) (-638 |#4|) (-638 |#5|) (-121) (-121))) (-15 -1589 ((-3 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|))) "failed") (-638 |#4|) |#5| (-638 |#4|) (-121) (-121) (-121) (-121) (-121)))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1073 |#1| |#2| |#3| |#4|)) (T -1105)) 
-((-1589 (*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| -2352 (-638 *9)) (|:| -1337 *4) (|:| |ineq| (-638 *9)))) (-5 *1 (-1105 *6 *7 *8 *9 *4)) (-5 *3 (-638 *9)) (-4 *4 (-1073 *6 *7 *8 *9)))) (-3474 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-638 *10)) (-5 *5 (-121)) (-4 *10 (-1073 *6 *7 *8 *9)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-1068 *6 *7 *8)) (-5 *2 (-638 (-2 (|:| -2352 (-638 *9)) (|:| -1337 *10) (|:| |ineq| (-638 *9))))) (-5 *1 (-1105 *6 *7 *8 *9 *10)) (-5 *3 (-638 *9)))) (-4552 (*1 *2 *2) (-12 (-5 *2 (-638 (-2 (|:| |val| (-638 *6)) (|:| -1337 *7)))) (-4 *6 (-1068 *3 *4 *5)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1105 *3 *4 *5 *6 *7)))) (-2331 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-638 *7)) (|:| -1337 *8))) (-4 *7 (-1068 *4 *5 *6)) (-4 *8 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)))) (-2219 (*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-1105 *3 *4 *5 *6 *7)))) (-1776 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1105 *5 *6 *7 *8 *3)))) (-1776 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-4024 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-1843 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-3999 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-2825 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-1611 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-2204 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-2927 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-2300 (*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-1105 *3 *4 *5 *6 *7)))) (-1382 (*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) (-2344 (*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1105 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) (-1735 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -1735 ((-1264) (-1152) (-1152) (-1152))) (-15 -2344 ((-1264))) (-15 -1382 ((-121) |#5| |#5|)) (-15 -2300 ((-638 |#5|) (-638 |#5|))) (-15 -2927 ((-121) |#5| |#5|)) (-15 -2204 ((-121) |#5| |#5|)) (-15 -1611 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -2825 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -3999 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -1843 ((-121) (-638 |#4|) (-638 |#4|))) (-15 -4024 ((-3 (-121) "failed") |#5| |#5|)) (-15 -1776 ((-121) |#5| |#5|)) (-15 -1776 ((-121) |#5| (-638 |#5|))) (-15 -2219 ((-638 |#5|) (-638 |#5|))) (-15 -2331 ((-121) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) (-15 -4552 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-15 -3474 ((-638 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|)))) (-638 |#4|) (-638 |#5|) (-121) (-121))) (-15 -1589 ((-3 (-2 (|:| -2352 (-638 |#4|)) (|:| -1337 |#5|) (|:| |ineq| (-638 |#4|))) "failed") (-638 |#4|) |#5| (-638 |#4|) (-121) (-121) (-121) (-121) (-121)))) 
-((-2398 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|) 94)) (-2785 (((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#4| |#4| |#5|) 70)) (-1678 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|) 88)) (-2094 (((-638 |#5|) |#4| |#5|) 109)) (-3911 (((-638 |#5|) |#4| |#5|) 116)) (-1427 (((-638 |#5|) |#4| |#5|) 117)) (-2136 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|) 95)) (-4510 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|) 115)) (-3202 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|) 44) (((-121) |#4| |#5|) 52)) (-4330 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#3| (-121)) 82) (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5| (-121) (-121)) 49)) (-2865 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|) 77)) (-2672 (((-1264)) 35)) (-1811 (((-1264)) 25)) (-4424 (((-1264) (-1152) (-1152) (-1152)) 31)) (-3553 (((-1264) (-1152) (-1152) (-1152)) 20))) 
-(((-1106 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3553 ((-1264) (-1152) (-1152) (-1152))) (-15 -1811 ((-1264))) (-15 -4424 ((-1264) (-1152) (-1152) (-1152))) (-15 -2672 ((-1264))) (-15 -2785 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -4330 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -4330 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#3| (-121))) (-15 -2865 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -1678 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -3202 ((-121) |#4| |#5|)) (-15 -2136 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -2094 ((-638 |#5|) |#4| |#5|)) (-15 -4510 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -3911 ((-638 |#5|) |#4| |#5|)) (-15 -3202 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -1427 ((-638 |#5|) |#4| |#5|)) (-15 -2398 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1073 |#1| |#2| |#3| |#4|)) (T -1106)) 
-((-2398 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-1427 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 *4)) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-3202 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-3911 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 *4)) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-4510 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-2094 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 *4)) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-2136 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-3202 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-1678 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-2865 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-4330 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-2 (|:| |val| (-638 *8)) (|:| -1337 *9)))) (-5 *5 (-121)) (-4 *8 (-1068 *6 *7 *4)) (-4 *9 (-1073 *6 *7 *4 *8)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *4 (-848)) (-5 *2 (-638 (-2 (|:| |val| *8) (|:| -1337 *9)))) (-5 *1 (-1106 *6 *7 *4 *8 *9)))) (-4330 (*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1106 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) (-2785 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) (-2672 (*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1106 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) (-4424 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1106 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) (-1811 (*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1106 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) (-3553 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1106 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -3553 ((-1264) (-1152) (-1152) (-1152))) (-15 -1811 ((-1264))) (-15 -4424 ((-1264) (-1152) (-1152) (-1152))) (-15 -2672 ((-1264))) (-15 -2785 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -4330 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -4330 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) |#3| (-121))) (-15 -2865 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -1678 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#4| |#5|)) (-15 -3202 ((-121) |#4| |#5|)) (-15 -2136 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -2094 ((-638 |#5|) |#4| |#5|)) (-15 -4510 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -3911 ((-638 |#5|) |#4| |#5|)) (-15 -3202 ((-638 (-2 (|:| |val| (-121)) (|:| -1337 |#5|))) |#4| |#5|)) (-15 -1427 ((-638 |#5|) |#4| |#5|)) (-15 -2398 ((-638 (-2 (|:| |val| |#4|) (|:| -1337 |#5|))) |#4| |#5|))) 
-((-2262 (((-121) $ $) 7)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) 78)) (-4165 (((-638 $) (-638 |#4|)) 79) (((-638 $) (-638 |#4|) (-121)) 104)) (-3456 (((-638 |#3|) $) 32)) (-3049 (((-121) $) 25)) (-3289 (((-121) $) 16 (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) 94) (((-121) $) 90)) (-1872 ((|#4| |#4| $) 85)) (-2844 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| $) 119)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) 26)) (-1946 (((-121) $ (-769)) 43)) (-2561 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) 72)) (-2211 (($) 44 T CONST)) (-3097 (((-121) $) 21 (|has| |#1| (-562)))) (-3760 (((-121) $ $) 23 (|has| |#1| (-562)))) (-3819 (((-121) $ $) 22 (|has| |#1| (-562)))) (-4331 (((-121) $) 24 (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3683 (((-638 |#4|) (-638 |#4|) $) 17 (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) 18 (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) 35)) (-1318 (($ (-638 |#4|)) 34)) (-1651 (((-3 $ "failed") $) 75)) (-2242 ((|#4| |#4| $) 82)) (-1643 (($ $) 67 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#4| $) 66 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-1673 ((|#4| |#4| $) 80)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) 98)) (-1706 (((-121) |#4| $) 129)) (-2989 (((-121) |#4| $) 126)) (-1366 (((-121) |#4| $) 130) (((-121) $) 127)) (-2010 (((-638 |#4|) $) 51 (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) 97) (((-121) $) 96)) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) 42)) (-4467 (((-638 |#4|) $) 52 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 46)) (-4062 (((-638 |#3|) $) 31)) (-1346 (((-121) |#3| $) 30)) (-3524 (((-121) $ (-769)) 41)) (-1658 (((-1152) $) 9)) (-2550 (((-3 |#4| (-638 $)) |#4| |#4| $) 121)) (-4416 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| |#4| $) 120)) (-3253 (((-3 |#4| "failed") $) 76)) (-2173 (((-638 $) |#4| $) 122)) (-2471 (((-3 (-121) (-638 $)) |#4| $) 125)) (-2338 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-1931 (((-638 $) |#4| $) 118) (((-638 $) (-638 |#4|) $) 117) (((-638 $) (-638 |#4|) (-638 $)) 116) (((-638 $) |#4| (-638 $)) 115)) (-3078 (($ |#4| $) 110) (($ (-638 |#4|) $) 109)) (-3727 (((-638 |#4|) $) 100)) (-1483 (((-121) |#4| $) 92) (((-121) $) 88)) (-2788 ((|#4| |#4| $) 83)) (-1843 (((-121) $ $) 103)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) 93) (((-121) $) 89)) (-4498 ((|#4| |#4| $) 84)) (-2607 (((-1116) $) 10)) (-1837 (((-3 |#4| "failed") $) 77)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1928 (((-3 $ "failed") $ |#4|) 71)) (-1977 (($ $ |#4|) 70) (((-638 $) |#4| $) 108) (((-638 $) |#4| (-638 $)) 107) (((-638 $) (-638 |#4|) $) 106) (((-638 $) (-638 |#4|) (-638 $)) 105)) (-2109 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) 58 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) 56 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) 55 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) 37)) (-4037 (((-121) $) 40)) (-1665 (($) 39)) (-4316 (((-769) $) 99)) (-1571 (((-769) |#4| $) 53 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4602)))) (-1607 (($ $) 38)) (-4081 (((-545) $) 68 (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 59)) (-1826 (($ $ |#3|) 27)) (-2291 (($ $ |#3|) 29)) (-3134 (($ $) 81)) (-1650 (($ $ |#3|) 28)) (-3972 (((-856) $) 11) (((-638 |#4|) $) 36)) (-2498 (((-769) $) 69 (|has| |#3| (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) 91)) (-2589 (((-638 $) |#4| $) 114) (((-638 $) |#4| (-638 $)) 113) (((-638 $) (-638 |#4|) $) 112) (((-638 $) (-638 |#4|) (-638 $)) 111)) (-3501 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) 74)) (-4191 (((-121) |#4| $) 128)) (-2213 (((-121) |#3| $) 73)) (-1324 (((-121) $ $) 6)) (-4032 (((-769) $) 45 (|has| $ (-6 -4602))))) 
-(((-1107 |#1| |#2| |#3| |#4|) (-1290) (-457) (-794) (-848) (-1068 |t#1| |t#2| |t#3|)) (T -1107)) 
-NIL 
-(-13 (-1073 |t#1| |t#2| |t#3| |t#4|)) 
-(((-39) . T) ((-105) . T) ((-612 (-638 |#4|)) . T) ((-612 (-856)) . T) ((-155 |#4|) . T) ((-613 (-545)) |has| |#4| (-613 (-545))) ((-305 |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-503 |#4|) . T) ((-527 |#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-984 |#1| |#2| |#3| |#4|) . T) ((-1073 |#1| |#2| |#3| |#4|) . T) ((-1098) . T) ((-1198 |#1| |#2| |#3| |#4|) . T) ((-1204) . T)) 
-((-2894 (((-638 (-572)) (-572) (-572) (-572)) 20)) (-1530 (((-638 (-572)) (-572) (-572) (-572)) 12)) (-1475 (((-638 (-572)) (-572) (-572) (-572)) 16)) (-4371 (((-572) (-572) (-572)) 9)) (-3189 (((-1259 (-572)) (-638 (-572)) (-1259 (-572)) (-572)) 44) (((-1259 (-572)) (-1259 (-572)) (-1259 (-572)) (-572)) 39)) (-3592 (((-638 (-572)) (-638 (-572)) (-638 (-572)) (-121)) 26)) (-1821 (((-685 (-572)) (-638 (-572)) (-638 (-572)) (-685 (-572))) 43)) (-4025 (((-685 (-572)) (-638 (-572)) (-638 (-572))) 31)) (-3635 (((-638 (-685 (-572))) (-638 (-572))) 33)) (-2997 (((-638 (-572)) (-638 (-572)) (-638 (-572)) (-685 (-572))) 46)) (-3393 (((-685 (-572)) (-638 (-572)) (-638 (-572)) (-638 (-572))) 54))) 
-(((-1108) (-10 -7 (-15 -3393 ((-685 (-572)) (-638 (-572)) (-638 (-572)) (-638 (-572)))) (-15 -2997 ((-638 (-572)) (-638 (-572)) (-638 (-572)) (-685 (-572)))) (-15 -3635 ((-638 (-685 (-572))) (-638 (-572)))) (-15 -4025 ((-685 (-572)) (-638 (-572)) (-638 (-572)))) (-15 -1821 ((-685 (-572)) (-638 (-572)) (-638 (-572)) (-685 (-572)))) (-15 -3592 ((-638 (-572)) (-638 (-572)) (-638 (-572)) (-121))) (-15 -3189 ((-1259 (-572)) (-1259 (-572)) (-1259 (-572)) (-572))) (-15 -3189 ((-1259 (-572)) (-638 (-572)) (-1259 (-572)) (-572))) (-15 -4371 ((-572) (-572) (-572))) (-15 -1475 ((-638 (-572)) (-572) (-572) (-572))) (-15 -1530 ((-638 (-572)) (-572) (-572) (-572))) (-15 -2894 ((-638 (-572)) (-572) (-572) (-572))))) (T -1108)) 
-((-2894 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1108)) (-5 *3 (-572)))) (-1530 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1108)) (-5 *3 (-572)))) (-1475 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1108)) (-5 *3 (-572)))) (-4371 (*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1108)))) (-3189 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-1259 (-572))) (-5 *3 (-638 (-572))) (-5 *4 (-572)) (-5 *1 (-1108)))) (-3189 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-1259 (-572))) (-5 *3 (-572)) (-5 *1 (-1108)))) (-3592 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-638 (-572))) (-5 *3 (-121)) (-5 *1 (-1108)))) (-1821 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-685 (-572))) (-5 *3 (-638 (-572))) (-5 *1 (-1108)))) (-4025 (*1 *2 *3 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-685 (-572))) (-5 *1 (-1108)))) (-3635 (*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-638 (-685 (-572)))) (-5 *1 (-1108)))) (-2997 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-638 (-572))) (-5 *3 (-685 (-572))) (-5 *1 (-1108)))) (-3393 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-685 (-572))) (-5 *1 (-1108))))) 
-(-10 -7 (-15 -3393 ((-685 (-572)) (-638 (-572)) (-638 (-572)) (-638 (-572)))) (-15 -2997 ((-638 (-572)) (-638 (-572)) (-638 (-572)) (-685 (-572)))) (-15 -3635 ((-638 (-685 (-572))) (-638 (-572)))) (-15 -4025 ((-685 (-572)) (-638 (-572)) (-638 (-572)))) (-15 -1821 ((-685 (-572)) (-638 (-572)) (-638 (-572)) (-685 (-572)))) (-15 -3592 ((-638 (-572)) (-638 (-572)) (-638 (-572)) (-121))) (-15 -3189 ((-1259 (-572)) (-1259 (-572)) (-1259 (-572)) (-572))) (-15 -3189 ((-1259 (-572)) (-638 (-572)) (-1259 (-572)) (-572))) (-15 -4371 ((-572) (-572) (-572))) (-15 -1475 ((-638 (-572)) (-572) (-572) (-572))) (-15 -1530 ((-638 (-572)) (-572) (-572) (-572))) (-15 -2894 ((-638 (-572)) (-572) (-572) (-572)))) 
-((-4174 (($ $ (-923)) 12)) (** (($ $ (-923)) 10))) 
-(((-1109 |#1|) (-10 -8 (-15 -4174 (|#1| |#1| (-923))) (-15 ** (|#1| |#1| (-923)))) (-1110)) (T -1109)) 
-NIL 
-(-10 -8 (-15 -4174 (|#1| |#1| (-923))) (-15 ** (|#1| |#1| (-923)))) 
-((-2262 (((-121) $ $) 7)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-4174 (($ $ (-923)) 12)) (-1324 (((-121) $ $) 6)) (** (($ $ (-923)) 13)) (* (($ $ $) 14))) 
-(((-1110) (-1290)) (T -1110)) 
-((* (*1 *1 *1 *1) (-4 *1 (-1110))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-1110)) (-5 *2 (-923)))) (-4174 (*1 *1 *1 *2) (-12 (-4 *1 (-1110)) (-5 *2 (-923))))) 
-(-13 (-1098) (-10 -8 (-15 * ($ $ $)) (-15 ** ($ $ (-923))) (-15 -4174 ($ $ (-923))))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#3| (-1098)))) (-1342 (((-121) $) NIL (|has| |#3| (-138)))) (-3421 (($ (-923)) NIL (|has| |#3| (-1054)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-1614 (($ $ $) NIL (|has| |#3| (-794)))) (-1572 (((-3 $ "failed") $ $) NIL (|has| |#3| (-138)))) (-1946 (((-121) $ (-769)) NIL)) (-1685 (((-769)) NIL (|has| |#3| (-374)))) (-2433 (((-572) $) NIL (|has| |#3| (-846)))) (-3283 ((|#3| $ (-572) |#3|) NIL (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (-12 (|has| |#3| (-1044 (-572))) (|has| |#3| (-1098)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| |#3| (-1044 (-413 (-572)))) (|has| |#3| (-1098)))) (((-3 |#3| "failed") $) NIL (|has| |#3| (-1098)))) (-1318 (((-572) $) NIL (-12 (|has| |#3| (-1044 (-572))) (|has| |#3| (-1098)))) (((-413 (-572)) $) NIL (-12 (|has| |#3| (-1044 (-413 (-572)))) (|has| |#3| (-1098)))) ((|#3| $) NIL (|has| |#3| (-1098)))) (-2284 (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#3| (-634 (-572))) (|has| |#3| (-1054)))) (((-2 (|:| -1369 (-685 |#3|)) (|:| |vec| (-1259 |#3|))) (-685 $) (-1259 $)) NIL (|has| |#3| (-1054))) (((-685 |#3|) (-685 $)) NIL (|has| |#3| (-1054)))) (-1799 (((-3 $ "failed") $) NIL (|has| |#3| (-722)))) (-3286 (($) NIL (|has| |#3| (-374)))) (-3037 ((|#3| $ (-572) |#3|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#3| $ (-572)) 12)) (-1908 (((-121) $) NIL (|has| |#3| (-846)))) (-2010 (((-638 |#3|) $) NIL (|has| $ (-6 -4602)))) (-3893 (((-121) $) NIL (|has| |#3| (-722)))) (-4472 (((-121) $) NIL (|has| |#3| (-846)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-4467 (((-638 |#3|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#3| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-2435 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#3| |#3|) $) NIL)) (-3633 (((-923) $) NIL (|has| |#3| (-374)))) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#3| (-1098)))) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-1763 (($ (-923)) NIL (|has| |#3| (-374)))) (-2607 (((-1116) $) NIL (|has| |#3| (-1098)))) (-1837 ((|#3| $) NIL (|has| (-572) (-848)))) (-3299 (($ $ |#3|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#3|))) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ (-290 |#3|)) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098)))) (($ $ (-638 |#3|) (-638 |#3|)) NIL (-12 (|has| |#3| (-305 |#3|)) (|has| |#3| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3587 (((-638 $)) NIL (|has| |#3| (-374)))) (-3167 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#3| (-1098))))) (-2957 (((-638 |#3|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#3| $ (-572) |#3|) NIL) ((|#3| $ (-572)) NIL)) (-1436 ((|#3| $ $) NIL (|has| |#3| (-1054)))) (-4315 (($ (-1259 |#3|)) NIL)) (-2502 (((-140)) NIL (|has| |#3| (-368)))) (-3139 (($ $) NIL (-12 (|has| |#3| (-227)) (|has| |#3| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#3| (-227)) (|has| |#3| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-1 |#3| |#3|) (-769)) NIL (|has| |#3| (-1054))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1054)))) (-1571 (((-769) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602))) (((-769) |#3| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#3| (-1098))))) (-1607 (($ $) NIL)) (-3972 (((-1259 |#3|) $) NIL) (((-856) $) NIL (|has| |#3| (-1098))) (($ (-572)) NIL (-1841 (-12 (|has| |#3| (-1044 (-572))) (|has| |#3| (-1098))) (|has| |#3| (-1054)))) (($ (-413 (-572))) NIL (-12 (|has| |#3| (-1044 (-413 (-572)))) (|has| |#3| (-1098)))) (($ |#3|) NIL (|has| |#3| (-1098)))) (-2140 (((-769)) NIL (|has| |#3| (-1054)))) (-3501 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4602)))) (-2264 (($ $) NIL (|has| |#3| (-846)))) (-4174 (($ $ (-769)) NIL (|has| |#3| (-722))) (($ $ (-923)) NIL (|has| |#3| (-722)))) (-2378 (($) NIL (|has| |#3| (-138)) CONST)) (-3255 (($) NIL (|has| |#3| (-722)) CONST)) (-1557 (($ $) NIL (-12 (|has| |#3| (-227)) (|has| |#3| (-1054)))) (($ $ (-769)) NIL (-12 (|has| |#3| (-227)) (|has| |#3| (-1054)))) (($ $ (-1170)) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#3| (-901 (-1170))) (|has| |#3| (-1054)))) (($ $ (-1 |#3| |#3|) (-769)) NIL (|has| |#3| (-1054))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1054)))) (-1349 (((-121) $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-1338 (((-121) $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-1324 (((-121) $ $) NIL (|has| |#3| (-1098)))) (-1343 (((-121) $ $) NIL (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-1334 (((-121) $ $) 17 (-1841 (|has| |#3| (-794)) (|has| |#3| (-846))))) (-1379 (($ $ |#3|) NIL (|has| |#3| (-368)))) (-1373 (($ $ $) NIL (|has| |#3| (-1054))) (($ $) NIL (|has| |#3| (-1054)))) (-1367 (($ $ $) NIL (|has| |#3| (-25)))) (** (($ $ (-769)) NIL (|has| |#3| (-722))) (($ $ (-923)) NIL (|has| |#3| (-722)))) (* (($ (-572) $) NIL (|has| |#3| (-1054))) (($ $ $) NIL (|has| |#3| (-722))) (($ $ |#3|) NIL (|has| |#3| (-722))) (($ |#3| $) NIL (|has| |#3| (-722))) (($ (-769) $) NIL (|has| |#3| (-138))) (($ (-923) $) NIL (|has| |#3| (-25)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1111 |#1| |#2| |#3|) (-232 |#1| |#3|) (-769) (-769) (-794)) (T -1111)) 
-NIL 
-(-232 |#1| |#3|) 
-((-1372 (((-638 (-1231 |#2| |#1|)) (-1231 |#2| |#1|) (-1231 |#2| |#1|)) 36)) (-2255 (((-572) (-1231 |#2| |#1|)) 67 (|has| |#1| (-457)))) (-2103 (((-572) (-1231 |#2| |#1|)) 53)) (-1472 (((-638 (-1231 |#2| |#1|)) (-1231 |#2| |#1|) (-1231 |#2| |#1|)) 44)) (-4256 (((-572) (-1231 |#2| |#1|) (-1231 |#2| |#1|)) 55 (|has| |#1| (-457)))) (-1552 (((-638 |#1|) (-1231 |#2| |#1|) (-1231 |#2| |#1|)) 47)) (-1860 (((-572) (-1231 |#2| |#1|) (-1231 |#2| |#1|)) 52))) 
-(((-1112 |#1| |#2|) (-10 -7 (-15 -1372 ((-638 (-1231 |#2| |#1|)) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -1472 ((-638 (-1231 |#2| |#1|)) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -1552 ((-638 |#1|) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -1860 ((-572) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -2103 ((-572) (-1231 |#2| |#1|))) (IF (|has| |#1| (-457)) (PROGN (-15 -4256 ((-572) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -2255 ((-572) (-1231 |#2| |#1|)))) |noBranch|)) (-821) (-1170)) (T -1112)) 
-((-2255 (*1 *2 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-457)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-572)) (-5 *1 (-1112 *4 *5)))) (-4256 (*1 *2 *3 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-457)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-572)) (-5 *1 (-1112 *4 *5)))) (-2103 (*1 *2 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-572)) (-5 *1 (-1112 *4 *5)))) (-1860 (*1 *2 *3 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-572)) (-5 *1 (-1112 *4 *5)))) (-1552 (*1 *2 *3 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-638 *4)) (-5 *1 (-1112 *4 *5)))) (-1472 (*1 *2 *3 *3) (-12 (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-638 (-1231 *5 *4))) (-5 *1 (-1112 *4 *5)) (-5 *3 (-1231 *5 *4)))) (-1372 (*1 *2 *3 *3) (-12 (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-638 (-1231 *5 *4))) (-5 *1 (-1112 *4 *5)) (-5 *3 (-1231 *5 *4))))) 
-(-10 -7 (-15 -1372 ((-638 (-1231 |#2| |#1|)) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -1472 ((-638 (-1231 |#2| |#1|)) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -1552 ((-638 |#1|) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -1860 ((-572) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -2103 ((-572) (-1231 |#2| |#1|))) (IF (|has| |#1| (-457)) (PROGN (-15 -4256 ((-572) (-1231 |#2| |#1|) (-1231 |#2| |#1|))) (-15 -2255 ((-572) (-1231 |#2| |#1|)))) |noBranch|)) 
-((-2433 (((-3 (-572) "failed") |#2| (-1170) |#2| (-1152)) 16) (((-3 (-572) "failed") |#2| (-1170) (-841 |#2|)) 14) (((-3 (-572) "failed") |#2|) 51))) 
-(((-1113 |#1| |#2|) (-10 -7 (-15 -2433 ((-3 (-572) "failed") |#2|)) (-15 -2433 ((-3 (-572) "failed") |#2| (-1170) (-841 |#2|))) (-15 -2433 ((-3 (-572) "failed") |#2| (-1170) |#2| (-1152)))) (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)) (-457)) (-13 (-27) (-1190) (-436 |#1|))) (T -1113)) 
-((-2433 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-1152)) (-4 *6 (-13 (-562) (-848) (-1044 *2) (-634 *2) (-457))) (-5 *2 (-572)) (-5 *1 (-1113 *6 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))))) (-2433 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-841 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 *2) (-634 *2) (-457))) (-5 *2 (-572)) (-5 *1 (-1113 *6 *3)))) (-2433 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-562) (-848) (-1044 *2) (-634 *2) (-457))) (-5 *2 (-572)) (-5 *1 (-1113 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4)))))) 
-(-10 -7 (-15 -2433 ((-3 (-572) "failed") |#2|)) (-15 -2433 ((-3 (-572) "failed") |#2| (-1170) (-841 |#2|))) (-15 -2433 ((-3 (-572) "failed") |#2| (-1170) |#2| (-1152)))) 
-((-2433 (((-3 (-572) "failed") (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|)) (-1152)) 34) (((-3 (-572) "failed") (-413 (-959 |#1|)) (-1170) (-841 (-413 (-959 |#1|)))) 29) (((-3 (-572) "failed") (-413 (-959 |#1|))) 12))) 
-(((-1114 |#1|) (-10 -7 (-15 -2433 ((-3 (-572) "failed") (-413 (-959 |#1|)))) (-15 -2433 ((-3 (-572) "failed") (-413 (-959 |#1|)) (-1170) (-841 (-413 (-959 |#1|))))) (-15 -2433 ((-3 (-572) "failed") (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|)) (-1152)))) (-457)) (T -1114)) 
-((-2433 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-413 (-959 *6))) (-5 *4 (-1170)) (-5 *5 (-1152)) (-4 *6 (-457)) (-5 *2 (-572)) (-5 *1 (-1114 *6)))) (-2433 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-841 (-413 (-959 *6)))) (-5 *3 (-413 (-959 *6))) (-4 *6 (-457)) (-5 *2 (-572)) (-5 *1 (-1114 *6)))) (-2433 (*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-457)) (-5 *2 (-572)) (-5 *1 (-1114 *4))))) 
-(-10 -7 (-15 -2433 ((-3 (-572) "failed") (-413 (-959 |#1|)))) (-15 -2433 ((-3 (-572) "failed") (-413 (-959 |#1|)) (-1170) (-841 (-413 (-959 |#1|))))) (-15 -2433 ((-3 (-572) "failed") (-413 (-959 |#1|)) (-1170) (-413 (-959 |#1|)) (-1152)))) 
-((-3925 (((-312 (-572)) (-53)) 11))) 
-(((-1115) (-10 -7 (-15 -3925 ((-312 (-572)) (-53))))) (T -1115)) 
-((-3925 (*1 *2 *3) (-12 (-5 *3 (-53)) (-5 *2 (-312 (-572))) (-5 *1 (-1115))))) 
-(-10 -7 (-15 -3925 ((-312 (-572)) (-53)))) 
-((-2262 (((-121) $ $) NIL)) (-2004 (($ $) 41)) (-1342 (((-121) $) 65)) (-2992 (($ $ $) 48)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 84)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1481 (($ $ $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2934 (($ $ $ $) 74)) (-2844 (($ $) NIL)) (-1466 (((-424 $) $) NIL)) (-3112 (((-121) $ $) NIL)) (-2433 (((-572) $) NIL)) (-3351 (($ $ $) 71)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL)) (-1318 (((-572) $) NIL)) (-2190 (($ $ $) 59)) (-2284 (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 78) (((-685 (-572)) (-685 $)) 28)) (-1799 (((-3 $ "failed") $) NIL)) (-2956 (((-3 (-413 (-572)) "failed") $) NIL)) (-3175 (((-121) $) NIL)) (-4299 (((-413 (-572)) $) NIL)) (-3286 (($) 81) (($ $) 82)) (-2208 (($ $ $) 58)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL)) (-1526 (((-121) $) NIL)) (-1968 (($ $ $ $) NIL)) (-4489 (($ $ $) 79)) (-1908 (((-121) $) NIL)) (-2133 (($ $ $) NIL)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL)) (-3893 (((-121) $) 66)) (-4240 (((-121) $) 64)) (-2959 (($ $) 42)) (-3961 (((-3 $ "failed") $) NIL)) (-4472 (((-121) $) 75)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-1628 (($ $ $ $) 72)) (-1771 (($ $ $) 68) (($) 39)) (-4238 (($ $ $) 67) (($) 38)) (-1582 (($ $) NIL)) (-3200 (($ $) 70)) (-1629 (($ $ $) NIL) (($ (-638 $)) NIL)) (-1658 (((-1152) $) NIL)) (-2144 (($ $ $) NIL)) (-1773 (($) NIL T CONST)) (-3088 (($ $) 50)) (-2607 (((-1116) $) NIL) (($ $) 69)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL)) (-3069 (($ $ $) 62) (($ (-638 $)) NIL)) (-2900 (($ $) NIL)) (-4304 (((-424 $) $) NIL)) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL)) (-1803 (((-3 $ "failed") $ $) NIL)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL)) (-4247 (((-121) $) NIL)) (-4029 (((-769) $) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 61)) (-3139 (($ $ (-769)) NIL) (($ $) NIL)) (-4340 (($ $) 51)) (-1607 (($ $) NIL)) (-4081 (((-572) $) 32) (((-545) $) NIL) (((-893 (-572)) $) NIL) (((-385) $) NIL) (((-217) $) NIL)) (-3972 (((-856) $) 31) (($ (-572)) 80) (($ $) NIL) (($ (-572)) 80)) (-2140 (((-769)) NIL)) (-1348 (((-121) $ $) NIL)) (-3610 (($ $ $) NIL)) (-4393 (($) 37)) (-3774 (((-121) $ $) NIL)) (-1498 (($ $ $ $) 73)) (-2264 (($ $) 63)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2235 (($ $ $) 44)) (-2378 (($) 35 T CONST)) (-3091 (($ $ $) 47)) (-3255 (($) 36 T CONST)) (-3594 (((-1152) $) 21) (((-1152) $ (-121)) 23) (((-1264) (-823) $) 24) (((-1264) (-823) $ (-121)) 25)) (-3076 (($ $) 45)) (-1557 (($ $ (-769)) NIL) (($ $) NIL)) (-2914 (($ $ $) 46)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 40)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 49)) (-2226 (($ $ $) 43)) (-1373 (($ $) 52) (($ $ $) 54)) (-1367 (($ $ $) 53)) (** (($ $ (-923)) NIL) (($ $ (-769)) 57)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 34) (($ $ $) 55))) 
-(((-1116) (-13 (-554) (-655) (-829) (-10 -8 (-6 -4589) (-6 -4594) (-6 -4590) (-15 -4238 ($)) (-15 -1771 ($)) (-15 -2959 ($ $)) (-15 -2004 ($ $)) (-15 -2226 ($ $ $)) (-15 -2235 ($ $ $)) (-15 -2992 ($ $ $)) (-15 -3076 ($ $)) (-15 -2914 ($ $ $)) (-15 -3091 ($ $ $))))) (T -1116)) 
-((-2235 (*1 *1 *1 *1) (-5 *1 (-1116))) (-2226 (*1 *1 *1 *1) (-5 *1 (-1116))) (-2004 (*1 *1 *1) (-5 *1 (-1116))) (-4238 (*1 *1) (-5 *1 (-1116))) (-1771 (*1 *1) (-5 *1 (-1116))) (-2959 (*1 *1 *1) (-5 *1 (-1116))) (-2992 (*1 *1 *1 *1) (-5 *1 (-1116))) (-3076 (*1 *1 *1) (-5 *1 (-1116))) (-2914 (*1 *1 *1 *1) (-5 *1 (-1116))) (-3091 (*1 *1 *1 *1) (-5 *1 (-1116)))) 
-(-13 (-554) (-655) (-829) (-10 -8 (-6 -4589) (-6 -4594) (-6 -4590) (-15 -4238 ($)) (-15 -1771 ($)) (-15 -2959 ($ $)) (-15 -2004 ($ $)) (-15 -2226 ($ $ $)) (-15 -2235 ($ $ $)) (-15 -2992 ($ $ $)) (-15 -3076 ($ $)) (-15 -2914 ($ $ $)) (-15 -3091 ($ $ $)))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-1615 ((|#1| $) 41)) (-1946 (((-121) $ (-769)) 8)) (-2211 (($) 7 T CONST)) (-4107 ((|#1| |#1| $) 43)) (-3772 ((|#1| $) 42)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-4221 ((|#1| $) 36)) (-1335 (($ |#1| $) 37)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-2232 ((|#1| $) 38)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-1564 (((-769) $) 40)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) 39)) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1117 |#1|) (-1290) (-1204)) (T -1117)) 
-((-4107 (*1 *2 *2 *1) (-12 (-4 *1 (-1117 *2)) (-4 *2 (-1204)))) (-3772 (*1 *2 *1) (-12 (-4 *1 (-1117 *2)) (-4 *2 (-1204)))) (-1615 (*1 *2 *1) (-12 (-4 *1 (-1117 *2)) (-4 *2 (-1204)))) (-1564 (*1 *2 *1) (-12 (-4 *1 (-1117 *3)) (-4 *3 (-1204)) (-5 *2 (-769))))) 
-(-13 (-111 |t#1|) (-10 -8 (-6 -4602) (-15 -4107 (|t#1| |t#1| $)) (-15 -3772 (|t#1| $)) (-15 -1615 (|t#1| $)) (-15 -1564 ((-769) $)))) 
-(((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-3520 ((|#3| $) 76)) (-3376 (((-3 (-572) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 |#3| "failed") $) 40)) (-1318 (((-572) $) NIL) (((-413 (-572)) $) NIL) ((|#3| $) 37)) (-2284 (((-685 (-572)) (-685 $)) NIL) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL) (((-2 (|:| -1369 (-685 |#3|)) (|:| |vec| (-1259 |#3|))) (-685 $) (-1259 $)) 73) (((-685 |#3|) (-685 $)) 65)) (-3139 (($ $ (-1 |#3| |#3|)) 19) (($ $ (-1 |#3| |#3|) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170)) NIL) (($ $ (-769)) NIL) (($ $) NIL)) (-3807 ((|#3| $) 78)) (-4479 ((|#4| $) 32)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 (-572))) NIL) (($ |#3|) 16)) (** (($ $ (-923)) NIL) (($ $ (-769)) 15) (($ $ (-572)) 82))) 
-(((-1118 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 ** (|#1| |#1| (-572))) (-15 -3807 (|#3| |#1|)) (-15 -3520 (|#3| |#1|)) (-15 -4479 (|#4| |#1|)) (-15 -2284 ((-685 |#3|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#3|)) (|:| |vec| (-1259 |#3|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -1318 (|#3| |#1|)) (-15 -3376 ((-3 |#3| "failed") |#1|)) (-15 -3972 (|#1| |#3|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|) (-769))) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|))) (-15 -3972 (|#1| (-572))) (-15 ** (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-923))) (-15 -3972 ((-856) |#1|))) (-1119 |#2| |#3| |#4| |#5|) (-769) (-1054) (-232 |#2| |#3|) (-232 |#2| |#3|)) (T -1118)) 
-NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-572))) (-15 -3807 (|#3| |#1|)) (-15 -3520 (|#3| |#1|)) (-15 -4479 (|#4| |#1|)) (-15 -2284 ((-685 |#3|) (-685 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 |#3|)) (|:| |vec| (-1259 |#3|))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 |#1|) (-1259 |#1|))) (-15 -2284 ((-685 (-572)) (-685 |#1|))) (-15 -1318 (|#3| |#1|)) (-15 -3376 ((-3 |#3| "failed") |#1|)) (-15 -3972 (|#1| |#3|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-572) |#1|)) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|) (-769))) (-15 -3139 (|#1| |#1| (-1 |#3| |#3|))) (-15 -3972 (|#1| (-572))) (-15 ** (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-923))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3520 ((|#2| $) 69)) (-3083 (((-121) $) 109)) (-1572 (((-3 $ "failed") $ $) 18)) (-4044 (((-121) $) 107)) (-1946 (((-121) $ (-769)) 99)) (-1468 (($ |#2|) 72)) (-2211 (($) 16 T CONST)) (-3292 (($ $) 126 (|has| |#2| (-303)))) (-4267 ((|#3| $ (-572)) 121)) (-3376 (((-3 (-572) "failed") $) 83 (|has| |#2| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) 81 (|has| |#2| (-1044 (-413 (-572))))) (((-3 |#2| "failed") $) 78)) (-1318 (((-572) $) 84 (|has| |#2| (-1044 (-572)))) (((-413 (-572)) $) 82 (|has| |#2| (-1044 (-413 (-572))))) ((|#2| $) 77)) (-2284 (((-685 (-572)) (-685 $)) 76 (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 75 (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) 74) (((-685 |#2|) (-685 $)) 73)) (-1799 (((-3 $ "failed") $) 33)) (-2667 (((-769) $) 127 (|has| |#2| (-562)))) (-4212 ((|#2| $ (-572) (-572)) 119)) (-2010 (((-638 |#2|) $) 92 (|has| $ (-6 -4602)))) (-3893 (((-121) $) 30)) (-3095 (((-769) $) 128 (|has| |#2| (-562)))) (-1301 (((-638 |#4|) $) 129 (|has| |#2| (-562)))) (-3704 (((-769) $) 115)) (-3712 (((-769) $) 116)) (-2157 (((-121) $ (-769)) 100)) (-1522 ((|#2| $) 64 (|has| |#2| (-6 (-4604 "*"))))) (-2660 (((-572) $) 111)) (-3092 (((-572) $) 113)) (-4467 (((-638 |#2|) $) 91 (|has| $ (-6 -4602)))) (-3002 (((-121) |#2| $) 89 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602))))) (-3927 (((-572) $) 112)) (-3227 (((-572) $) 114)) (-3597 (($ (-638 (-638 |#2|))) 106)) (-2435 (($ (-1 |#2| |#2|) $) 96 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#2| |#2| |#2|) $ $) 123) (($ (-1 |#2| |#2|) $) 97)) (-2259 (((-638 (-638 |#2|)) $) 117)) (-3524 (((-121) $ (-769)) 101)) (-1658 (((-1152) $) 9)) (-3750 (((-3 $ "failed") $) 63 (|has| |#2| (-368)))) (-2607 (((-1116) $) 10)) (-1803 (((-3 $ "failed") $ |#2|) 124 (|has| |#2| (-562)))) (-2109 (((-121) (-1 (-121) |#2|) $) 94 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#2|))) 88 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) 87 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) 86 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) 85 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) 105)) (-4037 (((-121) $) 102)) (-1665 (($) 103)) (-3277 ((|#2| $ (-572) (-572) |#2|) 120) ((|#2| $ (-572) (-572)) 118)) (-3139 (($ $ (-1 |#2| |#2|)) 51) (($ $ (-1 |#2| |#2|) (-769)) 50) (($ $ (-638 (-1170)) (-638 (-769))) 43 (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) 42 (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) 41 (|has| |#2| (-901 (-1170)))) (($ $ (-1170)) 40 (|has| |#2| (-901 (-1170)))) (($ $ (-769)) 38 (|has| |#2| (-227))) (($ $) 36 (|has| |#2| (-227)))) (-3807 ((|#2| $) 68)) (-3132 (($ (-638 |#2|)) 71)) (-3785 (((-121) $) 108)) (-4479 ((|#3| $) 70)) (-2271 ((|#2| $) 65 (|has| |#2| (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) |#2|) $) 93 (|has| $ (-6 -4602))) (((-769) |#2| $) 90 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 104)) (-4580 ((|#4| $ (-572)) 122)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 80 (|has| |#2| (-1044 (-413 (-572))))) (($ |#2|) 79)) (-2140 (((-769)) 28)) (-3501 (((-121) (-1 (-121) |#2|) $) 95 (|has| $ (-6 -4602)))) (-3354 (((-121) $) 110)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-1 |#2| |#2|)) 49) (($ $ (-1 |#2| |#2|) (-769)) 48) (($ $ (-638 (-1170)) (-638 (-769))) 47 (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) 46 (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) 45 (|has| |#2| (-901 (-1170)))) (($ $ (-1170)) 44 (|has| |#2| (-901 (-1170)))) (($ $ (-769)) 39 (|has| |#2| (-227))) (($ $) 37 (|has| |#2| (-227)))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#2|) 125 (|has| |#2| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 62 (|has| |#2| (-368)))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#2|) 131) (($ |#2| $) 130) ((|#4| $ |#4|) 67) ((|#3| |#3| $) 66)) (-4032 (((-769) $) 98 (|has| $ (-6 -4602))))) 
-(((-1119 |#1| |#2| |#3| |#4|) (-1290) (-769) (-1054) (-232 |t#1| |t#2|) (-232 |t#1| |t#2|)) (T -1119)) 
-((-1468 (*1 *1 *2) (-12 (-4 *2 (-1054)) (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)))) (-3132 (*1 *1 *2) (-12 (-5 *2 (-638 *4)) (-4 *4 (-1054)) (-4 *1 (-1119 *3 *4 *5 *6)) (-4 *5 (-232 *3 *4)) (-4 *6 (-232 *3 *4)))) (-4479 (*1 *2 *1) (-12 (-4 *1 (-1119 *3 *4 *2 *5)) (-4 *4 (-1054)) (-4 *5 (-232 *3 *4)) (-4 *2 (-232 *3 *4)))) (-3520 (*1 *2 *1) (-12 (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)) (-4 *2 (-1054)))) (-3807 (*1 *2 *1) (-12 (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)) (-4 *2 (-1054)))) (* (*1 *2 *1 *2) (-12 (-4 *1 (-1119 *3 *4 *5 *2)) (-4 *4 (-1054)) (-4 *5 (-232 *3 *4)) (-4 *2 (-232 *3 *4)))) (* (*1 *2 *2 *1) (-12 (-4 *1 (-1119 *3 *4 *2 *5)) (-4 *4 (-1054)) (-4 *2 (-232 *3 *4)) (-4 *5 (-232 *3 *4)))) (-2271 (*1 *2 *1) (-12 (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)) (|has| *2 (-6 (-4604 "*"))) (-4 *2 (-1054)))) (-1522 (*1 *2 *1) (-12 (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)) (|has| *2 (-6 (-4604 "*"))) (-4 *2 (-1054)))) (-3750 (*1 *1 *1) (|partial| -12 (-4 *1 (-1119 *2 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-232 *2 *3)) (-4 *5 (-232 *2 *3)) (-4 *3 (-368)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1119 *3 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-232 *3 *4)) (-4 *6 (-232 *3 *4)) (-4 *4 (-368))))) 
-(-13 (-225 |t#2|) (-120 |t#2| |t#2|) (-1057 |t#1| |t#1| |t#2| |t#3| |t#4|) (-417 |t#2|) (-383 |t#2|) (-10 -8 (IF (|has| |t#2| (-174)) (-6 (-713 |t#2|)) |noBranch|) (-15 -1468 ($ |t#2|)) (-15 -3132 ($ (-638 |t#2|))) (-15 -4479 (|t#3| $)) (-15 -3520 (|t#2| $)) (-15 -3807 (|t#2| $)) (-15 * (|t#4| $ |t#4|)) (-15 * (|t#3| |t#3| $)) (IF (|has| |t#2| (-6 (-4604 "*"))) (PROGN (-6 (-43 |t#2|)) (-15 -2271 (|t#2| $)) (-15 -1522 (|t#2| $))) |noBranch|) (IF (|has| |t#2| (-368)) (PROGN (-15 -3750 ((-3 $ "failed") $)) (-15 ** ($ $ (-572)))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-39) . T) ((-43 |#2|) |has| |#2| (-6 (-4604 "*"))) ((-105) . T) ((-120 |#2| |#2|) . T) ((-138) . T) ((-612 (-856)) . T) ((-225 |#2|) . T) ((-227) |has| |#2| (-227)) ((-305 |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-383 |#2|) . T) ((-417 |#2|) . T) ((-503 |#2|) . T) ((-527 |#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-641 |#2|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#2| (-634 (-572))) ((-634 |#2|) . T) ((-713 |#2|) -1841 (|has| |#2| (-174)) (|has| |#2| (-6 (-4604 "*")))) ((-722) . T) ((-901 (-1170)) |has| |#2| (-901 (-1170))) ((-1057 |#1| |#1| |#2| |#3| |#4|) . T) ((-1044 (-413 (-572))) |has| |#2| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#2| (-1044 (-572))) ((-1044 |#2|) . T) ((-1060 |#2|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1204) . T)) 
-((-4540 ((|#4| |#4|) 67)) (-1858 ((|#4| |#4|) 62)) (-2372 (((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|))) |#4| |#3|) 75)) (-2236 (((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|) 66)) (-3020 (((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|) 64))) 
-(((-1120 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1858 (|#4| |#4|)) (-15 -3020 ((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|)) (-15 -4540 (|#4| |#4|)) (-15 -2236 ((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|)) (-15 -2372 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|))) |#4| |#3|))) (-303) (-379 |#1|) (-379 |#1|) (-683 |#1| |#2| |#3|)) (T -1120)) 
-((-2372 (*1 *2 *3 *4) (-12 (-4 *5 (-303)) (-4 *6 (-379 *5)) (-4 *4 (-379 *5)) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-1120 *5 *6 *4 *3)) (-4 *3 (-683 *5 *6 *4)))) (-2236 (*1 *2 *3) (-12 (-4 *4 (-303)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-2 (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (-5 *1 (-1120 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-4540 (*1 *2 *2) (-12 (-4 *3 (-303)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-1120 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-3020 (*1 *2 *3) (-12 (-4 *4 (-303)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-2 (|:| |Hermite| *3) (|:| |eqMat| *3))) (-5 *1 (-1120 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) (-1858 (*1 *2 *2) (-12 (-4 *3 (-303)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-1120 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(-10 -7 (-15 -1858 (|#4| |#4|)) (-15 -3020 ((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|)) (-15 -4540 (|#4| |#4|)) (-15 -2236 ((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|)) (-15 -2372 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2237 (-638 |#3|))) |#4| |#3|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 17)) (-3456 (((-638 |#2|) $) 160)) (-4297 (((-1166 $) $ |#2|) 54) (((-1166 |#1|) $) 43)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 110 (|has| |#1| (-562)))) (-3946 (($ $) 112 (|has| |#1| (-562)))) (-3686 (((-121) $) 114 (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 |#2|)) 193)) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) 157) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 |#2| "failed") $) NIL)) (-1318 ((|#1| $) 155) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) ((|#2| $) NIL)) (-3190 (($ $ $ |#2|) NIL (|has| |#1| (-174)))) (-4383 (($ $) 197)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) 82)) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ |#2|) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-538 |#2|) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| |#1| (-887 (-385))) (|has| |#2| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| |#1| (-887 (-572))) (|has| |#2| (-887 (-572)))))) (-3893 (((-121) $) 19)) (-3475 (((-769) $) 26)) (-4335 (($ (-1166 |#1|) |#2|) 48) (($ (-1166 $) |#2|) 64)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) 31)) (-4328 (($ |#1| (-538 |#2|)) 71) (($ $ |#2| (-769)) 52) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ |#2|) NIL)) (-1784 (((-538 |#2|) $) 187) (((-769) $ |#2|) 188) (((-638 (-769)) $ (-638 |#2|)) 189)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-538 |#2|) (-538 |#2|)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) 122)) (-1470 (((-3 |#2| "failed") $) 162)) (-4368 (($ $) 196)) (-4373 ((|#1| $) 37)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| |#2|) (|:| -3751 (-769))) "failed") $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 32)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 140 (|has| |#1| (-457)))) (-3069 (($ (-638 $)) 145 (|has| |#1| (-457))) (($ $ $) 132 (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) 120 (|has| |#1| (-562)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ |#2| |#1|) 165) (($ $ (-638 |#2|) (-638 |#1|)) 178) (($ $ |#2| $) 164) (($ $ (-638 |#2|) (-638 $)) 177)) (-2119 (($ $ |#2|) NIL (|has| |#1| (-174)))) (-3139 (($ $ |#2|) 195) (($ $ (-638 |#2|)) NIL) (($ $ |#2| (-769)) NIL) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-4316 (((-538 |#2|) $) 183) (((-769) $ |#2|) 179) (((-638 (-769)) $ (-638 |#2|)) 181)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| |#1| (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| |#1| (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| |#1| (-613 (-545))) (|has| |#2| (-613 (-545)))))) (-3694 ((|#1| $) 128 (|has| |#1| (-457))) (($ $ |#2|) 131 (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-3972 (((-856) $) 151) (($ (-572)) 76) (($ |#1|) 77) (($ |#2|) 28) (($ $) NIL (|has| |#1| (-562))) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572))))))) (-3193 (((-638 |#1|) $) 154)) (-1958 ((|#1| $ (-538 |#2|)) 73) (($ $ |#2| (-769)) NIL) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) 79)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) 117 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 102) (($ $ (-769)) 104)) (-2378 (($) 12 T CONST)) (-3255 (($) 14 T CONST)) (-1557 (($ $ |#2|) NIL) (($ $ (-638 |#2|)) NIL) (($ $ |#2| (-769)) NIL) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) 97)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) 126 (|has| |#1| (-368)))) (-1373 (($ $) 85) (($ $ $) 95)) (-1367 (($ $ $) 49)) (** (($ $ (-923)) 103) (($ $ (-769)) 100)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 88) (($ $ $) 65) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 90) (($ $ |#1|) NIL))) 
-(((-1121 |#1| |#2|) (-956 |#1| (-538 |#2|) |#2|) (-1054) (-848)) (T -1121)) 
-NIL 
-(-956 |#1| (-538 |#2|) |#2|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 |#2|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-4284 (($ $) 154 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 130 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4273 (($ $) 150 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 126 (|has| |#1| (-43 (-413 (-572)))))) (-4295 (($ $) 158 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 134 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-1896 (((-959 |#1|) $ (-769)) NIL) (((-959 |#1|) $ (-769) (-769)) NIL)) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-769) $ |#2|) NIL) (((-769) $ |#2| (-769)) NIL)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4581 (((-121) $) NIL)) (-4328 (($ $ (-638 |#2|) (-638 (-538 |#2|))) NIL) (($ $ |#2| (-538 |#2|)) NIL) (($ |#1| (-538 |#2|)) NIL) (($ $ |#2| (-769)) 71) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3539 (($ $) 124 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2774 (($ $ |#2|) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ |#2| |#1|) 177 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-3620 (($ (-1 $) |#2| |#1|) 176 (|has| |#1| (-43 (-413 (-572)))))) (-1977 (($ $ (-769)) 15)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4179 (($ $) 122 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (($ $ |#2| $) 109) (($ $ (-638 |#2|) (-638 $)) 102) (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL)) (-3139 (($ $ |#2|) 111) (($ $ (-638 |#2|)) NIL) (($ $ |#2| (-769)) NIL) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-4316 (((-538 |#2|) $) NIL)) (-3817 (((-1 (-1150 |#3|) |#3|) (-638 |#2|) (-638 (-1150 |#3|))) 92)) (-4302 (($ $) 160 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 136 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 156 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 132 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 152 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 128 (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 17)) (-3972 (((-856) $) 192) (($ (-572)) NIL) (($ |#1|) 59 (|has| |#1| (-174))) (($ $) NIL (|has| |#1| (-562))) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#2|) 78) (($ |#3|) 76)) (-1958 ((|#1| $ (-538 |#2|)) 57) (($ $ |#2| (-769)) NIL) (($ $ (-638 |#2|) (-638 (-769))) 50) ((|#3| $ (-769)) 42)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-4321 (($ $) 166 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 142 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) 162 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 138 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 170 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 146 (|has| |#1| (-43 (-413 (-572)))))) (-2104 (($ $) 172 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 148 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 168 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 144 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 164 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 140 (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 18 T CONST)) (-3255 (($) 10 T CONST)) (-1557 (($ $ |#2|) NIL) (($ $ (-638 |#2|)) NIL) (($ $ |#2| (-769)) NIL) (($ $ (-638 |#2|) (-638 (-769))) NIL)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) 194 (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 74)) (** (($ $ (-923)) NIL) (($ $ (-769)) 83) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 114 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 73) (($ $ (-413 (-572))) 119 (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) 117 (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 62) (($ $ |#1|) 63) (($ |#3| $) 61))) 
-(((-1122 |#1| |#2| |#3|) (-13 (-736 |#1| |#2|) (-10 -8 (-15 -1958 (|#3| $ (-769))) (-15 -3972 ($ |#2|)) (-15 -3972 ($ |#3|)) (-15 * ($ |#3| $)) (-15 -3817 ((-1 (-1150 |#3|) |#3|) (-638 |#2|) (-638 (-1150 |#3|)))) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $ |#2| |#1|)) (-15 -3620 ($ (-1 $) |#2| |#1|))) |noBranch|))) (-1054) (-848) (-956 |#1| (-538 |#2|) |#2|)) (T -1122)) 
-((-1958 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *2 (-956 *4 (-538 *5) *5)) (-5 *1 (-1122 *4 *5 *2)) (-4 *4 (-1054)) (-4 *5 (-848)))) (-3972 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *2 (-848)) (-5 *1 (-1122 *3 *2 *4)) (-4 *4 (-956 *3 (-538 *2) *2)))) (-3972 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-848)) (-5 *1 (-1122 *3 *4 *2)) (-4 *2 (-956 *3 (-538 *4) *4)))) (* (*1 *1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-848)) (-5 *1 (-1122 *3 *4 *2)) (-4 *2 (-956 *3 (-538 *4) *4)))) (-3817 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-638 (-1150 *7))) (-4 *6 (-848)) (-4 *7 (-956 *5 (-538 *6) *6)) (-4 *5 (-1054)) (-5 *2 (-1 (-1150 *7) *7)) (-5 *1 (-1122 *5 *6 *7)))) (-2774 (*1 *1 *1 *2 *3) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-4 *2 (-848)) (-5 *1 (-1122 *3 *2 *4)) (-4 *4 (-956 *3 (-538 *2) *2)))) (-3620 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1122 *4 *3 *5))) (-4 *4 (-43 (-413 (-572)))) (-4 *4 (-1054)) (-4 *3 (-848)) (-5 *1 (-1122 *4 *3 *5)) (-4 *5 (-956 *4 (-538 *3) *3))))) 
-(-13 (-736 |#1| |#2|) (-10 -8 (-15 -1958 (|#3| $ (-769))) (-15 -3972 ($ |#2|)) (-15 -3972 ($ |#3|)) (-15 * ($ |#3| $)) (-15 -3817 ((-1 (-1150 |#3|) |#3|) (-638 |#2|) (-638 (-1150 |#3|)))) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $ |#2| |#1|)) (-15 -3620 ($ (-1 $) |#2| |#1|))) |noBranch|))) 
-((-2262 (((-121) $ $) 7)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) 78)) (-4165 (((-638 $) (-638 |#4|)) 79) (((-638 $) (-638 |#4|) (-121)) 104)) (-3456 (((-638 |#3|) $) 32)) (-3049 (((-121) $) 25)) (-3289 (((-121) $) 16 (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) 94) (((-121) $) 90)) (-1872 ((|#4| |#4| $) 85)) (-2844 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| $) 119)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) 26)) (-1946 (((-121) $ (-769)) 43)) (-2561 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) 72)) (-2211 (($) 44 T CONST)) (-3097 (((-121) $) 21 (|has| |#1| (-562)))) (-3760 (((-121) $ $) 23 (|has| |#1| (-562)))) (-3819 (((-121) $ $) 22 (|has| |#1| (-562)))) (-4331 (((-121) $) 24 (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3683 (((-638 |#4|) (-638 |#4|) $) 17 (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) 18 (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) 35)) (-1318 (($ (-638 |#4|)) 34)) (-1651 (((-3 $ "failed") $) 75)) (-2242 ((|#4| |#4| $) 82)) (-1643 (($ $) 67 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#4| $) 66 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-1673 ((|#4| |#4| $) 80)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) 98)) (-1706 (((-121) |#4| $) 129)) (-2989 (((-121) |#4| $) 126)) (-1366 (((-121) |#4| $) 130) (((-121) $) 127)) (-2010 (((-638 |#4|) $) 51 (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) 97) (((-121) $) 96)) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) 42)) (-4467 (((-638 |#4|) $) 52 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 46)) (-4062 (((-638 |#3|) $) 31)) (-1346 (((-121) |#3| $) 30)) (-3524 (((-121) $ (-769)) 41)) (-1658 (((-1152) $) 9)) (-2550 (((-3 |#4| (-638 $)) |#4| |#4| $) 121)) (-4416 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| |#4| $) 120)) (-3253 (((-3 |#4| "failed") $) 76)) (-2173 (((-638 $) |#4| $) 122)) (-2471 (((-3 (-121) (-638 $)) |#4| $) 125)) (-2338 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-1931 (((-638 $) |#4| $) 118) (((-638 $) (-638 |#4|) $) 117) (((-638 $) (-638 |#4|) (-638 $)) 116) (((-638 $) |#4| (-638 $)) 115)) (-3078 (($ |#4| $) 110) (($ (-638 |#4|) $) 109)) (-3727 (((-638 |#4|) $) 100)) (-1483 (((-121) |#4| $) 92) (((-121) $) 88)) (-2788 ((|#4| |#4| $) 83)) (-1843 (((-121) $ $) 103)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) 93) (((-121) $) 89)) (-4498 ((|#4| |#4| $) 84)) (-2607 (((-1116) $) 10)) (-1837 (((-3 |#4| "failed") $) 77)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1928 (((-3 $ "failed") $ |#4|) 71)) (-1977 (($ $ |#4|) 70) (((-638 $) |#4| $) 108) (((-638 $) |#4| (-638 $)) 107) (((-638 $) (-638 |#4|) $) 106) (((-638 $) (-638 |#4|) (-638 $)) 105)) (-2109 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) 58 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) 56 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) 55 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) 37)) (-4037 (((-121) $) 40)) (-1665 (($) 39)) (-4316 (((-769) $) 99)) (-1571 (((-769) |#4| $) 53 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4602)))) (-1607 (($ $) 38)) (-4081 (((-545) $) 68 (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 59)) (-1826 (($ $ |#3|) 27)) (-2291 (($ $ |#3|) 29)) (-3134 (($ $) 81)) (-1650 (($ $ |#3|) 28)) (-3972 (((-856) $) 11) (((-638 |#4|) $) 36)) (-2498 (((-769) $) 69 (|has| |#3| (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) 91)) (-2589 (((-638 $) |#4| $) 114) (((-638 $) |#4| (-638 $)) 113) (((-638 $) (-638 |#4|) $) 112) (((-638 $) (-638 |#4|) (-638 $)) 111)) (-3501 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) 74)) (-4191 (((-121) |#4| $) 128)) (-2213 (((-121) |#3| $) 73)) (-1324 (((-121) $ $) 6)) (-4032 (((-769) $) 45 (|has| $ (-6 -4602))))) 
-(((-1123 |#1| |#2| |#3| |#4|) (-1290) (-457) (-794) (-848) (-1068 |t#1| |t#2| |t#3|)) (T -1123)) 
-NIL 
-(-13 (-1107 |t#1| |t#2| |t#3| |t#4|) (-785 |t#1| |t#2| |t#3| |t#4|)) 
-(((-39) . T) ((-105) . T) ((-612 (-638 |#4|)) . T) ((-612 (-856)) . T) ((-155 |#4|) . T) ((-613 (-545)) |has| |#4| (-613 (-545))) ((-305 |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-503 |#4|) . T) ((-527 |#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-785 |#1| |#2| |#3| |#4|) . T) ((-984 |#1| |#2| |#3| |#4|) . T) ((-1073 |#1| |#2| |#3| |#4|) . T) ((-1098) . T) ((-1107 |#1| |#2| |#3| |#4|) . T) ((-1198 |#1| |#2| |#3| |#4|) . T) ((-1204) . T)) 
-((-2800 (((-638 |#2|) |#1|) 12)) (-4077 (((-638 |#2|) |#2| |#2| |#2| |#2| |#2|) 37) (((-638 |#2|) |#1|) 47)) (-3669 (((-638 |#2|) |#2| |#2| |#2|) 35) (((-638 |#2|) |#1|) 45)) (-3473 ((|#2| |#1|) 42)) (-4531 (((-2 (|:| |solns| (-638 |#2|)) (|:| |maps| (-638 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|)) 16)) (-3642 (((-638 |#2|) |#2| |#2|) 34) (((-638 |#2|) |#1|) 44)) (-2903 (((-638 |#2|) |#2| |#2| |#2| |#2|) 36) (((-638 |#2|) |#1|) 46)) (-2261 ((|#2| |#2| |#2| |#2| |#2| |#2|) 41)) (-2746 ((|#2| |#2| |#2| |#2|) 39)) (-1723 ((|#2| |#2| |#2|) 38)) (-4380 ((|#2| |#2| |#2| |#2| |#2|) 40))) 
-(((-1124 |#1| |#2|) (-10 -7 (-15 -2800 ((-638 |#2|) |#1|)) (-15 -3473 (|#2| |#1|)) (-15 -4531 ((-2 (|:| |solns| (-638 |#2|)) (|:| |maps| (-638 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|))) (-15 -3642 ((-638 |#2|) |#1|)) (-15 -3669 ((-638 |#2|) |#1|)) (-15 -2903 ((-638 |#2|) |#1|)) (-15 -4077 ((-638 |#2|) |#1|)) (-15 -3642 ((-638 |#2|) |#2| |#2|)) (-15 -3669 ((-638 |#2|) |#2| |#2| |#2|)) (-15 -2903 ((-638 |#2|) |#2| |#2| |#2| |#2|)) (-15 -4077 ((-638 |#2|) |#2| |#2| |#2| |#2| |#2|)) (-15 -1723 (|#2| |#2| |#2|)) (-15 -2746 (|#2| |#2| |#2| |#2|)) (-15 -4380 (|#2| |#2| |#2| |#2| |#2|)) (-15 -2261 (|#2| |#2| |#2| |#2| |#2| |#2|))) (-1234 |#2|) (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (T -1124)) 
-((-2261 (*1 *2 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2)))) (-4380 (*1 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2)))) (-2746 (*1 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2)))) (-1723 (*1 *2 *2 *2) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2)))) (-4077 (*1 *2 *3 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *3)) (-5 *1 (-1124 *4 *3)) (-4 *4 (-1234 *3)))) (-2903 (*1 *2 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *3)) (-5 *1 (-1124 *4 *3)) (-4 *4 (-1234 *3)))) (-3669 (*1 *2 *3 *3 *3) (-12 (-4 *3 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *3)) (-5 *1 (-1124 *4 *3)) (-4 *4 (-1234 *3)))) (-3642 (*1 *2 *3 *3) (-12 (-4 *3 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *3)) (-5 *1 (-1124 *4 *3)) (-4 *4 (-1234 *3)))) (-4077 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) (-2903 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) (-3669 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) (-3642 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) (-4531 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *5 *5)) (-4 *5 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-2 (|:| |solns| (-638 *5)) (|:| |maps| (-638 (-2 (|:| |arg| *5) (|:| |res| *5)))))) (-5 *1 (-1124 *3 *5)) (-4 *3 (-1234 *5)))) (-3473 (*1 *2 *3) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2)))) (-2800 (*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -2800 ((-638 |#2|) |#1|)) (-15 -3473 (|#2| |#1|)) (-15 -4531 ((-2 (|:| |solns| (-638 |#2|)) (|:| |maps| (-638 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|))) (-15 -3642 ((-638 |#2|) |#1|)) (-15 -3669 ((-638 |#2|) |#1|)) (-15 -2903 ((-638 |#2|) |#1|)) (-15 -4077 ((-638 |#2|) |#1|)) (-15 -3642 ((-638 |#2|) |#2| |#2|)) (-15 -3669 ((-638 |#2|) |#2| |#2| |#2|)) (-15 -2903 ((-638 |#2|) |#2| |#2| |#2| |#2|)) (-15 -4077 ((-638 |#2|) |#2| |#2| |#2| |#2| |#2|)) (-15 -1723 (|#2| |#2| |#2|)) (-15 -2746 (|#2| |#2| |#2| |#2|)) (-15 -4380 (|#2| |#2| |#2| |#2| |#2|)) (-15 -2261 (|#2| |#2| |#2| |#2| |#2| |#2|))) 
-((-1938 (((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-413 (-959 |#1|))))) 94) (((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-413 (-959 |#1|)))) (-638 (-1170))) 93) (((-638 (-638 (-290 (-312 |#1|)))) (-638 (-413 (-959 |#1|)))) 91) (((-638 (-638 (-290 (-312 |#1|)))) (-638 (-413 (-959 |#1|))) (-638 (-1170))) 89) (((-638 (-290 (-312 |#1|))) (-290 (-413 (-959 |#1|)))) 75) (((-638 (-290 (-312 |#1|))) (-290 (-413 (-959 |#1|))) (-1170)) 76) (((-638 (-290 (-312 |#1|))) (-413 (-959 |#1|))) 70) (((-638 (-290 (-312 |#1|))) (-413 (-959 |#1|)) (-1170)) 59)) (-3438 (((-638 (-638 (-312 |#1|))) (-638 (-413 (-959 |#1|))) (-638 (-1170))) 87) (((-638 (-312 |#1|)) (-413 (-959 |#1|)) (-1170)) 43)) (-1330 (((-1159 (-638 (-312 |#1|)) (-638 (-290 (-312 |#1|)))) (-413 (-959 |#1|)) (-1170)) 97) (((-1159 (-638 (-312 |#1|)) (-638 (-290 (-312 |#1|)))) (-290 (-413 (-959 |#1|))) (-1170)) 96))) 
-(((-1125 |#1|) (-10 -7 (-15 -1938 ((-638 (-290 (-312 |#1|))) (-413 (-959 |#1|)) (-1170))) (-15 -1938 ((-638 (-290 (-312 |#1|))) (-413 (-959 |#1|)))) (-15 -1938 ((-638 (-290 (-312 |#1|))) (-290 (-413 (-959 |#1|))) (-1170))) (-15 -1938 ((-638 (-290 (-312 |#1|))) (-290 (-413 (-959 |#1|))))) (-15 -1938 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-413 (-959 |#1|))) (-638 (-1170)))) (-15 -1938 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-413 (-959 |#1|))))) (-15 -1938 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-413 (-959 |#1|)))) (-638 (-1170)))) (-15 -1938 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-413 (-959 |#1|)))))) (-15 -3438 ((-638 (-312 |#1|)) (-413 (-959 |#1|)) (-1170))) (-15 -3438 ((-638 (-638 (-312 |#1|))) (-638 (-413 (-959 |#1|))) (-638 (-1170)))) (-15 -1330 ((-1159 (-638 (-312 |#1|)) (-638 (-290 (-312 |#1|)))) (-290 (-413 (-959 |#1|))) (-1170))) (-15 -1330 ((-1159 (-638 (-312 |#1|)) (-638 (-290 (-312 |#1|)))) (-413 (-959 |#1|)) (-1170)))) (-13 (-303) (-848) (-151))) (T -1125)) 
-((-1330 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-1159 (-638 (-312 *5)) (-638 (-290 (-312 *5))))) (-5 *1 (-1125 *5)))) (-1330 (*1 *2 *3 *4) (-12 (-5 *3 (-290 (-413 (-959 *5)))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-1159 (-638 (-312 *5)) (-638 (-290 (-312 *5))))) (-5 *1 (-1125 *5)))) (-3438 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 *5)))) (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-312 *5)))) (-5 *1 (-1125 *5)))) (-3438 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-312 *5))) (-5 *1 (-1125 *5)))) (-1938 (*1 *2 *3) (-12 (-5 *3 (-638 (-290 (-413 (-959 *4))))) (-4 *4 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *4))))) (-5 *1 (-1125 *4)))) (-1938 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-290 (-413 (-959 *5))))) (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *5))))) (-5 *1 (-1125 *5)))) (-1938 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 *4)))) (-4 *4 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *4))))) (-5 *1 (-1125 *4)))) (-1938 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 *5)))) (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *5))))) (-5 *1 (-1125 *5)))) (-1938 (*1 *2 *3) (-12 (-5 *3 (-290 (-413 (-959 *4)))) (-4 *4 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-290 (-312 *4)))) (-5 *1 (-1125 *4)))) (-1938 (*1 *2 *3 *4) (-12 (-5 *3 (-290 (-413 (-959 *5)))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-290 (-312 *5)))) (-5 *1 (-1125 *5)))) (-1938 (*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-290 (-312 *4)))) (-5 *1 (-1125 *4)))) (-1938 (*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-290 (-312 *5)))) (-5 *1 (-1125 *5))))) 
-(-10 -7 (-15 -1938 ((-638 (-290 (-312 |#1|))) (-413 (-959 |#1|)) (-1170))) (-15 -1938 ((-638 (-290 (-312 |#1|))) (-413 (-959 |#1|)))) (-15 -1938 ((-638 (-290 (-312 |#1|))) (-290 (-413 (-959 |#1|))) (-1170))) (-15 -1938 ((-638 (-290 (-312 |#1|))) (-290 (-413 (-959 |#1|))))) (-15 -1938 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-413 (-959 |#1|))) (-638 (-1170)))) (-15 -1938 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-413 (-959 |#1|))))) (-15 -1938 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-413 (-959 |#1|)))) (-638 (-1170)))) (-15 -1938 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-413 (-959 |#1|)))))) (-15 -3438 ((-638 (-312 |#1|)) (-413 (-959 |#1|)) (-1170))) (-15 -3438 ((-638 (-638 (-312 |#1|))) (-638 (-413 (-959 |#1|))) (-638 (-1170)))) (-15 -1330 ((-1159 (-638 (-312 |#1|)) (-638 (-290 (-312 |#1|)))) (-290 (-413 (-959 |#1|))) (-1170))) (-15 -1330 ((-1159 (-638 (-312 |#1|)) (-638 (-290 (-312 |#1|)))) (-413 (-959 |#1|)) (-1170)))) 
-((-3966 (((-413 (-1166 (-312 |#1|))) (-1259 (-312 |#1|)) (-413 (-1166 (-312 |#1|))) (-572)) 27)) (-4269 (((-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|)))) 39))) 
-(((-1126 |#1|) (-10 -7 (-15 -4269 ((-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|))))) (-15 -3966 ((-413 (-1166 (-312 |#1|))) (-1259 (-312 |#1|)) (-413 (-1166 (-312 |#1|))) (-572)))) (-13 (-562) (-848))) (T -1126)) 
-((-3966 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-413 (-1166 (-312 *5)))) (-5 *3 (-1259 (-312 *5))) (-5 *4 (-572)) (-4 *5 (-13 (-562) (-848))) (-5 *1 (-1126 *5)))) (-4269 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-413 (-1166 (-312 *3)))) (-4 *3 (-13 (-562) (-848))) (-5 *1 (-1126 *3))))) 
-(-10 -7 (-15 -4269 ((-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|))) (-413 (-1166 (-312 |#1|))))) (-15 -3966 ((-413 (-1166 (-312 |#1|))) (-1259 (-312 |#1|)) (-413 (-1166 (-312 |#1|))) (-572)))) 
-((-2800 (((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-312 |#1|))) (-638 (-1170))) 216) (((-638 (-290 (-312 |#1|))) (-312 |#1|) (-1170)) 20) (((-638 (-290 (-312 |#1|))) (-290 (-312 |#1|)) (-1170)) 26) (((-638 (-290 (-312 |#1|))) (-290 (-312 |#1|))) 25) (((-638 (-290 (-312 |#1|))) (-312 |#1|)) 21))) 
-(((-1127 |#1|) (-10 -7 (-15 -2800 ((-638 (-290 (-312 |#1|))) (-312 |#1|))) (-15 -2800 ((-638 (-290 (-312 |#1|))) (-290 (-312 |#1|)))) (-15 -2800 ((-638 (-290 (-312 |#1|))) (-290 (-312 |#1|)) (-1170))) (-15 -2800 ((-638 (-290 (-312 |#1|))) (-312 |#1|) (-1170))) (-15 -2800 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-312 |#1|))) (-638 (-1170))))) (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (T -1127)) 
-((-2800 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *5))))) (-5 *1 (-1127 *5)) (-5 *3 (-638 (-290 (-312 *5)))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-290 (-312 *5)))) (-5 *1 (-1127 *5)) (-5 *3 (-312 *5)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-290 (-312 *5)))) (-5 *1 (-1127 *5)) (-5 *3 (-290 (-312 *5))))) (-2800 (*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-290 (-312 *4)))) (-5 *1 (-1127 *4)) (-5 *3 (-290 (-312 *4))))) (-2800 (*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-290 (-312 *4)))) (-5 *1 (-1127 *4)) (-5 *3 (-312 *4))))) 
-(-10 -7 (-15 -2800 ((-638 (-290 (-312 |#1|))) (-312 |#1|))) (-15 -2800 ((-638 (-290 (-312 |#1|))) (-290 (-312 |#1|)))) (-15 -2800 ((-638 (-290 (-312 |#1|))) (-290 (-312 |#1|)) (-1170))) (-15 -2800 ((-638 (-290 (-312 |#1|))) (-312 |#1|) (-1170))) (-15 -2800 ((-638 (-638 (-290 (-312 |#1|)))) (-638 (-290 (-312 |#1|))) (-638 (-1170))))) 
-((-2192 ((|#2| |#2|) 20 (|has| |#1| (-848))) ((|#2| |#2| (-1 (-121) |#1| |#1|)) 16)) (-3586 ((|#2| |#2|) 19 (|has| |#1| (-848))) ((|#2| |#2| (-1 (-121) |#1| |#1|)) 15))) 
-(((-1128 |#1| |#2|) (-10 -7 (-15 -3586 (|#2| |#2| (-1 (-121) |#1| |#1|))) (-15 -2192 (|#2| |#2| (-1 (-121) |#1| |#1|))) (IF (|has| |#1| (-848)) (PROGN (-15 -3586 (|#2| |#2|)) (-15 -2192 (|#2| |#2|))) |noBranch|)) (-1204) (-13 (-605 (-572) |#1|) (-10 -7 (-6 -4602) (-6 -4603)))) (T -1128)) 
-((-2192 (*1 *2 *2) (-12 (-4 *3 (-848)) (-4 *3 (-1204)) (-5 *1 (-1128 *3 *2)) (-4 *2 (-13 (-605 (-572) *3) (-10 -7 (-6 -4602) (-6 -4603)))))) (-3586 (*1 *2 *2) (-12 (-4 *3 (-848)) (-4 *3 (-1204)) (-5 *1 (-1128 *3 *2)) (-4 *2 (-13 (-605 (-572) *3) (-10 -7 (-6 -4602) (-6 -4603)))))) (-2192 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-1128 *4 *2)) (-4 *2 (-13 (-605 (-572) *4) (-10 -7 (-6 -4602) (-6 -4603)))))) (-3586 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-1128 *4 *2)) (-4 *2 (-13 (-605 (-572) *4) (-10 -7 (-6 -4602) (-6 -4603))))))) 
-(-10 -7 (-15 -3586 (|#2| |#2| (-1 (-121) |#1| |#1|))) (-15 -2192 (|#2| |#2| (-1 (-121) |#1| |#1|))) (IF (|has| |#1| (-848)) (PROGN (-15 -3586 (|#2| |#2|)) (-15 -2192 (|#2| |#2|))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-4410 (((-1158 3 |#1|) $) 105)) (-1583 (((-121) $) 72)) (-3759 (($ $ (-638 (-950 |#1|))) 20) (($ $ (-638 (-638 |#1|))) 75) (($ (-638 (-950 |#1|))) 74) (((-638 (-950 |#1|)) $) 73)) (-4448 (((-121) $) 41)) (-1767 (($ $ (-950 |#1|)) 46) (($ $ (-638 |#1|)) 51) (($ $ (-769)) 53) (($ (-950 |#1|)) 47) (((-950 |#1|) $) 45)) (-3989 (((-2 (|:| -4161 (-769)) (|:| |curves| (-769)) (|:| |polygons| (-769)) (|:| |constructs| (-769))) $) 103)) (-2632 (((-769) $) 26)) (-1602 (((-769) $) 25)) (-2832 (($ $ (-769) (-950 |#1|)) 39)) (-2939 (((-121) $) 82)) (-2806 (($ $ (-638 (-638 (-950 |#1|))) (-638 (-173)) (-173)) 89) (($ $ (-638 (-638 (-638 |#1|))) (-638 (-173)) (-173)) 91) (($ $ (-638 (-638 (-950 |#1|))) (-121) (-121)) 85) (($ $ (-638 (-638 (-638 |#1|))) (-121) (-121)) 93) (($ (-638 (-638 (-950 |#1|)))) 86) (($ (-638 (-638 (-950 |#1|))) (-121) (-121)) 87) (((-638 (-638 (-950 |#1|))) $) 84)) (-4475 (($ (-638 $)) 28) (($ $ $) 29)) (-2696 (((-638 (-173)) $) 101)) (-3555 (((-638 (-950 |#1|)) $) 96)) (-3590 (((-638 (-638 (-173))) $) 100)) (-2665 (((-638 (-638 (-638 (-950 |#1|)))) $) NIL)) (-1669 (((-638 (-638 (-638 (-769)))) $) 98)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4433 (((-769) $ (-638 (-950 |#1|))) 37)) (-2874 (((-121) $) 54)) (-3702 (($ $ (-638 (-950 |#1|))) 56) (($ $ (-638 (-638 |#1|))) 62) (($ (-638 (-950 |#1|))) 57) (((-638 (-950 |#1|)) $) 55)) (-2045 (($) 23) (($ (-1158 3 |#1|)) 24)) (-1607 (($ $) 35)) (-2122 (((-638 $) $) 34)) (-2268 (($ (-638 $)) 31)) (-2303 (((-638 $) $) 33)) (-3972 (((-856) $) 109)) (-1916 (((-121) $) 64)) (-2092 (($ $ (-638 (-950 |#1|))) 66) (($ $ (-638 (-638 |#1|))) 69) (($ (-638 (-950 |#1|))) 67) (((-638 (-950 |#1|)) $) 65)) (-2285 (($ $) 104)) (-1324 (((-121) $ $) NIL))) 
-(((-1129 |#1|) (-1130 |#1|) (-1054)) (T -1129)) 
-NIL 
-(-1130 |#1|) 
-((-2262 (((-121) $ $) 7)) (-4410 (((-1158 3 |#1|) $) 12)) (-1583 (((-121) $) 28)) (-3759 (($ $ (-638 (-950 |#1|))) 32) (($ $ (-638 (-638 |#1|))) 31) (($ (-638 (-950 |#1|))) 30) (((-638 (-950 |#1|)) $) 29)) (-4448 (((-121) $) 43)) (-1767 (($ $ (-950 |#1|)) 48) (($ $ (-638 |#1|)) 47) (($ $ (-769)) 46) (($ (-950 |#1|)) 45) (((-950 |#1|) $) 44)) (-3989 (((-2 (|:| -4161 (-769)) (|:| |curves| (-769)) (|:| |polygons| (-769)) (|:| |constructs| (-769))) $) 14)) (-2632 (((-769) $) 57)) (-1602 (((-769) $) 58)) (-2832 (($ $ (-769) (-950 |#1|)) 49)) (-2939 (((-121) $) 20)) (-2806 (($ $ (-638 (-638 (-950 |#1|))) (-638 (-173)) (-173)) 27) (($ $ (-638 (-638 (-638 |#1|))) (-638 (-173)) (-173)) 26) (($ $ (-638 (-638 (-950 |#1|))) (-121) (-121)) 25) (($ $ (-638 (-638 (-638 |#1|))) (-121) (-121)) 24) (($ (-638 (-638 (-950 |#1|)))) 23) (($ (-638 (-638 (-950 |#1|))) (-121) (-121)) 22) (((-638 (-638 (-950 |#1|))) $) 21)) (-4475 (($ (-638 $)) 56) (($ $ $) 55)) (-2696 (((-638 (-173)) $) 15)) (-3555 (((-638 (-950 |#1|)) $) 19)) (-3590 (((-638 (-638 (-173))) $) 16)) (-2665 (((-638 (-638 (-638 (-950 |#1|)))) $) 17)) (-1669 (((-638 (-638 (-638 (-769)))) $) 18)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4433 (((-769) $ (-638 (-950 |#1|))) 50)) (-2874 (((-121) $) 38)) (-3702 (($ $ (-638 (-950 |#1|))) 42) (($ $ (-638 (-638 |#1|))) 41) (($ (-638 (-950 |#1|))) 40) (((-638 (-950 |#1|)) $) 39)) (-2045 (($) 60) (($ (-1158 3 |#1|)) 59)) (-1607 (($ $) 51)) (-2122 (((-638 $) $) 52)) (-2268 (($ (-638 $)) 54)) (-2303 (((-638 $) $) 53)) (-3972 (((-856) $) 11)) (-1916 (((-121) $) 33)) (-2092 (($ $ (-638 (-950 |#1|))) 37) (($ $ (-638 (-638 |#1|))) 36) (($ (-638 (-950 |#1|))) 35) (((-638 (-950 |#1|)) $) 34)) (-2285 (($ $) 13)) (-1324 (((-121) $ $) 6))) 
-(((-1130 |#1|) (-1290) (-1054)) (T -1130)) 
-((-3972 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-856)))) (-2045 (*1 *1) (-12 (-4 *1 (-1130 *2)) (-4 *2 (-1054)))) (-2045 (*1 *1 *2) (-12 (-5 *2 (-1158 3 *3)) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) (-1602 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) (-2632 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) (-4475 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-4475 (*1 *1 *1 *1) (-12 (-4 *1 (-1130 *2)) (-4 *2 (-1054)))) (-2268 (*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-2303 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-638 *1)) (-4 *1 (-1130 *3)))) (-2122 (*1 *2 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-638 *1)) (-4 *1 (-1130 *3)))) (-1607 (*1 *1 *1) (-12 (-4 *1 (-1130 *2)) (-4 *2 (-1054)))) (-4433 (*1 *2 *1 *3) (-12 (-5 *3 (-638 (-950 *4))) (-4 *1 (-1130 *4)) (-4 *4 (-1054)) (-5 *2 (-769)))) (-2832 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-950 *4)) (-4 *1 (-1130 *4)) (-4 *4 (-1054)))) (-1767 (*1 *1 *1 *2) (-12 (-5 *2 (-950 *3)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-1767 (*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-1767 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-1767 (*1 *1 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) (-1767 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-950 *3)))) (-4448 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121)))) (-3702 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-3702 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-3702 (*1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) (-3702 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-950 *3))))) (-2874 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121)))) (-2092 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-2092 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-2092 (*1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) (-2092 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-950 *3))))) (-1916 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121)))) (-3759 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-3759 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) (-3759 (*1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) (-3759 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-950 *3))))) (-1583 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121)))) (-2806 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-638 (-950 *5)))) (-5 *3 (-638 (-173))) (-5 *4 (-173)) (-4 *1 (-1130 *5)) (-4 *5 (-1054)))) (-2806 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-638 (-638 *5)))) (-5 *3 (-638 (-173))) (-5 *4 (-173)) (-4 *1 (-1130 *5)) (-4 *5 (-1054)))) (-2806 (*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-638 (-638 (-950 *4)))) (-5 *3 (-121)) (-4 *1 (-1130 *4)) (-4 *4 (-1054)))) (-2806 (*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-638 (-638 (-638 *4)))) (-5 *3 (-121)) (-4 *1 (-1130 *4)) (-4 *4 (-1054)))) (-2806 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-950 *3)))) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) (-2806 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-638 (-638 (-950 *4)))) (-5 *3 (-121)) (-4 *4 (-1054)) (-4 *1 (-1130 *4)))) (-2806 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-638 (-950 *3)))))) (-2939 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121)))) (-3555 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-950 *3))))) (-1669 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-638 (-638 (-769))))))) (-2665 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-638 (-638 (-950 *3))))))) (-3590 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-638 (-173)))))) (-2696 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-173))))) (-3989 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -4161 (-769)) (|:| |curves| (-769)) (|:| |polygons| (-769)) (|:| |constructs| (-769)))))) (-2285 (*1 *1 *1) (-12 (-4 *1 (-1130 *2)) (-4 *2 (-1054)))) (-4410 (*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-1158 3 *3))))) 
-(-13 (-1098) (-10 -8 (-15 -2045 ($)) (-15 -2045 ($ (-1158 3 |t#1|))) (-15 -1602 ((-769) $)) (-15 -2632 ((-769) $)) (-15 -4475 ($ (-638 $))) (-15 -4475 ($ $ $)) (-15 -2268 ($ (-638 $))) (-15 -2303 ((-638 $) $)) (-15 -2122 ((-638 $) $)) (-15 -1607 ($ $)) (-15 -4433 ((-769) $ (-638 (-950 |t#1|)))) (-15 -2832 ($ $ (-769) (-950 |t#1|))) (-15 -1767 ($ $ (-950 |t#1|))) (-15 -1767 ($ $ (-638 |t#1|))) (-15 -1767 ($ $ (-769))) (-15 -1767 ($ (-950 |t#1|))) (-15 -1767 ((-950 |t#1|) $)) (-15 -4448 ((-121) $)) (-15 -3702 ($ $ (-638 (-950 |t#1|)))) (-15 -3702 ($ $ (-638 (-638 |t#1|)))) (-15 -3702 ($ (-638 (-950 |t#1|)))) (-15 -3702 ((-638 (-950 |t#1|)) $)) (-15 -2874 ((-121) $)) (-15 -2092 ($ $ (-638 (-950 |t#1|)))) (-15 -2092 ($ $ (-638 (-638 |t#1|)))) (-15 -2092 ($ (-638 (-950 |t#1|)))) (-15 -2092 ((-638 (-950 |t#1|)) $)) (-15 -1916 ((-121) $)) (-15 -3759 ($ $ (-638 (-950 |t#1|)))) (-15 -3759 ($ $ (-638 (-638 |t#1|)))) (-15 -3759 ($ (-638 (-950 |t#1|)))) (-15 -3759 ((-638 (-950 |t#1|)) $)) (-15 -1583 ((-121) $)) (-15 -2806 ($ $ (-638 (-638 (-950 |t#1|))) (-638 (-173)) (-173))) (-15 -2806 ($ $ (-638 (-638 (-638 |t#1|))) (-638 (-173)) (-173))) (-15 -2806 ($ $ (-638 (-638 (-950 |t#1|))) (-121) (-121))) (-15 -2806 ($ $ (-638 (-638 (-638 |t#1|))) (-121) (-121))) (-15 -2806 ($ (-638 (-638 (-950 |t#1|))))) (-15 -2806 ($ (-638 (-638 (-950 |t#1|))) (-121) (-121))) (-15 -2806 ((-638 (-638 (-950 |t#1|))) $)) (-15 -2939 ((-121) $)) (-15 -3555 ((-638 (-950 |t#1|)) $)) (-15 -1669 ((-638 (-638 (-638 (-769)))) $)) (-15 -2665 ((-638 (-638 (-638 (-950 |t#1|)))) $)) (-15 -3590 ((-638 (-638 (-173))) $)) (-15 -2696 ((-638 (-173)) $)) (-15 -3989 ((-2 (|:| -4161 (-769)) (|:| |curves| (-769)) (|:| |polygons| (-769)) (|:| |constructs| (-769))) $)) (-15 -2285 ($ $)) (-15 -4410 ((-1158 3 |t#1|) $)) (-15 -3972 ((-856) $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-3554 (((-1264) (-638 (-856))) 23) (((-1264) (-856)) 22)) (-4411 (((-1264) (-638 (-856))) 21) (((-1264) (-856)) 20)) (-4355 (((-1264) (-638 (-856))) 19) (((-1264) (-856)) 11) (((-1264) (-1152) (-856)) 17))) 
-(((-1131) (-10 -7 (-15 -4355 ((-1264) (-1152) (-856))) (-15 -4355 ((-1264) (-856))) (-15 -4411 ((-1264) (-856))) (-15 -3554 ((-1264) (-856))) (-15 -4355 ((-1264) (-638 (-856)))) (-15 -4411 ((-1264) (-638 (-856)))) (-15 -3554 ((-1264) (-638 (-856)))))) (T -1131)) 
-((-3554 (*1 *2 *3) (-12 (-5 *3 (-638 (-856))) (-5 *2 (-1264)) (-5 *1 (-1131)))) (-4411 (*1 *2 *3) (-12 (-5 *3 (-638 (-856))) (-5 *2 (-1264)) (-5 *1 (-1131)))) (-4355 (*1 *2 *3) (-12 (-5 *3 (-638 (-856))) (-5 *2 (-1264)) (-5 *1 (-1131)))) (-3554 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-1131)))) (-4411 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-1131)))) (-4355 (*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-1131)))) (-4355 (*1 *2 *3 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-856)) (-5 *2 (-1264)) (-5 *1 (-1131))))) 
-(-10 -7 (-15 -4355 ((-1264) (-1152) (-856))) (-15 -4355 ((-1264) (-856))) (-15 -4411 ((-1264) (-856))) (-15 -3554 ((-1264) (-856))) (-15 -4355 ((-1264) (-638 (-856)))) (-15 -4411 ((-1264) (-638 (-856)))) (-15 -3554 ((-1264) (-638 (-856))))) 
-((-1459 (($ $ $) 10)) (-2350 (($ $) 9)) (-3045 (($ $ $) 13)) (-2625 (($ $ $) 15)) (-2312 (($ $ $) 12)) (-2638 (($ $ $) 14)) (-3804 (($ $) 17)) (-1465 (($ $) 16)) (-2264 (($ $) 6)) (-1877 (($ $ $) 11) (($ $) 7)) (-1869 (($ $ $) 8))) 
-(((-1132) (-1290)) (T -1132)) 
-((-3804 (*1 *1 *1) (-4 *1 (-1132))) (-1465 (*1 *1 *1) (-4 *1 (-1132))) (-2625 (*1 *1 *1 *1) (-4 *1 (-1132))) (-2638 (*1 *1 *1 *1) (-4 *1 (-1132))) (-3045 (*1 *1 *1 *1) (-4 *1 (-1132))) (-2312 (*1 *1 *1 *1) (-4 *1 (-1132))) (-1877 (*1 *1 *1 *1) (-4 *1 (-1132))) (-1459 (*1 *1 *1 *1) (-4 *1 (-1132))) (-2350 (*1 *1 *1) (-4 *1 (-1132))) (-1869 (*1 *1 *1 *1) (-4 *1 (-1132))) (-1877 (*1 *1 *1) (-4 *1 (-1132))) (-2264 (*1 *1 *1) (-4 *1 (-1132)))) 
-(-13 (-10 -8 (-15 -2264 ($ $)) (-15 -1877 ($ $)) (-15 -1869 ($ $ $)) (-15 -2350 ($ $)) (-15 -1459 ($ $ $)) (-15 -1877 ($ $ $)) (-15 -2312 ($ $ $)) (-15 -3045 ($ $ $)) (-15 -2638 ($ $ $)) (-15 -2625 ($ $ $)) (-15 -1465 ($ $)) (-15 -3804 ($ $)))) 
-((-2262 (((-121) $ $) 41)) (-2148 ((|#1| $) 15)) (-3769 (((-121) $ $ (-1 (-121) |#2| |#2|)) 36)) (-1541 (((-121) $) 17)) (-4041 (($ $ |#1|) 28)) (-2812 (($ $ (-121)) 30)) (-3552 (($ $) 31)) (-2391 (($ $ |#2|) 29)) (-1658 (((-1152) $) NIL)) (-4078 (((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|)) 35)) (-2607 (((-1116) $) NIL)) (-4037 (((-121) $) 14)) (-1665 (($) 10)) (-1607 (($ $) 27)) (-3921 (($ |#1| |#2| (-121)) 18) (($ |#1| |#2|) 19) (($ (-2 (|:| |val| |#1|) (|:| -1337 |#2|))) 21) (((-638 $) (-638 (-2 (|:| |val| |#1|) (|:| -1337 |#2|)))) 24) (((-638 $) |#1| (-638 |#2|)) 26)) (-3699 ((|#2| $) 16)) (-3972 (((-856) $) 50)) (-1324 (((-121) $ $) 39))) 
-(((-1133 |#1| |#2|) (-13 (-1098) (-10 -8 (-15 -1665 ($)) (-15 -4037 ((-121) $)) (-15 -2148 (|#1| $)) (-15 -3699 (|#2| $)) (-15 -1541 ((-121) $)) (-15 -3921 ($ |#1| |#2| (-121))) (-15 -3921 ($ |#1| |#2|)) (-15 -3921 ($ (-2 (|:| |val| |#1|) (|:| -1337 |#2|)))) (-15 -3921 ((-638 $) (-638 (-2 (|:| |val| |#1|) (|:| -1337 |#2|))))) (-15 -3921 ((-638 $) |#1| (-638 |#2|))) (-15 -1607 ($ $)) (-15 -4041 ($ $ |#1|)) (-15 -2391 ($ $ |#2|)) (-15 -2812 ($ $ (-121))) (-15 -3552 ($ $)) (-15 -4078 ((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|))) (-15 -3769 ((-121) $ $ (-1 (-121) |#2| |#2|))))) (-13 (-1098) (-39)) (-13 (-1098) (-39))) (T -1133)) 
-((-1665 (*1 *1) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-4037 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))))) (-2148 (*1 *2 *1) (-12 (-4 *2 (-13 (-1098) (-39))) (-5 *1 (-1133 *2 *3)) (-4 *3 (-13 (-1098) (-39))))) (-3699 (*1 *2 *1) (-12 (-4 *2 (-13 (-1098) (-39))) (-5 *1 (-1133 *3 *2)) (-4 *3 (-13 (-1098) (-39))))) (-1541 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))))) (-3921 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-3921 (*1 *1 *2 *3) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-3921 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |val| *3) (|:| -1337 *4))) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1133 *3 *4)))) (-3921 (*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| |val| *4) (|:| -1337 *5)))) (-4 *4 (-13 (-1098) (-39))) (-4 *5 (-13 (-1098) (-39))) (-5 *2 (-638 (-1133 *4 *5))) (-5 *1 (-1133 *4 *5)))) (-3921 (*1 *2 *3 *4) (-12 (-5 *4 (-638 *5)) (-4 *5 (-13 (-1098) (-39))) (-5 *2 (-638 (-1133 *3 *5))) (-5 *1 (-1133 *3 *5)) (-4 *3 (-13 (-1098) (-39))))) (-1607 (*1 *1 *1) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-4041 (*1 *1 *1 *2) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-2391 (*1 *1 *1 *2) (-12 (-5 *1 (-1133 *3 *2)) (-4 *3 (-13 (-1098) (-39))) (-4 *2 (-13 (-1098) (-39))))) (-2812 (*1 *1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))))) (-3552 (*1 *1 *1) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-4078 (*1 *2 *1 *1 *3 *4) (-12 (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1098) (-39))) (-4 *6 (-13 (-1098) (-39))) (-5 *2 (-121)) (-5 *1 (-1133 *5 *6)))) (-3769 (*1 *2 *1 *1 *3) (-12 (-5 *3 (-1 (-121) *5 *5)) (-4 *5 (-13 (-1098) (-39))) (-5 *2 (-121)) (-5 *1 (-1133 *4 *5)) (-4 *4 (-13 (-1098) (-39)))))) 
-(-13 (-1098) (-10 -8 (-15 -1665 ($)) (-15 -4037 ((-121) $)) (-15 -2148 (|#1| $)) (-15 -3699 (|#2| $)) (-15 -1541 ((-121) $)) (-15 -3921 ($ |#1| |#2| (-121))) (-15 -3921 ($ |#1| |#2|)) (-15 -3921 ($ (-2 (|:| |val| |#1|) (|:| -1337 |#2|)))) (-15 -3921 ((-638 $) (-638 (-2 (|:| |val| |#1|) (|:| -1337 |#2|))))) (-15 -3921 ((-638 $) |#1| (-638 |#2|))) (-15 -1607 ($ $)) (-15 -4041 ($ $ |#1|)) (-15 -2391 ($ $ |#2|)) (-15 -2812 ($ $ (-121))) (-15 -3552 ($ $)) (-15 -4078 ((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|))) (-15 -3769 ((-121) $ $ (-1 (-121) |#2| |#2|))))) 
-((-2262 (((-121) $ $) NIL (|has| (-1133 |#1| |#2|) (-1098)))) (-2148 (((-1133 |#1| |#2|) $) 25)) (-2686 (($ $) 75)) (-4391 (((-121) (-1133 |#1| |#2|) $ (-1 (-121) |#2| |#2|)) 84)) (-1422 (($ $ $ (-638 (-1133 |#1| |#2|))) 89) (($ $ $ (-638 (-1133 |#1| |#2|)) (-1 (-121) |#2| |#2|)) 90)) (-1946 (((-121) $ (-769)) NIL)) (-4436 (((-1133 |#1| |#2|) $ (-1133 |#1| |#2|)) 42 (|has| $ (-6 -4603)))) (-3283 (((-1133 |#1| |#2|) $ "value" (-1133 |#1| |#2|)) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 40 (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-4139 (((-638 (-2 (|:| |val| |#1|) (|:| -1337 |#2|))) $) 79)) (-1544 (($ (-1133 |#1| |#2|) $) 38)) (-3445 (($ (-1133 |#1| |#2|) $) 30)) (-2010 (((-638 (-1133 |#1| |#2|)) $) NIL (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 50)) (-1361 (((-121) (-1133 |#1| |#2|) $) 81)) (-1303 (((-121) $ $) NIL (|has| (-1133 |#1| |#2|) (-1098)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 (-1133 |#1| |#2|)) $) 54 (|has| $ (-6 -4602)))) (-3002 (((-121) (-1133 |#1| |#2|) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-1133 |#1| |#2|) (-1098))))) (-2435 (($ (-1 (-1133 |#1| |#2|) (-1133 |#1| |#2|)) $) 46 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-1133 |#1| |#2|) (-1133 |#1| |#2|)) $) 45)) (-3524 (((-121) $ (-769)) NIL)) (-2699 (((-638 (-1133 |#1| |#2|)) $) 52)) (-3113 (((-121) $) 41)) (-1658 (((-1152) $) NIL (|has| (-1133 |#1| |#2|) (-1098)))) (-2607 (((-1116) $) NIL (|has| (-1133 |#1| |#2|) (-1098)))) (-4277 (((-3 $ "failed") $) 74)) (-2109 (((-121) (-1 (-121) (-1133 |#1| |#2|)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-1133 |#1| |#2|)))) NIL (-12 (|has| (-1133 |#1| |#2|) (-305 (-1133 |#1| |#2|))) (|has| (-1133 |#1| |#2|) (-1098)))) (($ $ (-290 (-1133 |#1| |#2|))) NIL (-12 (|has| (-1133 |#1| |#2|) (-305 (-1133 |#1| |#2|))) (|has| (-1133 |#1| |#2|) (-1098)))) (($ $ (-1133 |#1| |#2|) (-1133 |#1| |#2|)) NIL (-12 (|has| (-1133 |#1| |#2|) (-305 (-1133 |#1| |#2|))) (|has| (-1133 |#1| |#2|) (-1098)))) (($ $ (-638 (-1133 |#1| |#2|)) (-638 (-1133 |#1| |#2|))) NIL (-12 (|has| (-1133 |#1| |#2|) (-305 (-1133 |#1| |#2|))) (|has| (-1133 |#1| |#2|) (-1098))))) (-3598 (((-121) $ $) 49)) (-4037 (((-121) $) 22)) (-1665 (($) 24)) (-3277 (((-1133 |#1| |#2|) $ "value") NIL)) (-3537 (((-572) $ $) NIL)) (-1791 (((-121) $) 43)) (-1571 (((-769) (-1 (-121) (-1133 |#1| |#2|)) $) NIL (|has| $ (-6 -4602))) (((-769) (-1133 |#1| |#2|) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-1133 |#1| |#2|) (-1098))))) (-1607 (($ $) 48)) (-3921 (($ (-1133 |#1| |#2|)) 9) (($ |#1| |#2| (-638 $)) 12) (($ |#1| |#2| (-638 (-1133 |#1| |#2|))) 14) (($ |#1| |#2| |#1| (-638 |#2|)) 17)) (-3301 (((-638 |#2|) $) 80)) (-3972 (((-856) $) 72 (|has| (-1133 |#1| |#2|) (-1098)))) (-4118 (((-638 $) $) 28)) (-3432 (((-121) $ $) NIL (|has| (-1133 |#1| |#2|) (-1098)))) (-3501 (((-121) (-1 (-121) (-1133 |#1| |#2|)) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 63 (|has| (-1133 |#1| |#2|) (-1098)))) (-4032 (((-769) $) 57 (|has| $ (-6 -4602))))) 
-(((-1134 |#1| |#2|) (-13 (-1017 (-1133 |#1| |#2|)) (-10 -8 (-6 -4603) (-6 -4602) (-15 -4277 ((-3 $ "failed") $)) (-15 -2686 ($ $)) (-15 -3921 ($ (-1133 |#1| |#2|))) (-15 -3921 ($ |#1| |#2| (-638 $))) (-15 -3921 ($ |#1| |#2| (-638 (-1133 |#1| |#2|)))) (-15 -3921 ($ |#1| |#2| |#1| (-638 |#2|))) (-15 -3301 ((-638 |#2|) $)) (-15 -4139 ((-638 (-2 (|:| |val| |#1|) (|:| -1337 |#2|))) $)) (-15 -1361 ((-121) (-1133 |#1| |#2|) $)) (-15 -4391 ((-121) (-1133 |#1| |#2|) $ (-1 (-121) |#2| |#2|))) (-15 -3445 ($ (-1133 |#1| |#2|) $)) (-15 -1544 ($ (-1133 |#1| |#2|) $)) (-15 -1422 ($ $ $ (-638 (-1133 |#1| |#2|)))) (-15 -1422 ($ $ $ (-638 (-1133 |#1| |#2|)) (-1 (-121) |#2| |#2|))))) (-13 (-1098) (-39)) (-13 (-1098) (-39))) (T -1134)) 
-((-4277 (*1 *1 *1) (|partial| -12 (-5 *1 (-1134 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-2686 (*1 *1 *1) (-12 (-5 *1 (-1134 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-3921 (*1 *1 *2) (-12 (-5 *2 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1134 *3 *4)))) (-3921 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-638 (-1134 *2 *3))) (-5 *1 (-1134 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) (-3921 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-638 (-1133 *2 *3))) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))) (-5 *1 (-1134 *2 *3)))) (-3921 (*1 *1 *2 *3 *2 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-13 (-1098) (-39))) (-5 *1 (-1134 *2 *3)) (-4 *2 (-13 (-1098) (-39))))) (-3301 (*1 *2 *1) (-12 (-5 *2 (-638 *4)) (-5 *1 (-1134 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))))) (-4139 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1134 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))))) (-1361 (*1 *2 *3 *1) (-12 (-5 *3 (-1133 *4 *5)) (-4 *4 (-13 (-1098) (-39))) (-4 *5 (-13 (-1098) (-39))) (-5 *2 (-121)) (-5 *1 (-1134 *4 *5)))) (-4391 (*1 *2 *3 *1 *4) (-12 (-5 *3 (-1133 *5 *6)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1098) (-39))) (-4 *6 (-13 (-1098) (-39))) (-5 *2 (-121)) (-5 *1 (-1134 *5 *6)))) (-3445 (*1 *1 *2 *1) (-12 (-5 *2 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1134 *3 *4)))) (-1544 (*1 *1 *2 *1) (-12 (-5 *2 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1134 *3 *4)))) (-1422 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-638 (-1133 *3 *4))) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1134 *3 *4)))) (-1422 (*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1133 *4 *5))) (-5 *3 (-1 (-121) *5 *5)) (-4 *4 (-13 (-1098) (-39))) (-4 *5 (-13 (-1098) (-39))) (-5 *1 (-1134 *4 *5))))) 
-(-13 (-1017 (-1133 |#1| |#2|)) (-10 -8 (-6 -4603) (-6 -4602) (-15 -4277 ((-3 $ "failed") $)) (-15 -2686 ($ $)) (-15 -3921 ($ (-1133 |#1| |#2|))) (-15 -3921 ($ |#1| |#2| (-638 $))) (-15 -3921 ($ |#1| |#2| (-638 (-1133 |#1| |#2|)))) (-15 -3921 ($ |#1| |#2| |#1| (-638 |#2|))) (-15 -3301 ((-638 |#2|) $)) (-15 -4139 ((-638 (-2 (|:| |val| |#1|) (|:| -1337 |#2|))) $)) (-15 -1361 ((-121) (-1133 |#1| |#2|) $)) (-15 -4391 ((-121) (-1133 |#1| |#2|) $ (-1 (-121) |#2| |#2|))) (-15 -3445 ($ (-1133 |#1| |#2|) $)) (-15 -1544 ($ (-1133 |#1| |#2|) $)) (-15 -1422 ($ $ $ (-638 (-1133 |#1| |#2|)))) (-15 -1422 ($ $ $ (-638 (-1133 |#1| |#2|)) (-1 (-121) |#2| |#2|))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1444 (($ $) NIL)) (-3520 ((|#2| $) NIL)) (-3083 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1304 (($ (-685 |#2|)) 45)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-1468 (($ |#2|) 9)) (-2211 (($) NIL T CONST)) (-3292 (($ $) 58 (|has| |#2| (-303)))) (-4267 (((-234 |#1| |#2|) $ (-572)) 31)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 |#2| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) ((|#2| $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) 72)) (-2667 (((-769) $) 60 (|has| |#2| (-562)))) (-4212 ((|#2| $ (-572) (-572)) NIL)) (-2010 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3893 (((-121) $) NIL)) (-3095 (((-769) $) 62 (|has| |#2| (-562)))) (-1301 (((-638 (-234 |#1| |#2|)) $) 66 (|has| |#2| (-562)))) (-3704 (((-769) $) NIL)) (-3712 (((-769) $) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-1522 ((|#2| $) 56 (|has| |#2| (-6 (-4604 "*"))))) (-2660 (((-572) $) NIL)) (-3092 (((-572) $) NIL)) (-4467 (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-3927 (((-572) $) NIL)) (-3227 (((-572) $) NIL)) (-3597 (($ (-638 (-638 |#2|))) 26)) (-2435 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 |#2| |#2|) $) NIL)) (-2259 (((-638 (-638 |#2|)) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-3750 (((-3 $ "failed") $) 69 (|has| |#2| (-368)))) (-2607 (((-1116) $) NIL)) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562)))) (-2109 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ (-572) (-572) |#2|) NIL) ((|#2| $ (-572) (-572)) NIL)) (-3139 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-769)) NIL (|has| |#2| (-227))) (($ $) NIL (|has| |#2| (-227)))) (-3807 ((|#2| $) NIL)) (-3132 (($ (-638 |#2|)) 40)) (-3785 (((-121) $) NIL)) (-4479 (((-234 |#1| |#2|) $) NIL)) (-2271 ((|#2| $) 54 (|has| |#2| (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-1607 (($ $) NIL)) (-4081 (((-545) $) 81 (|has| |#2| (-613 (-545))))) (-4580 (((-234 |#1| |#2|) $ (-572)) 33)) (-3972 (((-856) $) 36) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#2| (-1044 (-413 (-572))))) (($ |#2|) NIL) (((-685 |#2|) $) 42)) (-2140 (((-769)) 17)) (-3501 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 11 T CONST)) (-3255 (($) 14 T CONST)) (-1557 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-769)) NIL (|has| |#2| (-227))) (($ $) NIL (|has| |#2| (-227)))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) 52) (($ $ (-572)) 71 (|has| |#2| (-368)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (((-234 |#1| |#2|) $ (-234 |#1| |#2|)) 48) (((-234 |#1| |#2|) (-234 |#1| |#2|) $) 50)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1135 |#1| |#2|) (-13 (-1119 |#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) (-612 (-685 |#2|)) (-10 -8 (-15 -1444 ($ $)) (-15 -1304 ($ (-685 |#2|))) (-15 -3972 ((-685 |#2|) $)) (IF (|has| |#2| (-6 (-4604 "*"))) (-6 -4591) |noBranch|) (IF (|has| |#2| (-6 (-4604 "*"))) (IF (|has| |#2| (-6 -4599)) (-6 -4599) |noBranch|) |noBranch|) (IF (|has| |#2| (-613 (-545))) (-6 (-613 (-545))) |noBranch|))) (-769) (-1054)) (T -1135)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-685 *4)) (-5 *1 (-1135 *3 *4)) (-14 *3 (-769)) (-4 *4 (-1054)))) (-1444 (*1 *1 *1) (-12 (-5 *1 (-1135 *2 *3)) (-14 *2 (-769)) (-4 *3 (-1054)))) (-1304 (*1 *1 *2) (-12 (-5 *2 (-685 *4)) (-4 *4 (-1054)) (-5 *1 (-1135 *3 *4)) (-14 *3 (-769))))) 
-(-13 (-1119 |#1| |#2| (-234 |#1| |#2|) (-234 |#1| |#2|)) (-612 (-685 |#2|)) (-10 -8 (-15 -1444 ($ $)) (-15 -1304 ($ (-685 |#2|))) (-15 -3972 ((-685 |#2|) $)) (IF (|has| |#2| (-6 (-4604 "*"))) (-6 -4591) |noBranch|) (IF (|has| |#2| (-6 (-4604 "*"))) (IF (|has| |#2| (-6 -4599)) (-6 -4599) |noBranch|) |noBranch|) (IF (|has| |#2| (-613 (-545))) (-6 (-613 (-545))) |noBranch|))) 
-((-4013 (($ $) 19)) (-3867 (($ $ (-148)) 10) (($ $ (-143)) 14)) (-2174 (((-121) $ $) 24)) (-2676 (($ $) 17)) (-3277 (((-148) $ (-572) (-148)) NIL) (((-148) $ (-572)) NIL) (($ $ (-1225 (-572))) NIL) (($ $ $) 29)) (-3972 (($ (-148)) 27) (((-856) $) NIL))) 
-(((-1136 |#1|) (-10 -8 (-15 -3972 ((-856) |#1|)) (-15 -3277 (|#1| |#1| |#1|)) (-15 -3867 (|#1| |#1| (-143))) (-15 -3867 (|#1| |#1| (-148))) (-15 -3972 (|#1| (-148))) (-15 -2174 ((-121) |#1| |#1|)) (-15 -4013 (|#1| |#1|)) (-15 -2676 (|#1| |#1|)) (-15 -3277 (|#1| |#1| (-1225 (-572)))) (-15 -3277 ((-148) |#1| (-572))) (-15 -3277 ((-148) |#1| (-572) (-148)))) (-1137)) (T -1136)) 
-NIL 
-(-10 -8 (-15 -3972 ((-856) |#1|)) (-15 -3277 (|#1| |#1| |#1|)) (-15 -3867 (|#1| |#1| (-143))) (-15 -3867 (|#1| |#1| (-148))) (-15 -3972 (|#1| (-148))) (-15 -2174 ((-121) |#1| |#1|)) (-15 -4013 (|#1| |#1|)) (-15 -2676 (|#1| |#1|)) (-15 -3277 (|#1| |#1| (-1225 (-572)))) (-15 -3277 ((-148) |#1| (-572))) (-15 -3277 ((-148) |#1| (-572) (-148)))) 
-((-2262 (((-121) $ $) 18 (|has| (-148) (-1098)))) (-4092 (($ $) 113)) (-4013 (($ $) 114)) (-3867 (($ $ (-148)) 101) (($ $ (-143)) 100)) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-2066 (((-121) $ $) 111)) (-2013 (((-121) $ $ (-572)) 110)) (-1585 (((-638 $) $ (-148)) 103) (((-638 $) $ (-143)) 102)) (-2041 (((-121) (-1 (-121) (-148) (-148)) $) 91) (((-121) $) 85 (|has| (-148) (-848)))) (-4131 (($ (-1 (-121) (-148) (-148)) $) 82 (|has| $ (-6 -4603))) (($ $) 81 (-12 (|has| (-148) (-848)) (|has| $ (-6 -4603))))) (-3008 (($ (-1 (-121) (-148) (-148)) $) 92) (($ $) 86 (|has| (-148) (-848)))) (-1946 (((-121) $ (-769)) 8)) (-3283 (((-148) $ (-572) (-148)) 49 (|has| $ (-6 -4603))) (((-148) $ (-1225 (-572)) (-148)) 53 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-148)) $) 70 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-3429 (($ $ (-148)) 97) (($ $ (-143)) 96)) (-2985 (($ $) 83 (|has| $ (-6 -4603)))) (-1656 (($ $) 93)) (-3808 (($ $ (-1225 (-572)) $) 107)) (-1643 (($ $) 73 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ (-148) $) 72 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) (-148)) $) 69 (|has| $ (-6 -4602)))) (-3116 (((-148) (-1 (-148) (-148) (-148)) $ (-148) (-148)) 71 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602)))) (((-148) (-1 (-148) (-148) (-148)) $ (-148)) 68 (|has| $ (-6 -4602))) (((-148) (-1 (-148) (-148) (-148)) $) 67 (|has| $ (-6 -4602)))) (-3037 (((-148) $ (-572) (-148)) 50 (|has| $ (-6 -4603)))) (-4212 (((-148) $ (-572)) 48)) (-2174 (((-121) $ $) 112)) (-4014 (((-572) (-1 (-121) (-148)) $) 90) (((-572) (-148) $) 89 (|has| (-148) (-1098))) (((-572) (-148) $ (-572)) 88 (|has| (-148) (-1098))) (((-572) $ $ (-572)) 106) (((-572) (-143) $ (-572)) 105)) (-2010 (((-638 (-148)) $) 30 (|has| $ (-6 -4602)))) (-1364 (($ (-769) (-148)) 64)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-1771 (($ $ $) 80 (|has| (-148) (-848)))) (-4475 (($ (-1 (-121) (-148) (-148)) $ $) 94) (($ $ $) 87 (|has| (-148) (-848)))) (-4467 (((-638 (-148)) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) (-148) $) 27 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-4238 (($ $ $) 79 (|has| (-148) (-848)))) (-2524 (((-121) $ $ (-148)) 108)) (-3724 (((-769) $ $ (-148)) 109)) (-2435 (($ (-1 (-148) (-148)) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-148) (-148)) $) 35) (($ (-1 (-148) (-148) (-148)) $ $) 59)) (-2895 (($ $) 115)) (-2676 (($ $) 116)) (-3524 (((-121) $ (-769)) 10)) (-1796 (($ $ (-148)) 99) (($ $ (-143)) 98)) (-1658 (((-1152) $) 22 (|has| (-148) (-1098)))) (-2603 (($ (-148) $ (-572)) 55) (($ $ $ (-572)) 54)) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-2607 (((-1116) $) 21 (|has| (-148) (-1098)))) (-1837 (((-148) $) 39 (|has| (-572) (-848)))) (-3361 (((-3 (-148) "failed") (-1 (-121) (-148)) $) 66)) (-3299 (($ $ (-148)) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-148)) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-148)))) 26 (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-290 (-148))) 25 (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-148) (-148)) 24 (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-638 (-148)) (-638 (-148))) 23 (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) (-148) $) 42 (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-2957 (((-638 (-148)) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 (((-148) $ (-572) (-148)) 47) (((-148) $ (-572)) 46) (($ $ (-1225 (-572))) 58) (($ $ $) 95)) (-1940 (($ $ (-572)) 57) (($ $ (-1225 (-572))) 56)) (-1571 (((-769) (-1 (-121) (-148)) $) 31 (|has| $ (-6 -4602))) (((-769) (-148) $) 28 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602))))) (-2907 (($ $ $ (-572)) 84 (|has| $ (-6 -4603)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 74 (|has| (-148) (-613 (-545))))) (-3921 (($ (-638 (-148))) 65)) (-4500 (($ $ (-148)) 63) (($ (-148) $) 62) (($ $ $) 61) (($ (-638 $)) 60)) (-3972 (($ (-148)) 104) (((-856) $) 20 (|has| (-148) (-1098)))) (-3501 (((-121) (-1 (-121) (-148)) $) 33 (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) 77 (|has| (-148) (-848)))) (-1338 (((-121) $ $) 76 (|has| (-148) (-848)))) (-1324 (((-121) $ $) 19 (|has| (-148) (-1098)))) (-1343 (((-121) $ $) 78 (|has| (-148) (-848)))) (-1334 (((-121) $ $) 75 (|has| (-148) (-848)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1137) (-1290)) (T -1137)) 
-((-2676 (*1 *1 *1) (-4 *1 (-1137))) (-2895 (*1 *1 *1) (-4 *1 (-1137))) (-4013 (*1 *1 *1) (-4 *1 (-1137))) (-4092 (*1 *1 *1) (-4 *1 (-1137))) (-2174 (*1 *2 *1 *1) (-12 (-4 *1 (-1137)) (-5 *2 (-121)))) (-2066 (*1 *2 *1 *1) (-12 (-4 *1 (-1137)) (-5 *2 (-121)))) (-2013 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1137)) (-5 *3 (-572)) (-5 *2 (-121)))) (-3724 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1137)) (-5 *3 (-148)) (-5 *2 (-769)))) (-2524 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1137)) (-5 *3 (-148)) (-5 *2 (-121)))) (-3808 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-1137)) (-5 *2 (-1225 (-572))))) (-4014 (*1 *2 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-572)))) (-4014 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-572)) (-5 *3 (-143)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-148)) (-4 *1 (-1137)))) (-1585 (*1 *2 *1 *3) (-12 (-5 *3 (-148)) (-5 *2 (-638 *1)) (-4 *1 (-1137)))) (-1585 (*1 *2 *1 *3) (-12 (-5 *3 (-143)) (-5 *2 (-638 *1)) (-4 *1 (-1137)))) (-3867 (*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-148)))) (-3867 (*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-143)))) (-1796 (*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-148)))) (-1796 (*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-143)))) (-3429 (*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-148)))) (-3429 (*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-143)))) (-3277 (*1 *1 *1 *1) (-4 *1 (-1137)))) 
-(-13 (-19 (-148)) (-10 -8 (-15 -2676 ($ $)) (-15 -2895 ($ $)) (-15 -4013 ($ $)) (-15 -4092 ($ $)) (-15 -2174 ((-121) $ $)) (-15 -2066 ((-121) $ $)) (-15 -2013 ((-121) $ $ (-572))) (-15 -3724 ((-769) $ $ (-148))) (-15 -2524 ((-121) $ $ (-148))) (-15 -3808 ($ $ (-1225 (-572)) $)) (-15 -4014 ((-572) $ $ (-572))) (-15 -4014 ((-572) (-143) $ (-572))) (-15 -3972 ($ (-148))) (-15 -1585 ((-638 $) $ (-148))) (-15 -1585 ((-638 $) $ (-143))) (-15 -3867 ($ $ (-148))) (-15 -3867 ($ $ (-143))) (-15 -1796 ($ $ (-148))) (-15 -1796 ($ $ (-143))) (-15 -3429 ($ $ (-148))) (-15 -3429 ($ $ (-143))) (-15 -3277 ($ $ $)))) 
-(((-39) . T) ((-105) -1841 (|has| (-148) (-1098)) (|has| (-148) (-848))) ((-612 (-856)) -1841 (|has| (-148) (-1098)) (|has| (-148) (-848))) ((-155 (-148)) . T) ((-613 (-545)) |has| (-148) (-613 (-545))) ((-283 (-572) (-148)) . T) ((-285 (-572) (-148)) . T) ((-305 (-148)) -12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))) ((-379 (-148)) . T) ((-503 (-148)) . T) ((-605 (-572) (-148)) . T) ((-527 (-148) (-148)) -12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))) ((-644 (-148)) . T) ((-19 (-148)) . T) ((-848) |has| (-148) (-848)) ((-1098) -1841 (|has| (-148) (-1098)) (|has| (-148) (-848))) ((-1204) . T)) 
-((-3734 (((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 |#4|) (-638 |#5|) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-769)) 93)) (-1362 (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|) 54) (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769)) 53)) (-2936 (((-1264) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-769)) 85)) (-3094 (((-769) (-638 |#4|) (-638 |#5|)) 27)) (-4033 (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|) 56) (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769)) 55) (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769) (-121)) 57)) (-2880 (((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121) (-121) (-121) (-121)) 76) (((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121)) 77)) (-4081 (((-1152) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) 80)) (-4444 (((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|) 52)) (-2154 (((-769) (-638 |#4|) (-638 |#5|)) 19))) 
-(((-1138 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2154 ((-769) (-638 |#4|) (-638 |#5|))) (-15 -3094 ((-769) (-638 |#4|) (-638 |#5|))) (-15 -4444 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -1362 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769))) (-15 -1362 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769) (-121))) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769))) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -2880 ((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121))) (-15 -2880 ((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -3734 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 |#4|) (-638 |#5|) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-769))) (-15 -4081 ((-1152) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) (-15 -2936 ((-1264) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-769)))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|) (-1107 |#1| |#2| |#3| |#4|)) (T -1138)) 
-((-2936 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| |val| (-638 *8)) (|:| -1337 *9)))) (-5 *4 (-769)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-1264)) (-5 *1 (-1138 *5 *6 *7 *8 *9)))) (-4081 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-638 *7)) (|:| -1337 *8))) (-4 *7 (-1068 *4 *5 *6)) (-4 *8 (-1107 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1152)) (-5 *1 (-1138 *4 *5 *6 *7 *8)))) (-3734 (*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-638 *11)) (|:| |todo| (-638 (-2 (|:| |val| *3) (|:| -1337 *11)))))) (-5 *6 (-769)) (-5 *2 (-638 (-2 (|:| |val| (-638 *10)) (|:| -1337 *11)))) (-5 *3 (-638 *10)) (-5 *4 (-638 *11)) (-4 *10 (-1068 *7 *8 *9)) (-4 *11 (-1107 *7 *8 *9 *10)) (-4 *7 (-457)) (-4 *8 (-794)) (-4 *9 (-848)) (-5 *1 (-1138 *7 *8 *9 *10 *11)))) (-2880 (*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-638 *9)) (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1138 *5 *6 *7 *8 *9)))) (-2880 (*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-638 *9)) (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1138 *5 *6 *7 *8 *9)))) (-4033 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *5 *6 *7 *3 *4)) (-4 *4 (-1107 *5 *6 *7 *3)))) (-4033 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *6 *7 *8 *3 *4)) (-4 *4 (-1107 *6 *7 *8 *3)))) (-4033 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-769)) (-5 *6 (-121)) (-4 *7 (-457)) (-4 *8 (-794)) (-4 *9 (-848)) (-4 *3 (-1068 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *7 *8 *9 *3 *4)) (-4 *4 (-1107 *7 *8 *9 *3)))) (-1362 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *5 *6 *7 *3 *4)) (-4 *4 (-1107 *5 *6 *7 *3)))) (-1362 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *6 *7 *8 *3 *4)) (-4 *4 (-1107 *6 *7 *8 *3)))) (-4444 (*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *5 *6 *7 *3 *4)) (-4 *4 (-1107 *5 *6 *7 *3)))) (-3094 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *9)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-769)) (-5 *1 (-1138 *5 *6 *7 *8 *9)))) (-2154 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *9)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-769)) (-5 *1 (-1138 *5 *6 *7 *8 *9))))) 
-(-10 -7 (-15 -2154 ((-769) (-638 |#4|) (-638 |#5|))) (-15 -3094 ((-769) (-638 |#4|) (-638 |#5|))) (-15 -4444 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -1362 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769))) (-15 -1362 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769) (-121))) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5| (-769))) (-15 -4033 ((-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) |#4| |#5|)) (-15 -2880 ((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121))) (-15 -2880 ((-638 |#5|) (-638 |#4|) (-638 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -3734 ((-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-638 |#4|) (-638 |#5|) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-2 (|:| |done| (-638 |#5|)) (|:| |todo| (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))))) (-769))) (-15 -4081 ((-1152) (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|)))) (-15 -2936 ((-1264) (-638 (-2 (|:| |val| (-638 |#4|)) (|:| -1337 |#5|))) (-769)))) 
-((-2262 (((-121) $ $) NIL)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) NIL)) (-4165 (((-638 $) (-638 |#4|)) 109) (((-638 $) (-638 |#4|) (-121)) 110) (((-638 $) (-638 |#4|) (-121) (-121)) 108) (((-638 $) (-638 |#4|) (-121) (-121) (-121) (-121)) 111)) (-3456 (((-638 |#3|) $) NIL)) (-3049 (((-121) $) NIL)) (-3289 (((-121) $) NIL (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1872 ((|#4| |#4| $) NIL)) (-2844 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| $) 83)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2561 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) 61)) (-2211 (($) NIL T CONST)) (-3097 (((-121) $) 26 (|has| |#1| (-562)))) (-3760 (((-121) $ $) NIL (|has| |#1| (-562)))) (-3819 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4331 (((-121) $) NIL (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3683 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) NIL)) (-1318 (($ (-638 |#4|)) NIL)) (-1651 (((-3 $ "failed") $) 39)) (-2242 ((|#4| |#4| $) 64)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-3445 (($ |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 77 (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-1673 ((|#4| |#4| $) NIL)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) NIL)) (-1706 (((-121) |#4| $) NIL)) (-2989 (((-121) |#4| $) NIL)) (-1366 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-3345 (((-2 (|:| |val| (-638 |#4|)) (|:| |towers| (-638 $))) (-638 |#4|) (-121) (-121)) 123)) (-2010 (((-638 |#4|) $) 16 (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#4|) $) 17 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-2435 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 21)) (-4062 (((-638 |#3|) $) NIL)) (-1346 (((-121) |#3| $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-2550 (((-3 |#4| (-638 $)) |#4| |#4| $) NIL)) (-4416 (((-638 (-2 (|:| |val| |#4|) (|:| -1337 $))) |#4| |#4| $) 102)) (-3253 (((-3 |#4| "failed") $) 37)) (-2173 (((-638 $) |#4| $) 87)) (-2471 (((-3 (-121) (-638 $)) |#4| $) NIL)) (-2338 (((-638 (-2 (|:| |val| (-121)) (|:| -1337 $))) |#4| $) 97) (((-121) |#4| $) 52)) (-1931 (((-638 $) |#4| $) 106) (((-638 $) (-638 |#4|) $) NIL) (((-638 $) (-638 |#4|) (-638 $)) 107) (((-638 $) |#4| (-638 $)) NIL)) (-1605 (((-638 $) (-638 |#4|) (-121) (-121) (-121)) 118)) (-3078 (($ |#4| $) 74) (($ (-638 |#4|) $) 75) (((-638 $) |#4| $ (-121) (-121) (-121) (-121) (-121)) 73)) (-3727 (((-638 |#4|) $) NIL)) (-1483 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2788 ((|#4| |#4| $) NIL)) (-1843 (((-121) $ $) NIL)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4498 ((|#4| |#4| $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-3 |#4| "failed") $) 35)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1928 (((-3 $ "failed") $ |#4|) 47)) (-1977 (($ $ |#4|) NIL) (((-638 $) |#4| $) 89) (((-638 $) |#4| (-638 $)) NIL) (((-638 $) (-638 |#4|) $) NIL) (((-638 $) (-638 |#4|) (-638 $)) 85)) (-2109 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 15)) (-1665 (($) 13)) (-4316 (((-769) $) NIL)) (-1571 (((-769) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (((-769) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) 12)) (-4081 (((-545) $) NIL (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 20)) (-1826 (($ $ |#3|) 42)) (-2291 (($ $ |#3|) 43)) (-3134 (($ $) NIL)) (-1650 (($ $ |#3|) NIL)) (-3972 (((-856) $) 31) (((-638 |#4|) $) 40)) (-2498 (((-769) $) NIL (|has| |#3| (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) NIL)) (-2589 (((-638 $) |#4| $) 53) (((-638 $) |#4| (-638 $)) NIL) (((-638 $) (-638 |#4|) $) NIL) (((-638 $) (-638 |#4|) (-638 $)) NIL)) (-3501 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) NIL)) (-4191 (((-121) |#4| $) NIL)) (-2213 (((-121) |#3| $) 60)) (-1324 (((-121) $ $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1139 |#1| |#2| |#3| |#4|) (-13 (-1107 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3078 ((-638 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -4165 ((-638 $) (-638 |#4|) (-121) (-121))) (-15 -4165 ((-638 $) (-638 |#4|) (-121) (-121) (-121) (-121))) (-15 -1605 ((-638 $) (-638 |#4|) (-121) (-121) (-121))) (-15 -3345 ((-2 (|:| |val| (-638 |#4|)) (|:| |towers| (-638 $))) (-638 |#4|) (-121) (-121))))) (-457) (-794) (-848) (-1068 |#1| |#2| |#3|)) (T -1139)) 
-((-3078 (*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1139 *5 *6 *7 *3))) (-5 *1 (-1139 *5 *6 *7 *3)) (-4 *3 (-1068 *5 *6 *7)))) (-4165 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1139 *5 *6 *7 *8))) (-5 *1 (-1139 *5 *6 *7 *8)))) (-4165 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1139 *5 *6 *7 *8))) (-5 *1 (-1139 *5 *6 *7 *8)))) (-1605 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1139 *5 *6 *7 *8))) (-5 *1 (-1139 *5 *6 *7 *8)))) (-3345 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-638 *8)) (|:| |towers| (-638 (-1139 *5 *6 *7 *8))))) (-5 *1 (-1139 *5 *6 *7 *8)) (-5 *3 (-638 *8))))) 
-(-13 (-1107 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3078 ((-638 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -4165 ((-638 $) (-638 |#4|) (-121) (-121))) (-15 -4165 ((-638 $) (-638 |#4|) (-121) (-121) (-121) (-121))) (-15 -1605 ((-638 $) (-638 |#4|) (-121) (-121) (-121))) (-15 -3345 ((-2 (|:| |val| (-638 |#4|)) (|:| |towers| (-638 $))) (-638 |#4|) (-121) (-121))))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1615 ((|#1| $) 28)) (-3777 (($ (-638 |#1|)) 33)) (-1946 (((-121) $ (-769)) NIL)) (-2211 (($) NIL T CONST)) (-4107 ((|#1| |#1| $) 30)) (-3772 ((|#1| $) 26)) (-2010 (((-638 |#1|) $) 34 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) 39 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 37)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-4221 ((|#1| $) 29)) (-1335 (($ |#1| $) 31)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2232 ((|#1| $) 27)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 24)) (-1665 (($) 32)) (-1564 (((-769) $) 22)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) 20)) (-3972 (((-856) $) 17 (|has| |#1| (-1098)))) (-3058 (($ (-638 |#1|)) NIL)) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 12 (|has| |#1| (-1098)))) (-4032 (((-769) $) 23 (|has| $ (-6 -4602))))) 
-(((-1140 |#1|) (-13 (-1117 |#1|) (-10 -8 (-15 -3777 ($ (-638 |#1|))) (-15 -3772 (|#1| $)) (-15 -2232 (|#1| $)) (-15 -4107 (|#1| |#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -1615 (|#1| $)) (-15 -1564 ((-769) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -3058 ($ (-638 |#1|))) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -2211 ($)) (-15 -1607 ($ $)) (-15 -3598 ((-121) $ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) (-1098)) (T -1140)) 
-((-3598 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)))) (-1607 (*1 *1 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-1665 (*1 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-4037 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)))) (-3524 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1140 *4)) (-4 *4 (-1098)))) (-2157 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1140 *4)) (-4 *4 (-1098)))) (-1946 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1140 *4)) (-4 *4 (-1098)))) (-2211 (*1 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-4032 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-1140 *3)))) (-2435 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-1098)) (-5 *1 (-1140 *3)))) (-3501 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-1140 *4)))) (-2109 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-1140 *4)))) (-1571 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-1140 *4)))) (-2010 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)))) (-1571 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3002 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-1658 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-2607 (*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-1324 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-2262 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) (-3058 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1140 *3)))) (-2232 (*1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-1335 (*1 *1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-4221 (*1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-4107 (*1 *2 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-3772 (*1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-1615 (*1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) (-1564 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)))) (-3777 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1140 *3))))) 
-(-13 (-1117 |#1|) (-10 -8 (-15 -3777 ($ (-638 |#1|))) (-15 -3772 (|#1| $)) (-15 -2232 (|#1| $)) (-15 -4107 (|#1| |#1| $)) (-15 -1335 ($ |#1| $)) (-15 -4221 (|#1| $)) (-15 -1615 (|#1| $)) (-15 -1564 ((-769) $)) (-15 -3524 ((-121) $ (-769))) (-15 -2157 ((-121) $ (-769))) (-15 -1946 ((-121) $ (-769))) (-15 -3058 ($ (-638 |#1|))) (-15 -4037 ((-121) $)) (-15 -1665 ($)) (-15 -2211 ($)) (-15 -1607 ($ $)) (-15 -3598 ((-121) $ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4603)) (-15 -2435 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1098)) (PROGN (-15 -1658 ((-1152) $)) (-15 -2607 ((-1116) $)) (-15 -3972 ((-856) $)) (-15 -1324 ((-121) $ $)) (-15 -2262 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4602)) (PROGN (-15 -2109 ((-121) (-1 (-121) |#1|) $)) (-15 -3501 ((-121) (-1 (-121) |#1|) $)) (-15 -1571 ((-769) (-1 (-121) |#1|) $)) (-15 -4032 ((-769) $)) (-15 -2010 ((-638 |#1|) $)) (-15 -4467 ((-638 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4602)) (IF (|has| |#1| (-1098)) (PROGN (-15 -3002 ((-121) |#1| $)) (-15 -1571 ((-769) |#1| $))) |noBranch|) |noBranch|))) 
-((-3283 ((|#2| $ "value" |#2|) NIL) ((|#2| $ "first" |#2|) NIL) (($ $ "rest" $) NIL) ((|#2| $ "last" |#2|) NIL) ((|#2| $ (-1225 (-572)) |#2|) 43) ((|#2| $ (-572) |#2|) 40)) (-2429 (((-121) $) 11)) (-2435 (($ (-1 |#2| |#2|) $) 38)) (-1837 ((|#2| $) NIL) (($ $ (-769)) 16)) (-3299 (($ $ |#2|) 39)) (-3540 (((-121) $) 10)) (-3277 ((|#2| $ "value") NIL) ((|#2| $ "first") NIL) (($ $ "rest") NIL) ((|#2| $ "last") NIL) (($ $ (-1225 (-572))) 30) ((|#2| $ (-572)) 22) ((|#2| $ (-572) |#2|) NIL)) (-2977 (($ $ $) 46) (($ $ |#2|) NIL)) (-4500 (($ $ $) 32) (($ |#2| $) NIL) (($ (-638 $)) 35) (($ $ |#2|) NIL))) 
-(((-1141 |#1| |#2|) (-10 -8 (-15 -2429 ((-121) |#1|)) (-15 -3540 ((-121) |#1|)) (-15 -3283 (|#2| |#1| (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572))) (-15 -3299 (|#1| |#1| |#2|)) (-15 -4500 (|#1| |#1| |#2|)) (-15 -4500 (|#1| (-638 |#1|))) (-15 -3277 (|#1| |#1| (-1225 (-572)))) (-15 -3283 (|#2| |#1| (-1225 (-572)) |#2|)) (-15 -3283 (|#2| |#1| "last" |#2|)) (-15 -3283 (|#1| |#1| "rest" |#1|)) (-15 -3283 (|#2| |#1| "first" |#2|)) (-15 -2977 (|#1| |#1| |#2|)) (-15 -2977 (|#1| |#1| |#1|)) (-15 -3277 (|#2| |#1| "last")) (-15 -3277 (|#1| |#1| "rest")) (-15 -1837 (|#1| |#1| (-769))) (-15 -3277 (|#2| |#1| "first")) (-15 -1837 (|#2| |#1|)) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#1|)) (-15 -3283 (|#2| |#1| "value" |#2|)) (-15 -3277 (|#2| |#1| "value")) (-15 -2435 (|#1| (-1 |#2| |#2|) |#1|))) (-1142 |#2|) (-1204)) (T -1141)) 
-NIL 
-(-10 -8 (-15 -2429 ((-121) |#1|)) (-15 -3540 ((-121) |#1|)) (-15 -3283 (|#2| |#1| (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572) |#2|)) (-15 -3277 (|#2| |#1| (-572))) (-15 -3299 (|#1| |#1| |#2|)) (-15 -4500 (|#1| |#1| |#2|)) (-15 -4500 (|#1| (-638 |#1|))) (-15 -3277 (|#1| |#1| (-1225 (-572)))) (-15 -3283 (|#2| |#1| (-1225 (-572)) |#2|)) (-15 -3283 (|#2| |#1| "last" |#2|)) (-15 -3283 (|#1| |#1| "rest" |#1|)) (-15 -3283 (|#2| |#1| "first" |#2|)) (-15 -2977 (|#1| |#1| |#2|)) (-15 -2977 (|#1| |#1| |#1|)) (-15 -3277 (|#2| |#1| "last")) (-15 -3277 (|#1| |#1| "rest")) (-15 -1837 (|#1| |#1| (-769))) (-15 -3277 (|#2| |#1| "first")) (-15 -1837 (|#2| |#1|)) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#1|)) (-15 -3283 (|#2| |#1| "value" |#2|)) (-15 -3277 (|#2| |#1| "value")) (-15 -2435 (|#1| (-1 |#2| |#2|) |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-4230 ((|#1| $) 62)) (-4232 (($ $) 64)) (-2430 (((-1264) $ (-572) (-572)) 94 (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) 49 (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-3749 (($ $ $) 53 (|has| $ (-6 -4603)))) (-2656 ((|#1| $ |#1|) 51 (|has| $ (-6 -4603)))) (-4055 ((|#1| $ |#1|) 55 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4603))) (($ $ "rest" $) 52 (|has| $ (-6 -4603))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 114 (|has| $ (-6 -4603))) ((|#1| $ (-572) |#1|) 83 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) 99 (|has| $ (-6 -4602)))) (-4066 ((|#1| $) 63)) (-2211 (($) 7 T CONST)) (-1651 (($ $) 70) (($ $ (-769)) 68)) (-1643 (($ $) 96 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ (-1 (-121) |#1|) $) 100 (|has| $ (-6 -4602))) (($ |#1| $) 97 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3037 ((|#1| $ (-572) |#1|) 82 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 84)) (-2429 (((-121) $) 80)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-1364 (($ (-769) |#1|) 105)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 92 (|has| (-572) (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 91 (|has| (-572) (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-3524 (((-121) $ (-769)) 10)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-3253 ((|#1| $) 67) (($ $ (-769)) 65)) (-2603 (($ $ $ (-572)) 113) (($ |#1| $ (-572)) 112)) (-2739 (((-638 (-572)) $) 89)) (-1601 (((-121) (-572) $) 88)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 73) (($ $ (-769)) 71)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-3299 (($ $ |#1|) 93 (|has| $ (-6 -4603)))) (-3540 (((-121) $) 81)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 87)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1225 (-572))) 109) ((|#1| $ (-572)) 86) ((|#1| $ (-572) |#1|) 85)) (-3537 (((-572) $ $) 41)) (-1940 (($ $ (-1225 (-572))) 111) (($ $ (-572)) 110)) (-1791 (((-121) $) 43)) (-2619 (($ $) 59)) (-3316 (($ $) 56 (|has| $ (-6 -4603)))) (-1471 (((-769) $) 60)) (-3622 (($ $) 61)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-4081 (((-545) $) 95 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 104)) (-2977 (($ $ $) 58 (|has| $ (-6 -4603))) (($ $ |#1|) 57 (|has| $ (-6 -4603)))) (-4500 (($ $ $) 75) (($ |#1| $) 74) (($ (-638 $)) 107) (($ $ |#1|) 106)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1142 |#1|) (-1290) (-1204)) (T -1142)) 
-((-3540 (*1 *2 *1) (-12 (-4 *1 (-1142 *3)) (-4 *3 (-1204)) (-5 *2 (-121)))) (-2429 (*1 *2 *1) (-12 (-4 *1 (-1142 *3)) (-4 *3 (-1204)) (-5 *2 (-121))))) 
-(-13 (-1246 |t#1|) (-644 |t#1|) (-10 -8 (-15 -3540 ((-121) $)) (-15 -2429 ((-121) $)))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-644 |#1|) . T) ((-1017 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1204) . T) ((-1246 |#1|) . T)) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2430 (((-1264) $ |#1| |#1|) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#2| $ |#1| |#2|) NIL)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 |#2| "failed") |#1| $) NIL)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) NIL)) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) NIL)) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 ((|#1| $) NIL (|has| |#1| (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 ((|#1| $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2760 (((-638 |#1|) $) NIL)) (-2365 (((-121) |#1| $) NIL)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2739 (((-638 |#1|) $) NIL)) (-1601 (((-121) |#1| $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-1837 ((|#2| $) NIL (|has| |#1| (-848)))) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1143 |#1| |#2| |#3|) (-1181 |#1| |#2|) (-1098) (-1098) |#2|) (T -1143)) 
-NIL 
-(-1181 |#1| |#2|) 
-((-2262 (((-121) $ $) 7)) (-3961 (((-3 $ "failed") $) 12)) (-1658 (((-1152) $) 9)) (-1773 (($) 13 T CONST)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11)) (-1324 (((-121) $ $) 6))) 
-(((-1144) (-1290)) (T -1144)) 
-((-1773 (*1 *1) (-4 *1 (-1144))) (-3961 (*1 *1 *1) (|partial| -4 *1 (-1144)))) 
-(-13 (-1098) (-10 -8 (-15 -1773 ($) -3211) (-15 -3961 ((-3 $ "failed") $)))) 
-(((-105) . T) ((-612 (-856)) . T) ((-1098) . T)) 
-((-2590 (((-1150 |#1|) (-1150 |#1|)) 17)) (-2663 (((-1150 |#1|) (-1150 |#1|)) 13)) (-3577 (((-1150 |#1|) (-1150 |#1|) (-572) (-572)) 20)) (-2322 (((-1150 |#1|) (-1150 |#1|)) 15))) 
-(((-1145 |#1|) (-10 -7 (-15 -2663 ((-1150 |#1|) (-1150 |#1|))) (-15 -2322 ((-1150 |#1|) (-1150 |#1|))) (-15 -2590 ((-1150 |#1|) (-1150 |#1|))) (-15 -3577 ((-1150 |#1|) (-1150 |#1|) (-572) (-572)))) (-13 (-562) (-151))) (T -1145)) 
-((-3577 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-572)) (-4 *4 (-13 (-562) (-151))) (-5 *1 (-1145 *4)))) (-2590 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-13 (-562) (-151))) (-5 *1 (-1145 *3)))) (-2322 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-13 (-562) (-151))) (-5 *1 (-1145 *3)))) (-2663 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-13 (-562) (-151))) (-5 *1 (-1145 *3))))) 
-(-10 -7 (-15 -2663 ((-1150 |#1|) (-1150 |#1|))) (-15 -2322 ((-1150 |#1|) (-1150 |#1|))) (-15 -2590 ((-1150 |#1|) (-1150 |#1|))) (-15 -3577 ((-1150 |#1|) (-1150 |#1|) (-572) (-572)))) 
-((-2548 (((-1150 |#1|) (-1150 |#1|) (-1 (-638 |#1|) |#1|)) 16))) 
-(((-1146 |#1|) (-10 -7 (-15 -2548 ((-1150 |#1|) (-1150 |#1|) (-1 (-638 |#1|) |#1|)))) (-1204)) (T -1146)) 
-((-2548 (*1 *2 *2 *3) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-1 (-638 *4) *4)) (-4 *4 (-1204)) (-5 *1 (-1146 *4))))) 
-(-10 -7 (-15 -2548 ((-1150 |#1|) (-1150 |#1|) (-1 (-638 |#1|) |#1|)))) 
-((-4500 (((-1150 |#1|) (-1150 (-1150 |#1|))) 15))) 
-(((-1147 |#1|) (-10 -7 (-15 -4500 ((-1150 |#1|) (-1150 (-1150 |#1|))))) (-1204)) (T -1147)) 
-((-4500 (*1 *2 *3) (-12 (-5 *3 (-1150 (-1150 *4))) (-5 *2 (-1150 *4)) (-5 *1 (-1147 *4)) (-4 *4 (-1204))))) 
-(-10 -7 (-15 -4500 ((-1150 |#1|) (-1150 (-1150 |#1|))))) 
-((-1911 (((-1150 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1150 |#1|)) 25)) (-3116 ((|#2| |#2| (-1 |#2| |#1| |#2|) (-1150 |#1|)) 26)) (-3828 (((-1150 |#2|) (-1 |#2| |#1|) (-1150 |#1|)) 16))) 
-(((-1148 |#1| |#2|) (-10 -7 (-15 -3828 ((-1150 |#2|) (-1 |#2| |#1|) (-1150 |#1|))) (-15 -1911 ((-1150 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1150 |#1|))) (-15 -3116 (|#2| |#2| (-1 |#2| |#1| |#2|) (-1150 |#1|)))) (-1204) (-1204)) (T -1148)) 
-((-3116 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1150 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-1148 *5 *2)))) (-1911 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *3 *6 *3)) (-5 *5 (-1150 *6)) (-4 *6 (-1204)) (-4 *3 (-1204)) (-5 *2 (-1150 *3)) (-5 *1 (-1148 *6 *3)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1150 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1150 *6)) (-5 *1 (-1148 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-1150 |#2|) (-1 |#2| |#1|) (-1150 |#1|))) (-15 -1911 ((-1150 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1150 |#1|))) (-15 -3116 (|#2| |#2| (-1 |#2| |#1| |#2|) (-1150 |#1|)))) 
-((-3828 (((-1150 |#3|) (-1 |#3| |#1| |#2|) (-1150 |#1|) (-1150 |#2|)) 21))) 
-(((-1149 |#1| |#2| |#3|) (-10 -7 (-15 -3828 ((-1150 |#3|) (-1 |#3| |#1| |#2|) (-1150 |#1|) (-1150 |#2|)))) (-1204) (-1204) (-1204)) (T -1149)) 
-((-3828 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1150 *6)) (-5 *5 (-1150 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-1150 *8)) (-5 *1 (-1149 *6 *7 *8))))) 
-(-10 -7 (-15 -3828 ((-1150 |#3|) (-1 |#3| |#1| |#2|) (-1150 |#1|) (-1150 |#2|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) NIL)) (-4230 ((|#1| $) NIL)) (-4232 (($ $) 48)) (-2430 (((-1264) $ (-572) (-572)) 73 (|has| $ (-6 -4603)))) (-4390 (($ $ (-572)) 107 (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3706 (((-856) $) 37 (|has| |#1| (-1098)))) (-2158 (((-121)) 38 (|has| |#1| (-1098)))) (-4436 ((|#1| $ |#1|) NIL (|has| $ (-6 -4603)))) (-3749 (($ $ $) 95 (|has| $ (-6 -4603))) (($ $ (-572) $) 117)) (-2656 ((|#1| $ |#1|) 104 (|has| $ (-6 -4603)))) (-4055 ((|#1| $ |#1|) 99 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ "first" |#1|) 101 (|has| $ (-6 -4603))) (($ $ "rest" $) 103 (|has| $ (-6 -4603))) ((|#1| $ "last" |#1|) 106 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 86 (|has| $ (-6 -4603))) ((|#1| $ (-572) |#1|) 52 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) 55)) (-4066 ((|#1| $) NIL)) (-2211 (($) NIL T CONST)) (-2438 (($ $) 14)) (-1651 (($ $) 28) (($ $ (-769)) 85)) (-3609 (((-121) (-638 |#1|) $) 112 (|has| |#1| (-1098)))) (-1626 (($ (-638 |#1|)) 109)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) 54)) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-2429 (((-121) $) NIL)) (-2010 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-1857 (((-1264) (-572) $) 116 (|has| |#1| (-1098)))) (-2050 (((-769) $) 114)) (-2202 (((-638 $) $) NIL)) (-1303 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1364 (($ (-769) |#1|) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 70 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 60) (($ (-1 |#1| |#1| |#1|) $ $) 64)) (-3524 (((-121) $ (-769)) NIL)) (-2699 (((-638 |#1|) $) NIL)) (-3113 (((-121) $) NIL)) (-2556 (($ $) 87)) (-1493 (((-121) $) 13)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-3253 ((|#1| $) NIL) (($ $ (-769)) NIL)) (-2603 (($ $ $ (-572)) NIL) (($ |#1| $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) 71)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2516 (($ (-1 |#1|)) 119) (($ (-1 |#1| |#1|) |#1|) 120)) (-3179 ((|#1| $) 10)) (-1837 ((|#1| $) 27) (($ $ (-769)) 46)) (-2681 (((-2 (|:| |cycle?| (-121)) (|:| -2799 (-769)) (|:| |period| (-769))) (-769) $) 24)) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2543 (($ (-1 (-121) |#1|) $) 121)) (-2552 (($ (-1 (-121) |#1|) $) 122)) (-3299 (($ $ |#1|) 65 (|has| $ (-6 -4603)))) (-1977 (($ $ (-572)) 31)) (-3540 (((-121) $) 69)) (-3173 (((-121) $) 12)) (-4249 (((-121) $) 113)) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 20)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) 15)) (-1665 (($) 40)) (-3277 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1225 (-572))) NIL) ((|#1| $ (-572)) 51) ((|#1| $ (-572) |#1|) NIL)) (-3537 (((-572) $ $) 45)) (-1940 (($ $ (-1225 (-572))) NIL) (($ $ (-572)) NIL)) (-4216 (($ (-1 $)) 44)) (-1791 (((-121) $) 66)) (-2619 (($ $) 67)) (-3316 (($ $) 96 (|has| $ (-6 -4603)))) (-1471 (((-769) $) NIL)) (-3622 (($ $) NIL)) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) 41)) (-4081 (((-545) $) NIL (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 50)) (-1603 (($ |#1| $) 94)) (-2977 (($ $ $) 97 (|has| $ (-6 -4603))) (($ $ |#1|) 98 (|has| $ (-6 -4603)))) (-4500 (($ $ $) 75) (($ |#1| $) 42) (($ (-638 $)) 80) (($ $ |#1|) 74)) (-2424 (($ $) 47)) (-3972 (((-856) $) 39 (|has| |#1| (-1098))) (($ (-638 |#1|)) 108)) (-4118 (((-638 $) $) NIL)) (-3432 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 111 (|has| |#1| (-1098)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1150 |#1|) (-13 (-669 |#1|) (-10 -8 (-6 -4603) (-15 -3972 ($ (-638 |#1|))) (-15 -1626 ($ (-638 |#1|))) (IF (|has| |#1| (-1098)) (-15 -3609 ((-121) (-638 |#1|) $)) |noBranch|) (-15 -2681 ((-2 (|:| |cycle?| (-121)) (|:| -2799 (-769)) (|:| |period| (-769))) (-769) $)) (-15 -4216 ($ (-1 $))) (-15 -1603 ($ |#1| $)) (IF (|has| |#1| (-1098)) (PROGN (-15 -1857 ((-1264) (-572) $)) (-15 -3706 ((-856) $)) (-15 -2158 ((-121)))) |noBranch|) (-15 -3749 ($ $ (-572) $)) (-15 -2516 ($ (-1 |#1|))) (-15 -2516 ($ (-1 |#1| |#1|) |#1|)) (-15 -2543 ($ (-1 (-121) |#1|) $)) (-15 -2552 ($ (-1 (-121) |#1|) $)))) (-1204)) (T -1150)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3)))) (-1626 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3)))) (-3609 (*1 *2 *3 *1) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1098)) (-4 *4 (-1204)) (-5 *2 (-121)) (-5 *1 (-1150 *4)))) (-2681 (*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |cycle?| (-121)) (|:| -2799 (-769)) (|:| |period| (-769)))) (-5 *1 (-1150 *4)) (-4 *4 (-1204)) (-5 *3 (-769)))) (-4216 (*1 *1 *2) (-12 (-5 *2 (-1 (-1150 *3))) (-5 *1 (-1150 *3)) (-4 *3 (-1204)))) (-1603 (*1 *1 *2 *1) (-12 (-5 *1 (-1150 *2)) (-4 *2 (-1204)))) (-1857 (*1 *2 *3 *1) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-1150 *4)) (-4 *4 (-1098)) (-4 *4 (-1204)))) (-3706 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1150 *3)) (-4 *3 (-1098)) (-4 *3 (-1204)))) (-2158 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1150 *3)) (-4 *3 (-1098)) (-4 *3 (-1204)))) (-3749 (*1 *1 *1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1150 *3)) (-4 *3 (-1204)))) (-2516 (*1 *1 *2) (-12 (-5 *2 (-1 *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3)))) (-2516 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3)))) (-2543 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3)))) (-2552 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3))))) 
-(-13 (-669 |#1|) (-10 -8 (-6 -4603) (-15 -3972 ($ (-638 |#1|))) (-15 -1626 ($ (-638 |#1|))) (IF (|has| |#1| (-1098)) (-15 -3609 ((-121) (-638 |#1|) $)) |noBranch|) (-15 -2681 ((-2 (|:| |cycle?| (-121)) (|:| -2799 (-769)) (|:| |period| (-769))) (-769) $)) (-15 -4216 ($ (-1 $))) (-15 -1603 ($ |#1| $)) (IF (|has| |#1| (-1098)) (PROGN (-15 -1857 ((-1264) (-572) $)) (-15 -3706 ((-856) $)) (-15 -2158 ((-121)))) |noBranch|) (-15 -3749 ($ $ (-572) $)) (-15 -2516 ($ (-1 |#1|))) (-15 -2516 ($ (-1 |#1| |#1|) |#1|)) (-15 -2543 ($ (-1 (-121) |#1|) $)) (-15 -2552 ($ (-1 (-121) |#1|) $)))) 
-((-2262 (((-121) $ $) 18)) (-4092 (($ $) 113)) (-4013 (($ $) 114)) (-3867 (($ $ (-148)) 101) (($ $ (-143)) 100)) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-2066 (((-121) $ $) 111)) (-2013 (((-121) $ $ (-572)) 110)) (-4035 (($ (-572)) 118)) (-1585 (((-638 $) $ (-148)) 103) (((-638 $) $ (-143)) 102)) (-2041 (((-121) (-1 (-121) (-148) (-148)) $) 91) (((-121) $) 85 (|has| (-148) (-848)))) (-4131 (($ (-1 (-121) (-148) (-148)) $) 82 (|has| $ (-6 -4603))) (($ $) 81 (-12 (|has| (-148) (-848)) (|has| $ (-6 -4603))))) (-3008 (($ (-1 (-121) (-148) (-148)) $) 92) (($ $) 86 (|has| (-148) (-848)))) (-1946 (((-121) $ (-769)) 8)) (-3283 (((-148) $ (-572) (-148)) 49 (|has| $ (-6 -4603))) (((-148) $ (-1225 (-572)) (-148)) 53 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-148)) $) 70 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-3429 (($ $ (-148)) 97) (($ $ (-143)) 96)) (-2985 (($ $) 83 (|has| $ (-6 -4603)))) (-1656 (($ $) 93)) (-3808 (($ $ (-1225 (-572)) $) 107)) (-1643 (($ $) 73 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ (-148) $) 72 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) (-148)) $) 69 (|has| $ (-6 -4602)))) (-3116 (((-148) (-1 (-148) (-148) (-148)) $ (-148) (-148)) 71 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602)))) (((-148) (-1 (-148) (-148) (-148)) $ (-148)) 68 (|has| $ (-6 -4602))) (((-148) (-1 (-148) (-148) (-148)) $) 67 (|has| $ (-6 -4602)))) (-3037 (((-148) $ (-572) (-148)) 50 (|has| $ (-6 -4603)))) (-4212 (((-148) $ (-572)) 48)) (-2174 (((-121) $ $) 112)) (-4014 (((-572) (-1 (-121) (-148)) $) 90) (((-572) (-148) $) 89 (|has| (-148) (-1098))) (((-572) (-148) $ (-572)) 88 (|has| (-148) (-1098))) (((-572) $ $ (-572)) 106) (((-572) (-143) $ (-572)) 105)) (-2010 (((-638 (-148)) $) 30 (|has| $ (-6 -4602)))) (-1364 (($ (-769) (-148)) 64)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-1771 (($ $ $) 80 (|has| (-148) (-848)))) (-4475 (($ (-1 (-121) (-148) (-148)) $ $) 94) (($ $ $) 87 (|has| (-148) (-848)))) (-4467 (((-638 (-148)) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) (-148) $) 27 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-4238 (($ $ $) 79 (|has| (-148) (-848)))) (-2524 (((-121) $ $ (-148)) 108)) (-3724 (((-769) $ $ (-148)) 109)) (-2435 (($ (-1 (-148) (-148)) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-148) (-148)) $) 35) (($ (-1 (-148) (-148) (-148)) $ $) 59)) (-2895 (($ $) 115)) (-2676 (($ $) 116)) (-3524 (((-121) $ (-769)) 10)) (-1796 (($ $ (-148)) 99) (($ $ (-143)) 98)) (-1658 (((-1152) $) 22)) (-2603 (($ (-148) $ (-572)) 55) (($ $ $ (-572)) 54)) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-2607 (((-1116) $) 21)) (-1837 (((-148) $) 39 (|has| (-572) (-848)))) (-3361 (((-3 (-148) "failed") (-1 (-121) (-148)) $) 66)) (-3299 (($ $ (-148)) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-148)) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-148)))) 26 (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-290 (-148))) 25 (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-148) (-148)) 24 (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-638 (-148)) (-638 (-148))) 23 (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) (-148) $) 42 (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-2957 (((-638 (-148)) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 (((-148) $ (-572) (-148)) 47) (((-148) $ (-572)) 46) (($ $ (-1225 (-572))) 58) (($ $ $) 95)) (-1940 (($ $ (-572)) 57) (($ $ (-1225 (-572))) 56)) (-1571 (((-769) (-1 (-121) (-148)) $) 31 (|has| $ (-6 -4602))) (((-769) (-148) $) 28 (-12 (|has| (-148) (-1098)) (|has| $ (-6 -4602))))) (-2907 (($ $ $ (-572)) 84 (|has| $ (-6 -4603)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 74 (|has| (-148) (-613 (-545))))) (-3921 (($ (-638 (-148))) 65)) (-4500 (($ $ (-148)) 63) (($ (-148) $) 62) (($ $ $) 61) (($ (-638 $)) 60)) (-3972 (($ (-148)) 104) (((-856) $) 20)) (-3501 (((-121) (-1 (-121) (-148)) $) 33 (|has| $ (-6 -4602)))) (-3594 (((-1152) $) 122) (((-1152) $ (-121)) 121) (((-1264) (-823) $) 120) (((-1264) (-823) $ (-121)) 119)) (-1349 (((-121) $ $) 77 (|has| (-148) (-848)))) (-1338 (((-121) $ $) 76 (|has| (-148) (-848)))) (-1324 (((-121) $ $) 19)) (-1343 (((-121) $ $) 78 (|has| (-148) (-848)))) (-1334 (((-121) $ $) 75 (|has| (-148) (-848)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1151) (-1290)) (T -1151)) 
-((-4035 (*1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1151))))) 
-(-13 (-1137) (-1098) (-829) (-10 -8 (-15 -4035 ($ (-572))))) 
-(((-39) . T) ((-105) . T) ((-612 (-856)) . T) ((-155 (-148)) . T) ((-613 (-545)) |has| (-148) (-613 (-545))) ((-283 (-572) (-148)) . T) ((-285 (-572) (-148)) . T) ((-305 (-148)) -12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))) ((-379 (-148)) . T) ((-503 (-148)) . T) ((-605 (-572) (-148)) . T) ((-527 (-148) (-148)) -12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))) ((-644 (-148)) . T) ((-19 (-148)) . T) ((-829) . T) ((-848) |has| (-148) (-848)) ((-1098) . T) ((-1137) . T) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-4092 (($ $) NIL)) (-4013 (($ $) NIL)) (-3867 (($ $ (-148)) NIL) (($ $ (-143)) NIL)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2066 (((-121) $ $) NIL)) (-2013 (((-121) $ $ (-572)) NIL)) (-4035 (($ (-572)) 7)) (-1585 (((-638 $) $ (-148)) NIL) (((-638 $) $ (-143)) NIL)) (-2041 (((-121) (-1 (-121) (-148) (-148)) $) NIL) (((-121) $) NIL (|has| (-148) (-848)))) (-4131 (($ (-1 (-121) (-148) (-148)) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-148) (-848))))) (-3008 (($ (-1 (-121) (-148) (-148)) $) NIL) (($ $) NIL (|has| (-148) (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-148) $ (-572) (-148)) NIL (|has| $ (-6 -4603))) (((-148) $ (-1225 (-572)) (-148)) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-3429 (($ $ (-148)) NIL) (($ $ (-143)) NIL)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-3808 (($ $ (-1225 (-572)) $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-3445 (($ (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098)))) (($ (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-148) (-1 (-148) (-148) (-148)) $ (-148) (-148)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098)))) (((-148) (-1 (-148) (-148) (-148)) $ (-148)) NIL (|has| $ (-6 -4602))) (((-148) (-1 (-148) (-148) (-148)) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-148) $ (-572) (-148)) NIL (|has| $ (-6 -4603)))) (-4212 (((-148) $ (-572)) NIL)) (-2174 (((-121) $ $) NIL)) (-4014 (((-572) (-1 (-121) (-148)) $) NIL) (((-572) (-148) $) NIL (|has| (-148) (-1098))) (((-572) (-148) $ (-572)) NIL (|has| (-148) (-1098))) (((-572) $ $ (-572)) NIL) (((-572) (-143) $ (-572)) NIL)) (-2010 (((-638 (-148)) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) (-148)) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| (-148) (-848)))) (-4475 (($ (-1 (-121) (-148) (-148)) $ $) NIL) (($ $ $) NIL (|has| (-148) (-848)))) (-4467 (((-638 (-148)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-148) (-848)))) (-2524 (((-121) $ $ (-148)) NIL)) (-3724 (((-769) $ $ (-148)) NIL)) (-2435 (($ (-1 (-148) (-148)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-148) (-148)) $) NIL) (($ (-1 (-148) (-148) (-148)) $ $) NIL)) (-2895 (($ $) NIL)) (-2676 (($ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1796 (($ $ (-148)) NIL) (($ $ (-143)) NIL)) (-1658 (((-1152) $) NIL)) (-2603 (($ (-148) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-148) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-148) "failed") (-1 (-121) (-148)) $) NIL)) (-3299 (($ $ (-148)) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-148)))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-290 (-148))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-148) (-148)) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098)))) (($ $ (-638 (-148)) (-638 (-148))) NIL (-12 (|has| (-148) (-305 (-148))) (|has| (-148) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-2957 (((-638 (-148)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 (((-148) $ (-572) (-148)) NIL) (((-148) $ (-572)) NIL) (($ $ (-1225 (-572))) NIL) (($ $ $) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602))) (((-769) (-148) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-148) (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-148) (-613 (-545))))) (-3921 (($ (-638 (-148))) NIL)) (-4500 (($ $ (-148)) NIL) (($ (-148) $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (($ (-148)) NIL) (((-856) $) NIL)) (-3501 (((-121) (-1 (-121) (-148)) $) NIL (|has| $ (-6 -4602)))) (-3594 (((-1152) $) 18) (((-1152) $ (-121)) 20) (((-1264) (-823) $) 21) (((-1264) (-823) $ (-121)) 22)) (-1349 (((-121) $ $) NIL (|has| (-148) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-148) (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| (-148) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-148) (-848)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1152) (-1151)) (T -1152)) 
-NIL 
-(-1151) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)) (|has| |#1| (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL)) (-2430 (((-1264) $ (-1152) (-1152)) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-1152) |#1|) NIL)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 |#1| "failed") (-1152) $) NIL)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098))))) (-1544 (($ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (((-3 |#1| "failed") (-1152) $) NIL)) (-3445 (($ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-1152) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-1152)) NIL)) (-2010 (((-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-1152) $) NIL (|has| (-1152) (-848)))) (-4467 (((-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-1152) $) NIL (|has| (-1152) (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4603))) (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL) (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)) (|has| |#1| (-1098))))) (-2760 (((-638 (-1152)) $) NIL)) (-2365 (((-121) (-1152) $) NIL)) (-4221 (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL)) (-2739 (((-638 (-1152)) $) NIL)) (-1601 (((-121) (-1152) $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)) (|has| |#1| (-1098))))) (-1837 ((|#1| $) NIL (|has| (-1152) (-848)))) (-3361 (((-3 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) "failed") (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (($ $ (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL (-12 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-305 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-1152)) NIL) ((|#1| $ (-1152) |#1|) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)) (|has| |#1| (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 (-1152)) (|:| -4320 |#1|)) (-1098)) (|has| |#1| (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1153 |#1|) (-13 (-1181 (-1152) |#1|) (-10 -7 (-6 -4602))) (-1098)) (T -1153)) 
-NIL 
-(-13 (-1181 (-1152) |#1|) (-10 -7 (-6 -4602))) 
-((-3851 (((-1150 |#1|) (-1150 |#1|)) 77)) (-1799 (((-3 (-1150 |#1|) "failed") (-1150 |#1|)) 37)) (-3026 (((-1150 |#1|) (-413 (-572)) (-1150 |#1|)) 117 (|has| |#1| (-43 (-413 (-572)))))) (-1951 (((-1150 |#1|) |#1| (-1150 |#1|)) 121 (|has| |#1| (-368)))) (-1973 (((-1150 |#1|) (-1150 |#1|)) 90)) (-3274 (((-1150 (-572)) (-572)) 57)) (-3919 (((-1150 |#1|) (-1150 (-1150 |#1|))) 108 (|has| |#1| (-43 (-413 (-572)))))) (-3628 (((-1150 |#1|) (-572) (-572) (-1150 |#1|)) 95)) (-4518 (((-1150 |#1|) |#1| (-572)) 45)) (-1340 (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 60)) (-3562 (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 119 (|has| |#1| (-368)))) (-2960 (((-1150 |#1|) |#1| (-1 (-1150 |#1|))) 107 (|has| |#1| (-43 (-413 (-572)))))) (-2384 (((-1150 |#1|) (-1 |#1| (-572)) |#1| (-1 (-1150 |#1|))) 120 (|has| |#1| (-368)))) (-3358 (((-1150 |#1|) (-1150 |#1|)) 89)) (-2606 (((-1150 |#1|) (-1150 |#1|)) 76)) (-3959 (((-1150 |#1|) (-572) (-572) (-1150 |#1|)) 96)) (-2774 (((-1150 |#1|) |#1| (-1150 |#1|)) 105 (|has| |#1| (-43 (-413 (-572)))))) (-4101 (((-1150 (-572)) (-572)) 56)) (-3293 (((-1150 |#1|) |#1|) 59)) (-3130 (((-1150 |#1|) (-1150 |#1|) (-572) (-572)) 92)) (-3360 (((-1150 |#1|) (-1 |#1| (-572)) (-1150 |#1|)) 66)) (-1803 (((-3 (-1150 |#1|) "failed") (-1150 |#1|) (-1150 |#1|)) 35)) (-2827 (((-1150 |#1|) (-1150 |#1|)) 91)) (-4485 (((-1150 |#1|) (-1150 |#1|) |#1|) 71)) (-4119 (((-1150 |#1|) (-1150 |#1|)) 62)) (-2437 (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 72)) (-3972 (((-1150 |#1|) |#1|) 67)) (-3557 (((-1150 |#1|) (-1150 (-1150 |#1|))) 82)) (-1379 (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 36)) (-1373 (((-1150 |#1|) (-1150 |#1|)) 21) (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 23)) (-1367 (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 17)) (* (((-1150 |#1|) (-1150 |#1|) |#1|) 29) (((-1150 |#1|) |#1| (-1150 |#1|)) 26) (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 27))) 
-(((-1154 |#1|) (-10 -7 (-15 -1367 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -1373 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -1373 ((-1150 |#1|) (-1150 |#1|))) (-15 * ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 * ((-1150 |#1|) |#1| (-1150 |#1|))) (-15 * ((-1150 |#1|) (-1150 |#1|) |#1|)) (-15 -1803 ((-3 (-1150 |#1|) "failed") (-1150 |#1|) (-1150 |#1|))) (-15 -1379 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -1799 ((-3 (-1150 |#1|) "failed") (-1150 |#1|))) (-15 -4518 ((-1150 |#1|) |#1| (-572))) (-15 -4101 ((-1150 (-572)) (-572))) (-15 -3274 ((-1150 (-572)) (-572))) (-15 -3293 ((-1150 |#1|) |#1|)) (-15 -1340 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -4119 ((-1150 |#1|) (-1150 |#1|))) (-15 -3360 ((-1150 |#1|) (-1 |#1| (-572)) (-1150 |#1|))) (-15 -3972 ((-1150 |#1|) |#1|)) (-15 -4485 ((-1150 |#1|) (-1150 |#1|) |#1|)) (-15 -2437 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -2606 ((-1150 |#1|) (-1150 |#1|))) (-15 -3851 ((-1150 |#1|) (-1150 |#1|))) (-15 -3557 ((-1150 |#1|) (-1150 (-1150 |#1|)))) (-15 -3358 ((-1150 |#1|) (-1150 |#1|))) (-15 -1973 ((-1150 |#1|) (-1150 |#1|))) (-15 -2827 ((-1150 |#1|) (-1150 |#1|))) (-15 -3130 ((-1150 |#1|) (-1150 |#1|) (-572) (-572))) (-15 -3628 ((-1150 |#1|) (-572) (-572) (-1150 |#1|))) (-15 -3959 ((-1150 |#1|) (-572) (-572) (-1150 |#1|))) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ((-1150 |#1|) |#1| (-1150 |#1|))) (-15 -2960 ((-1150 |#1|) |#1| (-1 (-1150 |#1|)))) (-15 -3919 ((-1150 |#1|) (-1150 (-1150 |#1|)))) (-15 -3026 ((-1150 |#1|) (-413 (-572)) (-1150 |#1|)))) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-15 -3562 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -2384 ((-1150 |#1|) (-1 |#1| (-572)) |#1| (-1 (-1150 |#1|)))) (-15 -1951 ((-1150 |#1|) |#1| (-1150 |#1|)))) |noBranch|)) (-1054)) (T -1154)) 
-((-1951 (*1 *2 *3 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-2384 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *4 (-572))) (-5 *5 (-1 (-1150 *4))) (-4 *4 (-368)) (-4 *4 (-1054)) (-5 *2 (-1150 *4)) (-5 *1 (-1154 *4)))) (-3562 (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-3026 (*1 *2 *3 *2) (-12 (-5 *2 (-1150 *4)) (-4 *4 (-43 *3)) (-4 *4 (-1054)) (-5 *3 (-413 (-572))) (-5 *1 (-1154 *4)))) (-3919 (*1 *2 *3) (-12 (-5 *3 (-1150 (-1150 *4))) (-5 *2 (-1150 *4)) (-5 *1 (-1154 *4)) (-4 *4 (-43 (-413 (-572)))) (-4 *4 (-1054)))) (-2960 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-1150 *3))) (-5 *2 (-1150 *3)) (-5 *1 (-1154 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)))) (-2774 (*1 *2 *3 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-3959 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-572)) (-4 *4 (-1054)) (-5 *1 (-1154 *4)))) (-3628 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-572)) (-4 *4 (-1054)) (-5 *1 (-1154 *4)))) (-3130 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-572)) (-4 *4 (-1054)) (-5 *1 (-1154 *4)))) (-2827 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-1973 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-3358 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-3557 (*1 *2 *3) (-12 (-5 *3 (-1150 (-1150 *4))) (-5 *2 (-1150 *4)) (-5 *1 (-1154 *4)) (-4 *4 (-1054)))) (-3851 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-2606 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-2437 (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-4485 (*1 *2 *2 *3) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-3972 (*1 *2 *3) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-1154 *3)) (-4 *3 (-1054)))) (-3360 (*1 *2 *3 *2) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-1 *4 (-572))) (-4 *4 (-1054)) (-5 *1 (-1154 *4)))) (-4119 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-1340 (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-3293 (*1 *2 *3) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-1154 *3)) (-4 *3 (-1054)))) (-3274 (*1 *2 *3) (-12 (-5 *2 (-1150 (-572))) (-5 *1 (-1154 *4)) (-4 *4 (-1054)) (-5 *3 (-572)))) (-4101 (*1 *2 *3) (-12 (-5 *2 (-1150 (-572))) (-5 *1 (-1154 *4)) (-4 *4 (-1054)) (-5 *3 (-572)))) (-4518 (*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-5 *2 (-1150 *3)) (-5 *1 (-1154 *3)) (-4 *3 (-1054)))) (-1799 (*1 *2 *2) (|partial| -12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-1379 (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-1803 (*1 *2 *2 *2) (|partial| -12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (* (*1 *2 *2 *3) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-1373 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-1373 (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) (-1367 (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3))))) 
-(-10 -7 (-15 -1367 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -1373 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -1373 ((-1150 |#1|) (-1150 |#1|))) (-15 * ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 * ((-1150 |#1|) |#1| (-1150 |#1|))) (-15 * ((-1150 |#1|) (-1150 |#1|) |#1|)) (-15 -1803 ((-3 (-1150 |#1|) "failed") (-1150 |#1|) (-1150 |#1|))) (-15 -1379 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -1799 ((-3 (-1150 |#1|) "failed") (-1150 |#1|))) (-15 -4518 ((-1150 |#1|) |#1| (-572))) (-15 -4101 ((-1150 (-572)) (-572))) (-15 -3274 ((-1150 (-572)) (-572))) (-15 -3293 ((-1150 |#1|) |#1|)) (-15 -1340 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -4119 ((-1150 |#1|) (-1150 |#1|))) (-15 -3360 ((-1150 |#1|) (-1 |#1| (-572)) (-1150 |#1|))) (-15 -3972 ((-1150 |#1|) |#1|)) (-15 -4485 ((-1150 |#1|) (-1150 |#1|) |#1|)) (-15 -2437 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -2606 ((-1150 |#1|) (-1150 |#1|))) (-15 -3851 ((-1150 |#1|) (-1150 |#1|))) (-15 -3557 ((-1150 |#1|) (-1150 (-1150 |#1|)))) (-15 -3358 ((-1150 |#1|) (-1150 |#1|))) (-15 -1973 ((-1150 |#1|) (-1150 |#1|))) (-15 -2827 ((-1150 |#1|) (-1150 |#1|))) (-15 -3130 ((-1150 |#1|) (-1150 |#1|) (-572) (-572))) (-15 -3628 ((-1150 |#1|) (-572) (-572) (-1150 |#1|))) (-15 -3959 ((-1150 |#1|) (-572) (-572) (-1150 |#1|))) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ((-1150 |#1|) |#1| (-1150 |#1|))) (-15 -2960 ((-1150 |#1|) |#1| (-1 (-1150 |#1|)))) (-15 -3919 ((-1150 |#1|) (-1150 (-1150 |#1|)))) (-15 -3026 ((-1150 |#1|) (-413 (-572)) (-1150 |#1|)))) |noBranch|) (IF (|has| |#1| (-368)) (PROGN (-15 -3562 ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -2384 ((-1150 |#1|) (-1 |#1| (-572)) |#1| (-1 (-1150 |#1|)))) (-15 -1951 ((-1150 |#1|) |#1| (-1150 |#1|)))) |noBranch|)) 
-((-4284 (((-1150 |#1|) (-1150 |#1|)) 57)) (-4224 (((-1150 |#1|) (-1150 |#1|)) 39)) (-4273 (((-1150 |#1|) (-1150 |#1|)) 53)) (-4217 (((-1150 |#1|) (-1150 |#1|)) 35)) (-4295 (((-1150 |#1|) (-1150 |#1|)) 60)) (-4233 (((-1150 |#1|) (-1150 |#1|)) 42)) (-3539 (((-1150 |#1|) (-1150 |#1|)) 31)) (-4179 (((-1150 |#1|) (-1150 |#1|)) 27)) (-4302 (((-1150 |#1|) (-1150 |#1|)) 61)) (-4237 (((-1150 |#1|) (-1150 |#1|)) 43)) (-4289 (((-1150 |#1|) (-1150 |#1|)) 58)) (-4228 (((-1150 |#1|) (-1150 |#1|)) 40)) (-4278 (((-1150 |#1|) (-1150 |#1|)) 55)) (-4220 (((-1150 |#1|) (-1150 |#1|)) 37)) (-4321 (((-1150 |#1|) (-1150 |#1|)) 65)) (-4251 (((-1150 |#1|) (-1150 |#1|)) 47)) (-4308 (((-1150 |#1|) (-1150 |#1|)) 63)) (-4241 (((-1150 |#1|) (-1150 |#1|)) 45)) (-4333 (((-1150 |#1|) (-1150 |#1|)) 68)) (-4263 (((-1150 |#1|) (-1150 |#1|)) 50)) (-2104 (((-1150 |#1|) (-1150 |#1|)) 69)) (-4268 (((-1150 |#1|) (-1150 |#1|)) 51)) (-4327 (((-1150 |#1|) (-1150 |#1|)) 67)) (-4257 (((-1150 |#1|) (-1150 |#1|)) 49)) (-4314 (((-1150 |#1|) (-1150 |#1|)) 66)) (-4246 (((-1150 |#1|) (-1150 |#1|)) 48)) (** (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 33))) 
-(((-1155 |#1|) (-10 -7 (-15 -4179 ((-1150 |#1|) (-1150 |#1|))) (-15 -3539 ((-1150 |#1|) (-1150 |#1|))) (-15 ** ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -4217 ((-1150 |#1|) (-1150 |#1|))) (-15 -4220 ((-1150 |#1|) (-1150 |#1|))) (-15 -4224 ((-1150 |#1|) (-1150 |#1|))) (-15 -4228 ((-1150 |#1|) (-1150 |#1|))) (-15 -4233 ((-1150 |#1|) (-1150 |#1|))) (-15 -4237 ((-1150 |#1|) (-1150 |#1|))) (-15 -4241 ((-1150 |#1|) (-1150 |#1|))) (-15 -4246 ((-1150 |#1|) (-1150 |#1|))) (-15 -4251 ((-1150 |#1|) (-1150 |#1|))) (-15 -4257 ((-1150 |#1|) (-1150 |#1|))) (-15 -4263 ((-1150 |#1|) (-1150 |#1|))) (-15 -4268 ((-1150 |#1|) (-1150 |#1|))) (-15 -4273 ((-1150 |#1|) (-1150 |#1|))) (-15 -4278 ((-1150 |#1|) (-1150 |#1|))) (-15 -4284 ((-1150 |#1|) (-1150 |#1|))) (-15 -4289 ((-1150 |#1|) (-1150 |#1|))) (-15 -4295 ((-1150 |#1|) (-1150 |#1|))) (-15 -4302 ((-1150 |#1|) (-1150 |#1|))) (-15 -4308 ((-1150 |#1|) (-1150 |#1|))) (-15 -4314 ((-1150 |#1|) (-1150 |#1|))) (-15 -4321 ((-1150 |#1|) (-1150 |#1|))) (-15 -4327 ((-1150 |#1|) (-1150 |#1|))) (-15 -4333 ((-1150 |#1|) (-1150 |#1|))) (-15 -2104 ((-1150 |#1|) (-1150 |#1|)))) (-43 (-413 (-572)))) (T -1155)) 
-((-2104 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4333 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4327 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4321 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4314 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4308 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4302 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4295 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4289 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4284 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4278 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4273 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4268 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4263 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4257 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4251 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4246 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4241 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4237 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4233 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4228 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4224 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4220 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4217 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (** (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-3539 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) (-4179 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3))))) 
-(-10 -7 (-15 -4179 ((-1150 |#1|) (-1150 |#1|))) (-15 -3539 ((-1150 |#1|) (-1150 |#1|))) (-15 ** ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -4217 ((-1150 |#1|) (-1150 |#1|))) (-15 -4220 ((-1150 |#1|) (-1150 |#1|))) (-15 -4224 ((-1150 |#1|) (-1150 |#1|))) (-15 -4228 ((-1150 |#1|) (-1150 |#1|))) (-15 -4233 ((-1150 |#1|) (-1150 |#1|))) (-15 -4237 ((-1150 |#1|) (-1150 |#1|))) (-15 -4241 ((-1150 |#1|) (-1150 |#1|))) (-15 -4246 ((-1150 |#1|) (-1150 |#1|))) (-15 -4251 ((-1150 |#1|) (-1150 |#1|))) (-15 -4257 ((-1150 |#1|) (-1150 |#1|))) (-15 -4263 ((-1150 |#1|) (-1150 |#1|))) (-15 -4268 ((-1150 |#1|) (-1150 |#1|))) (-15 -4273 ((-1150 |#1|) (-1150 |#1|))) (-15 -4278 ((-1150 |#1|) (-1150 |#1|))) (-15 -4284 ((-1150 |#1|) (-1150 |#1|))) (-15 -4289 ((-1150 |#1|) (-1150 |#1|))) (-15 -4295 ((-1150 |#1|) (-1150 |#1|))) (-15 -4302 ((-1150 |#1|) (-1150 |#1|))) (-15 -4308 ((-1150 |#1|) (-1150 |#1|))) (-15 -4314 ((-1150 |#1|) (-1150 |#1|))) (-15 -4321 ((-1150 |#1|) (-1150 |#1|))) (-15 -4327 ((-1150 |#1|) (-1150 |#1|))) (-15 -4333 ((-1150 |#1|) (-1150 |#1|))) (-15 -2104 ((-1150 |#1|) (-1150 |#1|)))) 
-((-4284 (((-1150 |#1|) (-1150 |#1|)) 100)) (-4224 (((-1150 |#1|) (-1150 |#1|)) 64)) (-2184 (((-2 (|:| -4273 (-1150 |#1|)) (|:| -4278 (-1150 |#1|))) (-1150 |#1|)) 96)) (-4273 (((-1150 |#1|) (-1150 |#1|)) 97)) (-1353 (((-2 (|:| -4217 (-1150 |#1|)) (|:| -4220 (-1150 |#1|))) (-1150 |#1|)) 53)) (-4217 (((-1150 |#1|) (-1150 |#1|)) 54)) (-4295 (((-1150 |#1|) (-1150 |#1|)) 102)) (-4233 (((-1150 |#1|) (-1150 |#1|)) 71)) (-3539 (((-1150 |#1|) (-1150 |#1|)) 39)) (-4179 (((-1150 |#1|) (-1150 |#1|)) 36)) (-4302 (((-1150 |#1|) (-1150 |#1|)) 103)) (-4237 (((-1150 |#1|) (-1150 |#1|)) 72)) (-4289 (((-1150 |#1|) (-1150 |#1|)) 101)) (-4228 (((-1150 |#1|) (-1150 |#1|)) 67)) (-4278 (((-1150 |#1|) (-1150 |#1|)) 98)) (-4220 (((-1150 |#1|) (-1150 |#1|)) 55)) (-4321 (((-1150 |#1|) (-1150 |#1|)) 111)) (-4251 (((-1150 |#1|) (-1150 |#1|)) 86)) (-4308 (((-1150 |#1|) (-1150 |#1|)) 105)) (-4241 (((-1150 |#1|) (-1150 |#1|)) 82)) (-4333 (((-1150 |#1|) (-1150 |#1|)) 115)) (-4263 (((-1150 |#1|) (-1150 |#1|)) 90)) (-2104 (((-1150 |#1|) (-1150 |#1|)) 117)) (-4268 (((-1150 |#1|) (-1150 |#1|)) 92)) (-4327 (((-1150 |#1|) (-1150 |#1|)) 113)) (-4257 (((-1150 |#1|) (-1150 |#1|)) 88)) (-4314 (((-1150 |#1|) (-1150 |#1|)) 107)) (-4246 (((-1150 |#1|) (-1150 |#1|)) 84)) (** (((-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) 40))) 
-(((-1156 |#1|) (-10 -7 (-15 -4179 ((-1150 |#1|) (-1150 |#1|))) (-15 -3539 ((-1150 |#1|) (-1150 |#1|))) (-15 ** ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -1353 ((-2 (|:| -4217 (-1150 |#1|)) (|:| -4220 (-1150 |#1|))) (-1150 |#1|))) (-15 -4217 ((-1150 |#1|) (-1150 |#1|))) (-15 -4220 ((-1150 |#1|) (-1150 |#1|))) (-15 -4224 ((-1150 |#1|) (-1150 |#1|))) (-15 -4228 ((-1150 |#1|) (-1150 |#1|))) (-15 -4233 ((-1150 |#1|) (-1150 |#1|))) (-15 -4237 ((-1150 |#1|) (-1150 |#1|))) (-15 -4241 ((-1150 |#1|) (-1150 |#1|))) (-15 -4246 ((-1150 |#1|) (-1150 |#1|))) (-15 -4251 ((-1150 |#1|) (-1150 |#1|))) (-15 -4257 ((-1150 |#1|) (-1150 |#1|))) (-15 -4263 ((-1150 |#1|) (-1150 |#1|))) (-15 -4268 ((-1150 |#1|) (-1150 |#1|))) (-15 -2184 ((-2 (|:| -4273 (-1150 |#1|)) (|:| -4278 (-1150 |#1|))) (-1150 |#1|))) (-15 -4273 ((-1150 |#1|) (-1150 |#1|))) (-15 -4278 ((-1150 |#1|) (-1150 |#1|))) (-15 -4284 ((-1150 |#1|) (-1150 |#1|))) (-15 -4289 ((-1150 |#1|) (-1150 |#1|))) (-15 -4295 ((-1150 |#1|) (-1150 |#1|))) (-15 -4302 ((-1150 |#1|) (-1150 |#1|))) (-15 -4308 ((-1150 |#1|) (-1150 |#1|))) (-15 -4314 ((-1150 |#1|) (-1150 |#1|))) (-15 -4321 ((-1150 |#1|) (-1150 |#1|))) (-15 -4327 ((-1150 |#1|) (-1150 |#1|))) (-15 -4333 ((-1150 |#1|) (-1150 |#1|))) (-15 -2104 ((-1150 |#1|) (-1150 |#1|)))) (-43 (-413 (-572)))) (T -1156)) 
-((-2104 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4333 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4327 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4321 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4314 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4308 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4302 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4295 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4289 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4284 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4278 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4273 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-2184 (*1 *2 *3) (-12 (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-2 (|:| -4273 (-1150 *4)) (|:| -4278 (-1150 *4)))) (-5 *1 (-1156 *4)) (-5 *3 (-1150 *4)))) (-4268 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4263 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4257 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4251 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4246 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4241 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4237 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4233 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4228 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4224 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4220 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4217 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-1353 (*1 *2 *3) (-12 (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-2 (|:| -4217 (-1150 *4)) (|:| -4220 (-1150 *4)))) (-5 *1 (-1156 *4)) (-5 *3 (-1150 *4)))) (** (*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-3539 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) (-4179 (*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(-10 -7 (-15 -4179 ((-1150 |#1|) (-1150 |#1|))) (-15 -3539 ((-1150 |#1|) (-1150 |#1|))) (-15 ** ((-1150 |#1|) (-1150 |#1|) (-1150 |#1|))) (-15 -1353 ((-2 (|:| -4217 (-1150 |#1|)) (|:| -4220 (-1150 |#1|))) (-1150 |#1|))) (-15 -4217 ((-1150 |#1|) (-1150 |#1|))) (-15 -4220 ((-1150 |#1|) (-1150 |#1|))) (-15 -4224 ((-1150 |#1|) (-1150 |#1|))) (-15 -4228 ((-1150 |#1|) (-1150 |#1|))) (-15 -4233 ((-1150 |#1|) (-1150 |#1|))) (-15 -4237 ((-1150 |#1|) (-1150 |#1|))) (-15 -4241 ((-1150 |#1|) (-1150 |#1|))) (-15 -4246 ((-1150 |#1|) (-1150 |#1|))) (-15 -4251 ((-1150 |#1|) (-1150 |#1|))) (-15 -4257 ((-1150 |#1|) (-1150 |#1|))) (-15 -4263 ((-1150 |#1|) (-1150 |#1|))) (-15 -4268 ((-1150 |#1|) (-1150 |#1|))) (-15 -2184 ((-2 (|:| -4273 (-1150 |#1|)) (|:| -4278 (-1150 |#1|))) (-1150 |#1|))) (-15 -4273 ((-1150 |#1|) (-1150 |#1|))) (-15 -4278 ((-1150 |#1|) (-1150 |#1|))) (-15 -4284 ((-1150 |#1|) (-1150 |#1|))) (-15 -4289 ((-1150 |#1|) (-1150 |#1|))) (-15 -4295 ((-1150 |#1|) (-1150 |#1|))) (-15 -4302 ((-1150 |#1|) (-1150 |#1|))) (-15 -4308 ((-1150 |#1|) (-1150 |#1|))) (-15 -4314 ((-1150 |#1|) (-1150 |#1|))) (-15 -4321 ((-1150 |#1|) (-1150 |#1|))) (-15 -4327 ((-1150 |#1|) (-1150 |#1|))) (-15 -4333 ((-1150 |#1|) (-1150 |#1|))) (-15 -2104 ((-1150 |#1|) (-1150 |#1|)))) 
-((-3928 (((-965 |#2|) |#2| |#2|) 35)) (-3988 ((|#2| |#2| |#1|) 19 (|has| |#1| (-303))))) 
-(((-1157 |#1| |#2|) (-10 -7 (-15 -3928 ((-965 |#2|) |#2| |#2|)) (IF (|has| |#1| (-303)) (-15 -3988 (|#2| |#2| |#1|)) |noBranch|)) (-562) (-1234 |#1|)) (T -1157)) 
-((-3988 (*1 *2 *2 *3) (-12 (-4 *3 (-303)) (-4 *3 (-562)) (-5 *1 (-1157 *3 *2)) (-4 *2 (-1234 *3)))) (-3928 (*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-965 *3)) (-5 *1 (-1157 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -3928 ((-965 |#2|) |#2| |#2|)) (IF (|has| |#1| (-303)) (-15 -3988 (|#2| |#2| |#1|)) |noBranch|)) 
-((-2262 (((-121) $ $) NIL)) (-3033 (($ $ (-638 (-769))) 66)) (-4410 (($) 25)) (-2379 (($ $) 41)) (-2012 (((-638 $) $) 50)) (-3098 (((-121) $) 16)) (-1505 (((-638 (-950 |#2|)) $) 73)) (-1867 (($ $) 67)) (-1408 (((-769) $) 36)) (-1364 (($) 24)) (-4110 (($ $ (-638 (-769)) (-950 |#2|)) 59) (($ $ (-638 (-769)) (-769)) 60) (($ $ (-769) (-950 |#2|)) 62)) (-4475 (($ $ $) 47) (($ (-638 $)) 49)) (-1966 (((-769) $) 74)) (-3113 (((-121) $) 15)) (-1658 (((-1152) $) NIL)) (-3653 (((-121) $) 17)) (-2607 (((-1116) $) NIL)) (-2584 (((-173) $) 72)) (-2683 (((-950 |#2|) $) 68)) (-3224 (((-769) $) 69)) (-3151 (((-121) $) 71)) (-2406 (($ $ (-638 (-769)) (-173)) 65)) (-3250 (($ $) 42)) (-3972 (((-856) $) 84)) (-3191 (($ $ (-638 (-769)) (-121)) 64)) (-4118 (((-638 $) $) 11)) (-1352 (($ $ (-769)) 35)) (-3384 (($ $) 31)) (-1561 (($ $ $ (-950 |#2|) (-769)) 55)) (-2792 (($ $ (-950 |#2|)) 54)) (-1463 (($ $ (-638 (-769)) (-950 |#2|)) 53) (($ $ (-638 (-769)) (-769)) 57) (((-769) $ (-950 |#2|)) 58)) (-1324 (((-121) $ $) 78))) 
-(((-1158 |#1| |#2|) (-13 (-1098) (-10 -8 (-15 -3113 ((-121) $)) (-15 -3098 ((-121) $)) (-15 -3653 ((-121) $)) (-15 -1364 ($)) (-15 -4410 ($)) (-15 -3384 ($ $)) (-15 -1352 ($ $ (-769))) (-15 -4118 ((-638 $) $)) (-15 -1408 ((-769) $)) (-15 -2379 ($ $)) (-15 -3250 ($ $)) (-15 -4475 ($ $ $)) (-15 -4475 ($ (-638 $))) (-15 -2012 ((-638 $) $)) (-15 -1463 ($ $ (-638 (-769)) (-950 |#2|))) (-15 -2792 ($ $ (-950 |#2|))) (-15 -1561 ($ $ $ (-950 |#2|) (-769))) (-15 -4110 ($ $ (-638 (-769)) (-950 |#2|))) (-15 -1463 ($ $ (-638 (-769)) (-769))) (-15 -4110 ($ $ (-638 (-769)) (-769))) (-15 -1463 ((-769) $ (-950 |#2|))) (-15 -4110 ($ $ (-769) (-950 |#2|))) (-15 -3191 ($ $ (-638 (-769)) (-121))) (-15 -2406 ($ $ (-638 (-769)) (-173))) (-15 -3033 ($ $ (-638 (-769)))) (-15 -2683 ((-950 |#2|) $)) (-15 -3224 ((-769) $)) (-15 -3151 ((-121) $)) (-15 -2584 ((-173) $)) (-15 -1966 ((-769) $)) (-15 -1867 ($ $)) (-15 -1505 ((-638 (-950 |#2|)) $)))) (-923) (-1054)) (T -1158)) 
-((-3113 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-3098 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-3653 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-1364 (*1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) (-4410 (*1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) (-3384 (*1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) (-1352 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-4118 (*1 *2 *1) (-12 (-5 *2 (-638 (-1158 *3 *4))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-1408 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-2379 (*1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) (-3250 (*1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) (-4475 (*1 *1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) (-4475 (*1 *1 *2) (-12 (-5 *2 (-638 (-1158 *3 *4))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-2012 (*1 *2 *1) (-12 (-5 *2 (-638 (-1158 *3 *4))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-1463 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-950 *5)) (-4 *5 (-1054)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)))) (-2792 (*1 *1 *1 *2) (-12 (-5 *2 (-950 *4)) (-4 *4 (-1054)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)))) (-1561 (*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-950 *5)) (-5 *3 (-769)) (-4 *5 (-1054)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)))) (-4110 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-950 *5)) (-4 *5 (-1054)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)))) (-1463 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-769)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)) (-4 *5 (-1054)))) (-4110 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-769)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)) (-4 *5 (-1054)))) (-1463 (*1 *2 *1 *3) (-12 (-5 *3 (-950 *5)) (-4 *5 (-1054)) (-5 *2 (-769)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)))) (-4110 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-950 *5)) (-4 *5 (-1054)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)))) (-3191 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-121)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)) (-4 *5 (-1054)))) (-2406 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-173)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)) (-4 *5 (-1054)))) (-3033 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-769))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-2683 (*1 *2 *1) (-12 (-5 *2 (-950 *4)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-3224 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-3151 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-2584 (*1 *2 *1) (-12 (-5 *2 (-173)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-1966 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) (-1867 (*1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) (-1505 (*1 *2 *1) (-12 (-5 *2 (-638 (-950 *4))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(-13 (-1098) (-10 -8 (-15 -3113 ((-121) $)) (-15 -3098 ((-121) $)) (-15 -3653 ((-121) $)) (-15 -1364 ($)) (-15 -4410 ($)) (-15 -3384 ($ $)) (-15 -1352 ($ $ (-769))) (-15 -4118 ((-638 $) $)) (-15 -1408 ((-769) $)) (-15 -2379 ($ $)) (-15 -3250 ($ $)) (-15 -4475 ($ $ $)) (-15 -4475 ($ (-638 $))) (-15 -2012 ((-638 $) $)) (-15 -1463 ($ $ (-638 (-769)) (-950 |#2|))) (-15 -2792 ($ $ (-950 |#2|))) (-15 -1561 ($ $ $ (-950 |#2|) (-769))) (-15 -4110 ($ $ (-638 (-769)) (-950 |#2|))) (-15 -1463 ($ $ (-638 (-769)) (-769))) (-15 -4110 ($ $ (-638 (-769)) (-769))) (-15 -1463 ((-769) $ (-950 |#2|))) (-15 -4110 ($ $ (-769) (-950 |#2|))) (-15 -3191 ($ $ (-638 (-769)) (-121))) (-15 -2406 ($ $ (-638 (-769)) (-173))) (-15 -3033 ($ $ (-638 (-769)))) (-15 -2683 ((-950 |#2|) $)) (-15 -3224 ((-769) $)) (-15 -3151 ((-121) $)) (-15 -2584 ((-173) $)) (-15 -1966 ((-769) $)) (-15 -1867 ($ $)) (-15 -1505 ((-638 (-950 |#2|)) $)))) 
-((-2262 (((-121) $ $) NIL)) (-3194 ((|#2| $) 11)) (-4413 ((|#1| $) 10)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3921 (($ |#1| |#2|) 9)) (-3972 (((-856) $) 16)) (-1324 (((-121) $ $) NIL))) 
-(((-1159 |#1| |#2|) (-13 (-1098) (-10 -8 (-15 -3921 ($ |#1| |#2|)) (-15 -4413 (|#1| $)) (-15 -3194 (|#2| $)))) (-1098) (-1098)) (T -1159)) 
-((-3921 (*1 *1 *2 *3) (-12 (-5 *1 (-1159 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) (-4413 (*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-1159 *2 *3)) (-4 *3 (-1098)))) (-3194 (*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-1159 *3 *2)) (-4 *3 (-1098))))) 
-(-13 (-1098) (-10 -8 (-15 -3921 ($ |#1| |#2|)) (-15 -4413 (|#1| $)) (-15 -3194 (|#2| $)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 (((-1168 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-303)) (|has| |#1| (-368))))) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 11)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-3946 (($ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-3686 (((-121) $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-2525 (($ $ (-572)) NIL) (($ $ (-572) (-572)) 66)) (-2640 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL)) (-2118 (((-1168 |#1| |#2| |#3|) $) 36)) (-4272 (((-3 (-1168 |#1| |#2| |#3|) "failed") $) 29)) (-1881 (((-1168 |#1| |#2| |#3|) $) 30)) (-4284 (($ $) 107 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 83 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) 103 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 79 (|has| |#1| (-43 (-413 (-572)))))) (-2433 (((-572) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))))) (-4521 (($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) NIL)) (-4295 (($ $) 111 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 87 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-1168 |#1| |#2| |#3|) "failed") $) 31) (((-3 (-1170) "failed") $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1044 (-1170))) (|has| |#1| (-368)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368)))) (((-3 (-572) "failed") $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368))))) (-1318 (((-1168 |#1| |#2| |#3|) $) 131) (((-1170) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1044 (-1170))) (|has| |#1| (-368)))) (((-413 (-572)) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368)))) (((-572) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368))))) (-3729 (($ $) 34) (($ (-572) $) 35)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-1168 |#1| |#2| |#3|)) (-685 $)) NIL (|has| |#1| (-368))) (((-2 (|:| -1369 (-685 (-1168 |#1| |#2| |#3|))) (|:| |vec| (-1259 (-1168 |#1| |#2| |#3|)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-368))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-634 (-572))) (|has| |#1| (-368)))) (((-685 (-572)) (-685 $)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-634 (-572))) (|has| |#1| (-368))))) (-1799 (((-3 $ "failed") $) 48)) (-2059 (((-413 (-959 |#1|)) $ (-572)) 65 (|has| |#1| (-562))) (((-413 (-959 |#1|)) $ (-572) (-572)) 67 (|has| |#1| (-562)))) (-3286 (($) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-554)) (|has| |#1| (-368))))) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-1908 (((-121) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))))) (-1347 (((-121) $) 25)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-887 (-572))) (|has| |#1| (-368)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-887 (-385))) (|has| |#1| (-368))))) (-3377 (((-572) $) NIL) (((-572) $ (-572)) 24)) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL (|has| |#1| (-368)))) (-4487 (((-1168 |#1| |#2| |#3|) $) 38 (|has| |#1| (-368)))) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3961 (((-3 $ "failed") $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1144)) (|has| |#1| (-368))))) (-4472 (((-121) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))))) (-3965 (($ $ (-923)) NIL)) (-4324 (($ (-1 |#1| (-572)) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-572)) 18) (($ $ (-1082) (-572)) NIL) (($ $ (-638 (-1082)) (-638 (-572))) NIL)) (-1771 (($ $ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-4238 (($ $ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|)) $) NIL (|has| |#1| (-368)))) (-3539 (($ $) 72 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1885 (($ (-572) (-1168 |#1| |#2| |#3|)) 33)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-2774 (($ $) 70 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 |#2|)) 71 (|has| |#1| (-43 (-413 (-572)))))) (-1773 (($) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1144)) (|has| |#1| (-368))) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-3346 (($ $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-303)) (|has| |#1| (-368))))) (-1716 (((-1168 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-554)) (|has| |#1| (-368))))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1977 (($ $ (-572)) 145)) (-1803 (((-3 $ "failed") $ $) 49 (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4179 (($ $) 73 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-572))))) (($ $ (-1170) (-1168 |#1| |#2| |#3|)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-527 (-1170) (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-638 (-1170)) (-638 (-1168 |#1| |#2| |#3|))) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-527 (-1170) (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-638 (-290 (-1168 |#1| |#2| |#3|)))) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-305 (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-290 (-1168 |#1| |#2| |#3|))) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-305 (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-305 (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-638 (-1168 |#1| |#2| |#3|)) (-638 (-1168 |#1| |#2| |#3|))) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-305 (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368))))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ (-572)) NIL) (($ $ $) 54 (|has| (-572) (-1110))) (($ $ (-1168 |#1| |#2| |#3|)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-283 (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|))) (|has| |#1| (-368))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3139 (($ $ (-1 (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|))) NIL (|has| |#1| (-368))) (($ $ (-1 (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|)) (-769)) NIL (|has| |#1| (-368))) (($ $ (-1255 |#2|)) 51) (($ $ (-769)) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $) 50 (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170) (-769)) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-638 (-1170))) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))))) (-3425 (($ $) NIL (|has| |#1| (-368)))) (-4492 (((-1168 |#1| |#2| |#3|) $) 41 (|has| |#1| (-368)))) (-4316 (((-572) $) 37)) (-4302 (($ $) 113 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 89 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 109 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 85 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 105 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 81 (|has| |#1| (-43 (-413 (-572)))))) (-4081 (((-545) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-613 (-545))) (|has| |#1| (-368)))) (((-385) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1028)) (|has| |#1| (-368)))) (((-217) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1028)) (|has| |#1| (-368)))) (((-893 (-385)) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-613 (-893 (-385)))) (|has| |#1| (-368)))) (((-893 (-572)) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-613 (-893 (-572)))) (|has| |#1| (-368))))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-2424 (($ $) NIL)) (-3972 (((-856) $) 149) (($ (-572)) NIL) (($ |#1|) NIL (|has| |#1| (-174))) (($ (-1168 |#1| |#2| |#3|)) 27) (($ (-1255 |#2|)) 23) (($ (-1170)) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-1044 (-1170))) (|has| |#1| (-368)))) (($ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562)))) (($ (-413 (-572))) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368))) (|has| |#1| (-43 (-413 (-572))))))) (-1958 ((|#1| $ (-572)) 68)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-149)) (|has| |#1| (-368))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) 12)) (-2634 (((-1168 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-554)) (|has| |#1| (-368))))) (-4321 (($ $) 119 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 95 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-4308 (($ $) 115 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 91 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 123 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 99 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-572)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-572)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 125 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 101 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 121 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 97 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 117 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 93 (|has| |#1| (-43 (-413 (-572)))))) (-2264 (($ $) NIL (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 20 T CONST)) (-3255 (($) 16 T CONST)) (-1557 (($ $ (-1 (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|))) NIL (|has| |#1| (-368))) (($ $ (-1 (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|)) (-769)) NIL (|has| |#1| (-368))) (($ $ (-769)) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170) (-769)) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-638 (-1170))) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))))) (-1349 (((-121) $ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-1338 (((-121) $ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-1334 (((-121) $ $) NIL (-1841 (-12 (|has| (-1168 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1168 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) 44 (|has| |#1| (-368))) (($ (-1168 |#1| |#2| |#3|) (-1168 |#1| |#2| |#3|)) 45 (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 21)) (** (($ $ (-923)) NIL) (($ $ (-769)) 53) (($ $ (-572)) NIL (|has| |#1| (-368))) (($ $ $) 74 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 128 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 32) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-1168 |#1| |#2| |#3|)) 43 (|has| |#1| (-368))) (($ (-1168 |#1| |#2| |#3|) $) 42 (|has| |#1| (-368))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1160 |#1| |#2| |#3|) (-13 (-1220 |#1| (-1168 |#1| |#2| |#3|)) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) (-1054) (-1170) |#1|) (T -1160)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1160 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1160 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1160 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3)))) 
-(-13 (-1220 |#1| (-1168 |#1| |#2| |#3|)) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) 
-((-4360 ((|#2| |#2| (-1090 |#2|)) 26) ((|#2| |#2| (-1170)) 28))) 
-(((-1161 |#1| |#2|) (-10 -7 (-15 -4360 (|#2| |#2| (-1170))) (-15 -4360 (|#2| |#2| (-1090 |#2|)))) (-13 (-562) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-436 |#1|) (-162) (-27) (-1190))) (T -1161)) 
-((-4360 (*1 *2 *2 *3) (-12 (-5 *3 (-1090 *2)) (-4 *2 (-13 (-436 *4) (-162) (-27) (-1190))) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1161 *4 *2)))) (-4360 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1161 *4 *2)) (-4 *2 (-13 (-436 *4) (-162) (-27) (-1190)))))) 
-(-10 -7 (-15 -4360 (|#2| |#2| (-1170))) (-15 -4360 (|#2| |#2| (-1090 |#2|)))) 
-((-4360 (((-3 (-413 (-959 |#1|)) (-312 |#1|)) (-413 (-959 |#1|)) (-1090 (-413 (-959 |#1|)))) 30) (((-413 (-959 |#1|)) (-959 |#1|) (-1090 (-959 |#1|))) 44) (((-3 (-413 (-959 |#1|)) (-312 |#1|)) (-413 (-959 |#1|)) (-1170)) 32) (((-413 (-959 |#1|)) (-959 |#1|) (-1170)) 36))) 
-(((-1162 |#1|) (-10 -7 (-15 -4360 ((-413 (-959 |#1|)) (-959 |#1|) (-1170))) (-15 -4360 ((-3 (-413 (-959 |#1|)) (-312 |#1|)) (-413 (-959 |#1|)) (-1170))) (-15 -4360 ((-413 (-959 |#1|)) (-959 |#1|) (-1090 (-959 |#1|)))) (-15 -4360 ((-3 (-413 (-959 |#1|)) (-312 |#1|)) (-413 (-959 |#1|)) (-1090 (-413 (-959 |#1|)))))) (-13 (-562) (-848) (-1044 (-572)))) (T -1162)) 
-((-4360 (*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-413 (-959 *5)))) (-5 *3 (-413 (-959 *5))) (-4 *5 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-3 *3 (-312 *5))) (-5 *1 (-1162 *5)))) (-4360 (*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-959 *5))) (-5 *3 (-959 *5)) (-4 *5 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-413 *3)) (-5 *1 (-1162 *5)))) (-4360 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-3 (-413 (-959 *5)) (-312 *5))) (-5 *1 (-1162 *5)) (-5 *3 (-413 (-959 *5))))) (-4360 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-413 (-959 *5))) (-5 *1 (-1162 *5)) (-5 *3 (-959 *5))))) 
-(-10 -7 (-15 -4360 ((-413 (-959 |#1|)) (-959 |#1|) (-1170))) (-15 -4360 ((-3 (-413 (-959 |#1|)) (-312 |#1|)) (-413 (-959 |#1|)) (-1170))) (-15 -4360 ((-413 (-959 |#1|)) (-959 |#1|) (-1090 (-959 |#1|)))) (-15 -4360 ((-3 (-413 (-959 |#1|)) (-312 |#1|)) (-413 (-959 |#1|)) (-1090 (-413 (-959 |#1|)))))) 
-((-3828 (((-1166 |#2|) (-1 |#2| |#1|) (-1166 |#1|)) 13))) 
-(((-1163 |#1| |#2|) (-10 -7 (-15 -3828 ((-1166 |#2|) (-1 |#2| |#1|) (-1166 |#1|)))) (-1054) (-1054)) (T -1163)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1166 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-1166 *6)) (-5 *1 (-1163 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-1166 |#2|) (-1 |#2| |#1|) (-1166 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3275 (((-1259 |#1|) $ (-769)) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-2383 (($ (-1166 |#1|)) NIL)) (-4297 (((-1166 $) $ (-1082)) NIL) (((-1166 |#1|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1082))) NIL)) (-4284 (($ $) NIL (|has| |#1| (-1190)))) (-4224 (($ $) NIL (|has| |#1| (-1190)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2824 (($ $ $) NIL (|has| |#1| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) NIL (|has| |#1| (-1190)))) (-4217 (($ $) 22 (|has| |#1| (-1190)))) (-2786 (($ $ (-769)) NIL)) (-3944 (($ $ (-769)) NIL)) (-2012 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-457)))) (-4295 (($ $) NIL (|has| |#1| (-1190)))) (-4233 (($ $) NIL (|has| |#1| (-1190)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-1082) "failed") $) NIL)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-1082) $) NIL)) (-3190 (($ $ $ (-1082)) NIL (|has| |#1| (-174))) ((|#1| $ $) NIL (|has| |#1| (-174)))) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3890 (($ $ $) NIL)) (-3039 (($ $ $) NIL (|has| |#1| (-562)))) (-1449 (((-2 (|:| -4513 |#1|) (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-3988 (($ $) NIL (|has| |#1| (-457))) (($ $ (-1082)) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-769) $) NIL)) (-4184 (($) NIL (|has| |#1| (-1190)))) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1082) (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1082) (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3377 (((-769) $ $) NIL (|has| |#1| (-562)))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-1144)))) (-4335 (($ (-1166 |#1|) (-1082)) NIL) (($ (-1166 $) (-1082)) NIL)) (-3965 (($ $ (-769)) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1082)) NIL) (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-1784 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-769) (-769)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-4155 (((-1166 |#1|) $) NIL)) (-1470 (((-3 (-1082) "failed") $) NIL)) (-3539 (($ $) 18 (|has| |#1| (-1190)))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-2845 (((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769)) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-1082)) (|:| -3751 (-769))) "failed") $) NIL)) (-2774 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1773 (($) NIL (|has| |#1| (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 8)) (-4362 ((|#1| $) 9)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#1| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-910)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1803 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4179 (($ $) 20 (|has| |#1| (-1190)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1082) |#1|) NIL) (($ $ (-638 (-1082)) (-638 |#1|)) NIL) (($ $ (-1082) $) NIL) (($ $ (-638 (-1082)) (-638 $)) NIL)) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-413 $) (-413 $) (-413 $)) NIL (|has| |#1| (-562))) ((|#1| (-413 $) |#1|) NIL (|has| |#1| (-368))) (((-413 $) $ (-413 $)) NIL (|has| |#1| (-562)))) (-1997 (((-3 $ "failed") $ (-769)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-2119 (($ $ (-1082)) NIL (|has| |#1| (-174))) ((|#1| $) NIL (|has| |#1| (-174)))) (-3139 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-4316 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-4302 (($ $) NIL (|has| |#1| (-1190)))) (-4237 (($ $) NIL (|has| |#1| (-1190)))) (-4289 (($ $) NIL (|has| |#1| (-1190)))) (-4228 (($ $) NIL (|has| |#1| (-1190)))) (-4278 (($ $) NIL (|has| |#1| (-1190)))) (-4220 (($ $) 26 (|has| |#1| (-1190)))) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-1082) (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) NIL (|has| |#1| (-457))) (($ $ (-1082)) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-2268 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562))) (((-3 (-413 $) "failed") (-413 $) $) NIL (|has| |#1| (-562)))) (-3972 (((-856) $) 13) (($ (-572)) NIL) (($ |#1|) 11) (($ (-1082)) NIL) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-4321 (($ $) NIL (|has| |#1| (-1190)))) (-4251 (($ $) NIL (|has| |#1| (-1190)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-1190)))) (-4241 (($ $) 24 (|has| |#1| (-1190)))) (-4333 (($ $) NIL (|has| |#1| (-1190)))) (-4263 (($ $) NIL (|has| |#1| (-1190)))) (-2104 (($ $) NIL (|has| |#1| (-1190)))) (-4268 (($ $) NIL (|has| |#1| (-1190)))) (-4327 (($ $) NIL (|has| |#1| (-1190)))) (-4257 (($ $) NIL (|has| |#1| (-1190)))) (-4314 (($ $) NIL (|has| |#1| (-1190)))) (-4246 (($ $) 28 (|has| |#1| (-1190)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ $) NIL (|has| |#1| (-1190)))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-1164 |#1|) (-13 (-1234 |#1|) (-10 -7 (IF (|has| |#1| (-1190)) (-6 (-1190)) |noBranch|))) (-1054)) (T -1164)) 
-NIL 
-(-13 (-1234 |#1|) (-10 -7 (IF (|has| |#1| (-1190)) (-6 (-1190)) |noBranch|))) 
-((-1466 (((-424 (-1166 (-413 |#4|))) (-1166 (-413 |#4|))) 50)) (-4304 (((-424 (-1166 (-413 |#4|))) (-1166 (-413 |#4|))) 51))) 
-(((-1165 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4304 ((-424 (-1166 (-413 |#4|))) (-1166 (-413 |#4|)))) (-15 -1466 ((-424 (-1166 (-413 |#4|))) (-1166 (-413 |#4|))))) (-794) (-848) (-457) (-956 |#3| |#1| |#2|)) (T -1165)) 
-((-1466 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-457)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-424 (-1166 (-413 *7)))) (-5 *1 (-1165 *4 *5 *6 *7)) (-5 *3 (-1166 (-413 *7))))) (-4304 (*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-457)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-424 (-1166 (-413 *7)))) (-5 *1 (-1165 *4 *5 *6 *7)) (-5 *3 (-1166 (-413 *7)))))) 
-(-10 -7 (-15 -4304 ((-424 (-1166 (-413 |#4|))) (-1166 (-413 |#4|)))) (-15 -1466 ((-424 (-1166 (-413 |#4|))) (-1166 (-413 |#4|))))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 30)) (-3275 (((-1259 |#1|) $ (-769)) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-2383 (($ (-1166 |#1|)) NIL)) (-4297 (((-1166 $) $ (-1082)) 59) (((-1166 |#1|) $) 48)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) 132 (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1082))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2824 (($ $ $) 126 (|has| |#1| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) 72 (|has| |#1| (-910)))) (-2844 (($ $) NIL (|has| |#1| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 92 (|has| |#1| (-910)))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-2786 (($ $ (-769)) 42)) (-3944 (($ $ (-769)) 43)) (-2012 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-457)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#1| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-1082) "failed") $) NIL)) (-1318 ((|#1| $) NIL) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-1082) $) NIL)) (-3190 (($ $ $ (-1082)) NIL (|has| |#1| (-174))) ((|#1| $ $) 128 (|has| |#1| (-174)))) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) 57)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) NIL) (((-685 |#1|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3890 (($ $ $) 104)) (-3039 (($ $ $) NIL (|has| |#1| (-562)))) (-1449 (((-2 (|:| -4513 |#1|) (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-3988 (($ $) 133 (|has| |#1| (-457))) (($ $ (-1082)) NIL (|has| |#1| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-769) $) 46)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1082) (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1082) (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-2147 (((-856) $ (-856)) 117)) (-3377 (((-769) $ $) NIL (|has| |#1| (-562)))) (-3893 (((-121) $) 32)) (-3475 (((-769) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| |#1| (-1144)))) (-4335 (($ (-1166 |#1|) (-1082)) 50) (($ (-1166 $) (-1082)) 66)) (-3965 (($ $ (-769)) 34)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) 64) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1082)) NIL) (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 121)) (-1784 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-3918 (($ (-1 (-769) (-769)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-4155 (((-1166 |#1|) $) NIL)) (-1470 (((-3 (-1082) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) 53)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) NIL (|has| |#1| (-457)))) (-1658 (((-1152) $) NIL)) (-2845 (((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769)) 41)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-1082)) (|:| -3751 (-769))) "failed") $) NIL)) (-2774 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1773 (($) NIL (|has| |#1| (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) 33)) (-4362 ((|#1| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 80 (|has| |#1| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-457))) (($ $ $) 135 (|has| |#1| (-457)))) (-3311 (($ $ (-769) |#1| $) 99)) (-4364 (((-424 (-1166 $)) (-1166 $)) 78 (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) 77 (|has| |#1| (-910)))) (-4304 (((-424 $) $) 85 (|has| |#1| (-910)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1803 (((-3 $ "failed") $ |#1|) 131 (|has| |#1| (-562))) (((-3 $ "failed") $ $) 100 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1082) |#1|) NIL) (($ $ (-638 (-1082)) (-638 |#1|)) NIL) (($ $ (-1082) $) NIL) (($ $ (-638 (-1082)) (-638 $)) NIL)) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ |#1|) 119) (($ $ $) 120) (((-413 $) (-413 $) (-413 $)) NIL (|has| |#1| (-562))) ((|#1| (-413 $) |#1|) NIL (|has| |#1| (-368))) (((-413 $) $ (-413 $)) NIL (|has| |#1| (-562)))) (-1997 (((-3 $ "failed") $ (-769)) 37)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 137 (|has| |#1| (-368)))) (-2119 (($ $ (-1082)) NIL (|has| |#1| (-174))) ((|#1| $) 124 (|has| |#1| (-174)))) (-3139 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-4316 (((-769) $) 55) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-1082) (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) 130 (|has| |#1| (-457))) (($ $ (-1082)) NIL (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#1| (-910))))) (-2268 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562))) (((-3 (-413 $) "failed") (-413 $) $) NIL (|has| |#1| (-562)))) (-3972 (((-856) $) 118) (($ (-572)) NIL) (($ |#1|) 54) (($ (-1082)) NIL) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) 28 (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 15) (($ $ (-769)) 16)) (-2378 (($) 17 T CONST)) (-3255 (($) 18 T CONST)) (-1557 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) 97)) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1379 (($ $ |#1|) 138 (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 67)) (** (($ $ (-923)) 14) (($ $ (-769)) 12)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 27) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 102) (($ $ |#1|) NIL))) 
-(((-1166 |#1|) (-13 (-1234 |#1|) (-10 -8 (-15 -2147 ((-856) $ (-856))) (-15 -3311 ($ $ (-769) |#1| $)))) (-1054)) (T -1166)) 
-((-2147 (*1 *2 *1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-1166 *3)) (-4 *3 (-1054)))) (-3311 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1166 *3)) (-4 *3 (-1054))))) 
-(-13 (-1234 |#1|) (-10 -8 (-15 -2147 ((-856) $ (-856))) (-15 -3311 ($ $ (-769) |#1| $)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 11)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-413 (-572))) NIL) (($ $ (-413 (-572)) (-413 (-572))) NIL)) (-2640 (((-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|))) $) NIL)) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-769) (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|)))) NIL)) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-1160 |#1| |#2| |#3|) "failed") $) 32) (((-3 (-1168 |#1| |#2| |#3|) "failed") $) 35)) (-1318 (((-1160 |#1| |#2| |#3|) $) NIL) (((-1168 |#1| |#2| |#3|) $) NIL)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-4329 (((-413 (-572)) $) 55)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-1889 (($ (-413 (-572)) (-1160 |#1| |#2| |#3|)) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-413 (-572)) $) NIL) (((-413 (-572)) $ (-413 (-572))) NIL)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) NIL) (($ $ (-413 (-572))) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-413 (-572))) 19) (($ $ (-1082) (-413 (-572))) NIL) (($ $ (-638 (-1082)) (-638 (-413 (-572)))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-4170 (((-1160 |#1| |#2| |#3|) $) 40)) (-2475 (((-3 (-1160 |#1| |#2| |#3|) "failed") $) NIL)) (-1885 (((-1160 |#1| |#2| |#3|) $) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-2774 (($ $) 38 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 |#2|)) 39 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1977 (($ $ (-413 (-572))) NIL)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ (-413 (-572))) NIL) (($ $ $) NIL (|has| (-413 (-572)) (-1110)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) 36 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $ (-1255 |#2|)) 37)) (-4316 (((-413 (-572)) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) NIL)) (-3972 (((-856) $) 58) (($ (-572)) NIL) (($ |#1|) NIL (|has| |#1| (-174))) (($ (-1160 |#1| |#2| |#3|)) 29) (($ (-1168 |#1| |#2| |#3|)) 30) (($ (-1255 |#2|)) 25) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562)))) (-1958 ((|#1| $ (-413 (-572))) NIL)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) 12)) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-413 (-572))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 21 T CONST)) (-3255 (($) 16 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 23)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1167 |#1| |#2| |#3|) (-13 (-1241 |#1| (-1160 |#1| |#2| |#3|)) (-1044 (-1168 |#1| |#2| |#3|)) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) (-1054) (-1170) |#1|) (T -1167)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1167 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1167 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1167 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3)))) 
-(-13 (-1241 |#1| (-1160 |#1| |#2| |#3|)) (-1044 (-1168 |#1| |#2| |#3|)) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 124)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 115)) (-2970 (((-1231 |#2| |#1|) $ (-769)) 62)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-769)) 78) (($ $ (-769) (-769)) 75)) (-2640 (((-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|))) $) 101)) (-4284 (($ $) 168 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 144 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4273 (($ $) 164 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 140 (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|)))) 114) (($ (-1150 |#1|)) 109)) (-4295 (($ $) 172 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 148 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) 23)) (-2531 (($ $) 26)) (-1896 (((-959 |#1|) $ (-769)) 74) (((-959 |#1|) $ (-769) (-769)) 76)) (-1347 (((-121) $) 119)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-769) $) 121) (((-769) $ (-769)) 123)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) NIL)) (-4324 (($ (-1 |#1| (-572)) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) 13) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3539 (($ $) 130 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2774 (($ $) 128 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 |#2|)) 129 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-1977 (($ $ (-769)) 15)) (-1803 (((-3 $ "failed") $ $) 24 (|has| |#1| (-562)))) (-4179 (($ $) 132 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-769)))))) (-3277 ((|#1| $ (-769)) 118) (($ $ $) 127 (|has| (-769) (-1110)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) 27 (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $ (-1255 |#2|)) 29)) (-4316 (((-769) $) NIL)) (-4302 (($ $) 174 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 150 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 170 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 146 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 166 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 142 (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) NIL)) (-3972 (((-856) $) 200) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562))) (($ |#1|) 125 (|has| |#1| (-174))) (($ (-1231 |#2| |#1|)) 50) (($ (-1255 |#2|)) 32)) (-3193 (((-1150 |#1|) $) 97)) (-1958 ((|#1| $ (-769)) 117)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) 53)) (-4321 (($ $) 180 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 156 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) 176 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 152 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 184 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 160 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-769)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-769)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 186 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 162 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 182 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 158 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 178 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 154 (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 17 T CONST)) (-3255 (($) 19 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) 193)) (-1367 (($ $ $) 31)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ |#1|) 197 (|has| |#1| (-368))) (($ $ $) 133 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 136 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 131) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1168 |#1| |#2| |#3|) (-13 (-1249 |#1|) (-10 -8 (-15 -3972 ($ (-1231 |#2| |#1|))) (-15 -2970 ((-1231 |#2| |#1|) $ (-769))) (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) (-1054) (-1170) |#1|) (T -1168)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1231 *4 *3)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3) (-5 *1 (-1168 *3 *4 *5)))) (-2970 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1231 *5 *4)) (-5 *1 (-1168 *4 *5 *6)) (-4 *4 (-1054)) (-14 *5 (-1170)) (-14 *6 *4))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1168 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1168 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1168 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3)))) 
-(-13 (-1249 |#1|) (-10 -8 (-15 -3972 ($ (-1231 |#2| |#1|))) (-15 -2970 ((-1231 |#2| |#1|) $ (-769))) (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) 
-((-3972 (((-856) $) 22) (($ (-1170)) 24)) (-1841 (($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $))) 35)) (-1839 (($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $))) 28) (($ $) 29)) (-2363 (($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $))) 30)) (-1794 (($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $))) 32)) (-2624 (($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $))) 31)) (-1894 (($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $))) 33)) (-3015 (($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $))) 36)) (-12 (($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $))) 34))) 
-(((-1169) (-13 (-612 (-856)) (-10 -8 (-15 -3972 ($ (-1170))) (-15 -2363 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -2624 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1794 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1894 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1841 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -3015 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -12 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1839 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1839 ($ $))))) (T -1169)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1169)))) (-2363 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169)))) (-2624 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169)))) (-1794 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169)))) (-1894 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169)))) (-1841 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169)))) (-3015 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169)))) (-12 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169)))) (-1839 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169)))) (-1839 (*1 *1 *1) (-5 *1 (-1169)))) 
-(-13 (-612 (-856)) (-10 -8 (-15 -3972 ($ (-1170))) (-15 -2363 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -2624 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1794 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1894 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1841 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -3015 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -12 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)) (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1839 ($ (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| $)))) (-15 -1839 ($ $)))) 
-((-2262 (((-121) $ $) NIL)) (-3957 (($ $ (-638 (-856))) 58)) (-1339 (($ $ (-638 (-856))) 56)) (-4035 (((-1152) $) 82)) (-3206 (((-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856)))) $) 85)) (-2942 (((-121) $) 21)) (-1927 (($ $ (-638 (-638 (-856)))) 54) (($ $ (-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856))))) 80)) (-2211 (($) 122 T CONST)) (-2273 (((-1264)) 103)) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 65) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 71)) (-1364 (($) 92) (($ $) 98)) (-3201 (($ $) 81)) (-1771 (($ $ $) NIL)) (-4238 (($ $ $) NIL)) (-1624 (((-638 $) $) 104)) (-1658 (((-1152) $) 87)) (-2607 (((-1116) $) NIL)) (-3277 (($ $ (-638 (-856))) 57)) (-4081 (((-545) $) 45) (((-1170) $) 46) (((-893 (-572)) $) 75) (((-893 (-385)) $) 73)) (-3972 (((-856) $) 52) (($ (-1152)) 47)) (-4546 (($ $ (-638 (-856))) 59)) (-3594 (((-1152) $) 33) (((-1152) $ (-121)) 34) (((-1264) (-823) $) 35) (((-1264) (-823) $ (-121)) 36)) (-1349 (((-121) $ $) NIL)) (-1338 (((-121) $ $) NIL)) (-1324 (((-121) $ $) 48)) (-1343 (((-121) $ $) NIL)) (-1334 (((-121) $ $) 49))) 
-(((-1170) (-13 (-848) (-613 (-545)) (-829) (-613 (-1170)) (-613 (-893 (-572))) (-613 (-893 (-385))) (-887 (-572)) (-887 (-385)) (-10 -8 (-15 -1364 ($)) (-15 -1364 ($ $)) (-15 -2273 ((-1264))) (-15 -3972 ($ (-1152))) (-15 -3201 ($ $)) (-15 -2942 ((-121) $)) (-15 -3206 ((-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856)))) $)) (-15 -1927 ($ $ (-638 (-638 (-856))))) (-15 -1927 ($ $ (-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856)))))) (-15 -1339 ($ $ (-638 (-856)))) (-15 -3957 ($ $ (-638 (-856)))) (-15 -4546 ($ $ (-638 (-856)))) (-15 -3277 ($ $ (-638 (-856)))) (-15 -4035 ((-1152) $)) (-15 -1624 ((-638 $) $)) (-15 -2211 ($) -3211)))) (T -1170)) 
-((-1364 (*1 *1) (-5 *1 (-1170))) (-1364 (*1 *1 *1) (-5 *1 (-1170))) (-2273 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1170)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1170)))) (-3201 (*1 *1 *1) (-5 *1 (-1170))) (-2942 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1170)))) (-3206 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856))))) (-5 *1 (-1170)))) (-1927 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-638 (-856)))) (-5 *1 (-1170)))) (-1927 (*1 *1 *1 *2) (-12 (-5 *2 (-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856))))) (-5 *1 (-1170)))) (-1339 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-1170)))) (-3957 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-1170)))) (-4546 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-1170)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-1170)))) (-4035 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1170)))) (-1624 (*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-1170)))) (-2211 (*1 *1) (-5 *1 (-1170)))) 
-(-13 (-848) (-613 (-545)) (-829) (-613 (-1170)) (-613 (-893 (-572))) (-613 (-893 (-385))) (-887 (-572)) (-887 (-385)) (-10 -8 (-15 -1364 ($)) (-15 -1364 ($ $)) (-15 -2273 ((-1264))) (-15 -3972 ($ (-1152))) (-15 -3201 ($ $)) (-15 -2942 ((-121) $)) (-15 -3206 ((-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856)))) $)) (-15 -1927 ($ $ (-638 (-638 (-856))))) (-15 -1927 ($ $ (-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856)))))) (-15 -1339 ($ $ (-638 (-856)))) (-15 -3957 ($ $ (-638 (-856)))) (-15 -4546 ($ $ (-638 (-856)))) (-15 -3277 ($ $ (-638 (-856)))) (-15 -4035 ((-1152) $)) (-15 -1624 ((-638 $) $)) (-15 -2211 ($) -3211))) 
-((-2453 (((-1259 |#1|) |#1| (-923)) 16) (((-1259 |#1|) (-638 |#1|)) 20))) 
-(((-1171 |#1|) (-10 -7 (-15 -2453 ((-1259 |#1|) (-638 |#1|))) (-15 -2453 ((-1259 |#1|) |#1| (-923)))) (-1054)) (T -1171)) 
-((-2453 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-5 *2 (-1259 *3)) (-5 *1 (-1171 *3)) (-4 *3 (-1054)))) (-2453 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1054)) (-5 *2 (-1259 *4)) (-5 *1 (-1171 *4))))) 
-(-10 -7 (-15 -2453 ((-1259 |#1|) (-638 |#1|))) (-15 -2453 ((-1259 |#1|) |#1| (-923)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| |#1| (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#1| (-1044 (-413 (-572))))) (((-3 |#1| "failed") $) NIL)) (-1318 (((-572) $) NIL (|has| |#1| (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| |#1| (-1044 (-413 (-572))))) ((|#1| $) NIL)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-3988 (($ $) NIL (|has| |#1| (-457)))) (-3977 (($ $ |#1| (-979) $) NIL)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-979)) NIL)) (-1784 (((-979) $) NIL)) (-3918 (($ (-1 (-979) (-979)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#1| $) NIL)) (-3311 (($ $ (-979) |#1| $) NIL (-12 (|has| (-979) (-138)) (|has| |#1| (-562))))) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562))) (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-562)))) (-4316 (((-979) $) NIL)) (-3694 ((|#1| $) NIL (|has| |#1| (-457)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ $) NIL (|has| |#1| (-562))) (($ |#1|) NIL) (($ (-413 (-572))) NIL (-1841 (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-1044 (-413 (-572))))))) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ (-979)) NIL)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#1| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 9 T CONST)) (-3255 (($) 14 T CONST)) (-1324 (((-121) $ $) 16)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 19)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 20) (($ $ |#1|) NIL) (($ |#1| $) 13) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1172 |#1|) (-13 (-326 |#1| (-979)) (-10 -8 (IF (|has| |#1| (-562)) (IF (|has| (-979) (-138)) (-15 -3311 ($ $ (-979) |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4600)) (-6 -4600) |noBranch|))) (-1054)) (T -1172)) 
-((-3311 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-979)) (-4 *2 (-138)) (-5 *1 (-1172 *3)) (-4 *3 (-562)) (-4 *3 (-1054))))) 
-(-13 (-326 |#1| (-979)) (-10 -8 (IF (|has| |#1| (-562)) (IF (|has| (-979) (-138)) (-15 -3311 ($ $ (-979) |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4600)) (-6 -4600) |noBranch|))) 
-((-4381 (((-1174) (-1170) $) 24)) (-1597 (($) 28)) (-3122 (((-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-1170) $) 21)) (-4094 (((-1264) (-1170) (-3 (|:| |fst| (-440)) (|:| -3166 "void")) $) 40) (((-1264) (-1170) (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) 41) (((-1264) (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) 42)) (-1525 (((-1264) (-1170)) 57)) (-1655 (((-1264) (-1170) $) 54) (((-1264) (-1170)) 55) (((-1264)) 56)) (-4482 (((-1264) (-1170)) 36)) (-4402 (((-1170)) 35)) (-1665 (($) 33)) (-3372 (((-443) (-1170) (-443) (-1170) $) 44) (((-443) (-638 (-1170)) (-443) (-1170) $) 48) (((-443) (-1170) (-443)) 45) (((-443) (-1170) (-443) (-1170)) 49)) (-3459 (((-1170)) 34)) (-3972 (((-856) $) 27)) (-3495 (((-1264)) 29) (((-1264) (-1170)) 32)) (-2389 (((-638 (-1170)) (-1170) $) 23)) (-2921 (((-1264) (-1170) (-638 (-1170)) $) 37) (((-1264) (-1170) (-638 (-1170))) 38) (((-1264) (-638 (-1170))) 39))) 
-(((-1173) (-13 (-612 (-856)) (-10 -8 (-15 -1597 ($)) (-15 -3495 ((-1264))) (-15 -3495 ((-1264) (-1170))) (-15 -3372 ((-443) (-1170) (-443) (-1170) $)) (-15 -3372 ((-443) (-638 (-1170)) (-443) (-1170) $)) (-15 -3372 ((-443) (-1170) (-443))) (-15 -3372 ((-443) (-1170) (-443) (-1170))) (-15 -4482 ((-1264) (-1170))) (-15 -3459 ((-1170))) (-15 -4402 ((-1170))) (-15 -2921 ((-1264) (-1170) (-638 (-1170)) $)) (-15 -2921 ((-1264) (-1170) (-638 (-1170)))) (-15 -2921 ((-1264) (-638 (-1170)))) (-15 -4094 ((-1264) (-1170) (-3 (|:| |fst| (-440)) (|:| -3166 "void")) $)) (-15 -4094 ((-1264) (-1170) (-3 (|:| |fst| (-440)) (|:| -3166 "void")))) (-15 -4094 ((-1264) (-3 (|:| |fst| (-440)) (|:| -3166 "void")))) (-15 -1655 ((-1264) (-1170) $)) (-15 -1655 ((-1264) (-1170))) (-15 -1655 ((-1264))) (-15 -1525 ((-1264) (-1170))) (-15 -1665 ($)) (-15 -3122 ((-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-1170) $)) (-15 -2389 ((-638 (-1170)) (-1170) $)) (-15 -4381 ((-1174) (-1170) $))))) (T -1173)) 
-((-1597 (*1 *1) (-5 *1 (-1173))) (-3495 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1173)))) (-3495 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-3372 (*1 *2 *3 *2 *3 *1) (-12 (-5 *2 (-443)) (-5 *3 (-1170)) (-5 *1 (-1173)))) (-3372 (*1 *2 *3 *2 *4 *1) (-12 (-5 *2 (-443)) (-5 *3 (-638 (-1170))) (-5 *4 (-1170)) (-5 *1 (-1173)))) (-3372 (*1 *2 *3 *2) (-12 (-5 *2 (-443)) (-5 *3 (-1170)) (-5 *1 (-1173)))) (-3372 (*1 *2 *3 *2 *3) (-12 (-5 *2 (-443)) (-5 *3 (-1170)) (-5 *1 (-1173)))) (-4482 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-3459 (*1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1173)))) (-4402 (*1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1173)))) (-2921 (*1 *2 *3 *4 *1) (-12 (-5 *4 (-638 (-1170))) (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-2921 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-1170))) (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-2921 (*1 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-4094 (*1 *2 *3 *4 *1) (-12 (-5 *3 (-1170)) (-5 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-4094 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-4094 (*1 *2 *3) (-12 (-5 *3 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-1655 (*1 *2 *3 *1) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-1655 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-1655 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1173)))) (-1525 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) (-1665 (*1 *1) (-5 *1 (-1173))) (-3122 (*1 *2 *3 *1) (-12 (-5 *3 (-1170)) (-5 *2 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *1 (-1173)))) (-2389 (*1 *2 *3 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-1173)) (-5 *3 (-1170)))) (-4381 (*1 *2 *3 *1) (-12 (-5 *3 (-1170)) (-5 *2 (-1174)) (-5 *1 (-1173))))) 
-(-13 (-612 (-856)) (-10 -8 (-15 -1597 ($)) (-15 -3495 ((-1264))) (-15 -3495 ((-1264) (-1170))) (-15 -3372 ((-443) (-1170) (-443) (-1170) $)) (-15 -3372 ((-443) (-638 (-1170)) (-443) (-1170) $)) (-15 -3372 ((-443) (-1170) (-443))) (-15 -3372 ((-443) (-1170) (-443) (-1170))) (-15 -4482 ((-1264) (-1170))) (-15 -3459 ((-1170))) (-15 -4402 ((-1170))) (-15 -2921 ((-1264) (-1170) (-638 (-1170)) $)) (-15 -2921 ((-1264) (-1170) (-638 (-1170)))) (-15 -2921 ((-1264) (-638 (-1170)))) (-15 -4094 ((-1264) (-1170) (-3 (|:| |fst| (-440)) (|:| -3166 "void")) $)) (-15 -4094 ((-1264) (-1170) (-3 (|:| |fst| (-440)) (|:| -3166 "void")))) (-15 -4094 ((-1264) (-3 (|:| |fst| (-440)) (|:| -3166 "void")))) (-15 -1655 ((-1264) (-1170) $)) (-15 -1655 ((-1264) (-1170))) (-15 -1655 ((-1264))) (-15 -1525 ((-1264) (-1170))) (-15 -1665 ($)) (-15 -3122 ((-3 (|:| |fst| (-440)) (|:| -3166 "void")) (-1170) $)) (-15 -2389 ((-638 (-1170)) (-1170) $)) (-15 -4381 ((-1174) (-1170) $)))) 
-((-3967 (((-638 (-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572))))))))) $) 57)) (-1910 (((-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572)))))))) (-440) $) 40)) (-4332 (($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-443))))) 15)) (-1525 (((-1264) $) 65)) (-2536 (((-638 (-1170)) $) 20)) (-2205 (((-1102) $) 53)) (-2990 (((-443) (-1170) $) 27)) (-3896 (((-638 (-1170)) $) 30)) (-1665 (($) 17)) (-3372 (((-443) (-638 (-1170)) (-443) $) 25) (((-443) (-1170) (-443) $) 24)) (-3972 (((-856) $) 9) (((-1178 (-1170) (-443)) $) 11))) 
-(((-1174) (-13 (-612 (-856)) (-10 -8 (-15 -3972 ((-1178 (-1170) (-443)) $)) (-15 -1665 ($)) (-15 -3372 ((-443) (-638 (-1170)) (-443) $)) (-15 -3372 ((-443) (-1170) (-443) $)) (-15 -2990 ((-443) (-1170) $)) (-15 -2536 ((-638 (-1170)) $)) (-15 -1910 ((-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572)))))))) (-440) $)) (-15 -3896 ((-638 (-1170)) $)) (-15 -3967 ((-638 (-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572))))))))) $)) (-15 -2205 ((-1102) $)) (-15 -1525 ((-1264) $)) (-15 -4332 ($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-443))))))))) (T -1174)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-1178 (-1170) (-443))) (-5 *1 (-1174)))) (-1665 (*1 *1) (-5 *1 (-1174))) (-3372 (*1 *2 *3 *2 *1) (-12 (-5 *2 (-443)) (-5 *3 (-638 (-1170))) (-5 *1 (-1174)))) (-3372 (*1 *2 *3 *2 *1) (-12 (-5 *2 (-443)) (-5 *3 (-1170)) (-5 *1 (-1174)))) (-2990 (*1 *2 *3 *1) (-12 (-5 *3 (-1170)) (-5 *2 (-443)) (-5 *1 (-1174)))) (-2536 (*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-1174)))) (-1910 (*1 *2 *3 *1) (-12 (-5 *3 (-440)) (-5 *2 (-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572))))))))) (-5 *1 (-1174)))) (-3896 (*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-1174)))) (-3967 (*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572)))))))))) (-5 *1 (-1174)))) (-2205 (*1 *2 *1) (-12 (-5 *2 (-1102)) (-5 *1 (-1174)))) (-1525 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1174)))) (-4332 (*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-443))))) (-5 *1 (-1174))))) 
-(-13 (-612 (-856)) (-10 -8 (-15 -3972 ((-1178 (-1170) (-443)) $)) (-15 -1665 ($)) (-15 -3372 ((-443) (-638 (-1170)) (-443) $)) (-15 -3372 ((-443) (-1170) (-443) $)) (-15 -2990 ((-443) (-1170) $)) (-15 -2536 ((-638 (-1170)) $)) (-15 -1910 ((-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572)))))))) (-440) $)) (-15 -3896 ((-638 (-1170)) $)) (-15 -3967 ((-638 (-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572))))))))) $)) (-15 -2205 ((-1102) $)) (-15 -1525 ((-1264) $)) (-15 -4332 ($ (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-443)))))))) 
-((-4244 (((-638 (-638 (-959 |#1|))) (-638 (-413 (-959 |#1|))) (-638 (-1170))) 55)) (-2800 (((-638 (-290 (-413 (-959 |#1|)))) (-290 (-413 (-959 |#1|)))) 66) (((-638 (-290 (-413 (-959 |#1|)))) (-413 (-959 |#1|))) 62) (((-638 (-290 (-413 (-959 |#1|)))) (-290 (-413 (-959 |#1|))) (-1170)) 67) (((-638 (-290 (-413 (-959 |#1|)))) (-413 (-959 |#1|)) (-1170)) 61) (((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-290 (-413 (-959 |#1|))))) 91) (((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-413 (-959 |#1|)))) 90) (((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-290 (-413 (-959 |#1|)))) (-638 (-1170))) 92) (((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-413 (-959 |#1|))) (-638 (-1170))) 89))) 
-(((-1175 |#1|) (-10 -7 (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-413 (-959 |#1|))) (-638 (-1170)))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-290 (-413 (-959 |#1|)))) (-638 (-1170)))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-413 (-959 |#1|))))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-290 (-413 (-959 |#1|)))))) (-15 -2800 ((-638 (-290 (-413 (-959 |#1|)))) (-413 (-959 |#1|)) (-1170))) (-15 -2800 ((-638 (-290 (-413 (-959 |#1|)))) (-290 (-413 (-959 |#1|))) (-1170))) (-15 -2800 ((-638 (-290 (-413 (-959 |#1|)))) (-413 (-959 |#1|)))) (-15 -2800 ((-638 (-290 (-413 (-959 |#1|)))) (-290 (-413 (-959 |#1|))))) (-15 -4244 ((-638 (-638 (-959 |#1|))) (-638 (-413 (-959 |#1|))) (-638 (-1170))))) (-562)) (T -1175)) 
-((-4244 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 *5)))) (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-959 *5)))) (-5 *1 (-1175 *5)))) (-2800 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 (-290 (-413 (-959 *4))))) (-5 *1 (-1175 *4)) (-5 *3 (-290 (-413 (-959 *4)))))) (-2800 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 (-290 (-413 (-959 *4))))) (-5 *1 (-1175 *4)) (-5 *3 (-413 (-959 *4))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-562)) (-5 *2 (-638 (-290 (-413 (-959 *5))))) (-5 *1 (-1175 *5)) (-5 *3 (-290 (-413 (-959 *5)))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-562)) (-5 *2 (-638 (-290 (-413 (-959 *5))))) (-5 *1 (-1175 *5)) (-5 *3 (-413 (-959 *5))))) (-2800 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *4)))))) (-5 *1 (-1175 *4)) (-5 *3 (-638 (-290 (-413 (-959 *4))))))) (-2800 (*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 *4)))) (-4 *4 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *4)))))) (-5 *1 (-1175 *4)))) (-2800 (*1 *2 *3 *4) (-12 (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *5)))))) (-5 *1 (-1175 *5)) (-5 *3 (-638 (-290 (-413 (-959 *5))))))) (-2800 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 *5)))) (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *5)))))) (-5 *1 (-1175 *5))))) 
-(-10 -7 (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-413 (-959 |#1|))) (-638 (-1170)))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-290 (-413 (-959 |#1|)))) (-638 (-1170)))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-413 (-959 |#1|))))) (-15 -2800 ((-638 (-638 (-290 (-413 (-959 |#1|))))) (-638 (-290 (-413 (-959 |#1|)))))) (-15 -2800 ((-638 (-290 (-413 (-959 |#1|)))) (-413 (-959 |#1|)) (-1170))) (-15 -2800 ((-638 (-290 (-413 (-959 |#1|)))) (-290 (-413 (-959 |#1|))) (-1170))) (-15 -2800 ((-638 (-290 (-413 (-959 |#1|)))) (-413 (-959 |#1|)))) (-15 -2800 ((-638 (-290 (-413 (-959 |#1|)))) (-290 (-413 (-959 |#1|))))) (-15 -4244 ((-638 (-638 (-959 |#1|))) (-638 (-413 (-959 |#1|))) (-638 (-1170))))) 
-((-3099 (((-638 (-638 |#1|)) (-638 (-638 |#1|)) (-638 (-638 (-638 |#1|)))) 38)) (-2005 (((-638 (-638 (-638 |#1|))) (-638 (-638 |#1|))) 24)) (-4325 (((-1177 (-638 |#1|)) (-638 |#1|)) 34)) (-2533 (((-638 (-638 |#1|)) (-638 |#1|)) 30)) (-3187 (((-2 (|:| |f1| (-638 |#1|)) (|:| |f2| (-638 (-638 (-638 |#1|)))) (|:| |f3| (-638 (-638 |#1|))) (|:| |f4| (-638 (-638 (-638 |#1|))))) (-638 (-638 (-638 |#1|)))) 37)) (-2875 (((-2 (|:| |f1| (-638 |#1|)) (|:| |f2| (-638 (-638 (-638 |#1|)))) (|:| |f3| (-638 (-638 |#1|))) (|:| |f4| (-638 (-638 (-638 |#1|))))) (-638 |#1|) (-638 (-638 (-638 |#1|))) (-638 (-638 |#1|)) (-638 (-638 (-638 |#1|))) (-638 (-638 (-638 |#1|))) (-638 (-638 (-638 |#1|)))) 36)) (-4103 (((-638 (-638 |#1|)) (-638 (-638 |#1|))) 28)) (-3750 (((-638 |#1|) (-638 |#1|)) 31)) (-2593 (((-638 (-638 (-638 |#1|))) (-638 |#1|) (-638 (-638 (-638 |#1|)))) 18)) (-2688 (((-638 (-638 (-638 |#1|))) (-1 (-121) |#1| |#1|) (-638 |#1|) (-638 (-638 (-638 |#1|)))) 15)) (-2195 (((-2 (|:| |fs| (-121)) (|:| |sd| (-638 |#1|)) (|:| |td| (-638 (-638 |#1|)))) (-1 (-121) |#1| |#1|) (-638 |#1|) (-638 (-638 |#1|))) 13)) (-2470 (((-638 (-638 |#1|)) (-638 (-638 (-638 |#1|)))) 39)) (-4545 (((-638 (-638 |#1|)) (-1177 (-638 |#1|))) 41))) 
-(((-1176 |#1|) (-10 -7 (-15 -2195 ((-2 (|:| |fs| (-121)) (|:| |sd| (-638 |#1|)) (|:| |td| (-638 (-638 |#1|)))) (-1 (-121) |#1| |#1|) (-638 |#1|) (-638 (-638 |#1|)))) (-15 -2688 ((-638 (-638 (-638 |#1|))) (-1 (-121) |#1| |#1|) (-638 |#1|) (-638 (-638 (-638 |#1|))))) (-15 -2593 ((-638 (-638 (-638 |#1|))) (-638 |#1|) (-638 (-638 (-638 |#1|))))) (-15 -3099 ((-638 (-638 |#1|)) (-638 (-638 |#1|)) (-638 (-638 (-638 |#1|))))) (-15 -2470 ((-638 (-638 |#1|)) (-638 (-638 (-638 |#1|))))) (-15 -4545 ((-638 (-638 |#1|)) (-1177 (-638 |#1|)))) (-15 -2005 ((-638 (-638 (-638 |#1|))) (-638 (-638 |#1|)))) (-15 -4325 ((-1177 (-638 |#1|)) (-638 |#1|))) (-15 -4103 ((-638 (-638 |#1|)) (-638 (-638 |#1|)))) (-15 -2533 ((-638 (-638 |#1|)) (-638 |#1|))) (-15 -3750 ((-638 |#1|) (-638 |#1|))) (-15 -2875 ((-2 (|:| |f1| (-638 |#1|)) (|:| |f2| (-638 (-638 (-638 |#1|)))) (|:| |f3| (-638 (-638 |#1|))) (|:| |f4| (-638 (-638 (-638 |#1|))))) (-638 |#1|) (-638 (-638 (-638 |#1|))) (-638 (-638 |#1|)) (-638 (-638 (-638 |#1|))) (-638 (-638 (-638 |#1|))) (-638 (-638 (-638 |#1|))))) (-15 -3187 ((-2 (|:| |f1| (-638 |#1|)) (|:| |f2| (-638 (-638 (-638 |#1|)))) (|:| |f3| (-638 (-638 |#1|))) (|:| |f4| (-638 (-638 (-638 |#1|))))) (-638 (-638 (-638 |#1|)))))) (-848)) (T -1176)) 
-((-3187 (*1 *2 *3) (-12 (-4 *4 (-848)) (-5 *2 (-2 (|:| |f1| (-638 *4)) (|:| |f2| (-638 (-638 (-638 *4)))) (|:| |f3| (-638 (-638 *4))) (|:| |f4| (-638 (-638 (-638 *4)))))) (-5 *1 (-1176 *4)) (-5 *3 (-638 (-638 (-638 *4)))))) (-2875 (*1 *2 *3 *4 *5 *4 *4 *4) (-12 (-4 *6 (-848)) (-5 *3 (-638 *6)) (-5 *5 (-638 *3)) (-5 *2 (-2 (|:| |f1| *3) (|:| |f2| (-638 *5)) (|:| |f3| *5) (|:| |f4| (-638 *5)))) (-5 *1 (-1176 *6)) (-5 *4 (-638 *5)))) (-3750 (*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-1176 *3)))) (-2533 (*1 *2 *3) (-12 (-4 *4 (-848)) (-5 *2 (-638 (-638 *4))) (-5 *1 (-1176 *4)) (-5 *3 (-638 *4)))) (-4103 (*1 *2 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-848)) (-5 *1 (-1176 *3)))) (-4325 (*1 *2 *3) (-12 (-4 *4 (-848)) (-5 *2 (-1177 (-638 *4))) (-5 *1 (-1176 *4)) (-5 *3 (-638 *4)))) (-2005 (*1 *2 *3) (-12 (-4 *4 (-848)) (-5 *2 (-638 (-638 (-638 *4)))) (-5 *1 (-1176 *4)) (-5 *3 (-638 (-638 *4))))) (-4545 (*1 *2 *3) (-12 (-5 *3 (-1177 (-638 *4))) (-4 *4 (-848)) (-5 *2 (-638 (-638 *4))) (-5 *1 (-1176 *4)))) (-2470 (*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-638 *4)))) (-5 *2 (-638 (-638 *4))) (-5 *1 (-1176 *4)) (-4 *4 (-848)))) (-3099 (*1 *2 *2 *3) (-12 (-5 *3 (-638 (-638 (-638 *4)))) (-5 *2 (-638 (-638 *4))) (-4 *4 (-848)) (-5 *1 (-1176 *4)))) (-2593 (*1 *2 *3 *2) (-12 (-5 *2 (-638 (-638 (-638 *4)))) (-5 *3 (-638 *4)) (-4 *4 (-848)) (-5 *1 (-1176 *4)))) (-2688 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-638 (-638 (-638 *5)))) (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-638 *5)) (-4 *5 (-848)) (-5 *1 (-1176 *5)))) (-2195 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-121) *6 *6)) (-4 *6 (-848)) (-5 *4 (-638 *6)) (-5 *2 (-2 (|:| |fs| (-121)) (|:| |sd| *4) (|:| |td| (-638 *4)))) (-5 *1 (-1176 *6)) (-5 *5 (-638 *4))))) 
-(-10 -7 (-15 -2195 ((-2 (|:| |fs| (-121)) (|:| |sd| (-638 |#1|)) (|:| |td| (-638 (-638 |#1|)))) (-1 (-121) |#1| |#1|) (-638 |#1|) (-638 (-638 |#1|)))) (-15 -2688 ((-638 (-638 (-638 |#1|))) (-1 (-121) |#1| |#1|) (-638 |#1|) (-638 (-638 (-638 |#1|))))) (-15 -2593 ((-638 (-638 (-638 |#1|))) (-638 |#1|) (-638 (-638 (-638 |#1|))))) (-15 -3099 ((-638 (-638 |#1|)) (-638 (-638 |#1|)) (-638 (-638 (-638 |#1|))))) (-15 -2470 ((-638 (-638 |#1|)) (-638 (-638 (-638 |#1|))))) (-15 -4545 ((-638 (-638 |#1|)) (-1177 (-638 |#1|)))) (-15 -2005 ((-638 (-638 (-638 |#1|))) (-638 (-638 |#1|)))) (-15 -4325 ((-1177 (-638 |#1|)) (-638 |#1|))) (-15 -4103 ((-638 (-638 |#1|)) (-638 (-638 |#1|)))) (-15 -2533 ((-638 (-638 |#1|)) (-638 |#1|))) (-15 -3750 ((-638 |#1|) (-638 |#1|))) (-15 -2875 ((-2 (|:| |f1| (-638 |#1|)) (|:| |f2| (-638 (-638 (-638 |#1|)))) (|:| |f3| (-638 (-638 |#1|))) (|:| |f4| (-638 (-638 (-638 |#1|))))) (-638 |#1|) (-638 (-638 (-638 |#1|))) (-638 (-638 |#1|)) (-638 (-638 (-638 |#1|))) (-638 (-638 (-638 |#1|))) (-638 (-638 (-638 |#1|))))) (-15 -3187 ((-2 (|:| |f1| (-638 |#1|)) (|:| |f2| (-638 (-638 (-638 |#1|)))) (|:| |f3| (-638 (-638 |#1|))) (|:| |f4| (-638 (-638 (-638 |#1|))))) (-638 (-638 (-638 |#1|)))))) 
-((-2393 (($ (-638 (-638 |#1|))) 9)) (-2259 (((-638 (-638 |#1|)) $) 10)) (-3972 (((-856) $) 25))) 
-(((-1177 |#1|) (-10 -8 (-15 -2393 ($ (-638 (-638 |#1|)))) (-15 -2259 ((-638 (-638 |#1|)) $)) (-15 -3972 ((-856) $))) (-1098)) (T -1177)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1177 *3)) (-4 *3 (-1098)))) (-2259 (*1 *2 *1) (-12 (-5 *2 (-638 (-638 *3))) (-5 *1 (-1177 *3)) (-4 *3 (-1098)))) (-2393 (*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-5 *1 (-1177 *3))))) 
-(-10 -8 (-15 -2393 ($ (-638 (-638 |#1|)))) (-15 -2259 ((-638 (-638 |#1|)) $)) (-15 -3972 ((-856) $))) 
-((-2262 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2982 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-2430 (((-1264) $ |#1| |#1|) NIL (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#2| $ |#1| |#2|) NIL)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-1750 (((-3 |#2| "failed") |#1| $) NIL)) (-2211 (($) NIL T CONST)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) NIL)) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) NIL)) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) NIL)) (-3940 ((|#1| $) NIL (|has| |#1| (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-638 |#2|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2026 ((|#1| $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-2760 (((-638 |#1|) $) NIL)) (-2365 (((-121) |#1| $) NIL)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2739 (((-638 |#1|) $) NIL)) (-1601 (((-121) |#1| $) NIL)) (-2607 (((-1116) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-1837 ((|#2| $) NIL (|has| |#1| (-848)))) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL)) (-3299 (($ $ |#2|) NIL (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1535 (($) NIL) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (((-769) |#2| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098)))) (((-769) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3972 (((-856) $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) NIL)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) NIL (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) NIL (-1841 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| |#2| (-1098))))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1178 |#1| |#2|) (-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602))) (-1098) (-1098)) (T -1178)) 
-NIL 
-(-13 (-1181 |#1| |#2|) (-10 -7 (-6 -4602))) 
-((-4469 ((|#1| (-638 |#1|)) 32)) (-4567 ((|#1| |#1| (-572)) 18)) (-3217 (((-1166 |#1|) |#1| (-923)) 15))) 
-(((-1179 |#1|) (-10 -7 (-15 -4469 (|#1| (-638 |#1|))) (-15 -3217 ((-1166 |#1|) |#1| (-923))) (-15 -4567 (|#1| |#1| (-572)))) (-368)) (T -1179)) 
-((-4567 (*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-1179 *2)) (-4 *2 (-368)))) (-3217 (*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-5 *2 (-1166 *3)) (-5 *1 (-1179 *3)) (-4 *3 (-368)))) (-4469 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-5 *1 (-1179 *2)) (-4 *2 (-368))))) 
-(-10 -7 (-15 -4469 (|#1| (-638 |#1|))) (-15 -3217 ((-1166 |#1|) |#1| (-923))) (-15 -4567 (|#1| |#1| (-572)))) 
-((-2982 (($) 10) (($ (-638 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)))) 14)) (-1544 (($ (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) $) 60) (($ (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) $) NIL) (((-3 |#3| "failed") |#2| $) NIL)) (-2010 (((-638 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) $) 39) (((-638 |#3|) $) 41)) (-2435 (($ (-1 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) $) 52) (($ (-1 |#3| |#3|) $) 33)) (-3828 (($ (-1 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) $) 50) (($ (-1 |#3| |#3|) $) NIL) (($ (-1 |#3| |#3| |#3|) $ $) 38)) (-4221 (((-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) $) 53)) (-1335 (($ (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) $) 16)) (-2739 (((-638 |#2|) $) 19)) (-1601 (((-121) |#2| $) 58)) (-3361 (((-3 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) "failed") (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) $) 57)) (-2232 (((-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) $) 62)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) $) NIL) (((-121) (-1 (-121) |#3|) $) 65)) (-2957 (((-638 |#3|) $) 43)) (-3277 ((|#3| $ |#2|) 30) ((|#3| $ |#2| |#3|) 31)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) $) NIL) (((-769) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) $) NIL) (((-769) |#3| $) NIL) (((-769) (-1 (-121) |#3|) $) 66)) (-3972 (((-856) $) 27)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) $) NIL) (((-121) (-1 (-121) |#3|) $) 64)) (-1324 (((-121) $ $) 48))) 
-(((-1180 |#1| |#2| |#3|) (-10 -8 (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -3828 (|#1| (-1 |#3| |#3| |#3|) |#1| |#1|)) (-15 -2982 (|#1| (-638 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))))) (-15 -2982 (|#1|)) (-15 -3828 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2435 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -1571 ((-769) (-1 (-121) |#3|) |#1|)) (-15 -2010 ((-638 |#3|) |#1|)) (-15 -1571 ((-769) |#3| |#1|)) (-15 -3277 (|#3| |#1| |#2| |#3|)) (-15 -3277 (|#3| |#1| |#2|)) (-15 -2957 ((-638 |#3|) |#1|)) (-15 -1601 ((-121) |#2| |#1|)) (-15 -2739 ((-638 |#2|) |#1|)) (-15 -1544 ((-3 |#3| "failed") |#2| |#1|)) (-15 -1544 (|#1| (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -1544 (|#1| (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -3361 ((-3 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) "failed") (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -4221 ((-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -1335 (|#1| (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -2232 ((-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -1571 ((-769) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -2010 ((-638 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -1571 ((-769) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -2109 ((-121) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -3501 ((-121) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -2435 (|#1| (-1 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -3828 (|#1| (-1 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|))) (-1181 |#2| |#3|) (-1098) (-1098)) (T -1180)) 
-NIL 
-(-10 -8 (-15 -1324 ((-121) |#1| |#1|)) (-15 -3972 ((-856) |#1|)) (-15 -3828 (|#1| (-1 |#3| |#3| |#3|) |#1| |#1|)) (-15 -2982 (|#1| (-638 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))))) (-15 -2982 (|#1|)) (-15 -3828 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2435 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3501 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -2109 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -1571 ((-769) (-1 (-121) |#3|) |#1|)) (-15 -2010 ((-638 |#3|) |#1|)) (-15 -1571 ((-769) |#3| |#1|)) (-15 -3277 (|#3| |#1| |#2| |#3|)) (-15 -3277 (|#3| |#1| |#2|)) (-15 -2957 ((-638 |#3|) |#1|)) (-15 -1601 ((-121) |#2| |#1|)) (-15 -2739 ((-638 |#2|) |#1|)) (-15 -1544 ((-3 |#3| "failed") |#2| |#1|)) (-15 -1544 (|#1| (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -1544 (|#1| (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -3361 ((-3 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) "failed") (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -4221 ((-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -1335 (|#1| (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -2232 ((-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -1571 ((-769) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) |#1|)) (-15 -2010 ((-638 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -1571 ((-769) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -2109 ((-121) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -3501 ((-121) (-1 (-121) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -2435 (|#1| (-1 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|)) (-15 -3828 (|#1| (-1 (-2 (|:| -4111 |#2|) (|:| -4320 |#3|)) (-2 (|:| -4111 |#2|) (|:| -4320 |#3|))) |#1|))) 
-((-2262 (((-121) $ $) 18 (-1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-2982 (($) 66) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 65)) (-2430 (((-1264) $ |#1| |#1|) 93 (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#2| $ |#1| |#2|) 67)) (-1550 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 42 (|has| $ (-6 -4602)))) (-2561 (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 52 (|has| $ (-6 -4602)))) (-1750 (((-3 |#2| "failed") |#1| $) 57)) (-2211 (($) 7 T CONST)) (-1643 (($ $) 55 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602))))) (-1544 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 44 (|has| $ (-6 -4602))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 43 (|has| $ (-6 -4602))) (((-3 |#2| "failed") |#1| $) 58)) (-3445 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 54 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 51 (|has| $ (-6 -4602)))) (-3116 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 53 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 50 (|has| $ (-6 -4602))) (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 49 (|has| $ (-6 -4602)))) (-3037 ((|#2| $ |#1| |#2|) 81 (|has| $ (-6 -4603)))) (-4212 ((|#2| $ |#1|) 82)) (-2010 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 30 (|has| $ (-6 -4602))) (((-638 |#2|) $) 73 (|has| $ (-6 -4602)))) (-2157 (((-121) $ (-769)) 9)) (-3940 ((|#1| $) 90 (|has| |#1| (-848)))) (-4467 (((-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 29 (|has| $ (-6 -4602))) (((-638 |#2|) $) 74 (|has| $ (-6 -4602)))) (-3002 (((-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 27 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-121) |#2| $) 76 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602))))) (-2026 ((|#1| $) 89 (|has| |#1| (-848)))) (-2435 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 34 (|has| $ (-6 -4603))) (($ (-1 |#2| |#2|) $) 69 (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 35) (($ (-1 |#2| |#2|) $) 68) (($ (-1 |#2| |#2| |#2|) $ $) 64)) (-3524 (((-121) $ (-769)) 10)) (-1658 (((-1152) $) 22 (-1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-2760 (((-638 |#1|) $) 59)) (-2365 (((-121) |#1| $) 60)) (-4221 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 36)) (-1335 (($ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 37)) (-2739 (((-638 |#1|) $) 87)) (-1601 (((-121) |#1| $) 86)) (-2607 (((-1116) $) 21 (-1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-1837 ((|#2| $) 91 (|has| |#1| (-848)))) (-3361 (((-3 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) "failed") (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 48)) (-3299 (($ $ |#2|) 92 (|has| $ (-6 -4603)))) (-2232 (((-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 38)) (-2109 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 32 (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) 71 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))))) 26 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-290 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 25 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) 24 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 23 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)))) (($ $ (-638 |#2|) (-638 |#2|)) 80 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ |#2| |#2|) 79 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-290 |#2|)) 78 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098)))) (($ $ (-638 (-290 |#2|))) 77 (-12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#2| $) 88 (-12 (|has| $ (-6 -4602)) (|has| |#2| (-1098))))) (-2957 (((-638 |#2|) $) 85)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#2| $ |#1|) 84) ((|#2| $ |#1| |#2|) 83)) (-1535 (($) 46) (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 45)) (-1571 (((-769) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 31 (|has| $ (-6 -4602))) (((-769) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) $) 28 (-12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098)) (|has| $ (-6 -4602)))) (((-769) |#2| $) 75 (-12 (|has| |#2| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#2|) $) 72 (|has| $ (-6 -4602)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 56 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))))) (-3921 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 47)) (-3972 (((-856) $) 20 (-1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-3058 (($ (-638 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) 39)) (-3501 (((-121) (-1 (-121) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) $) 33 (|has| $ (-6 -4602))) (((-121) (-1 (-121) |#2|) $) 70 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (-1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1181 |#1| |#2|) (-1290) (-1098) (-1098)) (T -1181)) 
-((-3283 (*1 *2 *1 *3 *2) (-12 (-4 *1 (-1181 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098)))) (-2982 (*1 *1) (-12 (-4 *1 (-1181 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) (-2982 (*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 *3) (|:| -4320 *4)))) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *1 (-1181 *3 *4)))) (-3828 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *4 *4 *4)) (-4 *1 (-1181 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(-13 (-609 |t#1| |t#2|) (-605 |t#1| |t#2|) (-10 -8 (-15 -3283 (|t#2| $ |t#1| |t#2|)) (-15 -2982 ($)) (-15 -2982 ($ (-638 (-2 (|:| -4111 |t#1|) (|:| -4320 |t#2|))))) (-15 -3828 ($ (-1 |t#2| |t#2| |t#2|) $ $)))) 
-(((-39) . T) ((-111 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-105) -1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-612 (-856)) -1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-155 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-613 (-545)) |has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-613 (-545))) ((-223 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-229 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-283 |#1| |#2|) . T) ((-285 |#1| |#2|) . T) ((-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) -12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-305 |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-503 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) . T) ((-503 |#2|) . T) ((-605 |#1| |#2|) . T) ((-527 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-2 (|:| -4111 |#1|) (|:| -4320 |#2|))) -12 (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-305 (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)))) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-527 |#2| |#2|) -12 (|has| |#2| (-305 |#2|)) (|has| |#2| (-1098))) ((-609 |#1| |#2|) . T) ((-1098) -1841 (|has| |#2| (-1098)) (|has| (-2 (|:| -4111 |#1|) (|:| -4320 |#2|)) (-1098))) ((-1204) . T)) 
-((-3908 (((-121)) 24)) (-4488 (((-1264) (-1152)) 26)) (-2935 (((-121)) 36)) (-3436 (((-1264)) 34)) (-1914 (((-1264) (-1152) (-1152)) 25)) (-2370 (((-121)) 37)) (-1335 (((-1264) |#1| |#2|) 44)) (-4374 (((-1264)) 20)) (-4404 (((-3 |#2| "failed") |#1|) 42)) (-3412 (((-1264)) 35))) 
-(((-1182 |#1| |#2|) (-10 -7 (-15 -4374 ((-1264))) (-15 -1914 ((-1264) (-1152) (-1152))) (-15 -4488 ((-1264) (-1152))) (-15 -3436 ((-1264))) (-15 -3412 ((-1264))) (-15 -3908 ((-121))) (-15 -2935 ((-121))) (-15 -2370 ((-121))) (-15 -4404 ((-3 |#2| "failed") |#1|)) (-15 -1335 ((-1264) |#1| |#2|))) (-1098) (-1098)) (T -1182)) 
-((-1335 (*1 *2 *3 *4) (-12 (-5 *2 (-1264)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-4404 (*1 *2 *3) (|partial| -12 (-4 *2 (-1098)) (-5 *1 (-1182 *3 *2)) (-4 *3 (-1098)))) (-2370 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-2935 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-3908 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-3412 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-3436 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) (-4488 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1182 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1098)))) (-1914 (*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1182 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1098)))) (-4374 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(-10 -7 (-15 -4374 ((-1264))) (-15 -1914 ((-1264) (-1152) (-1152))) (-15 -4488 ((-1264) (-1152))) (-15 -3436 ((-1264))) (-15 -3412 ((-1264))) (-15 -3908 ((-121))) (-15 -2935 ((-121))) (-15 -2370 ((-121))) (-15 -4404 ((-3 |#2| "failed") |#1|)) (-15 -1335 ((-1264) |#1| |#2|))) 
-((-1499 (((-1152) (-1152)) 18)) (-4445 (((-57) (-1152)) 21))) 
-(((-1183) (-10 -7 (-15 -4445 ((-57) (-1152))) (-15 -1499 ((-1152) (-1152))))) (T -1183)) 
-((-1499 (*1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1183)))) (-4445 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-57)) (-5 *1 (-1183))))) 
-(-10 -7 (-15 -4445 ((-57) (-1152))) (-15 -1499 ((-1152) (-1152)))) 
-((-3972 (((-1185) |#1|) 11))) 
-(((-1184 |#1|) (-10 -7 (-15 -3972 ((-1185) |#1|))) (-1098)) (T -1184)) 
-((-3972 (*1 *2 *3) (-12 (-5 *2 (-1185)) (-5 *1 (-1184 *3)) (-4 *3 (-1098))))) 
-(-10 -7 (-15 -3972 ((-1185) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-2089 (((-638 (-1152)) $) 33)) (-4548 (((-638 (-1152)) $ (-638 (-1152))) 36)) (-3044 (((-638 (-1152)) $ (-638 (-1152))) 35)) (-2926 (((-638 (-1152)) $ (-638 (-1152))) 37)) (-2741 (((-638 (-1152)) $) 32)) (-1364 (($) 22)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2443 (((-638 (-1152)) $) 34)) (-2415 (((-1264) $ (-572)) 29) (((-1264) $) 30)) (-4081 (($ (-856) (-572)) 26) (($ (-856) (-572) (-856)) NIL)) (-3972 (((-856) $) 39) (($ (-856)) 24)) (-1324 (((-121) $ $) NIL))) 
-(((-1185) (-13 (-1098) (-10 -8 (-15 -3972 ($ (-856))) (-15 -4081 ($ (-856) (-572))) (-15 -4081 ($ (-856) (-572) (-856))) (-15 -2415 ((-1264) $ (-572))) (-15 -2415 ((-1264) $)) (-15 -2443 ((-638 (-1152)) $)) (-15 -2089 ((-638 (-1152)) $)) (-15 -1364 ($)) (-15 -2741 ((-638 (-1152)) $)) (-15 -2926 ((-638 (-1152)) $ (-638 (-1152)))) (-15 -4548 ((-638 (-1152)) $ (-638 (-1152)))) (-15 -3044 ((-638 (-1152)) $ (-638 (-1152))))))) (T -1185)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-1185)))) (-4081 (*1 *1 *2 *3) (-12 (-5 *2 (-856)) (-5 *3 (-572)) (-5 *1 (-1185)))) (-4081 (*1 *1 *2 *3 *2) (-12 (-5 *2 (-856)) (-5 *3 (-572)) (-5 *1 (-1185)))) (-2415 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-1185)))) (-2415 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1185)))) (-2443 (*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185)))) (-2089 (*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185)))) (-1364 (*1 *1) (-5 *1 (-1185))) (-2741 (*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185)))) (-2926 (*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185)))) (-4548 (*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185)))) (-3044 (*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185))))) 
-(-13 (-1098) (-10 -8 (-15 -3972 ($ (-856))) (-15 -4081 ($ (-856) (-572))) (-15 -4081 ($ (-856) (-572) (-856))) (-15 -2415 ((-1264) $ (-572))) (-15 -2415 ((-1264) $)) (-15 -2443 ((-638 (-1152)) $)) (-15 -2089 ((-638 (-1152)) $)) (-15 -1364 ($)) (-15 -2741 ((-638 (-1152)) $)) (-15 -2926 ((-638 (-1152)) $ (-638 (-1152)))) (-15 -4548 ((-638 (-1152)) $ (-638 (-1152)))) (-15 -3044 ((-638 (-1152)) $ (-638 (-1152)))))) 
-((-2262 (((-121) $ $) NIL)) (-4266 (((-1152) $ (-1152)) 15) (((-1152) $) 14)) (-3757 (((-1152) $ (-1152)) 13)) (-2582 (($ $ (-1152)) NIL)) (-3455 (((-3 (-1152) "failed") $) 11)) (-2149 (((-1152) $) 8)) (-1515 (((-3 (-1152) "failed") $) 12)) (-2159 (((-1152) $) 9)) (-1428 (($ (-394)) NIL) (($ (-394) (-1152)) NIL)) (-3201 (((-394) $) NIL)) (-1658 (((-1152) $) NIL)) (-1828 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-1734 (((-1264) $) NIL)) (-3722 (((-121) $) 17)) (-3972 (((-856) $) NIL)) (-1391 (($ $) NIL)) (-1324 (((-121) $ $) NIL))) 
-(((-1186) (-13 (-369 (-394) (-1152)) (-10 -8 (-15 -4266 ((-1152) $ (-1152))) (-15 -4266 ((-1152) $)) (-15 -2149 ((-1152) $)) (-15 -3455 ((-3 (-1152) "failed") $)) (-15 -1515 ((-3 (-1152) "failed") $)) (-15 -3722 ((-121) $))))) (T -1186)) 
-((-4266 (*1 *2 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1186)))) (-4266 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1186)))) (-2149 (*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1186)))) (-3455 (*1 *2 *1) (|partial| -12 (-5 *2 (-1152)) (-5 *1 (-1186)))) (-1515 (*1 *2 *1) (|partial| -12 (-5 *2 (-1152)) (-5 *1 (-1186)))) (-3722 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1186))))) 
-(-13 (-369 (-394) (-1152)) (-10 -8 (-15 -4266 ((-1152) $ (-1152))) (-15 -4266 ((-1152) $)) (-15 -2149 ((-1152) $)) (-15 -3455 ((-3 (-1152) "failed") $)) (-15 -1515 ((-3 (-1152) "failed") $)) (-15 -3722 ((-121) $)))) 
-((-2433 (((-3 (-572) "failed") |#1|) 19)) (-2803 (((-3 (-572) "failed") |#1|) 13)) (-2425 (((-572) (-1152)) 28))) 
-(((-1187 |#1|) (-10 -7 (-15 -2433 ((-3 (-572) "failed") |#1|)) (-15 -2803 ((-3 (-572) "failed") |#1|)) (-15 -2425 ((-572) (-1152)))) (-1054)) (T -1187)) 
-((-2425 (*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-572)) (-5 *1 (-1187 *4)) (-4 *4 (-1054)))) (-2803 (*1 *2 *3) (|partial| -12 (-5 *2 (-572)) (-5 *1 (-1187 *3)) (-4 *3 (-1054)))) (-2433 (*1 *2 *3) (|partial| -12 (-5 *2 (-572)) (-5 *1 (-1187 *3)) (-4 *3 (-1054))))) 
-(-10 -7 (-15 -2433 ((-3 (-572) "failed") |#1|)) (-15 -2803 ((-3 (-572) "failed") |#1|)) (-15 -2425 ((-572) (-1152)))) 
-((-1780 (((-1129 (-217))) 8))) 
-(((-1188) (-10 -7 (-15 -1780 ((-1129 (-217)))))) (T -1188)) 
-((-1780 (*1 *2) (-12 (-5 *2 (-1129 (-217))) (-5 *1 (-1188))))) 
-(-10 -7 (-15 -1780 ((-1129 (-217))))) 
-((-4184 (($) 11)) (-4321 (($ $) 35)) (-4308 (($ $) 33)) (-4241 (($ $) 25)) (-4333 (($ $) 17)) (-2104 (($ $) 15)) (-4327 (($ $) 19)) (-4257 (($ $) 30)) (-4314 (($ $) 34)) (-4246 (($ $) 29))) 
-(((-1189 |#1|) (-10 -8 (-15 -4184 (|#1|)) (-15 -4321 (|#1| |#1|)) (-15 -4308 (|#1| |#1|)) (-15 -4333 (|#1| |#1|)) (-15 -2104 (|#1| |#1|)) (-15 -4327 (|#1| |#1|)) (-15 -4314 (|#1| |#1|)) (-15 -4241 (|#1| |#1|)) (-15 -4257 (|#1| |#1|)) (-15 -4246 (|#1| |#1|))) (-1190)) (T -1189)) 
-NIL 
-(-10 -8 (-15 -4184 (|#1|)) (-15 -4321 (|#1| |#1|)) (-15 -4308 (|#1| |#1|)) (-15 -4333 (|#1| |#1|)) (-15 -2104 (|#1| |#1|)) (-15 -4327 (|#1| |#1|)) (-15 -4314 (|#1| |#1|)) (-15 -4241 (|#1| |#1|)) (-15 -4257 (|#1| |#1|)) (-15 -4246 (|#1| |#1|))) 
-((-4284 (($ $) 26)) (-4224 (($ $) 11)) (-4273 (($ $) 27)) (-4217 (($ $) 10)) (-4295 (($ $) 28)) (-4233 (($ $) 9)) (-4184 (($) 16)) (-3539 (($ $) 19)) (-4179 (($ $) 18)) (-4302 (($ $) 29)) (-4237 (($ $) 8)) (-4289 (($ $) 30)) (-4228 (($ $) 7)) (-4278 (($ $) 31)) (-4220 (($ $) 6)) (-4321 (($ $) 20)) (-4251 (($ $) 32)) (-4308 (($ $) 21)) (-4241 (($ $) 33)) (-4333 (($ $) 22)) (-4263 (($ $) 34)) (-2104 (($ $) 23)) (-4268 (($ $) 35)) (-4327 (($ $) 24)) (-4257 (($ $) 36)) (-4314 (($ $) 25)) (-4246 (($ $) 37)) (** (($ $ $) 17))) 
-(((-1190) (-1290)) (T -1190)) 
-((-4184 (*1 *1) (-4 *1 (-1190)))) 
-(-13 (-1193) (-98) (-506) (-40) (-281) (-10 -8 (-15 -4184 ($)))) 
-(((-40) . T) ((-98) . T) ((-281) . T) ((-506) . T) ((-1193) . T)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2148 ((|#1| $) 17)) (-4565 (($ |#1| (-638 $)) 23) (($ (-638 |#1|)) 27) (($ |#1|) 25)) (-1946 (((-121) $ (-769)) 46)) (-4436 ((|#1| $ |#1|) 14 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 13 (|has| $ (-6 -4603)))) (-2211 (($) NIL T CONST)) (-2010 (((-638 |#1|) $) 50 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 41)) (-1303 (((-121) $ $) 32 (|has| |#1| (-1098)))) (-2157 (((-121) $ (-769)) 39)) (-4467 (((-638 |#1|) $) 51 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 49 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2435 (($ (-1 |#1| |#1|) $) 24 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 22)) (-3524 (((-121) $ (-769)) 38)) (-2699 (((-638 |#1|) $) 36)) (-3113 (((-121) $) 35)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2109 (((-121) (-1 (-121) |#1|) $) 48 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 73)) (-4037 (((-121) $) 9)) (-1665 (($) 10)) (-3277 ((|#1| $ "value") NIL)) (-3537 (((-572) $ $) 31)) (-4151 (((-638 $) $) 57)) (-3948 (((-121) $ $) 75)) (-1521 (((-638 $) $) 70)) (-3773 (($ $) 71)) (-1791 (((-121) $) 54)) (-1571 (((-769) (-1 (-121) |#1|) $) 20 (|has| $ (-6 -4602))) (((-769) |#1| $) 16 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-1607 (($ $) 56)) (-3972 (((-856) $) 59 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 12)) (-3432 (((-121) $ $) 29 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 47 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 28 (|has| |#1| (-1098)))) (-4032 (((-769) $) 37 (|has| $ (-6 -4602))))) 
-(((-1191 |#1|) (-13 (-1017 |#1|) (-10 -8 (-6 -4602) (-6 -4603) (-15 -4565 ($ |#1| (-638 $))) (-15 -4565 ($ (-638 |#1|))) (-15 -4565 ($ |#1|)) (-15 -1791 ((-121) $)) (-15 -3773 ($ $)) (-15 -1521 ((-638 $) $)) (-15 -3948 ((-121) $ $)) (-15 -4151 ((-638 $) $)))) (-1098)) (T -1191)) 
-((-1791 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-1098)))) (-4565 (*1 *1 *2 *3) (-12 (-5 *3 (-638 (-1191 *2))) (-5 *1 (-1191 *2)) (-4 *2 (-1098)))) (-4565 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1191 *3)))) (-4565 (*1 *1 *2) (-12 (-5 *1 (-1191 *2)) (-4 *2 (-1098)))) (-3773 (*1 *1 *1) (-12 (-5 *1 (-1191 *2)) (-4 *2 (-1098)))) (-1521 (*1 *2 *1) (-12 (-5 *2 (-638 (-1191 *3))) (-5 *1 (-1191 *3)) (-4 *3 (-1098)))) (-3948 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-1098)))) (-4151 (*1 *2 *1) (-12 (-5 *2 (-638 (-1191 *3))) (-5 *1 (-1191 *3)) (-4 *3 (-1098))))) 
-(-13 (-1017 |#1|) (-10 -8 (-6 -4602) (-6 -4603) (-15 -4565 ($ |#1| (-638 $))) (-15 -4565 ($ (-638 |#1|))) (-15 -4565 ($ |#1|)) (-15 -1791 ((-121) $)) (-15 -3773 ($ $)) (-15 -1521 ((-638 $) $)) (-15 -3948 ((-121) $ $)) (-15 -4151 ((-638 $) $)))) 
-((-4224 (($ $) 15)) (-4233 (($ $) 12)) (-4237 (($ $) 10)) (-4228 (($ $) 17))) 
-(((-1192 |#1|) (-10 -8 (-15 -4228 (|#1| |#1|)) (-15 -4237 (|#1| |#1|)) (-15 -4233 (|#1| |#1|)) (-15 -4224 (|#1| |#1|))) (-1193)) (T -1192)) 
-NIL 
-(-10 -8 (-15 -4228 (|#1| |#1|)) (-15 -4237 (|#1| |#1|)) (-15 -4233 (|#1| |#1|)) (-15 -4224 (|#1| |#1|))) 
-((-4224 (($ $) 11)) (-4217 (($ $) 10)) (-4233 (($ $) 9)) (-4237 (($ $) 8)) (-4228 (($ $) 7)) (-4220 (($ $) 6))) 
-(((-1193) (-1290)) (T -1193)) 
-((-4224 (*1 *1 *1) (-4 *1 (-1193))) (-4217 (*1 *1 *1) (-4 *1 (-1193))) (-4233 (*1 *1 *1) (-4 *1 (-1193))) (-4237 (*1 *1 *1) (-4 *1 (-1193))) (-4228 (*1 *1 *1) (-4 *1 (-1193))) (-4220 (*1 *1 *1) (-4 *1 (-1193)))) 
-(-13 (-10 -8 (-15 -4220 ($ $)) (-15 -4228 ($ $)) (-15 -4237 ($ $)) (-15 -4233 ($ $)) (-15 -4217 ($ $)) (-15 -4224 ($ $)))) 
-((-3838 ((|#2| |#2|) 85)) (-4523 (((-121) |#2|) 25)) (-3359 ((|#2| |#2|) 29)) (-4310 ((|#2| |#2|) 31)) (-2126 ((|#2| |#2| (-1170)) 79) ((|#2| |#2|) 80)) (-1485 (((-171 |#2|) |#2|) 27)) (-2635 ((|#2| |#2| (-1170)) 81) ((|#2| |#2|) 82))) 
-(((-1194 |#1| |#2|) (-10 -7 (-15 -2126 (|#2| |#2|)) (-15 -2126 (|#2| |#2| (-1170))) (-15 -2635 (|#2| |#2|)) (-15 -2635 (|#2| |#2| (-1170))) (-15 -3838 (|#2| |#2|)) (-15 -3359 (|#2| |#2|)) (-15 -4310 (|#2| |#2|)) (-15 -4523 ((-121) |#2|)) (-15 -1485 ((-171 |#2|) |#2|))) (-13 (-457) (-848) (-1044 (-572)) (-634 (-572))) (-13 (-27) (-1190) (-436 |#1|))) (T -1194)) 
-((-1485 (*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-171 *3)) (-5 *1 (-1194 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) (-4523 (*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-121)) (-5 *1 (-1194 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) (-4310 (*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) (-3359 (*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) (-3838 (*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) (-2635 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))))) (-2635 (*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) (-2126 (*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))))) (-2126 (*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3)))))) 
-(-10 -7 (-15 -2126 (|#2| |#2|)) (-15 -2126 (|#2| |#2| (-1170))) (-15 -2635 (|#2| |#2|)) (-15 -2635 (|#2| |#2| (-1170))) (-15 -3838 (|#2| |#2|)) (-15 -3359 (|#2| |#2|)) (-15 -4310 (|#2| |#2|)) (-15 -4523 ((-121) |#2|)) (-15 -1485 ((-171 |#2|) |#2|))) 
-((-3746 ((|#4| |#4| |#1|) 27)) (-2532 ((|#4| |#4| |#1|) 28))) 
-(((-1195 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3746 (|#4| |#4| |#1|)) (-15 -2532 (|#4| |#4| |#1|))) (-562) (-379 |#1|) (-379 |#1|) (-683 |#1| |#2| |#3|)) (T -1195)) 
-((-2532 (*1 *2 *2 *3) (-12 (-4 *3 (-562)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-1195 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) (-3746 (*1 *2 *2 *3) (-12 (-4 *3 (-562)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-1195 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(-10 -7 (-15 -3746 (|#4| |#4| |#1|)) (-15 -2532 (|#4| |#4| |#1|))) 
-((-2731 ((|#2| |#2|) 144)) (-4264 ((|#2| |#2|) 142)) (-1508 ((|#2| |#2|) 134)) (-3850 ((|#2| |#2|) 131)) (-3986 ((|#2| |#2|) 139)) (-3606 ((|#2| |#2|) 127)) (-3955 ((|#2| |#2|) 59)) (-2302 ((|#2| |#2|) 109)) (-3925 ((|#2| |#2|) 89)) (-2765 ((|#2| |#2|) 141)) (-4177 ((|#2| |#2|) 129)) (-4236 ((|#2| |#2|) 149)) (-3059 ((|#2| |#2|) 147)) (-4499 ((|#2| |#2|) 148)) (-3118 ((|#2| |#2|) 146)) (-3365 ((|#2| |#2|) 158)) (-1709 ((|#2| |#2|) 48 (-12 (|has| |#2| (-613 (-893 |#1|))) (|has| |#2| (-887 |#1|)) (|has| |#1| (-613 (-893 |#1|))) (|has| |#1| (-887 |#1|))))) (-1416 ((|#2| |#2|) 90)) (-3721 ((|#2| |#2|) 150)) (-2534 ((|#2| |#2|) 151)) (-3093 ((|#2| |#2|) 140)) (-1990 ((|#2| |#2|) 128)) (-3353 ((|#2| |#2|) 145)) (-2511 ((|#2| |#2|) 143)) (-2881 ((|#2| |#2|) 135)) (-1726 ((|#2| |#2|) 133)) (-1970 ((|#2| |#2|) 137)) (-3126 ((|#2| |#2|) 125))) 
-(((-1196 |#1| |#2|) (-10 -7 (-15 -2534 (|#2| |#2|)) (-15 -3925 (|#2| |#2|)) (-15 -3365 (|#2| |#2|)) (-15 -2302 (|#2| |#2|)) (-15 -3955 (|#2| |#2|)) (-15 -1416 (|#2| |#2|)) (-15 -3721 (|#2| |#2|)) (-15 -3126 (|#2| |#2|)) (-15 -1970 (|#2| |#2|)) (-15 -2881 (|#2| |#2|)) (-15 -3353 (|#2| |#2|)) (-15 -1990 (|#2| |#2|)) (-15 -3093 (|#2| |#2|)) (-15 -4177 (|#2| |#2|)) (-15 -2765 (|#2| |#2|)) (-15 -3606 (|#2| |#2|)) (-15 -3986 (|#2| |#2|)) (-15 -1508 (|#2| |#2|)) (-15 -2731 (|#2| |#2|)) (-15 -3850 (|#2| |#2|)) (-15 -4264 (|#2| |#2|)) (-15 -1726 (|#2| |#2|)) (-15 -2511 (|#2| |#2|)) (-15 -3118 (|#2| |#2|)) (-15 -3059 (|#2| |#2|)) (-15 -4499 (|#2| |#2|)) (-15 -4236 (|#2| |#2|)) (IF (|has| |#1| (-887 |#1|)) (IF (|has| |#1| (-613 (-893 |#1|))) (IF (|has| |#2| (-613 (-893 |#1|))) (IF (|has| |#2| (-887 |#1|)) (-15 -1709 (|#2| |#2|)) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) (-13 (-848) (-457)) (-13 (-436 |#1|) (-1190))) (T -1196)) 
-((-1709 (*1 *2 *2) (-12 (-4 *3 (-613 (-893 *3))) (-4 *3 (-887 *3)) (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-613 (-893 *3))) (-4 *2 (-887 *3)) (-4 *2 (-13 (-436 *3) (-1190))))) (-4236 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-4499 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3059 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3118 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-2511 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-1726 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-4264 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3850 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-2731 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-1508 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3986 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3606 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-2765 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-4177 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3093 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-1990 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3353 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-2881 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-1970 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3126 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3721 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-1416 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3955 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-2302 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3365 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-3925 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) (-2534 (*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(-10 -7 (-15 -2534 (|#2| |#2|)) (-15 -3925 (|#2| |#2|)) (-15 -3365 (|#2| |#2|)) (-15 -2302 (|#2| |#2|)) (-15 -3955 (|#2| |#2|)) (-15 -1416 (|#2| |#2|)) (-15 -3721 (|#2| |#2|)) (-15 -3126 (|#2| |#2|)) (-15 -1970 (|#2| |#2|)) (-15 -2881 (|#2| |#2|)) (-15 -3353 (|#2| |#2|)) (-15 -1990 (|#2| |#2|)) (-15 -3093 (|#2| |#2|)) (-15 -4177 (|#2| |#2|)) (-15 -2765 (|#2| |#2|)) (-15 -3606 (|#2| |#2|)) (-15 -3986 (|#2| |#2|)) (-15 -1508 (|#2| |#2|)) (-15 -2731 (|#2| |#2|)) (-15 -3850 (|#2| |#2|)) (-15 -4264 (|#2| |#2|)) (-15 -1726 (|#2| |#2|)) (-15 -2511 (|#2| |#2|)) (-15 -3118 (|#2| |#2|)) (-15 -3059 (|#2| |#2|)) (-15 -4499 (|#2| |#2|)) (-15 -4236 (|#2| |#2|)) (IF (|has| |#1| (-887 |#1|)) (IF (|has| |#1| (-613 (-893 |#1|))) (IF (|has| |#2| (-613 (-893 |#1|))) (IF (|has| |#2| (-887 |#1|)) (-15 -1709 (|#2| |#2|)) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) 
-((-3366 (((-121) |#5| $) 59) (((-121) $) 101)) (-1872 ((|#5| |#5| $) 74)) (-2561 (($ (-1 (-121) |#5|) $) NIL) (((-3 |#5| "failed") $ |#4|) 118)) (-4577 (((-638 |#5|) (-638 |#5|) $ (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|)) 72)) (-3376 (((-3 $ "failed") (-638 |#5|)) 125)) (-1651 (((-3 $ "failed") $) 111)) (-2242 ((|#5| |#5| $) 93)) (-2240 (((-121) |#5| $ (-1 (-121) |#5| |#5|)) 30)) (-1673 ((|#5| |#5| $) 97)) (-3116 ((|#5| (-1 |#5| |#5| |#5|) $ |#5| |#5|) NIL) ((|#5| (-1 |#5| |#5| |#5|) $ |#5|) NIL) ((|#5| (-1 |#5| |#5| |#5|) $) NIL) ((|#5| |#5| $ (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|)) 68)) (-3725 (((-2 (|:| -2371 (-638 |#5|)) (|:| -1428 (-638 |#5|))) $) 54)) (-3824 (((-121) |#5| $) 57) (((-121) $) 102)) (-1792 ((|#4| $) 107)) (-3253 (((-3 |#5| "failed") $) 109)) (-3727 (((-638 |#5|) $) 48)) (-1483 (((-121) |#5| $) 66) (((-121) $) 106)) (-2788 ((|#5| |#5| $) 80)) (-1843 (((-121) $ $) 26)) (-1994 (((-121) |#5| $) 62) (((-121) $) 104)) (-4498 ((|#5| |#5| $) 77)) (-1837 (((-3 |#5| "failed") $) 108)) (-1977 (($ $ |#5|) 126)) (-4316 (((-769) $) 51)) (-3921 (($ (-638 |#5|)) 123)) (-1826 (($ $ |#4|) 121)) (-2291 (($ $ |#4|) 120)) (-3134 (($ $) 119)) (-3972 (((-856) $) NIL) (((-638 |#5|) $) 112)) (-2498 (((-769) $) 129)) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#5|))) "failed") (-638 |#5|) (-1 (-121) |#5| |#5|)) 42) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#5|))) "failed") (-638 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|)) 44)) (-2057 (((-121) $ (-1 (-121) |#5| (-638 |#5|))) 99)) (-1502 (((-638 |#4|) $) 114)) (-2213 (((-121) |#4| $) 117)) (-1324 (((-121) $ $) 19))) 
-(((-1197 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2498 ((-769) |#1|)) (-15 -1977 (|#1| |#1| |#5|)) (-15 -2561 ((-3 |#5| "failed") |#1| |#4|)) (-15 -2213 ((-121) |#4| |#1|)) (-15 -1502 ((-638 |#4|) |#1|)) (-15 -1651 ((-3 |#1| "failed") |#1|)) (-15 -3253 ((-3 |#5| "failed") |#1|)) (-15 -1837 ((-3 |#5| "failed") |#1|)) (-15 -1673 (|#5| |#5| |#1|)) (-15 -3134 (|#1| |#1|)) (-15 -2242 (|#5| |#5| |#1|)) (-15 -2788 (|#5| |#5| |#1|)) (-15 -4498 (|#5| |#5| |#1|)) (-15 -1872 (|#5| |#5| |#1|)) (-15 -4577 ((-638 |#5|) (-638 |#5|) |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -3116 (|#5| |#5| |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -1483 ((-121) |#1|)) (-15 -1994 ((-121) |#1|)) (-15 -3366 ((-121) |#1|)) (-15 -2057 ((-121) |#1| (-1 (-121) |#5| (-638 |#5|)))) (-15 -1483 ((-121) |#5| |#1|)) (-15 -1994 ((-121) |#5| |#1|)) (-15 -3366 ((-121) |#5| |#1|)) (-15 -2240 ((-121) |#5| |#1| (-1 (-121) |#5| |#5|))) (-15 -3824 ((-121) |#1|)) (-15 -3824 ((-121) |#5| |#1|)) (-15 -3725 ((-2 (|:| -2371 (-638 |#5|)) (|:| -1428 (-638 |#5|))) |#1|)) (-15 -4316 ((-769) |#1|)) (-15 -3727 ((-638 |#5|) |#1|)) (-15 -1586 ((-3 (-2 (|:| |bas| |#1|) (|:| -1615 (-638 |#5|))) "failed") (-638 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|))) (-15 -1586 ((-3 (-2 (|:| |bas| |#1|) (|:| -1615 (-638 |#5|))) "failed") (-638 |#5|) (-1 (-121) |#5| |#5|))) (-15 -1843 ((-121) |#1| |#1|)) (-15 -1826 (|#1| |#1| |#4|)) (-15 -2291 (|#1| |#1| |#4|)) (-15 -1792 (|#4| |#1|)) (-15 -3376 ((-3 |#1| "failed") (-638 |#5|))) (-15 -3972 ((-638 |#5|) |#1|)) (-15 -3921 (|#1| (-638 |#5|))) (-15 -3116 (|#5| (-1 |#5| |#5| |#5|) |#1|)) (-15 -3116 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5|)) (-15 -2561 (|#1| (-1 (-121) |#5|) |#1|)) (-15 -3116 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5| |#5|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) (-1198 |#2| |#3| |#4| |#5|) (-562) (-794) (-848) (-1068 |#2| |#3| |#4|)) (T -1197)) 
-NIL 
-(-10 -8 (-15 -2498 ((-769) |#1|)) (-15 -1977 (|#1| |#1| |#5|)) (-15 -2561 ((-3 |#5| "failed") |#1| |#4|)) (-15 -2213 ((-121) |#4| |#1|)) (-15 -1502 ((-638 |#4|) |#1|)) (-15 -1651 ((-3 |#1| "failed") |#1|)) (-15 -3253 ((-3 |#5| "failed") |#1|)) (-15 -1837 ((-3 |#5| "failed") |#1|)) (-15 -1673 (|#5| |#5| |#1|)) (-15 -3134 (|#1| |#1|)) (-15 -2242 (|#5| |#5| |#1|)) (-15 -2788 (|#5| |#5| |#1|)) (-15 -4498 (|#5| |#5| |#1|)) (-15 -1872 (|#5| |#5| |#1|)) (-15 -4577 ((-638 |#5|) (-638 |#5|) |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -3116 (|#5| |#5| |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -1483 ((-121) |#1|)) (-15 -1994 ((-121) |#1|)) (-15 -3366 ((-121) |#1|)) (-15 -2057 ((-121) |#1| (-1 (-121) |#5| (-638 |#5|)))) (-15 -1483 ((-121) |#5| |#1|)) (-15 -1994 ((-121) |#5| |#1|)) (-15 -3366 ((-121) |#5| |#1|)) (-15 -2240 ((-121) |#5| |#1| (-1 (-121) |#5| |#5|))) (-15 -3824 ((-121) |#1|)) (-15 -3824 ((-121) |#5| |#1|)) (-15 -3725 ((-2 (|:| -2371 (-638 |#5|)) (|:| -1428 (-638 |#5|))) |#1|)) (-15 -4316 ((-769) |#1|)) (-15 -3727 ((-638 |#5|) |#1|)) (-15 -1586 ((-3 (-2 (|:| |bas| |#1|) (|:| -1615 (-638 |#5|))) "failed") (-638 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|))) (-15 -1586 ((-3 (-2 (|:| |bas| |#1|) (|:| -1615 (-638 |#5|))) "failed") (-638 |#5|) (-1 (-121) |#5| |#5|))) (-15 -1843 ((-121) |#1| |#1|)) (-15 -1826 (|#1| |#1| |#4|)) (-15 -2291 (|#1| |#1| |#4|)) (-15 -1792 (|#4| |#1|)) (-15 -3376 ((-3 |#1| "failed") (-638 |#5|))) (-15 -3972 ((-638 |#5|) |#1|)) (-15 -3921 (|#1| (-638 |#5|))) (-15 -3116 (|#5| (-1 |#5| |#5| |#5|) |#1|)) (-15 -3116 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5|)) (-15 -2561 (|#1| (-1 (-121) |#5|) |#1|)) (-15 -3116 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5| |#5|)) (-15 -3972 ((-856) |#1|)) (-15 -1324 ((-121) |#1| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) 78)) (-4165 (((-638 $) (-638 |#4|)) 79)) (-3456 (((-638 |#3|) $) 32)) (-3049 (((-121) $) 25)) (-3289 (((-121) $) 16 (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) 94) (((-121) $) 90)) (-1872 ((|#4| |#4| $) 85)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) 26)) (-1946 (((-121) $ (-769)) 43)) (-2561 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) 72)) (-2211 (($) 44 T CONST)) (-3097 (((-121) $) 21 (|has| |#1| (-562)))) (-3760 (((-121) $ $) 23 (|has| |#1| (-562)))) (-3819 (((-121) $ $) 22 (|has| |#1| (-562)))) (-4331 (((-121) $) 24 (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3683 (((-638 |#4|) (-638 |#4|) $) 17 (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) 18 (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) 35)) (-1318 (($ (-638 |#4|)) 34)) (-1651 (((-3 $ "failed") $) 75)) (-2242 ((|#4| |#4| $) 82)) (-1643 (($ $) 67 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#4| $) 66 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-1673 ((|#4| |#4| $) 80)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) 98)) (-2010 (((-638 |#4|) $) 51 (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) 97) (((-121) $) 96)) (-1792 ((|#3| $) 33)) (-2157 (((-121) $ (-769)) 42)) (-4467 (((-638 |#4|) $) 52 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) 46)) (-4062 (((-638 |#3|) $) 31)) (-1346 (((-121) |#3| $) 30)) (-3524 (((-121) $ (-769)) 41)) (-1658 (((-1152) $) 9)) (-3253 (((-3 |#4| "failed") $) 76)) (-3727 (((-638 |#4|) $) 100)) (-1483 (((-121) |#4| $) 92) (((-121) $) 88)) (-2788 ((|#4| |#4| $) 83)) (-1843 (((-121) $ $) 103)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) 93) (((-121) $) 89)) (-4498 ((|#4| |#4| $) 84)) (-2607 (((-1116) $) 10)) (-1837 (((-3 |#4| "failed") $) 77)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1928 (((-3 $ "failed") $ |#4|) 71)) (-1977 (($ $ |#4|) 70)) (-2109 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) 58 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) 56 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) 55 (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) 37)) (-4037 (((-121) $) 40)) (-1665 (($) 39)) (-4316 (((-769) $) 99)) (-1571 (((-769) |#4| $) 53 (-12 (|has| |#4| (-1098)) (|has| $ (-6 -4602)))) (((-769) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4602)))) (-1607 (($ $) 38)) (-4081 (((-545) $) 68 (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) 59)) (-1826 (($ $ |#3|) 27)) (-2291 (($ $ |#3|) 29)) (-3134 (($ $) 81)) (-1650 (($ $ |#3|) 28)) (-3972 (((-856) $) 11) (((-638 |#4|) $) 36)) (-2498 (((-769) $) 69 (|has| |#3| (-374)))) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) 91)) (-3501 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) 74)) (-2213 (((-121) |#3| $) 73)) (-1324 (((-121) $ $) 6)) (-4032 (((-769) $) 45 (|has| $ (-6 -4602))))) 
-(((-1198 |#1| |#2| |#3| |#4|) (-1290) (-562) (-794) (-848) (-1068 |t#1| |t#2| |t#3|)) (T -1198)) 
-((-1843 (*1 *2 *1 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) (-1586 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1 (-121) *8 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |bas| *1) (|:| -1615 (-638 *8)))) (-5 *3 (-638 *8)) (-4 *1 (-1198 *5 *6 *7 *8)))) (-1586 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 (-121) *9)) (-5 *5 (-1 (-121) *9 *9)) (-4 *9 (-1068 *6 *7 *8)) (-4 *6 (-562)) (-4 *7 (-794)) (-4 *8 (-848)) (-5 *2 (-2 (|:| |bas| *1) (|:| -1615 (-638 *9)))) (-5 *3 (-638 *9)) (-4 *1 (-1198 *6 *7 *8 *9)))) (-3727 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-638 *6)))) (-4316 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-769)))) (-3725 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-2 (|:| -2371 (-638 *6)) (|:| -1428 (-638 *6)))))) (-3824 (*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *6 *3)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-3824 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) (-2240 (*1 *2 *3 *1 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *1 (-1198 *5 *6 *7 *3)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-121)))) (-3366 (*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *6 *3)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-1994 (*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *6 *3)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-1483 (*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *6 *3)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-2057 (*1 *2 *1 *3) (-12 (-5 *3 (-1 (-121) *7 (-638 *7))) (-4 *1 (-1198 *4 *5 *6 *7)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)))) (-3366 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) (-1994 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) (-1483 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) (-3116 (*1 *2 *2 *1 *3 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *4 (-1 (-121) *2 *2)) (-4 *1 (-1198 *5 *6 *7 *2)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *2 (-1068 *5 *6 *7)))) (-4577 (*1 *2 *2 *1 *3 *4) (-12 (-5 *2 (-638 *8)) (-5 *3 (-1 *8 *8 *8)) (-5 *4 (-1 (-121) *8 *8)) (-4 *1 (-1198 *5 *6 *7 *8)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)))) (-1872 (*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-4498 (*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-2788 (*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-2242 (*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-3134 (*1 *1 *1) (-12 (-4 *1 (-1198 *2 *3 *4 *5)) (-4 *2 (-562)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-1068 *2 *3 *4)))) (-1673 (*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-4165 (*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1198 *4 *5 *6 *7)))) (-4125 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-638 (-2 (|:| -2371 *1) (|:| -1428 (-638 *7))))) (-5 *3 (-638 *7)) (-4 *1 (-1198 *4 *5 *6 *7)))) (-1837 (*1 *2 *1) (|partial| -12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-3253 (*1 *2 *1) (|partial| -12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-1651 (*1 *1 *1) (|partial| -12 (-4 *1 (-1198 *2 *3 *4 *5)) (-4 *2 (-562)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-1068 *2 *3 *4)))) (-1502 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-638 *5)))) (-2213 (*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *3 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *3 (-848)) (-4 *6 (-1068 *4 *5 *3)) (-5 *2 (-121)))) (-2561 (*1 *2 *1 *3) (|partial| -12 (-4 *1 (-1198 *4 *5 *3 *2)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *3 (-848)) (-4 *2 (-1068 *4 *5 *3)))) (-1928 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-1977 (*1 *1 *1 *2) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) (-2498 (*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *5 (-374)) (-5 *2 (-769))))) 
-(-13 (-984 |t#1| |t#2| |t#3| |t#4|) (-10 -8 (-6 -4602) (-6 -4603) (-15 -1843 ((-121) $ $)) (-15 -1586 ((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |t#4|))) "failed") (-638 |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -1586 ((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |t#4|))) "failed") (-638 |t#4|) (-1 (-121) |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -3727 ((-638 |t#4|) $)) (-15 -4316 ((-769) $)) (-15 -3725 ((-2 (|:| -2371 (-638 |t#4|)) (|:| -1428 (-638 |t#4|))) $)) (-15 -3824 ((-121) |t#4| $)) (-15 -3824 ((-121) $)) (-15 -2240 ((-121) |t#4| $ (-1 (-121) |t#4| |t#4|))) (-15 -3366 ((-121) |t#4| $)) (-15 -1994 ((-121) |t#4| $)) (-15 -1483 ((-121) |t#4| $)) (-15 -2057 ((-121) $ (-1 (-121) |t#4| (-638 |t#4|)))) (-15 -3366 ((-121) $)) (-15 -1994 ((-121) $)) (-15 -1483 ((-121) $)) (-15 -3116 (|t#4| |t#4| $ (-1 |t#4| |t#4| |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -4577 ((-638 |t#4|) (-638 |t#4|) $ (-1 |t#4| |t#4| |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -1872 (|t#4| |t#4| $)) (-15 -4498 (|t#4| |t#4| $)) (-15 -2788 (|t#4| |t#4| $)) (-15 -2242 (|t#4| |t#4| $)) (-15 -3134 ($ $)) (-15 -1673 (|t#4| |t#4| $)) (-15 -4165 ((-638 $) (-638 |t#4|))) (-15 -4125 ((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |t#4|)))) (-638 |t#4|))) (-15 -1837 ((-3 |t#4| "failed") $)) (-15 -3253 ((-3 |t#4| "failed") $)) (-15 -1651 ((-3 $ "failed") $)) (-15 -1502 ((-638 |t#3|) $)) (-15 -2213 ((-121) |t#3| $)) (-15 -2561 ((-3 |t#4| "failed") $ |t#3|)) (-15 -1928 ((-3 $ "failed") $ |t#4|)) (-15 -1977 ($ $ |t#4|)) (IF (|has| |t#3| (-374)) (-15 -2498 ((-769) $)) |noBranch|))) 
-(((-39) . T) ((-105) . T) ((-612 (-638 |#4|)) . T) ((-612 (-856)) . T) ((-155 |#4|) . T) ((-613 (-545)) |has| |#4| (-613 (-545))) ((-305 |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-503 |#4|) . T) ((-527 |#4| |#4|) -12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))) ((-984 |#1| |#2| |#3| |#4|) . T) ((-1098) . T) ((-1204) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1170)) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-1896 (((-959 |#1|) $ (-769)) 16) (((-959 |#1|) $ (-769) (-769)) NIL)) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-769) $ (-1170)) NIL) (((-769) $ (-1170) (-769)) NIL)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4581 (((-121) $) NIL)) (-4328 (($ $ (-638 (-1170)) (-638 (-538 (-1170)))) NIL) (($ $ (-1170) (-538 (-1170))) NIL) (($ |#1| (-538 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2774 (($ $ (-1170)) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170) |#1|) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-3620 (($ (-1 $) (-1170) |#1|) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1977 (($ $ (-769)) NIL)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4485 (($ $ (-1170) $) NIL) (($ $ (-638 (-1170)) (-638 $)) NIL) (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL)) (-3139 (($ $ (-1170)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL)) (-4316 (((-538 (-1170)) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL (|has| |#1| (-174))) (($ $) NIL (|has| |#1| (-562))) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-1170)) NIL) (($ (-959 |#1|)) NIL)) (-1958 ((|#1| $ (-538 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (((-959 |#1|) $ (-769)) NIL)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-1170)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-1199 |#1|) (-13 (-736 |#1| (-1170)) (-10 -8 (-15 -1958 ((-959 |#1|) $ (-769))) (-15 -3972 ($ (-1170))) (-15 -3972 ($ (-959 |#1|))) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $ (-1170) |#1|)) (-15 -3620 ($ (-1 $) (-1170) |#1|))) |noBranch|))) (-1054)) (T -1199)) 
-((-1958 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-959 *4)) (-5 *1 (-1199 *4)) (-4 *4 (-1054)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1199 *3)) (-4 *3 (-1054)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-959 *3)) (-4 *3 (-1054)) (-5 *1 (-1199 *3)))) (-2774 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *1 (-1199 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)))) (-3620 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1199 *4))) (-5 *3 (-1170)) (-5 *1 (-1199 *4)) (-4 *4 (-43 (-413 (-572)))) (-4 *4 (-1054))))) 
-(-13 (-736 |#1| (-1170)) (-10 -8 (-15 -1958 ((-959 |#1|) $ (-769))) (-15 -3972 ($ (-1170))) (-15 -3972 ($ (-959 |#1|))) (IF (|has| |#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $ (-1170) |#1|)) (-15 -3620 ($ (-1 $) (-1170) |#1|))) |noBranch|))) 
-((-1440 (($ |#1| (-638 (-638 (-950 (-217)))) (-121)) 15)) (-3261 (((-121) $ (-121)) 14)) (-4466 (((-121) $) 13)) (-3531 (((-638 (-638 (-950 (-217)))) $) 10)) (-2400 ((|#1| $) 8)) (-2245 (((-121) $) 12))) 
-(((-1200 |#1|) (-10 -8 (-15 -2400 (|#1| $)) (-15 -3531 ((-638 (-638 (-950 (-217)))) $)) (-15 -2245 ((-121) $)) (-15 -4466 ((-121) $)) (-15 -3261 ((-121) $ (-121))) (-15 -1440 ($ |#1| (-638 (-638 (-950 (-217)))) (-121)))) (-982)) (T -1200)) 
-((-1440 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-121)) (-5 *1 (-1200 *2)) (-4 *2 (-982)))) (-3261 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1200 *3)) (-4 *3 (-982)))) (-4466 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1200 *3)) (-4 *3 (-982)))) (-2245 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1200 *3)) (-4 *3 (-982)))) (-3531 (*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *1 (-1200 *3)) (-4 *3 (-982)))) (-2400 (*1 *2 *1) (-12 (-5 *1 (-1200 *2)) (-4 *2 (-982))))) 
-(-10 -8 (-15 -2400 (|#1| $)) (-15 -3531 ((-638 (-638 (-950 (-217)))) $)) (-15 -2245 ((-121) $)) (-15 -4466 ((-121) $)) (-15 -3261 ((-121) $ (-121))) (-15 -1440 ($ |#1| (-638 (-638 (-950 (-217)))) (-121)))) 
-((-3421 (((-950 (-217)) (-950 (-217))) 25)) (-1767 (((-950 (-217)) (-217) (-217) (-217) (-217)) 10)) (-2991 (((-638 (-950 (-217))) (-950 (-217)) (-950 (-217)) (-950 (-217)) (-217) (-638 (-638 (-217)))) 35)) (-1436 (((-217) (-950 (-217)) (-950 (-217))) 21)) (-3780 (((-950 (-217)) (-950 (-217)) (-950 (-217))) 22)) (-2794 (((-638 (-638 (-217))) (-572)) 31)) (-1373 (((-950 (-217)) (-950 (-217)) (-950 (-217))) 20)) (-1367 (((-950 (-217)) (-950 (-217)) (-950 (-217))) 19)) (* (((-950 (-217)) (-217) (-950 (-217))) 18))) 
-(((-1201) (-10 -7 (-15 -1767 ((-950 (-217)) (-217) (-217) (-217) (-217))) (-15 * ((-950 (-217)) (-217) (-950 (-217)))) (-15 -1367 ((-950 (-217)) (-950 (-217)) (-950 (-217)))) (-15 -1373 ((-950 (-217)) (-950 (-217)) (-950 (-217)))) (-15 -1436 ((-217) (-950 (-217)) (-950 (-217)))) (-15 -3780 ((-950 (-217)) (-950 (-217)) (-950 (-217)))) (-15 -3421 ((-950 (-217)) (-950 (-217)))) (-15 -2794 ((-638 (-638 (-217))) (-572))) (-15 -2991 ((-638 (-950 (-217))) (-950 (-217)) (-950 (-217)) (-950 (-217)) (-217) (-638 (-638 (-217))))))) (T -1201)) 
-((-2991 (*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-638 (-638 (-217)))) (-5 *4 (-217)) (-5 *2 (-638 (-950 *4))) (-5 *1 (-1201)) (-5 *3 (-950 *4)))) (-2794 (*1 *2 *3) (-12 (-5 *3 (-572)) (-5 *2 (-638 (-638 (-217)))) (-5 *1 (-1201)))) (-3421 (*1 *2 *2) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)))) (-3780 (*1 *2 *2 *2) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)))) (-1436 (*1 *2 *3 *3) (-12 (-5 *3 (-950 (-217))) (-5 *2 (-217)) (-5 *1 (-1201)))) (-1373 (*1 *2 *2 *2) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)))) (-1367 (*1 *2 *2 *2) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-950 (-217))) (-5 *3 (-217)) (-5 *1 (-1201)))) (-1767 (*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)) (-5 *3 (-217))))) 
-(-10 -7 (-15 -1767 ((-950 (-217)) (-217) (-217) (-217) (-217))) (-15 * ((-950 (-217)) (-217) (-950 (-217)))) (-15 -1367 ((-950 (-217)) (-950 (-217)) (-950 (-217)))) (-15 -1373 ((-950 (-217)) (-950 (-217)) (-950 (-217)))) (-15 -1436 ((-217) (-950 (-217)) (-950 (-217)))) (-15 -3780 ((-950 (-217)) (-950 (-217)) (-950 (-217)))) (-15 -3421 ((-950 (-217)) (-950 (-217)))) (-15 -2794 ((-638 (-638 (-217))) (-572))) (-15 -2991 ((-638 (-950 (-217))) (-950 (-217)) (-950 (-217)) (-950 (-217)) (-217) (-638 (-638 (-217)))))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-2561 ((|#1| $ (-769)) 13)) (-3200 (((-769) $) 12)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-3972 (((-965 |#1|) $) 10) (($ (-965 |#1|)) 9) (((-856) $) 23 (|has| |#1| (-1098)))) (-1324 (((-121) $ $) 16 (|has| |#1| (-1098))))) 
-(((-1202 |#1|) (-13 (-612 (-965 |#1|)) (-10 -8 (-15 -3972 ($ (-965 |#1|))) (-15 -2561 (|#1| $ (-769))) (-15 -3200 ((-769) $)) (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|))) (-1204)) (T -1202)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-965 *3)) (-4 *3 (-1204)) (-5 *1 (-1202 *3)))) (-2561 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *1 (-1202 *2)) (-4 *2 (-1204)))) (-3200 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1202 *3)) (-4 *3 (-1204))))) 
-(-13 (-612 (-965 |#1|)) (-10 -8 (-15 -3972 ($ (-965 |#1|))) (-15 -2561 (|#1| $ (-769))) (-15 -3200 ((-769) $)) (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|))) 
-((-3820 (((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|)) (-572)) 79)) (-3623 (((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|))) 73)) (-1401 (((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|))) 58))) 
-(((-1203 |#1|) (-10 -7 (-15 -3623 ((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|)))) (-15 -1401 ((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|)))) (-15 -3820 ((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|)) (-572)))) (-353)) (T -1203)) 
-((-3820 (*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-353)) (-5 *2 (-424 (-1166 (-1166 *5)))) (-5 *1 (-1203 *5)) (-5 *3 (-1166 (-1166 *5))))) (-1401 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 (-1166 (-1166 *4)))) (-5 *1 (-1203 *4)) (-5 *3 (-1166 (-1166 *4))))) (-3623 (*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 (-1166 (-1166 *4)))) (-5 *1 (-1203 *4)) (-5 *3 (-1166 (-1166 *4)))))) 
-(-10 -7 (-15 -3623 ((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|)))) (-15 -1401 ((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|)))) (-15 -3820 ((-424 (-1166 (-1166 |#1|))) (-1166 (-1166 |#1|)) (-572)))) 
-NIL 
-(((-1204) (-1290)) (T -1204)) 
-NIL 
-(-13 (-10 -7 (-6 -3389))) 
-((-2262 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-4169 (($ (-769) (-769)) NIL)) (-2113 (($ $ $) NIL)) (-1444 (($ (-1206)) NIL) (($ $) NIL)) (-3083 (((-121) $) NIL)) (-3861 (($ $ (-572) (-572)) NIL)) (-3595 (($ $ (-572) (-572)) NIL)) (-4152 (($ $ (-572) (-572) (-572) (-572)) NIL)) (-4369 (($ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2569 (($ $ (-572) (-572) $) NIL)) (-3283 (((-572) $ (-572) (-572) (-572)) 17) (($ $ (-638 (-572)) (-638 (-572)) $) NIL)) (-1823 (($ $ (-572) (-1206)) NIL)) (-1695 (($ $ (-572) (-1206)) NIL)) (-1468 (($ (-769) (-572)) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) NIL (|has| (-572) (-303)))) (-4267 (((-1206) $ (-572)) NIL)) (-2667 (((-769) $) NIL (|has| (-572) (-562)))) (-3037 (((-572) $ (-572) (-572) (-572)) 16)) (-3596 (($ (-572) (-572)) 19)) (-4212 (((-572) $ (-572) (-572)) 14)) (-4439 (((-572) $) NIL (|has| (-572) (-174)))) (-2010 (((-638 (-572)) $) NIL)) (-3095 (((-769) $) NIL (|has| (-572) (-562)))) (-1301 (((-638 (-1206)) $) NIL (|has| (-572) (-562)))) (-3704 (((-769) $) 10)) (-1364 (($ (-769) (-769) (-572)) 20)) (-3712 (((-769) $) 11)) (-2157 (((-121) $ (-769)) NIL)) (-1522 (((-572) $) NIL (|has| (-572) (-6 (-4604 "*"))))) (-2660 (((-572) $) 7)) (-3092 (((-572) $) 8)) (-4467 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-3927 (((-572) $) 12)) (-3227 (((-572) $) 13)) (-3597 (($ (-638 (-638 (-572)))) NIL) (($ (-769) (-769) (-1 (-572) (-572) (-572))) NIL)) (-2435 (($ (-1 (-572) (-572)) $) NIL)) (-3828 (($ (-1 (-572) (-572)) $) NIL) (($ (-1 (-572) (-572) (-572)) $ $) NIL) (($ (-1 (-572) (-572) (-572)) $ $ (-572)) NIL)) (-2259 (((-638 (-638 (-572))) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| (-572) (-1098)))) (-3750 (((-3 $ "failed") $) NIL (|has| (-572) (-368)))) (-1865 (($ $ $) NIL)) (-2607 (((-1116) $) NIL (|has| (-572) (-1098)))) (-3299 (($ $ (-572)) NIL)) (-1803 (((-3 $ "failed") $ (-572)) NIL (|has| (-572) (-562)))) (-2109 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-572)))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-290 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-572) (-572)) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-638 (-572)) (-638 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 18)) (-3277 (((-572) $ (-572) (-572)) 15) (((-572) $ (-572) (-572) (-572)) NIL) (($ $ (-638 (-572)) (-638 (-572))) NIL)) (-3132 (($ (-638 (-572))) NIL) (($ (-638 $)) NIL)) (-3785 (((-121) $) NIL)) (-2271 (((-572) $) NIL (|has| (-572) (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602))) (((-769) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-1607 (($ $) NIL)) (-1802 (((-638 (-1206)) $) NIL (|has| (-572) (-303)))) (-4580 (((-1206) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| (-572) (-1098))) (($ (-1206)) NIL)) (-3501 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-1379 (($ $ (-572)) NIL (|has| (-572) (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-572) (-368)))) (* (($ $ $) NIL) (($ (-572) $) NIL) (($ $ (-572)) NIL) (($ (-572) $) NIL) (((-1206) $ (-1206)) NIL) (((-1206) (-1206) $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1205) (-13 (-683 (-572) (-1206) (-1206)) (-10 -8 (-15 -3596 ($ (-572) (-572)))))) (T -1205)) 
-((-3596 (*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1205))))) 
-(-13 (-683 (-572) (-1206) (-1206)) (-10 -8 (-15 -3596 ($ (-572) (-572))))) 
-((-2262 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) (-572) (-572)) $) NIL) (((-121) $) NIL (|has| (-572) (-848)))) (-4131 (($ (-1 (-121) (-572) (-572)) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-572) (-848))))) (-3008 (($ (-1 (-121) (-572) (-572)) $) NIL) (($ $) NIL (|has| (-572) (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-572) $ (-572) (-572)) 15 (|has| $ (-6 -4603))) (((-572) $ (-1225 (-572)) (-572)) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-3445 (($ (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098)))) (($ (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-572) (-1 (-572) (-572) (-572)) $ (-572) (-572)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098)))) (((-572) (-1 (-572) (-572) (-572)) $ (-572)) NIL (|has| $ (-6 -4602))) (((-572) (-1 (-572) (-572) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-572) $ (-572) (-572)) 14 (|has| $ (-6 -4603)))) (-4212 (((-572) $ (-572)) 12)) (-4014 (((-572) (-1 (-121) (-572)) $) NIL) (((-572) (-572) $) NIL (|has| (-572) (-1098))) (((-572) (-572) $ (-572)) NIL (|has| (-572) (-1098)))) (-2010 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) (-572)) 11)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 9 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| (-572) (-848)))) (-4475 (($ (-1 (-121) (-572) (-572)) $ $) NIL) (($ $ $) NIL (|has| (-572) (-848)))) (-4467 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-572) (-848)))) (-2435 (($ (-1 (-572) (-572)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-572) (-572)) $) NIL) (($ (-1 (-572) (-572) (-572)) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| (-572) (-1098)))) (-2603 (($ (-572) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| (-572) (-1098)))) (-1837 (((-572) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-572) "failed") (-1 (-121) (-572)) $) NIL)) (-3299 (($ $ (-572)) 16 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-572)))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-290 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-572) (-572)) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-638 (-572)) (-638 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2957 (((-638 (-572)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 10)) (-3277 (((-572) $ (-572) (-572)) NIL) (((-572) $ (-572)) 13) (($ $ (-1225 (-572))) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602))) (((-769) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-572) (-613 (-545))))) (-3921 (($ (-638 (-572))) NIL)) (-4500 (($ $ (-572)) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| (-572) (-1098)))) (-3501 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1324 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-1343 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-572) (-848)))) (-4032 (((-769) $) 7 (|has| $ (-6 -4602))))) 
-(((-1206) (-19 (-572))) (T -1206)) 
-NIL 
-(-19 (-572)) 
-((-2262 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-4169 (($ (-769) (-769)) NIL)) (-2113 (($ $ $) NIL)) (-1444 (($ (-1208)) NIL) (($ $) NIL)) (-3083 (((-121) $) NIL)) (-3861 (($ $ (-572) (-572)) NIL)) (-3595 (($ $ (-572) (-572)) NIL)) (-4152 (($ $ (-572) (-572) (-572) (-572)) NIL)) (-4369 (($ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2569 (($ $ (-572) (-572) $) NIL)) (-3283 (((-572) $ (-572) (-572) (-572)) 17) (($ $ (-638 (-572)) (-638 (-572)) $) NIL)) (-1823 (($ $ (-572) (-1208)) NIL)) (-1695 (($ $ (-572) (-1208)) NIL)) (-1468 (($ (-769) (-572)) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) NIL (|has| (-572) (-303)))) (-4267 (((-1208) $ (-572)) NIL)) (-2667 (((-769) $) NIL (|has| (-572) (-562)))) (-3037 (((-572) $ (-572) (-572) (-572)) 16)) (-3596 (($ (-572) (-572)) 19)) (-4212 (((-572) $ (-572) (-572)) 14)) (-4439 (((-572) $) NIL (|has| (-572) (-174)))) (-2010 (((-638 (-572)) $) NIL)) (-3095 (((-769) $) NIL (|has| (-572) (-562)))) (-1301 (((-638 (-1208)) $) NIL (|has| (-572) (-562)))) (-3704 (((-769) $) 10)) (-1364 (($ (-769) (-769) (-572)) 20)) (-3712 (((-769) $) 11)) (-2157 (((-121) $ (-769)) NIL)) (-1522 (((-572) $) NIL (|has| (-572) (-6 (-4604 "*"))))) (-2660 (((-572) $) 7)) (-3092 (((-572) $) 8)) (-4467 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-3927 (((-572) $) 12)) (-3227 (((-572) $) 13)) (-3597 (($ (-638 (-638 (-572)))) NIL) (($ (-769) (-769) (-1 (-572) (-572) (-572))) NIL)) (-2435 (($ (-1 (-572) (-572)) $) NIL)) (-3828 (($ (-1 (-572) (-572)) $) NIL) (($ (-1 (-572) (-572) (-572)) $ $) NIL) (($ (-1 (-572) (-572) (-572)) $ $ (-572)) NIL)) (-2259 (((-638 (-638 (-572))) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| (-572) (-1098)))) (-3750 (((-3 $ "failed") $) NIL (|has| (-572) (-368)))) (-1865 (($ $ $) NIL)) (-2607 (((-1116) $) NIL (|has| (-572) (-1098)))) (-3299 (($ $ (-572)) NIL)) (-1803 (((-3 $ "failed") $ (-572)) NIL (|has| (-572) (-562)))) (-2109 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-572)))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-290 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-572) (-572)) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-638 (-572)) (-638 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 18)) (-3277 (((-572) $ (-572) (-572)) 15) (((-572) $ (-572) (-572) (-572)) NIL) (($ $ (-638 (-572)) (-638 (-572))) NIL)) (-3132 (($ (-638 (-572))) NIL) (($ (-638 $)) NIL)) (-3785 (((-121) $) NIL)) (-2271 (((-572) $) NIL (|has| (-572) (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602))) (((-769) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-1607 (($ $) NIL)) (-1802 (((-638 (-1208)) $) NIL (|has| (-572) (-303)))) (-4580 (((-1208) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| (-572) (-1098))) (($ (-1208)) NIL)) (-3501 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-1379 (($ $ (-572)) NIL (|has| (-572) (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-572) (-368)))) (* (($ $ $) NIL) (($ (-572) $) NIL) (($ $ (-572)) NIL) (($ (-572) $) NIL) (((-1208) $ (-1208)) NIL) (((-1208) (-1208) $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1207) (-13 (-683 (-572) (-1208) (-1208)) (-10 -8 (-15 -3596 ($ (-572) (-572)))))) (T -1207)) 
-((-3596 (*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1207))))) 
-(-13 (-683 (-572) (-1208) (-1208)) (-10 -8 (-15 -3596 ($ (-572) (-572))))) 
-((-2262 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) (-572) (-572)) $) NIL) (((-121) $) NIL (|has| (-572) (-848)))) (-4131 (($ (-1 (-121) (-572) (-572)) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-572) (-848))))) (-3008 (($ (-1 (-121) (-572) (-572)) $) NIL) (($ $) NIL (|has| (-572) (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-572) $ (-572) (-572)) 15 (|has| $ (-6 -4603))) (((-572) $ (-1225 (-572)) (-572)) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-3445 (($ (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098)))) (($ (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-572) (-1 (-572) (-572) (-572)) $ (-572) (-572)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098)))) (((-572) (-1 (-572) (-572) (-572)) $ (-572)) NIL (|has| $ (-6 -4602))) (((-572) (-1 (-572) (-572) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-572) $ (-572) (-572)) 14 (|has| $ (-6 -4603)))) (-4212 (((-572) $ (-572)) 12)) (-4014 (((-572) (-1 (-121) (-572)) $) NIL) (((-572) (-572) $) NIL (|has| (-572) (-1098))) (((-572) (-572) $ (-572)) NIL (|has| (-572) (-1098)))) (-2010 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) (-572)) 11)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 9 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| (-572) (-848)))) (-4475 (($ (-1 (-121) (-572) (-572)) $ $) NIL) (($ $ $) NIL (|has| (-572) (-848)))) (-4467 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-572) (-848)))) (-2435 (($ (-1 (-572) (-572)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-572) (-572)) $) NIL) (($ (-1 (-572) (-572) (-572)) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| (-572) (-1098)))) (-2603 (($ (-572) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| (-572) (-1098)))) (-1837 (((-572) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-572) "failed") (-1 (-121) (-572)) $) NIL)) (-3299 (($ $ (-572)) 16 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-572)))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-290 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-572) (-572)) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-638 (-572)) (-638 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2957 (((-638 (-572)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 10)) (-3277 (((-572) $ (-572) (-572)) NIL) (((-572) $ (-572)) 13) (($ $ (-1225 (-572))) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602))) (((-769) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-572) (-613 (-545))))) (-3921 (($ (-638 (-572))) NIL)) (-4500 (($ $ (-572)) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| (-572) (-1098)))) (-3501 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1324 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-1343 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-572) (-848)))) (-4032 (((-769) $) 7 (|has| $ (-6 -4602))))) 
-(((-1208) (-19 (-572))) (T -1208)) 
-NIL 
-(-19 (-572)) 
-((-2262 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-4169 (($ (-769) (-769)) NIL)) (-2113 (($ $ $) NIL)) (-1444 (($ (-1210)) NIL) (($ $) NIL)) (-3083 (((-121) $) NIL)) (-3861 (($ $ (-572) (-572)) NIL)) (-3595 (($ $ (-572) (-572)) NIL)) (-4152 (($ $ (-572) (-572) (-572) (-572)) NIL)) (-4369 (($ $) NIL)) (-4044 (((-121) $) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2569 (($ $ (-572) (-572) $) NIL)) (-3283 (((-572) $ (-572) (-572) (-572)) 17) (($ $ (-638 (-572)) (-638 (-572)) $) NIL)) (-1823 (($ $ (-572) (-1210)) NIL)) (-1695 (($ $ (-572) (-1210)) NIL)) (-1468 (($ (-769) (-572)) NIL)) (-2211 (($) NIL T CONST)) (-3292 (($ $) NIL (|has| (-572) (-303)))) (-4267 (((-1210) $ (-572)) NIL)) (-2667 (((-769) $) NIL (|has| (-572) (-562)))) (-3037 (((-572) $ (-572) (-572) (-572)) 16)) (-3596 (($ (-572) (-572)) 19)) (-4212 (((-572) $ (-572) (-572)) 14)) (-4439 (((-572) $) NIL (|has| (-572) (-174)))) (-2010 (((-638 (-572)) $) NIL)) (-3095 (((-769) $) NIL (|has| (-572) (-562)))) (-1301 (((-638 (-1210)) $) NIL (|has| (-572) (-562)))) (-3704 (((-769) $) 10)) (-1364 (($ (-769) (-769) (-572)) 20)) (-3712 (((-769) $) 11)) (-2157 (((-121) $ (-769)) NIL)) (-1522 (((-572) $) NIL (|has| (-572) (-6 (-4604 "*"))))) (-2660 (((-572) $) 7)) (-3092 (((-572) $) 8)) (-4467 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-3927 (((-572) $) 12)) (-3227 (((-572) $) 13)) (-3597 (($ (-638 (-638 (-572)))) NIL) (($ (-769) (-769) (-1 (-572) (-572) (-572))) NIL)) (-2435 (($ (-1 (-572) (-572)) $) NIL)) (-3828 (($ (-1 (-572) (-572)) $) NIL) (($ (-1 (-572) (-572) (-572)) $ $) NIL) (($ (-1 (-572) (-572) (-572)) $ $ (-572)) NIL)) (-2259 (((-638 (-638 (-572))) $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| (-572) (-1098)))) (-3750 (((-3 $ "failed") $) NIL (|has| (-572) (-368)))) (-1865 (($ $ $) NIL)) (-2607 (((-1116) $) NIL (|has| (-572) (-1098)))) (-3299 (($ $ (-572)) NIL)) (-1803 (((-3 $ "failed") $ (-572)) NIL (|has| (-572) (-562)))) (-2109 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-572)))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-290 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-572) (-572)) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-638 (-572)) (-638 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 18)) (-3277 (((-572) $ (-572) (-572)) 15) (((-572) $ (-572) (-572) (-572)) NIL) (($ $ (-638 (-572)) (-638 (-572))) NIL)) (-3132 (($ (-638 (-572))) NIL) (($ (-638 $)) NIL)) (-3785 (((-121) $) NIL)) (-2271 (((-572) $) NIL (|has| (-572) (-6 (-4604 "*"))))) (-1571 (((-769) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602))) (((-769) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-1607 (($ $) NIL)) (-1802 (((-638 (-1210)) $) NIL (|has| (-572) (-303)))) (-4580 (((-1210) $ (-572)) NIL)) (-3972 (((-856) $) NIL (|has| (-572) (-1098))) (($ (-1210)) NIL)) (-3501 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3354 (((-121) $) NIL)) (-1324 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-1379 (($ $ (-572)) NIL (|has| (-572) (-368)))) (-1373 (($ $ $) NIL) (($ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| (-572) (-368)))) (* (($ $ $) NIL) (($ (-572) $) NIL) (($ $ (-572)) NIL) (($ (-572) $) NIL) (((-1210) $ (-1210)) NIL) (((-1210) (-1210) $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1209) (-13 (-683 (-572) (-1210) (-1210)) (-10 -8 (-15 -3596 ($ (-572) (-572)))))) (T -1209)) 
-((-3596 (*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1209))))) 
-(-13 (-683 (-572) (-1210) (-1210)) (-10 -8 (-15 -3596 ($ (-572) (-572))))) 
-((-2262 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) (-572) (-572)) $) NIL) (((-121) $) NIL (|has| (-572) (-848)))) (-4131 (($ (-1 (-121) (-572) (-572)) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| (-572) (-848))))) (-3008 (($ (-1 (-121) (-572) (-572)) $) NIL) (($ $) NIL (|has| (-572) (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 (((-572) $ (-572) (-572)) 15 (|has| $ (-6 -4603))) (((-572) $ (-1225 (-572)) (-572)) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-3445 (($ (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098)))) (($ (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3116 (((-572) (-1 (-572) (-572) (-572)) $ (-572) (-572)) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098)))) (((-572) (-1 (-572) (-572) (-572)) $ (-572)) NIL (|has| $ (-6 -4602))) (((-572) (-1 (-572) (-572) (-572)) $) NIL (|has| $ (-6 -4602)))) (-3037 (((-572) $ (-572) (-572)) 14 (|has| $ (-6 -4603)))) (-4212 (((-572) $ (-572)) 12)) (-4014 (((-572) (-1 (-121) (-572)) $) NIL) (((-572) (-572) $) NIL (|has| (-572) (-1098))) (((-572) (-572) $ (-572)) NIL (|has| (-572) (-1098)))) (-2010 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-1364 (($ (-769) (-572)) 11)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) 9 (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| (-572) (-848)))) (-4475 (($ (-1 (-121) (-572) (-572)) $ $) NIL) (($ $ $) NIL (|has| (-572) (-848)))) (-4467 (((-638 (-572)) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| (-572) (-848)))) (-2435 (($ (-1 (-572) (-572)) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 (-572) (-572)) $) NIL) (($ (-1 (-572) (-572) (-572)) $ $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL (|has| (-572) (-1098)))) (-2603 (($ (-572) $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| (-572) (-1098)))) (-1837 (((-572) $) NIL (|has| (-572) (-848)))) (-3361 (((-3 (-572) "failed") (-1 (-121) (-572)) $) NIL)) (-3299 (($ $ (-572)) 16 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 (-572)))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-290 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-572) (-572)) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098)))) (($ $ (-638 (-572)) (-638 (-572))) NIL (-12 (|has| (-572) (-305 (-572))) (|has| (-572) (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2957 (((-638 (-572)) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) 10)) (-3277 (((-572) $ (-572) (-572)) NIL) (((-572) $ (-572)) 13) (($ $ (-1225 (-572))) NIL)) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1571 (((-769) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602))) (((-769) (-572) $) NIL (-12 (|has| $ (-6 -4602)) (|has| (-572) (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| (-572) (-613 (-545))))) (-3921 (($ (-638 (-572))) NIL)) (-4500 (($ $ (-572)) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| (-572) (-1098)))) (-3501 (((-121) (-1 (-121) (-572)) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1338 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1324 (((-121) $ $) NIL (|has| (-572) (-1098)))) (-1343 (((-121) $ $) NIL (|has| (-572) (-848)))) (-1334 (((-121) $ $) NIL (|has| (-572) (-848)))) (-4032 (((-769) $) 7 (|has| $ (-6 -4602))))) 
-(((-1210) (-19 (-572))) (T -1210)) 
-NIL 
-(-19 (-572)) 
-((-4171 (((-121)) 14)) (-2583 (((-1264) (-638 |#1|) (-638 |#1|)) 18) (((-1264) (-638 |#1|)) 19)) (-2157 (((-121) |#1| |#1|) 30 (|has| |#1| (-848)))) (-3524 (((-121) |#1| |#1| (-1 (-121) |#1| |#1|)) 26) (((-3 (-121) "failed") |#1| |#1|) 24)) (-3519 ((|#1| (-638 |#1|)) 31 (|has| |#1| (-848))) ((|#1| (-638 |#1|) (-1 (-121) |#1| |#1|)) 27)) (-3489 (((-2 (|:| -2861 (-638 |#1|)) (|:| -4461 (-638 |#1|)))) 16))) 
-(((-1211 |#1|) (-10 -7 (-15 -2583 ((-1264) (-638 |#1|))) (-15 -2583 ((-1264) (-638 |#1|) (-638 |#1|))) (-15 -3489 ((-2 (|:| -2861 (-638 |#1|)) (|:| -4461 (-638 |#1|))))) (-15 -3524 ((-3 (-121) "failed") |#1| |#1|)) (-15 -3524 ((-121) |#1| |#1| (-1 (-121) |#1| |#1|))) (-15 -3519 (|#1| (-638 |#1|) (-1 (-121) |#1| |#1|))) (-15 -4171 ((-121))) (IF (|has| |#1| (-848)) (PROGN (-15 -3519 (|#1| (-638 |#1|))) (-15 -2157 ((-121) |#1| |#1|))) |noBranch|)) (-1098)) (T -1211)) 
-((-2157 (*1 *2 *3 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1211 *3)) (-4 *3 (-848)) (-4 *3 (-1098)))) (-3519 (*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-1098)) (-4 *2 (-848)) (-5 *1 (-1211 *2)))) (-4171 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1211 *3)) (-4 *3 (-1098)))) (-3519 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *2)) (-5 *4 (-1 (-121) *2 *2)) (-5 *1 (-1211 *2)) (-4 *2 (-1098)))) (-3524 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *3 (-1098)) (-5 *2 (-121)) (-5 *1 (-1211 *3)))) (-3524 (*1 *2 *3 *3) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-1211 *3)) (-4 *3 (-1098)))) (-3489 (*1 *2) (-12 (-5 *2 (-2 (|:| -2861 (-638 *3)) (|:| -4461 (-638 *3)))) (-5 *1 (-1211 *3)) (-4 *3 (-1098)))) (-2583 (*1 *2 *3 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1098)) (-5 *2 (-1264)) (-5 *1 (-1211 *4)))) (-2583 (*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1098)) (-5 *2 (-1264)) (-5 *1 (-1211 *4))))) 
-(-10 -7 (-15 -2583 ((-1264) (-638 |#1|))) (-15 -2583 ((-1264) (-638 |#1|) (-638 |#1|))) (-15 -3489 ((-2 (|:| -2861 (-638 |#1|)) (|:| -4461 (-638 |#1|))))) (-15 -3524 ((-3 (-121) "failed") |#1| |#1|)) (-15 -3524 ((-121) |#1| |#1| (-1 (-121) |#1| |#1|))) (-15 -3519 (|#1| (-638 |#1|) (-1 (-121) |#1| |#1|))) (-15 -4171 ((-121))) (IF (|has| |#1| (-848)) (PROGN (-15 -3519 (|#1| (-638 |#1|))) (-15 -2157 ((-121) |#1| |#1|))) |noBranch|)) 
-((-1924 (((-1264) (-638 (-1170)) (-638 (-1170))) 12) (((-1264) (-638 (-1170))) 10)) (-1296 (((-1264)) 13)) (-3842 (((-2 (|:| -4461 (-638 (-1170))) (|:| -2861 (-638 (-1170))))) 17))) 
-(((-1212) (-10 -7 (-15 -1924 ((-1264) (-638 (-1170)))) (-15 -1924 ((-1264) (-638 (-1170)) (-638 (-1170)))) (-15 -3842 ((-2 (|:| -4461 (-638 (-1170))) (|:| -2861 (-638 (-1170)))))) (-15 -1296 ((-1264))))) (T -1212)) 
-((-1296 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1212)))) (-3842 (*1 *2) (-12 (-5 *2 (-2 (|:| -4461 (-638 (-1170))) (|:| -2861 (-638 (-1170))))) (-5 *1 (-1212)))) (-1924 (*1 *2 *3 *3) (-12 (-5 *3 (-638 (-1170))) (-5 *2 (-1264)) (-5 *1 (-1212)))) (-1924 (*1 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-5 *2 (-1264)) (-5 *1 (-1212))))) 
-(-10 -7 (-15 -1924 ((-1264) (-638 (-1170)))) (-15 -1924 ((-1264) (-638 (-1170)) (-638 (-1170)))) (-15 -3842 ((-2 (|:| -4461 (-638 (-1170))) (|:| -2861 (-638 (-1170)))))) (-15 -1296 ((-1264)))) 
-((-2844 (($ $) 16)) (-1526 (((-121) $) 23))) 
-(((-1213 |#1|) (-10 -8 (-15 -2844 (|#1| |#1|)) (-15 -1526 ((-121) |#1|))) (-1214)) (T -1213)) 
-NIL 
-(-10 -8 (-15 -2844 (|#1| |#1|)) (-15 -1526 ((-121) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 49)) (-1466 (((-424 $) $) 50)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-1526 (((-121) $) 51)) (-3893 (((-121) $) 30)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-4304 (((-424 $) $) 48)) (-1803 (((-3 $ "failed") $ $) 41)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42)) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23))) 
-(((-1214) (-1290)) (T -1214)) 
-((-1526 (*1 *2 *1) (-12 (-4 *1 (-1214)) (-5 *2 (-121)))) (-1466 (*1 *2 *1) (-12 (-5 *2 (-424 *1)) (-4 *1 (-1214)))) (-2844 (*1 *1 *1) (-4 *1 (-1214))) (-4304 (*1 *2 *1) (-12 (-5 *2 (-424 *1)) (-4 *1 (-1214))))) 
-(-13 (-457) (-10 -8 (-15 -1526 ((-121) $)) (-15 -1466 ((-424 $) $)) (-15 -2844 ($ $)) (-15 -4304 ((-424 $) $)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-138) . T) ((-612 (-856)) . T) ((-174) . T) ((-287) . T) ((-457) . T) ((-562) . T) ((-641 $) . T) ((-713 $) . T) ((-722) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-1783 (((-1216 |#1|) (-1216 |#1|) (-1216 |#1|)) 15))) 
-(((-1215 |#1|) (-10 -7 (-15 -1783 ((-1216 |#1|) (-1216 |#1|) (-1216 |#1|)))) (-1054)) (T -1215)) 
-((-1783 (*1 *2 *2 *2) (-12 (-5 *2 (-1216 *3)) (-4 *3 (-1054)) (-5 *1 (-1215 *3))))) 
-(-10 -7 (-15 -1783 ((-1216 |#1|) (-1216 |#1|) (-1216 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) NIL)) (-2970 (((-1231 (QUOTE |x|) |#1|) $ (-769)) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-769)) NIL) (($ $ (-769) (-769)) NIL)) (-2640 (((-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|))) $) NIL)) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|)))) NIL) (($ (-1150 |#1|)) NIL)) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3851 (($ $) NIL)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2531 (($ $) NIL)) (-1896 (((-959 |#1|) $ (-769)) NIL) (((-959 |#1|) $ (-769) (-769)) NIL)) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-769) $) NIL) (((-769) $ (-769)) NIL)) (-3893 (((-121) $) NIL)) (-1973 (($ $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3628 (($ (-572) (-572) $) NIL)) (-3965 (($ $ (-923)) NIL)) (-4324 (($ (-1 |#1| (-572)) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-3358 (($ $) NIL)) (-2606 (($ $) NIL)) (-3959 (($ (-572) (-572) $) NIL)) (-2774 (($ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 (QUOTE |x|))) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-3130 (($ $ (-572) (-572)) NIL)) (-1977 (($ $ (-769)) NIL)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2827 (($ $) NIL)) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-769)))))) (-3277 ((|#1| $ (-769)) NIL) (($ $ $) NIL (|has| (-769) (-1110)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $ (-1255 (QUOTE |x|))) NIL)) (-4316 (((-769) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562))) (($ |#1|) NIL (|has| |#1| (-174))) (($ (-1231 (QUOTE |x|) |#1|)) NIL) (($ (-1255 (QUOTE |x|))) NIL)) (-3193 (((-1150 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) NIL)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) NIL)) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-769)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-769)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) NIL T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1216 |#1|) (-13 (-1249 |#1|) (-10 -8 (-15 -3972 ($ (-1231 (QUOTE |x|) |#1|))) (-15 -2970 ((-1231 (QUOTE |x|) |#1|) $ (-769))) (-15 -3972 ($ (-1255 (QUOTE |x|)))) (-15 -3139 ($ $ (-1255 (QUOTE |x|)))) (-15 -2606 ($ $)) (-15 -3358 ($ $)) (-15 -1973 ($ $)) (-15 -2827 ($ $)) (-15 -3130 ($ $ (-572) (-572))) (-15 -3851 ($ $)) (-15 -3628 ($ (-572) (-572) $)) (-15 -3959 ($ (-572) (-572) $)) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 (QUOTE |x|)))) |noBranch|))) (-1054)) (T -1216)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1231 (QUOTE |x|) *3)) (-4 *3 (-1054)) (-5 *1 (-1216 *3)))) (-2970 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1231 (QUOTE |x|) *4)) (-5 *1 (-1216 *4)) (-4 *4 (-1054)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 (QUOTE |x|))) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 (QUOTE |x|))) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) (-2606 (*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) (-3358 (*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) (-1973 (*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) (-2827 (*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) (-3130 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) (-3851 (*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) (-3628 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) (-3959 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 (QUOTE |x|))) (-5 *1 (-1216 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054))))) 
-(-13 (-1249 |#1|) (-10 -8 (-15 -3972 ($ (-1231 (QUOTE |x|) |#1|))) (-15 -2970 ((-1231 (QUOTE |x|) |#1|) $ (-769))) (-15 -3972 ($ (-1255 (QUOTE |x|)))) (-15 -3139 ($ $ (-1255 (QUOTE |x|)))) (-15 -2606 ($ $)) (-15 -3358 ($ $)) (-15 -1973 ($ $)) (-15 -2827 ($ $)) (-15 -3130 ($ $ (-572) (-572))) (-15 -3851 ($ $)) (-15 -3628 ($ (-572) (-572) $)) (-15 -3959 ($ (-572) (-572) $)) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 (QUOTE |x|)))) |noBranch|))) 
-((-3828 (((-1222 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1222 |#1| |#3| |#5|)) 23))) 
-(((-1217 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -3828 ((-1222 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1222 |#1| |#3| |#5|)))) (-1054) (-1054) (-1170) (-1170) |#1| |#2|) (T -1217)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1222 *5 *7 *9)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-14 *7 (-1170)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1222 *6 *8 *10)) (-5 *1 (-1217 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1170))))) 
-(-10 -7 (-15 -3828 ((-1222 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1222 |#1| |#3| |#5|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 (-1082)) $) 70)) (-3342 (((-1170) $) 98)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-2525 (($ $ (-572)) 93) (($ $ (-572) (-572)) 92)) (-2640 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) 100)) (-4284 (($ $) 127 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 110 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 154 (|has| |#1| (-368)))) (-1466 (((-424 $) $) 155 (|has| |#1| (-368)))) (-4190 (($ $) 109 (|has| |#1| (-43 (-413 (-572)))))) (-3112 (((-121) $ $) 145 (|has| |#1| (-368)))) (-4273 (($ $) 126 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 111 (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) 166)) (-4295 (($ $) 125 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 112 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) 16 T CONST)) (-2190 (($ $ $) 149 (|has| |#1| (-368)))) (-4383 (($ $) 59)) (-1799 (((-3 $ "failed") $) 33)) (-2059 (((-413 (-959 |#1|)) $ (-572)) 164 (|has| |#1| (-562))) (((-413 (-959 |#1|)) $ (-572) (-572)) 163 (|has| |#1| (-562)))) (-2208 (($ $ $) 148 (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 143 (|has| |#1| (-368)))) (-1526 (((-121) $) 156 (|has| |#1| (-368)))) (-1347 (((-121) $) 69)) (-4184 (($) 137 (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-572) $) 95) (((-572) $ (-572)) 94)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 108 (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) 96)) (-4324 (($ (-1 |#1| (-572)) $) 165)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 152 (|has| |#1| (-368)))) (-4581 (((-121) $) 61)) (-4328 (($ |#1| (-572)) 60) (($ $ (-1082) (-572)) 72) (($ $ (-638 (-1082)) (-638 (-572))) 71)) (-3828 (($ (-1 |#1| |#1|) $) 62)) (-3539 (($ $) 134 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1629 (($ (-638 $)) 141 (|has| |#1| (-368))) (($ $ $) 140 (|has| |#1| (-368)))) (-1658 (((-1152) $) 9)) (-4350 (($ $) 157 (|has| |#1| (-368)))) (-2774 (($ $) 162 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 161 (-1841 (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-966)) (|has| |#1| (-1190)) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-43 (-413 (-572)))))))) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 142 (|has| |#1| (-368)))) (-3069 (($ (-638 $)) 139 (|has| |#1| (-368))) (($ $ $) 138 (|has| |#1| (-368)))) (-4304 (((-424 $) $) 153 (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 150 (|has| |#1| (-368)))) (-1977 (($ $ (-572)) 90)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 144 (|has| |#1| (-368)))) (-4179 (($ $) 135 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-572)))))) (-4029 (((-769) $) 146 (|has| |#1| (-368)))) (-3277 ((|#1| $ (-572)) 99) (($ $ $) 76 (|has| (-572) (-1110)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 147 (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) 84 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-1170) (-769)) 83 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170))) 82 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-1170)) 81 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-769)) 79 (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (-4316 (((-572) $) 63)) (-4302 (($ $) 124 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 113 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 123 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 114 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 122 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 115 (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 68)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 46 (|has| |#1| (-174))) (($ (-413 (-572))) 56 (|has| |#1| (-43 (-413 (-572))))) (($ $) 48 (|has| |#1| (-562)))) (-1958 ((|#1| $ (-572)) 58)) (-2779 (((-3 $ "failed") $) 47 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-1694 ((|#1| $) 97)) (-4321 (($ $) 133 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 121 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-4308 (($ $) 132 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 120 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 131 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 119 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-572)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-572)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 130 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 118 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 129 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 117 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 128 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 116 (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 158 (|has| |#1| (-368)))) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) 88 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-1170) (-769)) 87 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170))) 86 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-1170)) 85 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-769)) 80 (|has| |#1| (-15 * (|#1| (-572) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368))) (($ $ $) 160 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 159 (|has| |#1| (-368))) (($ $ $) 136 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 107 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1218 |#1|) (-1290) (-1054)) (T -1218)) 
-((-4521 (*1 *1 *2) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))) (-4 *3 (-1054)) (-4 *1 (-1218 *3)))) (-4324 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-572))) (-4 *1 (-1218 *3)) (-4 *3 (-1054)))) (-2059 (*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1218 *4)) (-4 *4 (-1054)) (-4 *4 (-562)) (-5 *2 (-413 (-959 *4))))) (-2059 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1218 *4)) (-4 *4 (-1054)) (-4 *4 (-562)) (-5 *2 (-413 (-959 *4))))) (-2774 (*1 *1 *1) (-12 (-4 *1 (-1218 *2)) (-4 *2 (-1054)) (-4 *2 (-43 (-413 (-572)))))) (-2774 (*1 *1 *1 *2) (-1841 (-12 (-5 *2 (-1170)) (-4 *1 (-1218 *3)) (-4 *3 (-1054)) (-12 (-4 *3 (-29 (-572))) (-4 *3 (-966)) (-4 *3 (-1190)) (-4 *3 (-43 (-413 (-572)))))) (-12 (-5 *2 (-1170)) (-4 *1 (-1218 *3)) (-4 *3 (-1054)) (-12 (|has| *3 (-15 -3456 ((-638 *2) *3))) (|has| *3 (-15 -2774 (*3 *3 *2))) (-4 *3 (-43 (-413 (-572))))))))) 
-(-13 (-1236 |t#1| (-572)) (-10 -8 (-15 -4521 ($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |t#1|))))) (-15 -4324 ($ (-1 |t#1| (-572)) $)) (IF (|has| |t#1| (-562)) (PROGN (-15 -2059 ((-413 (-959 |t#1|)) $ (-572))) (-15 -2059 ((-413 (-959 |t#1|)) $ (-572) (-572)))) |noBranch|) (IF (|has| |t#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $)) (IF (|has| |t#1| (-15 -2774 (|t#1| |t#1| (-1170)))) (IF (|has| |t#1| (-15 -3456 ((-638 (-1170)) |t#1|))) (-15 -2774 ($ $ (-1170))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1190)) (IF (|has| |t#1| (-966)) (IF (|has| |t#1| (-29 (-572))) (-15 -2774 ($ $ (-1170))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1009)) (-6 (-1190))) |noBranch|) (IF (|has| |t#1| (-368)) (-6 (-368)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-572)) . T) ((-25) . T) ((-43 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-40) |has| |#1| (-43 (-413 (-572)))) ((-98) |has| |#1| (-43 (-413 (-572)))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-227) |has| |#1| (-15 * (|#1| (-572) |#1|))) ((-240) |has| |#1| (-368)) ((-281) |has| |#1| (-43 (-413 (-572)))) ((-283 $ $) |has| (-572) (-1110)) ((-287) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-303) |has| |#1| (-368)) ((-368) |has| |#1| (-368)) ((-457) |has| |#1| (-368)) ((-506) |has| |#1| (-43 (-413 (-572)))) ((-562) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-641 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-722) . T) ((-901 (-1170)) -12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))) ((-981 |#1| (-572) (-1082)) . T) ((-922) |has| |#1| (-368)) ((-1009) |has| |#1| (-43 (-413 (-572)))) ((-1060 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1190) |has| |#1| (-43 (-413 (-572)))) ((-1193) |has| |#1| (-43 (-413 (-572)))) ((-1214) |has| |#1| (-368)) ((-1236 |#1| (-572)) . T)) 
-((-1342 (((-121) $) 12)) (-3376 (((-3 |#3| "failed") $) 17) (((-3 (-1170) "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 (-572) "failed") $) NIL)) (-1318 ((|#3| $) 14) (((-1170) $) NIL) (((-413 (-572)) $) NIL) (((-572) $) NIL))) 
-(((-1219 |#1| |#2| |#3|) (-10 -8 (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-1170) |#1|)) (-15 -3376 ((-3 (-1170) "failed") |#1|)) (-15 -1318 (|#3| |#1|)) (-15 -3376 ((-3 |#3| "failed") |#1|)) (-15 -1342 ((-121) |#1|))) (-1220 |#2| |#3|) (-1054) (-1249 |#2|)) (T -1219)) 
-NIL 
-(-10 -8 (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -1318 ((-1170) |#1|)) (-15 -3376 ((-3 (-1170) "failed") |#1|)) (-15 -1318 (|#3| |#1|)) (-15 -3376 ((-3 |#3| "failed") |#1|)) (-15 -1342 ((-121) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2551 ((|#2| $) 219 (-4028 (|has| |#2| (-303)) (|has| |#1| (-368))))) (-3456 (((-638 (-1082)) $) 70)) (-3342 (((-1170) $) 98)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-2525 (($ $ (-572)) 93) (($ $ (-572) (-572)) 92)) (-2640 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) 100)) (-2118 ((|#2| $) 255)) (-4272 (((-3 |#2| "failed") $) 251)) (-1881 ((|#2| $) 252)) (-4284 (($ $) 127 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 110 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) 18)) (-4073 (((-424 (-1166 $)) (-1166 $)) 228 (-4028 (|has| |#2| (-910)) (|has| |#1| (-368))))) (-2844 (($ $) 154 (|has| |#1| (-368)))) (-1466 (((-424 $) $) 155 (|has| |#1| (-368)))) (-4190 (($ $) 109 (|has| |#1| (-43 (-413 (-572)))))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 225 (-4028 (|has| |#2| (-910)) (|has| |#1| (-368))))) (-3112 (((-121) $ $) 145 (|has| |#1| (-368)))) (-4273 (($ $) 126 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 111 (|has| |#1| (-43 (-413 (-572)))))) (-2433 (((-572) $) 237 (-4028 (|has| |#2| (-821)) (|has| |#1| (-368))))) (-4521 (($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) 166)) (-4295 (($ $) 125 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 112 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#2| "failed") $) 258) (((-3 (-572) "failed") $) 247 (-4028 (|has| |#2| (-1044 (-572))) (|has| |#1| (-368)))) (((-3 (-413 (-572)) "failed") $) 245 (-4028 (|has| |#2| (-1044 (-572))) (|has| |#1| (-368)))) (((-3 (-1170) "failed") $) 230 (-4028 (|has| |#2| (-1044 (-1170))) (|has| |#1| (-368))))) (-1318 ((|#2| $) 257) (((-572) $) 248 (-4028 (|has| |#2| (-1044 (-572))) (|has| |#1| (-368)))) (((-413 (-572)) $) 246 (-4028 (|has| |#2| (-1044 (-572))) (|has| |#1| (-368)))) (((-1170) $) 231 (-4028 (|has| |#2| (-1044 (-1170))) (|has| |#1| (-368))))) (-3729 (($ $) 254) (($ (-572) $) 253)) (-2190 (($ $ $) 149 (|has| |#1| (-368)))) (-4383 (($ $) 59)) (-2284 (((-685 |#2|) (-685 $)) 209 (|has| |#1| (-368))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) 208 (|has| |#1| (-368))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 207 (-4028 (|has| |#2| (-634 (-572))) (|has| |#1| (-368)))) (((-685 (-572)) (-685 $)) 206 (-4028 (|has| |#2| (-634 (-572))) (|has| |#1| (-368))))) (-1799 (((-3 $ "failed") $) 33)) (-2059 (((-413 (-959 |#1|)) $ (-572)) 164 (|has| |#1| (-562))) (((-413 (-959 |#1|)) $ (-572) (-572)) 163 (|has| |#1| (-562)))) (-3286 (($) 221 (-4028 (|has| |#2| (-554)) (|has| |#1| (-368))))) (-2208 (($ $ $) 148 (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 143 (|has| |#1| (-368)))) (-1526 (((-121) $) 156 (|has| |#1| (-368)))) (-1908 (((-121) $) 235 (-4028 (|has| |#2| (-821)) (|has| |#1| (-368))))) (-1347 (((-121) $) 69)) (-4184 (($) 137 (|has| |#1| (-43 (-413 (-572)))))) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 213 (-4028 (|has| |#2| (-887 (-385))) (|has| |#1| (-368)))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 212 (-4028 (|has| |#2| (-887 (-572))) (|has| |#1| (-368))))) (-3377 (((-572) $) 95) (((-572) $ (-572)) 94)) (-3893 (((-121) $) 30)) (-4347 (($ $) 217 (|has| |#1| (-368)))) (-4487 ((|#2| $) 215 (|has| |#1| (-368)))) (-1451 (($ $ (-572)) 108 (|has| |#1| (-43 (-413 (-572)))))) (-3961 (((-3 $ "failed") $) 249 (-4028 (|has| |#2| (-1144)) (|has| |#1| (-368))))) (-4472 (((-121) $) 236 (-4028 (|has| |#2| (-821)) (|has| |#1| (-368))))) (-3965 (($ $ (-923)) 96)) (-4324 (($ (-1 |#1| (-572)) $) 165)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 152 (|has| |#1| (-368)))) (-4581 (((-121) $) 61)) (-4328 (($ |#1| (-572)) 60) (($ $ (-1082) (-572)) 72) (($ $ (-638 (-1082)) (-638 (-572))) 71)) (-1771 (($ $ $) 239 (-4028 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-4238 (($ $ $) 240 (-4028 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-3828 (($ (-1 |#1| |#1|) $) 62) (($ (-1 |#2| |#2|) $) 201 (|has| |#1| (-368)))) (-3539 (($ $) 134 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1629 (($ (-638 $)) 141 (|has| |#1| (-368))) (($ $ $) 140 (|has| |#1| (-368)))) (-1885 (($ (-572) |#2|) 256)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 157 (|has| |#1| (-368)))) (-2774 (($ $) 162 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 161 (-1841 (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-966)) (|has| |#1| (-1190)) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-43 (-413 (-572)))))))) (-1773 (($) 250 (-4028 (|has| |#2| (-1144)) (|has| |#1| (-368))) CONST)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 142 (|has| |#1| (-368)))) (-3069 (($ (-638 $)) 139 (|has| |#1| (-368))) (($ $ $) 138 (|has| |#1| (-368)))) (-3346 (($ $) 220 (-4028 (|has| |#2| (-303)) (|has| |#1| (-368))))) (-1716 ((|#2| $) 223 (-4028 (|has| |#2| (-554)) (|has| |#1| (-368))))) (-4364 (((-424 (-1166 $)) (-1166 $)) 226 (-4028 (|has| |#2| (-910)) (|has| |#1| (-368))))) (-3992 (((-424 (-1166 $)) (-1166 $)) 227 (-4028 (|has| |#2| (-910)) (|has| |#1| (-368))))) (-4304 (((-424 $) $) 153 (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 150 (|has| |#1| (-368)))) (-1977 (($ $ (-572)) 90)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 144 (|has| |#1| (-368)))) (-4179 (($ $) 135 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-572))))) (($ $ (-1170) |#2|) 200 (-4028 (|has| |#2| (-527 (-1170) |#2|)) (|has| |#1| (-368)))) (($ $ (-638 (-1170)) (-638 |#2|)) 199 (-4028 (|has| |#2| (-527 (-1170) |#2|)) (|has| |#1| (-368)))) (($ $ (-638 (-290 |#2|))) 198 (-4028 (|has| |#2| (-305 |#2|)) (|has| |#1| (-368)))) (($ $ (-290 |#2|)) 197 (-4028 (|has| |#2| (-305 |#2|)) (|has| |#1| (-368)))) (($ $ |#2| |#2|) 196 (-4028 (|has| |#2| (-305 |#2|)) (|has| |#1| (-368)))) (($ $ (-638 |#2|) (-638 |#2|)) 195 (-4028 (|has| |#2| (-305 |#2|)) (|has| |#1| (-368))))) (-4029 (((-769) $) 146 (|has| |#1| (-368)))) (-3277 ((|#1| $ (-572)) 99) (($ $ $) 76 (|has| (-572) (-1110))) (($ $ |#2|) 194 (-4028 (|has| |#2| (-283 |#2| |#2|)) (|has| |#1| (-368))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 147 (|has| |#1| (-368)))) (-3139 (($ $ (-1 |#2| |#2|)) 205 (|has| |#1| (-368))) (($ $ (-1 |#2| |#2|) (-769)) 204 (|has| |#1| (-368))) (($ $ (-769)) 79 (-1841 (-4028 (|has| |#2| (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $) 77 (-1841 (-4028 (|has| |#2| (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) 84 (-1841 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))))) (($ $ (-1170) (-769)) 83 (-1841 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))))) (($ $ (-638 (-1170))) 82 (-1841 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))))) (($ $ (-1170)) 81 (-1841 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))))) (-3425 (($ $) 218 (|has| |#1| (-368)))) (-4492 ((|#2| $) 216 (|has| |#1| (-368)))) (-4316 (((-572) $) 63)) (-4302 (($ $) 124 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 113 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 123 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 114 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 122 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 115 (|has| |#1| (-43 (-413 (-572)))))) (-4081 (((-217) $) 234 (-4028 (|has| |#2| (-1028)) (|has| |#1| (-368)))) (((-385) $) 233 (-4028 (|has| |#2| (-1028)) (|has| |#1| (-368)))) (((-545) $) 232 (-4028 (|has| |#2| (-613 (-545))) (|has| |#1| (-368)))) (((-893 (-385)) $) 211 (-4028 (|has| |#2| (-613 (-893 (-385)))) (|has| |#1| (-368)))) (((-893 (-572)) $) 210 (-4028 (|has| |#2| (-613 (-893 (-572)))) (|has| |#1| (-368))))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 224 (-4028 (-4028 (|has| $ (-149)) (|has| |#2| (-910))) (|has| |#1| (-368))))) (-2424 (($ $) 68)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 46 (|has| |#1| (-174))) (($ |#2|) 259) (($ (-1170)) 229 (-4028 (|has| |#2| (-1044 (-1170))) (|has| |#1| (-368)))) (($ (-413 (-572))) 56 (|has| |#1| (-43 (-413 (-572))))) (($ $) 48 (|has| |#1| (-562)))) (-1958 ((|#1| $ (-572)) 58)) (-2779 (((-3 $ "failed") $) 47 (-1841 (-4028 (-1841 (|has| |#2| (-149)) (-4028 (|has| $ (-149)) (|has| |#2| (-910)))) (|has| |#1| (-368))) (|has| |#1| (-149))))) (-2140 (((-769)) 28)) (-1694 ((|#1| $) 97)) (-2634 ((|#2| $) 222 (-4028 (|has| |#2| (-554)) (|has| |#1| (-368))))) (-4321 (($ $) 133 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 121 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-4308 (($ $) 132 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 120 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 131 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 119 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-572)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-572)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 130 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 118 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 129 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 117 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 128 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 116 (|has| |#1| (-43 (-413 (-572)))))) (-2264 (($ $) 238 (-4028 (|has| |#2| (-821)) (|has| |#1| (-368))))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 158 (|has| |#1| (-368)))) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-1 |#2| |#2|)) 203 (|has| |#1| (-368))) (($ $ (-1 |#2| |#2|) (-769)) 202 (|has| |#1| (-368))) (($ $ (-769)) 80 (-1841 (-4028 (|has| |#2| (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $) 78 (-1841 (-4028 (|has| |#2| (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) 88 (-1841 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))))) (($ $ (-1170) (-769)) 87 (-1841 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))))) (($ $ (-638 (-1170))) 86 (-1841 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))))) (($ $ (-1170)) 85 (-1841 (-4028 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))))) (-1349 (((-121) $ $) 242 (-4028 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-1338 (((-121) $ $) 243 (-4028 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 241 (-4028 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-1334 (((-121) $ $) 244 (-4028 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368))) (($ $ $) 160 (|has| |#1| (-368))) (($ |#2| |#2|) 214 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 159 (|has| |#1| (-368))) (($ $ $) 136 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 107 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ $ |#2|) 193 (|has| |#1| (-368))) (($ |#2| $) 192 (|has| |#1| (-368))) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1220 |#1| |#2|) (-1290) (-1054) (-1249 |t#1|)) (T -1220)) 
-((-4316 (*1 *2 *1) (-12 (-4 *1 (-1220 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1249 *3)) (-5 *2 (-572)))) (-3972 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *1 (-1220 *3 *2)) (-4 *2 (-1249 *3)))) (-1885 (*1 *1 *2 *3) (-12 (-5 *2 (-572)) (-4 *4 (-1054)) (-4 *1 (-1220 *4 *3)) (-4 *3 (-1249 *4)))) (-2118 (*1 *2 *1) (-12 (-4 *1 (-1220 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1249 *3)))) (-3729 (*1 *1 *1) (-12 (-4 *1 (-1220 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-1249 *2)))) (-3729 (*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-1220 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1249 *3)))) (-1881 (*1 *2 *1) (-12 (-4 *1 (-1220 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1249 *3)))) (-4272 (*1 *2 *1) (|partial| -12 (-4 *1 (-1220 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1249 *3))))) 
-(-13 (-1218 |t#1|) (-1044 |t#2|) (-10 -8 (-15 -1885 ($ (-572) |t#2|)) (-15 -4316 ((-572) $)) (-15 -2118 (|t#2| $)) (-15 -3729 ($ $)) (-15 -3729 ($ (-572) $)) (-15 -3972 ($ |t#2|)) (-15 -1881 (|t#2| $)) (-15 -4272 ((-3 |t#2| "failed") $)) (IF (|has| |t#1| (-368)) (-6 (-1000 |t#2|)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-572)) . T) ((-25) . T) ((-43 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-43 |#1|) |has| |#1| (-174)) ((-43 |#2|) |has| |#1| (-368)) ((-43 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-40) |has| |#1| (-43 (-413 (-572)))) ((-98) |has| |#1| (-43 (-413 (-572)))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-120 |#1| |#1|) . T) ((-120 |#2| |#2|) |has| |#1| (-368)) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-138) . T) ((-149) -1841 (-12 (|has| |#1| (-368)) (|has| |#2| (-149))) (|has| |#1| (-149))) ((-151) -1841 (-12 (|has| |#1| (-368)) (|has| |#2| (-151))) (|has| |#1| (-151))) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-613 (-217)) -12 (|has| |#1| (-368)) (|has| |#2| (-1028))) ((-613 (-385)) -12 (|has| |#1| (-368)) (|has| |#2| (-1028))) ((-613 (-545)) -12 (|has| |#1| (-368)) (|has| |#2| (-613 (-545)))) ((-613 (-893 (-385))) -12 (|has| |#1| (-368)) (|has| |#2| (-613 (-893 (-385))))) ((-613 (-893 (-572))) -12 (|has| |#1| (-368)) (|has| |#2| (-613 (-893 (-572))))) ((-225 |#2|) |has| |#1| (-368)) ((-227) -1841 (-12 (|has| |#1| (-368)) (|has| |#2| (-227))) (|has| |#1| (-15 * (|#1| (-572) |#1|)))) ((-240) |has| |#1| (-368)) ((-281) |has| |#1| (-43 (-413 (-572)))) ((-283 |#2| $) -12 (|has| |#1| (-368)) (|has| |#2| (-283 |#2| |#2|))) ((-283 $ $) |has| (-572) (-1110)) ((-287) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-303) |has| |#1| (-368)) ((-305 |#2|) -12 (|has| |#1| (-368)) (|has| |#2| (-305 |#2|))) ((-368) |has| |#1| (-368)) ((-338 |#2|) |has| |#1| (-368)) ((-383 |#2|) |has| |#1| (-368)) ((-406 |#2|) |has| |#1| (-368)) ((-457) |has| |#1| (-368)) ((-506) |has| |#1| (-43 (-413 (-572)))) ((-527 (-1170) |#2|) -12 (|has| |#1| (-368)) (|has| |#2| (-527 (-1170) |#2|))) ((-527 |#2| |#2|) -12 (|has| |#1| (-368)) (|has| |#2| (-305 |#2|))) ((-562) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-641 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-641 |#1|) . T) ((-641 |#2|) |has| |#1| (-368)) ((-641 $) . T) ((-634 (-572)) -12 (|has| |#1| (-368)) (|has| |#2| (-634 (-572)))) ((-634 |#2|) |has| |#1| (-368)) ((-713 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-713 |#1|) |has| |#1| (-174)) ((-713 |#2|) |has| |#1| (-368)) ((-713 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-722) . T) ((-792) -12 (|has| |#1| (-368)) (|has| |#2| (-821))) ((-793) -12 (|has| |#1| (-368)) (|has| |#2| (-821))) ((-795) -12 (|has| |#1| (-368)) (|has| |#2| (-821))) ((-796) -12 (|has| |#1| (-368)) (|has| |#2| (-821))) ((-821) -12 (|has| |#1| (-368)) (|has| |#2| (-821))) ((-846) -12 (|has| |#1| (-368)) (|has| |#2| (-821))) ((-848) -1841 (-12 (|has| |#1| (-368)) (|has| |#2| (-848))) (-12 (|has| |#1| (-368)) (|has| |#2| (-821)))) ((-901 (-1170)) -1841 (-12 (|has| |#1| (-368)) (|has| |#2| (-901 (-1170)))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))) ((-887 (-385)) -12 (|has| |#1| (-368)) (|has| |#2| (-887 (-385)))) ((-887 (-572)) -12 (|has| |#1| (-368)) (|has| |#2| (-887 (-572)))) ((-885 |#2|) |has| |#1| (-368)) ((-910) -12 (|has| |#1| (-368)) (|has| |#2| (-910))) ((-981 |#1| (-572) (-1082)) . T) ((-922) |has| |#1| (-368)) ((-1000 |#2|) |has| |#1| (-368)) ((-1009) |has| |#1| (-43 (-413 (-572)))) ((-1028) -12 (|has| |#1| (-368)) (|has| |#2| (-1028))) ((-1044 (-413 (-572))) -12 (|has| |#1| (-368)) (|has| |#2| (-1044 (-572)))) ((-1044 (-572)) -12 (|has| |#1| (-368)) (|has| |#2| (-1044 (-572)))) ((-1044 (-1170)) -12 (|has| |#1| (-368)) (|has| |#2| (-1044 (-1170)))) ((-1044 |#2|) . T) ((-1060 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-1060 |#1|) . T) ((-1060 |#2|) |has| |#1| (-368)) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) -12 (|has| |#1| (-368)) (|has| |#2| (-1144))) ((-1190) |has| |#1| (-43 (-413 (-572)))) ((-1193) |has| |#1| (-43 (-413 (-572)))) ((-1204) |has| |#1| (-368)) ((-1214) |has| |#1| (-368)) ((-1218 |#1|) . T) ((-1236 |#1| (-572)) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 70)) (-2551 ((|#2| $) NIL (-12 (|has| |#2| (-303)) (|has| |#1| (-368))))) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 88)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-572)) 97) (($ $ (-572) (-572)) 99)) (-2640 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) 47)) (-2118 ((|#2| $) 11)) (-4272 (((-3 |#2| "failed") $) 30)) (-1881 ((|#2| $) 31)) (-4284 (($ $) 192 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 168 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| |#2| (-910)) (|has| |#1| (-368))))) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (-12 (|has| |#2| (-910)) (|has| |#1| (-368))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) 188 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 164 (|has| |#1| (-43 (-413 (-572)))))) (-2433 (((-572) $) NIL (-12 (|has| |#2| (-821)) (|has| |#1| (-368))))) (-4521 (($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) 57)) (-4295 (($ $) 196 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 172 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) 144) (((-3 (-572) "failed") $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#1| (-368)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#1| (-368)))) (((-3 (-1170) "failed") $) NIL (-12 (|has| |#2| (-1044 (-1170))) (|has| |#1| (-368))))) (-1318 ((|#2| $) 143) (((-572) $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#1| (-368)))) (((-413 (-572)) $) NIL (-12 (|has| |#2| (-1044 (-572))) (|has| |#1| (-368)))) (((-1170) $) NIL (-12 (|has| |#2| (-1044 (-1170))) (|has| |#1| (-368))))) (-3729 (($ $) 61) (($ (-572) $) 24)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-2284 (((-685 |#2|) (-685 $)) NIL (|has| |#1| (-368))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL (|has| |#1| (-368))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#1| (-368)))) (((-685 (-572)) (-685 $)) NIL (-12 (|has| |#2| (-634 (-572))) (|has| |#1| (-368))))) (-1799 (((-3 $ "failed") $) 77)) (-2059 (((-413 (-959 |#1|)) $ (-572)) 112 (|has| |#1| (-562))) (((-413 (-959 |#1|)) $ (-572) (-572)) 114 (|has| |#1| (-562)))) (-3286 (($) NIL (-12 (|has| |#2| (-554)) (|has| |#1| (-368))))) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-1908 (((-121) $) NIL (-12 (|has| |#2| (-821)) (|has| |#1| (-368))))) (-1347 (((-121) $) 64)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| |#2| (-887 (-385))) (|has| |#1| (-368)))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| |#2| (-887 (-572))) (|has| |#1| (-368))))) (-3377 (((-572) $) 93) (((-572) $ (-572)) 95)) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL (|has| |#1| (-368)))) (-4487 ((|#2| $) 151 (|has| |#1| (-368)))) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3961 (((-3 $ "failed") $) NIL (-12 (|has| |#2| (-1144)) (|has| |#1| (-368))))) (-4472 (((-121) $) NIL (-12 (|has| |#2| (-821)) (|has| |#1| (-368))))) (-3965 (($ $ (-923)) 136)) (-4324 (($ (-1 |#1| (-572)) $) 132)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-572)) 19) (($ $ (-1082) (-572)) NIL) (($ $ (-638 (-1082)) (-638 (-572))) NIL)) (-1771 (($ $ $) NIL (-12 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-4238 (($ $ $) NIL (-12 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-3828 (($ (-1 |#1| |#1|) $) 129) (($ (-1 |#2| |#2|) $) NIL (|has| |#1| (-368)))) (-3539 (($ $) 162 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1885 (($ (-572) |#2|) 10)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 145 (|has| |#1| (-368)))) (-2774 (($ $) 214 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 219 (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190)))))) (-1773 (($) NIL (-12 (|has| |#2| (-1144)) (|has| |#1| (-368))) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-3346 (($ $) NIL (-12 (|has| |#2| (-303)) (|has| |#1| (-368))))) (-1716 ((|#2| $) NIL (-12 (|has| |#2| (-554)) (|has| |#1| (-368))))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| |#2| (-910)) (|has| |#1| (-368))))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| |#2| (-910)) (|has| |#1| (-368))))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1977 (($ $ (-572)) 126)) (-1803 (((-3 $ "failed") $ $) 116 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4179 (($ $) 160 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) 85 (|has| |#1| (-15 ** (|#1| |#1| (-572))))) (($ $ (-1170) |#2|) NIL (-12 (|has| |#2| (-527 (-1170) |#2|)) (|has| |#1| (-368)))) (($ $ (-638 (-1170)) (-638 |#2|)) NIL (-12 (|has| |#2| (-527 (-1170) |#2|)) (|has| |#1| (-368)))) (($ $ (-638 (-290 |#2|))) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#1| (-368)))) (($ $ (-290 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#1| (-368)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#1| (-368)))) (($ $ (-638 |#2|) (-638 |#2|)) NIL (-12 (|has| |#2| (-305 |#2|)) (|has| |#1| (-368))))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ (-572)) 91) (($ $ $) 79 (|has| (-572) (-1110))) (($ $ |#2|) NIL (-12 (|has| |#2| (-283 |#2| |#2|)) (|has| |#1| (-368))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3139 (($ $ (-1 |#2| |#2|)) NIL (|has| |#1| (-368))) (($ $ (-1 |#2| |#2|) (-769)) NIL (|has| |#1| (-368))) (($ $ (-769)) NIL (-1841 (-12 (|has| |#2| (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $) 137 (-1841 (-12 (|has| |#2| (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-1841 (-12 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170) (-769)) NIL (-1841 (-12 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-638 (-1170))) NIL (-1841 (-12 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170)) 140 (-1841 (-12 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))))) (-3425 (($ $) NIL (|has| |#1| (-368)))) (-4492 ((|#2| $) 152 (|has| |#1| (-368)))) (-4316 (((-572) $) 12)) (-4302 (($ $) 198 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 174 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 194 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 170 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 190 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 166 (|has| |#1| (-43 (-413 (-572)))))) (-4081 (((-217) $) NIL (-12 (|has| |#2| (-1028)) (|has| |#1| (-368)))) (((-385) $) NIL (-12 (|has| |#2| (-1028)) (|has| |#1| (-368)))) (((-545) $) NIL (-12 (|has| |#2| (-613 (-545))) (|has| |#1| (-368)))) (((-893 (-385)) $) NIL (-12 (|has| |#2| (-613 (-893 (-385)))) (|has| |#1| (-368)))) (((-893 (-572)) $) NIL (-12 (|has| |#2| (-613 (-893 (-572)))) (|has| |#1| (-368))))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#2| (-910)) (|has| |#1| (-368))))) (-2424 (($ $) 124)) (-3972 (((-856) $) 242) (($ (-572)) 23) (($ |#1|) 21 (|has| |#1| (-174))) (($ |#2|) 20) (($ (-1170)) NIL (-12 (|has| |#2| (-1044 (-1170))) (|has| |#1| (-368)))) (($ (-413 (-572))) 155 (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562)))) (-1958 ((|#1| $ (-572)) 74)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#2| (-910)) (|has| |#1| (-368))) (-12 (|has| |#2| (-149)) (|has| |#1| (-368))) (|has| |#1| (-149))))) (-2140 (((-769)) 142)) (-1694 ((|#1| $) 90)) (-2634 ((|#2| $) NIL (-12 (|has| |#2| (-554)) (|has| |#1| (-368))))) (-4321 (($ $) 204 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 180 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) 200 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 176 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 208 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 184 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-572)) 122 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-572)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 210 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 186 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 206 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 182 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 202 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 178 (|has| |#1| (-43 (-413 (-572)))))) (-2264 (($ $) NIL (-12 (|has| |#2| (-821)) (|has| |#1| (-368))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 13 T CONST)) (-3255 (($) 17 T CONST)) (-1557 (($ $ (-1 |#2| |#2|)) NIL (|has| |#1| (-368))) (($ $ (-1 |#2| |#2|) (-769)) NIL (|has| |#1| (-368))) (($ $ (-769)) NIL (-1841 (-12 (|has| |#2| (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $) NIL (-1841 (-12 (|has| |#2| (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-1841 (-12 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170) (-769)) NIL (-1841 (-12 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-638 (-1170))) NIL (-1841 (-12 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| |#2| (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))))) (-1349 (((-121) $ $) NIL (-12 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-1338 (((-121) $ $) NIL (-12 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-1324 (((-121) $ $) 63)) (-1343 (((-121) $ $) NIL (-12 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-1334 (((-121) $ $) NIL (-12 (|has| |#2| (-848)) (|has| |#1| (-368))))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) 149 (|has| |#1| (-368))) (($ |#2| |#2|) 150 (|has| |#1| (-368)))) (-1373 (($ $) 213) (($ $ $) 68)) (-1367 (($ $ $) 66)) (** (($ $ (-923)) NIL) (($ $ (-769)) 73) (($ $ (-572)) 146 (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 158 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 69) (($ $ |#1|) NIL) (($ |#1| $) 139) (($ $ |#2|) 148 (|has| |#1| (-368))) (($ |#2| $) 147 (|has| |#1| (-368))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1221 |#1| |#2|) (-1220 |#1| |#2|) (-1054) (-1249 |#1|)) (T -1221)) 
-NIL 
-(-1220 |#1| |#2|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2551 (((-1250 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-303)) (|has| |#1| (-368))))) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 10)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-3946 (($ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-3686 (((-121) $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-2525 (($ $ (-572)) NIL) (($ $ (-572) (-572)) NIL)) (-2640 (((-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|))) $) NIL)) (-2118 (((-1250 |#1| |#2| |#3|) $) NIL)) (-4272 (((-3 (-1250 |#1| |#2| |#3|) "failed") $) NIL)) (-1881 (((-1250 |#1| |#2| |#3|) $) NIL)) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2433 (((-572) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))))) (-4521 (($ (-1150 (-2 (|:| |k| (-572)) (|:| |c| |#1|)))) NIL)) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-1250 |#1| |#2| |#3|) "failed") $) NIL) (((-3 (-1170) "failed") $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1044 (-1170))) (|has| |#1| (-368)))) (((-3 (-413 (-572)) "failed") $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368)))) (((-3 (-572) "failed") $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368))))) (-1318 (((-1250 |#1| |#2| |#3|) $) NIL) (((-1170) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1044 (-1170))) (|has| |#1| (-368)))) (((-413 (-572)) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368)))) (((-572) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368))))) (-3729 (($ $) NIL) (($ (-572) $) NIL)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-1250 |#1| |#2| |#3|)) (-685 $)) NIL (|has| |#1| (-368))) (((-2 (|:| -1369 (-685 (-1250 |#1| |#2| |#3|))) (|:| |vec| (-1259 (-1250 |#1| |#2| |#3|)))) (-685 $) (-1259 $)) NIL (|has| |#1| (-368))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-634 (-572))) (|has| |#1| (-368)))) (((-685 (-572)) (-685 $)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-634 (-572))) (|has| |#1| (-368))))) (-1799 (((-3 $ "failed") $) NIL)) (-2059 (((-413 (-959 |#1|)) $ (-572)) NIL (|has| |#1| (-562))) (((-413 (-959 |#1|)) $ (-572) (-572)) NIL (|has| |#1| (-562)))) (-3286 (($) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-554)) (|has| |#1| (-368))))) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-1908 (((-121) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))))) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3103 (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-887 (-572))) (|has| |#1| (-368)))) (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-887 (-385))) (|has| |#1| (-368))))) (-3377 (((-572) $) NIL) (((-572) $ (-572)) NIL)) (-3893 (((-121) $) NIL)) (-4347 (($ $) NIL (|has| |#1| (-368)))) (-4487 (((-1250 |#1| |#2| |#3|) $) NIL (|has| |#1| (-368)))) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3961 (((-3 $ "failed") $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1144)) (|has| |#1| (-368))))) (-4472 (((-121) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))))) (-3965 (($ $ (-923)) NIL)) (-4324 (($ (-1 |#1| (-572)) $) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-572)) 17) (($ $ (-1082) (-572)) NIL) (($ $ (-638 (-1082)) (-638 (-572))) NIL)) (-1771 (($ $ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-4238 (($ $ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|)) $) NIL (|has| |#1| (-368)))) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1885 (($ (-572) (-1250 |#1| |#2| |#3|)) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-2774 (($ $) 25 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 |#2|)) 26 (|has| |#1| (-43 (-413 (-572)))))) (-1773 (($) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1144)) (|has| |#1| (-368))) CONST)) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-3346 (($ $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-303)) (|has| |#1| (-368))))) (-1716 (((-1250 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-554)) (|has| |#1| (-368))))) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1977 (($ $ (-572)) NIL)) (-1803 (((-3 $ "failed") $ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-572))))) (($ $ (-1170) (-1250 |#1| |#2| |#3|)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-527 (-1170) (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-638 (-1170)) (-638 (-1250 |#1| |#2| |#3|))) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-527 (-1170) (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-638 (-290 (-1250 |#1| |#2| |#3|)))) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-305 (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-290 (-1250 |#1| |#2| |#3|))) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-305 (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-305 (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368)))) (($ $ (-638 (-1250 |#1| |#2| |#3|)) (-638 (-1250 |#1| |#2| |#3|))) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-305 (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368))))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ (-572)) NIL) (($ $ $) NIL (|has| (-572) (-1110))) (($ $ (-1250 |#1| |#2| |#3|)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-283 (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|))) (|has| |#1| (-368))))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3139 (($ $ (-1 (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|))) NIL (|has| |#1| (-368))) (($ $ (-1 (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|)) (-769)) NIL (|has| |#1| (-368))) (($ $ (-1255 |#2|)) 24) (($ $ (-769)) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $) 23 (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170) (-769)) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-638 (-1170))) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))))) (-3425 (($ $) NIL (|has| |#1| (-368)))) (-4492 (((-1250 |#1| |#2| |#3|) $) NIL (|has| |#1| (-368)))) (-4316 (((-572) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4081 (((-545) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-613 (-545))) (|has| |#1| (-368)))) (((-385) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1028)) (|has| |#1| (-368)))) (((-217) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1028)) (|has| |#1| (-368)))) (((-893 (-385)) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-613 (-893 (-385)))) (|has| |#1| (-368)))) (((-893 (-572)) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-613 (-893 (-572)))) (|has| |#1| (-368))))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))))) (-2424 (($ $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL (|has| |#1| (-174))) (($ (-1250 |#1| |#2| |#3|)) NIL) (($ (-1255 |#2|)) 22) (($ (-1170)) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-1044 (-1170))) (|has| |#1| (-368)))) (($ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562)))) (($ (-413 (-572))) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-1044 (-572))) (|has| |#1| (-368))) (|has| |#1| (-43 (-413 (-572))))))) (-1958 ((|#1| $ (-572)) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-149)) (|has| |#1| (-368))) (|has| |#1| (-149))))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) 11)) (-2634 (((-1250 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-554)) (|has| |#1| (-368))))) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-910)) (|has| |#1| (-368))) (|has| |#1| (-562))))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-572)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-572)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2264 (($ $) NIL (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 19 T CONST)) (-3255 (($) 15 T CONST)) (-1557 (($ $ (-1 (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|))) NIL (|has| |#1| (-368))) (($ $ (-1 (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|)) (-769)) NIL (|has| |#1| (-368))) (($ $ (-769)) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-227)) (|has| |#1| (-368))) (|has| |#1| (-15 * (|#1| (-572) |#1|))))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170) (-769)) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-638 (-1170))) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170)))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-901 (-1170))) (|has| |#1| (-368))) (-12 (|has| |#1| (-15 * (|#1| (-572) |#1|))) (|has| |#1| (-901 (-1170))))))) (-1349 (((-121) $ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-1338 (((-121) $ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-1334 (((-121) $ $) NIL (-1841 (-12 (|has| (-1250 |#1| |#2| |#3|) (-821)) (|has| |#1| (-368))) (-12 (|has| (-1250 |#1| |#2| |#3|) (-848)) (|has| |#1| (-368)))))) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368))) (($ (-1250 |#1| |#2| |#3|) (-1250 |#1| |#2| |#3|)) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 20)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-1250 |#1| |#2| |#3|)) NIL (|has| |#1| (-368))) (($ (-1250 |#1| |#2| |#3|) $) NIL (|has| |#1| (-368))) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1222 |#1| |#2| |#3|) (-13 (-1220 |#1| (-1250 |#1| |#2| |#3|)) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) (-1054) (-1170) |#1|) (T -1222)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1222 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1222 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1222 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3)))) 
-(-13 (-1220 |#1| (-1250 |#1| |#2| |#3|)) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) 
-((-3560 (((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121)) 10)) (-2602 (((-424 |#1|) |#1|) 21)) (-4304 (((-424 |#1|) |#1|) 20))) 
-(((-1223 |#1|) (-10 -7 (-15 -4304 ((-424 |#1|) |#1|)) (-15 -2602 ((-424 |#1|) |#1|)) (-15 -3560 ((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121)))) (-1234 (-572))) (T -1223)) 
-((-3560 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| *3) (|:| -3341 (-572))))))) (-5 *1 (-1223 *3)) (-4 *3 (-1234 (-572))))) (-2602 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1223 *3)) (-4 *3 (-1234 (-572))))) (-4304 (*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1223 *3)) (-4 *3 (-1234 (-572)))))) 
-(-10 -7 (-15 -4304 ((-424 |#1|) |#1|)) (-15 -2602 ((-424 |#1|) |#1|)) (-15 -3560 ((-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| |#1|) (|:| -3341 (-572)))))) |#1| (-121)))) 
-((-3828 (((-1150 |#2|) (-1 |#2| |#1|) (-1225 |#1|)) 23 (|has| |#1| (-846))) (((-1225 |#2|) (-1 |#2| |#1|) (-1225 |#1|)) 17))) 
-(((-1224 |#1| |#2|) (-10 -7 (-15 -3828 ((-1225 |#2|) (-1 |#2| |#1|) (-1225 |#1|))) (IF (|has| |#1| (-846)) (-15 -3828 ((-1150 |#2|) (-1 |#2| |#1|) (-1225 |#1|))) |noBranch|)) (-1204) (-1204)) (T -1224)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1225 *5)) (-4 *5 (-846)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1150 *6)) (-5 *1 (-1224 *5 *6)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1225 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1225 *6)) (-5 *1 (-1224 *5 *6))))) 
-(-10 -7 (-15 -3828 ((-1225 |#2|) (-1 |#2| |#1|) (-1225 |#1|))) (IF (|has| |#1| (-846)) (-15 -3828 ((-1150 |#2|) (-1 |#2| |#1|) (-1225 |#1|))) |noBranch|)) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4199 (($ |#1| |#1|) 9) (($ |#1|) 8)) (-3828 (((-1150 |#1|) (-1 |#1| |#1|) $) 41 (|has| |#1| (-846)))) (-2861 ((|#1| $) 14)) (-2399 ((|#1| $) 10)) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2408 (((-572) $) 18)) (-4461 ((|#1| $) 17)) (-2417 ((|#1| $) 11)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-2647 (((-121) $) 16)) (-2534 (((-1150 |#1|) $) 38 (|has| |#1| (-846))) (((-1150 |#1|) (-638 $)) 37 (|has| |#1| (-846)))) (-4081 (($ |#1|) 25)) (-3972 (($ (-1092 |#1|)) 24) (((-856) $) 34 (|has| |#1| (-1098)))) (-2770 (($ |#1| |#1|) 20) (($ |#1|) 19)) (-3887 (($ $ (-572)) 13)) (-1324 (((-121) $ $) 27 (|has| |#1| (-1098))))) 
-(((-1225 |#1|) (-13 (-1091 |#1|) (-10 -8 (-15 -2770 ($ |#1|)) (-15 -4199 ($ |#1|)) (-15 -3972 ($ (-1092 |#1|))) (-15 -2647 ((-121) $)) (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|) (IF (|has| |#1| (-846)) (-6 (-1093 |#1| (-1150 |#1|))) |noBranch|))) (-1204)) (T -1225)) 
-((-2770 (*1 *1 *2) (-12 (-5 *1 (-1225 *2)) (-4 *2 (-1204)))) (-4199 (*1 *1 *2) (-12 (-5 *1 (-1225 *2)) (-4 *2 (-1204)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1092 *3)) (-4 *3 (-1204)) (-5 *1 (-1225 *3)))) (-2647 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1225 *3)) (-4 *3 (-1204))))) 
-(-13 (-1091 |#1|) (-10 -8 (-15 -2770 ($ |#1|)) (-15 -4199 ($ |#1|)) (-15 -3972 ($ (-1092 |#1|))) (-15 -2647 ((-121) $)) (IF (|has| |#1| (-1098)) (-6 (-1098)) |noBranch|) (IF (|has| |#1| (-846)) (-6 (-1093 |#1| (-1150 |#1|))) |noBranch|))) 
-((-3828 (((-1231 |#3| |#4|) (-1 |#4| |#2|) (-1231 |#1| |#2|)) 15))) 
-(((-1226 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 ((-1231 |#3| |#4|) (-1 |#4| |#2|) (-1231 |#1| |#2|)))) (-1170) (-1054) (-1170) (-1054)) (T -1226)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *6)) (-5 *4 (-1231 *5 *6)) (-14 *5 (-1170)) (-4 *6 (-1054)) (-4 *8 (-1054)) (-5 *2 (-1231 *7 *8)) (-5 *1 (-1226 *5 *6 *7 *8)) (-14 *7 (-1170))))) 
-(-10 -7 (-15 -3828 ((-1231 |#3| |#4|) (-1 |#4| |#2|) (-1231 |#1| |#2|)))) 
-((-1518 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) 21)) (-3559 ((|#1| |#3|) 13)) (-1443 ((|#3| |#3|) 19))) 
-(((-1227 |#1| |#2| |#3|) (-10 -7 (-15 -3559 (|#1| |#3|)) (-15 -1443 (|#3| |#3|)) (-15 -1518 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) (-562) (-1000 |#1|) (-1234 |#2|)) (T -1227)) 
-((-1518 (*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-1000 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-1227 *4 *5 *3)) (-4 *3 (-1234 *5)))) (-1443 (*1 *2 *2) (-12 (-4 *3 (-562)) (-4 *4 (-1000 *3)) (-5 *1 (-1227 *3 *4 *2)) (-4 *2 (-1234 *4)))) (-3559 (*1 *2 *3) (-12 (-4 *4 (-1000 *2)) (-4 *2 (-562)) (-5 *1 (-1227 *2 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -3559 (|#1| |#3|)) (-15 -1443 (|#3| |#3|)) (-15 -1518 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) 
-((-1384 (((-3 |#2| "failed") |#2| (-769) |#1|) 29)) (-3523 (((-3 |#2| "failed") |#2| (-769)) 30)) (-1710 (((-3 (-2 (|:| -1866 |#2|) (|:| -1862 |#2|)) "failed") |#2|) 42)) (-1641 (((-638 |#2|) |#2|) 44)) (-1818 (((-3 |#2| "failed") |#2| |#2|) 39))) 
-(((-1228 |#1| |#2|) (-10 -7 (-15 -3523 ((-3 |#2| "failed") |#2| (-769))) (-15 -1384 ((-3 |#2| "failed") |#2| (-769) |#1|)) (-15 -1818 ((-3 |#2| "failed") |#2| |#2|)) (-15 -1710 ((-3 (-2 (|:| -1866 |#2|) (|:| -1862 |#2|)) "failed") |#2|)) (-15 -1641 ((-638 |#2|) |#2|))) (-13 (-562) (-151)) (-1234 |#1|)) (T -1228)) 
-((-1641 (*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-151))) (-5 *2 (-638 *3)) (-5 *1 (-1228 *4 *3)) (-4 *3 (-1234 *4)))) (-1710 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-562) (-151))) (-5 *2 (-2 (|:| -1866 *3) (|:| -1862 *3))) (-5 *1 (-1228 *4 *3)) (-4 *3 (-1234 *4)))) (-1818 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-13 (-562) (-151))) (-5 *1 (-1228 *3 *2)) (-4 *2 (-1234 *3)))) (-1384 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-769)) (-4 *4 (-13 (-562) (-151))) (-5 *1 (-1228 *4 *2)) (-4 *2 (-1234 *4)))) (-3523 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-769)) (-4 *4 (-13 (-562) (-151))) (-5 *1 (-1228 *4 *2)) (-4 *2 (-1234 *4))))) 
-(-10 -7 (-15 -3523 ((-3 |#2| "failed") |#2| (-769))) (-15 -1384 ((-3 |#2| "failed") |#2| (-769) |#1|)) (-15 -1818 ((-3 |#2| "failed") |#2| |#2|)) (-15 -1710 ((-3 (-2 (|:| -1866 |#2|) (|:| -1862 |#2|)) "failed") |#2|)) (-15 -1641 ((-638 |#2|) |#2|))) 
-((-3401 (((-3 (-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) "failed") |#2| |#2|) 31))) 
-(((-1229 |#1| |#2|) (-10 -7 (-15 -3401 ((-3 (-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) "failed") |#2| |#2|))) (-562) (-1234 |#1|)) (T -1229)) 
-((-3401 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-562)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-1229 *4 *3)) (-4 *3 (-1234 *4))))) 
-(-10 -7 (-15 -3401 ((-3 (-2 (|:| -3043 |#2|) (|:| -2492 |#2|)) "failed") |#2| |#2|))) 
-((-4563 ((|#2| |#2| |#2|) 19)) (-2029 ((|#2| |#2| |#2|) 30)) (-3082 ((|#2| |#2| |#2| (-769) (-769)) 36))) 
-(((-1230 |#1| |#2|) (-10 -7 (-15 -4563 (|#2| |#2| |#2|)) (-15 -2029 (|#2| |#2| |#2|)) (-15 -3082 (|#2| |#2| |#2| (-769) (-769)))) (-1054) (-1234 |#1|)) (T -1230)) 
-((-3082 (*1 *2 *2 *2 *3 *3) (-12 (-5 *3 (-769)) (-4 *4 (-1054)) (-5 *1 (-1230 *4 *2)) (-4 *2 (-1234 *4)))) (-2029 (*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-1230 *3 *2)) (-4 *2 (-1234 *3)))) (-4563 (*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-1230 *3 *2)) (-4 *2 (-1234 *3))))) 
-(-10 -7 (-15 -4563 (|#2| |#2| |#2|)) (-15 -2029 (|#2| |#2| |#2|)) (-15 -3082 (|#2| |#2| |#2| (-769) (-769)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3275 (((-1259 |#2|) $ (-769)) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-2383 (($ (-1166 |#2|)) NIL)) (-4297 (((-1166 $) $ (-1082)) NIL) (((-1166 |#2|) $) NIL)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#2| (-562)))) (-3946 (($ $) NIL (|has| |#2| (-562)))) (-3686 (((-121) $) NIL (|has| |#2| (-562)))) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1082))) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2824 (($ $ $) NIL (|has| |#2| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-2844 (($ $) NIL (|has| |#2| (-457)))) (-1466 (((-424 $) $) NIL (|has| |#2| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3112 (((-121) $ $) NIL (|has| |#2| (-368)))) (-2786 (($ $ (-769)) NIL)) (-3944 (($ $ (-769)) NIL)) (-2012 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#2| (-457)))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) NIL) (((-3 (-413 (-572)) "failed") $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) NIL (|has| |#2| (-1044 (-572)))) (((-3 (-1082) "failed") $) NIL)) (-1318 ((|#2| $) NIL) (((-413 (-572)) $) NIL (|has| |#2| (-1044 (-413 (-572))))) (((-572) $) NIL (|has| |#2| (-1044 (-572)))) (((-1082) $) NIL)) (-3190 (($ $ $ (-1082)) NIL (|has| |#2| (-174))) ((|#2| $ $) NIL (|has| |#2| (-174)))) (-2190 (($ $ $) NIL (|has| |#2| (-368)))) (-4383 (($ $) NIL)) (-2284 (((-685 (-572)) (-685 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) NIL (|has| |#2| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#2|)) (|:| |vec| (-1259 |#2|))) (-685 $) (-1259 $)) NIL) (((-685 |#2|) (-685 $)) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2208 (($ $ $) NIL (|has| |#2| (-368)))) (-3890 (($ $ $) NIL)) (-3039 (($ $ $) NIL (|has| |#2| (-562)))) (-1449 (((-2 (|:| -4513 |#2|) (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#2| (-368)))) (-3988 (($ $) NIL (|has| |#2| (-457))) (($ $ (-1082)) NIL (|has| |#2| (-457)))) (-4378 (((-638 $) $) NIL)) (-1526 (((-121) $) NIL (|has| |#2| (-910)))) (-3977 (($ $ |#2| (-769) $) NIL)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) NIL (-12 (|has| (-1082) (-887 (-385))) (|has| |#2| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) NIL (-12 (|has| (-1082) (-887 (-572))) (|has| |#2| (-887 (-572)))))) (-3377 (((-769) $ $) NIL (|has| |#2| (-562)))) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3961 (((-3 $ "failed") $) NIL (|has| |#2| (-1144)))) (-4335 (($ (-1166 |#2|) (-1082)) NIL) (($ (-1166 $) (-1082)) NIL)) (-3965 (($ $ (-769)) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#2| (-368)))) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4328 (($ |#2| (-769)) 17) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1082)) NIL) (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL)) (-1784 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-1771 (($ $ $) NIL (|has| |#2| (-848)))) (-4238 (($ $ $) NIL (|has| |#2| (-848)))) (-3918 (($ (-1 (-769) (-769)) $) NIL)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-4155 (((-1166 |#2|) $) NIL)) (-1470 (((-3 (-1082) "failed") $) NIL)) (-4368 (($ $) NIL)) (-4373 ((|#2| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-1658 (((-1152) $) NIL)) (-2845 (((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769)) NIL)) (-1921 (((-3 (-638 $) "failed") $) NIL)) (-2336 (((-3 (-638 $) "failed") $) NIL)) (-3019 (((-3 (-2 (|:| |var| (-1082)) (|:| -3751 (-769))) "failed") $) NIL)) (-2774 (($ $) NIL (|has| |#2| (-43 (-413 (-572)))))) (-1773 (($) NIL (|has| |#2| (-1144)) CONST)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 ((|#2| $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#2| (-457)))) (-3069 (($ (-638 $)) NIL (|has| |#2| (-457))) (($ $ $) NIL (|has| |#2| (-457)))) (-3311 (($ $ (-769) |#2| $) NIL)) (-4364 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) NIL (|has| |#2| (-910)))) (-4304 (((-424 $) $) NIL (|has| |#2| (-910)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#2| (-368)))) (-1803 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-562))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#2| (-368)))) (-4485 (($ $ (-638 (-290 $))) NIL) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1082) |#2|) NIL) (($ $ (-638 (-1082)) (-638 |#2|)) NIL) (($ $ (-1082) $) NIL) (($ $ (-638 (-1082)) (-638 $)) NIL)) (-4029 (((-769) $) NIL (|has| |#2| (-368)))) (-3277 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-413 $) (-413 $) (-413 $)) NIL (|has| |#2| (-562))) ((|#2| (-413 $) |#2|) NIL (|has| |#2| (-368))) (((-413 $) $ (-413 $)) NIL (|has| |#2| (-562)))) (-1997 (((-3 $ "failed") $ (-769)) NIL)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#2| (-368)))) (-2119 (($ $ (-1082)) NIL (|has| |#2| (-174))) ((|#2| $) NIL (|has| |#2| (-174)))) (-3139 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) $) NIL)) (-4316 (((-769) $) NIL) (((-769) $ (-1082)) NIL) (((-638 (-769)) $ (-638 (-1082))) NIL)) (-4081 (((-893 (-385)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-385)))) (|has| |#2| (-613 (-893 (-385)))))) (((-893 (-572)) $) NIL (-12 (|has| (-1082) (-613 (-893 (-572)))) (|has| |#2| (-613 (-893 (-572)))))) (((-545) $) NIL (-12 (|has| (-1082) (-613 (-545))) (|has| |#2| (-613 (-545)))))) (-3694 ((|#2| $) NIL (|has| |#2| (-457))) (($ $ (-1082)) NIL (|has| |#2| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) NIL (-12 (|has| $ (-149)) (|has| |#2| (-910))))) (-2268 (((-3 $ "failed") $ $) NIL (|has| |#2| (-562))) (((-3 (-413 $) "failed") (-413 $) $) NIL (|has| |#2| (-562)))) (-3972 (((-856) $) 13) (($ (-572)) NIL) (($ |#2|) NIL) (($ (-1082)) NIL) (($ (-1255 |#1|)) 19) (($ (-413 (-572))) NIL (-1841 (|has| |#2| (-43 (-413 (-572)))) (|has| |#2| (-1044 (-413 (-572)))))) (($ $) NIL (|has| |#2| (-562)))) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-769)) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-2779 (((-3 $ "failed") $) NIL (-1841 (-12 (|has| $ (-149)) (|has| |#2| (-910))) (|has| |#2| (-149))))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| |#2| (-174)))) (-3774 (((-121) $ $) NIL (|has| |#2| (-562)))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3255 (($) 14 T CONST)) (-1557 (($ $ (-1082)) NIL) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) NIL) (($ $ (-1170)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1170) (-769)) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) NIL (|has| |#2| (-901 (-1170)))) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1349 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1324 (((-121) $ $) NIL)) (-1343 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#2| (-848)))) (-1379 (($ $ |#2|) NIL (|has| |#2| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-413 (-572))) NIL (|has| |#2| (-43 (-413 (-572))))) (($ (-413 (-572)) $) NIL (|has| |#2| (-43 (-413 (-572))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-1231 |#1| |#2|) (-13 (-1234 |#2|) (-10 -8 (-15 -3972 ($ (-1255 |#1|))) (-15 -3311 ($ $ (-769) |#2| $)))) (-1170) (-1054)) (T -1231)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *3)) (-14 *3 (-1170)) (-5 *1 (-1231 *3 *4)) (-4 *4 (-1054)))) (-3311 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1231 *4 *3)) (-14 *4 (-1170)) (-4 *3 (-1054))))) 
-(-13 (-1234 |#2|) (-10 -8 (-15 -3972 ($ (-1255 |#1|))) (-15 -3311 ($ $ (-769) |#2| $)))) 
-((-3828 ((|#4| (-1 |#3| |#1|) |#2|) 22))) 
-(((-1232 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#4| (-1 |#3| |#1|) |#2|))) (-1054) (-1234 |#1|) (-1054) (-1234 |#3|)) (T -1232)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-4 *2 (-1234 *6)) (-5 *1 (-1232 *5 *4 *6 *2)) (-4 *4 (-1234 *5))))) 
-(-10 -7 (-15 -3828 (|#4| (-1 |#3| |#1|) |#2|))) 
-((-3275 (((-1259 |#2|) $ (-769)) 113)) (-3456 (((-638 (-1082)) $) 15)) (-2383 (($ (-1166 |#2|)) 66)) (-2357 (((-769) $) NIL) (((-769) $ (-638 (-1082))) 18)) (-4073 (((-424 (-1166 $)) (-1166 $)) 183)) (-2844 (($ $) 173)) (-1466 (((-424 $) $) 171)) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 81)) (-2786 (($ $ (-769)) 70)) (-3944 (($ $ (-769)) 72)) (-2012 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) 129)) (-3376 (((-3 |#2| "failed") $) 116) (((-3 (-413 (-572)) "failed") $) NIL) (((-3 (-572) "failed") $) NIL) (((-3 (-1082) "failed") $) NIL)) (-1318 ((|#2| $) 114) (((-413 (-572)) $) NIL) (((-572) $) NIL) (((-1082) $) NIL)) (-3039 (($ $ $) 150)) (-1449 (((-2 (|:| -4513 |#2|) (|:| -3043 $) (|:| -2492 $)) $ $) 152)) (-3377 (((-769) $ $) 168)) (-3961 (((-3 $ "failed") $) 122)) (-4328 (($ |#2| (-769)) NIL) (($ $ (-1082) (-769)) 46) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-1784 (((-769) $) NIL) (((-769) $ (-1082)) 41) (((-638 (-769)) $ (-638 (-1082))) 42)) (-4155 (((-1166 |#2|) $) 58)) (-1470 (((-3 (-1082) "failed") $) 39)) (-2845 (((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769)) 69)) (-2774 (($ $) 194)) (-1773 (($) 118)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 180)) (-4364 (((-424 (-1166 $)) (-1166 $)) 87)) (-3992 (((-424 (-1166 $)) (-1166 $)) 85)) (-4304 (((-424 $) $) 105)) (-4485 (($ $ (-638 (-290 $))) 38) (($ $ (-290 $)) NIL) (($ $ $ $) NIL) (($ $ (-638 $) (-638 $)) NIL) (($ $ (-1082) |#2|) 31) (($ $ (-638 (-1082)) (-638 |#2|)) 28) (($ $ (-1082) $) 25) (($ $ (-638 (-1082)) (-638 $)) 23)) (-4029 (((-769) $) 186)) (-3277 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-413 $) (-413 $) (-413 $)) 146) ((|#2| (-413 $) |#2|) 185) (((-413 $) $ (-413 $)) 167)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 189)) (-3139 (($ $ (-1082)) 139) (($ $ (-638 (-1082))) NIL) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL) (($ $ (-769)) NIL) (($ $) 137) (($ $ (-1170)) NIL) (($ $ (-638 (-1170))) NIL) (($ $ (-1170) (-769)) NIL) (($ $ (-638 (-1170)) (-638 (-769))) NIL) (($ $ (-1 |#2| |#2|) (-769)) NIL) (($ $ (-1 |#2| |#2|)) 136) (($ $ (-1 |#2| |#2|) $) 133)) (-4316 (((-769) $) NIL) (((-769) $ (-1082)) 16) (((-638 (-769)) $ (-638 (-1082))) 20)) (-3694 ((|#2| $) NIL) (($ $ (-1082)) 124)) (-2268 (((-3 $ "failed") $ $) 160) (((-3 (-413 $) "failed") (-413 $) $) 156)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#2|) NIL) (($ (-1082)) 50) (($ (-413 (-572))) NIL) (($ $) NIL))) 
-(((-1233 |#1| |#2|) (-10 -8 (-15 -3972 (|#1| |#1|)) (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|))) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -2844 (|#1| |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -1773 (|#1|)) (-15 -3961 ((-3 |#1| "failed") |#1|)) (-15 -3277 ((-413 |#1|) |#1| (-413 |#1|))) (-15 -4029 ((-769) |#1|)) (-15 -2541 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -2774 (|#1| |#1|)) (-15 -3277 (|#2| (-413 |#1|) |#2|)) (-15 -2012 ((-2 (|:| |primePart| |#1|) (|:| |commonPart| |#1|)) |#1| |#1|)) (-15 -1449 ((-2 (|:| -4513 |#2|) (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -3039 (|#1| |#1| |#1|)) (-15 -2268 ((-3 (-413 |#1|) "failed") (-413 |#1|) |#1|)) (-15 -2268 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3377 ((-769) |#1| |#1|)) (-15 -3277 ((-413 |#1|) (-413 |#1|) (-413 |#1|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) |#1|)) (-15 -3944 (|#1| |#1| (-769))) (-15 -2786 (|#1| |#1| (-769))) (-15 -2845 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| (-769))) (-15 -2383 (|#1| (-1166 |#2|))) (-15 -4155 ((-1166 |#2|) |#1|)) (-15 -3275 ((-1259 |#2|) |#1| (-769))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3277 (|#1| |#1| |#1|)) (-15 -3277 (|#2| |#1| |#2|)) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -4073 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -3992 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -4364 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -2462 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|))) (-15 -3694 (|#1| |#1| (-1082))) (-15 -3456 ((-638 (-1082)) |#1|)) (-15 -2357 ((-769) |#1| (-638 (-1082)))) (-15 -2357 ((-769) |#1|)) (-15 -4328 (|#1| |#1| (-638 (-1082)) (-638 (-769)))) (-15 -4328 (|#1| |#1| (-1082) (-769))) (-15 -1784 ((-638 (-769)) |#1| (-638 (-1082)))) (-15 -1784 ((-769) |#1| (-1082))) (-15 -1470 ((-3 (-1082) "failed") |#1|)) (-15 -4316 ((-638 (-769)) |#1| (-638 (-1082)))) (-15 -4316 ((-769) |#1| (-1082))) (-15 -1318 ((-1082) |#1|)) (-15 -3376 ((-3 (-1082) "failed") |#1|)) (-15 -3972 (|#1| (-1082))) (-15 -4485 (|#1| |#1| (-638 (-1082)) (-638 |#1|))) (-15 -4485 (|#1| |#1| (-1082) |#1|)) (-15 -4485 (|#1| |#1| (-638 (-1082)) (-638 |#2|))) (-15 -4485 (|#1| |#1| (-1082) |#2|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4316 ((-769) |#1|)) (-15 -4328 (|#1| |#2| (-769))) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -1784 ((-769) |#1|)) (-15 -3694 (|#2| |#1|)) (-15 -3139 (|#1| |#1| (-638 (-1082)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1082) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1082)))) (-15 -3139 (|#1| |#1| (-1082))) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) (-1234 |#2|) (-1054)) (T -1233)) 
-NIL 
-(-10 -8 (-15 -3972 (|#1| |#1|)) (-15 -3905 ((-1166 |#1|) (-1166 |#1|) (-1166 |#1|))) (-15 -1466 ((-424 |#1|) |#1|)) (-15 -2844 (|#1| |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -1773 (|#1|)) (-15 -3961 ((-3 |#1| "failed") |#1|)) (-15 -3277 ((-413 |#1|) |#1| (-413 |#1|))) (-15 -4029 ((-769) |#1|)) (-15 -2541 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -2774 (|#1| |#1|)) (-15 -3277 (|#2| (-413 |#1|) |#2|)) (-15 -2012 ((-2 (|:| |primePart| |#1|) (|:| |commonPart| |#1|)) |#1| |#1|)) (-15 -1449 ((-2 (|:| -4513 |#2|) (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| |#1|)) (-15 -3039 (|#1| |#1| |#1|)) (-15 -2268 ((-3 (-413 |#1|) "failed") (-413 |#1|) |#1|)) (-15 -2268 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3377 ((-769) |#1| |#1|)) (-15 -3277 ((-413 |#1|) (-413 |#1|) (-413 |#1|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) |#1|)) (-15 -3944 (|#1| |#1| (-769))) (-15 -2786 (|#1| |#1| (-769))) (-15 -2845 ((-2 (|:| -3043 |#1|) (|:| -2492 |#1|)) |#1| (-769))) (-15 -2383 (|#1| (-1166 |#2|))) (-15 -4155 ((-1166 |#2|) |#1|)) (-15 -3275 ((-1259 |#2|) |#1| (-769))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3139 (|#1| |#1| (-1 |#2| |#2|) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1170) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1170)))) (-15 -3139 (|#1| |#1| (-1170))) (-15 -3139 (|#1| |#1|)) (-15 -3139 (|#1| |#1| (-769))) (-15 -3277 (|#1| |#1| |#1|)) (-15 -3277 (|#2| |#1| |#2|)) (-15 -4304 ((-424 |#1|) |#1|)) (-15 -4073 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -3992 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -4364 ((-424 (-1166 |#1|)) (-1166 |#1|))) (-15 -2462 ((-3 (-638 (-1166 |#1|)) "failed") (-638 (-1166 |#1|)) (-1166 |#1|))) (-15 -3694 (|#1| |#1| (-1082))) (-15 -3456 ((-638 (-1082)) |#1|)) (-15 -2357 ((-769) |#1| (-638 (-1082)))) (-15 -2357 ((-769) |#1|)) (-15 -4328 (|#1| |#1| (-638 (-1082)) (-638 (-769)))) (-15 -4328 (|#1| |#1| (-1082) (-769))) (-15 -1784 ((-638 (-769)) |#1| (-638 (-1082)))) (-15 -1784 ((-769) |#1| (-1082))) (-15 -1470 ((-3 (-1082) "failed") |#1|)) (-15 -4316 ((-638 (-769)) |#1| (-638 (-1082)))) (-15 -4316 ((-769) |#1| (-1082))) (-15 -1318 ((-1082) |#1|)) (-15 -3376 ((-3 (-1082) "failed") |#1|)) (-15 -3972 (|#1| (-1082))) (-15 -4485 (|#1| |#1| (-638 (-1082)) (-638 |#1|))) (-15 -4485 (|#1| |#1| (-1082) |#1|)) (-15 -4485 (|#1| |#1| (-638 (-1082)) (-638 |#2|))) (-15 -4485 (|#1| |#1| (-1082) |#2|)) (-15 -4485 (|#1| |#1| (-638 |#1|) (-638 |#1|))) (-15 -4485 (|#1| |#1| |#1| |#1|)) (-15 -4485 (|#1| |#1| (-290 |#1|))) (-15 -4485 (|#1| |#1| (-638 (-290 |#1|)))) (-15 -4316 ((-769) |#1|)) (-15 -4328 (|#1| |#2| (-769))) (-15 -1318 ((-572) |#1|)) (-15 -3376 ((-3 (-572) "failed") |#1|)) (-15 -1318 ((-413 (-572)) |#1|)) (-15 -3376 ((-3 (-413 (-572)) "failed") |#1|)) (-15 -3972 (|#1| |#2|)) (-15 -3376 ((-3 |#2| "failed") |#1|)) (-15 -1318 (|#2| |#1|)) (-15 -1784 ((-769) |#1|)) (-15 -3694 (|#2| |#1|)) (-15 -3139 (|#1| |#1| (-638 (-1082)) (-638 (-769)))) (-15 -3139 (|#1| |#1| (-1082) (-769))) (-15 -3139 (|#1| |#1| (-638 (-1082)))) (-15 -3139 (|#1| |#1| (-1082))) (-15 -3972 (|#1| (-572))) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3275 (((-1259 |#1|) $ (-769)) 217)) (-3456 (((-638 (-1082)) $) 108)) (-2383 (($ (-1166 |#1|)) 215)) (-4297 (((-1166 $) $ (-1082)) 123) (((-1166 |#1|) $) 122)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 85 (|has| |#1| (-562)))) (-3946 (($ $) 86 (|has| |#1| (-562)))) (-3686 (((-121) $) 88 (|has| |#1| (-562)))) (-2357 (((-769) $) 110) (((-769) $ (-638 (-1082))) 109)) (-1572 (((-3 $ "failed") $ $) 18)) (-2824 (($ $ $) 202 (|has| |#1| (-562)))) (-4073 (((-424 (-1166 $)) (-1166 $)) 98 (|has| |#1| (-910)))) (-2844 (($ $) 96 (|has| |#1| (-457)))) (-1466 (((-424 $) $) 95 (|has| |#1| (-457)))) (-2462 (((-3 (-638 (-1166 $)) "failed") (-638 (-1166 $)) (-1166 $)) 101 (|has| |#1| (-910)))) (-3112 (((-121) $ $) 187 (|has| |#1| (-368)))) (-2786 (($ $ (-769)) 210)) (-3944 (($ $ (-769)) 209)) (-2012 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) 197 (|has| |#1| (-457)))) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 162) (((-3 (-413 (-572)) "failed") $) 160 (|has| |#1| (-1044 (-413 (-572))))) (((-3 (-572) "failed") $) 158 (|has| |#1| (-1044 (-572)))) (((-3 (-1082) "failed") $) 134)) (-1318 ((|#1| $) 163) (((-413 (-572)) $) 159 (|has| |#1| (-1044 (-413 (-572))))) (((-572) $) 157 (|has| |#1| (-1044 (-572)))) (((-1082) $) 133)) (-3190 (($ $ $ (-1082)) 106 (|has| |#1| (-174))) ((|#1| $ $) 205 (|has| |#1| (-174)))) (-2190 (($ $ $) 191 (|has| |#1| (-368)))) (-4383 (($ $) 152)) (-2284 (((-685 (-572)) (-685 $)) 132 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 (-572))) (|:| |vec| (-1259 (-572)))) (-685 $) (-1259 $)) 131 (|has| |#1| (-634 (-572)))) (((-2 (|:| -1369 (-685 |#1|)) (|:| |vec| (-1259 |#1|))) (-685 $) (-1259 $)) 130) (((-685 |#1|) (-685 $)) 129)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 190 (|has| |#1| (-368)))) (-3890 (($ $ $) 208)) (-3039 (($ $ $) 199 (|has| |#1| (-562)))) (-1449 (((-2 (|:| -4513 |#1|) (|:| -3043 $) (|:| -2492 $)) $ $) 198 (|has| |#1| (-562)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 185 (|has| |#1| (-368)))) (-3988 (($ $) 174 (|has| |#1| (-457))) (($ $ (-1082)) 103 (|has| |#1| (-457)))) (-4378 (((-638 $) $) 107)) (-1526 (((-121) $) 94 (|has| |#1| (-910)))) (-3977 (($ $ |#1| (-769) $) 170)) (-3103 (((-890 (-385) $) $ (-893 (-385)) (-890 (-385) $)) 82 (-12 (|has| (-1082) (-887 (-385))) (|has| |#1| (-887 (-385))))) (((-890 (-572) $) $ (-893 (-572)) (-890 (-572) $)) 81 (-12 (|has| (-1082) (-887 (-572))) (|has| |#1| (-887 (-572)))))) (-3377 (((-769) $ $) 203 (|has| |#1| (-562)))) (-3893 (((-121) $) 30)) (-3475 (((-769) $) 167)) (-3961 (((-3 $ "failed") $) 183 (|has| |#1| (-1144)))) (-4335 (($ (-1166 |#1|) (-1082)) 115) (($ (-1166 $) (-1082)) 114)) (-3965 (($ $ (-769)) 214)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 194 (|has| |#1| (-368)))) (-3658 (((-638 $) $) 124)) (-4581 (((-121) $) 150)) (-4328 (($ |#1| (-769)) 151) (($ $ (-1082) (-769)) 117) (($ $ (-638 (-1082)) (-638 (-769))) 116)) (-3835 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $ (-1082)) 118) (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 212)) (-1784 (((-769) $) 168) (((-769) $ (-1082)) 120) (((-638 (-769)) $ (-638 (-1082))) 119)) (-1771 (($ $ $) 77 (|has| |#1| (-848)))) (-4238 (($ $ $) 76 (|has| |#1| (-848)))) (-3918 (($ (-1 (-769) (-769)) $) 169)) (-3828 (($ (-1 |#1| |#1|) $) 149)) (-4155 (((-1166 |#1|) $) 216)) (-1470 (((-3 (-1082) "failed") $) 121)) (-4368 (($ $) 147)) (-4373 ((|#1| $) 146)) (-1629 (($ (-638 $)) 92 (|has| |#1| (-457))) (($ $ $) 91 (|has| |#1| (-457)))) (-1658 (((-1152) $) 9)) (-2845 (((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769)) 211)) (-1921 (((-3 (-638 $) "failed") $) 112)) (-2336 (((-3 (-638 $) "failed") $) 113)) (-3019 (((-3 (-2 (|:| |var| (-1082)) (|:| -3751 (-769))) "failed") $) 111)) (-2774 (($ $) 195 (|has| |#1| (-43 (-413 (-572)))))) (-1773 (($) 182 (|has| |#1| (-1144)) CONST)) (-2607 (((-1116) $) 10)) (-4357 (((-121) $) 164)) (-4362 ((|#1| $) 165)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 93 (|has| |#1| (-457)))) (-3069 (($ (-638 $)) 90 (|has| |#1| (-457))) (($ $ $) 89 (|has| |#1| (-457)))) (-4364 (((-424 (-1166 $)) (-1166 $)) 100 (|has| |#1| (-910)))) (-3992 (((-424 (-1166 $)) (-1166 $)) 99 (|has| |#1| (-910)))) (-4304 (((-424 $) $) 97 (|has| |#1| (-910)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 193 (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 192 (|has| |#1| (-368)))) (-1803 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-562))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 186 (|has| |#1| (-368)))) (-4485 (($ $ (-638 (-290 $))) 143) (($ $ (-290 $)) 142) (($ $ $ $) 141) (($ $ (-638 $) (-638 $)) 140) (($ $ (-1082) |#1|) 139) (($ $ (-638 (-1082)) (-638 |#1|)) 138) (($ $ (-1082) $) 137) (($ $ (-638 (-1082)) (-638 $)) 136)) (-4029 (((-769) $) 188 (|has| |#1| (-368)))) (-3277 ((|#1| $ |#1|) 235) (($ $ $) 234) (((-413 $) (-413 $) (-413 $)) 204 (|has| |#1| (-562))) ((|#1| (-413 $) |#1|) 196 (|has| |#1| (-368))) (((-413 $) $ (-413 $)) 184 (|has| |#1| (-562)))) (-1997 (((-3 $ "failed") $ (-769)) 213)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 189 (|has| |#1| (-368)))) (-2119 (($ $ (-1082)) 105 (|has| |#1| (-174))) ((|#1| $) 206 (|has| |#1| (-174)))) (-3139 (($ $ (-1082)) 41) (($ $ (-638 (-1082))) 40) (($ $ (-1082) (-769)) 39) (($ $ (-638 (-1082)) (-638 (-769))) 38) (($ $ (-769)) 232) (($ $) 230) (($ $ (-1170)) 229 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 228 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 227 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) 226 (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) 219) (($ $ (-1 |#1| |#1|)) 218) (($ $ (-1 |#1| |#1|) $) 207)) (-4316 (((-769) $) 148) (((-769) $ (-1082)) 128) (((-638 (-769)) $ (-638 (-1082))) 127)) (-4081 (((-893 (-385)) $) 80 (-12 (|has| (-1082) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385)))))) (((-893 (-572)) $) 79 (-12 (|has| (-1082) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572)))))) (((-545) $) 78 (-12 (|has| (-1082) (-613 (-545))) (|has| |#1| (-613 (-545)))))) (-3694 ((|#1| $) 173 (|has| |#1| (-457))) (($ $ (-1082)) 104 (|has| |#1| (-457)))) (-1696 (((-3 (-1259 $) "failed") (-685 $)) 102 (-4028 (|has| $ (-149)) (|has| |#1| (-910))))) (-2268 (((-3 $ "failed") $ $) 201 (|has| |#1| (-562))) (((-3 (-413 $) "failed") (-413 $) $) 200 (|has| |#1| (-562)))) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 161) (($ (-1082)) 135) (($ (-413 (-572))) 70 (-1841 (|has| |#1| (-1044 (-413 (-572)))) (|has| |#1| (-43 (-413 (-572)))))) (($ $) 83 (|has| |#1| (-562)))) (-3193 (((-638 |#1|) $) 166)) (-1958 ((|#1| $ (-769)) 153) (($ $ (-1082) (-769)) 126) (($ $ (-638 (-1082)) (-638 (-769))) 125)) (-2779 (((-3 $ "failed") $) 71 (-1841 (-4028 (|has| $ (-149)) (|has| |#1| (-910))) (|has| |#1| (-149))))) (-2140 (((-769)) 28)) (-2565 (($ $ $ (-769)) 171 (|has| |#1| (-174)))) (-3774 (((-121) $ $) 87 (|has| |#1| (-562)))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-1082)) 37) (($ $ (-638 (-1082))) 36) (($ $ (-1082) (-769)) 35) (($ $ (-638 (-1082)) (-638 (-769))) 34) (($ $ (-769)) 233) (($ $) 231) (($ $ (-1170)) 225 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170))) 224 (|has| |#1| (-901 (-1170)))) (($ $ (-1170) (-769)) 223 (|has| |#1| (-901 (-1170)))) (($ $ (-638 (-1170)) (-638 (-769))) 222 (|has| |#1| (-901 (-1170)))) (($ $ (-1 |#1| |#1|) (-769)) 221) (($ $ (-1 |#1| |#1|)) 220)) (-1349 (((-121) $ $) 74 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 73 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 6)) (-1343 (((-121) $ $) 75 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 72 (|has| |#1| (-848)))) (-1379 (($ $ |#1|) 154 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 156 (|has| |#1| (-43 (-413 (-572))))) (($ (-413 (-572)) $) 155 (|has| |#1| (-43 (-413 (-572))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
-(((-1234 |#1|) (-1290) (-1054)) (T -1234)) 
-((-3275 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-1234 *4)) (-4 *4 (-1054)) (-5 *2 (-1259 *4)))) (-4155 (*1 *2 *1) (-12 (-4 *1 (-1234 *3)) (-4 *3 (-1054)) (-5 *2 (-1166 *3)))) (-2383 (*1 *1 *2) (-12 (-5 *2 (-1166 *3)) (-4 *3 (-1054)) (-4 *1 (-1234 *3)))) (-3965 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)))) (-1997 (*1 *1 *1 *2) (|partial| -12 (-5 *2 (-769)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)))) (-3835 (*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1234 *3)))) (-2845 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *4 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1234 *4)))) (-2786 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)))) (-3944 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)))) (-3890 (*1 *1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)))) (-3139 (*1 *1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)))) (-2119 (*1 *2 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-174)))) (-3190 (*1 *2 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-174)))) (-3277 (*1 *2 *2 *2) (-12 (-5 *2 (-413 *1)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)) (-4 *3 (-562)))) (-3377 (*1 *2 *1 *1) (-12 (-4 *1 (-1234 *3)) (-4 *3 (-1054)) (-4 *3 (-562)) (-5 *2 (-769)))) (-2824 (*1 *1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-562)))) (-2268 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-562)))) (-2268 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-413 *1)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)) (-4 *3 (-562)))) (-3039 (*1 *1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-562)))) (-1449 (*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -4513 *3) (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1234 *3)))) (-2012 (*1 *2 *1 *1) (-12 (-4 *3 (-457)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| |primePart| *1) (|:| |commonPart| *1))) (-4 *1 (-1234 *3)))) (-3277 (*1 *2 *3 *2) (-12 (-5 *3 (-413 *1)) (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-2774 (*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-43 (-413 (-572))))))) 
-(-13 (-956 |t#1| (-769) (-1082)) (-283 |t#1| |t#1|) (-283 $ $) (-227) (-225 |t#1|) (-10 -8 (-15 -3275 ((-1259 |t#1|) $ (-769))) (-15 -4155 ((-1166 |t#1|) $)) (-15 -2383 ($ (-1166 |t#1|))) (-15 -3965 ($ $ (-769))) (-15 -1997 ((-3 $ "failed") $ (-769))) (-15 -3835 ((-2 (|:| -3043 $) (|:| -2492 $)) $ $)) (-15 -2845 ((-2 (|:| -3043 $) (|:| -2492 $)) $ (-769))) (-15 -2786 ($ $ (-769))) (-15 -3944 ($ $ (-769))) (-15 -3890 ($ $ $)) (-15 -3139 ($ $ (-1 |t#1| |t#1|) $)) (IF (|has| |t#1| (-1144)) (-6 (-1144)) |noBranch|) (IF (|has| |t#1| (-174)) (PROGN (-15 -2119 (|t#1| $)) (-15 -3190 (|t#1| $ $))) |noBranch|) (IF (|has| |t#1| (-562)) (PROGN (-6 (-283 (-413 $) (-413 $))) (-15 -3277 ((-413 $) (-413 $) (-413 $))) (-15 -3377 ((-769) $ $)) (-15 -2824 ($ $ $)) (-15 -2268 ((-3 $ "failed") $ $)) (-15 -2268 ((-3 (-413 $) "failed") (-413 $) $)) (-15 -3039 ($ $ $)) (-15 -1449 ((-2 (|:| -4513 |t#1|) (|:| -3043 $) (|:| -2492 $)) $ $))) |noBranch|) (IF (|has| |t#1| (-457)) (-15 -2012 ((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $)) |noBranch|) (IF (|has| |t#1| (-368)) (PROGN (-6 (-303)) (-6 -4598) (-15 -3277 (|t#1| (-413 $) |t#1|))) |noBranch|) (IF (|has| |t#1| (-43 (-413 (-572)))) (-15 -2774 ($ $)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-769)) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-368))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-613 (-545)) -12 (|has| (-1082) (-613 (-545))) (|has| |#1| (-613 (-545)))) ((-613 (-893 (-385))) -12 (|has| (-1082) (-613 (-893 (-385)))) (|has| |#1| (-613 (-893 (-385))))) ((-613 (-893 (-572))) -12 (|has| (-1082) (-613 (-893 (-572)))) (|has| |#1| (-613 (-893 (-572))))) ((-225 |#1|) . T) ((-227) . T) ((-283 (-413 $) (-413 $)) |has| |#1| (-562)) ((-283 |#1| |#1|) . T) ((-283 $ $) . T) ((-287) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-368))) ((-303) |has| |#1| (-368)) ((-305 $) . T) ((-326 |#1| (-769)) . T) ((-383 |#1|) . T) ((-417 |#1|) . T) ((-457) -1841 (|has| |#1| (-910)) (|has| |#1| (-457)) (|has| |#1| (-368))) ((-527 (-1082) |#1|) . T) ((-527 (-1082) $) . T) ((-527 $ $) . T) ((-562) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-368))) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-634 (-572)) |has| |#1| (-634 (-572))) ((-634 |#1|) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-368))) ((-722) . T) ((-848) |has| |#1| (-848)) ((-901 (-1082)) . T) ((-901 (-1170)) |has| |#1| (-901 (-1170))) ((-887 (-385)) -12 (|has| (-1082) (-887 (-385))) (|has| |#1| (-887 (-385)))) ((-887 (-572)) -12 (|has| (-1082) (-887 (-572))) (|has| |#1| (-887 (-572)))) ((-956 |#1| (-769) (-1082)) . T) ((-910) |has| |#1| (-910)) ((-922) |has| |#1| (-368)) ((-1044 (-413 (-572))) |has| |#1| (-1044 (-413 (-572)))) ((-1044 (-572)) |has| |#1| (-1044 (-572))) ((-1044 (-1082)) . T) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-910)) (|has| |#1| (-562)) (|has| |#1| (-457)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1144) |has| |#1| (-1144)) ((-1214) |has| |#1| (-910))) 
-((-3456 (((-638 (-1082)) $) 28)) (-4383 (($ $) 25)) (-4328 (($ |#2| |#3|) NIL) (($ $ (-1082) |#3|) 22) (($ $ (-638 (-1082)) (-638 |#3|)) 20)) (-4368 (($ $) 14)) (-4373 ((|#2| $) 12)) (-4316 ((|#3| $) 10))) 
-(((-1235 |#1| |#2| |#3|) (-10 -8 (-15 -3456 ((-638 (-1082)) |#1|)) (-15 -4328 (|#1| |#1| (-638 (-1082)) (-638 |#3|))) (-15 -4328 (|#1| |#1| (-1082) |#3|)) (-15 -4383 (|#1| |#1|)) (-15 -4328 (|#1| |#2| |#3|)) (-15 -4316 (|#3| |#1|)) (-15 -4368 (|#1| |#1|)) (-15 -4373 (|#2| |#1|))) (-1236 |#2| |#3|) (-1054) (-793)) (T -1235)) 
-NIL 
-(-10 -8 (-15 -3456 ((-638 (-1082)) |#1|)) (-15 -4328 (|#1| |#1| (-638 (-1082)) (-638 |#3|))) (-15 -4328 (|#1| |#1| (-1082) |#3|)) (-15 -4383 (|#1| |#1|)) (-15 -4328 (|#1| |#2| |#3|)) (-15 -4316 (|#3| |#1|)) (-15 -4368 (|#1| |#1|)) (-15 -4373 (|#2| |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 (-1082)) $) 70)) (-3342 (((-1170) $) 98)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-2525 (($ $ |#2|) 93) (($ $ |#2| |#2|) 92)) (-2640 (((-1150 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 100)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-4383 (($ $) 59)) (-1799 (((-3 $ "failed") $) 33)) (-1347 (((-121) $) 69)) (-3377 ((|#2| $) 95) ((|#2| $ |#2|) 94)) (-3893 (((-121) $) 30)) (-3965 (($ $ (-923)) 96)) (-4581 (((-121) $) 61)) (-4328 (($ |#1| |#2|) 60) (($ $ (-1082) |#2|) 72) (($ $ (-638 (-1082)) (-638 |#2|)) 71)) (-3828 (($ (-1 |#1| |#1|) $) 62)) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-1977 (($ $ |#2|) 90)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562)))) (-4485 (((-1150 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| |#2|))))) (-3277 ((|#1| $ |#2|) 99) (($ $ $) 76 (|has| |#2| (-1110)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) 84 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1170) (-769)) 83 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-638 (-1170))) 82 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1170)) 81 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-769)) 79 (|has| |#1| (-15 * (|#1| |#2| |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (-4316 ((|#2| $) 63)) (-2424 (($ $) 68)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 56 (|has| |#1| (-43 (-413 (-572))))) (($ $) 48 (|has| |#1| (-562))) (($ |#1|) 46 (|has| |#1| (-174)))) (-1958 ((|#1| $ |#2|) 58)) (-2779 (((-3 $ "failed") $) 47 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-1694 ((|#1| $) 97)) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-3410 ((|#1| $ |#2|) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| |#2|))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) 88 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1170) (-769)) 87 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-638 (-1170))) 86 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1170)) 85 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-769)) 80 (|has| |#1| (-15 * (|#1| |#2| |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1236 |#1| |#2|) (-1290) (-1054) (-793)) (T -1236)) 
-((-2640 (*1 *2 *1) (-12 (-4 *1 (-1236 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-1150 (-2 (|:| |k| *4) (|:| |c| *3)))))) (-3277 (*1 *2 *1 *3) (-12 (-4 *1 (-1236 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) (-3342 (*1 *2 *1) (-12 (-4 *1 (-1236 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-1170)))) (-1694 (*1 *2 *1) (-12 (-4 *1 (-1236 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) (-3965 (*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-1236 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)))) (-3377 (*1 *2 *1) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) (-3377 (*1 *2 *1 *2) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) (-2525 (*1 *1 *1 *2) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) (-2525 (*1 *1 *1 *2 *2) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) (-3410 (*1 *2 *1 *3) (-12 (-4 *1 (-1236 *2 *3)) (-4 *3 (-793)) (|has| *2 (-15 ** (*2 *2 *3))) (|has| *2 (-15 -3972 (*2 (-1170)))) (-4 *2 (-1054)))) (-1977 (*1 *1 *1 *2) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) (-4485 (*1 *2 *1 *3) (-12 (-4 *1 (-1236 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (|has| *3 (-15 ** (*3 *3 *4))) (-5 *2 (-1150 *3))))) 
-(-13 (-981 |t#1| |t#2| (-1082)) (-10 -8 (-15 -2640 ((-1150 (-2 (|:| |k| |t#2|) (|:| |c| |t#1|))) $)) (-15 -3277 (|t#1| $ |t#2|)) (-15 -3342 ((-1170) $)) (-15 -1694 (|t#1| $)) (-15 -3965 ($ $ (-923))) (-15 -3377 (|t#2| $)) (-15 -3377 (|t#2| $ |t#2|)) (-15 -2525 ($ $ |t#2|)) (-15 -2525 ($ $ |t#2| |t#2|)) (IF (|has| |t#1| (-15 -3972 (|t#1| (-1170)))) (IF (|has| |t#1| (-15 ** (|t#1| |t#1| |t#2|))) (-15 -3410 (|t#1| $ |t#2|)) |noBranch|) |noBranch|) (-15 -1977 ($ $ |t#2|)) (IF (|has| |t#2| (-1110)) (-6 (-283 $ $)) |noBranch|) (IF (|has| |t#1| (-15 * (|t#1| |t#2| |t#1|))) (PROGN (-6 (-227)) (IF (|has| |t#1| (-901 (-1170))) (-6 (-901 (-1170))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-15 ** (|t#1| |t#1| |t#2|))) (-15 -4485 ((-1150 |t#1|) $ |t#1|)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) |has| |#1| (-562)) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-227) |has| |#1| (-15 * (|#1| |#2| |#1|))) ((-283 $ $) |has| |#2| (-1110)) ((-287) |has| |#1| (-562)) ((-562) |has| |#1| (-562)) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) |has| |#1| (-562)) ((-722) . T) ((-901 (-1170)) -12 (|has| |#1| (-15 * (|#1| |#2| |#1|))) (|has| |#1| (-901 (-1170)))) ((-981 |#1| |#2| (-1082)) . T) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2844 ((|#2| |#2|) 12)) (-1466 (((-424 |#2|) |#2|) 14)) (-2586 (((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-572))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-572)))) 30))) 
-(((-1237 |#1| |#2|) (-10 -7 (-15 -1466 ((-424 |#2|) |#2|)) (-15 -2844 (|#2| |#2|)) (-15 -2586 ((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-572))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-572)))))) (-562) (-13 (-1234 |#1|) (-562) (-10 -8 (-15 -3069 ($ $ $))))) (T -1237)) 
-((-2586 (*1 *2 *2) (-12 (-5 *2 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (-572)))) (-4 *4 (-13 (-1234 *3) (-562) (-10 -8 (-15 -3069 ($ $ $))))) (-4 *3 (-562)) (-5 *1 (-1237 *3 *4)))) (-2844 (*1 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-1237 *3 *2)) (-4 *2 (-13 (-1234 *3) (-562) (-10 -8 (-15 -3069 ($ $ $))))))) (-1466 (*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-424 *3)) (-5 *1 (-1237 *4 *3)) (-4 *3 (-13 (-1234 *4) (-562) (-10 -8 (-15 -3069 ($ $ $)))))))) 
-(-10 -7 (-15 -1466 ((-424 |#2|) |#2|)) (-15 -2844 (|#2| |#2|)) (-15 -2586 ((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-572))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-572)))))) 
-((-3828 (((-1243 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1243 |#1| |#3| |#5|)) 23))) 
-(((-1238 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -3828 ((-1243 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1243 |#1| |#3| |#5|)))) (-1054) (-1054) (-1170) (-1170) |#1| |#2|) (T -1238)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1243 *5 *7 *9)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-14 *7 (-1170)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1243 *6 *8 *10)) (-5 *1 (-1238 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1170))))) 
-(-10 -7 (-15 -3828 ((-1243 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1243 |#1| |#3| |#5|)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 (-1082)) $) 70)) (-3342 (((-1170) $) 98)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-2525 (($ $ (-413 (-572))) 93) (($ $ (-413 (-572)) (-413 (-572))) 92)) (-2640 (((-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|))) $) 100)) (-4284 (($ $) 127 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 110 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 154 (|has| |#1| (-368)))) (-1466 (((-424 $) $) 155 (|has| |#1| (-368)))) (-4190 (($ $) 109 (|has| |#1| (-43 (-413 (-572)))))) (-3112 (((-121) $ $) 145 (|has| |#1| (-368)))) (-4273 (($ $) 126 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 111 (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-769) (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|)))) 164)) (-4295 (($ $) 125 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 112 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) 16 T CONST)) (-2190 (($ $ $) 149 (|has| |#1| (-368)))) (-4383 (($ $) 59)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 148 (|has| |#1| (-368)))) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 143 (|has| |#1| (-368)))) (-1526 (((-121) $) 156 (|has| |#1| (-368)))) (-1347 (((-121) $) 69)) (-4184 (($) 137 (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-413 (-572)) $) 95) (((-413 (-572)) $ (-413 (-572))) 94)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 108 (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) 96) (($ $ (-413 (-572))) 163)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 152 (|has| |#1| (-368)))) (-4581 (((-121) $) 61)) (-4328 (($ |#1| (-413 (-572))) 60) (($ $ (-1082) (-413 (-572))) 72) (($ $ (-638 (-1082)) (-638 (-413 (-572)))) 71)) (-3828 (($ (-1 |#1| |#1|) $) 62)) (-3539 (($ $) 134 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1629 (($ (-638 $)) 141 (|has| |#1| (-368))) (($ $ $) 140 (|has| |#1| (-368)))) (-1658 (((-1152) $) 9)) (-4350 (($ $) 157 (|has| |#1| (-368)))) (-2774 (($ $) 162 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 161 (-1841 (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-966)) (|has| |#1| (-1190)) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-43 (-413 (-572)))))))) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 142 (|has| |#1| (-368)))) (-3069 (($ (-638 $)) 139 (|has| |#1| (-368))) (($ $ $) 138 (|has| |#1| (-368)))) (-4304 (((-424 $) $) 153 (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 150 (|has| |#1| (-368)))) (-1977 (($ $ (-413 (-572))) 90)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 144 (|has| |#1| (-368)))) (-4179 (($ $) 135 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))))) (-4029 (((-769) $) 146 (|has| |#1| (-368)))) (-3277 ((|#1| $ (-413 (-572))) 99) (($ $ $) 76 (|has| (-413 (-572)) (-1110)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 147 (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) 84 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-1170) (-769)) 83 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-638 (-1170))) 82 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-1170)) 81 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-769)) 79 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-4316 (((-413 (-572)) $) 63)) (-4302 (($ $) 124 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 113 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 123 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 114 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 122 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 115 (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 68)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 46 (|has| |#1| (-174))) (($ (-413 (-572))) 56 (|has| |#1| (-43 (-413 (-572))))) (($ $) 48 (|has| |#1| (-562)))) (-1958 ((|#1| $ (-413 (-572))) 58)) (-2779 (((-3 $ "failed") $) 47 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-1694 ((|#1| $) 97)) (-4321 (($ $) 133 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 121 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-4308 (($ $) 132 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 120 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 131 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 119 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-413 (-572))) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 130 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 118 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 129 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 117 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 128 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 116 (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 158 (|has| |#1| (-368)))) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) 88 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-1170) (-769)) 87 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-638 (-1170))) 86 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-1170)) 85 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-769)) 80 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368))) (($ $ $) 160 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 159 (|has| |#1| (-368))) (($ $ $) 136 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 107 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1239 |#1|) (-1290) (-1054)) (T -1239)) 
-((-4521 (*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| *4)))) (-4 *4 (-1054)) (-4 *1 (-1239 *4)))) (-3965 (*1 *1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-4 *1 (-1239 *3)) (-4 *3 (-1054)))) (-2774 (*1 *1 *1) (-12 (-4 *1 (-1239 *2)) (-4 *2 (-1054)) (-4 *2 (-43 (-413 (-572)))))) (-2774 (*1 *1 *1 *2) (-1841 (-12 (-5 *2 (-1170)) (-4 *1 (-1239 *3)) (-4 *3 (-1054)) (-12 (-4 *3 (-29 (-572))) (-4 *3 (-966)) (-4 *3 (-1190)) (-4 *3 (-43 (-413 (-572)))))) (-12 (-5 *2 (-1170)) (-4 *1 (-1239 *3)) (-4 *3 (-1054)) (-12 (|has| *3 (-15 -3456 ((-638 *2) *3))) (|has| *3 (-15 -2774 (*3 *3 *2))) (-4 *3 (-43 (-413 (-572))))))))) 
-(-13 (-1236 |t#1| (-413 (-572))) (-10 -8 (-15 -4521 ($ (-769) (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |t#1|))))) (-15 -3965 ($ $ (-413 (-572)))) (IF (|has| |t#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $)) (IF (|has| |t#1| (-15 -2774 (|t#1| |t#1| (-1170)))) (IF (|has| |t#1| (-15 -3456 ((-638 (-1170)) |t#1|))) (-15 -2774 ($ $ (-1170))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1190)) (IF (|has| |t#1| (-966)) (IF (|has| |t#1| (-29 (-572))) (-15 -2774 ($ $ (-1170))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1009)) (-6 (-1190))) |noBranch|) (IF (|has| |t#1| (-368)) (-6 (-368)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-413 (-572))) . T) ((-25) . T) ((-43 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-40) |has| |#1| (-43 (-413 (-572)))) ((-98) |has| |#1| (-43 (-413 (-572)))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-227) |has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) ((-240) |has| |#1| (-368)) ((-281) |has| |#1| (-43 (-413 (-572)))) ((-283 $ $) |has| (-413 (-572)) (-1110)) ((-287) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-303) |has| |#1| (-368)) ((-368) |has| |#1| (-368)) ((-457) |has| |#1| (-368)) ((-506) |has| |#1| (-43 (-413 (-572)))) ((-562) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-641 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-722) . T) ((-901 (-1170)) -12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170)))) ((-981 |#1| (-413 (-572)) (-1082)) . T) ((-922) |has| |#1| (-368)) ((-1009) |has| |#1| (-43 (-413 (-572)))) ((-1060 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1190) |has| |#1| (-43 (-413 (-572)))) ((-1193) |has| |#1| (-43 (-413 (-572)))) ((-1214) |has| |#1| (-368)) ((-1236 |#1| (-413 (-572))) . T)) 
-((-1342 (((-121) $) 12)) (-3376 (((-3 |#3| "failed") $) 17)) (-1318 ((|#3| $) 14))) 
-(((-1240 |#1| |#2| |#3|) (-10 -8 (-15 -1318 (|#3| |#1|)) (-15 -3376 ((-3 |#3| "failed") |#1|)) (-15 -1342 ((-121) |#1|))) (-1241 |#2| |#3|) (-1054) (-1218 |#2|)) (T -1240)) 
-NIL 
-(-10 -8 (-15 -1318 (|#3| |#1|)) (-15 -3376 ((-3 |#3| "failed") |#1|)) (-15 -1342 ((-121) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 (-1082)) $) 70)) (-3342 (((-1170) $) 98)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-2525 (($ $ (-413 (-572))) 93) (($ $ (-413 (-572)) (-413 (-572))) 92)) (-2640 (((-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|))) $) 100)) (-4284 (($ $) 127 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 110 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 154 (|has| |#1| (-368)))) (-1466 (((-424 $) $) 155 (|has| |#1| (-368)))) (-4190 (($ $) 109 (|has| |#1| (-43 (-413 (-572)))))) (-3112 (((-121) $ $) 145 (|has| |#1| (-368)))) (-4273 (($ $) 126 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 111 (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-769) (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|)))) 164)) (-4295 (($ $) 125 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 112 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#2| "failed") $) 172)) (-1318 ((|#2| $) 171)) (-2190 (($ $ $) 149 (|has| |#1| (-368)))) (-4383 (($ $) 59)) (-1799 (((-3 $ "failed") $) 33)) (-4329 (((-413 (-572)) $) 169)) (-2208 (($ $ $) 148 (|has| |#1| (-368)))) (-1889 (($ (-413 (-572)) |#2|) 170)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 143 (|has| |#1| (-368)))) (-1526 (((-121) $) 156 (|has| |#1| (-368)))) (-1347 (((-121) $) 69)) (-4184 (($) 137 (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-413 (-572)) $) 95) (((-413 (-572)) $ (-413 (-572))) 94)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 108 (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) 96) (($ $ (-413 (-572))) 163)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 152 (|has| |#1| (-368)))) (-4581 (((-121) $) 61)) (-4328 (($ |#1| (-413 (-572))) 60) (($ $ (-1082) (-413 (-572))) 72) (($ $ (-638 (-1082)) (-638 (-413 (-572)))) 71)) (-3828 (($ (-1 |#1| |#1|) $) 62)) (-3539 (($ $) 134 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1629 (($ (-638 $)) 141 (|has| |#1| (-368))) (($ $ $) 140 (|has| |#1| (-368)))) (-4170 ((|#2| $) 168)) (-2475 (((-3 |#2| "failed") $) 166)) (-1885 ((|#2| $) 167)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 157 (|has| |#1| (-368)))) (-2774 (($ $) 162 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 161 (-1841 (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-966)) (|has| |#1| (-1190)) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-43 (-413 (-572)))))))) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 142 (|has| |#1| (-368)))) (-3069 (($ (-638 $)) 139 (|has| |#1| (-368))) (($ $ $) 138 (|has| |#1| (-368)))) (-4304 (((-424 $) $) 153 (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 150 (|has| |#1| (-368)))) (-1977 (($ $ (-413 (-572))) 90)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 144 (|has| |#1| (-368)))) (-4179 (($ $) 135 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))))) (-4029 (((-769) $) 146 (|has| |#1| (-368)))) (-3277 ((|#1| $ (-413 (-572))) 99) (($ $ $) 76 (|has| (-413 (-572)) (-1110)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 147 (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) 84 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-1170) (-769)) 83 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-638 (-1170))) 82 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-1170)) 81 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-769)) 79 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-4316 (((-413 (-572)) $) 63)) (-4302 (($ $) 124 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 113 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 123 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 114 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 122 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 115 (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 68)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 46 (|has| |#1| (-174))) (($ |#2|) 173) (($ (-413 (-572))) 56 (|has| |#1| (-43 (-413 (-572))))) (($ $) 48 (|has| |#1| (-562)))) (-1958 ((|#1| $ (-413 (-572))) 58)) (-2779 (((-3 $ "failed") $) 47 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-1694 ((|#1| $) 97)) (-4321 (($ $) 133 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 121 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-4308 (($ $) 132 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 120 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 131 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 119 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-413 (-572))) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 130 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 118 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 129 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 117 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 128 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 116 (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 158 (|has| |#1| (-368)))) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) 88 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-1170) (-769)) 87 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-638 (-1170))) 86 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-1170)) 85 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (($ $ (-769)) 80 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368))) (($ $ $) 160 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 159 (|has| |#1| (-368))) (($ $ $) 136 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 107 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1241 |#1| |#2|) (-1290) (-1054) (-1218 |t#1|)) (T -1241)) 
-((-4316 (*1 *2 *1) (-12 (-4 *1 (-1241 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1218 *3)) (-5 *2 (-413 (-572))))) (-3972 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *1 (-1241 *3 *2)) (-4 *2 (-1218 *3)))) (-1889 (*1 *1 *2 *3) (-12 (-5 *2 (-413 (-572))) (-4 *4 (-1054)) (-4 *1 (-1241 *4 *3)) (-4 *3 (-1218 *4)))) (-4329 (*1 *2 *1) (-12 (-4 *1 (-1241 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1218 *3)) (-5 *2 (-413 (-572))))) (-4170 (*1 *2 *1) (-12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1218 *3)))) (-1885 (*1 *2 *1) (-12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1218 *3)))) (-2475 (*1 *2 *1) (|partial| -12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1218 *3))))) 
-(-13 (-1239 |t#1|) (-1044 |t#2|) (-10 -8 (-15 -1889 ($ (-413 (-572)) |t#2|)) (-15 -4329 ((-413 (-572)) $)) (-15 -4170 (|t#2| $)) (-15 -4316 ((-413 (-572)) $)) (-15 -3972 ($ |t#2|)) (-15 -1885 (|t#2| $)) (-15 -2475 ((-3 |t#2| "failed") $)))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-413 (-572))) . T) ((-25) . T) ((-43 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-40) |has| |#1| (-43 (-413 (-572)))) ((-98) |has| |#1| (-43 (-413 (-572)))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-227) |has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) ((-240) |has| |#1| (-368)) ((-281) |has| |#1| (-43 (-413 (-572)))) ((-283 $ $) |has| (-413 (-572)) (-1110)) ((-287) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-303) |has| |#1| (-368)) ((-368) |has| |#1| (-368)) ((-457) |has| |#1| (-368)) ((-506) |has| |#1| (-43 (-413 (-572)))) ((-562) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-641 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368))) ((-722) . T) ((-901 (-1170)) -12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170)))) ((-981 |#1| (-413 (-572)) (-1082)) . T) ((-922) |has| |#1| (-368)) ((-1009) |has| |#1| (-43 (-413 (-572)))) ((-1044 |#2|) . T) ((-1060 (-413 (-572))) -1841 (|has| |#1| (-368)) (|has| |#1| (-43 (-413 (-572))))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-368)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1190) |has| |#1| (-43 (-413 (-572)))) ((-1193) |has| |#1| (-43 (-413 (-572)))) ((-1214) |has| |#1| (-368)) ((-1236 |#1| (-413 (-572))) . T) ((-1239 |#1|) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 96)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-413 (-572))) 106) (($ $ (-413 (-572)) (-413 (-572))) 108)) (-2640 (((-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|))) $) 51)) (-4284 (($ $) 179 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 155 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) 175 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 151 (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-769) (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|)))) 61)) (-4295 (($ $) 183 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 159 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) NIL)) (-1318 ((|#2| $) NIL)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) 79)) (-4329 (((-413 (-572)) $) 12)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-1889 (($ (-413 (-572)) |#2|) 10)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-1347 (((-121) $) 68)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-413 (-572)) $) 103) (((-413 (-572)) $ (-413 (-572))) 104)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) 120) (($ $ (-413 (-572))) 118)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-413 (-572))) 31) (($ $ (-1082) (-413 (-572))) NIL) (($ $ (-638 (-1082)) (-638 (-413 (-572)))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) 115)) (-3539 (($ $) 149 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-4170 ((|#2| $) 11)) (-2475 (((-3 |#2| "failed") $) 41)) (-1885 ((|#2| $) 42)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) 93 (|has| |#1| (-368)))) (-2774 (($ $) 135 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 140 (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190)))))) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1977 (($ $ (-413 (-572))) 112)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4179 (($ $) 147 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) 90 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ (-413 (-572))) 100) (($ $ $) 86 (|has| (-413 (-572)) (-1110)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) 127 (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) 124 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-4316 (((-413 (-572)) $) 16)) (-4302 (($ $) 185 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 161 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 181 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 157 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 177 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 153 (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 110)) (-3972 (((-856) $) NIL) (($ (-572)) 35) (($ |#1|) 27 (|has| |#1| (-174))) (($ |#2|) 32) (($ (-413 (-572))) 128 (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562)))) (-1958 ((|#1| $ (-413 (-572))) 99)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) 117)) (-1694 ((|#1| $) 98)) (-4321 (($ $) 191 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 167 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) 187 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 163 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 195 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 171 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-413 (-572))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 197 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 173 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 193 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 169 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 189 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 165 (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 21 T CONST)) (-3255 (($) 17 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-1324 (((-121) $ $) 66)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) 92 (|has| |#1| (-368)))) (-1373 (($ $) 131) (($ $ $) 72)) (-1367 (($ $ $) 70)) (** (($ $ (-923)) NIL) (($ $ (-769)) 76) (($ $ (-572)) 144 (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 145 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 74) (($ $ |#1|) NIL) (($ |#1| $) 126) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1242 |#1| |#2|) (-1241 |#1| |#2|) (-1054) (-1218 |#1|)) (T -1242)) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-1424 (($ $ (-944)) 25)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-1082) (-1311)) (T -1082)) 
+NIL 
+(-13 (-21) (-1131)) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-158) . T) ((-632 (-877)) . T) ((-1131) . T) ((-1119) . T)) 
+((-2306 (($ $) 16)) (-1755 (($ $) 22)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 49)) (-2793 (($ $) 24)) (-3856 (($ $) 11)) (-2039 (($ $) 38)) (-1778 (((-405) $) NIL) (((-237) $) NIL) (((-914 (-405)) $) 33)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL) (($ (-433 (-592))) 28) (($ (-592)) NIL) (($ (-433 (-592))) 28)) (-4010 (((-790)) 8)) (-2744 (($ $) 39))) 
+(((-1083 |#1|) (-10 -8 (-15 -1755 (|#1| |#1|)) (-15 -2306 (|#1| |#1|)) (-15 -3856 (|#1| |#1|)) (-15 -2039 (|#1| |#1|)) (-15 -2744 (|#1| |#1|)) (-15 -2793 (|#1| |#1|)) (-15 -3412 ((-911 (-405) |#1|) |#1| (-914 (-405)) (-911 (-405) |#1|))) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| (-592))) (-15 -1778 ((-237) |#1|)) (-15 -1778 ((-405) |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| |#1|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 -1683 ((-877) |#1|))) (-1084)) (T -1083)) 
+((-4010 (*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1083 *3)) (-4 *3 (-1084))))) 
+(-10 -8 (-15 -1755 (|#1| |#1|)) (-15 -2306 (|#1| |#1|)) (-15 -3856 (|#1| |#1|)) (-15 -2039 (|#1| |#1|)) (-15 -2744 (|#1| |#1|)) (-15 -2793 (|#1| |#1|)) (-15 -3412 ((-911 (-405) |#1|) |#1| (-914 (-405)) (-911 (-405) |#1|))) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| (-592))) (-15 -1778 ((-237) |#1|)) (-15 -1778 ((-405) |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| |#1|)) (-15 -1683 (|#1| (-592))) (-15 -4010 ((-790))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-1505 (((-592) $) 87)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2306 (($ $) 85)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 73)) (-3164 (((-444 $) $) 72)) (-1442 (($ $) 95)) (-3652 (((-141) $ $) 58)) (-3940 (((-592) $) 112)) (-3001 (($) 16 T CONST)) (-1755 (($ $) 84)) (-4368 (((-3 (-592) "failed") $) 100) (((-3 (-433 (-592)) "failed") $) 97)) (-2400 (((-592) $) 99) (((-433 (-592)) $) 96)) (-1586 (($ $ $) 54)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 55)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 50)) (-2802 (((-141) $) 71)) (-1691 (((-141) $) 110)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 91)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 94)) (-2793 (($ $) 90)) (-1324 (((-141) $) 111)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 51)) (-1837 (($ $ $) 109)) (-3319 (($ $ $) 108)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 48)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 70)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-3856 (($ $) 86)) (-2039 (($ $) 88)) (-4500 (((-444 $) $) 74)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 53) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 52)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 49)) (-2769 (((-790) $) 57)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 56)) (-1778 (((-405) $) 103) (((-237) $) 102) (((-914 (-405)) $) 92)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 65) (($ (-592)) 101) (($ (-433 (-592))) 98)) (-4010 (((-790)) 28)) (-2744 (($ $) 89)) (-2537 (((-141) $ $) 38)) (-1392 (($ $) 113)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 69)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3286 (((-141) $ $) 106)) (-3273 (((-141) $ $) 105)) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 107)) (-3266 (((-141) $ $) 104)) (-3313 (($ $ $) 64)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 68) (($ $ (-433 (-592))) 93)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 67) (($ (-433 (-592)) $) 66))) 
+(((-1084) (-1311)) (T -1084)) 
+((-1392 (*1 *1 *1) (-4 *1 (-1084))) (-2793 (*1 *1 *1) (-4 *1 (-1084))) (-2744 (*1 *1 *1) (-4 *1 (-1084))) (-2039 (*1 *1 *1) (-4 *1 (-1084))) (-1505 (*1 *2 *1) (-12 (-4 *1 (-1084)) (-5 *2 (-592)))) (-3856 (*1 *1 *1) (-4 *1 (-1084))) (-2306 (*1 *1 *1) (-4 *1 (-1084))) (-1755 (*1 *1 *1) (-4 *1 (-1084)))) 
+(-13 (-388) (-867) (-1049) (-1065 (-592)) (-1065 (-433 (-592))) (-1030) (-633 (-914 (-405))) (-908 (-405)) (-171) (-10 -8 (-15 -2793 ($ $)) (-15 -2744 ($ $)) (-15 -2039 ($ $)) (-15 -1505 ((-592) $)) (-15 -3856 ($ $)) (-15 -2306 ($ $)) (-15 -1755 ($ $)) (-15 -1392 ($ $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 $ $) . T) ((-158) . T) ((-171) . T) ((-632 (-877)) . T) ((-194) . T) ((-633 (-237)) . T) ((-633 (-405)) . T) ((-633 (-914 (-405))) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 $) . T) ((-743) . T) ((-813) . T) ((-814) . T) ((-816) . T) ((-817) . T) ((-867) . T) ((-869) . T) ((-908 (-405)) . T) ((-943) . T) ((-1030) . T) ((-1049) . T) ((-1065 (-433 (-592))) . T) ((-1065 (-592)) . T) ((-1081 (-433 (-592))) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) |#2| $) 23)) (-1403 ((|#1| $) 10)) (-3940 (((-592) |#2| $) 88)) (-3906 (((-3 $ "failed") |#2| (-944)) 58)) (-1954 ((|#1| $) 28)) (-4216 ((|#1| |#2| $ |#1|) 37)) (-4028 (($ $) 25)) (-3371 (((-3 |#2| "failed") |#2| $) 87)) (-1691 (((-141) |#2| $) NIL)) (-1324 (((-141) |#2| $) NIL)) (-3724 (((-141) |#2| $) 24)) (-3170 ((|#1| $) 89)) (-1961 ((|#1| $) 27)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3390 ((|#2| $) 79)) (-1683 (((-877) $) 71)) (-2642 ((|#1| |#2| $ |#1|) 38)) (-3740 (((-658 $) |#2|) 60)) (-3255 (((-141) $ $) 74))) 
+(((-1085 |#1| |#2|) (-13 (-1091 |#1| |#2|) (-10 -8 (-15 -1961 (|#1| $)) (-15 -1954 (|#1| $)) (-15 -1403 (|#1| $)) (-15 -3170 (|#1| $)) (-15 -4028 ($ $)) (-15 -3724 ((-141) |#2| $)) (-15 -4216 (|#1| |#2| $ |#1|)))) (-13 (-867) (-388)) (-1255 |#1|)) (T -1085)) 
+((-4216 (*1 *2 *3 *1 *2) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2)))) (-1961 (*1 *2 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2)))) (-1954 (*1 *2 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2)))) (-1403 (*1 *2 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2)))) (-3170 (*1 *2 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2)))) (-4028 (*1 *1 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2)))) (-3724 (*1 *2 *3 *1) (-12 (-4 *4 (-13 (-867) (-388))) (-5 *2 (-141)) (-5 *1 (-1085 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-13 (-1091 |#1| |#2|) (-10 -8 (-15 -1961 (|#1| $)) (-15 -1954 (|#1| $)) (-15 -1403 (|#1| $)) (-15 -3170 (|#1| $)) (-15 -4028 ($ $)) (-15 -3724 ((-141) |#2| $)) (-15 -4216 (|#1| |#2| $ |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2204 (($ $ $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1686 (($ $ $ $) NIL)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL)) (-3651 (($ $ $) NIL)) (-3001 (($) NIL T CONST)) (-2127 (($ (-1191)) 10) (($ (-592)) 7)) (-4368 (((-3 (-592) "failed") $) NIL)) (-2400 (((-592) $) NIL)) (-1586 (($ $ $) NIL)) (-3945 (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-706 (-592)) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-4182 (((-3 (-433 (-592)) "failed") $) NIL)) (-2435 (((-141) $) NIL)) (-2270 (((-433 (-592)) $) NIL)) (-4290 (($) NIL) (($ $) NIL)) (-1599 (($ $ $) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-2520 (($ $ $ $) NIL)) (-1592 (($ $ $) NIL)) (-1691 (((-141) $) NIL)) (-3870 (($ $ $) NIL)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL)) (-3558 (((-141) $) NIL)) (-3372 (((-141) $) NIL)) (-3921 (((-3 $ "failed") $) NIL)) (-1324 (((-141) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3260 (($ $ $ $) NIL)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-4561 (($ $) NIL)) (-4233 (($ $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4092 (($ $ $) NIL)) (-3703 (($) NIL T CONST)) (-4185 (($ $) NIL)) (-2951 (((-1137) $) NIL) (($ $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2283 (($ $) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3554 (((-141) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-3644 (($ $ (-790)) NIL) (($ $) NIL)) (-1676 (($ $) NIL)) (-4599 (($ $) NIL)) (-1778 (((-592) $) 16) (((-565) $) NIL) (((-914 (-592)) $) NIL) (((-405) $) NIL) (((-237) $) NIL) (($ (-1191)) 9)) (-1683 (((-877) $) 20) (($ (-592)) 6) (($ $) NIL) (($ (-592)) 6)) (-4010 (((-790)) NIL)) (-3911 (((-141) $ $) NIL)) (-4042 (($ $ $) NIL)) (-4226 (($) NIL)) (-2537 (((-141) $ $) NIL)) (-1475 (($ $ $ $) NIL)) (-1392 (($ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) NIL)) (-3306 (($ $) 19) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL))) 
+(((-1086) (-13 (-574) (-10 -8 (-6 -4612) (-6 -4617) (-6 -4613) (-15 -1778 ($ (-1191))) (-15 -2127 ($ (-1191))) (-15 -2127 ($ (-592)))))) (T -1086)) 
+((-1778 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1086)))) (-2127 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1086)))) (-2127 (*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1086))))) 
+(-13 (-574) (-10 -8 (-6 -4612) (-6 -4617) (-6 -4613) (-15 -1778 ($ (-1191))) (-15 -2127 ($ (-1191))) (-15 -2127 ($ (-592))))) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL)) (-3898 (((-1285) $ (-1191) (-1191)) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-2670 (($) 9)) (-3932 (((-57) $ (-1191) (-57)) NIL)) (-3152 (($ $) 23)) (-1320 (($ $) 21)) (-4333 (($ $) 20)) (-3311 (($ $) 22)) (-3915 (($ $) 25)) (-3808 (($ $) 26)) (-1383 (($ $) 19)) (-1754 (($ $) 24)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) 18 (|has| $ (-6 -4625)))) (-2916 (((-3 (-57) "failed") (-1191) $) 34)) (-3001 (($) NIL T CONST)) (-3041 (($) 7)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-4065 (($ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) 46 (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-3 (-57) "failed") (-1191) $) NIL)) (-4459 (($ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625)))) (-1312 (((-3 (-1173) "failed") $ (-1173) (-592)) 59)) (-1426 (((-57) $ (-1191) (-57)) NIL (|has| $ (-6 -4626)))) (-3959 (((-57) $ (-1191)) NIL)) (-4004 (((-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-658 (-57)) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-1191) $) NIL (|has| (-1191) (-869)))) (-4467 (((-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) 28 (|has| $ (-6 -4625))) (((-658 (-57)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (((-141) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119))))) (-1813 (((-1191) $) NIL (|has| (-1191) (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4626))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-2840 (((-658 (-1191)) $) NIL)) (-2396 (((-141) (-1191) $) NIL)) (-4137 (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL)) (-2113 (($ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) 37)) (-3708 (((-658 (-1191)) $) NIL)) (-3780 (((-141) (-1191) $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-2835 (((-405) $ (-1191)) 45)) (-2630 (((-658 (-1173)) $ (-1173)) 60)) (-1918 (((-57) $) NIL (|has| (-1191) (-869)))) (-4050 (((-3 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) "failed") (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL)) (-1892 (($ $ (-57)) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))))) NIL (-12 (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ $ (-310 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL (-12 (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ $ (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) NIL (-12 (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ $ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL (-12 (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-325 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (($ $ (-658 (-57)) (-658 (-57))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-310 (-57))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119)))) (($ $ (-658 (-310 (-57)))) NIL (-12 (|has| (-57) (-325 (-57))) (|has| (-57) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119))))) (-4210 (((-658 (-57)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 (((-57) $ (-1191)) NIL) (((-57) $ (-1191) (-57)) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL)) (-4288 (($ $ (-1191)) 47)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119)))) (((-790) (-57) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-57) (-1119)))) (((-790) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) 30)) (-2266 (($ $ $) 31)) (-1683 (((-877) $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-4541 (($ $ (-1191) (-405)) 43)) (-2020 (($ $ (-1191) (-405)) 44)) (-4560 (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 (-1191)) (|:| -3552 (-57)))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) (-57)) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-57) (-1119)) (|has| (-2 (|:| -1350 (-1191)) (|:| -3552 (-57))) (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1087) (-13 (-1202 (-1191) (-57)) (-10 -8 (-15 -2266 ($ $ $)) (-15 -3041 ($)) (-15 -1383 ($ $)) (-15 -4333 ($ $)) (-15 -1320 ($ $)) (-15 -3311 ($ $)) (-15 -1754 ($ $)) (-15 -3152 ($ $)) (-15 -3915 ($ $)) (-15 -3808 ($ $)) (-15 -4541 ($ $ (-1191) (-405))) (-15 -2020 ($ $ (-1191) (-405))) (-15 -2835 ((-405) $ (-1191))) (-15 -2630 ((-658 (-1173)) $ (-1173))) (-15 -4288 ($ $ (-1191))) (-15 -2670 ($)) (-15 -1312 ((-3 (-1173) "failed") $ (-1173) (-592))) (-6 -4625)))) (T -1087)) 
+((-2266 (*1 *1 *1 *1) (-5 *1 (-1087))) (-3041 (*1 *1) (-5 *1 (-1087))) (-1383 (*1 *1 *1) (-5 *1 (-1087))) (-4333 (*1 *1 *1) (-5 *1 (-1087))) (-1320 (*1 *1 *1) (-5 *1 (-1087))) (-3311 (*1 *1 *1) (-5 *1 (-1087))) (-1754 (*1 *1 *1) (-5 *1 (-1087))) (-3152 (*1 *1 *1) (-5 *1 (-1087))) (-3915 (*1 *1 *1) (-5 *1 (-1087))) (-3808 (*1 *1 *1) (-5 *1 (-1087))) (-4541 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-405)) (-5 *1 (-1087)))) (-2020 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-405)) (-5 *1 (-1087)))) (-2835 (*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-405)) (-5 *1 (-1087)))) (-2630 (*1 *2 *1 *3) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1087)) (-5 *3 (-1173)))) (-4288 (*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1087)))) (-2670 (*1 *1) (-5 *1 (-1087))) (-1312 (*1 *2 *1 *2 *3) (|partial| -12 (-5 *2 (-1173)) (-5 *3 (-592)) (-5 *1 (-1087))))) 
+(-13 (-1202 (-1191) (-57)) (-10 -8 (-15 -2266 ($ $ $)) (-15 -3041 ($)) (-15 -1383 ($ $)) (-15 -4333 ($ $)) (-15 -1320 ($ $)) (-15 -3311 ($ $)) (-15 -1754 ($ $)) (-15 -3152 ($ $)) (-15 -3915 ($ $)) (-15 -3808 ($ $)) (-15 -4541 ($ $ (-1191) (-405))) (-15 -2020 ($ $ (-1191) (-405))) (-15 -2835 ((-405) $ (-1191))) (-15 -2630 ((-658 (-1173)) $ (-1173))) (-15 -4288 ($ $ (-1191))) (-15 -2670 ($)) (-15 -1312 ((-3 (-1173) "failed") $ (-1173) (-592))) (-6 -4625))) 
+((-3188 (($ $) 45)) (-3078 (((-141) $ $) 74)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 (-592) "failed") $) NIL) (((-3 |#4| "failed") $) NIL) (((-3 $ "failed") (-980 (-433 (-592)))) 226) (((-3 $ "failed") (-980 (-592))) 225) (((-3 $ "failed") (-980 |#2|)) 228)) (-2400 ((|#2| $) NIL) (((-433 (-592)) $) NIL) (((-592) $) NIL) ((|#4| $) NIL) (($ (-980 (-433 (-592)))) 214) (($ (-980 (-592))) 210) (($ (-980 |#2|)) 230)) (-4593 (($ $) NIL) (($ $ |#4|) 43)) (-2172 (((-141) $ $) 111) (((-141) $ (-658 $)) 112)) (-2034 (((-141) $) 56)) (-4369 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 106)) (-4544 (($ $) 137)) (-1342 (($ $) 133)) (-2481 (($ $) 132)) (-3383 (($ $ $) 79) (($ $ $ |#4|) 84)) (-1877 (($ $ $) 82) (($ $ $ |#4|) 86)) (-2479 (((-141) $ $) 120) (((-141) $ (-658 $)) 121)) (-3259 ((|#4| $) 33)) (-4371 (($ $ $) 109)) (-1469 (((-141) $) 55)) (-1824 (((-790) $) 35)) (-3158 (($ $) 151)) (-4568 (($ $) 148)) (-4003 (((-658 $) $) 68)) (-4473 (($ $) 57)) (-3923 (($ $) 144)) (-3026 (((-658 $) $) 65)) (-1508 (($ $) 59)) (-4579 ((|#2| $) NIL) (($ $ |#4|) 38)) (-3037 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -3116 (-790))) $ $) 110)) (-2198 (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $) 107) (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $ |#4|) 108)) (-4517 (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -3027 $)) $ $) 103) (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -3027 $)) $ $ |#4|) 104)) (-1499 (($ $ $) 89) (($ $ $ |#4|) 94)) (-1494 (($ $ $) 90) (($ $ $ |#4|) 95)) (-2434 (((-658 $) $) 51)) (-2346 (((-141) $ $) 117) (((-141) $ (-658 $)) 118)) (-1751 (($ $ $) 102)) (-3703 (($ $) 37)) (-3085 (((-141) $ $) 72)) (-4442 (((-141) $ $) 113) (((-141) $ (-658 $)) 115)) (-1803 (($ $ $) 100)) (-3296 (($ $) 40)) (-3548 ((|#2| |#2| $) 141) (($ (-658 $)) NIL) (($ $ $) NIL)) (-2909 (($ $ |#2|) NIL) (($ $ $) 130)) (-3194 (($ $ |#2|) 125) (($ $ $) 128)) (-2676 (($ $) 48)) (-1526 (($ $) 52)) (-1778 (((-914 (-405)) $) NIL) (((-914 (-592)) $) NIL) (((-565) $) NIL) (($ (-980 (-433 (-592)))) 216) (($ (-980 (-592))) 212) (($ (-980 |#2|)) 227) (((-1173) $) 249) (((-980 |#2|) $) 161)) (-1683 (((-877) $) 30) (($ (-592)) NIL) (($ |#2|) NIL) (($ |#4|) NIL) (((-980 |#2|) $) 162) (($ (-433 (-592))) NIL) (($ $) NIL)) (-2745 (((-3 (-141) "failed") $ $) 71))) 
+(((-1088 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -1683 (|#1| |#1|)) (-15 -3548 (|#1| |#1| |#1|)) (-15 -3548 (|#1| (-658 |#1|))) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 ((-980 |#2|) |#1|)) (-15 -1778 ((-980 |#2|) |#1|)) (-15 -1778 ((-1173) |#1|)) (-15 -3158 (|#1| |#1|)) (-15 -4568 (|#1| |#1|)) (-15 -3923 (|#1| |#1|)) (-15 -4544 (|#1| |#1|)) (-15 -3548 (|#2| |#2| |#1|)) (-15 -2909 (|#1| |#1| |#1|)) (-15 -3194 (|#1| |#1| |#1|)) (-15 -2909 (|#1| |#1| |#2|)) (-15 -3194 (|#1| |#1| |#2|)) (-15 -1342 (|#1| |#1|)) (-15 -2481 (|#1| |#1|)) (-15 -1778 (|#1| (-980 |#2|))) (-15 -2400 (|#1| (-980 |#2|))) (-15 -4368 ((-3 |#1| "failed") (-980 |#2|))) (-15 -1778 (|#1| (-980 (-592)))) (-15 -2400 (|#1| (-980 (-592)))) (-15 -4368 ((-3 |#1| "failed") (-980 (-592)))) (-15 -1778 (|#1| (-980 (-433 (-592))))) (-15 -2400 (|#1| (-980 (-433 (-592))))) (-15 -4368 ((-3 |#1| "failed") (-980 (-433 (-592))))) (-15 -1751 (|#1| |#1| |#1|)) (-15 -1803 (|#1| |#1| |#1|)) (-15 -3037 ((-2 (|:| |polnum| |#1|) (|:| |polden| |#1|) (|:| -3116 (-790))) |#1| |#1|)) (-15 -4371 (|#1| |#1| |#1|)) (-15 -4369 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -2198 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1| |#4|)) (-15 -2198 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -4517 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -3027 |#1|)) |#1| |#1| |#4|)) (-15 -4517 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -1494 (|#1| |#1| |#1| |#4|)) (-15 -1499 (|#1| |#1| |#1| |#4|)) (-15 -1494 (|#1| |#1| |#1|)) (-15 -1499 (|#1| |#1| |#1|)) (-15 -1877 (|#1| |#1| |#1| |#4|)) (-15 -3383 (|#1| |#1| |#1| |#4|)) (-15 -1877 (|#1| |#1| |#1|)) (-15 -3383 (|#1| |#1| |#1|)) (-15 -2479 ((-141) |#1| (-658 |#1|))) (-15 -2479 ((-141) |#1| |#1|)) (-15 -2346 ((-141) |#1| (-658 |#1|))) (-15 -2346 ((-141) |#1| |#1|)) (-15 -4442 ((-141) |#1| (-658 |#1|))) (-15 -4442 ((-141) |#1| |#1|)) (-15 -2172 ((-141) |#1| (-658 |#1|))) (-15 -2172 ((-141) |#1| |#1|)) (-15 -3078 ((-141) |#1| |#1|)) (-15 -3085 ((-141) |#1| |#1|)) (-15 -2745 ((-3 (-141) "failed") |#1| |#1|)) (-15 -4003 ((-658 |#1|) |#1|)) (-15 -3026 ((-658 |#1|) |#1|)) (-15 -1508 (|#1| |#1|)) (-15 -4473 (|#1| |#1|)) (-15 -2034 ((-141) |#1|)) (-15 -1469 ((-141) |#1|)) (-15 -4593 (|#1| |#1| |#4|)) (-15 -4579 (|#1| |#1| |#4|)) (-15 -1526 (|#1| |#1|)) (-15 -2434 ((-658 |#1|) |#1|)) (-15 -2676 (|#1| |#1|)) (-15 -3188 (|#1| |#1|)) (-15 -3296 (|#1| |#1|)) (-15 -3703 (|#1| |#1|)) (-15 -1824 ((-790) |#1|)) (-15 -3259 (|#4| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -2400 (|#4| |#1|)) (-15 -4368 ((-3 |#4| "failed") |#1|)) (-15 -1683 (|#1| |#4|)) (-15 -4579 (|#2| |#1|)) (-15 -4593 (|#1| |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) (-1089 |#2| |#3| |#4|) (-1075) (-815) (-869)) (T -1088)) 
+NIL 
+(-10 -8 (-15 -1683 (|#1| |#1|)) (-15 -3548 (|#1| |#1| |#1|)) (-15 -3548 (|#1| (-658 |#1|))) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 ((-980 |#2|) |#1|)) (-15 -1778 ((-980 |#2|) |#1|)) (-15 -1778 ((-1173) |#1|)) (-15 -3158 (|#1| |#1|)) (-15 -4568 (|#1| |#1|)) (-15 -3923 (|#1| |#1|)) (-15 -4544 (|#1| |#1|)) (-15 -3548 (|#2| |#2| |#1|)) (-15 -2909 (|#1| |#1| |#1|)) (-15 -3194 (|#1| |#1| |#1|)) (-15 -2909 (|#1| |#1| |#2|)) (-15 -3194 (|#1| |#1| |#2|)) (-15 -1342 (|#1| |#1|)) (-15 -2481 (|#1| |#1|)) (-15 -1778 (|#1| (-980 |#2|))) (-15 -2400 (|#1| (-980 |#2|))) (-15 -4368 ((-3 |#1| "failed") (-980 |#2|))) (-15 -1778 (|#1| (-980 (-592)))) (-15 -2400 (|#1| (-980 (-592)))) (-15 -4368 ((-3 |#1| "failed") (-980 (-592)))) (-15 -1778 (|#1| (-980 (-433 (-592))))) (-15 -2400 (|#1| (-980 (-433 (-592))))) (-15 -4368 ((-3 |#1| "failed") (-980 (-433 (-592))))) (-15 -1751 (|#1| |#1| |#1|)) (-15 -1803 (|#1| |#1| |#1|)) (-15 -3037 ((-2 (|:| |polnum| |#1|) (|:| |polden| |#1|) (|:| -3116 (-790))) |#1| |#1|)) (-15 -4371 (|#1| |#1| |#1|)) (-15 -4369 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -2198 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1| |#4|)) (-15 -2198 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -4517 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -3027 |#1|)) |#1| |#1| |#4|)) (-15 -4517 ((-2 (|:| -1487 |#1|) (|:| |gap| (-790)) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -1494 (|#1| |#1| |#1| |#4|)) (-15 -1499 (|#1| |#1| |#1| |#4|)) (-15 -1494 (|#1| |#1| |#1|)) (-15 -1499 (|#1| |#1| |#1|)) (-15 -1877 (|#1| |#1| |#1| |#4|)) (-15 -3383 (|#1| |#1| |#1| |#4|)) (-15 -1877 (|#1| |#1| |#1|)) (-15 -3383 (|#1| |#1| |#1|)) (-15 -2479 ((-141) |#1| (-658 |#1|))) (-15 -2479 ((-141) |#1| |#1|)) (-15 -2346 ((-141) |#1| (-658 |#1|))) (-15 -2346 ((-141) |#1| |#1|)) (-15 -4442 ((-141) |#1| (-658 |#1|))) (-15 -4442 ((-141) |#1| |#1|)) (-15 -2172 ((-141) |#1| (-658 |#1|))) (-15 -2172 ((-141) |#1| |#1|)) (-15 -3078 ((-141) |#1| |#1|)) (-15 -3085 ((-141) |#1| |#1|)) (-15 -2745 ((-3 (-141) "failed") |#1| |#1|)) (-15 -4003 ((-658 |#1|) |#1|)) (-15 -3026 ((-658 |#1|) |#1|)) (-15 -1508 (|#1| |#1|)) (-15 -4473 (|#1| |#1|)) (-15 -2034 ((-141) |#1|)) (-15 -1469 ((-141) |#1|)) (-15 -4593 (|#1| |#1| |#4|)) (-15 -4579 (|#1| |#1| |#4|)) (-15 -1526 (|#1| |#1|)) (-15 -2434 ((-658 |#1|) |#1|)) (-15 -2676 (|#1| |#1|)) (-15 -3188 (|#1| |#1|)) (-15 -3296 (|#1| |#1|)) (-15 -3703 (|#1| |#1|)) (-15 -1824 ((-790) |#1|)) (-15 -3259 (|#4| |#1|)) (-15 -1778 ((-565) |#1|)) (-15 -1778 ((-914 (-592)) |#1|)) (-15 -1778 ((-914 (-405)) |#1|)) (-15 -2400 (|#4| |#1|)) (-15 -4368 ((-3 |#4| "failed") |#1|)) (-15 -1683 (|#1| |#4|)) (-15 -4579 (|#2| |#1|)) (-15 -4593 (|#1| |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 |#3|) $) 108)) (-4492 (((-1187 $) $ |#3|) 123) (((-1187 |#1|) $) 122)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 85 (|has| |#1| (-582)))) (-1555 (($ $) 86 (|has| |#1| (-582)))) (-1313 (((-141) $) 88 (|has| |#1| (-582)))) (-2189 (((-790) $) 110) (((-790) $ (-658 |#3|)) 109)) (-3188 (($ $) 250)) (-3078 (((-141) $ $) 236)) (-2350 (((-3 $ "failed") $ $) 18)) (-3250 (($ $ $) 195 (|has| |#1| (-582)))) (-3181 (((-658 $) $ $) 190 (|has| |#1| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) 98 (|has| |#1| (-931)))) (-3743 (($ $) 96 (|has| |#1| (-477)))) (-3164 (((-444 $) $) 95 (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 101 (|has| |#1| (-931)))) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 162) (((-3 (-433 (-592)) "failed") $) 160 (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) 158 (|has| |#1| (-1065 (-592)))) (((-3 |#3| "failed") $) 134) (((-3 $ "failed") (-980 (-433 (-592)))) 210 (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#3| (-633 (-1191))))) (((-3 $ "failed") (-980 (-592))) 207 (-3836 (-12 (-3252 (|has| |#1| (-43 (-433 (-592))))) (|has| |#1| (-43 (-592))) (|has| |#3| (-633 (-1191)))) (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#3| (-633 (-1191)))))) (((-3 $ "failed") (-980 |#1|)) 204 (-3836 (-12 (-3252 (|has| |#1| (-43 (-433 (-592))))) (-3252 (|has| |#1| (-43 (-592)))) (|has| |#3| (-633 (-1191)))) (-12 (-3252 (|has| |#1| (-574))) (-3252 (|has| |#1| (-43 (-433 (-592))))) (|has| |#1| (-43 (-592))) (|has| |#3| (-633 (-1191)))) (-12 (-3252 (|has| |#1| (-1021 (-592)))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#3| (-633 (-1191))))))) (-2400 ((|#1| $) 163) (((-433 (-592)) $) 159 (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) 157 (|has| |#1| (-1065 (-592)))) ((|#3| $) 133) (($ (-980 (-433 (-592)))) 209 (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#3| (-633 (-1191))))) (($ (-980 (-592))) 206 (-3836 (-12 (-3252 (|has| |#1| (-43 (-433 (-592))))) (|has| |#1| (-43 (-592))) (|has| |#3| (-633 (-1191)))) (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#3| (-633 (-1191)))))) (($ (-980 |#1|)) 203 (-3836 (-12 (-3252 (|has| |#1| (-43 (-433 (-592))))) (-3252 (|has| |#1| (-43 (-592)))) (|has| |#3| (-633 (-1191)))) (-12 (-3252 (|has| |#1| (-574))) (-3252 (|has| |#1| (-43 (-433 (-592))))) (|has| |#1| (-43 (-592))) (|has| |#3| (-633 (-1191)))) (-12 (-3252 (|has| |#1| (-1021 (-592)))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#3| (-633 (-1191))))))) (-1544 (($ $ $ |#3|) 106 (|has| |#1| (-194))) (($ $ $) 191 (|has| |#1| (-582)))) (-4593 (($ $) 152) (($ $ |#3|) 245)) (-3945 (((-706 (-592)) (-706 $)) 132 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 131 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 130) (((-706 |#1|) (-706 $)) 129)) (-2172 (((-141) $ $) 235) (((-141) $ (-658 $)) 234)) (-3371 (((-3 $ "failed") $) 33)) (-2034 (((-141) $) 243)) (-4369 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 215)) (-4544 (($ $) 184 (|has| |#1| (-477)))) (-3262 (($ $) 174 (|has| |#1| (-477))) (($ $ |#3|) 103 (|has| |#1| (-477)))) (-4585 (((-658 $) $) 107)) (-2802 (((-141) $) 94 (|has| |#1| (-931)))) (-1342 (($ $) 200 (|has| |#1| (-582)))) (-2481 (($ $) 201 (|has| |#1| (-582)))) (-3383 (($ $ $) 227) (($ $ $ |#3|) 225)) (-1877 (($ $ $) 226) (($ $ $ |#3|) 224)) (-4209 (($ $ |#1| |#2| $) 170)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 82 (-12 (|has| |#3| (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 81 (-12 (|has| |#3| (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-3558 (((-141) $) 30)) (-4036 (((-790) $) 167)) (-2479 (((-141) $ $) 229) (((-141) $ (-658 $)) 228)) (-2707 (($ $ $ $ $) 186 (|has| |#1| (-582)))) (-3259 ((|#3| $) 254)) (-4533 (($ (-1187 |#1|) |#3|) 115) (($ (-1187 $) |#3|) 114)) (-3108 (((-658 $) $) 124)) (-2027 (((-141) $) 150)) (-4526 (($ |#1| |#2|) 151) (($ $ |#3| (-790)) 117) (($ $ (-658 |#3|) (-658 (-790))) 116)) (-4371 (($ $ $) 214)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ |#3|) 118)) (-1469 (((-141) $) 244)) (-4206 ((|#2| $) 168) (((-790) $ |#3|) 120) (((-658 (-790)) $ (-658 |#3|)) 119)) (-1837 (($ $ $) 77 (|has| |#1| (-869)))) (-1824 (((-790) $) 253)) (-3319 (($ $ $) 76 (|has| |#1| (-869)))) (-2976 (($ (-1 |#2| |#2|) $) 169)) (-2731 (($ (-1 |#1| |#1|) $) 149)) (-3254 (((-3 |#3| "failed") $) 121)) (-3158 (($ $) 181 (|has| |#1| (-477)))) (-4568 (($ $) 182 (|has| |#1| (-477)))) (-4003 (((-658 $) $) 239)) (-4473 (($ $) 242)) (-3923 (($ $) 183 (|has| |#1| (-477)))) (-3026 (((-658 $) $) 240)) (-1508 (($ $) 241)) (-4573 (($ $) 147)) (-4579 ((|#1| $) 146) (($ $ |#3|) 246)) (-2750 (($ (-658 $)) 92 (|has| |#1| (-477))) (($ $ $) 91 (|has| |#1| (-477)))) (-3037 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -3116 (-790))) $ $) 213)) (-2198 (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $) 217) (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $ |#3|) 216)) (-4517 (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -3027 $)) $ $) 219) (((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -3027 $)) $ $ |#3|) 218)) (-1499 (($ $ $) 223) (($ $ $ |#3|) 221)) (-1494 (($ $ $) 222) (($ $ $ |#3|) 220)) (-2685 (((-1173) $) 9)) (-3722 (($ $ $) 189 (|has| |#1| (-582)))) (-2434 (((-658 $) $) 248)) (-4421 (((-3 (-658 $) "failed") $) 112)) (-2947 (((-3 (-658 $) "failed") $) 113)) (-2257 (((-3 (-2 (|:| |var| |#3|) (|:| -3215 (-790))) "failed") $) 111)) (-2346 (((-141) $ $) 231) (((-141) $ (-658 $)) 230)) (-1751 (($ $ $) 211)) (-3703 (($ $) 252)) (-3085 (((-141) $ $) 237)) (-4442 (((-141) $ $) 233) (((-141) $ (-658 $)) 232)) (-1803 (($ $ $) 212)) (-3296 (($ $) 251)) (-2951 (((-1137) $) 10)) (-1453 (((-2 (|:| -3548 $) (|:| |coef2| $)) $ $) 192 (|has| |#1| (-582)))) (-2845 (((-2 (|:| -3548 $) (|:| |coef1| $)) $ $) 193 (|has| |#1| (-582)))) (-4559 (((-141) $) 164)) (-4565 ((|#1| $) 165)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 93 (|has| |#1| (-477)))) (-3548 ((|#1| |#1| $) 185 (|has| |#1| (-477))) (($ (-658 $)) 90 (|has| |#1| (-477))) (($ $ $) 89 (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) 100 (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) 99 (|has| |#1| (-931)))) (-4500 (((-444 $) $) 97 (|has| |#1| (-931)))) (-2049 (((-2 (|:| -3548 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 194 (|has| |#1| (-582)))) (-3616 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-582))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-582)))) (-2909 (($ $ |#1|) 198 (|has| |#1| (-582))) (($ $ $) 196 (|has| |#1| (-582)))) (-3194 (($ $ |#1|) 199 (|has| |#1| (-582))) (($ $ $) 197 (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) 143) (($ $ (-310 $)) 142) (($ $ $ $) 141) (($ $ (-658 $) (-658 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-658 |#3|) (-658 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-658 |#3|) (-658 $)) 136)) (-1482 (($ $ |#3|) 105 (|has| |#1| (-194)))) (-3644 (($ $ |#3|) 41) (($ $ (-658 |#3|)) 40) (($ $ |#3| (-790)) 39) (($ $ (-658 |#3|) (-658 (-790))) 38)) (-4525 ((|#2| $) 148) (((-790) $ |#3|) 128) (((-658 (-790)) $ (-658 |#3|)) 127)) (-2676 (($ $) 249)) (-1526 (($ $) 247)) (-1778 (((-914 (-405)) $) 80 (-12 (|has| |#3| (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) 79 (-12 (|has| |#3| (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) 78 (-12 (|has| |#3| (-633 (-565))) (|has| |#1| (-633 (-565))))) (($ (-980 (-433 (-592)))) 208 (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#3| (-633 (-1191))))) (($ (-980 (-592))) 205 (-3836 (-12 (-3252 (|has| |#1| (-43 (-433 (-592))))) (|has| |#1| (-43 (-592))) (|has| |#3| (-633 (-1191)))) (-12 (|has| |#1| (-43 (-433 (-592)))) (|has| |#3| (-633 (-1191)))))) (($ (-980 |#1|)) 202 (|has| |#3| (-633 (-1191)))) (((-1173) $) 180 (-12 (|has| |#1| (-1065 (-592))) (|has| |#3| (-633 (-1191))))) (((-980 |#1|) $) 179 (|has| |#3| (-633 (-1191))))) (-1554 ((|#1| $) 173 (|has| |#1| (-477))) (($ $ |#3|) 104 (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 102 (-1732 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 161) (($ |#3|) 135) (((-980 |#1|) $) 178 (|has| |#3| (-633 (-1191)))) (($ (-433 (-592))) 70 (-3836 (|has| |#1| (-1065 (-433 (-592)))) (|has| |#1| (-43 (-433 (-592)))))) (($ $) 83 (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) 166)) (-1937 ((|#1| $ |#2|) 153) (($ $ |#3| (-790)) 126) (($ $ (-658 |#3|) (-658 (-790))) 125)) (-1517 (((-3 $ "failed") $) 71 (-3836 (-1732 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) 28)) (-4064 (($ $ $ (-790)) 171 (|has| |#1| (-194)))) (-2537 (((-141) $ $) 87 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-2745 (((-3 (-141) "failed") $ $) 238)) (-4257 (($) 29 T CONST)) (-4594 (($ $ $ $ (-790)) 187 (|has| |#1| (-582)))) (-2650 (($ $ $ (-790)) 188 (|has| |#1| (-582)))) (-1940 (($ $ |#3|) 37) (($ $ (-658 |#3|)) 36) (($ $ |#3| (-790)) 35) (($ $ (-658 |#3|) (-658 (-790))) 34)) (-3286 (((-141) $ $) 74 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 73 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 75 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 72 (|has| |#1| (-869)))) (-3313 (($ $ |#1|) 154 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 156 (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) 155 (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
+(((-1089 |#1| |#2| |#3|) (-1311) (-1075) (-815) (-869)) (T -1089)) 
+((-3259 (*1 *2 *1) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) (-1824 (*1 *2 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-790)))) (-3703 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-3296 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-3188 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-2676 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-2434 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1089 *3 *4 *5)))) (-1526 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-4579 (*1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) (-4593 (*1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) (-1469 (*1 *2 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-2034 (*1 *2 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-4473 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-1508 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-3026 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1089 *3 *4 *5)))) (-4003 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1089 *3 *4 *5)))) (-2745 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-3085 (*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-3078 (*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-2172 (*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-2172 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1089 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)))) (-4442 (*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-4442 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1089 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)))) (-2346 (*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-2346 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1089 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)))) (-2479 (*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) (-2479 (*1 *2 *1 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1089 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)))) (-3383 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-1877 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-3383 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) (-1877 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) (-1499 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-1494 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-1499 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) (-1494 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) (-4517 (*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -1487 *1) (|:| |gap| (-790)) (|:| -3027 *1))) (-4 *1 (-1089 *3 *4 *5)))) (-4517 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-2 (|:| -1487 *1) (|:| |gap| (-790)) (|:| -3027 *1))) (-4 *1 (-1089 *4 *5 *3)))) (-2198 (*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -1487 *1) (|:| |gap| (-790)) (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1089 *3 *4 *5)))) (-2198 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-2 (|:| -1487 *1) (|:| |gap| (-790)) (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1089 *4 *5 *3)))) (-4369 (*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1089 *3 *4 *5)))) (-4371 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-3037 (*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| |polnum| *1) (|:| |polden| *1) (|:| -3116 (-790)))) (-4 *1 (-1089 *3 *4 *5)))) (-1803 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-1751 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) (-4368 (*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-433 (-592)))) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)))) (-2400 (*1 *1 *2) (-12 (-5 *2 (-980 (-433 (-592)))) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-980 (-433 (-592)))) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)))) (-4368 (*1 *1 *2) (|partial| -3836 (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))))) (-2400 (*1 *1 *2) (-3836 (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))))) (-1778 (*1 *1 *2) (-3836 (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))))) (-4368 (*1 *1 *2) (|partial| -3836 (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-3252 (-4 *3 (-43 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-574))) (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-1021 (-592)))) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))))) (-2400 (*1 *1 *2) (-3836 (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-3252 (-4 *3 (-43 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-574))) (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-1021 (-592)))) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-980 *3)) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *5 (-633 (-1191))) (-4 *4 (-815)) (-4 *5 (-869)))) (-2481 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-1342 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-3194 (*1 *1 *1 *2) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-2909 (*1 *1 *1 *2) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-3194 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-2909 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-3250 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-2049 (*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -3548 *1) (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-1089 *3 *4 *5)))) (-2845 (*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -3548 *1) (|:| |coef1| *1))) (-4 *1 (-1089 *3 *4 *5)))) (-1453 (*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -3548 *1) (|:| |coef2| *1))) (-4 *1 (-1089 *3 *4 *5)))) (-1544 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-3181 (*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1089 *3 *4 *5)))) (-3722 (*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-2650 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *3 (-582)))) (-4594 (*1 *1 *1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *3 (-582)))) (-2707 (*1 *1 *1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) (-3548 (*1 *2 *2 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477)))) (-4544 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477)))) (-3923 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477)))) (-4568 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477)))) (-3158 (*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477))))) 
+(-13 (-977 |t#1| |t#2| |t#3|) (-10 -8 (-15 -3259 (|t#3| $)) (-15 -1824 ((-790) $)) (-15 -3703 ($ $)) (-15 -3296 ($ $)) (-15 -3188 ($ $)) (-15 -2676 ($ $)) (-15 -2434 ((-658 $) $)) (-15 -1526 ($ $)) (-15 -4579 ($ $ |t#3|)) (-15 -4593 ($ $ |t#3|)) (-15 -1469 ((-141) $)) (-15 -2034 ((-141) $)) (-15 -4473 ($ $)) (-15 -1508 ($ $)) (-15 -3026 ((-658 $) $)) (-15 -4003 ((-658 $) $)) (-15 -2745 ((-3 (-141) "failed") $ $)) (-15 -3085 ((-141) $ $)) (-15 -3078 ((-141) $ $)) (-15 -2172 ((-141) $ $)) (-15 -2172 ((-141) $ (-658 $))) (-15 -4442 ((-141) $ $)) (-15 -4442 ((-141) $ (-658 $))) (-15 -2346 ((-141) $ $)) (-15 -2346 ((-141) $ (-658 $))) (-15 -2479 ((-141) $ $)) (-15 -2479 ((-141) $ (-658 $))) (-15 -3383 ($ $ $)) (-15 -1877 ($ $ $)) (-15 -3383 ($ $ $ |t#3|)) (-15 -1877 ($ $ $ |t#3|)) (-15 -1499 ($ $ $)) (-15 -1494 ($ $ $)) (-15 -1499 ($ $ $ |t#3|)) (-15 -1494 ($ $ $ |t#3|)) (-15 -4517 ((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -3027 $)) $ $)) (-15 -4517 ((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -3027 $)) $ $ |t#3|)) (-15 -2198 ((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -2198 ((-2 (|:| -1487 $) (|:| |gap| (-790)) (|:| -2230 $) (|:| -3027 $)) $ $ |t#3|)) (-15 -4369 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -4371 ($ $ $)) (-15 -3037 ((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -3116 (-790))) $ $)) (-15 -1803 ($ $ $)) (-15 -1751 ($ $ $)) (IF (|has| |t#3| (-633 (-1191))) (PROGN (-6 (-632 (-980 |t#1|))) (-6 (-633 (-980 |t#1|))) (IF (|has| |t#1| (-43 (-433 (-592)))) (PROGN (-15 -4368 ((-3 $ "failed") (-980 (-433 (-592))))) (-15 -2400 ($ (-980 (-433 (-592))))) (-15 -1778 ($ (-980 (-433 (-592))))) (-15 -4368 ((-3 $ "failed") (-980 (-592)))) (-15 -2400 ($ (-980 (-592)))) (-15 -1778 ($ (-980 (-592)))) (IF (|has| |t#1| (-1021 (-592))) |noBranch| (PROGN (-15 -4368 ((-3 $ "failed") (-980 |t#1|))) (-15 -2400 ($ (-980 |t#1|)))))) |noBranch|) (IF (|has| |t#1| (-43 (-592))) (IF (|has| |t#1| (-43 (-433 (-592)))) |noBranch| (PROGN (-15 -4368 ((-3 $ "failed") (-980 (-592)))) (-15 -2400 ($ (-980 (-592)))) (-15 -1778 ($ (-980 (-592)))) (IF (|has| |t#1| (-574)) |noBranch| (PROGN (-15 -4368 ((-3 $ "failed") (-980 |t#1|))) (-15 -2400 ($ (-980 |t#1|))))))) |noBranch|) (IF (|has| |t#1| (-43 (-592))) |noBranch| (IF (|has| |t#1| (-43 (-433 (-592)))) |noBranch| (PROGN (-15 -4368 ((-3 $ "failed") (-980 |t#1|))) (-15 -2400 ($ (-980 |t#1|)))))) (-15 -1778 ($ (-980 |t#1|))) (IF (|has| |t#1| (-1065 (-592))) (-6 (-633 (-1173))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-582)) (PROGN (-15 -2481 ($ $)) (-15 -1342 ($ $)) (-15 -3194 ($ $ |t#1|)) (-15 -2909 ($ $ |t#1|)) (-15 -3194 ($ $ $)) (-15 -2909 ($ $ $)) (-15 -3250 ($ $ $)) (-15 -2049 ((-2 (|:| -3548 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -2845 ((-2 (|:| -3548 $) (|:| |coef1| $)) $ $)) (-15 -1453 ((-2 (|:| -3548 $) (|:| |coef2| $)) $ $)) (-15 -1544 ($ $ $)) (-15 -3181 ((-658 $) $ $)) (-15 -3722 ($ $ $)) (-15 -2650 ($ $ $ (-790))) (-15 -4594 ($ $ $ $ (-790))) (-15 -2707 ($ $ $ $ $))) |noBranch|) (IF (|has| |t#1| (-477)) (PROGN (-15 -3548 (|t#1| |t#1| $)) (-15 -4544 ($ $)) (-15 -3923 ($ $)) (-15 -4568 ($ $)) (-15 -3158 ($ $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-632 (-980 |#1|)) |has| |#3| (-633 (-1191))) ((-194) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-633 (-565)) -12 (|has| |#1| (-633 (-565))) (|has| |#3| (-633 (-565)))) ((-633 (-914 (-405))) -12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#3| (-633 (-914 (-405))))) ((-633 (-914 (-592))) -12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#3| (-633 (-914 (-592))))) ((-633 (-980 |#1|)) |has| |#3| (-633 (-1191))) ((-633 (-1173)) -12 (|has| |#1| (-1065 (-592))) (|has| |#3| (-633 (-1191)))) ((-307) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-325 $) . T) ((-346 |#1| |#2|) . T) ((-403 |#1|) . T) ((-437 |#1|) . T) ((-477) -3836 (|has| |#1| (-931)) (|has| |#1| (-477))) ((-547 |#3| |#1|) . T) ((-547 |#3| $) . T) ((-547 $ $) . T) ((-582) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) -3836 (|has| |#1| (-931)) (|has| |#1| (-477))) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477))) ((-743) . T) ((-869) |has| |#1| (-869)) ((-922 |#3|) . T) ((-908 (-405)) -12 (|has| |#1| (-908 (-405))) (|has| |#3| (-908 (-405)))) ((-908 (-592)) -12 (|has| |#1| (-908 (-592))) (|has| |#3| (-908 (-592)))) ((-977 |#1| |#2| |#3|) . T) ((-931) |has| |#1| (-931)) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 |#1|) . T) ((-1065 |#3|) . T) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) |has| |#1| (-931))) 
+((-2272 (((-141) |#3| $) 13)) (-3906 (((-3 $ "failed") |#3| (-944)) 23)) (-3371 (((-3 |#3| "failed") |#3| $) 37)) (-1691 (((-141) |#3| $) 16)) (-1324 (((-141) |#3| $) 14))) 
+(((-1090 |#1| |#2| |#3|) (-10 -8 (-15 -3906 ((-3 |#1| "failed") |#3| (-944))) (-15 -3371 ((-3 |#3| "failed") |#3| |#1|)) (-15 -1691 ((-141) |#3| |#1|)) (-15 -1324 ((-141) |#3| |#1|)) (-15 -2272 ((-141) |#3| |#1|))) (-1091 |#2| |#3|) (-13 (-867) (-388)) (-1255 |#2|)) (T -1090)) 
+NIL 
+(-10 -8 (-15 -3906 ((-3 |#1| "failed") |#3| (-944))) (-15 -3371 ((-3 |#3| "failed") |#3| |#1|)) (-15 -1691 ((-141) |#3| |#1|)) (-15 -1324 ((-141) |#3| |#1|)) (-15 -2272 ((-141) |#3| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) |#2| $) 20)) (-3940 (((-592) |#2| $) 21)) (-3906 (((-3 $ "failed") |#2| (-944)) 14)) (-4216 ((|#1| |#2| $ |#1|) 12)) (-3371 (((-3 |#2| "failed") |#2| $) 17)) (-1691 (((-141) |#2| $) 18)) (-1324 (((-141) |#2| $) 19)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-3390 ((|#2| $) 16)) (-1683 (((-877) $) 11)) (-2642 ((|#1| |#2| $ |#1|) 13)) (-3740 (((-658 $) |#2|) 15)) (-3255 (((-141) $ $) 6))) 
+(((-1091 |#1| |#2|) (-1311) (-13 (-867) (-388)) (-1255 |t#1|)) (T -1091)) 
+((-3940 (*1 *2 *3 *1) (-12 (-4 *1 (-1091 *4 *3)) (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-592)))) (-2272 (*1 *2 *3 *1) (-12 (-4 *1 (-1091 *4 *3)) (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-141)))) (-1324 (*1 *2 *3 *1) (-12 (-4 *1 (-1091 *4 *3)) (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-141)))) (-1691 (*1 *2 *3 *1) (-12 (-4 *1 (-1091 *4 *3)) (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-141)))) (-3371 (*1 *2 *2 *1) (|partial| -12 (-4 *1 (-1091 *3 *2)) (-4 *3 (-13 (-867) (-388))) (-4 *2 (-1255 *3)))) (-3390 (*1 *2 *1) (-12 (-4 *1 (-1091 *3 *2)) (-4 *3 (-13 (-867) (-388))) (-4 *2 (-1255 *3)))) (-3740 (*1 *2 *3) (-12 (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-658 *1)) (-4 *1 (-1091 *4 *3)))) (-3906 (*1 *1 *2 *3) (|partial| -12 (-5 *3 (-944)) (-4 *4 (-13 (-867) (-388))) (-4 *1 (-1091 *4 *2)) (-4 *2 (-1255 *4)))) (-2642 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1091 *2 *3)) (-4 *2 (-13 (-867) (-388))) (-4 *3 (-1255 *2)))) (-4216 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1091 *2 *3)) (-4 *2 (-13 (-867) (-388))) (-4 *3 (-1255 *2))))) 
+(-13 (-1119) (-10 -8 (-15 -3940 ((-592) |t#2| $)) (-15 -2272 ((-141) |t#2| $)) (-15 -1324 ((-141) |t#2| $)) (-15 -1691 ((-141) |t#2| $)) (-15 -3371 ((-3 |t#2| "failed") |t#2| $)) (-15 -3390 (|t#2| $)) (-15 -3740 ((-658 $) |t#2|)) (-15 -3906 ((-3 $ "failed") |t#2| (-944))) (-15 -2642 (|t#1| |t#2| $ |t#1|)) (-15 -4216 (|t#1| |t#2| $ |t#1|)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-3931 (((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 |#4|) (-658 |#5|) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-790)) 95)) (-4304 (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|) 56) (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790)) 55)) (-3891 (((-1285) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-790)) 87)) (-3148 (((-790) (-658 |#4|) (-658 |#5|)) 27)) (-2856 (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|) 58) (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790)) 57) (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790) (-141)) 59)) (-1906 (((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141) (-141) (-141) (-141)) 78) (((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141)) 79)) (-1778 (((-1173) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) 82)) (-1929 (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-141)) 54)) (-4270 (((-790) (-658 |#4|) (-658 |#5|)) 19))) 
+(((-1092 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4270 ((-790) (-658 |#4|) (-658 |#5|))) (-15 -3148 ((-790) (-658 |#4|) (-658 |#5|))) (-15 -1929 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-141))) (-15 -4304 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790))) (-15 -4304 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790) (-141))) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790))) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -1906 ((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141))) (-15 -1906 ((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141) (-141) (-141) (-141))) (-15 -3931 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 |#4|) (-658 |#5|) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-790))) (-15 -1778 ((-1173) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) (-15 -3891 ((-1285) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-790)))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1094 |#1| |#2| |#3| |#4|)) (T -1092)) 
+((-3891 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| |val| (-658 *8)) (|:| -2165 *9)))) (-5 *4 (-790)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-1285)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) (-1778 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-658 *7)) (|:| -2165 *8))) (-4 *7 (-1089 *4 *5 *6)) (-4 *8 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1173)) (-5 *1 (-1092 *4 *5 *6 *7 *8)))) (-3931 (*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-658 *11)) (|:| |todo| (-658 (-2 (|:| |val| *3) (|:| -2165 *11)))))) (-5 *6 (-790)) (-5 *2 (-658 (-2 (|:| |val| (-658 *10)) (|:| -2165 *11)))) (-5 *3 (-658 *10)) (-5 *4 (-658 *11)) (-4 *10 (-1089 *7 *8 *9)) (-4 *11 (-1094 *7 *8 *9 *10)) (-4 *7 (-477)) (-4 *8 (-815)) (-4 *9 (-869)) (-5 *1 (-1092 *7 *8 *9 *10 *11)))) (-1906 (*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-658 *9)) (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) (-1906 (*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-658 *9)) (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) (-2856 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-2856 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) (-2856 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-790)) (-5 *6 (-141)) (-4 *7 (-477)) (-4 *8 (-815)) (-4 *9 (-869)) (-4 *3 (-1089 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *7 *8 *9 *3 *4)) (-4 *4 (-1094 *7 *8 *9 *3)))) (-4304 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-4304 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) (-1929 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) (-3148 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *9)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-790)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) (-4270 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *9)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-790)) (-5 *1 (-1092 *5 *6 *7 *8 *9))))) 
+(-10 -7 (-15 -4270 ((-790) (-658 |#4|) (-658 |#5|))) (-15 -3148 ((-790) (-658 |#4|) (-658 |#5|))) (-15 -1929 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-141))) (-15 -4304 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790))) (-15 -4304 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790) (-141))) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790))) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -1906 ((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141))) (-15 -1906 ((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141) (-141) (-141) (-141))) (-15 -3931 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 |#4|) (-658 |#5|) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-790))) (-15 -1778 ((-1173) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) (-15 -3891 ((-1285) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-790)))) 
+((-1836 (((-141) |#5| $) 20)) (-2659 (((-141) |#5| $) 23)) (-3195 (((-141) |#5| $) 16) (((-141) $) 44)) (-2852 (((-658 $) |#5| $) NIL) (((-658 $) (-658 |#5|) $) 76) (((-658 $) (-658 |#5|) (-658 $)) 74) (((-658 $) |#5| (-658 $)) 77)) (-2807 (($ $ |#5|) NIL) (((-658 $) |#5| $) NIL) (((-658 $) |#5| (-658 $)) 59) (((-658 $) (-658 |#5|) $) 61) (((-658 $) (-658 |#5|) (-658 $)) 63)) (-3032 (((-658 $) |#5| $) NIL) (((-658 $) |#5| (-658 $)) 53) (((-658 $) (-658 |#5|) $) 55) (((-658 $) (-658 |#5|) (-658 $)) 57)) (-1437 (((-141) |#5| $) 26))) 
+(((-1093 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2807 ((-658 |#1|) (-658 |#5|) (-658 |#1|))) (-15 -2807 ((-658 |#1|) (-658 |#5|) |#1|)) (-15 -2807 ((-658 |#1|) |#5| (-658 |#1|))) (-15 -2807 ((-658 |#1|) |#5| |#1|)) (-15 -3032 ((-658 |#1|) (-658 |#5|) (-658 |#1|))) (-15 -3032 ((-658 |#1|) (-658 |#5|) |#1|)) (-15 -3032 ((-658 |#1|) |#5| (-658 |#1|))) (-15 -3032 ((-658 |#1|) |#5| |#1|)) (-15 -2852 ((-658 |#1|) |#5| (-658 |#1|))) (-15 -2852 ((-658 |#1|) (-658 |#5|) (-658 |#1|))) (-15 -2852 ((-658 |#1|) (-658 |#5|) |#1|)) (-15 -2852 ((-658 |#1|) |#5| |#1|)) (-15 -2659 ((-141) |#5| |#1|)) (-15 -3195 ((-141) |#1|)) (-15 -1437 ((-141) |#5| |#1|)) (-15 -1836 ((-141) |#5| |#1|)) (-15 -3195 ((-141) |#5| |#1|)) (-15 -2807 (|#1| |#1| |#5|))) (-1094 |#2| |#3| |#4| |#5|) (-477) (-815) (-869) (-1089 |#2| |#3| |#4|)) (T -1093)) 
+NIL 
+(-10 -8 (-15 -2807 ((-658 |#1|) (-658 |#5|) (-658 |#1|))) (-15 -2807 ((-658 |#1|) (-658 |#5|) |#1|)) (-15 -2807 ((-658 |#1|) |#5| (-658 |#1|))) (-15 -2807 ((-658 |#1|) |#5| |#1|)) (-15 -3032 ((-658 |#1|) (-658 |#5|) (-658 |#1|))) (-15 -3032 ((-658 |#1|) (-658 |#5|) |#1|)) (-15 -3032 ((-658 |#1|) |#5| (-658 |#1|))) (-15 -3032 ((-658 |#1|) |#5| |#1|)) (-15 -2852 ((-658 |#1|) |#5| (-658 |#1|))) (-15 -2852 ((-658 |#1|) (-658 |#5|) (-658 |#1|))) (-15 -2852 ((-658 |#1|) (-658 |#5|) |#1|)) (-15 -2852 ((-658 |#1|) |#5| |#1|)) (-15 -2659 ((-141) |#5| |#1|)) (-15 -3195 ((-141) |#1|)) (-15 -1437 ((-141) |#5| |#1|)) (-15 -1836 ((-141) |#5| |#1|)) (-15 -3195 ((-141) |#5| |#1|)) (-15 -2807 (|#1| |#1| |#5|))) 
+((-1641 (((-141) $ $) 7)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) 78)) (-2248 (((-658 $) (-658 |#4|)) 79) (((-658 $) (-658 |#4|) (-141)) 104)) (-4085 (((-658 |#3|) $) 32)) (-4325 (((-141) $) 25)) (-2988 (((-141) $) 16 (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) 94) (((-141) $) 90)) (-2244 ((|#4| |#4| $) 85)) (-3743 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| $) 119)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) 26)) (-2126 (((-141) $ (-790)) 43)) (-3113 (($ (-1 (-141) |#4|) $) 64 (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) 72)) (-3001 (($) 44 T CONST)) (-3239 (((-141) $) 21 (|has| |#1| (-582)))) (-3478 (((-141) $ $) 23 (|has| |#1| (-582)))) (-2398 (((-141) $ $) 22 (|has| |#1| (-582)))) (-1529 (((-141) $) 24 (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 86)) (-4521 (((-658 |#4|) (-658 |#4|) $) 17 (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) 18 (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) 35)) (-2400 (($ (-658 |#4|)) 34)) (-1366 (((-3 $ "failed") $) 75)) (-2226 ((|#4| |#4| $) 82)) (-1360 (($ $) 67 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#4| $) 66 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#4|) $) 63 (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) 95)) (-3092 ((|#4| |#4| $) 80)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 87)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) 98)) (-1836 (((-141) |#4| $) 129)) (-2659 (((-141) |#4| $) 126)) (-3195 (((-141) |#4| $) 130) (((-141) $) 127)) (-4004 (((-658 |#4|) $) 51 (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) 97) (((-141) $) 96)) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) 42)) (-4467 (((-658 |#4|) $) 52 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 54 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 46)) (-2290 (((-658 |#3|) $) 31)) (-2645 (((-141) |#3| $) 30)) (-2554 (((-141) $ (-790)) 41)) (-2685 (((-1173) $) 9)) (-1470 (((-3 |#4| (-658 $)) |#4| |#4| $) 121)) (-3722 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| |#4| $) 120)) (-4255 (((-3 |#4| "failed") $) 76)) (-3501 (((-658 $) |#4| $) 122)) (-3732 (((-3 (-141) (-658 $)) |#4| $) 125)) (-2978 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 $))) |#4| $) 124) (((-141) |#4| $) 123)) (-2852 (((-658 $) |#4| $) 118) (((-658 $) (-658 |#4|) $) 117) (((-658 $) (-658 |#4|) (-658 $)) 116) (((-658 $) |#4| (-658 $)) 115)) (-3902 (($ |#4| $) 110) (($ (-658 |#4|) $) 109)) (-1712 (((-658 |#4|) $) 100)) (-2346 (((-141) |#4| $) 92) (((-141) $) 88)) (-1751 ((|#4| |#4| $) 83)) (-3085 (((-141) $ $) 103)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) 93) (((-141) $) 89)) (-1803 ((|#4| |#4| $) 84)) (-2951 (((-1137) $) 10)) (-1918 (((-3 |#4| "failed") $) 77)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) 60)) (-2778 (((-3 $ "failed") $ |#4|) 71)) (-2807 (($ $ |#4|) 70) (((-658 $) |#4| $) 108) (((-658 $) |#4| (-658 $)) 107) (((-658 $) (-658 |#4|) $) 106) (((-658 $) (-658 |#4|) (-658 $)) 105)) (-3002 (((-141) (-1 (-141) |#4|) $) 49 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) 58 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) 56 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) 55 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) 37)) (-2943 (((-141) $) 40)) (-2890 (($) 39)) (-4525 (((-790) $) 99)) (-3452 (((-790) |#4| $) 53 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#4|) $) 50 (|has| $ (-6 -4625)))) (-4599 (($ $) 38)) (-1778 (((-565) $) 68 (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 59)) (-2613 (($ $ |#3|) 27)) (-4152 (($ $ |#3|) 29)) (-2965 (($ $) 81)) (-2507 (($ $ |#3|) 28)) (-1683 (((-877) $) 11) (((-658 |#4|) $) 36)) (-1857 (((-790) $) 69 (|has| |#3| (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) 101)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) 91)) (-3032 (((-658 $) |#4| $) 114) (((-658 $) |#4| (-658 $)) 113) (((-658 $) (-658 |#4|) $) 112) (((-658 $) (-658 |#4|) (-658 $)) 111)) (-3369 (((-141) (-1 (-141) |#4|) $) 48 (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) 74)) (-1437 (((-141) |#4| $) 128)) (-3069 (((-141) |#3| $) 73)) (-3255 (((-141) $ $) 6)) (-1699 (((-790) $) 45 (|has| $ (-6 -4625))))) 
+(((-1094 |#1| |#2| |#3| |#4|) (-1311) (-477) (-815) (-869) (-1089 |t#1| |t#2| |t#3|)) (T -1094)) 
+((-3195 (*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-1836 (*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-1437 (*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-3195 (*1 *2 *1) (-12 (-4 *1 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) (-2659 (*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-3732 (*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-3 (-141) (-658 *1))) (-4 *1 (-1094 *4 *5 *6 *3)))) (-2978 (*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *1)))) (-4 *1 (-1094 *4 *5 *6 *3)))) (-2978 (*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-3501 (*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)))) (-1470 (*1 *2 *3 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-3 *3 (-658 *1))) (-4 *1 (-1094 *4 *5 *6 *3)))) (-3722 (*1 *2 *3 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *1)))) (-4 *1 (-1094 *4 *5 *6 *3)))) (-3743 (*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *1)))) (-4 *1 (-1094 *4 *5 *6 *3)))) (-2852 (*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)))) (-2852 (*1 *2 *3 *1) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *7)))) (-2852 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-5 *3 (-658 *7)) (-4 *1 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)))) (-2852 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)))) (-3032 (*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)))) (-3032 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)))) (-3032 (*1 *2 *3 *1) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *7)))) (-3032 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-5 *3 (-658 *7)) (-4 *1 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)))) (-3902 (*1 *1 *2 *1) (-12 (-4 *1 (-1094 *3 *4 *5 *2)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-3902 (*1 *1 *2 *1) (-12 (-5 *2 (-658 *6)) (-4 *1 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)))) (-2807 (*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)))) (-2807 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)))) (-2807 (*1 *2 *3 *1) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *7)))) (-2807 (*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-5 *3 (-658 *7)) (-4 *1 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)))) (-2248 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *5 *6 *7 *8))))) 
+(-13 (-1219 |t#1| |t#2| |t#3| |t#4|) (-10 -8 (-15 -3195 ((-141) |t#4| $)) (-15 -1836 ((-141) |t#4| $)) (-15 -1437 ((-141) |t#4| $)) (-15 -3195 ((-141) $)) (-15 -2659 ((-141) |t#4| $)) (-15 -3732 ((-3 (-141) (-658 $)) |t#4| $)) (-15 -2978 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 $))) |t#4| $)) (-15 -2978 ((-141) |t#4| $)) (-15 -3501 ((-658 $) |t#4| $)) (-15 -1470 ((-3 |t#4| (-658 $)) |t#4| |t#4| $)) (-15 -3722 ((-658 (-2 (|:| |val| |t#4|) (|:| -2165 $))) |t#4| |t#4| $)) (-15 -3743 ((-658 (-2 (|:| |val| |t#4|) (|:| -2165 $))) |t#4| $)) (-15 -2852 ((-658 $) |t#4| $)) (-15 -2852 ((-658 $) (-658 |t#4|) $)) (-15 -2852 ((-658 $) (-658 |t#4|) (-658 $))) (-15 -2852 ((-658 $) |t#4| (-658 $))) (-15 -3032 ((-658 $) |t#4| $)) (-15 -3032 ((-658 $) |t#4| (-658 $))) (-15 -3032 ((-658 $) (-658 |t#4|) $)) (-15 -3032 ((-658 $) (-658 |t#4|) (-658 $))) (-15 -3902 ($ |t#4| $)) (-15 -3902 ($ (-658 |t#4|) $)) (-15 -2807 ((-658 $) |t#4| $)) (-15 -2807 ((-658 $) |t#4| (-658 $))) (-15 -2807 ((-658 $) (-658 |t#4|) $)) (-15 -2807 ((-658 $) (-658 |t#4|) (-658 $))) (-15 -2248 ((-658 $) (-658 |t#4|) (-141))))) 
+(((-39) . T) ((-125) . T) ((-632 (-658 |#4|)) . T) ((-632 (-877)) . T) ((-175 |#4|) . T) ((-633 (-565)) |has| |#4| (-633 (-565))) ((-325 |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-523 |#4|) . T) ((-547 |#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-1005 |#1| |#2| |#3| |#4|) . T) ((-1119) . T) ((-1219 |#1| |#2| |#3| |#4|) . T) ((-1225) . T)) 
+((-3658 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|) 81)) (-3096 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|) 112)) (-2977 (((-658 |#5|) |#4| |#5|) 70)) (-3566 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|) 44) (((-141) |#4| |#5|) 52)) (-1543 (((-1285)) 35)) (-3611 (((-1285)) 25)) (-2599 (((-1285) (-1173) (-1173) (-1173)) 31)) (-1938 (((-1285) (-1173) (-1173) (-1173)) 20)) (-2584 (((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#4| |#4| |#5|) 95)) (-4410 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#3| (-141)) 106) (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5| (-141) (-141)) 49)) (-2639 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|) 101))) 
+(((-1095 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1938 ((-1285) (-1173) (-1173) (-1173))) (-15 -3611 ((-1285))) (-15 -2599 ((-1285) (-1173) (-1173) (-1173))) (-15 -1543 ((-1285))) (-15 -2584 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -4410 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5| (-141) (-141))) (-15 -4410 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#3| (-141))) (-15 -2639 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -3096 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -3566 ((-141) |#4| |#5|)) (-15 -3566 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2977 ((-658 |#5|) |#4| |#5|)) (-15 -3658 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1094 |#1| |#2| |#3| |#4|)) (T -1095)) 
+((-3658 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-2977 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 *4)) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-3566 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-3566 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-3096 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-2639 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-4410 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-2 (|:| |val| (-658 *8)) (|:| -2165 *9)))) (-5 *5 (-141)) (-4 *8 (-1089 *6 *7 *4)) (-4 *9 (-1094 *6 *7 *4 *8)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *4 (-869)) (-5 *2 (-658 (-2 (|:| |val| *8) (|:| -2165 *9)))) (-5 *1 (-1095 *6 *7 *4 *8 *9)))) (-4410 (*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1095 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) (-2584 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-1543 (*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1095 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) (-2599 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1095 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-3611 (*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1095 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) (-1938 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1095 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -1938 ((-1285) (-1173) (-1173) (-1173))) (-15 -3611 ((-1285))) (-15 -2599 ((-1285) (-1173) (-1173) (-1173))) (-15 -1543 ((-1285))) (-15 -2584 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -4410 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5| (-141) (-141))) (-15 -4410 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#3| (-141))) (-15 -2639 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -3096 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -3566 ((-141) |#4| |#5|)) (-15 -3566 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2977 ((-658 |#5|) |#4| |#5|)) (-15 -3658 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|))) 
+((-1641 (((-141) $ $) NIL)) (-4095 (((-1191) $) 8)) (-2685 (((-1173) $) 16)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 13))) 
+(((-1096 |#1|) (-13 (-1119) (-10 -8 (-15 -4095 ((-1191) $)))) (-1191)) (T -1096)) 
+((-4095 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1096 *3)) (-14 *3 *2)))) 
+(-13 (-1119) (-10 -8 (-15 -4095 ((-1191) $)))) 
+((-1641 (((-141) $ $) NIL)) (-4355 (($ $ (-658 (-1191)) (-1 (-141) (-658 |#3|))) 29)) (-1512 (($ |#3| |#3|) 21) (($ |#3| |#3| (-658 (-1191))) 19)) (-1673 ((|#3| $) 13)) (-4368 (((-3 (-310 |#3|) "failed") $) 56)) (-2400 (((-310 |#3|) $) NIL)) (-2289 (((-658 (-1191)) $) 15)) (-2162 (((-914 |#1|) $) 11)) (-3634 ((|#3| $) 12)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3927 ((|#3| $ |#3|) 25) ((|#3| $ |#3| (-944)) 36)) (-1683 (((-877) $) 84) (($ (-310 |#3|)) 20)) (-3255 (((-141) $ $) 33))) 
+(((-1097 |#1| |#2| |#3|) (-13 (-1119) (-303 |#3| |#3|) (-1065 (-310 |#3|)) (-10 -8 (-15 -1512 ($ |#3| |#3|)) (-15 -1512 ($ |#3| |#3| (-658 (-1191)))) (-15 -4355 ($ $ (-658 (-1191)) (-1 (-141) (-658 |#3|)))) (-15 -2162 ((-914 |#1|) $)) (-15 -3634 (|#3| $)) (-15 -1673 (|#3| $)) (-15 -3927 (|#3| $ |#3| (-944))) (-15 -2289 ((-658 (-1191)) $)))) (-1119) (-13 (-1075) (-908 |#1|) (-869) (-633 (-914 |#1|))) (-13 (-456 |#2|) (-908 |#1|) (-633 (-914 |#1|)))) (T -1097)) 
+((-1512 (*1 *1 *2 *2) (-12 (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))) (-5 *1 (-1097 *3 *4 *2)) (-4 *2 (-13 (-456 *4) (-908 *3) (-633 (-914 *3)))))) (-1512 (*1 *1 *2 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-1097 *4 *5 *2)) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))))) (-4355 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-1 (-141) (-658 *6))) (-4 *6 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-1097 *4 *5 *6)))) (-2162 (*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 *2))) (-5 *2 (-914 *3)) (-5 *1 (-1097 *3 *4 *5)) (-4 *5 (-13 (-456 *4) (-908 *3) (-633 *2))))) (-3634 (*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *2 (-13 (-456 *4) (-908 *3) (-633 (-914 *3)))) (-5 *1 (-1097 *3 *4 *2)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))))) (-1673 (*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *2 (-13 (-456 *4) (-908 *3) (-633 (-914 *3)))) (-5 *1 (-1097 *3 *4 *2)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))))) (-3927 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-1097 *4 *5 *2)) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))))) (-2289 (*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))) (-5 *2 (-658 (-1191))) (-5 *1 (-1097 *3 *4 *5)) (-4 *5 (-13 (-456 *4) (-908 *3) (-633 (-914 *3))))))) 
+(-13 (-1119) (-303 |#3| |#3|) (-1065 (-310 |#3|)) (-10 -8 (-15 -1512 ($ |#3| |#3|)) (-15 -1512 ($ |#3| |#3| (-658 (-1191)))) (-15 -4355 ($ $ (-658 (-1191)) (-1 (-141) (-658 |#3|)))) (-15 -2162 ((-914 |#1|) $)) (-15 -3634 (|#3| $)) (-15 -1673 (|#3| $)) (-15 -3927 (|#3| $ |#3| (-944))) (-15 -2289 ((-658 (-1191)) $)))) 
+((-1641 (((-141) $ $) NIL)) (-1532 (($ (-658 (-1097 |#1| |#2| |#3|))) 12)) (-1566 (((-658 (-1097 |#1| |#2| |#3|)) $) 19)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3927 ((|#3| $ |#3|) 22) ((|#3| $ |#3| (-944)) 25)) (-1683 (((-877) $) 15)) (-3255 (((-141) $ $) 18))) 
+(((-1098 |#1| |#2| |#3|) (-13 (-1119) (-303 |#3| |#3|) (-10 -8 (-15 -1532 ($ (-658 (-1097 |#1| |#2| |#3|)))) (-15 -1566 ((-658 (-1097 |#1| |#2| |#3|)) $)) (-15 -3927 (|#3| $ |#3| (-944))))) (-1119) (-13 (-1075) (-908 |#1|) (-869) (-633 (-914 |#1|))) (-13 (-456 |#2|) (-908 |#1|) (-633 (-914 |#1|)))) (T -1098)) 
+((-1532 (*1 *1 *2) (-12 (-5 *2 (-658 (-1097 *3 *4 *5))) (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))) (-4 *5 (-13 (-456 *4) (-908 *3) (-633 (-914 *3)))) (-5 *1 (-1098 *3 *4 *5)))) (-1566 (*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))) (-5 *2 (-658 (-1097 *3 *4 *5))) (-5 *1 (-1098 *3 *4 *5)) (-4 *5 (-13 (-456 *4) (-908 *3) (-633 (-914 *3)))))) (-3927 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-1098 *4 *5 *2)) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4))))))) 
+(-13 (-1119) (-303 |#3| |#3|) (-10 -8 (-15 -1532 ($ (-658 (-1097 |#1| |#2| |#3|)))) (-15 -1566 ((-658 (-1097 |#1| |#2| |#3|)) $)) (-15 -3927 (|#3| $ |#3| (-944))))) 
+((-2004 (((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141)) 73) (((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|))) 75) (((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141)) 74))) 
+(((-1099 |#1| |#2|) (-10 -7 (-15 -2004 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141))) (-15 -2004 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)))) (-15 -2004 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141)))) (-13 (-323) (-171)) (-658 (-1191))) (T -1099)) 
+((-2004 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1099 *5 *6)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191))))) (-2004 (*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *4)) (|:| -2231 (-658 (-980 *4)))))) (-5 *1 (-1099 *4 *5)) (-5 *3 (-658 (-980 *4))) (-14 *5 (-658 (-1191))))) (-2004 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1099 *5 *6)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191)))))) 
+(-10 -7 (-15 -2004 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141))) (-15 -2004 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)))) (-15 -2004 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141)))) 
+((-4500 (((-444 |#3|) |#3|) 16))) 
+(((-1100 |#1| |#2| |#3|) (-10 -7 (-15 -4500 ((-444 |#3|) |#3|))) (-1255 (-433 (-592))) (-13 (-388) (-171) (-741 (-433 (-592)) |#1|)) (-1255 |#2|)) (T -1100)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-1255 (-433 (-592)))) (-4 *5 (-13 (-388) (-171) (-741 (-433 (-592)) *4))) (-5 *2 (-444 *3)) (-5 *1 (-1100 *4 *5 *3)) (-4 *3 (-1255 *5))))) 
+(-10 -7 (-15 -4500 ((-444 |#3|) |#3|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 125)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-388)))) (-1555 (($ $) NIL (|has| |#1| (-388)))) (-1313 (((-141) $) NIL (|has| |#1| (-388)))) (-1800 (((-706 |#1|) (-1280 $)) NIL) (((-706 |#1|)) 115)) (-4529 ((|#1| $) 119)) (-4217 (((-1199 (-944) (-790)) (-592)) NIL (|has| |#1| (-373)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1403 (((-790)) 40 (|has| |#1| (-394)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-1626 (($ (-1280 |#1|) (-1280 $)) NIL) (($ (-1280 |#1|)) 43)) (-4440 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-373)))) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4493 (((-706 |#1|) $ (-1280 $)) NIL) (((-706 |#1|) $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 106) (((-706 |#1|) (-706 $)) 100)) (-3657 (($ |#2|) 61) (((-3 $ "failed") (-433 |#2|)) NIL (|has| |#1| (-388)))) (-3371 (((-3 $ "failed") $) NIL)) (-4175 (((-944)) 77)) (-4290 (($) 44 (|has| |#1| (-394)))) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2667 (($) NIL (|has| |#1| (-373)))) (-3293 (((-141) $) NIL (|has| |#1| (-373)))) (-1525 (($ $ (-790)) NIL (|has| |#1| (-373))) (($ $) NIL (|has| |#1| (-373)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-4346 (((-944) $) NIL (|has| |#1| (-373))) (((-855 (-944)) $) NIL (|has| |#1| (-373)))) (-3558 (((-141) $) NIL)) (-2793 ((|#1| $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-373)))) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-3504 ((|#2| $) 84 (|has| |#1| (-388)))) (-3546 (((-944) $) 129 (|has| |#1| (-394)))) (-3650 ((|#2| $) 58)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-3703 (($) NIL (|has| |#1| (-373)) CONST)) (-1825 (($ (-944)) 124 (|has| |#1| (-394)))) (-2951 (((-1137) $) NIL)) (-2934 (($) 121)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-1967 (((-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592))))) NIL (|has| |#1| (-373)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-1482 ((|#1| (-1280 $)) NIL) ((|#1|) 109)) (-2177 (((-790) $) NIL (|has| |#1| (-373))) (((-3 (-790) "failed") $ $) NIL (|has| |#1| (-373)))) (-3644 (($ $) NIL (-3836 (-12 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373)))) (($ $ (-790)) NIL (-3836 (-12 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373)))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) (($ $ (-1 |#1| |#1|) (-790)) NIL (|has| |#1| (-388))) (($ $ (-1 |#1| |#1|)) NIL (|has| |#1| (-388)))) (-4174 (((-706 |#1|) (-1280 $) (-1 |#1| |#1|)) NIL (|has| |#1| (-388)))) (-3390 ((|#2|) 73)) (-3809 (($) NIL (|has| |#1| (-373)))) (-2231 (((-1280 |#1|) $ (-1280 $)) 89) (((-706 |#1|) (-1280 $) (-1280 $)) NIL) (((-1280 |#1|) $) 71) (((-706 |#1|) (-1280 $)) 85)) (-1778 (((-1280 |#1|) $) NIL) (($ (-1280 |#1|)) NIL) ((|#2| $) NIL) (($ |#2|) NIL)) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (|has| |#1| (-373)))) (-1683 (((-877) $) 57) (($ (-592)) 53) (($ |#1|) 54) (($ $) NIL (|has| |#1| (-388))) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-388)) (|has| |#1| (-1065 (-433 (-592))))))) (-1517 (($ $) NIL (|has| |#1| (-373))) (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4198 ((|#2| $) 82)) (-4010 (((-790)) 75)) (-2195 (((-1280 $)) 81)) (-2537 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 30 T CONST)) (-4257 (($) 19 T CONST)) (-1940 (($ $) NIL (-3836 (-12 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373)))) (($ $ (-790)) NIL (-3836 (-12 (|has| |#1| (-247)) (|has| |#1| (-388))) (|has| |#1| (-373)))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-388)) (|has| |#1| (-922 (-1191))))) (($ $ (-1 |#1| |#1|) (-790)) NIL (|has| |#1| (-388))) (($ $ (-1 |#1| |#1|)) NIL (|has| |#1| (-388)))) (-3255 (((-141) $ $) 63)) (-3313 (($ $ $) NIL (|has| |#1| (-388)))) (-3306 (($ $) 67) (($ $ $) NIL)) (-3300 (($ $ $) 65)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 51) (($ $ $) 69) (($ $ |#1|) NIL) (($ |#1| $) 48) (($ (-433 (-592)) $) NIL (|has| |#1| (-388))) (($ $ (-433 (-592))) NIL (|has| |#1| (-388))))) 
+(((-1101 |#1| |#2| |#3|) (-741 |#1| |#2|) (-194) (-1255 |#1|) |#2|) (T -1101)) 
+NIL 
+(-741 |#1| |#2|) 
+((-4500 (((-444 |#3|) |#3|) 16))) 
+(((-1102 |#1| |#2| |#3|) (-10 -7 (-15 -4500 ((-444 |#3|) |#3|))) (-1255 (-433 (-980 (-592)))) (-13 (-388) (-171) (-741 (-433 (-980 (-592))) |#1|)) (-1255 |#2|)) (T -1102)) 
+((-4500 (*1 *2 *3) (-12 (-4 *4 (-1255 (-433 (-980 (-592))))) (-4 *5 (-13 (-388) (-171) (-741 (-433 (-980 (-592))) *4))) (-5 *2 (-444 *3)) (-5 *1 (-1102 *4 *5 *3)) (-4 *3 (-1255 *5))))) 
+(-10 -7 (-15 -4500 ((-444 |#3|) |#3|))) 
+((-1641 (((-141) $ $) NIL)) (-1837 (($ $ $) 14)) (-3319 (($ $ $) 15)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2443 (($) 6)) (-1778 (((-1191) $) 18)) (-1683 (((-877) $) 12)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 13)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 8))) 
+(((-1103) (-13 (-869) (-10 -8 (-15 -2443 ($)) (-15 -1778 ((-1191) $))))) (T -1103)) 
+((-2443 (*1 *1) (-5 *1 (-1103))) (-1778 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1103))))) 
+(-13 (-869) (-10 -8 (-15 -2443 ($)) (-15 -1778 ((-1191) $)))) 
+((-2910 ((|#1| |#1| (-1 (-592) |#1| |#1|)) 21) ((|#1| |#1| (-1 (-141) |#1|)) 18)) (-4141 (((-1285)) 15)) (-2188 (((-658 |#1|)) 9))) 
+(((-1104 |#1|) (-10 -7 (-15 -4141 ((-1285))) (-15 -2188 ((-658 |#1|))) (-15 -2910 (|#1| |#1| (-1 (-141) |#1|))) (-15 -2910 (|#1| |#1| (-1 (-592) |#1| |#1|)))) (-159)) (T -1104)) 
+((-2910 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-592) *2 *2)) (-4 *2 (-159)) (-5 *1 (-1104 *2)))) (-2910 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-141) *2)) (-4 *2 (-159)) (-5 *1 (-1104 *2)))) (-2188 (*1 *2) (-12 (-5 *2 (-658 *3)) (-5 *1 (-1104 *3)) (-4 *3 (-159)))) (-4141 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1104 *3)) (-4 *3 (-159))))) 
+(-10 -7 (-15 -4141 ((-1285))) (-15 -2188 ((-658 |#1|))) (-15 -2910 (|#1| |#1| (-1 (-141) |#1|))) (-15 -2910 (|#1| |#1| (-1 (-592) |#1| |#1|)))) 
+((-4061 (((-1280 (-706 |#1|)) (-658 (-706 |#1|))) 41) (((-1280 (-706 (-980 |#1|))) (-658 (-1191)) (-706 (-980 |#1|))) 60) (((-1280 (-706 (-433 (-980 |#1|)))) (-658 (-1191)) (-706 (-433 (-980 |#1|)))) 76)) (-2231 (((-1280 |#1|) (-706 |#1|) (-658 (-706 |#1|))) 35))) 
+(((-1105 |#1|) (-10 -7 (-15 -4061 ((-1280 (-706 (-433 (-980 |#1|)))) (-658 (-1191)) (-706 (-433 (-980 |#1|))))) (-15 -4061 ((-1280 (-706 (-980 |#1|))) (-658 (-1191)) (-706 (-980 |#1|)))) (-15 -4061 ((-1280 (-706 |#1|)) (-658 (-706 |#1|)))) (-15 -2231 ((-1280 |#1|) (-706 |#1|) (-658 (-706 |#1|))))) (-388)) (T -1105)) 
+((-2231 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-706 *5))) (-5 *3 (-706 *5)) (-4 *5 (-388)) (-5 *2 (-1280 *5)) (-5 *1 (-1105 *5)))) (-4061 (*1 *2 *3) (-12 (-5 *3 (-658 (-706 *4))) (-4 *4 (-388)) (-5 *2 (-1280 (-706 *4))) (-5 *1 (-1105 *4)))) (-4061 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1191))) (-4 *5 (-388)) (-5 *2 (-1280 (-706 (-980 *5)))) (-5 *1 (-1105 *5)) (-5 *4 (-706 (-980 *5))))) (-4061 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1191))) (-4 *5 (-388)) (-5 *2 (-1280 (-706 (-433 (-980 *5))))) (-5 *1 (-1105 *5)) (-5 *4 (-706 (-433 (-980 *5))))))) 
+(-10 -7 (-15 -4061 ((-1280 (-706 (-433 (-980 |#1|)))) (-658 (-1191)) (-706 (-433 (-980 |#1|))))) (-15 -4061 ((-1280 (-706 (-980 |#1|))) (-658 (-1191)) (-706 (-980 |#1|)))) (-15 -4061 ((-1280 (-706 |#1|)) (-658 (-706 |#1|)))) (-15 -2231 ((-1280 |#1|) (-706 |#1|) (-658 (-706 |#1|))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2328 (((-141) $ $) 89) (((-141) (-658 $) (-658 $)) 94) (((-141) (-658 (-658 $))) 97)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4567 (((-877)) 88)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-150) "failed") $) NIL)) (-2400 (((-150) $) 68)) (-4319 (((-658 (-150)) $) 70)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1319 (((-141) $ (-150)) 64)) (-2724 (((-3 (-310 $) "failed") $ |#1|) 75) (((-3 (-310 $) "failed") |#1| $) 76)) (-4229 (($ $) 62)) (-3394 (((-1199 $ $)) 79)) (-1750 (((-1199 $ $)) 78)) (-1683 (((-877) $) 47) (($ (-150)) 35)) (-1937 (((-332 |#1|) $ (-150)) 66)) (-3907 (((-3 $ "failed") (-150) (-150) $) 39)) (-3054 (((-3 $ "failed") (-150) $) 40)) (-1424 (($ $ (-944)) 61)) (-3514 (($) 21 T CONST)) (-3255 (((-141) $ $) 33)) (-3313 (($ $ (-332 |#1|)) 11)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 56)) (** (($ $ (-944)) 60)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 32) (($ $ (-332 |#1|)) NIL) (($ (-332 |#1|) $) 10))) 
+(((-1106 |#1|) (-13 (-1082) (-734 (-332 |#1|)) (-10 -8 (-6 (-1065 (-150))) (-15 -3907 ((-3 $ "failed") (-150) (-150) $)) (-15 -3054 ((-3 $ "failed") (-150) $)) (-15 -4229 ($ $)) (-15 -1319 ((-141) $ (-150))) (-15 -1937 ((-332 |#1|) $ (-150))) (-15 -4319 ((-658 (-150)) $)) (-15 -2724 ((-3 (-310 $) "failed") $ |#1|)) (-15 -2724 ((-3 (-310 $) "failed") |#1| $)) (-15 -1750 ((-1199 $ $))) (-15 -3394 ((-1199 $ $))) (-15 -3313 ($ $ (-332 |#1|))) (-15 ** ($ $ (-944))) (-15 -1424 ($ $ (-944))) (-15 -4567 ((-877))) (-15 -2328 ((-141) $ $)) (-15 -2328 ((-141) (-658 $) (-658 $))) (-15 -2328 ((-141) (-658 (-658 $)))))) (-13 (-869) (-582))) (T -1106)) 
+((-1424 (*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-3907 (*1 *1 *2 *2 *1) (|partial| -12 (-5 *2 (-150)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-3054 (*1 *1 *2 *1) (|partial| -12 (-5 *2 (-150)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-4229 (*1 *1 *1) (-12 (-5 *1 (-1106 *2)) (-4 *2 (-13 (-869) (-582))))) (-1319 (*1 *2 *1 *3) (-12 (-5 *3 (-150)) (-5 *2 (-141)) (-5 *1 (-1106 *4)) (-4 *4 (-13 (-869) (-582))))) (-1937 (*1 *2 *1 *3) (-12 (-5 *3 (-150)) (-5 *2 (-332 *4)) (-5 *1 (-1106 *4)) (-4 *4 (-13 (-869) (-582))))) (-4319 (*1 *2 *1) (-12 (-5 *2 (-658 (-150))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-2724 (*1 *2 *1 *3) (|partial| -12 (-5 *2 (-310 (-1106 *3))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-2724 (*1 *2 *3 *1) (|partial| -12 (-5 *2 (-310 (-1106 *3))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-1750 (*1 *2) (-12 (-5 *2 (-1199 (-1106 *3) (-1106 *3))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-3394 (*1 *2) (-12 (-5 *2 (-1199 (-1106 *3) (-1106 *3))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-3313 (*1 *1 *1 *2) (-12 (-5 *2 (-332 *3)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-1106 *3)))) (-4567 (*1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-2328 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) (-2328 (*1 *2 *3 *3) (-12 (-5 *3 (-658 (-1106 *4))) (-5 *2 (-141)) (-5 *1 (-1106 *4)) (-4 *4 (-13 (-869) (-582))))) (-2328 (*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-1106 *4)))) (-5 *2 (-141)) (-5 *1 (-1106 *4)) (-4 *4 (-13 (-869) (-582)))))) 
+(-13 (-1082) (-734 (-332 |#1|)) (-10 -8 (-6 (-1065 (-150))) (-15 -3907 ((-3 $ "failed") (-150) (-150) $)) (-15 -3054 ((-3 $ "failed") (-150) $)) (-15 -4229 ($ $)) (-15 -1319 ((-141) $ (-150))) (-15 -1937 ((-332 |#1|) $ (-150))) (-15 -4319 ((-658 (-150)) $)) (-15 -2724 ((-3 (-310 $) "failed") $ |#1|)) (-15 -2724 ((-3 (-310 $) "failed") |#1| $)) (-15 -1750 ((-1199 $ $))) (-15 -3394 ((-1199 $ $))) (-15 -3313 ($ $ (-332 |#1|))) (-15 ** ($ $ (-944))) (-15 -1424 ($ $ (-944))) (-15 -4567 ((-877))) (-15 -2328 ((-141) $ $)) (-15 -2328 ((-141) (-658 $) (-658 $))) (-15 -2328 ((-141) (-658 (-658 $)))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1399 (((-658 (-790)) $) NIL) (((-658 (-790)) $ (-1191)) NIL)) (-3775 (((-790) $) NIL) (((-790) $ (-1191)) NIL)) (-4085 (((-658 (-1108 (-1191))) $) NIL)) (-4492 (((-1187 $) $ (-1108 (-1191))) NIL) (((-1187 |#1|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1108 (-1191)))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-1885 (($ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-1108 (-1191)) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL) (((-3 (-1142 |#1| (-1191)) "failed") $) NIL)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-1108 (-1191)) $) NIL) (((-1191) $) NIL) (((-1142 |#1| (-1191)) $) NIL)) (-1544 (($ $ $ (-1108 (-1191))) NIL (|has| |#1| (-194)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ (-1108 (-1191))) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-558 (-1108 (-1191))) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1108 (-1191)) (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1108 (-1191)) (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-4346 (((-790) $ (-1191)) NIL) (((-790) $) NIL)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-4533 (($ (-1187 |#1|) (-1108 (-1191))) NIL) (($ (-1187 $) (-1108 (-1191))) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-558 (-1108 (-1191)))) NIL) (($ $ (-1108 (-1191)) (-790)) NIL) (($ $ (-658 (-1108 (-1191))) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1108 (-1191))) NIL)) (-4206 (((-558 (-1108 (-1191))) $) NIL) (((-790) $ (-1108 (-1191))) NIL) (((-658 (-790)) $ (-658 (-1108 (-1191)))) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-558 (-1108 (-1191))) (-558 (-1108 (-1191)))) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3358 (((-1 $ (-790)) (-1191)) NIL) (((-1 $ (-790)) $) NIL (|has| |#1| (-247)))) (-3254 (((-3 (-1108 (-1191)) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-1692 (((-1108 (-1191)) $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-4401 (((-141) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-1108 (-1191))) (|:| -3215 (-790))) "failed") $) NIL)) (-3198 (($ $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1108 (-1191)) |#1|) NIL) (($ $ (-658 (-1108 (-1191))) (-658 |#1|)) NIL) (($ $ (-1108 (-1191)) $) NIL) (($ $ (-658 (-1108 (-1191))) (-658 $)) NIL) (($ $ (-1191) $) NIL (|has| |#1| (-247))) (($ $ (-658 (-1191)) (-658 $)) NIL (|has| |#1| (-247))) (($ $ (-1191) |#1|) NIL (|has| |#1| (-247))) (($ $ (-658 (-1191)) (-658 |#1|)) NIL (|has| |#1| (-247)))) (-1482 (($ $ (-1108 (-1191))) NIL (|has| |#1| (-194)))) (-3644 (($ $ (-1108 (-1191))) NIL) (($ $ (-658 (-1108 (-1191)))) NIL) (($ $ (-1108 (-1191)) (-790)) NIL) (($ $ (-658 (-1108 (-1191))) (-658 (-790))) NIL) (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2912 (((-658 (-1191)) $) NIL)) (-4525 (((-558 (-1108 (-1191))) $) NIL) (((-790) $ (-1108 (-1191))) NIL) (((-658 (-790)) $ (-658 (-1108 (-1191)))) NIL) (((-790) $ (-1191)) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-1108 (-1191)) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-1108 (-1191)) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-1108 (-1191)) (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) NIL (|has| |#1| (-477))) (($ $ (-1108 (-1191))) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-1108 (-1191))) NIL) (($ (-1191)) NIL) (($ (-1142 |#1| (-1191))) NIL) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-558 (-1108 (-1191)))) NIL) (($ $ (-1108 (-1191)) (-790)) NIL) (($ $ (-658 (-1108 (-1191))) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-1108 (-1191))) NIL) (($ $ (-658 (-1108 (-1191)))) NIL) (($ $ (-1108 (-1191)) (-790)) NIL) (($ $ (-658 (-1108 (-1191))) (-658 (-790))) NIL) (($ $) NIL (|has| |#1| (-247))) (($ $ (-790)) NIL (|has| |#1| (-247))) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-1107 |#1|) (-13 (-268 |#1| (-1191) (-1108 (-1191)) (-558 (-1108 (-1191)))) (-1065 (-1142 |#1| (-1191)))) (-1075)) (T -1107)) 
+NIL 
+(-13 (-268 |#1| (-1191) (-1108 (-1191)) (-558 (-1108 (-1191)))) (-1065 (-1142 |#1| (-1191)))) 
+((-1641 (((-141) $ $) NIL)) (-3775 (((-790) $) NIL)) (-3983 ((|#1| $) 10)) (-4368 (((-3 |#1| "failed") $) NIL)) (-2400 ((|#1| $) NIL)) (-4346 (((-790) $) 11)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-3358 (($ |#1| (-790)) 9)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3644 (($ $) NIL) (($ $ (-790)) NIL)) (-1683 (((-877) $) NIL) (($ |#1|) NIL)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 15))) 
+(((-1108 |#1|) (-284 |#1|) (-869)) (T -1108)) 
+NIL 
+(-284 |#1|) 
+((-2731 (((-658 |#2|) (-1 |#2| |#1|) (-1113 |#1|)) 23 (|has| |#1| (-867))) (((-1113 |#2|) (-1 |#2| |#1|) (-1113 |#1|)) 14))) 
+(((-1109 |#1| |#2|) (-10 -7 (-15 -2731 ((-1113 |#2|) (-1 |#2| |#1|) (-1113 |#1|))) (IF (|has| |#1| (-867)) (-15 -2731 ((-658 |#2|) (-1 |#2| |#1|) (-1113 |#1|))) |noBranch|)) (-1225) (-1225)) (T -1109)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1113 *5)) (-4 *5 (-867)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-658 *6)) (-5 *1 (-1109 *5 *6)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1113 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1113 *6)) (-5 *1 (-1109 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-1113 |#2|) (-1 |#2| |#1|) (-1113 |#1|))) (IF (|has| |#1| (-867)) (-15 -2731 ((-658 |#2|) (-1 |#2| |#1|) (-1113 |#1|))) |noBranch|)) 
+((-2731 (((-1111 |#2|) (-1 |#2| |#1|) (-1111 |#1|)) 19))) 
+(((-1110 |#1| |#2|) (-10 -7 (-15 -2731 ((-1111 |#2|) (-1 |#2| |#1|) (-1111 |#1|)))) (-1225) (-1225)) (T -1110)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1111 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1111 *6)) (-5 *1 (-1110 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-1111 |#2|) (-1 |#2| |#1|) (-1111 |#1|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3983 (((-1191) $) 11)) (-1896 (((-1113 |#1|) $) 12)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-2724 (($ (-1191) (-1113 |#1|)) 10)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3255 (((-141) $ $) 15 (|has| |#1| (-1119))))) 
+(((-1111 |#1|) (-13 (-1225) (-10 -8 (-15 -2724 ($ (-1191) (-1113 |#1|))) (-15 -3983 ((-1191) $)) (-15 -1896 ((-1113 |#1|) $)) (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|))) (-1225)) (T -1111)) 
+((-2724 (*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1113 *4)) (-4 *4 (-1225)) (-5 *1 (-1111 *4)))) (-3983 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1111 *3)) (-4 *3 (-1225)))) (-1896 (*1 *2 *1) (-12 (-5 *2 (-1113 *3)) (-5 *1 (-1111 *3)) (-4 *3 (-1225))))) 
+(-13 (-1225) (-10 -8 (-15 -2724 ($ (-1191) (-1113 |#1|))) (-15 -3983 ((-1191) $)) (-15 -1896 ((-1113 |#1|) $)) (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|))) 
+((-1896 (($ |#1| |#1|) 7)) (-2781 ((|#1| $) 10)) (-3000 ((|#1| $) 12)) (-3008 (((-592) $) 8)) (-2369 ((|#1| $) 9)) (-3015 ((|#1| $) 11)) (-1778 (($ |#1|) 6)) (-3766 (($ |#1| |#1|) 14)) (-2408 (($ $ (-592)) 13))) 
+(((-1112 |#1|) (-1311) (-1225)) (T -1112)) 
+((-3766 (*1 *1 *2 *2) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) (-2408 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1112 *3)) (-4 *3 (-1225)))) (-3000 (*1 *2 *1) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) (-3015 (*1 *2 *1) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) (-2781 (*1 *2 *1) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) (-2369 (*1 *2 *1) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) (-3008 (*1 *2 *1) (-12 (-4 *1 (-1112 *3)) (-4 *3 (-1225)) (-5 *2 (-592)))) (-1896 (*1 *1 *2 *2) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) (-1778 (*1 *1 *2) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225))))) 
+(-13 (-1225) (-10 -8 (-15 -3766 ($ |t#1| |t#1|)) (-15 -2408 ($ $ (-592))) (-15 -3000 (|t#1| $)) (-15 -3015 (|t#1| $)) (-15 -2781 (|t#1| $)) (-15 -2369 (|t#1| $)) (-15 -3008 ((-592) $)) (-15 -1896 ($ |t#1| |t#1|)) (-15 -1778 ($ |t#1|)))) 
+(((-1225) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1896 (($ |#1| |#1|) 15)) (-2731 (((-658 |#1|) (-1 |#1| |#1|) $) 37 (|has| |#1| (-867)))) (-2781 ((|#1| $) 10)) (-3000 ((|#1| $) 9)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3008 (((-592) $) 14)) (-2369 ((|#1| $) 12)) (-3015 ((|#1| $) 11)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3098 (((-658 |#1|) $) 35 (|has| |#1| (-867))) (((-658 |#1|) (-658 $)) 34 (|has| |#1| (-867)))) (-1778 (($ |#1|) 26)) (-1683 (((-877) $) 25 (|has| |#1| (-1119)))) (-3766 (($ |#1| |#1|) 8)) (-2408 (($ $ (-592)) 16)) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119))))) 
+(((-1113 |#1|) (-13 (-1112 |#1|) (-10 -7 (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|) (IF (|has| |#1| (-867)) (-6 (-1114 |#1| (-658 |#1|))) |noBranch|))) (-1225)) (T -1113)) 
+NIL 
+(-13 (-1112 |#1|) (-10 -7 (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|) (IF (|has| |#1| (-867)) (-6 (-1114 |#1| (-658 |#1|))) |noBranch|))) 
+((-1896 (($ |#1| |#1|) 7)) (-2731 ((|#2| (-1 |#1| |#1|) $) 15)) (-2781 ((|#1| $) 10)) (-3000 ((|#1| $) 12)) (-3008 (((-592) $) 8)) (-2369 ((|#1| $) 9)) (-3015 ((|#1| $) 11)) (-3098 ((|#2| (-658 $)) 17) ((|#2| $) 16)) (-1778 (($ |#1|) 6)) (-3766 (($ |#1| |#1|) 14)) (-2408 (($ $ (-592)) 13))) 
+(((-1114 |#1| |#2|) (-1311) (-867) (-1163 |t#1|)) (T -1114)) 
+((-3098 (*1 *2 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1114 *4 *2)) (-4 *4 (-867)) (-4 *2 (-1163 *4)))) (-3098 (*1 *2 *1) (-12 (-4 *1 (-1114 *3 *2)) (-4 *3 (-867)) (-4 *2 (-1163 *3)))) (-2731 (*1 *2 *3 *1) (-12 (-5 *3 (-1 *4 *4)) (-4 *1 (-1114 *4 *2)) (-4 *4 (-867)) (-4 *2 (-1163 *4))))) 
+(-13 (-1112 |t#1|) (-10 -8 (-15 -3098 (|t#2| (-658 $))) (-15 -3098 (|t#2| $)) (-15 -2731 (|t#2| (-1 |t#1| |t#1|) $)))) 
+(((-1112 |#1|) . T) ((-1225) . T)) 
+((-4528 (($ $ $) NIL) (($ $ |#2|) 13) (($ |#2| $) 14)) (-4471 (($ $ $) 10)) (-4328 (($ $ $) NIL) (($ $ |#2|) 15))) 
+(((-1115 |#1| |#2|) (-10 -8 (-15 -4528 (|#1| |#2| |#1|)) (-15 -4528 (|#1| |#1| |#2|)) (-15 -4528 (|#1| |#1| |#1|)) (-15 -4471 (|#1| |#1| |#1|)) (-15 -4328 (|#1| |#1| |#2|)) (-15 -4328 (|#1| |#1| |#1|))) (-1116 |#2|) (-1119)) (T -1115)) 
+NIL 
+(-10 -8 (-15 -4528 (|#1| |#2| |#1|)) (-15 -4528 (|#1| |#1| |#2|)) (-15 -4528 (|#1| |#1| |#1|)) (-15 -4471 (|#1| |#1| |#1|)) (-15 -4328 (|#1| |#1| |#2|)) (-15 -4328 (|#1| |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-4528 (($ $ $) 17) (($ $ |#1|) 16) (($ |#1| $) 15)) (-4471 (($ $ $) 19)) (-2461 (((-141) $ $) 18)) (-2126 (((-141) $ (-790)) 34)) (-2224 (($) 24) (($ (-658 |#1|)) 23)) (-3113 (($ (-1 (-141) |#1|) $) 55 (|has| $ (-6 -4625)))) (-3001 (($) 35 T CONST)) (-1360 (($ $) 58 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#1| $) 57 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 54 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 56 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 53 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 52 (|has| $ (-6 -4625)))) (-4004 (((-658 |#1|) $) 42 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 33)) (-4467 (((-658 |#1|) $) 43 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 45 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 38 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 37)) (-2554 (((-141) $ (-790)) 32)) (-2685 (((-1173) $) 9)) (-2852 (($ $ $) 22)) (-2951 (((-1137) $) 10)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 51)) (-3002 (((-141) (-1 (-141) |#1|) $) 40 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#1|) (-658 |#1|)) 49 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 48 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 47 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 (-310 |#1|))) 46 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 28)) (-2943 (((-141) $) 31)) (-2890 (($) 30)) (-4328 (($ $ $) 21) (($ $ |#1|) 20)) (-3452 (((-790) |#1| $) 44 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#1|) $) 41 (|has| $ (-6 -4625)))) (-4599 (($ $) 29)) (-1778 (((-565) $) 59 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 50)) (-1683 (((-877) $) 11)) (-4586 (($) 26) (($ (-658 |#1|)) 25)) (-3369 (((-141) (-1 (-141) |#1|) $) 39 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 6)) (-3266 (((-141) $ $) 27)) (-1699 (((-790) $) 36 (|has| $ (-6 -4625))))) 
+(((-1116 |#1|) (-1311) (-1119)) (T -1116)) 
+((-3266 (*1 *2 *1 *1) (-12 (-4 *1 (-1116 *3)) (-4 *3 (-1119)) (-5 *2 (-141)))) (-4586 (*1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) (-4586 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-1116 *3)))) (-2224 (*1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) (-2224 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-1116 *3)))) (-2852 (*1 *1 *1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) (-4328 (*1 *1 *1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) (-4328 (*1 *1 *1 *2) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) (-4471 (*1 *1 *1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) (-2461 (*1 *2 *1 *1) (-12 (-4 *1 (-1116 *3)) (-4 *3 (-1119)) (-5 *2 (-141)))) (-4528 (*1 *1 *1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) (-4528 (*1 *1 *1 *2) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) (-4528 (*1 *1 *2 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119))))) 
+(-13 (-1119) (-175 |t#1|) (-10 -8 (-6 -4615) (-15 -3266 ((-141) $ $)) (-15 -4586 ($)) (-15 -4586 ($ (-658 |t#1|))) (-15 -2224 ($)) (-15 -2224 ($ (-658 |t#1|))) (-15 -2852 ($ $ $)) (-15 -4328 ($ $ $)) (-15 -4328 ($ $ |t#1|)) (-15 -4471 ($ $ $)) (-15 -2461 ((-141) $ $)) (-15 -4528 ($ $ $)) (-15 -4528 ($ $ |t#1|)) (-15 -4528 ($ |t#1| $)))) 
+(((-39) . T) ((-125) . T) ((-632 (-877)) . T) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) . T) ((-1225) . T)) 
+((-1641 (((-141) $ $) 7)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-4525 (((-944) $) 12)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-1117) (-1311)) (T -1117)) 
+((-4525 (*1 *2 *1) (-12 (-4 *1 (-1117)) (-5 *2 (-944))))) 
+(-13 (-1119) (-10 -8 (-15 -4525 ((-944) $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-2685 (((-1173) $) 10)) (-2951 (((-1137) $) 8))) 
+(((-1118 |#1|) (-10 -8 (-15 -2685 ((-1173) |#1|)) (-15 -2951 ((-1137) |#1|))) (-1119)) (T -1118)) 
+NIL 
+(-10 -8 (-15 -2685 ((-1173) |#1|)) (-15 -2951 ((-1137) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-1119) (-1311)) (T -1119)) 
+((-2951 (*1 *2 *1) (-12 (-4 *1 (-1119)) (-5 *2 (-1137)))) (-2685 (*1 *2 *1) (-12 (-4 *1 (-1119)) (-5 *2 (-1173))))) 
+(-13 (-125) (-632 (-877)) (-10 -8 (-15 -2951 ((-1137) $)) (-15 -2685 ((-1173) $)))) 
+(((-125) . T) ((-632 (-877)) . T)) 
+((-1641 (((-141) $ $) NIL)) (-1403 (((-790)) 30)) (-4364 (($ (-658 (-944))) 52)) (-1934 (((-3 $ "failed") $ (-944) (-944)) 57)) (-4290 (($) 32)) (-3133 (((-141) (-944) $) 35)) (-3546 (((-944) $) 50)) (-2685 (((-1173) $) NIL)) (-1825 (($ (-944)) 31)) (-1369 (((-3 $ "failed") $ (-944)) 55)) (-2951 (((-1137) $) NIL)) (-1405 (((-658 $)) NIL) (((-1280 $)) 40)) (-3105 (((-658 (-944)) $) 23)) (-2026 (((-790) $ (-944) (-944)) 56)) (-1683 (((-877) $) 29)) (-3255 (((-141) $ $) 21))) 
+(((-1120 |#1| |#2|) (-13 (-394) (-10 -8 (-15 -1369 ((-3 $ "failed") $ (-944))) (-15 -1934 ((-3 $ "failed") $ (-944) (-944))) (-15 -3105 ((-658 (-944)) $)) (-15 -4364 ($ (-658 (-944)))) (-15 -1405 ((-1280 $))) (-15 -3133 ((-141) (-944) $)) (-15 -2026 ((-790) $ (-944) (-944))))) (-944) (-944)) (T -1120)) 
+((-1369 (*1 *1 *1 *2) (|partial| -12 (-5 *2 (-944)) (-5 *1 (-1120 *3 *4)) (-14 *3 *2) (-14 *4 *2))) (-1934 (*1 *1 *1 *2 *2) (|partial| -12 (-5 *2 (-944)) (-5 *1 (-1120 *3 *4)) (-14 *3 *2) (-14 *4 *2))) (-3105 (*1 *2 *1) (-12 (-5 *2 (-658 (-944))) (-5 *1 (-1120 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) (-4364 (*1 *1 *2) (-12 (-5 *2 (-658 (-944))) (-5 *1 (-1120 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) (-1405 (*1 *2) (-12 (-5 *2 (-1280 (-1120 *3 *4))) (-5 *1 (-1120 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) (-3133 (*1 *2 *3 *1) (-12 (-5 *3 (-944)) (-5 *2 (-141)) (-5 *1 (-1120 *4 *5)) (-14 *4 *3) (-14 *5 *3))) (-2026 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-790)) (-5 *1 (-1120 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
+(-13 (-394) (-10 -8 (-15 -1369 ((-3 $ "failed") $ (-944))) (-15 -1934 ((-3 $ "failed") $ (-944) (-944))) (-15 -3105 ((-658 (-944)) $)) (-15 -4364 ($ (-658 (-944)))) (-15 -1405 ((-1280 $))) (-15 -3133 ((-141) (-944) $)) (-15 -2026 ((-790) $ (-944) (-944))))) 
+((-1641 (((-141) $ $) NIL)) (-1875 (($) NIL (|has| |#1| (-394)))) (-4528 (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ $ $) 73)) (-4471 (($ $ $) 71)) (-2461 (((-141) $ $) 72)) (-2126 (((-141) $ (-790)) NIL)) (-1403 (((-790)) NIL (|has| |#1| (-394)))) (-2224 (($ (-658 |#1|)) NIL) (($) 13)) (-4125 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4065 (($ |#1| $) 67 (|has| $ (-6 -4625))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 43 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 41 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 39 (|has| $ (-6 -4625)))) (-4290 (($) NIL (|has| |#1| (-394)))) (-4004 (((-658 |#1|) $) 19 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-1837 ((|#1| $) 57 (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 66 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3319 ((|#1| $) 55 (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 33 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 34)) (-3546 (((-944) $) NIL (|has| |#1| (-394)))) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-2852 (($ $ $) 69)) (-4137 ((|#1| $) 25)) (-2113 (($ |#1| $) 65)) (-1825 (($ (-944)) NIL (|has| |#1| (-394)))) (-2951 (((-1137) $) NIL)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 31)) (-2106 ((|#1| $) 27)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1405 (((-658 $)) NIL (|has| |#1| (-394)))) (-2943 (((-141) $) 21)) (-2890 (($) 11)) (-4328 (($ $ |#1|) NIL) (($ $ $) 70)) (-1653 (($) NIL) (($ (-658 |#1|)) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) 16)) (-1778 (((-565) $) 52 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 61)) (-2184 (($ $) NIL (|has| |#1| (-394)))) (-1683 (((-877) $) NIL)) (-1484 (((-790) $) NIL)) (-4586 (($ (-658 |#1|)) NIL) (($) 12)) (-4560 (($ (-658 |#1|)) NIL)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 54)) (-3266 (((-141) $ $) NIL)) (-1699 (((-790) $) 10 (|has| $ (-6 -4625))))) 
+(((-1121 |#1|) (-451 |#1|) (-1119)) (T -1121)) 
+NIL 
+(-451 |#1|) 
+((-1641 (((-141) $ $) 7)) (-4188 (((-141) $) 31)) (-1398 ((|#2| $) 26)) (-4602 (((-141) $) 32)) (-4574 ((|#1| $) 27)) (-1549 (((-141) $) 34)) (-2830 (((-141) $) 36)) (-1968 (((-141) $) 33)) (-2685 (((-1173) $) 9)) (-4277 (((-141) $) 30)) (-4553 ((|#3| $) 25)) (-2951 (((-1137) $) 10)) (-4603 (((-141) $) 29)) (-4540 ((|#4| $) 24)) (-1564 ((|#5| $) 23)) (-2042 (((-141) $ $) 37)) (-3927 (($ $ (-592)) 13) (($ $ (-658 (-592))) 12)) (-4518 (((-658 $) $) 28)) (-1778 (($ (-658 $)) 22) (($ |#1|) 21) (($ |#2|) 20) (($ |#3|) 19) (($ |#4|) 18) (($ |#5|) 17)) (-1683 (((-877) $) 11)) (-1565 (($ $) 15)) (-1558 (($ $) 16)) (-2767 (((-141) $) 35)) (-3255 (((-141) $ $) 6)) (-1699 (((-592) $) 14))) 
+(((-1122 |#1| |#2| |#3| |#4| |#5|) (-1311) (-1119) (-1119) (-1119) (-1119) (-1119)) (T -1122)) 
+((-2042 (*1 *2 *1 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-2830 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-2767 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-1549 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-1968 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-4602 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-4188 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-4277 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-4603 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141)))) (-4518 (*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-658 *1)) (-4 *1 (-1122 *3 *4 *5 *6 *7)))) (-4574 (*1 *2 *1) (-12 (-4 *1 (-1122 *2 *3 *4 *5 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)))) (-1398 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *2 *4 *5 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)))) (-4553 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *2 *5 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)))) (-4540 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *2 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)))) (-1564 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *2)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)))) (-1778 (*1 *1 *2) (-12 (-4 *1 (-1122 *2 *3 *4 *5 *6)) (-4 *2 (-1119)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)))) (-1778 (*1 *1 *2) (-12 (-4 *1 (-1122 *3 *2 *4 *5 *6)) (-4 *3 (-1119)) (-4 *2 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)))) (-1778 (*1 *1 *2) (-12 (-4 *1 (-1122 *3 *4 *2 *5 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *2 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)))) (-1778 (*1 *1 *2) (-12 (-4 *1 (-1122 *3 *4 *5 *2 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *2 (-1119)) (-4 *6 (-1119)))) (-1778 (*1 *1 *2) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *2)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)))) (-1558 (*1 *1 *1) (-12 (-4 *1 (-1122 *2 *3 *4 *5 *6)) (-4 *2 (-1119)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)))) (-1565 (*1 *1 *1) (-12 (-4 *1 (-1122 *2 *3 *4 *5 *6)) (-4 *2 (-1119)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)))) (-1699 (*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-592)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119))))) 
+(-13 (-1119) (-10 -8 (-15 -2042 ((-141) $ $)) (-15 -2830 ((-141) $)) (-15 -2767 ((-141) $)) (-15 -1549 ((-141) $)) (-15 -1968 ((-141) $)) (-15 -4602 ((-141) $)) (-15 -4188 ((-141) $)) (-15 -4277 ((-141) $)) (-15 -4603 ((-141) $)) (-15 -4518 ((-658 $) $)) (-15 -4574 (|t#1| $)) (-15 -1398 (|t#2| $)) (-15 -4553 (|t#3| $)) (-15 -4540 (|t#4| $)) (-15 -1564 (|t#5| $)) (-15 -1778 ($ (-658 $))) (-15 -1778 ($ |t#1|)) (-15 -1778 ($ |t#2|)) (-15 -1778 ($ |t#3|)) (-15 -1778 ($ |t#4|)) (-15 -1778 ($ |t#5|)) (-15 -1558 ($ $)) (-15 -1565 ($ $)) (-15 -1699 ((-592) $)) (-15 -3927 ($ $ (-592))) (-15 -3927 ($ $ (-658 (-592)))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-4188 (((-141) $) NIL)) (-1398 (((-1191) $) NIL)) (-4602 (((-141) $) NIL)) (-4574 (((-1173) $) NIL)) (-1549 (((-141) $) NIL)) (-2830 (((-141) $) NIL)) (-1968 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-4277 (((-141) $) NIL)) (-4553 (((-592) $) NIL)) (-2951 (((-1137) $) NIL)) (-4603 (((-141) $) NIL)) (-4540 (((-237) $) NIL)) (-1564 (((-877) $) NIL)) (-2042 (((-141) $ $) NIL)) (-3927 (($ $ (-592)) NIL) (($ $ (-658 (-592))) NIL)) (-4518 (((-658 $) $) NIL)) (-1778 (($ (-658 $)) NIL) (($ (-1173)) NIL) (($ (-1191)) NIL) (($ (-592)) NIL) (($ (-237)) NIL) (($ (-877)) NIL)) (-1683 (((-877) $) NIL)) (-1565 (($ $) NIL)) (-1558 (($ $) NIL)) (-2767 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL)) (-1699 (((-592) $) NIL))) 
+(((-1123) (-1122 (-1173) (-1191) (-592) (-237) (-877))) (T -1123)) 
+NIL 
+(-1122 (-1173) (-1191) (-592) (-237) (-877)) 
+((-1641 (((-141) $ $) NIL)) (-4188 (((-141) $) 37)) (-1398 ((|#2| $) 41)) (-4602 (((-141) $) 36)) (-4574 ((|#1| $) 40)) (-1549 (((-141) $) 34)) (-2830 (((-141) $) 14)) (-1968 (((-141) $) 35)) (-2685 (((-1173) $) NIL)) (-4277 (((-141) $) 38)) (-4553 ((|#3| $) 43)) (-2951 (((-1137) $) NIL)) (-4603 (((-141) $) 39)) (-4540 ((|#4| $) 42)) (-1564 ((|#5| $) 44)) (-2042 (((-141) $ $) 33)) (-3927 (($ $ (-592)) 55) (($ $ (-658 (-592))) 57)) (-4518 (((-658 $) $) 21)) (-1778 (($ (-658 $)) 45) (($ |#1|) 46) (($ |#2|) 47) (($ |#3|) 48) (($ |#4|) 49) (($ |#5|) 50)) (-1683 (((-877) $) 22)) (-1565 (($ $) 20)) (-1558 (($ $) 51)) (-2767 (((-141) $) 18)) (-3255 (((-141) $ $) 32)) (-1699 (((-592) $) 53))) 
+(((-1124 |#1| |#2| |#3| |#4| |#5|) (-1122 |#1| |#2| |#3| |#4| |#5|) (-1119) (-1119) (-1119) (-1119) (-1119)) (T -1124)) 
+NIL 
+(-1122 |#1| |#2| |#3| |#4| |#5|) 
+((-3592 (((-1285) $) 23)) (-2406 (($ (-1191) (-460) |#2|) 11)) (-1683 (((-877) $) 16))) 
+(((-1125 |#1| |#2|) (-13 (-421) (-10 -8 (-15 -2406 ($ (-1191) (-460) |#2|)))) (-869) (-456 |#1|)) (T -1125)) 
+((-2406 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-460)) (-4 *5 (-869)) (-5 *1 (-1125 *5 *4)) (-4 *4 (-456 *5))))) 
+(-13 (-421) (-10 -8 (-15 -2406 ($ (-1191) (-460) |#2|)))) 
+((-3635 (((-141) |#5| |#5|) 37)) (-2846 (((-141) |#5| |#5|) 51)) (-3962 (((-141) |#5| (-658 |#5|)) 74) (((-141) |#5| |#5|) 60)) (-3988 (((-141) (-658 |#4|) (-658 |#4|)) 57)) (-2728 (((-141) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) 62)) (-3128 (((-1285)) 33)) (-4376 (((-1285) (-1173) (-1173) (-1173)) 29)) (-1859 (((-658 |#5|) (-658 |#5|)) 81)) (-2441 (((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) 79)) (-4015 (((-658 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|)))) (-658 |#4|) (-658 |#5|) (-141) (-141)) 101)) (-1496 (((-141) |#5| |#5|) 46)) (-2655 (((-3 (-141) "failed") |#5| |#5|) 70)) (-3274 (((-141) (-658 |#4|) (-658 |#4|)) 56)) (-3481 (((-141) (-658 |#4|) (-658 |#4|)) 58)) (-3085 (((-141) (-658 |#4|) (-658 |#4|)) 59)) (-1481 (((-3 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|))) "failed") (-658 |#4|) |#5| (-658 |#4|) (-141) (-141) (-141) (-141) (-141)) 97)) (-3174 (((-658 |#5|) (-658 |#5|)) 42))) 
+(((-1126 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4376 ((-1285) (-1173) (-1173) (-1173))) (-15 -3128 ((-1285))) (-15 -3635 ((-141) |#5| |#5|)) (-15 -3174 ((-658 |#5|) (-658 |#5|))) (-15 -1496 ((-141) |#5| |#5|)) (-15 -2846 ((-141) |#5| |#5|)) (-15 -3988 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3274 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3481 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3085 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -2655 ((-3 (-141) "failed") |#5| |#5|)) (-15 -3962 ((-141) |#5| |#5|)) (-15 -3962 ((-141) |#5| (-658 |#5|))) (-15 -1859 ((-658 |#5|) (-658 |#5|))) (-15 -2728 ((-141) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) (-15 -2441 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-15 -4015 ((-658 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|)))) (-658 |#4|) (-658 |#5|) (-141) (-141))) (-15 -1481 ((-3 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|))) "failed") (-658 |#4|) |#5| (-658 |#4|) (-141) (-141) (-141) (-141) (-141)))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1094 |#1| |#2| |#3| |#4|)) (T -1126)) 
+((-1481 (*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| -2042 (-658 *9)) (|:| -2165 *4) (|:| |ineq| (-658 *9)))) (-5 *1 (-1126 *6 *7 *8 *9 *4)) (-5 *3 (-658 *9)) (-4 *4 (-1094 *6 *7 *8 *9)))) (-4015 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-658 *10)) (-5 *5 (-141)) (-4 *10 (-1094 *6 *7 *8 *9)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-1089 *6 *7 *8)) (-5 *2 (-658 (-2 (|:| -2042 (-658 *9)) (|:| -2165 *10) (|:| |ineq| (-658 *9))))) (-5 *1 (-1126 *6 *7 *8 *9 *10)) (-5 *3 (-658 *9)))) (-2441 (*1 *2 *2) (-12 (-5 *2 (-658 (-2 (|:| |val| (-658 *6)) (|:| -2165 *7)))) (-4 *6 (-1089 *3 *4 *5)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1126 *3 *4 *5 *6 *7)))) (-2728 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-658 *7)) (|:| -2165 *8))) (-4 *7 (-1089 *4 *5 *6)) (-4 *8 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)))) (-1859 (*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-1126 *3 *4 *5 *6 *7)))) (-3962 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-1126 *5 *6 *7 *8 *3)))) (-3962 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-2655 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-3085 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-3481 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-3274 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-3988 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-2846 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-1496 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-3174 (*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-1126 *3 *4 *5 *6 *7)))) (-3635 (*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) (-3128 (*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1126 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) (-4376 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -4376 ((-1285) (-1173) (-1173) (-1173))) (-15 -3128 ((-1285))) (-15 -3635 ((-141) |#5| |#5|)) (-15 -3174 ((-658 |#5|) (-658 |#5|))) (-15 -1496 ((-141) |#5| |#5|)) (-15 -2846 ((-141) |#5| |#5|)) (-15 -3988 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3274 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3481 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -3085 ((-141) (-658 |#4|) (-658 |#4|))) (-15 -2655 ((-3 (-141) "failed") |#5| |#5|)) (-15 -3962 ((-141) |#5| |#5|)) (-15 -3962 ((-141) |#5| (-658 |#5|))) (-15 -1859 ((-658 |#5|) (-658 |#5|))) (-15 -2728 ((-141) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) (-15 -2441 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-15 -4015 ((-658 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|)))) (-658 |#4|) (-658 |#5|) (-141) (-141))) (-15 -1481 ((-3 (-2 (|:| -2042 (-658 |#4|)) (|:| -2165 |#5|) (|:| |ineq| (-658 |#4|))) "failed") (-658 |#4|) |#5| (-658 |#4|) (-141) (-141) (-141) (-141) (-141)))) 
+((-4349 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|) 94)) (-1665 (((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#4| |#4| |#5|) 70)) (-1845 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|) 88)) (-2636 (((-658 |#5|) |#4| |#5|) 109)) (-2719 (((-658 |#5|) |#4| |#5|) 116)) (-2828 (((-658 |#5|) |#4| |#5|) 117)) (-3934 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|) 95)) (-4416 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|) 115)) (-4130 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|) 44) (((-141) |#4| |#5|) 52)) (-1497 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#3| (-141)) 82) (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5| (-141) (-141)) 49)) (-2884 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|) 77)) (-1543 (((-1285)) 35)) (-3611 (((-1285)) 25)) (-2599 (((-1285) (-1173) (-1173) (-1173)) 31)) (-1938 (((-1285) (-1173) (-1173) (-1173)) 20))) 
+(((-1127 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1938 ((-1285) (-1173) (-1173) (-1173))) (-15 -3611 ((-1285))) (-15 -2599 ((-1285) (-1173) (-1173) (-1173))) (-15 -1543 ((-1285))) (-15 -1665 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -1497 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5| (-141) (-141))) (-15 -1497 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#3| (-141))) (-15 -2884 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -1845 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -4130 ((-141) |#4| |#5|)) (-15 -3934 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2636 ((-658 |#5|) |#4| |#5|)) (-15 -4416 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2719 ((-658 |#5|) |#4| |#5|)) (-15 -4130 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2828 ((-658 |#5|) |#4| |#5|)) (-15 -4349 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1094 |#1| |#2| |#3| |#4|)) (T -1127)) 
+((-4349 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-2828 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 *4)) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-4130 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-2719 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 *4)) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-4416 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-2636 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 *4)) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-3934 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-4130 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-1845 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-2884 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-1497 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-2 (|:| |val| (-658 *8)) (|:| -2165 *9)))) (-5 *5 (-141)) (-4 *8 (-1089 *6 *7 *4)) (-4 *9 (-1094 *6 *7 *4 *8)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *4 (-869)) (-5 *2 (-658 (-2 (|:| |val| *8) (|:| -2165 *9)))) (-5 *1 (-1127 *6 *7 *4 *8 *9)))) (-1497 (*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1127 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) (-1665 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) (-1543 (*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1127 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) (-2599 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1127 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) (-3611 (*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1127 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) (-1938 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1127 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -1938 ((-1285) (-1173) (-1173) (-1173))) (-15 -3611 ((-1285))) (-15 -2599 ((-1285) (-1173) (-1173) (-1173))) (-15 -1543 ((-1285))) (-15 -1665 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -1497 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5| (-141) (-141))) (-15 -1497 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) |#3| (-141))) (-15 -2884 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -1845 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#4| |#5|)) (-15 -4130 ((-141) |#4| |#5|)) (-15 -3934 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2636 ((-658 |#5|) |#4| |#5|)) (-15 -4416 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2719 ((-658 |#5|) |#4| |#5|)) (-15 -4130 ((-658 (-2 (|:| |val| (-141)) (|:| -2165 |#5|))) |#4| |#5|)) (-15 -2828 ((-658 |#5|) |#4| |#5|)) (-15 -4349 ((-658 (-2 (|:| |val| |#4|) (|:| -2165 |#5|))) |#4| |#5|))) 
+((-1641 (((-141) $ $) 7)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) 78)) (-2248 (((-658 $) (-658 |#4|)) 79) (((-658 $) (-658 |#4|) (-141)) 104)) (-4085 (((-658 |#3|) $) 32)) (-4325 (((-141) $) 25)) (-2988 (((-141) $) 16 (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) 94) (((-141) $) 90)) (-2244 ((|#4| |#4| $) 85)) (-3743 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| $) 119)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) 26)) (-2126 (((-141) $ (-790)) 43)) (-3113 (($ (-1 (-141) |#4|) $) 64 (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) 72)) (-3001 (($) 44 T CONST)) (-3239 (((-141) $) 21 (|has| |#1| (-582)))) (-3478 (((-141) $ $) 23 (|has| |#1| (-582)))) (-2398 (((-141) $ $) 22 (|has| |#1| (-582)))) (-1529 (((-141) $) 24 (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 86)) (-4521 (((-658 |#4|) (-658 |#4|) $) 17 (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) 18 (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) 35)) (-2400 (($ (-658 |#4|)) 34)) (-1366 (((-3 $ "failed") $) 75)) (-2226 ((|#4| |#4| $) 82)) (-1360 (($ $) 67 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#4| $) 66 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#4|) $) 63 (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) 95)) (-3092 ((|#4| |#4| $) 80)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 87)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) 98)) (-1836 (((-141) |#4| $) 129)) (-2659 (((-141) |#4| $) 126)) (-3195 (((-141) |#4| $) 130) (((-141) $) 127)) (-4004 (((-658 |#4|) $) 51 (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) 97) (((-141) $) 96)) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) 42)) (-4467 (((-658 |#4|) $) 52 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 54 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 46)) (-2290 (((-658 |#3|) $) 31)) (-2645 (((-141) |#3| $) 30)) (-2554 (((-141) $ (-790)) 41)) (-2685 (((-1173) $) 9)) (-1470 (((-3 |#4| (-658 $)) |#4| |#4| $) 121)) (-3722 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| |#4| $) 120)) (-4255 (((-3 |#4| "failed") $) 76)) (-3501 (((-658 $) |#4| $) 122)) (-3732 (((-3 (-141) (-658 $)) |#4| $) 125)) (-2978 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 $))) |#4| $) 124) (((-141) |#4| $) 123)) (-2852 (((-658 $) |#4| $) 118) (((-658 $) (-658 |#4|) $) 117) (((-658 $) (-658 |#4|) (-658 $)) 116) (((-658 $) |#4| (-658 $)) 115)) (-3902 (($ |#4| $) 110) (($ (-658 |#4|) $) 109)) (-1712 (((-658 |#4|) $) 100)) (-2346 (((-141) |#4| $) 92) (((-141) $) 88)) (-1751 ((|#4| |#4| $) 83)) (-3085 (((-141) $ $) 103)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) 93) (((-141) $) 89)) (-1803 ((|#4| |#4| $) 84)) (-2951 (((-1137) $) 10)) (-1918 (((-3 |#4| "failed") $) 77)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) 60)) (-2778 (((-3 $ "failed") $ |#4|) 71)) (-2807 (($ $ |#4|) 70) (((-658 $) |#4| $) 108) (((-658 $) |#4| (-658 $)) 107) (((-658 $) (-658 |#4|) $) 106) (((-658 $) (-658 |#4|) (-658 $)) 105)) (-3002 (((-141) (-1 (-141) |#4|) $) 49 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) 58 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) 56 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) 55 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) 37)) (-2943 (((-141) $) 40)) (-2890 (($) 39)) (-4525 (((-790) $) 99)) (-3452 (((-790) |#4| $) 53 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#4|) $) 50 (|has| $ (-6 -4625)))) (-4599 (($ $) 38)) (-1778 (((-565) $) 68 (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 59)) (-2613 (($ $ |#3|) 27)) (-4152 (($ $ |#3|) 29)) (-2965 (($ $) 81)) (-2507 (($ $ |#3|) 28)) (-1683 (((-877) $) 11) (((-658 |#4|) $) 36)) (-1857 (((-790) $) 69 (|has| |#3| (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) 101)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) 91)) (-3032 (((-658 $) |#4| $) 114) (((-658 $) |#4| (-658 $)) 113) (((-658 $) (-658 |#4|) $) 112) (((-658 $) (-658 |#4|) (-658 $)) 111)) (-3369 (((-141) (-1 (-141) |#4|) $) 48 (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) 74)) (-1437 (((-141) |#4| $) 128)) (-3069 (((-141) |#3| $) 73)) (-3255 (((-141) $ $) 6)) (-1699 (((-790) $) 45 (|has| $ (-6 -4625))))) 
+(((-1128 |#1| |#2| |#3| |#4|) (-1311) (-477) (-815) (-869) (-1089 |t#1| |t#2| |t#3|)) (T -1128)) 
+NIL 
+(-13 (-1094 |t#1| |t#2| |t#3| |t#4|)) 
+(((-39) . T) ((-125) . T) ((-632 (-658 |#4|)) . T) ((-632 (-877)) . T) ((-175 |#4|) . T) ((-633 (-565)) |has| |#4| (-633 (-565))) ((-325 |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-523 |#4|) . T) ((-547 |#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-1005 |#1| |#2| |#3| |#4|) . T) ((-1094 |#1| |#2| |#3| |#4|) . T) ((-1119) . T) ((-1219 |#1| |#2| |#3| |#4|) . T) ((-1225) . T)) 
+((-2179 (((-658 (-592)) (-592) (-592) (-592)) 20)) (-2967 (((-658 (-592)) (-592) (-592) (-592)) 12)) (-2684 (((-658 (-592)) (-592) (-592) (-592)) 16)) (-1648 (((-592) (-592) (-592)) 9)) (-1511 (((-1280 (-592)) (-658 (-592)) (-1280 (-592)) (-592)) 44) (((-1280 (-592)) (-1280 (-592)) (-1280 (-592)) (-592)) 39)) (-1569 (((-658 (-592)) (-658 (-592)) (-658 (-592)) (-141)) 26)) (-2496 (((-706 (-592)) (-658 (-592)) (-658 (-592)) (-706 (-592))) 43)) (-2679 (((-706 (-592)) (-658 (-592)) (-658 (-592))) 31)) (-3625 (((-658 (-706 (-592))) (-658 (-592))) 33)) (-2954 (((-658 (-592)) (-658 (-592)) (-658 (-592)) (-706 (-592))) 46)) (-3475 (((-706 (-592)) (-658 (-592)) (-658 (-592)) (-658 (-592))) 54))) 
+(((-1129) (-10 -7 (-15 -3475 ((-706 (-592)) (-658 (-592)) (-658 (-592)) (-658 (-592)))) (-15 -2954 ((-658 (-592)) (-658 (-592)) (-658 (-592)) (-706 (-592)))) (-15 -3625 ((-658 (-706 (-592))) (-658 (-592)))) (-15 -2679 ((-706 (-592)) (-658 (-592)) (-658 (-592)))) (-15 -2496 ((-706 (-592)) (-658 (-592)) (-658 (-592)) (-706 (-592)))) (-15 -1569 ((-658 (-592)) (-658 (-592)) (-658 (-592)) (-141))) (-15 -1511 ((-1280 (-592)) (-1280 (-592)) (-1280 (-592)) (-592))) (-15 -1511 ((-1280 (-592)) (-658 (-592)) (-1280 (-592)) (-592))) (-15 -1648 ((-592) (-592) (-592))) (-15 -2684 ((-658 (-592)) (-592) (-592) (-592))) (-15 -2967 ((-658 (-592)) (-592) (-592) (-592))) (-15 -2179 ((-658 (-592)) (-592) (-592) (-592))))) (T -1129)) 
+((-2179 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1129)) (-5 *3 (-592)))) (-2967 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1129)) (-5 *3 (-592)))) (-2684 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1129)) (-5 *3 (-592)))) (-1648 (*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1129)))) (-1511 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-1280 (-592))) (-5 *3 (-658 (-592))) (-5 *4 (-592)) (-5 *1 (-1129)))) (-1511 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-1280 (-592))) (-5 *3 (-592)) (-5 *1 (-1129)))) (-1569 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-658 (-592))) (-5 *3 (-141)) (-5 *1 (-1129)))) (-2496 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-706 (-592))) (-5 *3 (-658 (-592))) (-5 *1 (-1129)))) (-2679 (*1 *2 *3 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-706 (-592))) (-5 *1 (-1129)))) (-3625 (*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-658 (-706 (-592)))) (-5 *1 (-1129)))) (-2954 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-658 (-592))) (-5 *3 (-706 (-592))) (-5 *1 (-1129)))) (-3475 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-706 (-592))) (-5 *1 (-1129))))) 
+(-10 -7 (-15 -3475 ((-706 (-592)) (-658 (-592)) (-658 (-592)) (-658 (-592)))) (-15 -2954 ((-658 (-592)) (-658 (-592)) (-658 (-592)) (-706 (-592)))) (-15 -3625 ((-658 (-706 (-592))) (-658 (-592)))) (-15 -2679 ((-706 (-592)) (-658 (-592)) (-658 (-592)))) (-15 -2496 ((-706 (-592)) (-658 (-592)) (-658 (-592)) (-706 (-592)))) (-15 -1569 ((-658 (-592)) (-658 (-592)) (-658 (-592)) (-141))) (-15 -1511 ((-1280 (-592)) (-1280 (-592)) (-1280 (-592)) (-592))) (-15 -1511 ((-1280 (-592)) (-658 (-592)) (-1280 (-592)) (-592))) (-15 -1648 ((-592) (-592) (-592))) (-15 -2684 ((-658 (-592)) (-592) (-592) (-592))) (-15 -2967 ((-658 (-592)) (-592) (-592) (-592))) (-15 -2179 ((-658 (-592)) (-592) (-592) (-592)))) 
+((-1424 (($ $ (-944)) 12)) (** (($ $ (-944)) 10))) 
+(((-1130 |#1|) (-10 -8 (-15 -1424 (|#1| |#1| (-944))) (-15 ** (|#1| |#1| (-944)))) (-1131)) (T -1130)) 
+NIL 
+(-10 -8 (-15 -1424 (|#1| |#1| (-944))) (-15 ** (|#1| |#1| (-944)))) 
+((-1641 (((-141) $ $) 7)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-1424 (($ $ (-944)) 12)) (-3255 (((-141) $ $) 6)) (** (($ $ (-944)) 13)) (* (($ $ $) 14))) 
+(((-1131) (-1311)) (T -1131)) 
+((* (*1 *1 *1 *1) (-4 *1 (-1131))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-1131)) (-5 *2 (-944)))) (-1424 (*1 *1 *1 *2) (-12 (-4 *1 (-1131)) (-5 *2 (-944))))) 
+(-13 (-1119) (-10 -8 (-15 * ($ $ $)) (-15 ** ($ $ (-944))) (-15 -1424 ($ $ (-944))))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#3| (-1119)))) (-2272 (((-141) $) NIL (|has| |#3| (-158)))) (-2673 (($ (-944)) NIL (|has| |#3| (-1075)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4079 (($ $ $) NIL (|has| |#3| (-815)))) (-2350 (((-3 $ "failed") $ $) NIL (|has| |#3| (-158)))) (-2126 (((-141) $ (-790)) NIL)) (-1403 (((-790)) NIL (|has| |#3| (-394)))) (-3940 (((-592) $) NIL (|has| |#3| (-867)))) (-3932 ((|#3| $ (-592) |#3|) NIL (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (-12 (|has| |#3| (-1065 (-592))) (|has| |#3| (-1119)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| |#3| (-1065 (-433 (-592)))) (|has| |#3| (-1119)))) (((-3 |#3| "failed") $) NIL (|has| |#3| (-1119)))) (-2400 (((-592) $) NIL (-12 (|has| |#3| (-1065 (-592))) (|has| |#3| (-1119)))) (((-433 (-592)) $) NIL (-12 (|has| |#3| (-1065 (-433 (-592)))) (|has| |#3| (-1119)))) ((|#3| $) NIL (|has| |#3| (-1119)))) (-3945 (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#3| (-654 (-592))) (|has| |#3| (-1075)))) (((-2 (|:| -3253 (-706 |#3|)) (|:| |vec| (-1280 |#3|))) (-706 $) (-1280 $)) NIL (|has| |#3| (-1075))) (((-706 |#3|) (-706 $)) NIL (|has| |#3| (-1075)))) (-3371 (((-3 $ "failed") $) NIL (|has| |#3| (-743)))) (-4290 (($) NIL (|has| |#3| (-394)))) (-1426 ((|#3| $ (-592) |#3|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#3| $ (-592)) 12)) (-1691 (((-141) $) NIL (|has| |#3| (-867)))) (-4004 (((-658 |#3|) $) NIL (|has| $ (-6 -4625)))) (-3558 (((-141) $) NIL (|has| |#3| (-743)))) (-1324 (((-141) $) NIL (|has| |#3| (-867)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-4467 (((-658 |#3|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#3| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#3| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3987 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#3| |#3|) $) NIL)) (-3546 (((-944) $) NIL (|has| |#3| (-394)))) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#3| (-1119)))) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-1825 (($ (-944)) NIL (|has| |#3| (-394)))) (-2951 (((-1137) $) NIL (|has| |#3| (-1119)))) (-1918 ((|#3| $) NIL (|has| (-592) (-869)))) (-1892 (($ $ |#3|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#3|))) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ (-310 |#3|)) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119)))) (($ $ (-658 |#3|) (-658 |#3|)) NIL (-12 (|has| |#3| (-325 |#3|)) (|has| |#3| (-1119))))) (-1724 (((-141) $ $) NIL)) (-1405 (((-658 $)) NIL (|has| |#3| (-394)))) (-2254 (((-141) |#3| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#3| (-1119))))) (-4210 (((-658 |#3|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#3| $ (-592) |#3|) NIL) ((|#3| $ (-592)) NIL)) (-1729 ((|#3| $ $) NIL (|has| |#3| (-1075)))) (-4512 (($ (-1280 |#3|)) NIL)) (-1936 (((-160)) NIL (|has| |#3| (-388)))) (-3644 (($ $) NIL (-12 (|has| |#3| (-247)) (|has| |#3| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#3| (-247)) (|has| |#3| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-1 |#3| |#3|) (-790)) NIL (|has| |#3| (-1075))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1075)))) (-3452 (((-790) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625))) (((-790) |#3| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#3| (-1119))))) (-4599 (($ $) NIL)) (-1683 (((-1280 |#3|) $) NIL) (((-877) $) NIL (|has| |#3| (-1119))) (($ (-592)) NIL (-3836 (-12 (|has| |#3| (-1065 (-592))) (|has| |#3| (-1119))) (|has| |#3| (-1075)))) (($ (-433 (-592))) NIL (-12 (|has| |#3| (-1065 (-433 (-592)))) (|has| |#3| (-1119)))) (($ |#3|) NIL (|has| |#3| (-1119)))) (-4010 (((-790)) NIL (|has| |#3| (-1075)))) (-3369 (((-141) (-1 (-141) |#3|) $) NIL (|has| $ (-6 -4625)))) (-1392 (($ $) NIL (|has| |#3| (-867)))) (-1424 (($ $ (-790)) NIL (|has| |#3| (-743))) (($ $ (-944)) NIL (|has| |#3| (-743)))) (-3514 (($) NIL (|has| |#3| (-158)) CONST)) (-4257 (($) NIL (|has| |#3| (-743)) CONST)) (-1940 (($ $) NIL (-12 (|has| |#3| (-247)) (|has| |#3| (-1075)))) (($ $ (-790)) NIL (-12 (|has| |#3| (-247)) (|has| |#3| (-1075)))) (($ $ (-1191)) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#3| (-922 (-1191))) (|has| |#3| (-1075)))) (($ $ (-1 |#3| |#3|) (-790)) NIL (|has| |#3| (-1075))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1075)))) (-3286 (((-141) $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3273 (((-141) $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3255 (((-141) $ $) NIL (|has| |#3| (-1119)))) (-3279 (((-141) $ $) NIL (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3266 (((-141) $ $) 17 (-3836 (|has| |#3| (-815)) (|has| |#3| (-867))))) (-3313 (($ $ |#3|) NIL (|has| |#3| (-388)))) (-3306 (($ $ $) NIL (|has| |#3| (-1075))) (($ $) NIL (|has| |#3| (-1075)))) (-3300 (($ $ $) NIL (|has| |#3| (-25)))) (** (($ $ (-790)) NIL (|has| |#3| (-743))) (($ $ (-944)) NIL (|has| |#3| (-743)))) (* (($ (-592) $) NIL (|has| |#3| (-1075))) (($ $ $) NIL (|has| |#3| (-743))) (($ $ |#3|) NIL (|has| |#3| (-743))) (($ |#3| $) NIL (|has| |#3| (-743))) (($ (-790) $) NIL (|has| |#3| (-158))) (($ (-944) $) NIL (|has| |#3| (-25)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1132 |#1| |#2| |#3|) (-252 |#1| |#3|) (-790) (-790) (-815)) (T -1132)) 
+NIL 
+(-252 |#1| |#3|) 
+((-3355 (((-658 (-1252 |#2| |#1|)) (-1252 |#2| |#1|) (-1252 |#2| |#1|)) 36)) (-4476 (((-592) (-1252 |#2| |#1|)) 67 (|has| |#1| (-477)))) (-2863 (((-592) (-1252 |#2| |#1|)) 53)) (-3345 (((-658 (-1252 |#2| |#1|)) (-1252 |#2| |#1|) (-1252 |#2| |#1|)) 44)) (-2462 (((-592) (-1252 |#2| |#1|) (-1252 |#2| |#1|)) 55 (|has| |#1| (-477)))) (-1818 (((-658 |#1|) (-1252 |#2| |#1|) (-1252 |#2| |#1|)) 47)) (-1958 (((-592) (-1252 |#2| |#1|) (-1252 |#2| |#1|)) 52))) 
+(((-1133 |#1| |#2|) (-10 -7 (-15 -3355 ((-658 (-1252 |#2| |#1|)) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -3345 ((-658 (-1252 |#2| |#1|)) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -1818 ((-658 |#1|) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -1958 ((-592) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -2863 ((-592) (-1252 |#2| |#1|))) (IF (|has| |#1| (-477)) (PROGN (-15 -2462 ((-592) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -4476 ((-592) (-1252 |#2| |#1|)))) |noBranch|)) (-842) (-1191)) (T -1133)) 
+((-4476 (*1 *2 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-477)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-592)) (-5 *1 (-1133 *4 *5)))) (-2462 (*1 *2 *3 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-477)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-592)) (-5 *1 (-1133 *4 *5)))) (-2863 (*1 *2 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-592)) (-5 *1 (-1133 *4 *5)))) (-1958 (*1 *2 *3 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-592)) (-5 *1 (-1133 *4 *5)))) (-1818 (*1 *2 *3 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-658 *4)) (-5 *1 (-1133 *4 *5)))) (-3345 (*1 *2 *3 *3) (-12 (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-658 (-1252 *5 *4))) (-5 *1 (-1133 *4 *5)) (-5 *3 (-1252 *5 *4)))) (-3355 (*1 *2 *3 *3) (-12 (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-658 (-1252 *5 *4))) (-5 *1 (-1133 *4 *5)) (-5 *3 (-1252 *5 *4))))) 
+(-10 -7 (-15 -3355 ((-658 (-1252 |#2| |#1|)) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -3345 ((-658 (-1252 |#2| |#1|)) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -1818 ((-658 |#1|) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -1958 ((-592) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -2863 ((-592) (-1252 |#2| |#1|))) (IF (|has| |#1| (-477)) (PROGN (-15 -2462 ((-592) (-1252 |#2| |#1|) (-1252 |#2| |#1|))) (-15 -4476 ((-592) (-1252 |#2| |#1|)))) |noBranch|)) 
+((-3940 (((-3 (-592) "failed") |#2| (-1191) |#2| (-1173)) 16) (((-3 (-592) "failed") |#2| (-1191) (-862 |#2|)) 14) (((-3 (-592) "failed") |#2|) 51))) 
+(((-1134 |#1| |#2|) (-10 -7 (-15 -3940 ((-3 (-592) "failed") |#2|)) (-15 -3940 ((-3 (-592) "failed") |#2| (-1191) (-862 |#2|))) (-15 -3940 ((-3 (-592) "failed") |#2| (-1191) |#2| (-1173)))) (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)) (-477)) (-13 (-27) (-1211) (-456 |#1|))) (T -1134)) 
+((-3940 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-1173)) (-4 *6 (-13 (-582) (-869) (-1065 *2) (-654 *2) (-477))) (-5 *2 (-592)) (-5 *1 (-1134 *6 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))))) (-3940 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-862 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 *2) (-654 *2) (-477))) (-5 *2 (-592)) (-5 *1 (-1134 *6 *3)))) (-3940 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-582) (-869) (-1065 *2) (-654 *2) (-477))) (-5 *2 (-592)) (-5 *1 (-1134 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4)))))) 
+(-10 -7 (-15 -3940 ((-3 (-592) "failed") |#2|)) (-15 -3940 ((-3 (-592) "failed") |#2| (-1191) (-862 |#2|))) (-15 -3940 ((-3 (-592) "failed") |#2| (-1191) |#2| (-1173)))) 
+((-3940 (((-3 (-592) "failed") (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|)) (-1173)) 34) (((-3 (-592) "failed") (-433 (-980 |#1|)) (-1191) (-862 (-433 (-980 |#1|)))) 29) (((-3 (-592) "failed") (-433 (-980 |#1|))) 12))) 
+(((-1135 |#1|) (-10 -7 (-15 -3940 ((-3 (-592) "failed") (-433 (-980 |#1|)))) (-15 -3940 ((-3 (-592) "failed") (-433 (-980 |#1|)) (-1191) (-862 (-433 (-980 |#1|))))) (-15 -3940 ((-3 (-592) "failed") (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|)) (-1173)))) (-477)) (T -1135)) 
+((-3940 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-433 (-980 *6))) (-5 *4 (-1191)) (-5 *5 (-1173)) (-4 *6 (-477)) (-5 *2 (-592)) (-5 *1 (-1135 *6)))) (-3940 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-862 (-433 (-980 *6)))) (-5 *3 (-433 (-980 *6))) (-4 *6 (-477)) (-5 *2 (-592)) (-5 *1 (-1135 *6)))) (-3940 (*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-477)) (-5 *2 (-592)) (-5 *1 (-1135 *4))))) 
+(-10 -7 (-15 -3940 ((-3 (-592) "failed") (-433 (-980 |#1|)))) (-15 -3940 ((-3 (-592) "failed") (-433 (-980 |#1|)) (-1191) (-862 (-433 (-980 |#1|))))) (-15 -3940 ((-3 (-592) "failed") (-433 (-980 |#1|)) (-1191) (-433 (-980 |#1|)) (-1173)))) 
+((-1849 (((-332 (-592)) (-53)) 11))) 
+(((-1136) (-10 -7 (-15 -1849 ((-332 (-592)) (-53))))) (T -1136)) 
+((-1849 (*1 *2 *3) (-12 (-5 *3 (-53)) (-5 *2 (-332 (-592))) (-5 *1 (-1136))))) 
+(-10 -7 (-15 -1849 ((-332 (-592)) (-53)))) 
+((-1641 (((-141) $ $) NIL)) (-3163 (($ $) 41)) (-2272 (((-141) $) 65)) (-2773 (($ $ $) 48)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 84)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2204 (($ $ $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1686 (($ $ $ $) 74)) (-3743 (($ $) NIL)) (-3164 (((-444 $) $) NIL)) (-3652 (((-141) $ $) NIL)) (-3940 (((-592) $) NIL)) (-3651 (($ $ $) 71)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL)) (-2400 (((-592) $) NIL)) (-1586 (($ $ $) 59)) (-3945 (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 78) (((-706 (-592)) (-706 $)) 28)) (-3371 (((-3 $ "failed") $) NIL)) (-4182 (((-3 (-433 (-592)) "failed") $) NIL)) (-2435 (((-141) $) NIL)) (-2270 (((-433 (-592)) $) NIL)) (-4290 (($) 81) (($ $) 82)) (-1599 (($ $ $) 58)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL)) (-2802 (((-141) $) NIL)) (-2520 (($ $ $ $) NIL)) (-1592 (($ $ $) 79)) (-1691 (((-141) $) NIL)) (-3870 (($ $ $) NIL)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL)) (-3558 (((-141) $) 66)) (-3372 (((-141) $) 64)) (-3252 (($ $) 42)) (-3921 (((-3 $ "failed") $) NIL)) (-1324 (((-141) $) 75)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3260 (($ $ $ $) 72)) (-1837 (($ $ $) 68) (($) 39)) (-3319 (($ $ $) 67) (($) 38)) (-4561 (($ $) NIL)) (-4233 (($ $) 70)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) NIL)) (-2750 (($ $ $) NIL) (($ (-658 $)) NIL)) (-2685 (((-1173) $) NIL)) (-4092 (($ $ $) NIL)) (-3703 (($) NIL T CONST)) (-4185 (($ $) 50)) (-2951 (((-1137) $) NIL) (($ $) 69)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL)) (-3548 (($ $ $) 62) (($ (-658 $)) NIL)) (-2283 (($ $) NIL)) (-4500 (((-444 $) $) NIL)) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL)) (-3616 (((-3 $ "failed") $ $) NIL)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL)) (-3554 (((-141) $) NIL)) (-2769 (((-790) $) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 61)) (-3644 (($ $ (-790)) NIL) (($ $) NIL)) (-1676 (($ $) 51)) (-4599 (($ $) NIL)) (-1778 (((-592) $) 32) (((-565) $) NIL) (((-914 (-592)) $) NIL) (((-405) $) NIL) (((-237) $) NIL)) (-1683 (((-877) $) 31) (($ (-592)) 80) (($ $) NIL) (($ (-592)) 80)) (-4010 (((-790)) NIL)) (-3911 (((-141) $ $) NIL)) (-4042 (($ $ $) NIL)) (-4226 (($) 37)) (-2537 (((-141) $ $) NIL)) (-1475 (($ $ $ $) 73)) (-1392 (($ $) 63)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-1623 (($ $ $) 44)) (-3514 (($) 35 T CONST)) (-1447 (($ $ $) 47)) (-4257 (($) 36 T CONST)) (-1637 (((-1173) $) 21) (((-1173) $ (-141)) 23) (((-1285) (-844) $) 24) (((-1285) (-844) $ (-141)) 25)) (-1422 (($ $) 45)) (-1940 (($ $ (-790)) NIL) (($ $) NIL)) (-3214 (($ $ $) 46)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 40)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 49)) (-1616 (($ $ $) 43)) (-3306 (($ $) 52) (($ $ $) 54)) (-3300 (($ $ $) 53)) (** (($ $ (-944)) NIL) (($ $ (-790)) 57)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 34) (($ $ $) 55))) 
+(((-1137) (-13 (-574) (-675) (-850) (-10 -8 (-6 -4612) (-6 -4617) (-6 -4613) (-15 -3319 ($)) (-15 -1837 ($)) (-15 -3252 ($ $)) (-15 -3163 ($ $)) (-15 -1616 ($ $ $)) (-15 -1623 ($ $ $)) (-15 -2773 ($ $ $)) (-15 -1422 ($ $)) (-15 -3214 ($ $ $)) (-15 -1447 ($ $ $))))) (T -1137)) 
+((-1623 (*1 *1 *1 *1) (-5 *1 (-1137))) (-1616 (*1 *1 *1 *1) (-5 *1 (-1137))) (-3163 (*1 *1 *1) (-5 *1 (-1137))) (-3319 (*1 *1) (-5 *1 (-1137))) (-1837 (*1 *1) (-5 *1 (-1137))) (-3252 (*1 *1 *1) (-5 *1 (-1137))) (-2773 (*1 *1 *1 *1) (-5 *1 (-1137))) (-1422 (*1 *1 *1) (-5 *1 (-1137))) (-3214 (*1 *1 *1 *1) (-5 *1 (-1137))) (-1447 (*1 *1 *1 *1) (-5 *1 (-1137)))) 
+(-13 (-574) (-675) (-850) (-10 -8 (-6 -4612) (-6 -4617) (-6 -4613) (-15 -3319 ($)) (-15 -1837 ($)) (-15 -3252 ($ $)) (-15 -3163 ($ $)) (-15 -1616 ($ $ $)) (-15 -1623 ($ $ $)) (-15 -2773 ($ $ $)) (-15 -1422 ($ $)) (-15 -3214 ($ $ $)) (-15 -1447 ($ $ $)))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-3349 ((|#1| $) 41)) (-2126 (((-141) $ (-790)) 8)) (-3001 (($) 7 T CONST)) (-3568 ((|#1| |#1| $) 43)) (-2486 ((|#1| $) 42)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4137 ((|#1| $) 36)) (-2113 (($ |#1| $) 37)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-2106 ((|#1| $) 38)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3439 (((-790) $) 40)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) 39)) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1138 |#1|) (-1311) (-1225)) (T -1138)) 
+((-3568 (*1 *2 *2 *1) (-12 (-4 *1 (-1138 *2)) (-4 *2 (-1225)))) (-2486 (*1 *2 *1) (-12 (-4 *1 (-1138 *2)) (-4 *2 (-1225)))) (-3349 (*1 *2 *1) (-12 (-4 *1 (-1138 *2)) (-4 *2 (-1225)))) (-3439 (*1 *2 *1) (-12 (-4 *1 (-1138 *3)) (-4 *3 (-1225)) (-5 *2 (-790))))) 
+(-13 (-131 |t#1|) (-10 -8 (-6 -4625) (-15 -3568 (|t#1| |t#1| $)) (-15 -2486 (|t#1| $)) (-15 -3349 (|t#1| $)) (-15 -3439 ((-790) $)))) 
+(((-39) . T) ((-131 |#1|) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-4529 ((|#3| $) 76)) (-4368 (((-3 (-592) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 |#3| "failed") $) 40)) (-2400 (((-592) $) NIL) (((-433 (-592)) $) NIL) ((|#3| $) 37)) (-3945 (((-706 (-592)) (-706 $)) NIL) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL) (((-2 (|:| -3253 (-706 |#3|)) (|:| |vec| (-1280 |#3|))) (-706 $) (-1280 $)) 73) (((-706 |#3|) (-706 $)) 65)) (-3644 (($ $ (-1 |#3| |#3|)) 19) (($ $ (-1 |#3| |#3|) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191)) NIL) (($ $ (-790)) NIL) (($ $) NIL)) (-2236 ((|#3| $) 78)) (-1332 ((|#4| $) 32)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 (-592))) NIL) (($ |#3|) 16)) (** (($ $ (-944)) NIL) (($ $ (-790)) 15) (($ $ (-592)) 82))) 
+(((-1139 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 ** (|#1| |#1| (-592))) (-15 -2236 (|#3| |#1|)) (-15 -4529 (|#3| |#1|)) (-15 -1332 (|#4| |#1|)) (-15 -3945 ((-706 |#3|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#3|)) (|:| |vec| (-1280 |#3|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -2400 (|#3| |#1|)) (-15 -4368 ((-3 |#3| "failed") |#1|)) (-15 -1683 (|#1| |#3|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|) (-790))) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|))) (-15 -1683 (|#1| (-592))) (-15 ** (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-944))) (-15 -1683 ((-877) |#1|))) (-1140 |#2| |#3| |#4| |#5|) (-790) (-1075) (-252 |#2| |#3|) (-252 |#2| |#3|)) (T -1139)) 
+NIL 
+(-10 -8 (-15 ** (|#1| |#1| (-592))) (-15 -2236 (|#3| |#1|)) (-15 -4529 (|#3| |#1|)) (-15 -1332 (|#4| |#1|)) (-15 -3945 ((-706 |#3|) (-706 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 |#3|)) (|:| |vec| (-1280 |#3|))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 |#1|) (-1280 |#1|))) (-15 -3945 ((-706 (-592)) (-706 |#1|))) (-15 -2400 (|#3| |#1|)) (-15 -4368 ((-3 |#3| "failed") |#1|)) (-15 -1683 (|#1| |#3|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-592) |#1|)) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|) (-790))) (-15 -3644 (|#1| |#1| (-1 |#3| |#3|))) (-15 -1683 (|#1| (-592))) (-15 ** (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-944))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4529 ((|#2| $) 69)) (-4034 (((-141) $) 109)) (-2350 (((-3 $ "failed") $ $) 18)) (-3120 (((-141) $) 107)) (-2126 (((-141) $ (-790)) 99)) (-3223 (($ |#2|) 72)) (-3001 (($) 16 T CONST)) (-3052 (($ $) 126 (|has| |#2| (-323)))) (-2747 ((|#3| $ (-592)) 121)) (-4368 (((-3 (-592) "failed") $) 83 (|has| |#2| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) 81 (|has| |#2| (-1065 (-433 (-592))))) (((-3 |#2| "failed") $) 78)) (-2400 (((-592) $) 84 (|has| |#2| (-1065 (-592)))) (((-433 (-592)) $) 82 (|has| |#2| (-1065 (-433 (-592))))) ((|#2| $) 77)) (-3945 (((-706 (-592)) (-706 $)) 76 (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 75 (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) 74) (((-706 |#2|) (-706 $)) 73)) (-3371 (((-3 $ "failed") $) 33)) (-4175 (((-790) $) 127 (|has| |#2| (-582)))) (-3959 ((|#2| $ (-592) (-592)) 119)) (-4004 (((-658 |#2|) $) 92 (|has| $ (-6 -4625)))) (-3558 (((-141) $) 30)) (-3178 (((-790) $) 128 (|has| |#2| (-582)))) (-3555 (((-658 |#4|) $) 129 (|has| |#2| (-582)))) (-4292 (((-790) $) 115)) (-4298 (((-790) $) 116)) (-4345 (((-141) $ (-790)) 100)) (-3781 ((|#2| $) 64 (|has| |#2| (-6 (-4627 "*"))))) (-4577 (((-592) $) 111)) (-4280 (((-592) $) 113)) (-4467 (((-658 |#2|) $) 91 (|has| $ (-6 -4625)))) (-3133 (((-141) |#2| $) 89 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625))))) (-1898 (((-592) $) 112)) (-3005 (((-592) $) 114)) (-4186 (($ (-658 (-658 |#2|))) 106)) (-3987 (($ (-1 |#2| |#2|) $) 96 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#2| |#2| |#2|) $ $) 123) (($ (-1 |#2| |#2|) $) 97)) (-4601 (((-658 (-658 |#2|)) $) 117)) (-2554 (((-141) $ (-790)) 101)) (-2685 (((-1173) $) 9)) (-3183 (((-3 $ "failed") $) 63 (|has| |#2| (-388)))) (-2951 (((-1137) $) 10)) (-3616 (((-3 $ "failed") $ |#2|) 124 (|has| |#2| (-582)))) (-3002 (((-141) (-1 (-141) |#2|) $) 94 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#2|))) 88 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) 87 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) 86 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) 85 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) 105)) (-2943 (((-141) $) 102)) (-2890 (($) 103)) (-3927 ((|#2| $ (-592) (-592) |#2|) 120) ((|#2| $ (-592) (-592)) 118)) (-3644 (($ $ (-1 |#2| |#2|)) 51) (($ $ (-1 |#2| |#2|) (-790)) 50) (($ $ (-658 (-1191)) (-658 (-790))) 43 (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) 42 (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) 41 (|has| |#2| (-922 (-1191)))) (($ $ (-1191)) 40 (|has| |#2| (-922 (-1191)))) (($ $ (-790)) 38 (|has| |#2| (-247))) (($ $) 36 (|has| |#2| (-247)))) (-2236 ((|#2| $) 68)) (-2933 (($ (-658 |#2|)) 71)) (-2940 (((-141) $) 108)) (-1332 ((|#3| $) 70)) (-1625 ((|#2| $) 65 (|has| |#2| (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) |#2|) $) 93 (|has| $ (-6 -4625))) (((-790) |#2| $) 90 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 104)) (-2000 ((|#4| $ (-592)) 122)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 80 (|has| |#2| (-1065 (-433 (-592))))) (($ |#2|) 79)) (-4010 (((-790)) 28)) (-3369 (((-141) (-1 (-141) |#2|) $) 95 (|has| $ (-6 -4625)))) (-3951 (((-141) $) 110)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-1 |#2| |#2|)) 49) (($ $ (-1 |#2| |#2|) (-790)) 48) (($ $ (-658 (-1191)) (-658 (-790))) 47 (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) 46 (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) 45 (|has| |#2| (-922 (-1191)))) (($ $ (-1191)) 44 (|has| |#2| (-922 (-1191)))) (($ $ (-790)) 39 (|has| |#2| (-247))) (($ $) 37 (|has| |#2| (-247)))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#2|) 125 (|has| |#2| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 62 (|has| |#2| (-388)))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#2|) 131) (($ |#2| $) 130) ((|#4| $ |#4|) 67) ((|#3| |#3| $) 66)) (-1699 (((-790) $) 98 (|has| $ (-6 -4625))))) 
+(((-1140 |#1| |#2| |#3| |#4|) (-1311) (-790) (-1075) (-252 |t#1| |t#2|) (-252 |t#1| |t#2|)) (T -1140)) 
+((-3223 (*1 *1 *2) (-12 (-4 *2 (-1075)) (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)))) (-2933 (*1 *1 *2) (-12 (-5 *2 (-658 *4)) (-4 *4 (-1075)) (-4 *1 (-1140 *3 *4 *5 *6)) (-4 *5 (-252 *3 *4)) (-4 *6 (-252 *3 *4)))) (-1332 (*1 *2 *1) (-12 (-4 *1 (-1140 *3 *4 *2 *5)) (-4 *4 (-1075)) (-4 *5 (-252 *3 *4)) (-4 *2 (-252 *3 *4)))) (-4529 (*1 *2 *1) (-12 (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)) (-4 *2 (-1075)))) (-2236 (*1 *2 *1) (-12 (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)) (-4 *2 (-1075)))) (* (*1 *2 *1 *2) (-12 (-4 *1 (-1140 *3 *4 *5 *2)) (-4 *4 (-1075)) (-4 *5 (-252 *3 *4)) (-4 *2 (-252 *3 *4)))) (* (*1 *2 *2 *1) (-12 (-4 *1 (-1140 *3 *4 *2 *5)) (-4 *4 (-1075)) (-4 *2 (-252 *3 *4)) (-4 *5 (-252 *3 *4)))) (-1625 (*1 *2 *1) (-12 (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)) (|has| *2 (-6 (-4627 "*"))) (-4 *2 (-1075)))) (-3781 (*1 *2 *1) (-12 (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)) (|has| *2 (-6 (-4627 "*"))) (-4 *2 (-1075)))) (-3183 (*1 *1 *1) (|partial| -12 (-4 *1 (-1140 *2 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-252 *2 *3)) (-4 *5 (-252 *2 *3)) (-4 *3 (-388)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1140 *3 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-252 *3 *4)) (-4 *6 (-252 *3 *4)) (-4 *4 (-388))))) 
+(-13 (-245 |t#2|) (-140 |t#2| |t#2|) (-1078 |t#1| |t#1| |t#2| |t#3| |t#4|) (-437 |t#2|) (-403 |t#2|) (-10 -8 (IF (|has| |t#2| (-194)) (-6 (-734 |t#2|)) |noBranch|) (-15 -3223 ($ |t#2|)) (-15 -2933 ($ (-658 |t#2|))) (-15 -1332 (|t#3| $)) (-15 -4529 (|t#2| $)) (-15 -2236 (|t#2| $)) (-15 * (|t#4| $ |t#4|)) (-15 * (|t#3| |t#3| $)) (IF (|has| |t#2| (-6 (-4627 "*"))) (PROGN (-6 (-43 |t#2|)) (-15 -1625 (|t#2| $)) (-15 -3781 (|t#2| $))) |noBranch|) (IF (|has| |t#2| (-388)) (PROGN (-15 -3183 ((-3 $ "failed") $)) (-15 ** ($ $ (-592)))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-39) . T) ((-43 |#2|) |has| |#2| (-6 (-4627 "*"))) ((-125) . T) ((-140 |#2| |#2|) . T) ((-158) . T) ((-632 (-877)) . T) ((-245 |#2|) . T) ((-247) |has| |#2| (-247)) ((-325 |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-403 |#2|) . T) ((-437 |#2|) . T) ((-523 |#2|) . T) ((-547 |#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-661 |#2|) . T) ((-661 $) . T) ((-654 (-592)) |has| |#2| (-654 (-592))) ((-654 |#2|) . T) ((-734 |#2|) -3836 (|has| |#2| (-194)) (|has| |#2| (-6 (-4627 "*")))) ((-743) . T) ((-922 (-1191)) |has| |#2| (-922 (-1191))) ((-1078 |#1| |#1| |#2| |#3| |#4|) . T) ((-1065 (-433 (-592))) |has| |#2| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#2| (-1065 (-592))) ((-1065 |#2|) . T) ((-1081 |#2|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1225) . T)) 
+((-3136 ((|#4| |#4|) 67)) (-1893 ((|#4| |#4|) 62)) (-4489 (((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|))) |#4| |#3|) 75)) (-2174 (((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|) 66)) (-2299 (((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|) 64))) 
+(((-1141 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1893 (|#4| |#4|)) (-15 -2299 ((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|)) (-15 -3136 (|#4| |#4|)) (-15 -2174 ((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|)) (-15 -4489 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|))) |#4| |#3|))) (-323) (-399 |#1|) (-399 |#1|) (-704 |#1| |#2| |#3|)) (T -1141)) 
+((-4489 (*1 *2 *3 *4) (-12 (-4 *5 (-323)) (-4 *6 (-399 *5)) (-4 *4 (-399 *5)) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-1141 *5 *6 *4 *3)) (-4 *3 (-704 *5 *6 *4)))) (-2174 (*1 *2 *3) (-12 (-4 *4 (-323)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-2 (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (-5 *1 (-1141 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-3136 (*1 *2 *2) (-12 (-4 *3 (-323)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-1141 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-2299 (*1 *2 *3) (-12 (-4 *4 (-323)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-2 (|:| |Hermite| *3) (|:| |eqMat| *3))) (-5 *1 (-1141 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) (-1893 (*1 *2 *2) (-12 (-4 *3 (-323)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-1141 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(-10 -7 (-15 -1893 (|#4| |#4|)) (-15 -2299 ((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|)) (-15 -3136 (|#4| |#4|)) (-15 -2174 ((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|)) (-15 -4489 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2195 (-658 |#3|))) |#4| |#3|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 17)) (-4085 (((-658 |#2|) $) 160)) (-4492 (((-1187 $) $ |#2|) 54) (((-1187 |#1|) $) 43)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 110 (|has| |#1| (-582)))) (-1555 (($ $) 112 (|has| |#1| (-582)))) (-1313 (((-141) $) 114 (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 |#2|)) 193)) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) 157) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 |#2| "failed") $) NIL)) (-2400 ((|#1| $) 155) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) ((|#2| $) NIL)) (-1544 (($ $ $ |#2|) NIL (|has| |#1| (-194)))) (-4593 (($ $) 197)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) 82)) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ |#2|) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-558 |#2|) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| |#1| (-908 (-405))) (|has| |#2| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| |#1| (-908 (-592))) (|has| |#2| (-908 (-592)))))) (-3558 (((-141) $) 19)) (-4036 (((-790) $) 26)) (-4533 (($ (-1187 |#1|) |#2|) 48) (($ (-1187 $) |#2|) 64)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) 31)) (-4526 (($ |#1| (-558 |#2|)) 71) (($ $ |#2| (-790)) 52) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ |#2|) NIL)) (-4206 (((-558 |#2|) $) 187) (((-790) $ |#2|) 188) (((-658 (-790)) $ (-658 |#2|)) 189)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-558 |#2|) (-558 |#2|)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) 122)) (-3254 (((-3 |#2| "failed") $) 162)) (-4573 (($ $) 196)) (-4579 ((|#1| $) 37)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| |#2|) (|:| -3215 (-790))) "failed") $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 32)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 140 (|has| |#1| (-477)))) (-3548 (($ (-658 $)) 145 (|has| |#1| (-477))) (($ $ $) 132 (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) 120 (|has| |#1| (-582)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ |#2| |#1|) 165) (($ $ (-658 |#2|) (-658 |#1|)) 178) (($ $ |#2| $) 164) (($ $ (-658 |#2|) (-658 $)) 177)) (-1482 (($ $ |#2|) NIL (|has| |#1| (-194)))) (-3644 (($ $ |#2|) 195) (($ $ (-658 |#2|)) NIL) (($ $ |#2| (-790)) NIL) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-4525 (((-558 |#2|) $) 183) (((-790) $ |#2|) 179) (((-658 (-790)) $ (-658 |#2|)) 181)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| |#1| (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| |#1| (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| |#1| (-633 (-565))) (|has| |#2| (-633 (-565)))))) (-1554 ((|#1| $) 128 (|has| |#1| (-477))) (($ $ |#2|) 131 (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1683 (((-877) $) 151) (($ (-592)) 76) (($ |#1|) 77) (($ |#2|) 28) (($ $) NIL (|has| |#1| (-582))) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592))))))) (-1647 (((-658 |#1|) $) 154)) (-1937 ((|#1| $ (-558 |#2|)) 73) (($ $ |#2| (-790)) NIL) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) 79)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) 117 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 102) (($ $ (-790)) 104)) (-3514 (($) 12 T CONST)) (-4257 (($) 14 T CONST)) (-1940 (($ $ |#2|) NIL) (($ $ (-658 |#2|)) NIL) (($ $ |#2| (-790)) NIL) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) 97)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) 126 (|has| |#1| (-388)))) (-3306 (($ $) 85) (($ $ $) 95)) (-3300 (($ $ $) 49)) (** (($ $ (-944)) 103) (($ $ (-790)) 100)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 88) (($ $ $) 65) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 90) (($ $ |#1|) NIL))) 
+(((-1142 |#1| |#2|) (-977 |#1| (-558 |#2|) |#2|) (-1075) (-869)) (T -1142)) 
+NIL 
+(-977 |#1| (-558 |#2|) |#2|) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 |#2|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-1588 (($ $) 154 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 130 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1575 (($ $) 150 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 126 (|has| |#1| (-43 (-433 (-592)))))) (-1601 (($ $) 158 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 134 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-2012 (((-980 |#1|) $ (-790)) NIL) (((-980 |#1|) $ (-790) (-790)) NIL)) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-790) $ |#2|) NIL) (((-790) $ |#2| (-790)) NIL)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2027 (((-141) $) NIL)) (-4526 (($ $ (-658 |#2|) (-658 (-558 |#2|))) NIL) (($ $ |#2| (-558 |#2|)) NIL) (($ |#1| (-558 |#2|)) NIL) (($ $ |#2| (-790)) 71) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4546 (($ $) 124 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-3162 (($ $ |#2|) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ |#2| |#1|) 177 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-4320 (($ (-1 $) |#2| |#1|) 176 (|has| |#1| (-43 (-433 (-592)))))) (-2807 (($ $ (-790)) 15)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-1430 (($ $) 122 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (($ $ |#2| $) 109) (($ $ (-658 |#2|) (-658 $)) 102) (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL)) (-3644 (($ $ |#2|) 111) (($ $ (-658 |#2|)) NIL) (($ $ |#2| (-790)) NIL) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-4525 (((-558 |#2|) $) NIL)) (-4461 (((-1 (-1171 |#3|) |#3|) (-658 |#2|) (-658 (-1171 |#3|))) 92)) (-1609 (($ $) 160 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 136 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 156 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 132 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 152 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 128 (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 17)) (-1683 (((-877) $) 192) (($ (-592)) NIL) (($ |#1|) 59 (|has| |#1| (-194))) (($ $) NIL (|has| |#1| (-582))) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#2|) 78) (($ |#3|) 76)) (-1937 ((|#1| $ (-558 |#2|)) 57) (($ $ |#2| (-790)) NIL) (($ $ (-658 |#2|) (-658 (-790))) 50) ((|#3| $ (-790)) 42)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-1630 (($ $) 166 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 142 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) 162 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 138 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 170 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 146 (|has| |#1| (-43 (-433 (-592)))))) (-2892 (($ $) 172 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 148 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 168 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 144 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 164 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 140 (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 18 T CONST)) (-4257 (($) 10 T CONST)) (-1940 (($ $ |#2|) NIL) (($ $ (-658 |#2|)) NIL) (($ $ |#2| (-790)) NIL) (($ $ (-658 |#2|) (-658 (-790))) NIL)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) 194 (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 74)) (** (($ $ (-944)) NIL) (($ $ (-790)) 83) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 114 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 73) (($ $ (-433 (-592))) 119 (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) 117 (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 62) (($ $ |#1|) 63) (($ |#3| $) 61))) 
+(((-1143 |#1| |#2| |#3|) (-13 (-757 |#1| |#2|) (-10 -8 (-15 -1937 (|#3| $ (-790))) (-15 -1683 ($ |#2|)) (-15 -1683 ($ |#3|)) (-15 * ($ |#3| $)) (-15 -4461 ((-1 (-1171 |#3|) |#3|) (-658 |#2|) (-658 (-1171 |#3|)))) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $ |#2| |#1|)) (-15 -4320 ($ (-1 $) |#2| |#1|))) |noBranch|))) (-1075) (-869) (-977 |#1| (-558 |#2|) |#2|)) (T -1143)) 
+((-1937 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *2 (-977 *4 (-558 *5) *5)) (-5 *1 (-1143 *4 *5 *2)) (-4 *4 (-1075)) (-4 *5 (-869)))) (-1683 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *2 (-869)) (-5 *1 (-1143 *3 *2 *4)) (-4 *4 (-977 *3 (-558 *2) *2)))) (-1683 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-869)) (-5 *1 (-1143 *3 *4 *2)) (-4 *2 (-977 *3 (-558 *4) *4)))) (* (*1 *1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-869)) (-5 *1 (-1143 *3 *4 *2)) (-4 *2 (-977 *3 (-558 *4) *4)))) (-4461 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-658 (-1171 *7))) (-4 *6 (-869)) (-4 *7 (-977 *5 (-558 *6) *6)) (-4 *5 (-1075)) (-5 *2 (-1 (-1171 *7) *7)) (-5 *1 (-1143 *5 *6 *7)))) (-3162 (*1 *1 *1 *2 *3) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-4 *2 (-869)) (-5 *1 (-1143 *3 *2 *4)) (-4 *4 (-977 *3 (-558 *2) *2)))) (-4320 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1143 *4 *3 *5))) (-4 *4 (-43 (-433 (-592)))) (-4 *4 (-1075)) (-4 *3 (-869)) (-5 *1 (-1143 *4 *3 *5)) (-4 *5 (-977 *4 (-558 *3) *3))))) 
+(-13 (-757 |#1| |#2|) (-10 -8 (-15 -1937 (|#3| $ (-790))) (-15 -1683 ($ |#2|)) (-15 -1683 ($ |#3|)) (-15 * ($ |#3| $)) (-15 -4461 ((-1 (-1171 |#3|) |#3|) (-658 |#2|) (-658 (-1171 |#3|)))) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $ |#2| |#1|)) (-15 -4320 ($ (-1 $) |#2| |#1|))) |noBranch|))) 
+((-1641 (((-141) $ $) 7)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) 78)) (-2248 (((-658 $) (-658 |#4|)) 79) (((-658 $) (-658 |#4|) (-141)) 104)) (-4085 (((-658 |#3|) $) 32)) (-4325 (((-141) $) 25)) (-2988 (((-141) $) 16 (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) 94) (((-141) $) 90)) (-2244 ((|#4| |#4| $) 85)) (-3743 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| $) 119)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) 26)) (-2126 (((-141) $ (-790)) 43)) (-3113 (($ (-1 (-141) |#4|) $) 64 (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) 72)) (-3001 (($) 44 T CONST)) (-3239 (((-141) $) 21 (|has| |#1| (-582)))) (-3478 (((-141) $ $) 23 (|has| |#1| (-582)))) (-2398 (((-141) $ $) 22 (|has| |#1| (-582)))) (-1529 (((-141) $) 24 (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 86)) (-4521 (((-658 |#4|) (-658 |#4|) $) 17 (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) 18 (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) 35)) (-2400 (($ (-658 |#4|)) 34)) (-1366 (((-3 $ "failed") $) 75)) (-2226 ((|#4| |#4| $) 82)) (-1360 (($ $) 67 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#4| $) 66 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#4|) $) 63 (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) 95)) (-3092 ((|#4| |#4| $) 80)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 87)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) 98)) (-1836 (((-141) |#4| $) 129)) (-2659 (((-141) |#4| $) 126)) (-3195 (((-141) |#4| $) 130) (((-141) $) 127)) (-4004 (((-658 |#4|) $) 51 (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) 97) (((-141) $) 96)) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) 42)) (-4467 (((-658 |#4|) $) 52 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 54 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 46)) (-2290 (((-658 |#3|) $) 31)) (-2645 (((-141) |#3| $) 30)) (-2554 (((-141) $ (-790)) 41)) (-2685 (((-1173) $) 9)) (-1470 (((-3 |#4| (-658 $)) |#4| |#4| $) 121)) (-3722 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| |#4| $) 120)) (-4255 (((-3 |#4| "failed") $) 76)) (-3501 (((-658 $) |#4| $) 122)) (-3732 (((-3 (-141) (-658 $)) |#4| $) 125)) (-2978 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 $))) |#4| $) 124) (((-141) |#4| $) 123)) (-2852 (((-658 $) |#4| $) 118) (((-658 $) (-658 |#4|) $) 117) (((-658 $) (-658 |#4|) (-658 $)) 116) (((-658 $) |#4| (-658 $)) 115)) (-3902 (($ |#4| $) 110) (($ (-658 |#4|) $) 109)) (-1712 (((-658 |#4|) $) 100)) (-2346 (((-141) |#4| $) 92) (((-141) $) 88)) (-1751 ((|#4| |#4| $) 83)) (-3085 (((-141) $ $) 103)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) 93) (((-141) $) 89)) (-1803 ((|#4| |#4| $) 84)) (-2951 (((-1137) $) 10)) (-1918 (((-3 |#4| "failed") $) 77)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) 60)) (-2778 (((-3 $ "failed") $ |#4|) 71)) (-2807 (($ $ |#4|) 70) (((-658 $) |#4| $) 108) (((-658 $) |#4| (-658 $)) 107) (((-658 $) (-658 |#4|) $) 106) (((-658 $) (-658 |#4|) (-658 $)) 105)) (-3002 (((-141) (-1 (-141) |#4|) $) 49 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) 58 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) 56 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) 55 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) 37)) (-2943 (((-141) $) 40)) (-2890 (($) 39)) (-4525 (((-790) $) 99)) (-3452 (((-790) |#4| $) 53 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#4|) $) 50 (|has| $ (-6 -4625)))) (-4599 (($ $) 38)) (-1778 (((-565) $) 68 (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 59)) (-2613 (($ $ |#3|) 27)) (-4152 (($ $ |#3|) 29)) (-2965 (($ $) 81)) (-2507 (($ $ |#3|) 28)) (-1683 (((-877) $) 11) (((-658 |#4|) $) 36)) (-1857 (((-790) $) 69 (|has| |#3| (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) 101)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) 91)) (-3032 (((-658 $) |#4| $) 114) (((-658 $) |#4| (-658 $)) 113) (((-658 $) (-658 |#4|) $) 112) (((-658 $) (-658 |#4|) (-658 $)) 111)) (-3369 (((-141) (-1 (-141) |#4|) $) 48 (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) 74)) (-1437 (((-141) |#4| $) 128)) (-3069 (((-141) |#3| $) 73)) (-3255 (((-141) $ $) 6)) (-1699 (((-790) $) 45 (|has| $ (-6 -4625))))) 
+(((-1144 |#1| |#2| |#3| |#4|) (-1311) (-477) (-815) (-869) (-1089 |t#1| |t#2| |t#3|)) (T -1144)) 
+NIL 
+(-13 (-1128 |t#1| |t#2| |t#3| |t#4|) (-806 |t#1| |t#2| |t#3| |t#4|)) 
+(((-39) . T) ((-125) . T) ((-632 (-658 |#4|)) . T) ((-632 (-877)) . T) ((-175 |#4|) . T) ((-633 (-565)) |has| |#4| (-633 (-565))) ((-325 |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-523 |#4|) . T) ((-547 |#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-806 |#1| |#2| |#3| |#4|) . T) ((-1005 |#1| |#2| |#3| |#4|) . T) ((-1094 |#1| |#2| |#3| |#4|) . T) ((-1119) . T) ((-1128 |#1| |#2| |#3| |#4|) . T) ((-1219 |#1| |#2| |#3| |#4|) . T) ((-1225) . T)) 
+((-4005 (((-658 |#2|) |#1|) 12)) (-4123 (((-658 |#2|) |#2| |#2| |#2| |#2| |#2|) 37) (((-658 |#2|) |#1|) 47)) (-2163 (((-658 |#2|) |#2| |#2| |#2|) 35) (((-658 |#2|) |#1|) 45)) (-3993 ((|#2| |#1|) 42)) (-1829 (((-2 (|:| |solns| (-658 |#2|)) (|:| |maps| (-658 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|)) 16)) (-4232 (((-658 |#2|) |#2| |#2|) 34) (((-658 |#2|) |#1|) 44)) (-2352 (((-658 |#2|) |#2| |#2| |#2| |#2|) 36) (((-658 |#2|) |#1|) 46)) (-1335 ((|#2| |#2| |#2| |#2| |#2| |#2|) 41)) (-2519 ((|#2| |#2| |#2| |#2|) 39)) (-2192 ((|#2| |#2| |#2|) 38)) (-3887 ((|#2| |#2| |#2| |#2| |#2|) 40))) 
+(((-1145 |#1| |#2|) (-10 -7 (-15 -4005 ((-658 |#2|) |#1|)) (-15 -3993 (|#2| |#1|)) (-15 -1829 ((-2 (|:| |solns| (-658 |#2|)) (|:| |maps| (-658 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|))) (-15 -4232 ((-658 |#2|) |#1|)) (-15 -2163 ((-658 |#2|) |#1|)) (-15 -2352 ((-658 |#2|) |#1|)) (-15 -4123 ((-658 |#2|) |#1|)) (-15 -4232 ((-658 |#2|) |#2| |#2|)) (-15 -2163 ((-658 |#2|) |#2| |#2| |#2|)) (-15 -2352 ((-658 |#2|) |#2| |#2| |#2| |#2|)) (-15 -4123 ((-658 |#2|) |#2| |#2| |#2| |#2| |#2|)) (-15 -2192 (|#2| |#2| |#2|)) (-15 -2519 (|#2| |#2| |#2| |#2|)) (-15 -3887 (|#2| |#2| |#2| |#2| |#2|)) (-15 -1335 (|#2| |#2| |#2| |#2| |#2| |#2|))) (-1255 |#2|) (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (T -1145)) 
+((-1335 (*1 *2 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2)))) (-3887 (*1 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2)))) (-2519 (*1 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2)))) (-2192 (*1 *2 *2 *2) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2)))) (-4123 (*1 *2 *3 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *3)) (-5 *1 (-1145 *4 *3)) (-4 *4 (-1255 *3)))) (-2352 (*1 *2 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *3)) (-5 *1 (-1145 *4 *3)) (-4 *4 (-1255 *3)))) (-2163 (*1 *2 *3 *3 *3) (-12 (-4 *3 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *3)) (-5 *1 (-1145 *4 *3)) (-4 *4 (-1255 *3)))) (-4232 (*1 *2 *3 *3) (-12 (-4 *3 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *3)) (-5 *1 (-1145 *4 *3)) (-4 *4 (-1255 *3)))) (-4123 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) (-2352 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) (-2163 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) (-4232 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) (-1829 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *5 *5)) (-4 *5 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-2 (|:| |solns| (-658 *5)) (|:| |maps| (-658 (-2 (|:| |arg| *5) (|:| |res| *5)))))) (-5 *1 (-1145 *3 *5)) (-4 *3 (-1255 *5)))) (-3993 (*1 *2 *3) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2)))) (-4005 (*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -4005 ((-658 |#2|) |#1|)) (-15 -3993 (|#2| |#1|)) (-15 -1829 ((-2 (|:| |solns| (-658 |#2|)) (|:| |maps| (-658 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|))) (-15 -4232 ((-658 |#2|) |#1|)) (-15 -2163 ((-658 |#2|) |#1|)) (-15 -2352 ((-658 |#2|) |#1|)) (-15 -4123 ((-658 |#2|) |#1|)) (-15 -4232 ((-658 |#2|) |#2| |#2|)) (-15 -2163 ((-658 |#2|) |#2| |#2| |#2|)) (-15 -2352 ((-658 |#2|) |#2| |#2| |#2| |#2|)) (-15 -4123 ((-658 |#2|) |#2| |#2| |#2| |#2| |#2|)) (-15 -2192 (|#2| |#2| |#2|)) (-15 -2519 (|#2| |#2| |#2| |#2|)) (-15 -3887 (|#2| |#2| |#2| |#2| |#2|)) (-15 -1335 (|#2| |#2| |#2| |#2| |#2| |#2|))) 
+((-4142 (((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-433 (-980 |#1|))))) 94) (((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-433 (-980 |#1|)))) (-658 (-1191))) 93) (((-658 (-658 (-310 (-332 |#1|)))) (-658 (-433 (-980 |#1|)))) 91) (((-658 (-658 (-310 (-332 |#1|)))) (-658 (-433 (-980 |#1|))) (-658 (-1191))) 89) (((-658 (-310 (-332 |#1|))) (-310 (-433 (-980 |#1|)))) 75) (((-658 (-310 (-332 |#1|))) (-310 (-433 (-980 |#1|))) (-1191)) 76) (((-658 (-310 (-332 |#1|))) (-433 (-980 |#1|))) 70) (((-658 (-310 (-332 |#1|))) (-433 (-980 |#1|)) (-1191)) 59)) (-3070 (((-658 (-658 (-332 |#1|))) (-658 (-433 (-980 |#1|))) (-658 (-1191))) 87) (((-658 (-332 |#1|)) (-433 (-980 |#1|)) (-1191)) 43)) (-2015 (((-1180 (-658 (-332 |#1|)) (-658 (-310 (-332 |#1|)))) (-433 (-980 |#1|)) (-1191)) 97) (((-1180 (-658 (-332 |#1|)) (-658 (-310 (-332 |#1|)))) (-310 (-433 (-980 |#1|))) (-1191)) 96))) 
+(((-1146 |#1|) (-10 -7 (-15 -4142 ((-658 (-310 (-332 |#1|))) (-433 (-980 |#1|)) (-1191))) (-15 -4142 ((-658 (-310 (-332 |#1|))) (-433 (-980 |#1|)))) (-15 -4142 ((-658 (-310 (-332 |#1|))) (-310 (-433 (-980 |#1|))) (-1191))) (-15 -4142 ((-658 (-310 (-332 |#1|))) (-310 (-433 (-980 |#1|))))) (-15 -4142 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-433 (-980 |#1|))) (-658 (-1191)))) (-15 -4142 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-433 (-980 |#1|))))) (-15 -4142 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-433 (-980 |#1|)))) (-658 (-1191)))) (-15 -4142 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-433 (-980 |#1|)))))) (-15 -3070 ((-658 (-332 |#1|)) (-433 (-980 |#1|)) (-1191))) (-15 -3070 ((-658 (-658 (-332 |#1|))) (-658 (-433 (-980 |#1|))) (-658 (-1191)))) (-15 -2015 ((-1180 (-658 (-332 |#1|)) (-658 (-310 (-332 |#1|)))) (-310 (-433 (-980 |#1|))) (-1191))) (-15 -2015 ((-1180 (-658 (-332 |#1|)) (-658 (-310 (-332 |#1|)))) (-433 (-980 |#1|)) (-1191)))) (-13 (-323) (-869) (-171))) (T -1146)) 
+((-2015 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-1180 (-658 (-332 *5)) (-658 (-310 (-332 *5))))) (-5 *1 (-1146 *5)))) (-2015 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-433 (-980 *5)))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-1180 (-658 (-332 *5)) (-658 (-310 (-332 *5))))) (-5 *1 (-1146 *5)))) (-3070 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 *5)))) (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-332 *5)))) (-5 *1 (-1146 *5)))) (-3070 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-332 *5))) (-5 *1 (-1146 *5)))) (-4142 (*1 *2 *3) (-12 (-5 *3 (-658 (-310 (-433 (-980 *4))))) (-4 *4 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *4))))) (-5 *1 (-1146 *4)))) (-4142 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-310 (-433 (-980 *5))))) (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *5))))) (-5 *1 (-1146 *5)))) (-4142 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 *4)))) (-4 *4 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *4))))) (-5 *1 (-1146 *4)))) (-4142 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 *5)))) (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *5))))) (-5 *1 (-1146 *5)))) (-4142 (*1 *2 *3) (-12 (-5 *3 (-310 (-433 (-980 *4)))) (-4 *4 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-310 (-332 *4)))) (-5 *1 (-1146 *4)))) (-4142 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-433 (-980 *5)))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-310 (-332 *5)))) (-5 *1 (-1146 *5)))) (-4142 (*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-310 (-332 *4)))) (-5 *1 (-1146 *4)))) (-4142 (*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-310 (-332 *5)))) (-5 *1 (-1146 *5))))) 
+(-10 -7 (-15 -4142 ((-658 (-310 (-332 |#1|))) (-433 (-980 |#1|)) (-1191))) (-15 -4142 ((-658 (-310 (-332 |#1|))) (-433 (-980 |#1|)))) (-15 -4142 ((-658 (-310 (-332 |#1|))) (-310 (-433 (-980 |#1|))) (-1191))) (-15 -4142 ((-658 (-310 (-332 |#1|))) (-310 (-433 (-980 |#1|))))) (-15 -4142 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-433 (-980 |#1|))) (-658 (-1191)))) (-15 -4142 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-433 (-980 |#1|))))) (-15 -4142 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-433 (-980 |#1|)))) (-658 (-1191)))) (-15 -4142 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-433 (-980 |#1|)))))) (-15 -3070 ((-658 (-332 |#1|)) (-433 (-980 |#1|)) (-1191))) (-15 -3070 ((-658 (-658 (-332 |#1|))) (-658 (-433 (-980 |#1|))) (-658 (-1191)))) (-15 -2015 ((-1180 (-658 (-332 |#1|)) (-658 (-310 (-332 |#1|)))) (-310 (-433 (-980 |#1|))) (-1191))) (-15 -2015 ((-1180 (-658 (-332 |#1|)) (-658 (-310 (-332 |#1|)))) (-433 (-980 |#1|)) (-1191)))) 
+((-4011 (((-433 (-1187 (-332 |#1|))) (-1280 (-332 |#1|)) (-433 (-1187 (-332 |#1|))) (-592)) 27)) (-2787 (((-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|)))) 39))) 
+(((-1147 |#1|) (-10 -7 (-15 -2787 ((-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|))))) (-15 -4011 ((-433 (-1187 (-332 |#1|))) (-1280 (-332 |#1|)) (-433 (-1187 (-332 |#1|))) (-592)))) (-13 (-582) (-869))) (T -1147)) 
+((-4011 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-433 (-1187 (-332 *5)))) (-5 *3 (-1280 (-332 *5))) (-5 *4 (-592)) (-4 *5 (-13 (-582) (-869))) (-5 *1 (-1147 *5)))) (-2787 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-433 (-1187 (-332 *3)))) (-4 *3 (-13 (-582) (-869))) (-5 *1 (-1147 *3))))) 
+(-10 -7 (-15 -2787 ((-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|))) (-433 (-1187 (-332 |#1|))))) (-15 -4011 ((-433 (-1187 (-332 |#1|))) (-1280 (-332 |#1|)) (-433 (-1187 (-332 |#1|))) (-592)))) 
+((-4005 (((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-332 |#1|))) (-658 (-1191))) 216) (((-658 (-310 (-332 |#1|))) (-332 |#1|) (-1191)) 20) (((-658 (-310 (-332 |#1|))) (-310 (-332 |#1|)) (-1191)) 26) (((-658 (-310 (-332 |#1|))) (-310 (-332 |#1|))) 25) (((-658 (-310 (-332 |#1|))) (-332 |#1|)) 21))) 
+(((-1148 |#1|) (-10 -7 (-15 -4005 ((-658 (-310 (-332 |#1|))) (-332 |#1|))) (-15 -4005 ((-658 (-310 (-332 |#1|))) (-310 (-332 |#1|)))) (-15 -4005 ((-658 (-310 (-332 |#1|))) (-310 (-332 |#1|)) (-1191))) (-15 -4005 ((-658 (-310 (-332 |#1|))) (-332 |#1|) (-1191))) (-15 -4005 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-332 |#1|))) (-658 (-1191))))) (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (T -1148)) 
+((-4005 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *5))))) (-5 *1 (-1148 *5)) (-5 *3 (-658 (-310 (-332 *5)))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-310 (-332 *5)))) (-5 *1 (-1148 *5)) (-5 *3 (-332 *5)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-310 (-332 *5)))) (-5 *1 (-1148 *5)) (-5 *3 (-310 (-332 *5))))) (-4005 (*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-310 (-332 *4)))) (-5 *1 (-1148 *4)) (-5 *3 (-310 (-332 *4))))) (-4005 (*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-310 (-332 *4)))) (-5 *1 (-1148 *4)) (-5 *3 (-332 *4))))) 
+(-10 -7 (-15 -4005 ((-658 (-310 (-332 |#1|))) (-332 |#1|))) (-15 -4005 ((-658 (-310 (-332 |#1|))) (-310 (-332 |#1|)))) (-15 -4005 ((-658 (-310 (-332 |#1|))) (-310 (-332 |#1|)) (-1191))) (-15 -4005 ((-658 (-310 (-332 |#1|))) (-332 |#1|) (-1191))) (-15 -4005 ((-658 (-658 (-310 (-332 |#1|)))) (-658 (-310 (-332 |#1|))) (-658 (-1191))))) 
+((-2544 ((|#2| |#2|) 20 (|has| |#1| (-869))) ((|#2| |#2| (-1 (-141) |#1| |#1|)) 16)) (-1375 ((|#2| |#2|) 19 (|has| |#1| (-869))) ((|#2| |#2| (-1 (-141) |#1| |#1|)) 15))) 
+(((-1149 |#1| |#2|) (-10 -7 (-15 -1375 (|#2| |#2| (-1 (-141) |#1| |#1|))) (-15 -2544 (|#2| |#2| (-1 (-141) |#1| |#1|))) (IF (|has| |#1| (-869)) (PROGN (-15 -1375 (|#2| |#2|)) (-15 -2544 (|#2| |#2|))) |noBranch|)) (-1225) (-13 (-625 (-592) |#1|) (-10 -7 (-6 -4625) (-6 -4626)))) (T -1149)) 
+((-2544 (*1 *2 *2) (-12 (-4 *3 (-869)) (-4 *3 (-1225)) (-5 *1 (-1149 *3 *2)) (-4 *2 (-13 (-625 (-592) *3) (-10 -7 (-6 -4625) (-6 -4626)))))) (-1375 (*1 *2 *2) (-12 (-4 *3 (-869)) (-4 *3 (-1225)) (-5 *1 (-1149 *3 *2)) (-4 *2 (-13 (-625 (-592) *3) (-10 -7 (-6 -4625) (-6 -4626)))))) (-2544 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-1149 *4 *2)) (-4 *2 (-13 (-625 (-592) *4) (-10 -7 (-6 -4625) (-6 -4626)))))) (-1375 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-1149 *4 *2)) (-4 *2 (-13 (-625 (-592) *4) (-10 -7 (-6 -4625) (-6 -4626))))))) 
+(-10 -7 (-15 -1375 (|#2| |#2| (-1 (-141) |#1| |#1|))) (-15 -2544 (|#2| |#2| (-1 (-141) |#1| |#1|))) (IF (|has| |#1| (-869)) (PROGN (-15 -1375 (|#2| |#2|)) (-15 -2544 (|#2| |#2|))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-3540 (((-1179 3 |#1|) $) 105)) (-4595 (((-141) $) 72)) (-3449 (($ $ (-658 (-971 |#1|))) 20) (($ $ (-658 (-658 |#1|))) 75) (($ (-658 (-971 |#1|))) 74) (((-658 (-971 |#1|)) $) 73)) (-2048 (((-141) $) 41)) (-1831 (($ $ (-971 |#1|)) 46) (($ $ (-658 |#1|)) 51) (($ $ (-790)) 53) (($ (-971 |#1|)) 47) (((-971 |#1|) $) 45)) (-3284 (((-2 (|:| -2190 (-790)) (|:| |curves| (-790)) (|:| |polygons| (-790)) (|:| |constructs| (-790))) $) 103)) (-2675 (((-790) $) 26)) (-3804 (((-790) $) 25)) (-3443 (($ $ (-790) (-971 |#1|)) 39)) (-3788 (((-141) $) 82)) (-4138 (($ $ (-658 (-658 (-971 |#1|))) (-658 (-193)) (-193)) 89) (($ $ (-658 (-658 (-658 |#1|))) (-658 (-193)) (-193)) 91) (($ $ (-658 (-658 (-971 |#1|))) (-141) (-141)) 85) (($ $ (-658 (-658 (-658 |#1|))) (-141) (-141)) 93) (($ (-658 (-658 (-971 |#1|)))) 86) (($ (-658 (-658 (-971 |#1|))) (-141) (-141)) 87) (((-658 (-658 (-971 |#1|))) $) 84)) (-4491 (($ (-658 $)) 28) (($ $ $) 29)) (-4021 (((-658 (-193)) $) 101)) (-1988 (((-658 (-971 |#1|)) $) 96)) (-1502 (((-658 (-658 (-193))) $) 100)) (-1401 (((-658 (-658 (-658 (-971 |#1|)))) $) NIL)) (-2972 (((-658 (-658 (-658 (-790)))) $) 98)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2946 (((-790) $ (-658 (-971 |#1|))) 37)) (-3141 (((-141) $) 54)) (-2354 (($ $ (-658 (-971 |#1|))) 56) (($ $ (-658 (-658 |#1|))) 62) (($ (-658 (-971 |#1|))) 57) (((-658 (-971 |#1|)) $) 55)) (-4146 (($) 23) (($ (-1179 3 |#1|)) 24)) (-4599 (($ $) 35)) (-1570 (((-658 $) $) 34)) (-1528 (($ (-658 $)) 31)) (-3233 (((-658 $) $) 33)) (-1683 (((-877) $) 109)) (-4093 (((-141) $) 64)) (-2579 (($ $ (-658 (-971 |#1|))) 66) (($ $ (-658 (-658 |#1|))) 69) (($ (-658 (-971 |#1|))) 67) (((-658 (-971 |#1|)) $) 65)) (-3971 (($ $) 104)) (-3255 (((-141) $ $) NIL))) 
+(((-1150 |#1|) (-1151 |#1|) (-1075)) (T -1150)) 
+NIL 
+(-1151 |#1|) 
+((-1641 (((-141) $ $) 7)) (-3540 (((-1179 3 |#1|) $) 12)) (-4595 (((-141) $) 28)) (-3449 (($ $ (-658 (-971 |#1|))) 32) (($ $ (-658 (-658 |#1|))) 31) (($ (-658 (-971 |#1|))) 30) (((-658 (-971 |#1|)) $) 29)) (-2048 (((-141) $) 43)) (-1831 (($ $ (-971 |#1|)) 48) (($ $ (-658 |#1|)) 47) (($ $ (-790)) 46) (($ (-971 |#1|)) 45) (((-971 |#1|) $) 44)) (-3284 (((-2 (|:| -2190 (-790)) (|:| |curves| (-790)) (|:| |polygons| (-790)) (|:| |constructs| (-790))) $) 14)) (-2675 (((-790) $) 57)) (-3804 (((-790) $) 58)) (-3443 (($ $ (-790) (-971 |#1|)) 49)) (-3788 (((-141) $) 20)) (-4138 (($ $ (-658 (-658 (-971 |#1|))) (-658 (-193)) (-193)) 27) (($ $ (-658 (-658 (-658 |#1|))) (-658 (-193)) (-193)) 26) (($ $ (-658 (-658 (-971 |#1|))) (-141) (-141)) 25) (($ $ (-658 (-658 (-658 |#1|))) (-141) (-141)) 24) (($ (-658 (-658 (-971 |#1|)))) 23) (($ (-658 (-658 (-971 |#1|))) (-141) (-141)) 22) (((-658 (-658 (-971 |#1|))) $) 21)) (-4491 (($ (-658 $)) 56) (($ $ $) 55)) (-4021 (((-658 (-193)) $) 15)) (-1988 (((-658 (-971 |#1|)) $) 19)) (-1502 (((-658 (-658 (-193))) $) 16)) (-1401 (((-658 (-658 (-658 (-971 |#1|)))) $) 17)) (-2972 (((-658 (-658 (-658 (-790)))) $) 18)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2946 (((-790) $ (-658 (-971 |#1|))) 50)) (-3141 (((-141) $) 38)) (-2354 (($ $ (-658 (-971 |#1|))) 42) (($ $ (-658 (-658 |#1|))) 41) (($ (-658 (-971 |#1|))) 40) (((-658 (-971 |#1|)) $) 39)) (-4146 (($) 60) (($ (-1179 3 |#1|)) 59)) (-4599 (($ $) 51)) (-1570 (((-658 $) $) 52)) (-1528 (($ (-658 $)) 54)) (-3233 (((-658 $) $) 53)) (-1683 (((-877) $) 11)) (-4093 (((-141) $) 33)) (-2579 (($ $ (-658 (-971 |#1|))) 37) (($ $ (-658 (-658 |#1|))) 36) (($ (-658 (-971 |#1|))) 35) (((-658 (-971 |#1|)) $) 34)) (-3971 (($ $) 13)) (-3255 (((-141) $ $) 6))) 
+(((-1151 |#1|) (-1311) (-1075)) (T -1151)) 
+((-1683 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-877)))) (-4146 (*1 *1) (-12 (-4 *1 (-1151 *2)) (-4 *2 (-1075)))) (-4146 (*1 *1 *2) (-12 (-5 *2 (-1179 3 *3)) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) (-3804 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) (-2675 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) (-4491 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-4491 (*1 *1 *1 *1) (-12 (-4 *1 (-1151 *2)) (-4 *2 (-1075)))) (-1528 (*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-3233 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-658 *1)) (-4 *1 (-1151 *3)))) (-1570 (*1 *2 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-658 *1)) (-4 *1 (-1151 *3)))) (-4599 (*1 *1 *1) (-12 (-4 *1 (-1151 *2)) (-4 *2 (-1075)))) (-2946 (*1 *2 *1 *3) (-12 (-5 *3 (-658 (-971 *4))) (-4 *1 (-1151 *4)) (-4 *4 (-1075)) (-5 *2 (-790)))) (-3443 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-971 *4)) (-4 *1 (-1151 *4)) (-4 *4 (-1075)))) (-1831 (*1 *1 *1 *2) (-12 (-5 *2 (-971 *3)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-1831 (*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-1831 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-1831 (*1 *1 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) (-1831 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-971 *3)))) (-2048 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141)))) (-2354 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-2354 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-2354 (*1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) (-2354 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-971 *3))))) (-3141 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141)))) (-2579 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-2579 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-2579 (*1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) (-2579 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-971 *3))))) (-4093 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141)))) (-3449 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-3449 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) (-3449 (*1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) (-3449 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-971 *3))))) (-4595 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141)))) (-4138 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-658 (-971 *5)))) (-5 *3 (-658 (-193))) (-5 *4 (-193)) (-4 *1 (-1151 *5)) (-4 *5 (-1075)))) (-4138 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-658 (-658 *5)))) (-5 *3 (-658 (-193))) (-5 *4 (-193)) (-4 *1 (-1151 *5)) (-4 *5 (-1075)))) (-4138 (*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-658 (-658 (-971 *4)))) (-5 *3 (-141)) (-4 *1 (-1151 *4)) (-4 *4 (-1075)))) (-4138 (*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-658 (-658 (-658 *4)))) (-5 *3 (-141)) (-4 *1 (-1151 *4)) (-4 *4 (-1075)))) (-4138 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-971 *3)))) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) (-4138 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-658 (-658 (-971 *4)))) (-5 *3 (-141)) (-4 *4 (-1075)) (-4 *1 (-1151 *4)))) (-4138 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-658 (-971 *3)))))) (-3788 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141)))) (-1988 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-971 *3))))) (-2972 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-658 (-658 (-790))))))) (-1401 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-658 (-658 (-971 *3))))))) (-1502 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-658 (-193)))))) (-4021 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-193))))) (-3284 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2190 (-790)) (|:| |curves| (-790)) (|:| |polygons| (-790)) (|:| |constructs| (-790)))))) (-3971 (*1 *1 *1) (-12 (-4 *1 (-1151 *2)) (-4 *2 (-1075)))) (-3540 (*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-1179 3 *3))))) 
+(-13 (-1119) (-10 -8 (-15 -4146 ($)) (-15 -4146 ($ (-1179 3 |t#1|))) (-15 -3804 ((-790) $)) (-15 -2675 ((-790) $)) (-15 -4491 ($ (-658 $))) (-15 -4491 ($ $ $)) (-15 -1528 ($ (-658 $))) (-15 -3233 ((-658 $) $)) (-15 -1570 ((-658 $) $)) (-15 -4599 ($ $)) (-15 -2946 ((-790) $ (-658 (-971 |t#1|)))) (-15 -3443 ($ $ (-790) (-971 |t#1|))) (-15 -1831 ($ $ (-971 |t#1|))) (-15 -1831 ($ $ (-658 |t#1|))) (-15 -1831 ($ $ (-790))) (-15 -1831 ($ (-971 |t#1|))) (-15 -1831 ((-971 |t#1|) $)) (-15 -2048 ((-141) $)) (-15 -2354 ($ $ (-658 (-971 |t#1|)))) (-15 -2354 ($ $ (-658 (-658 |t#1|)))) (-15 -2354 ($ (-658 (-971 |t#1|)))) (-15 -2354 ((-658 (-971 |t#1|)) $)) (-15 -3141 ((-141) $)) (-15 -2579 ($ $ (-658 (-971 |t#1|)))) (-15 -2579 ($ $ (-658 (-658 |t#1|)))) (-15 -2579 ($ (-658 (-971 |t#1|)))) (-15 -2579 ((-658 (-971 |t#1|)) $)) (-15 -4093 ((-141) $)) (-15 -3449 ($ $ (-658 (-971 |t#1|)))) (-15 -3449 ($ $ (-658 (-658 |t#1|)))) (-15 -3449 ($ (-658 (-971 |t#1|)))) (-15 -3449 ((-658 (-971 |t#1|)) $)) (-15 -4595 ((-141) $)) (-15 -4138 ($ $ (-658 (-658 (-971 |t#1|))) (-658 (-193)) (-193))) (-15 -4138 ($ $ (-658 (-658 (-658 |t#1|))) (-658 (-193)) (-193))) (-15 -4138 ($ $ (-658 (-658 (-971 |t#1|))) (-141) (-141))) (-15 -4138 ($ $ (-658 (-658 (-658 |t#1|))) (-141) (-141))) (-15 -4138 ($ (-658 (-658 (-971 |t#1|))))) (-15 -4138 ($ (-658 (-658 (-971 |t#1|))) (-141) (-141))) (-15 -4138 ((-658 (-658 (-971 |t#1|))) $)) (-15 -3788 ((-141) $)) (-15 -1988 ((-658 (-971 |t#1|)) $)) (-15 -2972 ((-658 (-658 (-658 (-790)))) $)) (-15 -1401 ((-658 (-658 (-658 (-971 |t#1|)))) $)) (-15 -1502 ((-658 (-658 (-193))) $)) (-15 -4021 ((-658 (-193)) $)) (-15 -3284 ((-2 (|:| -2190 (-790)) (|:| |curves| (-790)) (|:| |polygons| (-790)) (|:| |constructs| (-790))) $)) (-15 -3971 ($ $)) (-15 -3540 ((-1179 3 |t#1|) $)) (-15 -1683 ((-877) $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-1969 (((-1285) (-658 (-877))) 23) (((-1285) (-877)) 22)) (-3574 (((-1285) (-658 (-877))) 21) (((-1285) (-877)) 20)) (-3592 (((-1285) (-658 (-877))) 19) (((-1285) (-877)) 11) (((-1285) (-1173) (-877)) 17))) 
+(((-1152) (-10 -7 (-15 -3592 ((-1285) (-1173) (-877))) (-15 -3592 ((-1285) (-877))) (-15 -3574 ((-1285) (-877))) (-15 -1969 ((-1285) (-877))) (-15 -3592 ((-1285) (-658 (-877)))) (-15 -3574 ((-1285) (-658 (-877)))) (-15 -1969 ((-1285) (-658 (-877)))))) (T -1152)) 
+((-1969 (*1 *2 *3) (-12 (-5 *3 (-658 (-877))) (-5 *2 (-1285)) (-5 *1 (-1152)))) (-3574 (*1 *2 *3) (-12 (-5 *3 (-658 (-877))) (-5 *2 (-1285)) (-5 *1 (-1152)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-658 (-877))) (-5 *2 (-1285)) (-5 *1 (-1152)))) (-1969 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-1152)))) (-3574 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-1152)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-1152)))) (-3592 (*1 *2 *3 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-877)) (-5 *2 (-1285)) (-5 *1 (-1152))))) 
+(-10 -7 (-15 -3592 ((-1285) (-1173) (-877))) (-15 -3592 ((-1285) (-877))) (-15 -3574 ((-1285) (-877))) (-15 -1969 ((-1285) (-877))) (-15 -3592 ((-1285) (-658 (-877)))) (-15 -3574 ((-1285) (-658 (-877)))) (-15 -1969 ((-1285) (-658 (-877))))) 
+((-4018 (($ $ $) 10)) (-2002 (($ $) 9)) (-2280 (($ $ $) 13)) (-2500 (($ $ $) 15)) (-3468 (($ $ $) 12)) (-2894 (($ $ $) 14)) (-2156 (($ $) 17)) (-3132 (($ $) 16)) (-1392 (($ $) 6)) (-2348 (($ $ $) 11) (($ $) 7)) (-2170 (($ $ $) 8))) 
+(((-1153) (-1311)) (T -1153)) 
+((-2156 (*1 *1 *1) (-4 *1 (-1153))) (-3132 (*1 *1 *1) (-4 *1 (-1153))) (-2500 (*1 *1 *1 *1) (-4 *1 (-1153))) (-2894 (*1 *1 *1 *1) (-4 *1 (-1153))) (-2280 (*1 *1 *1 *1) (-4 *1 (-1153))) (-3468 (*1 *1 *1 *1) (-4 *1 (-1153))) (-2348 (*1 *1 *1 *1) (-4 *1 (-1153))) (-4018 (*1 *1 *1 *1) (-4 *1 (-1153))) (-2002 (*1 *1 *1) (-4 *1 (-1153))) (-2170 (*1 *1 *1 *1) (-4 *1 (-1153))) (-2348 (*1 *1 *1) (-4 *1 (-1153))) (-1392 (*1 *1 *1) (-4 *1 (-1153)))) 
+(-13 (-10 -8 (-15 -1392 ($ $)) (-15 -2348 ($ $)) (-15 -2170 ($ $ $)) (-15 -2002 ($ $)) (-15 -4018 ($ $ $)) (-15 -2348 ($ $ $)) (-15 -3468 ($ $ $)) (-15 -2280 ($ $ $)) (-15 -2894 ($ $ $)) (-15 -2500 ($ $ $)) (-15 -3132 ($ $)) (-15 -2156 ($ $)))) 
+((-1641 (((-141) $ $) 41)) (-2324 ((|#1| $) 15)) (-2412 (((-141) $ $ (-1 (-141) |#2| |#2|)) 36)) (-4499 (((-141) $) 17)) (-3050 (($ $ |#1|) 28)) (-4235 (($ $ (-141)) 30)) (-1912 (($ $) 31)) (-2250 (($ $ |#2|) 29)) (-2685 (((-1173) $) NIL)) (-4145 (((-141) $ $ (-1 (-141) |#1| |#1|) (-1 (-141) |#2| |#2|)) 35)) (-2951 (((-1137) $) NIL)) (-2943 (((-141) $) 14)) (-2890 (($) 10)) (-4599 (($ $) 27)) (-4466 (($ |#1| |#2| (-141)) 18) (($ |#1| |#2|) 19) (($ (-2 (|:| |val| |#1|) (|:| -2165 |#2|))) 21) (((-658 $) (-658 (-2 (|:| |val| |#1|) (|:| -2165 |#2|)))) 24) (((-658 $) |#1| (-658 |#2|)) 26)) (-2847 ((|#2| $) 16)) (-1683 (((-877) $) 50)) (-3255 (((-141) $ $) 39))) 
+(((-1154 |#1| |#2|) (-13 (-1119) (-10 -8 (-15 -2890 ($)) (-15 -2943 ((-141) $)) (-15 -2324 (|#1| $)) (-15 -2847 (|#2| $)) (-15 -4499 ((-141) $)) (-15 -4466 ($ |#1| |#2| (-141))) (-15 -4466 ($ |#1| |#2|)) (-15 -4466 ($ (-2 (|:| |val| |#1|) (|:| -2165 |#2|)))) (-15 -4466 ((-658 $) (-658 (-2 (|:| |val| |#1|) (|:| -2165 |#2|))))) (-15 -4466 ((-658 $) |#1| (-658 |#2|))) (-15 -4599 ($ $)) (-15 -3050 ($ $ |#1|)) (-15 -2250 ($ $ |#2|)) (-15 -4235 ($ $ (-141))) (-15 -1912 ($ $)) (-15 -4145 ((-141) $ $ (-1 (-141) |#1| |#1|) (-1 (-141) |#2| |#2|))) (-15 -2412 ((-141) $ $ (-1 (-141) |#2| |#2|))))) (-13 (-1119) (-39)) (-13 (-1119) (-39))) (T -1154)) 
+((-2890 (*1 *1) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-2943 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))))) (-2324 (*1 *2 *1) (-12 (-4 *2 (-13 (-1119) (-39))) (-5 *1 (-1154 *2 *3)) (-4 *3 (-13 (-1119) (-39))))) (-2847 (*1 *2 *1) (-12 (-4 *2 (-13 (-1119) (-39))) (-5 *1 (-1154 *3 *2)) (-4 *3 (-13 (-1119) (-39))))) (-4499 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))))) (-4466 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-141)) (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-4466 (*1 *1 *2 *3) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-4466 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |val| *3) (|:| -2165 *4))) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1154 *3 *4)))) (-4466 (*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| |val| *4) (|:| -2165 *5)))) (-4 *4 (-13 (-1119) (-39))) (-4 *5 (-13 (-1119) (-39))) (-5 *2 (-658 (-1154 *4 *5))) (-5 *1 (-1154 *4 *5)))) (-4466 (*1 *2 *3 *4) (-12 (-5 *4 (-658 *5)) (-4 *5 (-13 (-1119) (-39))) (-5 *2 (-658 (-1154 *3 *5))) (-5 *1 (-1154 *3 *5)) (-4 *3 (-13 (-1119) (-39))))) (-4599 (*1 *1 *1) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-3050 (*1 *1 *1 *2) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-2250 (*1 *1 *1 *2) (-12 (-5 *1 (-1154 *3 *2)) (-4 *3 (-13 (-1119) (-39))) (-4 *2 (-13 (-1119) (-39))))) (-4235 (*1 *1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))))) (-1912 (*1 *1 *1) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-4145 (*1 *2 *1 *1 *3 *4) (-12 (-5 *3 (-1 (-141) *5 *5)) (-5 *4 (-1 (-141) *6 *6)) (-4 *5 (-13 (-1119) (-39))) (-4 *6 (-13 (-1119) (-39))) (-5 *2 (-141)) (-5 *1 (-1154 *5 *6)))) (-2412 (*1 *2 *1 *1 *3) (-12 (-5 *3 (-1 (-141) *5 *5)) (-4 *5 (-13 (-1119) (-39))) (-5 *2 (-141)) (-5 *1 (-1154 *4 *5)) (-4 *4 (-13 (-1119) (-39)))))) 
+(-13 (-1119) (-10 -8 (-15 -2890 ($)) (-15 -2943 ((-141) $)) (-15 -2324 (|#1| $)) (-15 -2847 (|#2| $)) (-15 -4499 ((-141) $)) (-15 -4466 ($ |#1| |#2| (-141))) (-15 -4466 ($ |#1| |#2|)) (-15 -4466 ($ (-2 (|:| |val| |#1|) (|:| -2165 |#2|)))) (-15 -4466 ((-658 $) (-658 (-2 (|:| |val| |#1|) (|:| -2165 |#2|))))) (-15 -4466 ((-658 $) |#1| (-658 |#2|))) (-15 -4599 ($ $)) (-15 -3050 ($ $ |#1|)) (-15 -2250 ($ $ |#2|)) (-15 -4235 ($ $ (-141))) (-15 -1912 ($ $)) (-15 -4145 ((-141) $ $ (-1 (-141) |#1| |#1|) (-1 (-141) |#2| |#2|))) (-15 -2412 ((-141) $ $ (-1 (-141) |#2| |#2|))))) 
+((-1641 (((-141) $ $) NIL (|has| (-1154 |#1| |#2|) (-1119)))) (-2324 (((-1154 |#1| |#2|) $) 25)) (-1839 (($ $) 75)) (-4167 (((-141) (-1154 |#1| |#2|) $ (-1 (-141) |#2| |#2|)) 84)) (-3324 (($ $ $ (-658 (-1154 |#1| |#2|))) 89) (($ $ $ (-658 (-1154 |#1| |#2|)) (-1 (-141) |#2| |#2|)) 90)) (-2126 (((-141) $ (-790)) NIL)) (-3047 (((-1154 |#1| |#2|) $ (-1154 |#1| |#2|)) 42 (|has| $ (-6 -4626)))) (-3932 (((-1154 |#1| |#2|) $ "value" (-1154 |#1| |#2|)) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 40 (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-3080 (((-658 (-2 (|:| |val| |#1|) (|:| -2165 |#2|))) $) 79)) (-4065 (($ (-1154 |#1| |#2|) $) 38)) (-4459 (($ (-1154 |#1| |#2|) $) 30)) (-4004 (((-658 (-1154 |#1| |#2|)) $) NIL (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 50)) (-4276 (((-141) (-1154 |#1| |#2|) $) 81)) (-3055 (((-141) $ $) NIL (|has| (-1154 |#1| |#2|) (-1119)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 (-1154 |#1| |#2|)) $) 54 (|has| $ (-6 -4625)))) (-3133 (((-141) (-1154 |#1| |#2|) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-1154 |#1| |#2|) (-1119))))) (-3987 (($ (-1 (-1154 |#1| |#2|) (-1154 |#1| |#2|)) $) 46 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-1154 |#1| |#2|) (-1154 |#1| |#2|)) $) 45)) (-2554 (((-141) $ (-790)) NIL)) (-4063 (((-658 (-1154 |#1| |#2|)) $) 52)) (-3683 (((-141) $) 41)) (-2685 (((-1173) $) NIL (|has| (-1154 |#1| |#2|) (-1119)))) (-2951 (((-1137) $) NIL (|has| (-1154 |#1| |#2|) (-1119)))) (-3079 (((-3 $ "failed") $) 74)) (-3002 (((-141) (-1 (-141) (-1154 |#1| |#2|)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-1154 |#1| |#2|)))) NIL (-12 (|has| (-1154 |#1| |#2|) (-325 (-1154 |#1| |#2|))) (|has| (-1154 |#1| |#2|) (-1119)))) (($ $ (-310 (-1154 |#1| |#2|))) NIL (-12 (|has| (-1154 |#1| |#2|) (-325 (-1154 |#1| |#2|))) (|has| (-1154 |#1| |#2|) (-1119)))) (($ $ (-1154 |#1| |#2|) (-1154 |#1| |#2|)) NIL (-12 (|has| (-1154 |#1| |#2|) (-325 (-1154 |#1| |#2|))) (|has| (-1154 |#1| |#2|) (-1119)))) (($ $ (-658 (-1154 |#1| |#2|)) (-658 (-1154 |#1| |#2|))) NIL (-12 (|has| (-1154 |#1| |#2|) (-325 (-1154 |#1| |#2|))) (|has| (-1154 |#1| |#2|) (-1119))))) (-1724 (((-141) $ $) 49)) (-2943 (((-141) $) 22)) (-2890 (($) 24)) (-3927 (((-1154 |#1| |#2|) $ "value") NIL)) (-2920 (((-592) $ $) NIL)) (-3228 (((-141) $) 43)) (-3452 (((-790) (-1 (-141) (-1154 |#1| |#2|)) $) NIL (|has| $ (-6 -4625))) (((-790) (-1154 |#1| |#2|) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-1154 |#1| |#2|) (-1119))))) (-4599 (($ $) 48)) (-4466 (($ (-1154 |#1| |#2|)) 9) (($ |#1| |#2| (-658 $)) 12) (($ |#1| |#2| (-658 (-1154 |#1| |#2|))) 14) (($ |#1| |#2| |#1| (-658 |#2|)) 17)) (-4203 (((-658 |#2|) $) 80)) (-1683 (((-877) $) 72 (|has| (-1154 |#1| |#2|) (-1119)))) (-2493 (((-658 $) $) 28)) (-2936 (((-141) $ $) NIL (|has| (-1154 |#1| |#2|) (-1119)))) (-3369 (((-141) (-1 (-141) (-1154 |#1| |#2|)) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 63 (|has| (-1154 |#1| |#2|) (-1119)))) (-1699 (((-790) $) 57 (|has| $ (-6 -4625))))) 
+(((-1155 |#1| |#2|) (-13 (-1038 (-1154 |#1| |#2|)) (-10 -8 (-6 -4626) (-6 -4625) (-15 -3079 ((-3 $ "failed") $)) (-15 -1839 ($ $)) (-15 -4466 ($ (-1154 |#1| |#2|))) (-15 -4466 ($ |#1| |#2| (-658 $))) (-15 -4466 ($ |#1| |#2| (-658 (-1154 |#1| |#2|)))) (-15 -4466 ($ |#1| |#2| |#1| (-658 |#2|))) (-15 -4203 ((-658 |#2|) $)) (-15 -3080 ((-658 (-2 (|:| |val| |#1|) (|:| -2165 |#2|))) $)) (-15 -4276 ((-141) (-1154 |#1| |#2|) $)) (-15 -4167 ((-141) (-1154 |#1| |#2|) $ (-1 (-141) |#2| |#2|))) (-15 -4459 ($ (-1154 |#1| |#2|) $)) (-15 -4065 ($ (-1154 |#1| |#2|) $)) (-15 -3324 ($ $ $ (-658 (-1154 |#1| |#2|)))) (-15 -3324 ($ $ $ (-658 (-1154 |#1| |#2|)) (-1 (-141) |#2| |#2|))))) (-13 (-1119) (-39)) (-13 (-1119) (-39))) (T -1155)) 
+((-3079 (*1 *1 *1) (|partial| -12 (-5 *1 (-1155 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-1839 (*1 *1 *1) (-12 (-5 *1 (-1155 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-4466 (*1 *1 *2) (-12 (-5 *2 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1155 *3 *4)))) (-4466 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-658 (-1155 *2 *3))) (-5 *1 (-1155 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) (-4466 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-658 (-1154 *2 *3))) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))) (-5 *1 (-1155 *2 *3)))) (-4466 (*1 *1 *2 *3 *2 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-13 (-1119) (-39))) (-5 *1 (-1155 *2 *3)) (-4 *2 (-13 (-1119) (-39))))) (-4203 (*1 *2 *1) (-12 (-5 *2 (-658 *4)) (-5 *1 (-1155 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))))) (-3080 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1155 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))))) (-4276 (*1 *2 *3 *1) (-12 (-5 *3 (-1154 *4 *5)) (-4 *4 (-13 (-1119) (-39))) (-4 *5 (-13 (-1119) (-39))) (-5 *2 (-141)) (-5 *1 (-1155 *4 *5)))) (-4167 (*1 *2 *3 *1 *4) (-12 (-5 *3 (-1154 *5 *6)) (-5 *4 (-1 (-141) *6 *6)) (-4 *5 (-13 (-1119) (-39))) (-4 *6 (-13 (-1119) (-39))) (-5 *2 (-141)) (-5 *1 (-1155 *5 *6)))) (-4459 (*1 *1 *2 *1) (-12 (-5 *2 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1155 *3 *4)))) (-4065 (*1 *1 *2 *1) (-12 (-5 *2 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1155 *3 *4)))) (-3324 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-658 (-1154 *3 *4))) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1155 *3 *4)))) (-3324 (*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1154 *4 *5))) (-5 *3 (-1 (-141) *5 *5)) (-4 *4 (-13 (-1119) (-39))) (-4 *5 (-13 (-1119) (-39))) (-5 *1 (-1155 *4 *5))))) 
+(-13 (-1038 (-1154 |#1| |#2|)) (-10 -8 (-6 -4626) (-6 -4625) (-15 -3079 ((-3 $ "failed") $)) (-15 -1839 ($ $)) (-15 -4466 ($ (-1154 |#1| |#2|))) (-15 -4466 ($ |#1| |#2| (-658 $))) (-15 -4466 ($ |#1| |#2| (-658 (-1154 |#1| |#2|)))) (-15 -4466 ($ |#1| |#2| |#1| (-658 |#2|))) (-15 -4203 ((-658 |#2|) $)) (-15 -3080 ((-658 (-2 (|:| |val| |#1|) (|:| -2165 |#2|))) $)) (-15 -4276 ((-141) (-1154 |#1| |#2|) $)) (-15 -4167 ((-141) (-1154 |#1| |#2|) $ (-1 (-141) |#2| |#2|))) (-15 -4459 ($ (-1154 |#1| |#2|) $)) (-15 -4065 ($ (-1154 |#1| |#2|) $)) (-15 -3324 ($ $ $ (-658 (-1154 |#1| |#2|)))) (-15 -3324 ($ $ $ (-658 (-1154 |#1| |#2|)) (-1 (-141) |#2| |#2|))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2245 (($ $) NIL)) (-4529 ((|#2| $) NIL)) (-4034 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3083 (($ (-706 |#2|)) 45)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3223 (($ |#2|) 9)) (-3001 (($) NIL T CONST)) (-3052 (($ $) 58 (|has| |#2| (-323)))) (-2747 (((-254 |#1| |#2|) $ (-592)) 31)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 |#2| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) ((|#2| $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) 72)) (-4175 (((-790) $) 60 (|has| |#2| (-582)))) (-3959 ((|#2| $ (-592) (-592)) NIL)) (-4004 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3558 (((-141) $) NIL)) (-3178 (((-790) $) 62 (|has| |#2| (-582)))) (-3555 (((-658 (-254 |#1| |#2|)) $) 66 (|has| |#2| (-582)))) (-4292 (((-790) $) NIL)) (-4298 (((-790) $) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-3781 ((|#2| $) 56 (|has| |#2| (-6 (-4627 "*"))))) (-4577 (((-592) $) NIL)) (-4280 (((-592) $) NIL)) (-4467 (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1898 (((-592) $) NIL)) (-3005 (((-592) $) NIL)) (-4186 (($ (-658 (-658 |#2|))) 26)) (-3987 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 |#2| |#2|) $) NIL)) (-4601 (((-658 (-658 |#2|)) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-3183 (((-3 $ "failed") $) 69 (|has| |#2| (-388)))) (-2951 (((-1137) $) NIL)) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582)))) (-3002 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ (-592) (-592) |#2|) NIL) ((|#2| $ (-592) (-592)) NIL)) (-3644 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-790)) NIL (|has| |#2| (-247))) (($ $) NIL (|has| |#2| (-247)))) (-2236 ((|#2| $) NIL)) (-2933 (($ (-658 |#2|)) 40)) (-2940 (((-141) $) NIL)) (-1332 (((-254 |#1| |#2|) $) NIL)) (-1625 ((|#2| $) 54 (|has| |#2| (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4599 (($ $) NIL)) (-1778 (((-565) $) 81 (|has| |#2| (-633 (-565))))) (-2000 (((-254 |#1| |#2|) $ (-592)) 33)) (-1683 (((-877) $) 36) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#2| (-1065 (-433 (-592))))) (($ |#2|) NIL) (((-706 |#2|) $) 42)) (-4010 (((-790)) 17)) (-3369 (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 11 T CONST)) (-4257 (($) 14 T CONST)) (-1940 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-790)) NIL (|has| |#2| (-247))) (($ $) NIL (|has| |#2| (-247)))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) 52) (($ $ (-592)) 71 (|has| |#2| (-388)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (((-254 |#1| |#2|) $ (-254 |#1| |#2|)) 48) (((-254 |#1| |#2|) (-254 |#1| |#2|) $) 50)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1156 |#1| |#2|) (-13 (-1140 |#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) (-632 (-706 |#2|)) (-10 -8 (-15 -2245 ($ $)) (-15 -3083 ($ (-706 |#2|))) (-15 -1683 ((-706 |#2|) $)) (IF (|has| |#2| (-6 (-4627 "*"))) (-6 -4614) |noBranch|) (IF (|has| |#2| (-6 (-4627 "*"))) (IF (|has| |#2| (-6 -4622)) (-6 -4622) |noBranch|) |noBranch|) (IF (|has| |#2| (-633 (-565))) (-6 (-633 (-565))) |noBranch|))) (-790) (-1075)) (T -1156)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-706 *4)) (-5 *1 (-1156 *3 *4)) (-14 *3 (-790)) (-4 *4 (-1075)))) (-2245 (*1 *1 *1) (-12 (-5 *1 (-1156 *2 *3)) (-14 *2 (-790)) (-4 *3 (-1075)))) (-3083 (*1 *1 *2) (-12 (-5 *2 (-706 *4)) (-4 *4 (-1075)) (-5 *1 (-1156 *3 *4)) (-14 *3 (-790))))) 
+(-13 (-1140 |#1| |#2| (-254 |#1| |#2|) (-254 |#1| |#2|)) (-632 (-706 |#2|)) (-10 -8 (-15 -2245 ($ $)) (-15 -3083 ($ (-706 |#2|))) (-15 -1683 ((-706 |#2|) $)) (IF (|has| |#2| (-6 (-4627 "*"))) (-6 -4614) |noBranch|) (IF (|has| |#2| (-6 (-4627 "*"))) (IF (|has| |#2| (-6 -4622)) (-6 -4622) |noBranch|) |noBranch|) (IF (|has| |#2| (-633 (-565))) (-6 (-633 (-565))) |noBranch|))) 
+((-3777 (($ $) 19)) (-2874 (($ $ (-168)) 10) (($ $ (-163)) 14)) (-3379 (((-141) $ $) 24)) (-1633 (($ $) 17)) (-3927 (((-168) $ (-592) (-168)) NIL) (((-168) $ (-592)) NIL) (($ $ (-1246 (-592))) NIL) (($ $ $) 29)) (-1683 (($ (-168)) 27) (((-877) $) NIL))) 
+(((-1157 |#1|) (-10 -8 (-15 -1683 ((-877) |#1|)) (-15 -3927 (|#1| |#1| |#1|)) (-15 -2874 (|#1| |#1| (-163))) (-15 -2874 (|#1| |#1| (-168))) (-15 -1683 (|#1| (-168))) (-15 -3379 ((-141) |#1| |#1|)) (-15 -3777 (|#1| |#1|)) (-15 -1633 (|#1| |#1|)) (-15 -3927 (|#1| |#1| (-1246 (-592)))) (-15 -3927 ((-168) |#1| (-592))) (-15 -3927 ((-168) |#1| (-592) (-168)))) (-1158)) (T -1157)) 
+NIL 
+(-10 -8 (-15 -1683 ((-877) |#1|)) (-15 -3927 (|#1| |#1| |#1|)) (-15 -2874 (|#1| |#1| (-163))) (-15 -2874 (|#1| |#1| (-168))) (-15 -1683 (|#1| (-168))) (-15 -3379 ((-141) |#1| |#1|)) (-15 -3777 (|#1| |#1|)) (-15 -1633 (|#1| |#1|)) (-15 -3927 (|#1| |#1| (-1246 (-592)))) (-15 -3927 ((-168) |#1| (-592))) (-15 -3927 ((-168) |#1| (-592) (-168)))) 
+((-1641 (((-141) $ $) 18 (|has| (-168) (-1119)))) (-3202 (($ $) 113)) (-3777 (($ $) 114)) (-2874 (($ $ (-168)) 101) (($ $ (-163)) 100)) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-3326 (((-141) $ $) 111)) (-3288 (((-141) $ $ (-592)) 110)) (-1356 (((-658 $) $ (-168)) 103) (((-658 $) $ (-163)) 102)) (-4076 (((-141) (-1 (-141) (-168) (-168)) $) 91) (((-141) $) 85 (|has| (-168) (-869)))) (-2831 (($ (-1 (-141) (-168) (-168)) $) 82 (|has| $ (-6 -4626))) (($ $) 81 (-12 (|has| (-168) (-869)) (|has| $ (-6 -4626))))) (-3960 (($ (-1 (-141) (-168) (-168)) $) 92) (($ $) 86 (|has| (-168) (-869)))) (-2126 (((-141) $ (-790)) 8)) (-3932 (((-168) $ (-592) (-168)) 49 (|has| $ (-6 -4626))) (((-168) $ (-1246 (-592)) (-168)) 53 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-168)) $) 70 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-4447 (($ $ (-168)) 97) (($ $ (-163)) 96)) (-2512 (($ $) 83 (|has| $ (-6 -4626)))) (-1373 (($ $) 93)) (-2262 (($ $ (-1246 (-592)) $) 107)) (-1360 (($ $) 73 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ (-168) $) 72 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) (-168)) $) 69 (|has| $ (-6 -4625)))) (-3657 (((-168) (-1 (-168) (-168) (-168)) $ (-168) (-168)) 71 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625)))) (((-168) (-1 (-168) (-168) (-168)) $ (-168)) 68 (|has| $ (-6 -4625))) (((-168) (-1 (-168) (-168) (-168)) $) 67 (|has| $ (-6 -4625)))) (-1426 (((-168) $ (-592) (-168)) 50 (|has| $ (-6 -4626)))) (-3959 (((-168) $ (-592)) 48)) (-3379 (((-141) $ $) 112)) (-1721 (((-592) (-1 (-141) (-168)) $) 90) (((-592) (-168) $) 89 (|has| (-168) (-1119))) (((-592) (-168) $ (-592)) 88 (|has| (-168) (-1119))) (((-592) $ $ (-592)) 106) (((-592) (-163) $ (-592)) 105)) (-4004 (((-658 (-168)) $) 30 (|has| $ (-6 -4625)))) (-3242 (($ (-790) (-168)) 64)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-1837 (($ $ $) 80 (|has| (-168) (-869)))) (-4491 (($ (-1 (-141) (-168) (-168)) $ $) 94) (($ $ $) 87 (|has| (-168) (-869)))) (-4467 (((-658 (-168)) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) (-168) $) 27 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3319 (($ $ $) 79 (|has| (-168) (-869)))) (-3614 (((-141) $ $ (-168)) 108)) (-1600 (((-790) $ $ (-168)) 109)) (-3987 (($ (-1 (-168) (-168)) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-168) (-168)) $) 35) (($ (-1 (-168) (-168) (-168)) $ $) 59)) (-2200 (($ $) 115)) (-1633 (($ $) 116)) (-2554 (((-141) $ (-790)) 10)) (-2999 (($ $ (-168)) 99) (($ $ (-163)) 98)) (-2685 (((-1173) $) 22 (|has| (-168) (-1119)))) (-3666 (($ (-168) $ (-592)) 55) (($ $ $ (-592)) 54)) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-2951 (((-1137) $) 21 (|has| (-168) (-1119)))) (-1918 (((-168) $) 39 (|has| (-592) (-869)))) (-4050 (((-3 (-168) "failed") (-1 (-141) (-168)) $) 66)) (-1892 (($ $ (-168)) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-168)) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-168)))) 26 (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-310 (-168))) 25 (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-168) (-168)) 24 (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-658 (-168)) (-658 (-168))) 23 (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) (-168) $) 42 (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-4210 (((-658 (-168)) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 (((-168) $ (-592) (-168)) 47) (((-168) $ (-592)) 46) (($ $ (-1246 (-592))) 58) (($ $ $) 95)) (-3208 (($ $ (-592)) 57) (($ $ (-1246 (-592))) 56)) (-3452 (((-790) (-1 (-141) (-168)) $) 31 (|has| $ (-6 -4625))) (((-790) (-168) $) 28 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625))))) (-2385 (($ $ $ (-592)) 84 (|has| $ (-6 -4626)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 74 (|has| (-168) (-633 (-565))))) (-4466 (($ (-658 (-168))) 65)) (-2266 (($ $ (-168)) 63) (($ (-168) $) 62) (($ $ $) 61) (($ (-658 $)) 60)) (-1683 (($ (-168)) 104) (((-877) $) 20 (|has| (-168) (-1119)))) (-3369 (((-141) (-1 (-141) (-168)) $) 33 (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) 77 (|has| (-168) (-869)))) (-3273 (((-141) $ $) 76 (|has| (-168) (-869)))) (-3255 (((-141) $ $) 19 (|has| (-168) (-1119)))) (-3279 (((-141) $ $) 78 (|has| (-168) (-869)))) (-3266 (((-141) $ $) 75 (|has| (-168) (-869)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1158) (-1311)) (T -1158)) 
+((-1633 (*1 *1 *1) (-4 *1 (-1158))) (-2200 (*1 *1 *1) (-4 *1 (-1158))) (-3777 (*1 *1 *1) (-4 *1 (-1158))) (-3202 (*1 *1 *1) (-4 *1 (-1158))) (-3379 (*1 *2 *1 *1) (-12 (-4 *1 (-1158)) (-5 *2 (-141)))) (-3326 (*1 *2 *1 *1) (-12 (-4 *1 (-1158)) (-5 *2 (-141)))) (-3288 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1158)) (-5 *3 (-592)) (-5 *2 (-141)))) (-1600 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1158)) (-5 *3 (-168)) (-5 *2 (-790)))) (-3614 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1158)) (-5 *3 (-168)) (-5 *2 (-141)))) (-2262 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-1158)) (-5 *2 (-1246 (-592))))) (-1721 (*1 *2 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-592)))) (-1721 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-592)) (-5 *3 (-163)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-168)) (-4 *1 (-1158)))) (-1356 (*1 *2 *1 *3) (-12 (-5 *3 (-168)) (-5 *2 (-658 *1)) (-4 *1 (-1158)))) (-1356 (*1 *2 *1 *3) (-12 (-5 *3 (-163)) (-5 *2 (-658 *1)) (-4 *1 (-1158)))) (-2874 (*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-168)))) (-2874 (*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-163)))) (-2999 (*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-168)))) (-2999 (*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-163)))) (-4447 (*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-168)))) (-4447 (*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-163)))) (-3927 (*1 *1 *1 *1) (-4 *1 (-1158)))) 
+(-13 (-19 (-168)) (-10 -8 (-15 -1633 ($ $)) (-15 -2200 ($ $)) (-15 -3777 ($ $)) (-15 -3202 ($ $)) (-15 -3379 ((-141) $ $)) (-15 -3326 ((-141) $ $)) (-15 -3288 ((-141) $ $ (-592))) (-15 -1600 ((-790) $ $ (-168))) (-15 -3614 ((-141) $ $ (-168))) (-15 -2262 ($ $ (-1246 (-592)) $)) (-15 -1721 ((-592) $ $ (-592))) (-15 -1721 ((-592) (-163) $ (-592))) (-15 -1683 ($ (-168))) (-15 -1356 ((-658 $) $ (-168))) (-15 -1356 ((-658 $) $ (-163))) (-15 -2874 ($ $ (-168))) (-15 -2874 ($ $ (-163))) (-15 -2999 ($ $ (-168))) (-15 -2999 ($ $ (-163))) (-15 -4447 ($ $ (-168))) (-15 -4447 ($ $ (-163))) (-15 -3927 ($ $ $)))) 
+(((-39) . T) ((-125) -3836 (|has| (-168) (-1119)) (|has| (-168) (-869))) ((-632 (-877)) -3836 (|has| (-168) (-1119)) (|has| (-168) (-869))) ((-175 (-168)) . T) ((-633 (-565)) |has| (-168) (-633 (-565))) ((-303 (-592) (-168)) . T) ((-305 (-592) (-168)) . T) ((-325 (-168)) -12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))) ((-399 (-168)) . T) ((-523 (-168)) . T) ((-625 (-592) (-168)) . T) ((-547 (-168) (-168)) -12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))) ((-664 (-168)) . T) ((-19 (-168)) . T) ((-869) |has| (-168) (-869)) ((-1119) -3836 (|has| (-168) (-1119)) (|has| (-168) (-869))) ((-1225) . T)) 
+((-3931 (((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 |#4|) (-658 |#5|) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-790)) 93)) (-4304 (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|) 54) (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790)) 53)) (-3891 (((-1285) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-790)) 85)) (-3148 (((-790) (-658 |#4|) (-658 |#5|)) 27)) (-2856 (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|) 56) (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790)) 55) (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790) (-141)) 57)) (-1906 (((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141) (-141) (-141) (-141)) 76) (((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141)) 77)) (-1778 (((-1173) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) 80)) (-1929 (((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|) 52)) (-4270 (((-790) (-658 |#4|) (-658 |#5|)) 19))) 
+(((-1159 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4270 ((-790) (-658 |#4|) (-658 |#5|))) (-15 -3148 ((-790) (-658 |#4|) (-658 |#5|))) (-15 -1929 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -4304 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790))) (-15 -4304 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790) (-141))) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790))) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -1906 ((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141))) (-15 -1906 ((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141) (-141) (-141) (-141))) (-15 -3931 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 |#4|) (-658 |#5|) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-790))) (-15 -1778 ((-1173) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) (-15 -3891 ((-1285) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-790)))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|) (-1128 |#1| |#2| |#3| |#4|)) (T -1159)) 
+((-3891 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| |val| (-658 *8)) (|:| -2165 *9)))) (-5 *4 (-790)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-1285)) (-5 *1 (-1159 *5 *6 *7 *8 *9)))) (-1778 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-658 *7)) (|:| -2165 *8))) (-4 *7 (-1089 *4 *5 *6)) (-4 *8 (-1128 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1173)) (-5 *1 (-1159 *4 *5 *6 *7 *8)))) (-3931 (*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-658 *11)) (|:| |todo| (-658 (-2 (|:| |val| *3) (|:| -2165 *11)))))) (-5 *6 (-790)) (-5 *2 (-658 (-2 (|:| |val| (-658 *10)) (|:| -2165 *11)))) (-5 *3 (-658 *10)) (-5 *4 (-658 *11)) (-4 *10 (-1089 *7 *8 *9)) (-4 *11 (-1128 *7 *8 *9 *10)) (-4 *7 (-477)) (-4 *8 (-815)) (-4 *9 (-869)) (-5 *1 (-1159 *7 *8 *9 *10 *11)))) (-1906 (*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-658 *9)) (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1159 *5 *6 *7 *8 *9)))) (-1906 (*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-658 *9)) (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1159 *5 *6 *7 *8 *9)))) (-2856 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *5 *6 *7 *3 *4)) (-4 *4 (-1128 *5 *6 *7 *3)))) (-2856 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *6 *7 *8 *3 *4)) (-4 *4 (-1128 *6 *7 *8 *3)))) (-2856 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-790)) (-5 *6 (-141)) (-4 *7 (-477)) (-4 *8 (-815)) (-4 *9 (-869)) (-4 *3 (-1089 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *7 *8 *9 *3 *4)) (-4 *4 (-1128 *7 *8 *9 *3)))) (-4304 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *5 *6 *7 *3 *4)) (-4 *4 (-1128 *5 *6 *7 *3)))) (-4304 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *6 *7 *8 *3 *4)) (-4 *4 (-1128 *6 *7 *8 *3)))) (-1929 (*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *5 *6 *7 *3 *4)) (-4 *4 (-1128 *5 *6 *7 *3)))) (-3148 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *9)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-790)) (-5 *1 (-1159 *5 *6 *7 *8 *9)))) (-4270 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *9)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-790)) (-5 *1 (-1159 *5 *6 *7 *8 *9))))) 
+(-10 -7 (-15 -4270 ((-790) (-658 |#4|) (-658 |#5|))) (-15 -3148 ((-790) (-658 |#4|) (-658 |#5|))) (-15 -1929 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -4304 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790))) (-15 -4304 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790) (-141))) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5| (-790))) (-15 -2856 ((-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) |#4| |#5|)) (-15 -1906 ((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141))) (-15 -1906 ((-658 |#5|) (-658 |#4|) (-658 |#5|) (-141) (-141) (-141) (-141) (-141))) (-15 -3931 ((-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-658 |#4|) (-658 |#5|) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-2 (|:| |done| (-658 |#5|)) (|:| |todo| (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))))) (-790))) (-15 -1778 ((-1173) (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|)))) (-15 -3891 ((-1285) (-658 (-2 (|:| |val| (-658 |#4|)) (|:| -2165 |#5|))) (-790)))) 
+((-1641 (((-141) $ $) NIL)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) NIL)) (-2248 (((-658 $) (-658 |#4|)) 109) (((-658 $) (-658 |#4|) (-141)) 110) (((-658 $) (-658 |#4|) (-141) (-141)) 108) (((-658 $) (-658 |#4|) (-141) (-141) (-141) (-141)) 111)) (-4085 (((-658 |#3|) $) NIL)) (-4325 (((-141) $) NIL)) (-2988 (((-141) $) NIL (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-2244 ((|#4| |#4| $) NIL)) (-3743 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| $) 83)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3113 (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) 61)) (-3001 (($) NIL T CONST)) (-3239 (((-141) $) 26 (|has| |#1| (-582)))) (-3478 (((-141) $ $) NIL (|has| |#1| (-582)))) (-2398 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1529 (((-141) $) NIL (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-4521 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) NIL)) (-2400 (($ (-658 |#4|)) NIL)) (-1366 (((-3 $ "failed") $) 39)) (-2226 ((|#4| |#4| $) 64)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-4459 (($ |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 77 (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) NIL)) (-3092 ((|#4| |#4| $) NIL)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) NIL)) (-1836 (((-141) |#4| $) NIL)) (-2659 (((-141) |#4| $) NIL)) (-3195 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1822 (((-2 (|:| |val| (-658 |#4|)) (|:| |towers| (-658 $))) (-658 |#4|) (-141) (-141)) 123)) (-4004 (((-658 |#4|) $) 16 (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#4|) $) 17 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 25 (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-3987 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 21)) (-2290 (((-658 |#3|) $) NIL)) (-2645 (((-141) |#3| $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-1470 (((-3 |#4| (-658 $)) |#4| |#4| $) NIL)) (-3722 (((-658 (-2 (|:| |val| |#4|) (|:| -2165 $))) |#4| |#4| $) 102)) (-4255 (((-3 |#4| "failed") $) 37)) (-3501 (((-658 $) |#4| $) 87)) (-3732 (((-3 (-141) (-658 $)) |#4| $) NIL)) (-2978 (((-658 (-2 (|:| |val| (-141)) (|:| -2165 $))) |#4| $) 97) (((-141) |#4| $) 52)) (-2852 (((-658 $) |#4| $) 106) (((-658 $) (-658 |#4|) $) NIL) (((-658 $) (-658 |#4|) (-658 $)) 107) (((-658 $) |#4| (-658 $)) NIL)) (-3859 (((-658 $) (-658 |#4|) (-141) (-141) (-141)) 118)) (-3902 (($ |#4| $) 74) (($ (-658 |#4|) $) 75) (((-658 $) |#4| $ (-141) (-141) (-141) (-141) (-141)) 73)) (-1712 (((-658 |#4|) $) NIL)) (-2346 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1751 ((|#4| |#4| $) NIL)) (-3085 (((-141) $ $) NIL)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1803 ((|#4| |#4| $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-3 |#4| "failed") $) 35)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) NIL)) (-2778 (((-3 $ "failed") $ |#4|) 47)) (-2807 (($ $ |#4|) NIL) (((-658 $) |#4| $) 89) (((-658 $) |#4| (-658 $)) NIL) (((-658 $) (-658 |#4|) $) NIL) (((-658 $) (-658 |#4|) (-658 $)) 85)) (-3002 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 15)) (-2890 (($) 13)) (-4525 (((-790) $) NIL)) (-3452 (((-790) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (((-790) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) 12)) (-1778 (((-565) $) NIL (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 20)) (-2613 (($ $ |#3|) 42)) (-4152 (($ $ |#3|) 43)) (-2965 (($ $) NIL)) (-2507 (($ $ |#3|) NIL)) (-1683 (((-877) $) 31) (((-658 |#4|) $) 40)) (-1857 (((-790) $) NIL (|has| |#3| (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) NIL)) (-3032 (((-658 $) |#4| $) 53) (((-658 $) |#4| (-658 $)) NIL) (((-658 $) (-658 |#4|) $) NIL) (((-658 $) (-658 |#4|) (-658 $)) NIL)) (-3369 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) NIL)) (-1437 (((-141) |#4| $) NIL)) (-3069 (((-141) |#3| $) 60)) (-3255 (((-141) $ $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1160 |#1| |#2| |#3| |#4|) (-13 (-1128 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3902 ((-658 $) |#4| $ (-141) (-141) (-141) (-141) (-141))) (-15 -2248 ((-658 $) (-658 |#4|) (-141) (-141))) (-15 -2248 ((-658 $) (-658 |#4|) (-141) (-141) (-141) (-141))) (-15 -3859 ((-658 $) (-658 |#4|) (-141) (-141) (-141))) (-15 -1822 ((-2 (|:| |val| (-658 |#4|)) (|:| |towers| (-658 $))) (-658 |#4|) (-141) (-141))))) (-477) (-815) (-869) (-1089 |#1| |#2| |#3|)) (T -1160)) 
+((-3902 (*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1160 *5 *6 *7 *3))) (-5 *1 (-1160 *5 *6 *7 *3)) (-4 *3 (-1089 *5 *6 *7)))) (-2248 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1160 *5 *6 *7 *8))) (-5 *1 (-1160 *5 *6 *7 *8)))) (-2248 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1160 *5 *6 *7 *8))) (-5 *1 (-1160 *5 *6 *7 *8)))) (-3859 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1160 *5 *6 *7 *8))) (-5 *1 (-1160 *5 *6 *7 *8)))) (-1822 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-658 *8)) (|:| |towers| (-658 (-1160 *5 *6 *7 *8))))) (-5 *1 (-1160 *5 *6 *7 *8)) (-5 *3 (-658 *8))))) 
+(-13 (-1128 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3902 ((-658 $) |#4| $ (-141) (-141) (-141) (-141) (-141))) (-15 -2248 ((-658 $) (-658 |#4|) (-141) (-141))) (-15 -2248 ((-658 $) (-658 |#4|) (-141) (-141) (-141) (-141))) (-15 -3859 ((-658 $) (-658 |#4|) (-141) (-141) (-141))) (-15 -1822 ((-2 (|:| |val| (-658 |#4|)) (|:| |towers| (-658 $))) (-658 |#4|) (-141) (-141))))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3349 ((|#1| $) 28)) (-2633 (($ (-658 |#1|)) 33)) (-2126 (((-141) $ (-790)) NIL)) (-3001 (($) NIL T CONST)) (-3568 ((|#1| |#1| $) 30)) (-2486 ((|#1| $) 26)) (-4004 (((-658 |#1|) $) 34 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) 39 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 37)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4137 ((|#1| $) 29)) (-2113 (($ |#1| $) 31)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-2106 ((|#1| $) 27)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 24)) (-2890 (($) 32)) (-3439 (((-790) $) 22)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) 20)) (-1683 (((-877) $) 17 (|has| |#1| (-1119)))) (-4560 (($ (-658 |#1|)) NIL)) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 12 (|has| |#1| (-1119)))) (-1699 (((-790) $) 23 (|has| $ (-6 -4625))))) 
+(((-1161 |#1|) (-13 (-1138 |#1|) (-10 -8 (-15 -2633 ($ (-658 |#1|))) (-15 -2486 (|#1| $)) (-15 -2106 (|#1| $)) (-15 -3568 (|#1| |#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -3349 (|#1| $)) (-15 -3439 ((-790) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -4560 ($ (-658 |#1|))) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -3001 ($)) (-15 -4599 ($ $)) (-15 -1724 ((-141) $ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) (-1119)) (T -1161)) 
+((-1724 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)))) (-4599 (*1 *1 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-2890 (*1 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-2943 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)))) (-2554 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1161 *4)) (-4 *4 (-1119)))) (-4345 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1161 *4)) (-4 *4 (-1119)))) (-2126 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1161 *4)) (-4 *4 (-1119)))) (-3001 (*1 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-1161 *3)))) (-3987 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-1119)) (-5 *1 (-1161 *3)))) (-3369 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-1161 *4)))) (-3002 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-1161 *4)))) (-3452 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-1161 *4)))) (-4004 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)))) (-4467 (*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)))) (-3452 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-3133 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-2685 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-2951 (*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-3255 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-1641 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) (-4560 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1161 *3)))) (-2106 (*1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-2113 (*1 *1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-4137 (*1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-3568 (*1 *2 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-2486 (*1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-3349 (*1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) (-3439 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)))) (-2633 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1161 *3))))) 
+(-13 (-1138 |#1|) (-10 -8 (-15 -2633 ($ (-658 |#1|))) (-15 -2486 (|#1| $)) (-15 -2106 (|#1| $)) (-15 -3568 (|#1| |#1| $)) (-15 -2113 ($ |#1| $)) (-15 -4137 (|#1| $)) (-15 -3349 (|#1| $)) (-15 -3439 ((-790) $)) (-15 -2554 ((-141) $ (-790))) (-15 -4345 ((-141) $ (-790))) (-15 -2126 ((-141) $ (-790))) (-15 -4560 ($ (-658 |#1|))) (-15 -2943 ((-141) $)) (-15 -2890 ($)) (-15 -3001 ($)) (-15 -4599 ($ $)) (-15 -1724 ((-141) $ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4626)) (-15 -3987 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1119)) (PROGN (-15 -2685 ((-1173) $)) (-15 -2951 ((-1137) $)) (-15 -1683 ((-877) $)) (-15 -3255 ((-141) $ $)) (-15 -1641 ((-141) $ $))) |noBranch|) (IF (|has| $ (-6 -4625)) (PROGN (-15 -3002 ((-141) (-1 (-141) |#1|) $)) (-15 -3369 ((-141) (-1 (-141) |#1|) $)) (-15 -3452 ((-790) (-1 (-141) |#1|) $)) (-15 -1699 ((-790) $)) (-15 -4004 ((-658 |#1|) $)) (-15 -4467 ((-658 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4625)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3133 ((-141) |#1| $)) (-15 -3452 ((-790) |#1| $))) |noBranch|) |noBranch|))) 
+((-3932 ((|#2| $ "value" |#2|) NIL) ((|#2| $ "first" |#2|) NIL) (($ $ "rest" $) NIL) ((|#2| $ "last" |#2|) NIL) ((|#2| $ (-1246 (-592)) |#2|) 43) ((|#2| $ (-592) |#2|) 40)) (-3868 (((-141) $) 11)) (-3987 (($ (-1 |#2| |#2|) $) 38)) (-1918 ((|#2| $) NIL) (($ $ (-790)) 16)) (-1892 (($ $ |#2|) 39)) (-2955 (((-141) $) 10)) (-3927 ((|#2| $ "value") NIL) ((|#2| $ "first") NIL) (($ $ "rest") NIL) ((|#2| $ "last") NIL) (($ $ (-1246 (-592))) 30) ((|#2| $ (-592)) 22) ((|#2| $ (-592) |#2|) NIL)) (-3619 (($ $ $) 46) (($ $ |#2|) NIL)) (-2266 (($ $ $) 32) (($ |#2| $) NIL) (($ (-658 $)) 35) (($ $ |#2|) NIL))) 
+(((-1162 |#1| |#2|) (-10 -8 (-15 -3868 ((-141) |#1|)) (-15 -2955 ((-141) |#1|)) (-15 -3932 (|#2| |#1| (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592))) (-15 -1892 (|#1| |#1| |#2|)) (-15 -2266 (|#1| |#1| |#2|)) (-15 -2266 (|#1| (-658 |#1|))) (-15 -3927 (|#1| |#1| (-1246 (-592)))) (-15 -3932 (|#2| |#1| (-1246 (-592)) |#2|)) (-15 -3932 (|#2| |#1| "last" |#2|)) (-15 -3932 (|#1| |#1| "rest" |#1|)) (-15 -3932 (|#2| |#1| "first" |#2|)) (-15 -3619 (|#1| |#1| |#2|)) (-15 -3619 (|#1| |#1| |#1|)) (-15 -3927 (|#2| |#1| "last")) (-15 -3927 (|#1| |#1| "rest")) (-15 -1918 (|#1| |#1| (-790))) (-15 -3927 (|#2| |#1| "first")) (-15 -1918 (|#2| |#1|)) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#1|)) (-15 -3932 (|#2| |#1| "value" |#2|)) (-15 -3927 (|#2| |#1| "value")) (-15 -3987 (|#1| (-1 |#2| |#2|) |#1|))) (-1163 |#2|) (-1225)) (T -1162)) 
+NIL 
+(-10 -8 (-15 -3868 ((-141) |#1|)) (-15 -2955 ((-141) |#1|)) (-15 -3932 (|#2| |#1| (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592) |#2|)) (-15 -3927 (|#2| |#1| (-592))) (-15 -1892 (|#1| |#1| |#2|)) (-15 -2266 (|#1| |#1| |#2|)) (-15 -2266 (|#1| (-658 |#1|))) (-15 -3927 (|#1| |#1| (-1246 (-592)))) (-15 -3932 (|#2| |#1| (-1246 (-592)) |#2|)) (-15 -3932 (|#2| |#1| "last" |#2|)) (-15 -3932 (|#1| |#1| "rest" |#1|)) (-15 -3932 (|#2| |#1| "first" |#2|)) (-15 -3619 (|#1| |#1| |#2|)) (-15 -3619 (|#1| |#1| |#1|)) (-15 -3927 (|#2| |#1| "last")) (-15 -3927 (|#1| |#1| "rest")) (-15 -1918 (|#1| |#1| (-790))) (-15 -3927 (|#2| |#1| "first")) (-15 -1918 (|#2| |#1|)) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#1|)) (-15 -3932 (|#2| |#1| "value" |#2|)) (-15 -3927 (|#2| |#1| "value")) (-15 -3987 (|#1| (-1 |#2| |#2|) |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-1915 ((|#1| $) 62)) (-3188 (($ $) 64)) (-3898 (((-1285) $ (-592) (-592)) 94 (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) 49 (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-3153 (($ $ $) 53 (|has| $ (-6 -4626)))) (-4496 ((|#1| $ |#1|) 51 (|has| $ (-6 -4626)))) (-2101 ((|#1| $ |#1|) 55 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4626))) (($ $ "rest" $) 52 (|has| $ (-6 -4626))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 114 (|has| $ (-6 -4626))) ((|#1| $ (-592) |#1|) 83 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) 99 (|has| $ (-6 -4625)))) (-1765 ((|#1| $) 63)) (-3001 (($) 7 T CONST)) (-1366 (($ $) 70) (($ $ (-790)) 68)) (-1360 (($ $) 96 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ (-1 (-141) |#1|) $) 100 (|has| $ (-6 -4625))) (($ |#1| $) 97 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1426 ((|#1| $ (-592) |#1|) 82 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 84)) (-3868 (((-141) $) 80)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-3242 (($ (-790) |#1|) 105)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 92 (|has| (-592) (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 91 (|has| (-592) (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-2554 (((-141) $ (-790)) 10)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4255 ((|#1| $) 67) (($ $ (-790)) 65)) (-3666 (($ $ $ (-592)) 113) (($ |#1| $ (-592)) 112)) (-3708 (((-658 (-592)) $) 89)) (-3780 (((-141) (-592) $) 88)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 73) (($ $ (-790)) 71)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 103)) (-1892 (($ $ |#1|) 93 (|has| $ (-6 -4626)))) (-2955 (((-141) $) 81)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 90 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 87)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1246 (-592))) 109) ((|#1| $ (-592)) 86) ((|#1| $ (-592) |#1|) 85)) (-2920 (((-592) $ $) 41)) (-3208 (($ $ (-1246 (-592))) 111) (($ $ (-592)) 110)) (-3228 (((-141) $) 43)) (-2399 (($ $) 59)) (-1337 (($ $) 56 (|has| $ (-6 -4626)))) (-3318 (((-790) $) 60)) (-3184 (($ $) 61)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-1778 (((-565) $) 95 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 104)) (-3619 (($ $ $) 58 (|has| $ (-6 -4626))) (($ $ |#1|) 57 (|has| $ (-6 -4626)))) (-2266 (($ $ $) 75) (($ |#1| $) 74) (($ (-658 $)) 107) (($ $ |#1|) 106)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1163 |#1|) (-1311) (-1225)) (T -1163)) 
+((-2955 (*1 *2 *1) (-12 (-4 *1 (-1163 *3)) (-4 *3 (-1225)) (-5 *2 (-141)))) (-3868 (*1 *2 *1) (-12 (-4 *1 (-1163 *3)) (-4 *3 (-1225)) (-5 *2 (-141))))) 
+(-13 (-1267 |t#1|) (-664 |t#1|) (-10 -8 (-15 -2955 ((-141) $)) (-15 -3868 ((-141) $)))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-664 |#1|) . T) ((-1038 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1225) . T) ((-1267 |#1|) . T)) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3898 (((-1285) $ |#1| |#1|) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#2| $ |#1| |#2|) NIL)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 |#2| "failed") |#1| $) NIL)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) NIL)) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) NIL)) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 ((|#1| $) NIL (|has| |#1| (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 ((|#1| $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-2840 (((-658 |#1|) $) NIL)) (-2396 (((-141) |#1| $) NIL)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3708 (((-658 |#1|) $) NIL)) (-3780 (((-141) |#1| $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1918 ((|#2| $) NIL (|has| |#1| (-869)))) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1164 |#1| |#2| |#3|) (-1202 |#1| |#2|) (-1119) (-1119) |#2|) (T -1164)) 
+NIL 
+(-1202 |#1| |#2|) 
+((-1641 (((-141) $ $) 7)) (-3921 (((-3 $ "failed") $) 12)) (-2685 (((-1173) $) 9)) (-3703 (($) 13 T CONST)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11)) (-3255 (((-141) $ $) 6))) 
+(((-1165) (-1311)) (T -1165)) 
+((-3703 (*1 *1) (-4 *1 (-1165))) (-3921 (*1 *1 *1) (|partial| -4 *1 (-1165)))) 
+(-13 (-1119) (-10 -8 (-15 -3703 ($) -4249) (-15 -3921 ((-3 $ "failed") $)))) 
+(((-125) . T) ((-632 (-877)) . T) ((-1119) . T)) 
+((-3066 (((-1171 |#1|) (-1171 |#1|)) 17)) (-1353 (((-1171 |#1|) (-1171 |#1|)) 13)) (-2448 (((-1171 |#1|) (-1171 |#1|) (-592) (-592)) 20)) (-2447 (((-1171 |#1|) (-1171 |#1|)) 15))) 
+(((-1166 |#1|) (-10 -7 (-15 -1353 ((-1171 |#1|) (-1171 |#1|))) (-15 -2447 ((-1171 |#1|) (-1171 |#1|))) (-15 -3066 ((-1171 |#1|) (-1171 |#1|))) (-15 -2448 ((-1171 |#1|) (-1171 |#1|) (-592) (-592)))) (-13 (-582) (-171))) (T -1166)) 
+((-2448 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-592)) (-4 *4 (-13 (-582) (-171))) (-5 *1 (-1166 *4)))) (-3066 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-13 (-582) (-171))) (-5 *1 (-1166 *3)))) (-2447 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-13 (-582) (-171))) (-5 *1 (-1166 *3)))) (-1353 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-13 (-582) (-171))) (-5 *1 (-1166 *3))))) 
+(-10 -7 (-15 -1353 ((-1171 |#1|) (-1171 |#1|))) (-15 -2447 ((-1171 |#1|) (-1171 |#1|))) (-15 -3066 ((-1171 |#1|) (-1171 |#1|))) (-15 -2448 ((-1171 |#1|) (-1171 |#1|) (-592) (-592)))) 
+((-1440 (((-1171 |#1|) (-1171 |#1|) (-1 (-658 |#1|) |#1|)) 16))) 
+(((-1167 |#1|) (-10 -7 (-15 -1440 ((-1171 |#1|) (-1171 |#1|) (-1 (-658 |#1|) |#1|)))) (-1225)) (T -1167)) 
+((-1440 (*1 *2 *2 *3) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-1 (-658 *4) *4)) (-4 *4 (-1225)) (-5 *1 (-1167 *4))))) 
+(-10 -7 (-15 -1440 ((-1171 |#1|) (-1171 |#1|) (-1 (-658 |#1|) |#1|)))) 
+((-2266 (((-1171 |#1|) (-1171 (-1171 |#1|))) 15))) 
+(((-1168 |#1|) (-10 -7 (-15 -2266 ((-1171 |#1|) (-1171 (-1171 |#1|))))) (-1225)) (T -1168)) 
+((-2266 (*1 *2 *3) (-12 (-5 *3 (-1171 (-1171 *4))) (-5 *2 (-1171 *4)) (-5 *1 (-1168 *4)) (-4 *4 (-1225))))) 
+(-10 -7 (-15 -2266 ((-1171 |#1|) (-1171 (-1171 |#1|))))) 
+((-1779 (((-1171 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1171 |#1|)) 25)) (-3657 ((|#2| |#2| (-1 |#2| |#1| |#2|) (-1171 |#1|)) 26)) (-2731 (((-1171 |#2|) (-1 |#2| |#1|) (-1171 |#1|)) 16))) 
+(((-1169 |#1| |#2|) (-10 -7 (-15 -2731 ((-1171 |#2|) (-1 |#2| |#1|) (-1171 |#1|))) (-15 -1779 ((-1171 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1171 |#1|))) (-15 -3657 (|#2| |#2| (-1 |#2| |#1| |#2|) (-1171 |#1|)))) (-1225) (-1225)) (T -1169)) 
+((-3657 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1171 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-1169 *5 *2)))) (-1779 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *3 *6 *3)) (-5 *5 (-1171 *6)) (-4 *6 (-1225)) (-4 *3 (-1225)) (-5 *2 (-1171 *3)) (-5 *1 (-1169 *6 *3)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1171 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1171 *6)) (-5 *1 (-1169 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-1171 |#2|) (-1 |#2| |#1|) (-1171 |#1|))) (-15 -1779 ((-1171 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1171 |#1|))) (-15 -3657 (|#2| |#2| (-1 |#2| |#1| |#2|) (-1171 |#1|)))) 
+((-2731 (((-1171 |#3|) (-1 |#3| |#1| |#2|) (-1171 |#1|) (-1171 |#2|)) 21))) 
+(((-1170 |#1| |#2| |#3|) (-10 -7 (-15 -2731 ((-1171 |#3|) (-1 |#3| |#1| |#2|) (-1171 |#1|) (-1171 |#2|)))) (-1225) (-1225) (-1225)) (T -1170)) 
+((-2731 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1171 *6)) (-5 *5 (-1171 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-1171 *8)) (-5 *1 (-1170 *6 *7 *8))))) 
+(-10 -7 (-15 -2731 ((-1171 |#3|) (-1 |#3| |#1| |#2|) (-1171 |#1|) (-1171 |#2|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) NIL)) (-1915 ((|#1| $) NIL)) (-3188 (($ $) 48)) (-3898 (((-1285) $ (-592) (-592)) 73 (|has| $ (-6 -4626)))) (-4143 (($ $ (-592)) 107 (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-4391 (((-877) $) 37 (|has| |#1| (-1119)))) (-4372 (((-141)) 38 (|has| |#1| (-1119)))) (-3047 ((|#1| $ |#1|) NIL (|has| $ (-6 -4626)))) (-3153 (($ $ $) 95 (|has| $ (-6 -4626))) (($ $ (-592) $) 117)) (-4496 ((|#1| $ |#1|) 104 (|has| $ (-6 -4626)))) (-2101 ((|#1| $ |#1|) 99 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ "first" |#1|) 101 (|has| $ (-6 -4626))) (($ $ "rest" $) 103 (|has| $ (-6 -4626))) ((|#1| $ "last" |#1|) 106 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 86 (|has| $ (-6 -4626))) ((|#1| $ (-592) |#1|) 52 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) 55)) (-1765 ((|#1| $) NIL)) (-3001 (($) NIL T CONST)) (-4083 (($ $) 14)) (-1366 (($ $) 28) (($ $ (-790)) 85)) (-4009 (((-141) (-658 |#1|) $) 112 (|has| |#1| (-1119)))) (-3201 (($ (-658 |#1|)) 109)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) 54)) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-3868 (((-141) $) NIL)) (-4004 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3087 (((-1285) (-592) $) 116 (|has| |#1| (-1119)))) (-4219 (((-790) $) 114)) (-2774 (((-658 $) $) NIL)) (-3055 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3242 (($ (-790) |#1|) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 70 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 60) (($ (-1 |#1| |#1| |#1|) $ $) 64)) (-2554 (((-141) $ (-790)) NIL)) (-4063 (((-658 |#1|) $) NIL)) (-3683 (((-141) $) NIL)) (-1640 (($ $) 87)) (-1323 (((-141) $) 13)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-4255 ((|#1| $) NIL) (($ $ (-790)) NIL)) (-3666 (($ $ $ (-592)) NIL) (($ |#1| $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) 71)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3086 (($ (-1 |#1|)) 119) (($ (-1 |#1| |#1|) |#1|) 120)) (-4479 ((|#1| $) 10)) (-1918 ((|#1| $) 27) (($ $ (-790)) 46)) (-1726 (((-2 (|:| |cycle?| (-141)) (|:| -3989 (-790)) (|:| |period| (-790))) (-790) $) 24)) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-3103 (($ (-1 (-141) |#1|) $) 121)) (-3109 (($ (-1 (-141) |#1|) $) 122)) (-1892 (($ $ |#1|) 65 (|has| $ (-6 -4626)))) (-2807 (($ $ (-592)) 31)) (-2955 (((-141) $) 69)) (-2393 (((-141) $) 12)) (-3630 (((-141) $) 113)) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 20)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) 15)) (-2890 (($) 40)) (-3927 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1246 (-592))) NIL) ((|#1| $ (-592)) 51) ((|#1| $ (-592) |#1|) NIL)) (-2920 (((-592) $ $) 45)) (-3208 (($ $ (-1246 (-592))) NIL) (($ $ (-592)) NIL)) (-4048 (($ (-1 $)) 44)) (-3228 (((-141) $) 66)) (-2399 (($ $) 67)) (-1337 (($ $) 96 (|has| $ (-6 -4626)))) (-3318 (((-790) $) NIL)) (-3184 (($ $) NIL)) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) 41)) (-1778 (((-565) $) NIL (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 50)) (-4592 (($ |#1| $) 94)) (-3619 (($ $ $) 97 (|has| $ (-6 -4626))) (($ $ |#1|) 98 (|has| $ (-6 -4626)))) (-2266 (($ $ $) 75) (($ |#1| $) 42) (($ (-658 $)) 80) (($ $ |#1|) 74)) (-1700 (($ $) 47)) (-1683 (((-877) $) 39 (|has| |#1| (-1119))) (($ (-658 |#1|)) 108)) (-2493 (((-658 $) $) NIL)) (-2936 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 111 (|has| |#1| (-1119)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1171 |#1|) (-13 (-690 |#1|) (-10 -8 (-6 -4626) (-15 -1683 ($ (-658 |#1|))) (-15 -3201 ($ (-658 |#1|))) (IF (|has| |#1| (-1119)) (-15 -4009 ((-141) (-658 |#1|) $)) |noBranch|) (-15 -1726 ((-2 (|:| |cycle?| (-141)) (|:| -3989 (-790)) (|:| |period| (-790))) (-790) $)) (-15 -4048 ($ (-1 $))) (-15 -4592 ($ |#1| $)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3087 ((-1285) (-592) $)) (-15 -4391 ((-877) $)) (-15 -4372 ((-141)))) |noBranch|) (-15 -3153 ($ $ (-592) $)) (-15 -3086 ($ (-1 |#1|))) (-15 -3086 ($ (-1 |#1| |#1|) |#1|)) (-15 -3103 ($ (-1 (-141) |#1|) $)) (-15 -3109 ($ (-1 (-141) |#1|) $)))) (-1225)) (T -1171)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3)))) (-3201 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3)))) (-4009 (*1 *2 *3 *1) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1119)) (-4 *4 (-1225)) (-5 *2 (-141)) (-5 *1 (-1171 *4)))) (-1726 (*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |cycle?| (-141)) (|:| -3989 (-790)) (|:| |period| (-790)))) (-5 *1 (-1171 *4)) (-4 *4 (-1225)) (-5 *3 (-790)))) (-4048 (*1 *1 *2) (-12 (-5 *2 (-1 (-1171 *3))) (-5 *1 (-1171 *3)) (-4 *3 (-1225)))) (-4592 (*1 *1 *2 *1) (-12 (-5 *1 (-1171 *2)) (-4 *2 (-1225)))) (-3087 (*1 *2 *3 *1) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-1171 *4)) (-4 *4 (-1119)) (-4 *4 (-1225)))) (-4391 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1171 *3)) (-4 *3 (-1119)) (-4 *3 (-1225)))) (-4372 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1171 *3)) (-4 *3 (-1119)) (-4 *3 (-1225)))) (-3153 (*1 *1 *1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1171 *3)) (-4 *3 (-1225)))) (-3086 (*1 *1 *2) (-12 (-5 *2 (-1 *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3)))) (-3086 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3)))) (-3103 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3)))) (-3109 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3))))) 
+(-13 (-690 |#1|) (-10 -8 (-6 -4626) (-15 -1683 ($ (-658 |#1|))) (-15 -3201 ($ (-658 |#1|))) (IF (|has| |#1| (-1119)) (-15 -4009 ((-141) (-658 |#1|) $)) |noBranch|) (-15 -1726 ((-2 (|:| |cycle?| (-141)) (|:| -3989 (-790)) (|:| |period| (-790))) (-790) $)) (-15 -4048 ($ (-1 $))) (-15 -4592 ($ |#1| $)) (IF (|has| |#1| (-1119)) (PROGN (-15 -3087 ((-1285) (-592) $)) (-15 -4391 ((-877) $)) (-15 -4372 ((-141)))) |noBranch|) (-15 -3153 ($ $ (-592) $)) (-15 -3086 ($ (-1 |#1|))) (-15 -3086 ($ (-1 |#1| |#1|) |#1|)) (-15 -3103 ($ (-1 (-141) |#1|) $)) (-15 -3109 ($ (-1 (-141) |#1|) $)))) 
+((-1641 (((-141) $ $) 18)) (-3202 (($ $) 113)) (-3777 (($ $) 114)) (-2874 (($ $ (-168)) 101) (($ $ (-163)) 100)) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-3326 (((-141) $ $) 111)) (-3288 (((-141) $ $ (-592)) 110)) (-4574 (($ (-592)) 118)) (-1356 (((-658 $) $ (-168)) 103) (((-658 $) $ (-163)) 102)) (-4076 (((-141) (-1 (-141) (-168) (-168)) $) 91) (((-141) $) 85 (|has| (-168) (-869)))) (-2831 (($ (-1 (-141) (-168) (-168)) $) 82 (|has| $ (-6 -4626))) (($ $) 81 (-12 (|has| (-168) (-869)) (|has| $ (-6 -4626))))) (-3960 (($ (-1 (-141) (-168) (-168)) $) 92) (($ $) 86 (|has| (-168) (-869)))) (-2126 (((-141) $ (-790)) 8)) (-3932 (((-168) $ (-592) (-168)) 49 (|has| $ (-6 -4626))) (((-168) $ (-1246 (-592)) (-168)) 53 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-168)) $) 70 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-4447 (($ $ (-168)) 97) (($ $ (-163)) 96)) (-2512 (($ $) 83 (|has| $ (-6 -4626)))) (-1373 (($ $) 93)) (-2262 (($ $ (-1246 (-592)) $) 107)) (-1360 (($ $) 73 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ (-168) $) 72 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) (-168)) $) 69 (|has| $ (-6 -4625)))) (-3657 (((-168) (-1 (-168) (-168) (-168)) $ (-168) (-168)) 71 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625)))) (((-168) (-1 (-168) (-168) (-168)) $ (-168)) 68 (|has| $ (-6 -4625))) (((-168) (-1 (-168) (-168) (-168)) $) 67 (|has| $ (-6 -4625)))) (-1426 (((-168) $ (-592) (-168)) 50 (|has| $ (-6 -4626)))) (-3959 (((-168) $ (-592)) 48)) (-3379 (((-141) $ $) 112)) (-1721 (((-592) (-1 (-141) (-168)) $) 90) (((-592) (-168) $) 89 (|has| (-168) (-1119))) (((-592) (-168) $ (-592)) 88 (|has| (-168) (-1119))) (((-592) $ $ (-592)) 106) (((-592) (-163) $ (-592)) 105)) (-4004 (((-658 (-168)) $) 30 (|has| $ (-6 -4625)))) (-3242 (($ (-790) (-168)) 64)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-1837 (($ $ $) 80 (|has| (-168) (-869)))) (-4491 (($ (-1 (-141) (-168) (-168)) $ $) 94) (($ $ $) 87 (|has| (-168) (-869)))) (-4467 (((-658 (-168)) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) (-168) $) 27 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3319 (($ $ $) 79 (|has| (-168) (-869)))) (-3614 (((-141) $ $ (-168)) 108)) (-1600 (((-790) $ $ (-168)) 109)) (-3987 (($ (-1 (-168) (-168)) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-168) (-168)) $) 35) (($ (-1 (-168) (-168) (-168)) $ $) 59)) (-2200 (($ $) 115)) (-1633 (($ $) 116)) (-2554 (((-141) $ (-790)) 10)) (-2999 (($ $ (-168)) 99) (($ $ (-163)) 98)) (-2685 (((-1173) $) 22)) (-3666 (($ (-168) $ (-592)) 55) (($ $ $ (-592)) 54)) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-2951 (((-1137) $) 21)) (-1918 (((-168) $) 39 (|has| (-592) (-869)))) (-4050 (((-3 (-168) "failed") (-1 (-141) (-168)) $) 66)) (-1892 (($ $ (-168)) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-168)) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-168)))) 26 (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-310 (-168))) 25 (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-168) (-168)) 24 (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-658 (-168)) (-658 (-168))) 23 (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) (-168) $) 42 (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-4210 (((-658 (-168)) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 (((-168) $ (-592) (-168)) 47) (((-168) $ (-592)) 46) (($ $ (-1246 (-592))) 58) (($ $ $) 95)) (-3208 (($ $ (-592)) 57) (($ $ (-1246 (-592))) 56)) (-3452 (((-790) (-1 (-141) (-168)) $) 31 (|has| $ (-6 -4625))) (((-790) (-168) $) 28 (-12 (|has| (-168) (-1119)) (|has| $ (-6 -4625))))) (-2385 (($ $ $ (-592)) 84 (|has| $ (-6 -4626)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 74 (|has| (-168) (-633 (-565))))) (-4466 (($ (-658 (-168))) 65)) (-2266 (($ $ (-168)) 63) (($ (-168) $) 62) (($ $ $) 61) (($ (-658 $)) 60)) (-1683 (($ (-168)) 104) (((-877) $) 20)) (-3369 (((-141) (-1 (-141) (-168)) $) 33 (|has| $ (-6 -4625)))) (-1637 (((-1173) $) 122) (((-1173) $ (-141)) 121) (((-1285) (-844) $) 120) (((-1285) (-844) $ (-141)) 119)) (-3286 (((-141) $ $) 77 (|has| (-168) (-869)))) (-3273 (((-141) $ $) 76 (|has| (-168) (-869)))) (-3255 (((-141) $ $) 19)) (-3279 (((-141) $ $) 78 (|has| (-168) (-869)))) (-3266 (((-141) $ $) 75 (|has| (-168) (-869)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1172) (-1311)) (T -1172)) 
+((-4574 (*1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1172))))) 
+(-13 (-1158) (-1119) (-850) (-10 -8 (-15 -4574 ($ (-592))))) 
+(((-39) . T) ((-125) . T) ((-632 (-877)) . T) ((-175 (-168)) . T) ((-633 (-565)) |has| (-168) (-633 (-565))) ((-303 (-592) (-168)) . T) ((-305 (-592) (-168)) . T) ((-325 (-168)) -12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))) ((-399 (-168)) . T) ((-523 (-168)) . T) ((-625 (-592) (-168)) . T) ((-547 (-168) (-168)) -12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))) ((-664 (-168)) . T) ((-19 (-168)) . T) ((-850) . T) ((-869) |has| (-168) (-869)) ((-1119) . T) ((-1158) . T) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-3202 (($ $) NIL)) (-3777 (($ $) NIL)) (-2874 (($ $ (-168)) NIL) (($ $ (-163)) NIL)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-3326 (((-141) $ $) NIL)) (-3288 (((-141) $ $ (-592)) NIL)) (-4574 (($ (-592)) 7)) (-1356 (((-658 $) $ (-168)) NIL) (((-658 $) $ (-163)) NIL)) (-4076 (((-141) (-1 (-141) (-168) (-168)) $) NIL) (((-141) $) NIL (|has| (-168) (-869)))) (-2831 (($ (-1 (-141) (-168) (-168)) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-168) (-869))))) (-3960 (($ (-1 (-141) (-168) (-168)) $) NIL) (($ $) NIL (|has| (-168) (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-168) $ (-592) (-168)) NIL (|has| $ (-6 -4626))) (((-168) $ (-1246 (-592)) (-168)) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-4447 (($ $ (-168)) NIL) (($ $ (-163)) NIL)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-2262 (($ $ (-1246 (-592)) $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-4459 (($ (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119)))) (($ (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-168) (-1 (-168) (-168) (-168)) $ (-168) (-168)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119)))) (((-168) (-1 (-168) (-168) (-168)) $ (-168)) NIL (|has| $ (-6 -4625))) (((-168) (-1 (-168) (-168) (-168)) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-168) $ (-592) (-168)) NIL (|has| $ (-6 -4626)))) (-3959 (((-168) $ (-592)) NIL)) (-3379 (((-141) $ $) NIL)) (-1721 (((-592) (-1 (-141) (-168)) $) NIL) (((-592) (-168) $) NIL (|has| (-168) (-1119))) (((-592) (-168) $ (-592)) NIL (|has| (-168) (-1119))) (((-592) $ $ (-592)) NIL) (((-592) (-163) $ (-592)) NIL)) (-4004 (((-658 (-168)) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) (-168)) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| (-168) (-869)))) (-4491 (($ (-1 (-141) (-168) (-168)) $ $) NIL) (($ $ $) NIL (|has| (-168) (-869)))) (-4467 (((-658 (-168)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-168) (-869)))) (-3614 (((-141) $ $ (-168)) NIL)) (-1600 (((-790) $ $ (-168)) NIL)) (-3987 (($ (-1 (-168) (-168)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-168) (-168)) $) NIL) (($ (-1 (-168) (-168) (-168)) $ $) NIL)) (-2200 (($ $) NIL)) (-1633 (($ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2999 (($ $ (-168)) NIL) (($ $ (-163)) NIL)) (-2685 (((-1173) $) NIL)) (-3666 (($ (-168) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-168) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-168) "failed") (-1 (-141) (-168)) $) NIL)) (-1892 (($ $ (-168)) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-168)))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-310 (-168))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-168) (-168)) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119)))) (($ $ (-658 (-168)) (-658 (-168))) NIL (-12 (|has| (-168) (-325 (-168))) (|has| (-168) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-4210 (((-658 (-168)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 (((-168) $ (-592) (-168)) NIL) (((-168) $ (-592)) NIL) (($ $ (-1246 (-592))) NIL) (($ $ $) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625))) (((-790) (-168) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-168) (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-168) (-633 (-565))))) (-4466 (($ (-658 (-168))) NIL)) (-2266 (($ $ (-168)) NIL) (($ (-168) $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (($ (-168)) NIL) (((-877) $) NIL)) (-3369 (((-141) (-1 (-141) (-168)) $) NIL (|has| $ (-6 -4625)))) (-1637 (((-1173) $) 18) (((-1173) $ (-141)) 20) (((-1285) (-844) $) 21) (((-1285) (-844) $ (-141)) 22)) (-3286 (((-141) $ $) NIL (|has| (-168) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-168) (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| (-168) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-168) (-869)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1173) (-1172)) (T -1173)) 
+NIL 
+(-1172) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)) (|has| |#1| (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL)) (-3898 (((-1285) $ (-1173) (-1173)) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-1173) |#1|) NIL)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 |#1| "failed") (-1173) $) NIL)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119))))) (-4065 (($ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (((-3 |#1| "failed") (-1173) $) NIL)) (-4459 (($ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-1173) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-1173)) NIL)) (-4004 (((-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-1173) $) NIL (|has| (-1173) (-869)))) (-4467 (((-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-1173) $) NIL (|has| (-1173) (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4626))) (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL) (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)) (|has| |#1| (-1119))))) (-2840 (((-658 (-1173)) $) NIL)) (-2396 (((-141) (-1173) $) NIL)) (-4137 (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL)) (-3708 (((-658 (-1173)) $) NIL)) (-3780 (((-141) (-1173) $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)) (|has| |#1| (-1119))))) (-1918 ((|#1| $) NIL (|has| (-1173) (-869)))) (-4050 (((-3 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) "failed") (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (($ $ (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL (-12 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-325 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-1173)) NIL) ((|#1| $ (-1173) |#1|) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)) (|has| |#1| (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 (-1173)) (|:| -3552 |#1|)) (-1119)) (|has| |#1| (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1174 |#1|) (-13 (-1202 (-1173) |#1|) (-10 -7 (-6 -4625))) (-1119)) (T -1174)) 
+NIL 
+(-13 (-1202 (-1173) |#1|) (-10 -7 (-6 -4625))) 
+((-3621 (((-1171 |#1|) (-1171 |#1|)) 77)) (-3371 (((-3 (-1171 |#1|) "failed") (-1171 |#1|)) 37)) (-4441 (((-1171 |#1|) (-433 (-592)) (-1171 |#1|)) 117 (|has| |#1| (-43 (-433 (-592)))))) (-3116 (((-1171 |#1|) |#1| (-1171 |#1|)) 121 (|has| |#1| (-388)))) (-2669 (((-1171 |#1|) (-1171 |#1|)) 90)) (-2620 (((-1171 (-592)) (-592)) 57)) (-3019 (((-1171 |#1|) (-1171 (-1171 |#1|))) 108 (|has| |#1| (-43 (-433 (-592)))))) (-3368 (((-1171 |#1|) (-592) (-592) (-1171 |#1|)) 95)) (-1493 (((-1171 |#1|) |#1| (-592)) 45)) (-2213 (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 60)) (-2164 (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 119 (|has| |#1| (-388)))) (-4286 (((-1171 |#1|) |#1| (-1 (-1171 |#1|))) 107 (|has| |#1| (-43 (-433 (-592)))))) (-2109 (((-1171 |#1|) (-1 |#1| (-592)) |#1| (-1 (-1171 |#1|))) 120 (|has| |#1| (-388)))) (-4006 (((-1171 |#1|) (-1171 |#1|)) 89)) (-3121 (((-1171 |#1|) (-1171 |#1|)) 76)) (-3884 (((-1171 |#1|) (-592) (-592) (-1171 |#1|)) 96)) (-3162 (((-1171 |#1|) |#1| (-1171 |#1|)) 105 (|has| |#1| (-43 (-433 (-592)))))) (-3402 (((-1171 (-592)) (-592)) 56)) (-1749 (((-1171 |#1|) |#1|) 59)) (-2860 (((-1171 |#1|) (-1171 |#1|) (-592) (-592)) 92)) (-4026 (((-1171 |#1|) (-1 |#1| (-592)) (-1171 |#1|)) 66)) (-3616 (((-3 (-1171 |#1|) "failed") (-1171 |#1|) (-1171 |#1|)) 35)) (-3325 (((-1171 |#1|) (-1171 |#1|)) 91)) (-2806 (((-1171 |#1|) (-1171 |#1|) |#1|) 71)) (-2513 (((-1171 |#1|) (-1171 |#1|)) 62)) (-4060 (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 72)) (-1683 (((-1171 |#1|) |#1|) 67)) (-2037 (((-1171 |#1|) (-1171 (-1171 |#1|))) 82)) (-3313 (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 36)) (-3306 (((-1171 |#1|) (-1171 |#1|)) 21) (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 23)) (-3300 (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 17)) (* (((-1171 |#1|) (-1171 |#1|) |#1|) 29) (((-1171 |#1|) |#1| (-1171 |#1|)) 26) (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 27))) 
+(((-1175 |#1|) (-10 -7 (-15 -3300 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -3306 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -3306 ((-1171 |#1|) (-1171 |#1|))) (-15 * ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 * ((-1171 |#1|) |#1| (-1171 |#1|))) (-15 * ((-1171 |#1|) (-1171 |#1|) |#1|)) (-15 -3616 ((-3 (-1171 |#1|) "failed") (-1171 |#1|) (-1171 |#1|))) (-15 -3313 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -3371 ((-3 (-1171 |#1|) "failed") (-1171 |#1|))) (-15 -1493 ((-1171 |#1|) |#1| (-592))) (-15 -3402 ((-1171 (-592)) (-592))) (-15 -2620 ((-1171 (-592)) (-592))) (-15 -1749 ((-1171 |#1|) |#1|)) (-15 -2213 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -2513 ((-1171 |#1|) (-1171 |#1|))) (-15 -4026 ((-1171 |#1|) (-1 |#1| (-592)) (-1171 |#1|))) (-15 -1683 ((-1171 |#1|) |#1|)) (-15 -2806 ((-1171 |#1|) (-1171 |#1|) |#1|)) (-15 -4060 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -3121 ((-1171 |#1|) (-1171 |#1|))) (-15 -3621 ((-1171 |#1|) (-1171 |#1|))) (-15 -2037 ((-1171 |#1|) (-1171 (-1171 |#1|)))) (-15 -4006 ((-1171 |#1|) (-1171 |#1|))) (-15 -2669 ((-1171 |#1|) (-1171 |#1|))) (-15 -3325 ((-1171 |#1|) (-1171 |#1|))) (-15 -2860 ((-1171 |#1|) (-1171 |#1|) (-592) (-592))) (-15 -3368 ((-1171 |#1|) (-592) (-592) (-1171 |#1|))) (-15 -3884 ((-1171 |#1|) (-592) (-592) (-1171 |#1|))) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ((-1171 |#1|) |#1| (-1171 |#1|))) (-15 -4286 ((-1171 |#1|) |#1| (-1 (-1171 |#1|)))) (-15 -3019 ((-1171 |#1|) (-1171 (-1171 |#1|)))) (-15 -4441 ((-1171 |#1|) (-433 (-592)) (-1171 |#1|)))) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-15 -2164 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -2109 ((-1171 |#1|) (-1 |#1| (-592)) |#1| (-1 (-1171 |#1|)))) (-15 -3116 ((-1171 |#1|) |#1| (-1171 |#1|)))) |noBranch|)) (-1075)) (T -1175)) 
+((-3116 (*1 *2 *3 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-2109 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *4 (-592))) (-5 *5 (-1 (-1171 *4))) (-4 *4 (-388)) (-4 *4 (-1075)) (-5 *2 (-1171 *4)) (-5 *1 (-1175 *4)))) (-2164 (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-4441 (*1 *2 *3 *2) (-12 (-5 *2 (-1171 *4)) (-4 *4 (-43 *3)) (-4 *4 (-1075)) (-5 *3 (-433 (-592))) (-5 *1 (-1175 *4)))) (-3019 (*1 *2 *3) (-12 (-5 *3 (-1171 (-1171 *4))) (-5 *2 (-1171 *4)) (-5 *1 (-1175 *4)) (-4 *4 (-43 (-433 (-592)))) (-4 *4 (-1075)))) (-4286 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-1171 *3))) (-5 *2 (-1171 *3)) (-5 *1 (-1175 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)))) (-3162 (*1 *2 *3 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-3884 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-592)) (-4 *4 (-1075)) (-5 *1 (-1175 *4)))) (-3368 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-592)) (-4 *4 (-1075)) (-5 *1 (-1175 *4)))) (-2860 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-592)) (-4 *4 (-1075)) (-5 *1 (-1175 *4)))) (-3325 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-2669 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-4006 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-2037 (*1 *2 *3) (-12 (-5 *3 (-1171 (-1171 *4))) (-5 *2 (-1171 *4)) (-5 *1 (-1175 *4)) (-4 *4 (-1075)))) (-3621 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-3121 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-4060 (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-2806 (*1 *2 *2 *3) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-1683 (*1 *2 *3) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-1175 *3)) (-4 *3 (-1075)))) (-4026 (*1 *2 *3 *2) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-1 *4 (-592))) (-4 *4 (-1075)) (-5 *1 (-1175 *4)))) (-2513 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-2213 (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-1749 (*1 *2 *3) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-1175 *3)) (-4 *3 (-1075)))) (-2620 (*1 *2 *3) (-12 (-5 *2 (-1171 (-592))) (-5 *1 (-1175 *4)) (-4 *4 (-1075)) (-5 *3 (-592)))) (-3402 (*1 *2 *3) (-12 (-5 *2 (-1171 (-592))) (-5 *1 (-1175 *4)) (-4 *4 (-1075)) (-5 *3 (-592)))) (-1493 (*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-5 *2 (-1171 *3)) (-5 *1 (-1175 *3)) (-4 *3 (-1075)))) (-3371 (*1 *2 *2) (|partial| -12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-3313 (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-3616 (*1 *2 *2 *2) (|partial| -12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (* (*1 *2 *2 *3) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-3306 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-3306 (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) (-3300 (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3))))) 
+(-10 -7 (-15 -3300 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -3306 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -3306 ((-1171 |#1|) (-1171 |#1|))) (-15 * ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 * ((-1171 |#1|) |#1| (-1171 |#1|))) (-15 * ((-1171 |#1|) (-1171 |#1|) |#1|)) (-15 -3616 ((-3 (-1171 |#1|) "failed") (-1171 |#1|) (-1171 |#1|))) (-15 -3313 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -3371 ((-3 (-1171 |#1|) "failed") (-1171 |#1|))) (-15 -1493 ((-1171 |#1|) |#1| (-592))) (-15 -3402 ((-1171 (-592)) (-592))) (-15 -2620 ((-1171 (-592)) (-592))) (-15 -1749 ((-1171 |#1|) |#1|)) (-15 -2213 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -2513 ((-1171 |#1|) (-1171 |#1|))) (-15 -4026 ((-1171 |#1|) (-1 |#1| (-592)) (-1171 |#1|))) (-15 -1683 ((-1171 |#1|) |#1|)) (-15 -2806 ((-1171 |#1|) (-1171 |#1|) |#1|)) (-15 -4060 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -3121 ((-1171 |#1|) (-1171 |#1|))) (-15 -3621 ((-1171 |#1|) (-1171 |#1|))) (-15 -2037 ((-1171 |#1|) (-1171 (-1171 |#1|)))) (-15 -4006 ((-1171 |#1|) (-1171 |#1|))) (-15 -2669 ((-1171 |#1|) (-1171 |#1|))) (-15 -3325 ((-1171 |#1|) (-1171 |#1|))) (-15 -2860 ((-1171 |#1|) (-1171 |#1|) (-592) (-592))) (-15 -3368 ((-1171 |#1|) (-592) (-592) (-1171 |#1|))) (-15 -3884 ((-1171 |#1|) (-592) (-592) (-1171 |#1|))) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ((-1171 |#1|) |#1| (-1171 |#1|))) (-15 -4286 ((-1171 |#1|) |#1| (-1 (-1171 |#1|)))) (-15 -3019 ((-1171 |#1|) (-1171 (-1171 |#1|)))) (-15 -4441 ((-1171 |#1|) (-433 (-592)) (-1171 |#1|)))) |noBranch|) (IF (|has| |#1| (-388)) (PROGN (-15 -2164 ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -2109 ((-1171 |#1|) (-1 |#1| (-592)) |#1| (-1 (-1171 |#1|)))) (-15 -3116 ((-1171 |#1|) |#1| (-1171 |#1|)))) |noBranch|)) 
+((-1588 (((-1171 |#1|) (-1171 |#1|)) 57)) (-1507 (((-1171 |#1|) (-1171 |#1|)) 39)) (-1575 (((-1171 |#1|) (-1171 |#1|)) 53)) (-1495 (((-1171 |#1|) (-1171 |#1|)) 35)) (-1601 (((-1171 |#1|) (-1171 |#1|)) 60)) (-1521 (((-1171 |#1|) (-1171 |#1|)) 42)) (-4546 (((-1171 |#1|) (-1171 |#1|)) 31)) (-1430 (((-1171 |#1|) (-1171 |#1|)) 27)) (-1609 (((-1171 |#1|) (-1171 |#1|)) 61)) (-1527 (((-1171 |#1|) (-1171 |#1|)) 43)) (-1594 (((-1171 |#1|) (-1171 |#1|)) 58)) (-1515 (((-1171 |#1|) (-1171 |#1|)) 40)) (-1581 (((-1171 |#1|) (-1171 |#1|)) 55)) (-1501 (((-1171 |#1|) (-1171 |#1|)) 37)) (-1630 (((-1171 |#1|) (-1171 |#1|)) 65)) (-1546 (((-1171 |#1|) (-1171 |#1|)) 47)) (-1617 (((-1171 |#1|) (-1171 |#1|)) 63)) (-1533 (((-1171 |#1|) (-1171 |#1|)) 45)) (-1642 (((-1171 |#1|) (-1171 |#1|)) 68)) (-1559 (((-1171 |#1|) (-1171 |#1|)) 50)) (-2892 (((-1171 |#1|) (-1171 |#1|)) 69)) (-1567 (((-1171 |#1|) (-1171 |#1|)) 51)) (-1636 (((-1171 |#1|) (-1171 |#1|)) 67)) (-1552 (((-1171 |#1|) (-1171 |#1|)) 49)) (-1624 (((-1171 |#1|) (-1171 |#1|)) 66)) (-1540 (((-1171 |#1|) (-1171 |#1|)) 48)) (** (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 33))) 
+(((-1176 |#1|) (-10 -7 (-15 -1430 ((-1171 |#1|) (-1171 |#1|))) (-15 -4546 ((-1171 |#1|) (-1171 |#1|))) (-15 ** ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -1495 ((-1171 |#1|) (-1171 |#1|))) (-15 -1501 ((-1171 |#1|) (-1171 |#1|))) (-15 -1507 ((-1171 |#1|) (-1171 |#1|))) (-15 -1515 ((-1171 |#1|) (-1171 |#1|))) (-15 -1521 ((-1171 |#1|) (-1171 |#1|))) (-15 -1527 ((-1171 |#1|) (-1171 |#1|))) (-15 -1533 ((-1171 |#1|) (-1171 |#1|))) (-15 -1540 ((-1171 |#1|) (-1171 |#1|))) (-15 -1546 ((-1171 |#1|) (-1171 |#1|))) (-15 -1552 ((-1171 |#1|) (-1171 |#1|))) (-15 -1559 ((-1171 |#1|) (-1171 |#1|))) (-15 -1567 ((-1171 |#1|) (-1171 |#1|))) (-15 -1575 ((-1171 |#1|) (-1171 |#1|))) (-15 -1581 ((-1171 |#1|) (-1171 |#1|))) (-15 -1588 ((-1171 |#1|) (-1171 |#1|))) (-15 -1594 ((-1171 |#1|) (-1171 |#1|))) (-15 -1601 ((-1171 |#1|) (-1171 |#1|))) (-15 -1609 ((-1171 |#1|) (-1171 |#1|))) (-15 -1617 ((-1171 |#1|) (-1171 |#1|))) (-15 -1624 ((-1171 |#1|) (-1171 |#1|))) (-15 -1630 ((-1171 |#1|) (-1171 |#1|))) (-15 -1636 ((-1171 |#1|) (-1171 |#1|))) (-15 -1642 ((-1171 |#1|) (-1171 |#1|))) (-15 -2892 ((-1171 |#1|) (-1171 |#1|)))) (-43 (-433 (-592)))) (T -1176)) 
+((-2892 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1642 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1636 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1630 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1624 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1617 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1609 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1601 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1594 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1588 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1581 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1575 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1567 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1559 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1552 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1546 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1540 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1533 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1527 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1521 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1515 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1507 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1501 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1495 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (** (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-4546 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) (-1430 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3))))) 
+(-10 -7 (-15 -1430 ((-1171 |#1|) (-1171 |#1|))) (-15 -4546 ((-1171 |#1|) (-1171 |#1|))) (-15 ** ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -1495 ((-1171 |#1|) (-1171 |#1|))) (-15 -1501 ((-1171 |#1|) (-1171 |#1|))) (-15 -1507 ((-1171 |#1|) (-1171 |#1|))) (-15 -1515 ((-1171 |#1|) (-1171 |#1|))) (-15 -1521 ((-1171 |#1|) (-1171 |#1|))) (-15 -1527 ((-1171 |#1|) (-1171 |#1|))) (-15 -1533 ((-1171 |#1|) (-1171 |#1|))) (-15 -1540 ((-1171 |#1|) (-1171 |#1|))) (-15 -1546 ((-1171 |#1|) (-1171 |#1|))) (-15 -1552 ((-1171 |#1|) (-1171 |#1|))) (-15 -1559 ((-1171 |#1|) (-1171 |#1|))) (-15 -1567 ((-1171 |#1|) (-1171 |#1|))) (-15 -1575 ((-1171 |#1|) (-1171 |#1|))) (-15 -1581 ((-1171 |#1|) (-1171 |#1|))) (-15 -1588 ((-1171 |#1|) (-1171 |#1|))) (-15 -1594 ((-1171 |#1|) (-1171 |#1|))) (-15 -1601 ((-1171 |#1|) (-1171 |#1|))) (-15 -1609 ((-1171 |#1|) (-1171 |#1|))) (-15 -1617 ((-1171 |#1|) (-1171 |#1|))) (-15 -1624 ((-1171 |#1|) (-1171 |#1|))) (-15 -1630 ((-1171 |#1|) (-1171 |#1|))) (-15 -1636 ((-1171 |#1|) (-1171 |#1|))) (-15 -1642 ((-1171 |#1|) (-1171 |#1|))) (-15 -2892 ((-1171 |#1|) (-1171 |#1|)))) 
+((-1588 (((-1171 |#1|) (-1171 |#1|)) 100)) (-1507 (((-1171 |#1|) (-1171 |#1|)) 64)) (-3739 (((-2 (|:| -1575 (-1171 |#1|)) (|:| -1581 (-1171 |#1|))) (-1171 |#1|)) 96)) (-1575 (((-1171 |#1|) (-1171 |#1|)) 97)) (-4024 (((-2 (|:| -1495 (-1171 |#1|)) (|:| -1501 (-1171 |#1|))) (-1171 |#1|)) 53)) (-1495 (((-1171 |#1|) (-1171 |#1|)) 54)) (-1601 (((-1171 |#1|) (-1171 |#1|)) 102)) (-1521 (((-1171 |#1|) (-1171 |#1|)) 71)) (-4546 (((-1171 |#1|) (-1171 |#1|)) 39)) (-1430 (((-1171 |#1|) (-1171 |#1|)) 36)) (-1609 (((-1171 |#1|) (-1171 |#1|)) 103)) (-1527 (((-1171 |#1|) (-1171 |#1|)) 72)) (-1594 (((-1171 |#1|) (-1171 |#1|)) 101)) (-1515 (((-1171 |#1|) (-1171 |#1|)) 67)) (-1581 (((-1171 |#1|) (-1171 |#1|)) 98)) (-1501 (((-1171 |#1|) (-1171 |#1|)) 55)) (-1630 (((-1171 |#1|) (-1171 |#1|)) 111)) (-1546 (((-1171 |#1|) (-1171 |#1|)) 86)) (-1617 (((-1171 |#1|) (-1171 |#1|)) 105)) (-1533 (((-1171 |#1|) (-1171 |#1|)) 82)) (-1642 (((-1171 |#1|) (-1171 |#1|)) 115)) (-1559 (((-1171 |#1|) (-1171 |#1|)) 90)) (-2892 (((-1171 |#1|) (-1171 |#1|)) 117)) (-1567 (((-1171 |#1|) (-1171 |#1|)) 92)) (-1636 (((-1171 |#1|) (-1171 |#1|)) 113)) (-1552 (((-1171 |#1|) (-1171 |#1|)) 88)) (-1624 (((-1171 |#1|) (-1171 |#1|)) 107)) (-1540 (((-1171 |#1|) (-1171 |#1|)) 84)) (** (((-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) 40))) 
+(((-1177 |#1|) (-10 -7 (-15 -1430 ((-1171 |#1|) (-1171 |#1|))) (-15 -4546 ((-1171 |#1|) (-1171 |#1|))) (-15 ** ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -4024 ((-2 (|:| -1495 (-1171 |#1|)) (|:| -1501 (-1171 |#1|))) (-1171 |#1|))) (-15 -1495 ((-1171 |#1|) (-1171 |#1|))) (-15 -1501 ((-1171 |#1|) (-1171 |#1|))) (-15 -1507 ((-1171 |#1|) (-1171 |#1|))) (-15 -1515 ((-1171 |#1|) (-1171 |#1|))) (-15 -1521 ((-1171 |#1|) (-1171 |#1|))) (-15 -1527 ((-1171 |#1|) (-1171 |#1|))) (-15 -1533 ((-1171 |#1|) (-1171 |#1|))) (-15 -1540 ((-1171 |#1|) (-1171 |#1|))) (-15 -1546 ((-1171 |#1|) (-1171 |#1|))) (-15 -1552 ((-1171 |#1|) (-1171 |#1|))) (-15 -1559 ((-1171 |#1|) (-1171 |#1|))) (-15 -1567 ((-1171 |#1|) (-1171 |#1|))) (-15 -3739 ((-2 (|:| -1575 (-1171 |#1|)) (|:| -1581 (-1171 |#1|))) (-1171 |#1|))) (-15 -1575 ((-1171 |#1|) (-1171 |#1|))) (-15 -1581 ((-1171 |#1|) (-1171 |#1|))) (-15 -1588 ((-1171 |#1|) (-1171 |#1|))) (-15 -1594 ((-1171 |#1|) (-1171 |#1|))) (-15 -1601 ((-1171 |#1|) (-1171 |#1|))) (-15 -1609 ((-1171 |#1|) (-1171 |#1|))) (-15 -1617 ((-1171 |#1|) (-1171 |#1|))) (-15 -1624 ((-1171 |#1|) (-1171 |#1|))) (-15 -1630 ((-1171 |#1|) (-1171 |#1|))) (-15 -1636 ((-1171 |#1|) (-1171 |#1|))) (-15 -1642 ((-1171 |#1|) (-1171 |#1|))) (-15 -2892 ((-1171 |#1|) (-1171 |#1|)))) (-43 (-433 (-592)))) (T -1177)) 
+((-2892 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1642 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1636 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1630 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1624 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1617 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1609 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1601 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1594 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1588 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1581 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1575 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-3739 (*1 *2 *3) (-12 (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-2 (|:| -1575 (-1171 *4)) (|:| -1581 (-1171 *4)))) (-5 *1 (-1177 *4)) (-5 *3 (-1171 *4)))) (-1567 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1559 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1552 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1546 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1540 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1533 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1527 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1521 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1515 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1507 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1501 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1495 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-4024 (*1 *2 *3) (-12 (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-2 (|:| -1495 (-1171 *4)) (|:| -1501 (-1171 *4)))) (-5 *1 (-1177 *4)) (-5 *3 (-1171 *4)))) (** (*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-4546 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) (-1430 (*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(-10 -7 (-15 -1430 ((-1171 |#1|) (-1171 |#1|))) (-15 -4546 ((-1171 |#1|) (-1171 |#1|))) (-15 ** ((-1171 |#1|) (-1171 |#1|) (-1171 |#1|))) (-15 -4024 ((-2 (|:| -1495 (-1171 |#1|)) (|:| -1501 (-1171 |#1|))) (-1171 |#1|))) (-15 -1495 ((-1171 |#1|) (-1171 |#1|))) (-15 -1501 ((-1171 |#1|) (-1171 |#1|))) (-15 -1507 ((-1171 |#1|) (-1171 |#1|))) (-15 -1515 ((-1171 |#1|) (-1171 |#1|))) (-15 -1521 ((-1171 |#1|) (-1171 |#1|))) (-15 -1527 ((-1171 |#1|) (-1171 |#1|))) (-15 -1533 ((-1171 |#1|) (-1171 |#1|))) (-15 -1540 ((-1171 |#1|) (-1171 |#1|))) (-15 -1546 ((-1171 |#1|) (-1171 |#1|))) (-15 -1552 ((-1171 |#1|) (-1171 |#1|))) (-15 -1559 ((-1171 |#1|) (-1171 |#1|))) (-15 -1567 ((-1171 |#1|) (-1171 |#1|))) (-15 -3739 ((-2 (|:| -1575 (-1171 |#1|)) (|:| -1581 (-1171 |#1|))) (-1171 |#1|))) (-15 -1575 ((-1171 |#1|) (-1171 |#1|))) (-15 -1581 ((-1171 |#1|) (-1171 |#1|))) (-15 -1588 ((-1171 |#1|) (-1171 |#1|))) (-15 -1594 ((-1171 |#1|) (-1171 |#1|))) (-15 -1601 ((-1171 |#1|) (-1171 |#1|))) (-15 -1609 ((-1171 |#1|) (-1171 |#1|))) (-15 -1617 ((-1171 |#1|) (-1171 |#1|))) (-15 -1624 ((-1171 |#1|) (-1171 |#1|))) (-15 -1630 ((-1171 |#1|) (-1171 |#1|))) (-15 -1636 ((-1171 |#1|) (-1171 |#1|))) (-15 -1642 ((-1171 |#1|) (-1171 |#1|))) (-15 -2892 ((-1171 |#1|) (-1171 |#1|)))) 
+((-1928 (((-986 |#2|) |#2| |#2|) 35)) (-3262 ((|#2| |#2| |#1|) 19 (|has| |#1| (-323))))) 
+(((-1178 |#1| |#2|) (-10 -7 (-15 -1928 ((-986 |#2|) |#2| |#2|)) (IF (|has| |#1| (-323)) (-15 -3262 (|#2| |#2| |#1|)) |noBranch|)) (-582) (-1255 |#1|)) (T -1178)) 
+((-3262 (*1 *2 *2 *3) (-12 (-4 *3 (-323)) (-4 *3 (-582)) (-5 *1 (-1178 *3 *2)) (-4 *2 (-1255 *3)))) (-1928 (*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-986 *3)) (-5 *1 (-1178 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -1928 ((-986 |#2|) |#2| |#2|)) (IF (|has| |#1| (-323)) (-15 -3262 (|#2| |#2| |#1|)) |noBranch|)) 
+((-1641 (((-141) $ $) NIL)) (-4000 (($ $ (-658 (-790))) 66)) (-3540 (($) 25)) (-1978 (($ $) 41)) (-1504 (((-658 $) $) 50)) (-3272 (((-141) $) 16)) (-1708 (((-658 (-971 |#2|)) $) 73)) (-2107 (($ $) 67)) (-1911 (((-790) $) 36)) (-3242 (($) 24)) (-3647 (($ $ (-658 (-790)) (-971 |#2|)) 59) (($ $ (-658 (-790)) (-790)) 60) (($ $ (-790) (-971 |#2|)) 62)) (-4491 (($ $ $) 47) (($ (-658 $)) 49)) (-3238 (((-790) $) 74)) (-3683 (((-141) $) 15)) (-2685 (((-1173) $) NIL)) (-2911 (((-141) $) 17)) (-2951 (((-1137) $) NIL)) (-2895 (((-193) $) 72)) (-1772 (((-971 |#2|) $) 68)) (-2902 (((-790) $) 69)) (-2006 (((-141) $) 71)) (-4554 (($ $ (-658 (-790)) (-193)) 65)) (-3446 (($ $) 42)) (-1683 (((-877) $) 84)) (-1579 (($ $ (-658 (-790)) (-141)) 64)) (-2493 (((-658 $) $) 11)) (-3992 (($ $ (-790)) 35)) (-3308 (($ $) 31)) (-2116 (($ $ $ (-971 |#2|) (-790)) 55)) (-3855 (($ $ (-971 |#2|)) 54)) (-4263 (($ $ (-658 (-790)) (-971 |#2|)) 53) (($ $ (-658 (-790)) (-790)) 57) (((-790) $ (-971 |#2|)) 58)) (-3255 (((-141) $ $) 78))) 
+(((-1179 |#1| |#2|) (-13 (-1119) (-10 -8 (-15 -3683 ((-141) $)) (-15 -3272 ((-141) $)) (-15 -2911 ((-141) $)) (-15 -3242 ($)) (-15 -3540 ($)) (-15 -3308 ($ $)) (-15 -3992 ($ $ (-790))) (-15 -2493 ((-658 $) $)) (-15 -1911 ((-790) $)) (-15 -1978 ($ $)) (-15 -3446 ($ $)) (-15 -4491 ($ $ $)) (-15 -4491 ($ (-658 $))) (-15 -1504 ((-658 $) $)) (-15 -4263 ($ $ (-658 (-790)) (-971 |#2|))) (-15 -3855 ($ $ (-971 |#2|))) (-15 -2116 ($ $ $ (-971 |#2|) (-790))) (-15 -3647 ($ $ (-658 (-790)) (-971 |#2|))) (-15 -4263 ($ $ (-658 (-790)) (-790))) (-15 -3647 ($ $ (-658 (-790)) (-790))) (-15 -4263 ((-790) $ (-971 |#2|))) (-15 -3647 ($ $ (-790) (-971 |#2|))) (-15 -1579 ($ $ (-658 (-790)) (-141))) (-15 -4554 ($ $ (-658 (-790)) (-193))) (-15 -4000 ($ $ (-658 (-790)))) (-15 -1772 ((-971 |#2|) $)) (-15 -2902 ((-790) $)) (-15 -2006 ((-141) $)) (-15 -2895 ((-193) $)) (-15 -3238 ((-790) $)) (-15 -2107 ($ $)) (-15 -1708 ((-658 (-971 |#2|)) $)))) (-944) (-1075)) (T -1179)) 
+((-3683 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-3272 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-2911 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-3242 (*1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) (-3540 (*1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) (-3308 (*1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) (-3992 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-2493 (*1 *2 *1) (-12 (-5 *2 (-658 (-1179 *3 *4))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-1911 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-1978 (*1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) (-3446 (*1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) (-4491 (*1 *1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) (-4491 (*1 *1 *2) (-12 (-5 *2 (-658 (-1179 *3 *4))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-1504 (*1 *2 *1) (-12 (-5 *2 (-658 (-1179 *3 *4))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-4263 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-971 *5)) (-4 *5 (-1075)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)))) (-3855 (*1 *1 *1 *2) (-12 (-5 *2 (-971 *4)) (-4 *4 (-1075)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)))) (-2116 (*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-971 *5)) (-5 *3 (-790)) (-4 *5 (-1075)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)))) (-3647 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-971 *5)) (-4 *5 (-1075)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)))) (-4263 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-790)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)) (-4 *5 (-1075)))) (-3647 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-790)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)) (-4 *5 (-1075)))) (-4263 (*1 *2 *1 *3) (-12 (-5 *3 (-971 *5)) (-4 *5 (-1075)) (-5 *2 (-790)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)))) (-3647 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-971 *5)) (-4 *5 (-1075)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)))) (-1579 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-141)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)) (-4 *5 (-1075)))) (-4554 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-193)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)) (-4 *5 (-1075)))) (-4000 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-790))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-1772 (*1 *2 *1) (-12 (-5 *2 (-971 *4)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-2902 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-2006 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-2895 (*1 *2 *1) (-12 (-5 *2 (-193)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-3238 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) (-2107 (*1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) (-1708 (*1 *2 *1) (-12 (-5 *2 (-658 (-971 *4))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(-13 (-1119) (-10 -8 (-15 -3683 ((-141) $)) (-15 -3272 ((-141) $)) (-15 -2911 ((-141) $)) (-15 -3242 ($)) (-15 -3540 ($)) (-15 -3308 ($ $)) (-15 -3992 ($ $ (-790))) (-15 -2493 ((-658 $) $)) (-15 -1911 ((-790) $)) (-15 -1978 ($ $)) (-15 -3446 ($ $)) (-15 -4491 ($ $ $)) (-15 -4491 ($ (-658 $))) (-15 -1504 ((-658 $) $)) (-15 -4263 ($ $ (-658 (-790)) (-971 |#2|))) (-15 -3855 ($ $ (-971 |#2|))) (-15 -2116 ($ $ $ (-971 |#2|) (-790))) (-15 -3647 ($ $ (-658 (-790)) (-971 |#2|))) (-15 -4263 ($ $ (-658 (-790)) (-790))) (-15 -3647 ($ $ (-658 (-790)) (-790))) (-15 -4263 ((-790) $ (-971 |#2|))) (-15 -3647 ($ $ (-790) (-971 |#2|))) (-15 -1579 ($ $ (-658 (-790)) (-141))) (-15 -4554 ($ $ (-658 (-790)) (-193))) (-15 -4000 ($ $ (-658 (-790)))) (-15 -1772 ((-971 |#2|) $)) (-15 -2902 ((-790) $)) (-15 -2006 ((-141) $)) (-15 -2895 ((-193) $)) (-15 -3238 ((-790) $)) (-15 -2107 ($ $)) (-15 -1708 ((-658 (-971 |#2|)) $)))) 
+((-1641 (((-141) $ $) NIL)) (-1673 ((|#2| $) 11)) (-3634 ((|#1| $) 10)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4466 (($ |#1| |#2|) 9)) (-1683 (((-877) $) 16)) (-3255 (((-141) $ $) NIL))) 
+(((-1180 |#1| |#2|) (-13 (-1119) (-10 -8 (-15 -4466 ($ |#1| |#2|)) (-15 -3634 (|#1| $)) (-15 -1673 (|#2| $)))) (-1119) (-1119)) (T -1180)) 
+((-4466 (*1 *1 *2 *3) (-12 (-5 *1 (-1180 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) (-3634 (*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-1180 *2 *3)) (-4 *3 (-1119)))) (-1673 (*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-1180 *3 *2)) (-4 *3 (-1119))))) 
+(-13 (-1119) (-10 -8 (-15 -4466 ($ |#1| |#2|)) (-15 -3634 (|#1| $)) (-15 -1673 (|#2| $)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 (((-1189 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-323)) (|has| |#1| (-388))))) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 11)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-1555 (($ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-1313 (((-141) $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-2306 (($ $ (-592)) NIL) (($ $ (-592) (-592)) 66)) (-2982 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL)) (-1444 (((-1189 |#1| |#2| |#3|) $) 36)) (-2919 (((-3 (-1189 |#1| |#2| |#3|) "failed") $) 29)) (-1986 (((-1189 |#1| |#2| |#3|) $) 30)) (-1588 (($ $) 107 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 83 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) 103 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 79 (|has| |#1| (-43 (-433 (-592)))))) (-3940 (((-592) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))))) (-2881 (($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) NIL)) (-1601 (($ $) 111 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 87 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-1189 |#1| |#2| |#3|) "failed") $) 31) (((-3 (-1191) "failed") $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1065 (-1191))) (|has| |#1| (-388)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388)))) (((-3 (-592) "failed") $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388))))) (-2400 (((-1189 |#1| |#2| |#3|) $) 131) (((-1191) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1065 (-1191))) (|has| |#1| (-388)))) (((-433 (-592)) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388)))) (((-592) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388))))) (-3792 (($ $) 34) (($ (-592) $) 35)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-1189 |#1| |#2| |#3|)) (-706 $)) NIL (|has| |#1| (-388))) (((-2 (|:| -3253 (-706 (-1189 |#1| |#2| |#3|))) (|:| |vec| (-1280 (-1189 |#1| |#2| |#3|)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-388))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-654 (-592))) (|has| |#1| (-388)))) (((-706 (-592)) (-706 $)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-654 (-592))) (|has| |#1| (-388))))) (-3371 (((-3 $ "failed") $) 48)) (-3247 (((-433 (-980 |#1|)) $ (-592)) 65 (|has| |#1| (-582))) (((-433 (-980 |#1|)) $ (-592) (-592)) 67 (|has| |#1| (-582)))) (-4290 (($) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-574)) (|has| |#1| (-388))))) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-1691 (((-141) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))))) (-2273 (((-141) $) 25)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-908 (-592))) (|has| |#1| (-388)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-908 (-405))) (|has| |#1| (-388))))) (-4346 (((-592) $) NIL) (((-592) $ (-592)) 24)) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL (|has| |#1| (-388)))) (-1448 (((-1189 |#1| |#2| |#3|) $) 38 (|has| |#1| (-388)))) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3921 (((-3 $ "failed") $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1165)) (|has| |#1| (-388))))) (-1324 (((-141) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))))) (-3990 (($ $ (-944)) NIL)) (-1376 (($ (-1 |#1| (-592)) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-592)) 18) (($ $ (-1103) (-592)) NIL) (($ $ (-658 (-1103)) (-658 (-592))) NIL)) (-1837 (($ $ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3319 (($ $ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|)) $) NIL (|has| |#1| (-388)))) (-4546 (($ $) 72 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-1994 (($ (-592) (-1189 |#1| |#2| |#3|)) 33)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-3162 (($ $) 70 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 |#2|)) 71 (|has| |#1| (-43 (-433 (-592)))))) (-3703 (($) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1165)) (|has| |#1| (-388))) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-3856 (($ $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-323)) (|has| |#1| (-388))))) (-2039 (((-1189 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-574)) (|has| |#1| (-388))))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-2807 (($ $ (-592)) 145)) (-3616 (((-3 $ "failed") $ $) 49 (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-1430 (($ $) 73 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-592))))) (($ $ (-1191) (-1189 |#1| |#2| |#3|)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-547 (-1191) (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-658 (-1191)) (-658 (-1189 |#1| |#2| |#3|))) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-547 (-1191) (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-658 (-310 (-1189 |#1| |#2| |#3|)))) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-325 (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-310 (-1189 |#1| |#2| |#3|))) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-325 (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-325 (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-658 (-1189 |#1| |#2| |#3|)) (-658 (-1189 |#1| |#2| |#3|))) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-325 (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388))))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ (-592)) NIL) (($ $ $) 54 (|has| (-592) (-1131))) (($ $ (-1189 |#1| |#2| |#3|)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-303 (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|))) (|has| |#1| (-388))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-3644 (($ $ (-1 (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|))) NIL (|has| |#1| (-388))) (($ $ (-1 (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|)) (-790)) NIL (|has| |#1| (-388))) (($ $ (-1276 |#2|)) 51) (($ $ (-790)) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $) 50 (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191) (-790)) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-658 (-1191))) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))))) (-2782 (($ $) NIL (|has| |#1| (-388)))) (-1456 (((-1189 |#1| |#2| |#3|) $) 41 (|has| |#1| (-388)))) (-4525 (((-592) $) 37)) (-1609 (($ $) 113 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 89 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 109 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 85 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 105 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 81 (|has| |#1| (-43 (-433 (-592)))))) (-1778 (((-565) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-633 (-565))) (|has| |#1| (-388)))) (((-405) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1049)) (|has| |#1| (-388)))) (((-237) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1049)) (|has| |#1| (-388)))) (((-914 (-405)) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-633 (-914 (-405)))) (|has| |#1| (-388)))) (((-914 (-592)) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-633 (-914 (-592)))) (|has| |#1| (-388))))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-1700 (($ $) NIL)) (-1683 (((-877) $) 149) (($ (-592)) NIL) (($ |#1|) NIL (|has| |#1| (-194))) (($ (-1189 |#1| |#2| |#3|)) 27) (($ (-1276 |#2|)) 23) (($ (-1191)) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-1065 (-1191))) (|has| |#1| (-388)))) (($ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582)))) (($ (-433 (-592))) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388))) (|has| |#1| (-43 (-433 (-592))))))) (-1937 ((|#1| $ (-592)) 68)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-169)) (|has| |#1| (-388))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) 12)) (-2744 (((-1189 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-574)) (|has| |#1| (-388))))) (-1630 (($ $) 119 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 95 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-1617 (($ $) 115 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 91 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 123 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 99 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-592)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-592)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 125 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 101 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 121 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 97 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 117 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 93 (|has| |#1| (-43 (-433 (-592)))))) (-1392 (($ $) NIL (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 20 T CONST)) (-4257 (($) 16 T CONST)) (-1940 (($ $ (-1 (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|))) NIL (|has| |#1| (-388))) (($ $ (-1 (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|)) (-790)) NIL (|has| |#1| (-388))) (($ $ (-790)) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191) (-790)) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-658 (-1191))) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))))) (-3286 (((-141) $ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3273 (((-141) $ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3266 (((-141) $ $) NIL (-3836 (-12 (|has| (-1189 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1189 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) 44 (|has| |#1| (-388))) (($ (-1189 |#1| |#2| |#3|) (-1189 |#1| |#2| |#3|)) 45 (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 21)) (** (($ $ (-944)) NIL) (($ $ (-790)) 53) (($ $ (-592)) NIL (|has| |#1| (-388))) (($ $ $) 74 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 128 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 32) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-1189 |#1| |#2| |#3|)) 43 (|has| |#1| (-388))) (($ (-1189 |#1| |#2| |#3|) $) 42 (|has| |#1| (-388))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1181 |#1| |#2| |#3|) (-13 (-1241 |#1| (-1189 |#1| |#2| |#3|)) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) (-1075) (-1191) |#1|) (T -1181)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1181 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1181 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1181 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3)))) 
+(-13 (-1241 |#1| (-1189 |#1| |#2| |#3|)) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) 
+((-2090 ((|#2| |#2| (-1111 |#2|)) 26) ((|#2| |#2| (-1191)) 28))) 
+(((-1182 |#1| |#2|) (-10 -7 (-15 -2090 (|#2| |#2| (-1191))) (-15 -2090 (|#2| |#2| (-1111 |#2|)))) (-13 (-582) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-456 |#1|) (-182) (-27) (-1211))) (T -1182)) 
+((-2090 (*1 *2 *2 *3) (-12 (-5 *3 (-1111 *2)) (-4 *2 (-13 (-456 *4) (-182) (-27) (-1211))) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1182 *4 *2)))) (-2090 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1182 *4 *2)) (-4 *2 (-13 (-456 *4) (-182) (-27) (-1211)))))) 
+(-10 -7 (-15 -2090 (|#2| |#2| (-1191))) (-15 -2090 (|#2| |#2| (-1111 |#2|)))) 
+((-2090 (((-3 (-433 (-980 |#1|)) (-332 |#1|)) (-433 (-980 |#1|)) (-1111 (-433 (-980 |#1|)))) 30) (((-433 (-980 |#1|)) (-980 |#1|) (-1111 (-980 |#1|))) 44) (((-3 (-433 (-980 |#1|)) (-332 |#1|)) (-433 (-980 |#1|)) (-1191)) 32) (((-433 (-980 |#1|)) (-980 |#1|) (-1191)) 36))) 
+(((-1183 |#1|) (-10 -7 (-15 -2090 ((-433 (-980 |#1|)) (-980 |#1|) (-1191))) (-15 -2090 ((-3 (-433 (-980 |#1|)) (-332 |#1|)) (-433 (-980 |#1|)) (-1191))) (-15 -2090 ((-433 (-980 |#1|)) (-980 |#1|) (-1111 (-980 |#1|)))) (-15 -2090 ((-3 (-433 (-980 |#1|)) (-332 |#1|)) (-433 (-980 |#1|)) (-1111 (-433 (-980 |#1|)))))) (-13 (-582) (-869) (-1065 (-592)))) (T -1183)) 
+((-2090 (*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-433 (-980 *5)))) (-5 *3 (-433 (-980 *5))) (-4 *5 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-3 *3 (-332 *5))) (-5 *1 (-1183 *5)))) (-2090 (*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-980 *5))) (-5 *3 (-980 *5)) (-4 *5 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-433 *3)) (-5 *1 (-1183 *5)))) (-2090 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-3 (-433 (-980 *5)) (-332 *5))) (-5 *1 (-1183 *5)) (-5 *3 (-433 (-980 *5))))) (-2090 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-433 (-980 *5))) (-5 *1 (-1183 *5)) (-5 *3 (-980 *5))))) 
+(-10 -7 (-15 -2090 ((-433 (-980 |#1|)) (-980 |#1|) (-1191))) (-15 -2090 ((-3 (-433 (-980 |#1|)) (-332 |#1|)) (-433 (-980 |#1|)) (-1191))) (-15 -2090 ((-433 (-980 |#1|)) (-980 |#1|) (-1111 (-980 |#1|)))) (-15 -2090 ((-3 (-433 (-980 |#1|)) (-332 |#1|)) (-433 (-980 |#1|)) (-1111 (-433 (-980 |#1|)))))) 
+((-2731 (((-1187 |#2|) (-1 |#2| |#1|) (-1187 |#1|)) 13))) 
+(((-1184 |#1| |#2|) (-10 -7 (-15 -2731 ((-1187 |#2|) (-1 |#2| |#1|) (-1187 |#1|)))) (-1075) (-1075)) (T -1184)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1187 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-1187 *6)) (-5 *1 (-1184 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-1187 |#2|) (-1 |#2| |#1|) (-1187 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2651 (((-1280 |#1|) $ (-790)) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-2085 (($ (-1187 |#1|)) NIL)) (-4492 (((-1187 $) $ (-1103)) NIL) (((-1187 |#1|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1103))) NIL)) (-1588 (($ $) NIL (|has| |#1| (-1211)))) (-1507 (($ $) NIL (|has| |#1| (-1211)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3250 (($ $ $) NIL (|has| |#1| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) NIL (|has| |#1| (-1211)))) (-1495 (($ $) 22 (|has| |#1| (-1211)))) (-1696 (($ $ (-790)) NIL)) (-1498 (($ $ (-790)) NIL)) (-1504 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-477)))) (-1601 (($ $) NIL (|has| |#1| (-1211)))) (-1521 (($ $) NIL (|has| |#1| (-1211)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-1103) "failed") $) NIL)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-1103) $) NIL)) (-1544 (($ $ $ (-1103)) NIL (|has| |#1| (-194))) ((|#1| $ $) NIL (|has| |#1| (-194)))) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-3213 (($ $ $) NIL)) (-2133 (($ $ $) NIL (|has| |#1| (-582)))) (-4369 (((-2 (|:| -1487 |#1|) (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-3262 (($ $) NIL (|has| |#1| (-477))) (($ $ (-1103)) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-790) $) NIL)) (-1435 (($) NIL (|has| |#1| (-1211)))) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1103) (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1103) (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-4346 (((-790) $ $) NIL (|has| |#1| (-582)))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-1165)))) (-4533 (($ (-1187 |#1|) (-1103)) NIL) (($ (-1187 $) (-1103)) NIL)) (-3990 (($ $ (-790)) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1103)) NIL) (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4206 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-790) (-790)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2070 (((-1187 |#1|) $) NIL)) (-3254 (((-3 (-1103) "failed") $) NIL)) (-4546 (($ $) 18 (|has| |#1| (-1211)))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-3768 (((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790)) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-1103)) (|:| -3215 (-790))) "failed") $) NIL)) (-3162 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3703 (($) NIL (|has| |#1| (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 8)) (-4565 ((|#1| $) 9)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#1| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-931)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-3616 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-1430 (($ $) 20 (|has| |#1| (-1211)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1103) |#1|) NIL) (($ $ (-658 (-1103)) (-658 |#1|)) NIL) (($ $ (-1103) $) NIL) (($ $ (-658 (-1103)) (-658 $)) NIL)) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-433 $) (-433 $) (-433 $)) NIL (|has| |#1| (-582))) ((|#1| (-433 $) |#1|) NIL (|has| |#1| (-388))) (((-433 $) $ (-433 $)) NIL (|has| |#1| (-582)))) (-4510 (((-3 $ "failed") $ (-790)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-1482 (($ $ (-1103)) NIL (|has| |#1| (-194))) ((|#1| $) NIL (|has| |#1| (-194)))) (-3644 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-4525 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1609 (($ $) NIL (|has| |#1| (-1211)))) (-1527 (($ $) NIL (|has| |#1| (-1211)))) (-1594 (($ $) NIL (|has| |#1| (-1211)))) (-1515 (($ $) NIL (|has| |#1| (-1211)))) (-1581 (($ $) NIL (|has| |#1| (-1211)))) (-1501 (($ $) 26 (|has| |#1| (-1211)))) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-1103) (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) NIL (|has| |#1| (-477))) (($ $ (-1103)) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1528 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582))) (((-3 (-433 $) "failed") (-433 $) $) NIL (|has| |#1| (-582)))) (-1683 (((-877) $) 13) (($ (-592)) NIL) (($ |#1|) 11) (($ (-1103)) NIL) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-1630 (($ $) NIL (|has| |#1| (-1211)))) (-1546 (($ $) NIL (|has| |#1| (-1211)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-1211)))) (-1533 (($ $) 24 (|has| |#1| (-1211)))) (-1642 (($ $) NIL (|has| |#1| (-1211)))) (-1559 (($ $) NIL (|has| |#1| (-1211)))) (-2892 (($ $) NIL (|has| |#1| (-1211)))) (-1567 (($ $) NIL (|has| |#1| (-1211)))) (-1636 (($ $) NIL (|has| |#1| (-1211)))) (-1552 (($ $) NIL (|has| |#1| (-1211)))) (-1624 (($ $) NIL (|has| |#1| (-1211)))) (-1540 (($ $) 28 (|has| |#1| (-1211)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ $) NIL (|has| |#1| (-1211)))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-1185 |#1|) (-13 (-1255 |#1|) (-10 -7 (IF (|has| |#1| (-1211)) (-6 (-1211)) |noBranch|))) (-1075)) (T -1185)) 
+NIL 
+(-13 (-1255 |#1|) (-10 -7 (IF (|has| |#1| (-1211)) (-6 (-1211)) |noBranch|))) 
+((-3164 (((-444 (-1187 (-433 |#4|))) (-1187 (-433 |#4|))) 50)) (-4500 (((-444 (-1187 (-433 |#4|))) (-1187 (-433 |#4|))) 51))) 
+(((-1186 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4500 ((-444 (-1187 (-433 |#4|))) (-1187 (-433 |#4|)))) (-15 -3164 ((-444 (-1187 (-433 |#4|))) (-1187 (-433 |#4|))))) (-815) (-869) (-477) (-977 |#3| |#1| |#2|)) (T -1186)) 
+((-3164 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-477)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-444 (-1187 (-433 *7)))) (-5 *1 (-1186 *4 *5 *6 *7)) (-5 *3 (-1187 (-433 *7))))) (-4500 (*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-477)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-444 (-1187 (-433 *7)))) (-5 *1 (-1186 *4 *5 *6 *7)) (-5 *3 (-1187 (-433 *7)))))) 
+(-10 -7 (-15 -4500 ((-444 (-1187 (-433 |#4|))) (-1187 (-433 |#4|)))) (-15 -3164 ((-444 (-1187 (-433 |#4|))) (-1187 (-433 |#4|))))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 30)) (-2651 (((-1280 |#1|) $ (-790)) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-2085 (($ (-1187 |#1|)) NIL)) (-4492 (((-1187 $) $ (-1103)) 59) (((-1187 |#1|) $) 48)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) 132 (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1103))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3250 (($ $ $) 126 (|has| |#1| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) 72 (|has| |#1| (-931)))) (-3743 (($ $) NIL (|has| |#1| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 92 (|has| |#1| (-931)))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1696 (($ $ (-790)) 42)) (-1498 (($ $ (-790)) 43)) (-1504 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-477)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#1| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-1103) "failed") $) NIL)) (-2400 ((|#1| $) NIL) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-1103) $) NIL)) (-1544 (($ $ $ (-1103)) NIL (|has| |#1| (-194))) ((|#1| $ $) 128 (|has| |#1| (-194)))) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) 57)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) NIL) (((-706 |#1|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-3213 (($ $ $) 104)) (-2133 (($ $ $) NIL (|has| |#1| (-582)))) (-4369 (((-2 (|:| -1487 |#1|) (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-3262 (($ $) 133 (|has| |#1| (-477))) (($ $ (-1103)) NIL (|has| |#1| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-790) $) 46)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1103) (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1103) (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-4149 (((-877) $ (-877)) 117)) (-4346 (((-790) $ $) NIL (|has| |#1| (-582)))) (-3558 (((-141) $) 32)) (-4036 (((-790) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| |#1| (-1165)))) (-4533 (($ (-1187 |#1|) (-1103)) 50) (($ (-1187 $) (-1103)) 66)) (-3990 (($ $ (-790)) 34)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) 64) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1103)) NIL) (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 121)) (-4206 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-2976 (($ (-1 (-790) (-790)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2070 (((-1187 |#1|) $) NIL)) (-3254 (((-3 (-1103) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) 53)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) NIL (|has| |#1| (-477)))) (-2685 (((-1173) $) NIL)) (-3768 (((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790)) 41)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-1103)) (|:| -3215 (-790))) "failed") $) NIL)) (-3162 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3703 (($) NIL (|has| |#1| (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) 33)) (-4565 ((|#1| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 80 (|has| |#1| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-477))) (($ $ $) 135 (|has| |#1| (-477)))) (-4550 (($ $ (-790) |#1| $) 99)) (-1416 (((-444 (-1187 $)) (-1187 $)) 78 (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) 77 (|has| |#1| (-931)))) (-4500 (((-444 $) $) 85 (|has| |#1| (-931)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-3616 (((-3 $ "failed") $ |#1|) 131 (|has| |#1| (-582))) (((-3 $ "failed") $ $) 100 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1103) |#1|) NIL) (($ $ (-658 (-1103)) (-658 |#1|)) NIL) (($ $ (-1103) $) NIL) (($ $ (-658 (-1103)) (-658 $)) NIL)) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ |#1|) 119) (($ $ $) 120) (((-433 $) (-433 $) (-433 $)) NIL (|has| |#1| (-582))) ((|#1| (-433 $) |#1|) NIL (|has| |#1| (-388))) (((-433 $) $ (-433 $)) NIL (|has| |#1| (-582)))) (-4510 (((-3 $ "failed") $ (-790)) 37)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 137 (|has| |#1| (-388)))) (-1482 (($ $ (-1103)) NIL (|has| |#1| (-194))) ((|#1| $) 124 (|has| |#1| (-194)))) (-3644 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-4525 (((-790) $) 55) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-1103) (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) 130 (|has| |#1| (-477))) (($ $ (-1103)) NIL (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#1| (-931))))) (-1528 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582))) (((-3 (-433 $) "failed") (-433 $) $) NIL (|has| |#1| (-582)))) (-1683 (((-877) $) 118) (($ (-592)) NIL) (($ |#1|) 54) (($ (-1103)) NIL) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) 28 (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 15) (($ $ (-790)) 16)) (-3514 (($) 17 T CONST)) (-4257 (($) 18 T CONST)) (-1940 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) 97)) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3313 (($ $ |#1|) 138 (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 67)) (** (($ $ (-944)) 14) (($ $ (-790)) 12)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 27) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 102) (($ $ |#1|) NIL))) 
+(((-1187 |#1|) (-13 (-1255 |#1|) (-10 -8 (-15 -4149 ((-877) $ (-877))) (-15 -4550 ($ $ (-790) |#1| $)))) (-1075)) (T -1187)) 
+((-4149 (*1 *2 *1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-1187 *3)) (-4 *3 (-1075)))) (-4550 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1187 *3)) (-4 *3 (-1075))))) 
+(-13 (-1255 |#1|) (-10 -8 (-15 -4149 ((-877) $ (-877))) (-15 -4550 ($ $ (-790) |#1| $)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 11)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-433 (-592))) NIL) (($ $ (-433 (-592)) (-433 (-592))) NIL)) (-2982 (((-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|))) $) NIL)) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-790) (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|)))) NIL)) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-1181 |#1| |#2| |#3|) "failed") $) 32) (((-3 (-1189 |#1| |#2| |#3|) "failed") $) 35)) (-2400 (((-1181 |#1| |#2| |#3|) $) NIL) (((-1189 |#1| |#2| |#3|) $) NIL)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1468 (((-433 (-592)) $) 55)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-2001 (($ (-433 (-592)) (-1181 |#1| |#2| |#3|)) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-433 (-592)) $) NIL) (((-433 (-592)) $ (-433 (-592))) NIL)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) NIL) (($ $ (-433 (-592))) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-433 (-592))) 19) (($ $ (-1103) (-433 (-592))) NIL) (($ $ (-658 (-1103)) (-658 (-433 (-592)))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-2337 (((-1181 |#1| |#2| |#3|) $) 40)) (-2501 (((-3 (-1181 |#1| |#2| |#3|) "failed") $) NIL)) (-1994 (((-1181 |#1| |#2| |#3|) $) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-3162 (($ $) 38 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 |#2|)) 39 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-2807 (($ $ (-433 (-592))) NIL)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ (-433 (-592))) NIL) (($ $ $) NIL (|has| (-433 (-592)) (-1131)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) 36 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $ (-1276 |#2|)) 37)) (-4525 (((-433 (-592)) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) NIL)) (-1683 (((-877) $) 58) (($ (-592)) NIL) (($ |#1|) NIL (|has| |#1| (-194))) (($ (-1181 |#1| |#2| |#3|)) 29) (($ (-1189 |#1| |#2| |#3|)) 30) (($ (-1276 |#2|)) 25) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582)))) (-1937 ((|#1| $ (-433 (-592))) NIL)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) 12)) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-433 (-592))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 21 T CONST)) (-4257 (($) 16 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 23)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1188 |#1| |#2| |#3|) (-13 (-1262 |#1| (-1181 |#1| |#2| |#3|)) (-1065 (-1189 |#1| |#2| |#3|)) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) (-1075) (-1191) |#1|) (T -1188)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1188 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1188 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1188 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3)))) 
+(-13 (-1262 |#1| (-1181 |#1| |#2| |#3|)) (-1065 (-1189 |#1| |#2| |#3|)) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 124)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 115)) (-3395 (((-1252 |#2| |#1|) $ (-790)) 62)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-790)) 78) (($ $ (-790) (-790)) 75)) (-2982 (((-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|))) $) 101)) (-1588 (($ $) 168 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 144 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1575 (($ $) 164 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 140 (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|)))) 114) (($ (-1171 |#1|)) 109)) (-1601 (($ $) 172 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 148 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) 23)) (-2410 (($ $) 26)) (-2012 (((-980 |#1|) $ (-790)) 74) (((-980 |#1|) $ (-790) (-790)) 76)) (-2273 (((-141) $) 119)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-790) $) 121) (((-790) $ (-790)) 123)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) NIL)) (-1376 (($ (-1 |#1| (-592)) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) 13) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4546 (($ $) 130 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-3162 (($ $) 128 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 |#2|)) 129 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-2807 (($ $ (-790)) 15)) (-3616 (((-3 $ "failed") $ $) 24 (|has| |#1| (-582)))) (-1430 (($ $) 132 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-790)))))) (-3927 ((|#1| $ (-790)) 118) (($ $ $) 127 (|has| (-790) (-1131)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) 27 (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $ (-1276 |#2|)) 29)) (-4525 (((-790) $) NIL)) (-1609 (($ $) 174 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 150 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 170 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 146 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 166 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 142 (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) NIL)) (-1683 (((-877) $) 200) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582))) (($ |#1|) 125 (|has| |#1| (-194))) (($ (-1252 |#2| |#1|)) 50) (($ (-1276 |#2|)) 32)) (-1647 (((-1171 |#1|) $) 97)) (-1937 ((|#1| $ (-790)) 117)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) 53)) (-1630 (($ $) 180 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 156 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) 176 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 152 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 184 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 160 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-790)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-790)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 186 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 162 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 182 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 158 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 178 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 154 (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 17 T CONST)) (-4257 (($) 19 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) 193)) (-3300 (($ $ $) 31)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ |#1|) 197 (|has| |#1| (-388))) (($ $ $) 133 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 136 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 131) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1189 |#1| |#2| |#3|) (-13 (-1270 |#1|) (-10 -8 (-15 -1683 ($ (-1252 |#2| |#1|))) (-15 -3395 ((-1252 |#2| |#1|) $ (-790))) (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) (-1075) (-1191) |#1|) (T -1189)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1252 *4 *3)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3) (-5 *1 (-1189 *3 *4 *5)))) (-3395 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1252 *5 *4)) (-5 *1 (-1189 *4 *5 *6)) (-4 *4 (-1075)) (-14 *5 (-1191)) (-14 *6 *4))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1189 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1189 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1189 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3)))) 
+(-13 (-1270 |#1|) (-10 -8 (-15 -1683 ($ (-1252 |#2| |#1|))) (-15 -3395 ((-1252 |#2| |#1|) $ (-790))) (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) 
+((-1683 (((-877) $) 22) (($ (-1191)) 24)) (-3836 (($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $))) 35)) (-3830 (($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $))) 28) (($ $) 29)) (-3517 (($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $))) 30)) (-2996 (($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $))) 32)) (-3681 (($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $))) 31)) (-3137 (($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $))) 33)) (-1465 (($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $))) 36)) (-12 (($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $))) 34))) 
+(((-1190) (-13 (-632 (-877)) (-10 -8 (-15 -1683 ($ (-1191))) (-15 -3517 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3681 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -2996 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3137 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3836 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -1465 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -12 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3830 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3830 ($ $))))) (T -1190)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1190)))) (-3517 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190)))) (-3681 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190)))) (-2996 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190)))) (-3137 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190)))) (-3836 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190)))) (-1465 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190)))) (-12 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190)))) (-3830 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190)))) (-3830 (*1 *1 *1) (-5 *1 (-1190)))) 
+(-13 (-632 (-877)) (-10 -8 (-15 -1683 ($ (-1191))) (-15 -3517 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3681 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -2996 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3137 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3836 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -1465 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -12 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)) (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3830 ($ (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| $)))) (-15 -3830 ($ $)))) 
+((-1641 (((-141) $ $) NIL)) (-1827 (($ $ (-658 (-877))) 58)) (-2191 (($ $ (-658 (-877))) 56)) (-4574 (((-1173) $) 82)) (-4239 (((-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877)))) $) 85)) (-3869 (((-141) $) 21)) (-2374 (($ $ (-658 (-658 (-877)))) 54) (($ $ (-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877))))) 80)) (-3001 (($) 122 T CONST)) (-1682 (((-1285)) 103)) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 65) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 71)) (-3242 (($) 92) (($ $) 98)) (-4095 (($ $) 81)) (-1837 (($ $ $) NIL)) (-3319 (($ $ $) NIL)) (-1333 (((-658 $) $) 104)) (-2685 (((-1173) $) 87)) (-2951 (((-1137) $) NIL)) (-3927 (($ $ (-658 (-877))) 57)) (-1778 (((-565) $) 45) (((-1191) $) 46) (((-914 (-592)) $) 75) (((-914 (-405)) $) 73)) (-1683 (((-877) $) 52) (($ (-1173)) 47)) (-1925 (($ $ (-658 (-877))) 59)) (-1637 (((-1173) $) 33) (((-1173) $ (-141)) 34) (((-1285) (-844) $) 35) (((-1285) (-844) $ (-141)) 36)) (-3286 (((-141) $ $) NIL)) (-3273 (((-141) $ $) NIL)) (-3255 (((-141) $ $) 48)) (-3279 (((-141) $ $) NIL)) (-3266 (((-141) $ $) 49))) 
+(((-1191) (-13 (-869) (-633 (-565)) (-850) (-633 (-1191)) (-633 (-914 (-592))) (-633 (-914 (-405))) (-908 (-592)) (-908 (-405)) (-10 -8 (-15 -3242 ($)) (-15 -3242 ($ $)) (-15 -1682 ((-1285))) (-15 -1683 ($ (-1173))) (-15 -4095 ($ $)) (-15 -3869 ((-141) $)) (-15 -4239 ((-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877)))) $)) (-15 -2374 ($ $ (-658 (-658 (-877))))) (-15 -2374 ($ $ (-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877)))))) (-15 -2191 ($ $ (-658 (-877)))) (-15 -1827 ($ $ (-658 (-877)))) (-15 -1925 ($ $ (-658 (-877)))) (-15 -3927 ($ $ (-658 (-877)))) (-15 -4574 ((-1173) $)) (-15 -1333 ((-658 $) $)) (-15 -3001 ($) -4249)))) (T -1191)) 
+((-3242 (*1 *1) (-5 *1 (-1191))) (-3242 (*1 *1 *1) (-5 *1 (-1191))) (-1682 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1191)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1191)))) (-4095 (*1 *1 *1) (-5 *1 (-1191))) (-3869 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1191)))) (-4239 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877))))) (-5 *1 (-1191)))) (-2374 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-658 (-877)))) (-5 *1 (-1191)))) (-2374 (*1 *1 *1 *2) (-12 (-5 *2 (-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877))))) (-5 *1 (-1191)))) (-2191 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-1191)))) (-1827 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-1191)))) (-1925 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-1191)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-1191)))) (-4574 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1191)))) (-1333 (*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-1191)))) (-3001 (*1 *1) (-5 *1 (-1191)))) 
+(-13 (-869) (-633 (-565)) (-850) (-633 (-1191)) (-633 (-914 (-592))) (-633 (-914 (-405))) (-908 (-592)) (-908 (-405)) (-10 -8 (-15 -3242 ($)) (-15 -3242 ($ $)) (-15 -1682 ((-1285))) (-15 -1683 ($ (-1173))) (-15 -4095 ($ $)) (-15 -3869 ((-141) $)) (-15 -4239 ((-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877)))) $)) (-15 -2374 ($ $ (-658 (-658 (-877))))) (-15 -2374 ($ $ (-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877)))))) (-15 -2191 ($ $ (-658 (-877)))) (-15 -1827 ($ $ (-658 (-877)))) (-15 -1925 ($ $ (-658 (-877)))) (-15 -3927 ($ $ (-658 (-877)))) (-15 -4574 ((-1173) $)) (-15 -1333 ((-658 $) $)) (-15 -3001 ($) -4249))) 
+((-3328 (((-1280 |#1|) |#1| (-944)) 16) (((-1280 |#1|) (-658 |#1|)) 20))) 
+(((-1192 |#1|) (-10 -7 (-15 -3328 ((-1280 |#1|) (-658 |#1|))) (-15 -3328 ((-1280 |#1|) |#1| (-944)))) (-1075)) (T -1192)) 
+((-3328 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-5 *2 (-1280 *3)) (-5 *1 (-1192 *3)) (-4 *3 (-1075)))) (-3328 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1075)) (-5 *2 (-1280 *4)) (-5 *1 (-1192 *4))))) 
+(-10 -7 (-15 -3328 ((-1280 |#1|) (-658 |#1|))) (-15 -3328 ((-1280 |#1|) |#1| (-944)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| |#1| (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#1| (-1065 (-433 (-592))))) (((-3 |#1| "failed") $) NIL)) (-2400 (((-592) $) NIL (|has| |#1| (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| |#1| (-1065 (-433 (-592))))) ((|#1| $) NIL)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3262 (($ $) NIL (|has| |#1| (-477)))) (-4209 (($ $ |#1| (-1000) $) NIL)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-1000)) NIL)) (-4206 (((-1000) $) NIL)) (-2976 (($ (-1 (-1000) (-1000)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#1| $) NIL)) (-4550 (($ $ (-1000) |#1| $) NIL (-12 (|has| (-1000) (-158)) (|has| |#1| (-582))))) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582))) (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-582)))) (-4525 (((-1000) $) NIL)) (-1554 ((|#1| $) NIL (|has| |#1| (-477)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ $) NIL (|has| |#1| (-582))) (($ |#1|) NIL) (($ (-433 (-592))) NIL (-3836 (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-1065 (-433 (-592))))))) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ (-1000)) NIL)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#1| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 9 T CONST)) (-4257 (($) 14 T CONST)) (-3255 (((-141) $ $) 16)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 19)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 20) (($ $ |#1|) NIL) (($ |#1| $) 13) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1193 |#1|) (-13 (-346 |#1| (-1000)) (-10 -8 (IF (|has| |#1| (-582)) (IF (|has| (-1000) (-158)) (-15 -4550 ($ $ (-1000) |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4623)) (-6 -4623) |noBranch|))) (-1075)) (T -1193)) 
+((-4550 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-1000)) (-4 *2 (-158)) (-5 *1 (-1193 *3)) (-4 *3 (-582)) (-4 *3 (-1075))))) 
+(-13 (-346 |#1| (-1000)) (-10 -8 (IF (|has| |#1| (-582)) (IF (|has| (-1000) (-158)) (-15 -4550 ($ $ (-1000) |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4623)) (-6 -4623) |noBranch|))) 
+((-3910 (((-1195) (-1191) $) 24)) (-1675 (($) 28)) (-2558 (((-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-1191) $) 21)) (-3241 (((-1285) (-1191) (-3 (|:| |fst| (-460)) (|:| -4191 "void")) $) 40) (((-1285) (-1191) (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) 41) (((-1285) (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) 42)) (-2768 (((-1285) (-1191)) 57)) (-2647 (((-1285) (-1191) $) 54) (((-1285) (-1191)) 55) (((-1285)) 56)) (-1421 (((-1285) (-1191)) 36)) (-3312 (((-1191)) 35)) (-2890 (($) 33)) (-3321 (((-463) (-1191) (-463) (-1191) $) 44) (((-463) (-658 (-1191)) (-463) (-1191) $) 48) (((-463) (-1191) (-463)) 45) (((-463) (-1191) (-463) (-1191)) 49)) (-1725 (((-1191)) 34)) (-1683 (((-877) $) 27)) (-3234 (((-1285)) 29) (((-1285) (-1191)) 32)) (-2197 (((-658 (-1191)) (-1191) $) 23)) (-1340 (((-1285) (-1191) (-658 (-1191)) $) 37) (((-1285) (-1191) (-658 (-1191))) 38) (((-1285) (-658 (-1191))) 39))) 
+(((-1194) (-13 (-632 (-877)) (-10 -8 (-15 -1675 ($)) (-15 -3234 ((-1285))) (-15 -3234 ((-1285) (-1191))) (-15 -3321 ((-463) (-1191) (-463) (-1191) $)) (-15 -3321 ((-463) (-658 (-1191)) (-463) (-1191) $)) (-15 -3321 ((-463) (-1191) (-463))) (-15 -3321 ((-463) (-1191) (-463) (-1191))) (-15 -1421 ((-1285) (-1191))) (-15 -1725 ((-1191))) (-15 -3312 ((-1191))) (-15 -1340 ((-1285) (-1191) (-658 (-1191)) $)) (-15 -1340 ((-1285) (-1191) (-658 (-1191)))) (-15 -1340 ((-1285) (-658 (-1191)))) (-15 -3241 ((-1285) (-1191) (-3 (|:| |fst| (-460)) (|:| -4191 "void")) $)) (-15 -3241 ((-1285) (-1191) (-3 (|:| |fst| (-460)) (|:| -4191 "void")))) (-15 -3241 ((-1285) (-3 (|:| |fst| (-460)) (|:| -4191 "void")))) (-15 -2647 ((-1285) (-1191) $)) (-15 -2647 ((-1285) (-1191))) (-15 -2647 ((-1285))) (-15 -2768 ((-1285) (-1191))) (-15 -2890 ($)) (-15 -2558 ((-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-1191) $)) (-15 -2197 ((-658 (-1191)) (-1191) $)) (-15 -3910 ((-1195) (-1191) $))))) (T -1194)) 
+((-1675 (*1 *1) (-5 *1 (-1194))) (-3234 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1194)))) (-3234 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-3321 (*1 *2 *3 *2 *3 *1) (-12 (-5 *2 (-463)) (-5 *3 (-1191)) (-5 *1 (-1194)))) (-3321 (*1 *2 *3 *2 *4 *1) (-12 (-5 *2 (-463)) (-5 *3 (-658 (-1191))) (-5 *4 (-1191)) (-5 *1 (-1194)))) (-3321 (*1 *2 *3 *2) (-12 (-5 *2 (-463)) (-5 *3 (-1191)) (-5 *1 (-1194)))) (-3321 (*1 *2 *3 *2 *3) (-12 (-5 *2 (-463)) (-5 *3 (-1191)) (-5 *1 (-1194)))) (-1421 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-1725 (*1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1194)))) (-3312 (*1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1194)))) (-1340 (*1 *2 *3 *4 *1) (-12 (-5 *4 (-658 (-1191))) (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-1340 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-1191))) (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-1340 (*1 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-3241 (*1 *2 *3 *4 *1) (-12 (-5 *3 (-1191)) (-5 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-3241 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-3241 (*1 *2 *3) (-12 (-5 *3 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-2647 (*1 *2 *3 *1) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-2647 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-2647 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1194)))) (-2768 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) (-2890 (*1 *1) (-5 *1 (-1194))) (-2558 (*1 *2 *3 *1) (-12 (-5 *3 (-1191)) (-5 *2 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *1 (-1194)))) (-2197 (*1 *2 *3 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-1194)) (-5 *3 (-1191)))) (-3910 (*1 *2 *3 *1) (-12 (-5 *3 (-1191)) (-5 *2 (-1195)) (-5 *1 (-1194))))) 
+(-13 (-632 (-877)) (-10 -8 (-15 -1675 ($)) (-15 -3234 ((-1285))) (-15 -3234 ((-1285) (-1191))) (-15 -3321 ((-463) (-1191) (-463) (-1191) $)) (-15 -3321 ((-463) (-658 (-1191)) (-463) (-1191) $)) (-15 -3321 ((-463) (-1191) (-463))) (-15 -3321 ((-463) (-1191) (-463) (-1191))) (-15 -1421 ((-1285) (-1191))) (-15 -1725 ((-1191))) (-15 -3312 ((-1191))) (-15 -1340 ((-1285) (-1191) (-658 (-1191)) $)) (-15 -1340 ((-1285) (-1191) (-658 (-1191)))) (-15 -1340 ((-1285) (-658 (-1191)))) (-15 -3241 ((-1285) (-1191) (-3 (|:| |fst| (-460)) (|:| -4191 "void")) $)) (-15 -3241 ((-1285) (-1191) (-3 (|:| |fst| (-460)) (|:| -4191 "void")))) (-15 -3241 ((-1285) (-3 (|:| |fst| (-460)) (|:| -4191 "void")))) (-15 -2647 ((-1285) (-1191) $)) (-15 -2647 ((-1285) (-1191))) (-15 -2647 ((-1285))) (-15 -2768 ((-1285) (-1191))) (-15 -2890 ($)) (-15 -2558 ((-3 (|:| |fst| (-460)) (|:| -4191 "void")) (-1191) $)) (-15 -2197 ((-658 (-1191)) (-1191) $)) (-15 -3910 ((-1195) (-1191) $)))) 
+((-4031 (((-658 (-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592))))))))) $) 57)) (-1753 (((-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592)))))))) (-460) $) 40)) (-3565 (($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-463))))) 15)) (-2768 (((-1285) $) 65)) (-2469 (((-658 (-1191)) $) 20)) (-2877 (((-1123) $) 53)) (-2697 (((-463) (-1191) $) 27)) (-2062 (((-658 (-1191)) $) 30)) (-2890 (($) 17)) (-3321 (((-463) (-658 (-1191)) (-463) $) 25) (((-463) (-1191) (-463) $) 24)) (-1683 (((-877) $) 9) (((-1199 (-1191) (-463)) $) 11))) 
+(((-1195) (-13 (-632 (-877)) (-10 -8 (-15 -1683 ((-1199 (-1191) (-463)) $)) (-15 -2890 ($)) (-15 -3321 ((-463) (-658 (-1191)) (-463) $)) (-15 -3321 ((-463) (-1191) (-463) $)) (-15 -2697 ((-463) (-1191) $)) (-15 -2469 ((-658 (-1191)) $)) (-15 -1753 ((-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592)))))))) (-460) $)) (-15 -2062 ((-658 (-1191)) $)) (-15 -4031 ((-658 (-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592))))))))) $)) (-15 -2877 ((-1123) $)) (-15 -2768 ((-1285) $)) (-15 -3565 ($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-463))))))))) (T -1195)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-1199 (-1191) (-463))) (-5 *1 (-1195)))) (-2890 (*1 *1) (-5 *1 (-1195))) (-3321 (*1 *2 *3 *2 *1) (-12 (-5 *2 (-463)) (-5 *3 (-658 (-1191))) (-5 *1 (-1195)))) (-3321 (*1 *2 *3 *2 *1) (-12 (-5 *2 (-463)) (-5 *3 (-1191)) (-5 *1 (-1195)))) (-2697 (*1 *2 *3 *1) (-12 (-5 *3 (-1191)) (-5 *2 (-463)) (-5 *1 (-1195)))) (-2469 (*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-1195)))) (-1753 (*1 *2 *3 *1) (-12 (-5 *3 (-460)) (-5 *2 (-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592))))))))) (-5 *1 (-1195)))) (-2062 (*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-1195)))) (-4031 (*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592)))))))))) (-5 *1 (-1195)))) (-2877 (*1 *2 *1) (-12 (-5 *2 (-1123)) (-5 *1 (-1195)))) (-2768 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1195)))) (-3565 (*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-463))))) (-5 *1 (-1195))))) 
+(-13 (-632 (-877)) (-10 -8 (-15 -1683 ((-1199 (-1191) (-463)) $)) (-15 -2890 ($)) (-15 -3321 ((-463) (-658 (-1191)) (-463) $)) (-15 -3321 ((-463) (-1191) (-463) $)) (-15 -2697 ((-463) (-1191) $)) (-15 -2469 ((-658 (-1191)) $)) (-15 -1753 ((-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592)))))))) (-460) $)) (-15 -2062 ((-658 (-1191)) $)) (-15 -4031 ((-658 (-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592))))))))) $)) (-15 -2877 ((-1123) $)) (-15 -2768 ((-1285) $)) (-15 -3565 ($ (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-463)))))))) 
+((-3485 (((-658 (-658 (-980 |#1|))) (-658 (-433 (-980 |#1|))) (-658 (-1191))) 55)) (-4005 (((-658 (-310 (-433 (-980 |#1|)))) (-310 (-433 (-980 |#1|)))) 66) (((-658 (-310 (-433 (-980 |#1|)))) (-433 (-980 |#1|))) 62) (((-658 (-310 (-433 (-980 |#1|)))) (-310 (-433 (-980 |#1|))) (-1191)) 67) (((-658 (-310 (-433 (-980 |#1|)))) (-433 (-980 |#1|)) (-1191)) 61) (((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-310 (-433 (-980 |#1|))))) 91) (((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-433 (-980 |#1|)))) 90) (((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-310 (-433 (-980 |#1|)))) (-658 (-1191))) 92) (((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-433 (-980 |#1|))) (-658 (-1191))) 89))) 
+(((-1196 |#1|) (-10 -7 (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-433 (-980 |#1|))) (-658 (-1191)))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-310 (-433 (-980 |#1|)))) (-658 (-1191)))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-433 (-980 |#1|))))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-310 (-433 (-980 |#1|)))))) (-15 -4005 ((-658 (-310 (-433 (-980 |#1|)))) (-433 (-980 |#1|)) (-1191))) (-15 -4005 ((-658 (-310 (-433 (-980 |#1|)))) (-310 (-433 (-980 |#1|))) (-1191))) (-15 -4005 ((-658 (-310 (-433 (-980 |#1|)))) (-433 (-980 |#1|)))) (-15 -4005 ((-658 (-310 (-433 (-980 |#1|)))) (-310 (-433 (-980 |#1|))))) (-15 -3485 ((-658 (-658 (-980 |#1|))) (-658 (-433 (-980 |#1|))) (-658 (-1191))))) (-582)) (T -1196)) 
+((-3485 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 *5)))) (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-980 *5)))) (-5 *1 (-1196 *5)))) (-4005 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 (-310 (-433 (-980 *4))))) (-5 *1 (-1196 *4)) (-5 *3 (-310 (-433 (-980 *4)))))) (-4005 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 (-310 (-433 (-980 *4))))) (-5 *1 (-1196 *4)) (-5 *3 (-433 (-980 *4))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-582)) (-5 *2 (-658 (-310 (-433 (-980 *5))))) (-5 *1 (-1196 *5)) (-5 *3 (-310 (-433 (-980 *5)))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-582)) (-5 *2 (-658 (-310 (-433 (-980 *5))))) (-5 *1 (-1196 *5)) (-5 *3 (-433 (-980 *5))))) (-4005 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *4)))))) (-5 *1 (-1196 *4)) (-5 *3 (-658 (-310 (-433 (-980 *4))))))) (-4005 (*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 *4)))) (-4 *4 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *4)))))) (-5 *1 (-1196 *4)))) (-4005 (*1 *2 *3 *4) (-12 (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *5)))))) (-5 *1 (-1196 *5)) (-5 *3 (-658 (-310 (-433 (-980 *5))))))) (-4005 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 *5)))) (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *5)))))) (-5 *1 (-1196 *5))))) 
+(-10 -7 (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-433 (-980 |#1|))) (-658 (-1191)))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-310 (-433 (-980 |#1|)))) (-658 (-1191)))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-433 (-980 |#1|))))) (-15 -4005 ((-658 (-658 (-310 (-433 (-980 |#1|))))) (-658 (-310 (-433 (-980 |#1|)))))) (-15 -4005 ((-658 (-310 (-433 (-980 |#1|)))) (-433 (-980 |#1|)) (-1191))) (-15 -4005 ((-658 (-310 (-433 (-980 |#1|)))) (-310 (-433 (-980 |#1|))) (-1191))) (-15 -4005 ((-658 (-310 (-433 (-980 |#1|)))) (-433 (-980 |#1|)))) (-15 -4005 ((-658 (-310 (-433 (-980 |#1|)))) (-310 (-433 (-980 |#1|))))) (-15 -3485 ((-658 (-658 (-980 |#1|))) (-658 (-433 (-980 |#1|))) (-658 (-1191))))) 
+((-3299 (((-658 (-658 |#1|)) (-658 (-658 |#1|)) (-658 (-658 (-658 |#1|)))) 38)) (-1347 (((-658 (-658 (-658 |#1|))) (-658 (-658 |#1|))) 24)) (-1406 (((-1198 (-658 |#1|)) (-658 |#1|)) 34)) (-2449 (((-658 (-658 |#1|)) (-658 |#1|)) 30)) (-1434 (((-2 (|:| |f1| (-658 |#1|)) (|:| |f2| (-658 (-658 (-658 |#1|)))) (|:| |f3| (-658 (-658 |#1|))) (|:| |f4| (-658 (-658 (-658 |#1|))))) (-658 (-658 (-658 |#1|)))) 37)) (-3161 (((-2 (|:| |f1| (-658 |#1|)) (|:| |f2| (-658 (-658 (-658 |#1|)))) (|:| |f3| (-658 (-658 |#1|))) (|:| |f4| (-658 (-658 (-658 |#1|))))) (-658 |#1|) (-658 (-658 (-658 |#1|))) (-658 (-658 |#1|)) (-658 (-658 (-658 |#1|))) (-658 (-658 (-658 |#1|))) (-658 (-658 (-658 |#1|)))) 36)) (-3457 (((-658 (-658 |#1|)) (-658 (-658 |#1|))) 28)) (-3183 (((-658 |#1|) (-658 |#1|)) 31)) (-1792 (((-658 (-658 (-658 |#1|))) (-658 |#1|) (-658 (-658 (-658 |#1|)))) 18)) (-3871 (((-658 (-658 (-658 |#1|))) (-1 (-141) |#1| |#1|) (-658 |#1|) (-658 (-658 (-658 |#1|)))) 15)) (-2615 (((-2 (|:| |fs| (-141)) (|:| |sd| (-658 |#1|)) (|:| |td| (-658 (-658 |#1|)))) (-1 (-141) |#1| |#1|) (-658 |#1|) (-658 (-658 |#1|))) 13)) (-3705 (((-658 (-658 |#1|)) (-658 (-658 (-658 |#1|)))) 39)) (-3564 (((-658 (-658 |#1|)) (-1198 (-658 |#1|))) 41))) 
+(((-1197 |#1|) (-10 -7 (-15 -2615 ((-2 (|:| |fs| (-141)) (|:| |sd| (-658 |#1|)) (|:| |td| (-658 (-658 |#1|)))) (-1 (-141) |#1| |#1|) (-658 |#1|) (-658 (-658 |#1|)))) (-15 -3871 ((-658 (-658 (-658 |#1|))) (-1 (-141) |#1| |#1|) (-658 |#1|) (-658 (-658 (-658 |#1|))))) (-15 -1792 ((-658 (-658 (-658 |#1|))) (-658 |#1|) (-658 (-658 (-658 |#1|))))) (-15 -3299 ((-658 (-658 |#1|)) (-658 (-658 |#1|)) (-658 (-658 (-658 |#1|))))) (-15 -3705 ((-658 (-658 |#1|)) (-658 (-658 (-658 |#1|))))) (-15 -3564 ((-658 (-658 |#1|)) (-1198 (-658 |#1|)))) (-15 -1347 ((-658 (-658 (-658 |#1|))) (-658 (-658 |#1|)))) (-15 -1406 ((-1198 (-658 |#1|)) (-658 |#1|))) (-15 -3457 ((-658 (-658 |#1|)) (-658 (-658 |#1|)))) (-15 -2449 ((-658 (-658 |#1|)) (-658 |#1|))) (-15 -3183 ((-658 |#1|) (-658 |#1|))) (-15 -3161 ((-2 (|:| |f1| (-658 |#1|)) (|:| |f2| (-658 (-658 (-658 |#1|)))) (|:| |f3| (-658 (-658 |#1|))) (|:| |f4| (-658 (-658 (-658 |#1|))))) (-658 |#1|) (-658 (-658 (-658 |#1|))) (-658 (-658 |#1|)) (-658 (-658 (-658 |#1|))) (-658 (-658 (-658 |#1|))) (-658 (-658 (-658 |#1|))))) (-15 -1434 ((-2 (|:| |f1| (-658 |#1|)) (|:| |f2| (-658 (-658 (-658 |#1|)))) (|:| |f3| (-658 (-658 |#1|))) (|:| |f4| (-658 (-658 (-658 |#1|))))) (-658 (-658 (-658 |#1|)))))) (-869)) (T -1197)) 
+((-1434 (*1 *2 *3) (-12 (-4 *4 (-869)) (-5 *2 (-2 (|:| |f1| (-658 *4)) (|:| |f2| (-658 (-658 (-658 *4)))) (|:| |f3| (-658 (-658 *4))) (|:| |f4| (-658 (-658 (-658 *4)))))) (-5 *1 (-1197 *4)) (-5 *3 (-658 (-658 (-658 *4)))))) (-3161 (*1 *2 *3 *4 *5 *4 *4 *4) (-12 (-4 *6 (-869)) (-5 *3 (-658 *6)) (-5 *5 (-658 *3)) (-5 *2 (-2 (|:| |f1| *3) (|:| |f2| (-658 *5)) (|:| |f3| *5) (|:| |f4| (-658 *5)))) (-5 *1 (-1197 *6)) (-5 *4 (-658 *5)))) (-3183 (*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-1197 *3)))) (-2449 (*1 *2 *3) (-12 (-4 *4 (-869)) (-5 *2 (-658 (-658 *4))) (-5 *1 (-1197 *4)) (-5 *3 (-658 *4)))) (-3457 (*1 *2 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-869)) (-5 *1 (-1197 *3)))) (-1406 (*1 *2 *3) (-12 (-4 *4 (-869)) (-5 *2 (-1198 (-658 *4))) (-5 *1 (-1197 *4)) (-5 *3 (-658 *4)))) (-1347 (*1 *2 *3) (-12 (-4 *4 (-869)) (-5 *2 (-658 (-658 (-658 *4)))) (-5 *1 (-1197 *4)) (-5 *3 (-658 (-658 *4))))) (-3564 (*1 *2 *3) (-12 (-5 *3 (-1198 (-658 *4))) (-4 *4 (-869)) (-5 *2 (-658 (-658 *4))) (-5 *1 (-1197 *4)))) (-3705 (*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-658 *4)))) (-5 *2 (-658 (-658 *4))) (-5 *1 (-1197 *4)) (-4 *4 (-869)))) (-3299 (*1 *2 *2 *3) (-12 (-5 *3 (-658 (-658 (-658 *4)))) (-5 *2 (-658 (-658 *4))) (-4 *4 (-869)) (-5 *1 (-1197 *4)))) (-1792 (*1 *2 *3 *2) (-12 (-5 *2 (-658 (-658 (-658 *4)))) (-5 *3 (-658 *4)) (-4 *4 (-869)) (-5 *1 (-1197 *4)))) (-3871 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-658 (-658 (-658 *5)))) (-5 *3 (-1 (-141) *5 *5)) (-5 *4 (-658 *5)) (-4 *5 (-869)) (-5 *1 (-1197 *5)))) (-2615 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-141) *6 *6)) (-4 *6 (-869)) (-5 *4 (-658 *6)) (-5 *2 (-2 (|:| |fs| (-141)) (|:| |sd| *4) (|:| |td| (-658 *4)))) (-5 *1 (-1197 *6)) (-5 *5 (-658 *4))))) 
+(-10 -7 (-15 -2615 ((-2 (|:| |fs| (-141)) (|:| |sd| (-658 |#1|)) (|:| |td| (-658 (-658 |#1|)))) (-1 (-141) |#1| |#1|) (-658 |#1|) (-658 (-658 |#1|)))) (-15 -3871 ((-658 (-658 (-658 |#1|))) (-1 (-141) |#1| |#1|) (-658 |#1|) (-658 (-658 (-658 |#1|))))) (-15 -1792 ((-658 (-658 (-658 |#1|))) (-658 |#1|) (-658 (-658 (-658 |#1|))))) (-15 -3299 ((-658 (-658 |#1|)) (-658 (-658 |#1|)) (-658 (-658 (-658 |#1|))))) (-15 -3705 ((-658 (-658 |#1|)) (-658 (-658 (-658 |#1|))))) (-15 -3564 ((-658 (-658 |#1|)) (-1198 (-658 |#1|)))) (-15 -1347 ((-658 (-658 (-658 |#1|))) (-658 (-658 |#1|)))) (-15 -1406 ((-1198 (-658 |#1|)) (-658 |#1|))) (-15 -3457 ((-658 (-658 |#1|)) (-658 (-658 |#1|)))) (-15 -2449 ((-658 (-658 |#1|)) (-658 |#1|))) (-15 -3183 ((-658 |#1|) (-658 |#1|))) (-15 -3161 ((-2 (|:| |f1| (-658 |#1|)) (|:| |f2| (-658 (-658 (-658 |#1|)))) (|:| |f3| (-658 (-658 |#1|))) (|:| |f4| (-658 (-658 (-658 |#1|))))) (-658 |#1|) (-658 (-658 (-658 |#1|))) (-658 (-658 |#1|)) (-658 (-658 (-658 |#1|))) (-658 (-658 (-658 |#1|))) (-658 (-658 (-658 |#1|))))) (-15 -1434 ((-2 (|:| |f1| (-658 |#1|)) (|:| |f2| (-658 (-658 (-658 |#1|)))) (|:| |f3| (-658 (-658 |#1|))) (|:| |f4| (-658 (-658 (-658 |#1|))))) (-658 (-658 (-658 |#1|)))))) 
+((-2292 (($ (-658 (-658 |#1|))) 9)) (-4601 (((-658 (-658 |#1|)) $) 10)) (-1683 (((-877) $) 25))) 
+(((-1198 |#1|) (-10 -8 (-15 -2292 ($ (-658 (-658 |#1|)))) (-15 -4601 ((-658 (-658 |#1|)) $)) (-15 -1683 ((-877) $))) (-1119)) (T -1198)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1198 *3)) (-4 *3 (-1119)))) (-4601 (*1 *2 *1) (-12 (-5 *2 (-658 (-658 *3))) (-5 *1 (-1198 *3)) (-4 *3 (-1119)))) (-2292 (*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-5 *1 (-1198 *3))))) 
+(-10 -8 (-15 -2292 ($ (-658 (-658 |#1|)))) (-15 -4601 ((-658 (-658 |#1|)) $)) (-15 -1683 ((-877) $))) 
+((-1641 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4016 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3898 (((-1285) $ |#1| |#1|) NIL (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#2| $ |#1| |#2|) NIL)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-2916 (((-3 |#2| "failed") |#1| $) NIL)) (-3001 (($) NIL T CONST)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) NIL)) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) NIL)) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) NIL)) (-2261 ((|#1| $) NIL (|has| |#1| (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-658 |#2|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-1813 ((|#1| $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-2840 (((-658 |#1|) $) NIL)) (-2396 (((-141) |#1| $) NIL)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3708 (((-658 |#1|) $) NIL)) (-3780 (((-141) |#1| $) NIL)) (-2951 (((-1137) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1918 ((|#2| $) NIL (|has| |#1| (-869)))) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL)) (-1892 (($ $ |#2|) NIL (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-1653 (($) NIL) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (((-790) |#2| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119)))) (((-790) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-1683 (((-877) $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) NIL)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) NIL (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) NIL (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) NIL (-3836 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| |#2| (-1119))))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1199 |#1| |#2|) (-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625))) (-1119) (-1119)) (T -1199)) 
+NIL 
+(-13 (-1202 |#1| |#2|) (-10 -7 (-6 -4625))) 
+((-4520 ((|#1| (-658 |#1|)) 32)) (-2917 ((|#1| |#1| (-592)) 18)) (-2695 (((-1187 |#1|) |#1| (-944)) 15))) 
+(((-1200 |#1|) (-10 -7 (-15 -4520 (|#1| (-658 |#1|))) (-15 -2695 ((-1187 |#1|) |#1| (-944))) (-15 -2917 (|#1| |#1| (-592)))) (-388)) (T -1200)) 
+((-2917 (*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-1200 *2)) (-4 *2 (-388)))) (-2695 (*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-5 *2 (-1187 *3)) (-5 *1 (-1200 *3)) (-4 *3 (-388)))) (-4520 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-5 *1 (-1200 *2)) (-4 *2 (-388))))) 
+(-10 -7 (-15 -4520 (|#1| (-658 |#1|))) (-15 -2695 ((-1187 |#1|) |#1| (-944))) (-15 -2917 (|#1| |#1| (-592)))) 
+((-4016 (($) 10) (($ (-658 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)))) 14)) (-4065 (($ (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) $) 60) (($ (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) $) NIL) (((-3 |#3| "failed") |#2| $) NIL)) (-4004 (((-658 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) $) 39) (((-658 |#3|) $) 41)) (-3987 (($ (-1 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) $) 52) (($ (-1 |#3| |#3|) $) 33)) (-2731 (($ (-1 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) $) 50) (($ (-1 |#3| |#3|) $) NIL) (($ (-1 |#3| |#3| |#3|) $ $) 38)) (-4137 (((-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) $) 53)) (-2113 (($ (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) $) 16)) (-3708 (((-658 |#2|) $) 19)) (-3780 (((-141) |#2| $) 58)) (-4050 (((-3 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) "failed") (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) $) 57)) (-2106 (((-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) $) 62)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) $) NIL) (((-141) (-1 (-141) |#3|) $) 65)) (-4210 (((-658 |#3|) $) 43)) (-3927 ((|#3| $ |#2|) 30) ((|#3| $ |#2| |#3|) 31)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) $) NIL) (((-790) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) $) NIL) (((-790) |#3| $) NIL) (((-790) (-1 (-141) |#3|) $) 66)) (-1683 (((-877) $) 27)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) $) NIL) (((-141) (-1 (-141) |#3|) $) 64)) (-3255 (((-141) $ $) 48))) 
+(((-1201 |#1| |#2| |#3|) (-10 -8 (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -2731 (|#1| (-1 |#3| |#3| |#3|) |#1| |#1|)) (-15 -4016 (|#1| (-658 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))))) (-15 -4016 (|#1|)) (-15 -2731 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3987 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#3|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#3|) |#1|)) (-15 -3452 ((-790) (-1 (-141) |#3|) |#1|)) (-15 -4004 ((-658 |#3|) |#1|)) (-15 -3452 ((-790) |#3| |#1|)) (-15 -3927 (|#3| |#1| |#2| |#3|)) (-15 -3927 (|#3| |#1| |#2|)) (-15 -4210 ((-658 |#3|) |#1|)) (-15 -3780 ((-141) |#2| |#1|)) (-15 -3708 ((-658 |#2|) |#1|)) (-15 -4065 ((-3 |#3| "failed") |#2| |#1|)) (-15 -4065 (|#1| (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -4065 (|#1| (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -4050 ((-3 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) "failed") (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -4137 ((-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -2113 (|#1| (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -2106 ((-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -3452 ((-790) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -4004 ((-658 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -3452 ((-790) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -3002 ((-141) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -3369 ((-141) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -3987 (|#1| (-1 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -2731 (|#1| (-1 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|))) (-1202 |#2| |#3|) (-1119) (-1119)) (T -1201)) 
+NIL 
+(-10 -8 (-15 -3255 ((-141) |#1| |#1|)) (-15 -1683 ((-877) |#1|)) (-15 -2731 (|#1| (-1 |#3| |#3| |#3|) |#1| |#1|)) (-15 -4016 (|#1| (-658 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))))) (-15 -4016 (|#1|)) (-15 -2731 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3987 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3369 ((-141) (-1 (-141) |#3|) |#1|)) (-15 -3002 ((-141) (-1 (-141) |#3|) |#1|)) (-15 -3452 ((-790) (-1 (-141) |#3|) |#1|)) (-15 -4004 ((-658 |#3|) |#1|)) (-15 -3452 ((-790) |#3| |#1|)) (-15 -3927 (|#3| |#1| |#2| |#3|)) (-15 -3927 (|#3| |#1| |#2|)) (-15 -4210 ((-658 |#3|) |#1|)) (-15 -3780 ((-141) |#2| |#1|)) (-15 -3708 ((-658 |#2|) |#1|)) (-15 -4065 ((-3 |#3| "failed") |#2| |#1|)) (-15 -4065 (|#1| (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -4065 (|#1| (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -4050 ((-3 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) "failed") (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -4137 ((-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -2113 (|#1| (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -2106 ((-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -3452 ((-790) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) |#1|)) (-15 -4004 ((-658 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -3452 ((-790) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -3002 ((-141) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -3369 ((-141) (-1 (-141) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -3987 (|#1| (-1 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|)) (-15 -2731 (|#1| (-1 (-2 (|:| -1350 |#2|) (|:| -3552 |#3|)) (-2 (|:| -1350 |#2|) (|:| -3552 |#3|))) |#1|))) 
+((-1641 (((-141) $ $) 18 (-3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4016 (($) 66) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 65)) (-3898 (((-1285) $ |#1| |#1|) 93 (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#2| $ |#1| |#2|) 67)) (-4125 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 42 (|has| $ (-6 -4625)))) (-3113 (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 52 (|has| $ (-6 -4625)))) (-2916 (((-3 |#2| "failed") |#1| $) 57)) (-3001 (($) 7 T CONST)) (-1360 (($ $) 55 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625))))) (-4065 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 44 (|has| $ (-6 -4625))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 43 (|has| $ (-6 -4625))) (((-3 |#2| "failed") |#1| $) 58)) (-4459 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 54 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 51 (|has| $ (-6 -4625)))) (-3657 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 53 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 50 (|has| $ (-6 -4625))) (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 49 (|has| $ (-6 -4625)))) (-1426 ((|#2| $ |#1| |#2|) 81 (|has| $ (-6 -4626)))) (-3959 ((|#2| $ |#1|) 82)) (-4004 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 30 (|has| $ (-6 -4625))) (((-658 |#2|) $) 73 (|has| $ (-6 -4625)))) (-4345 (((-141) $ (-790)) 9)) (-2261 ((|#1| $) 90 (|has| |#1| (-869)))) (-4467 (((-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 29 (|has| $ (-6 -4625))) (((-658 |#2|) $) 74 (|has| $ (-6 -4625)))) (-3133 (((-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 27 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-141) |#2| $) 76 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625))))) (-1813 ((|#1| $) 89 (|has| |#1| (-869)))) (-3987 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 34 (|has| $ (-6 -4626))) (($ (-1 |#2| |#2|) $) 69 (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 35) (($ (-1 |#2| |#2|) $) 68) (($ (-1 |#2| |#2| |#2|) $ $) 64)) (-2554 (((-141) $ (-790)) 10)) (-2685 (((-1173) $) 22 (-3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-2840 (((-658 |#1|) $) 59)) (-2396 (((-141) |#1| $) 60)) (-4137 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 36)) (-2113 (($ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 37)) (-3708 (((-658 |#1|) $) 87)) (-3780 (((-141) |#1| $) 86)) (-2951 (((-1137) $) 21 (-3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-1918 ((|#2| $) 91 (|has| |#1| (-869)))) (-4050 (((-3 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) "failed") (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 48)) (-1892 (($ $ |#2|) 92 (|has| $ (-6 -4626)))) (-2106 (((-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 38)) (-3002 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 32 (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) 71 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))))) 26 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-310 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 25 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) 24 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 23 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)))) (($ $ (-658 |#2|) (-658 |#2|)) 80 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ |#2| |#2|) 79 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-310 |#2|)) 78 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119)))) (($ $ (-658 (-310 |#2|))) 77 (-12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#2| $) 88 (-12 (|has| $ (-6 -4625)) (|has| |#2| (-1119))))) (-4210 (((-658 |#2|) $) 85)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#2| $ |#1|) 84) ((|#2| $ |#1| |#2|) 83)) (-1653 (($) 46) (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 45)) (-3452 (((-790) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 31 (|has| $ (-6 -4625))) (((-790) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) $) 28 (-12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119)) (|has| $ (-6 -4625)))) (((-790) |#2| $) 75 (-12 (|has| |#2| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#2|) $) 72 (|has| $ (-6 -4625)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 56 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))))) (-4466 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 47)) (-1683 (((-877) $) 20 (-3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-4560 (($ (-658 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) 39)) (-3369 (((-141) (-1 (-141) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) $) 33 (|has| $ (-6 -4625))) (((-141) (-1 (-141) |#2|) $) 70 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (-3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1202 |#1| |#2|) (-1311) (-1119) (-1119)) (T -1202)) 
+((-3932 (*1 *2 *1 *3 *2) (-12 (-4 *1 (-1202 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119)))) (-4016 (*1 *1) (-12 (-4 *1 (-1202 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) (-4016 (*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 *3) (|:| -3552 *4)))) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *1 (-1202 *3 *4)))) (-2731 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *4 *4 *4)) (-4 *1 (-1202 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(-13 (-629 |t#1| |t#2|) (-625 |t#1| |t#2|) (-10 -8 (-15 -3932 (|t#2| $ |t#1| |t#2|)) (-15 -4016 ($)) (-15 -4016 ($ (-658 (-2 (|:| -1350 |t#1|) (|:| -3552 |t#2|))))) (-15 -2731 ($ (-1 |t#2| |t#2| |t#2|) $ $)))) 
+(((-39) . T) ((-131 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-125) -3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-632 (-877)) -3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-175 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-633 (-565)) |has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-633 (-565))) ((-243 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-249 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-303 |#1| |#2|) . T) ((-305 |#1| |#2|) . T) ((-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) -12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-325 |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-523 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) . T) ((-523 |#2|) . T) ((-625 |#1| |#2|) . T) ((-547 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-2 (|:| -1350 |#1|) (|:| -3552 |#2|))) -12 (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-325 (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)))) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-547 |#2| |#2|) -12 (|has| |#2| (-325 |#2|)) (|has| |#2| (-1119))) ((-629 |#1| |#2|) . T) ((-1119) -3836 (|has| |#2| (-1119)) (|has| (-2 (|:| -1350 |#1|) (|:| -3552 |#2|)) (-1119))) ((-1225) . T)) 
+((-2626 (((-141)) 24)) (-1556 (((-1285) (-1173)) 26)) (-1720 (((-141)) 36)) (-3043 (((-1285)) 34)) (-3433 (((-1285) (-1173) (-1173)) 25)) (-4462 (((-141)) 37)) (-2113 (((-1285) |#1| |#2|) 44)) (-1719 (((-1285)) 20)) (-3367 (((-3 |#2| "failed") |#1|) 42)) (-3810 (((-1285)) 35))) 
+(((-1203 |#1| |#2|) (-10 -7 (-15 -1719 ((-1285))) (-15 -3433 ((-1285) (-1173) (-1173))) (-15 -1556 ((-1285) (-1173))) (-15 -3043 ((-1285))) (-15 -3810 ((-1285))) (-15 -2626 ((-141))) (-15 -1720 ((-141))) (-15 -4462 ((-141))) (-15 -3367 ((-3 |#2| "failed") |#1|)) (-15 -2113 ((-1285) |#1| |#2|))) (-1119) (-1119)) (T -1203)) 
+((-2113 (*1 *2 *3 *4) (-12 (-5 *2 (-1285)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-3367 (*1 *2 *3) (|partial| -12 (-4 *2 (-1119)) (-5 *1 (-1203 *3 *2)) (-4 *3 (-1119)))) (-4462 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-1720 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-2626 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-3810 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-3043 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) (-1556 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1203 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1119)))) (-3433 (*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1203 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1119)))) (-1719 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(-10 -7 (-15 -1719 ((-1285))) (-15 -3433 ((-1285) (-1173) (-1173))) (-15 -1556 ((-1285) (-1173))) (-15 -3043 ((-1285))) (-15 -3810 ((-1285))) (-15 -2626 ((-141))) (-15 -1720 ((-141))) (-15 -4462 ((-141))) (-15 -3367 ((-3 |#2| "failed") |#1|)) (-15 -2113 ((-1285) |#1| |#2|))) 
+((-1503 (((-1173) (-1173)) 18)) (-1955 (((-57) (-1173)) 21))) 
+(((-1204) (-10 -7 (-15 -1955 ((-57) (-1173))) (-15 -1503 ((-1173) (-1173))))) (T -1204)) 
+((-1503 (*1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1204)))) (-1955 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-57)) (-5 *1 (-1204))))) 
+(-10 -7 (-15 -1955 ((-57) (-1173))) (-15 -1503 ((-1173) (-1173)))) 
+((-1683 (((-1206) |#1|) 11))) 
+(((-1205 |#1|) (-10 -7 (-15 -1683 ((-1206) |#1|))) (-1119)) (T -1205)) 
+((-1683 (*1 *2 *3) (-12 (-5 *2 (-1206)) (-5 *1 (-1205 *3)) (-4 *3 (-1119))))) 
+(-10 -7 (-15 -1683 ((-1206) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2515 (((-658 (-1173)) $) 33)) (-2069 (((-658 (-1173)) $ (-658 (-1173))) 36)) (-2255 (((-658 (-1173)) $ (-658 (-1173))) 35)) (-1458 (((-658 (-1173)) $ (-658 (-1173))) 37)) (-3749 (((-658 (-1173)) $) 32)) (-3242 (($) 22)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4240 (((-658 (-1173)) $) 34)) (-3536 (((-1285) $ (-592)) 29) (((-1285) $) 30)) (-1778 (($ (-877) (-592)) 26) (($ (-877) (-592) (-877)) NIL)) (-1683 (((-877) $) 39) (($ (-877)) 24)) (-3255 (((-141) $ $) NIL))) 
+(((-1206) (-13 (-1119) (-10 -8 (-15 -1683 ($ (-877))) (-15 -1778 ($ (-877) (-592))) (-15 -1778 ($ (-877) (-592) (-877))) (-15 -3536 ((-1285) $ (-592))) (-15 -3536 ((-1285) $)) (-15 -4240 ((-658 (-1173)) $)) (-15 -2515 ((-658 (-1173)) $)) (-15 -3242 ($)) (-15 -3749 ((-658 (-1173)) $)) (-15 -1458 ((-658 (-1173)) $ (-658 (-1173)))) (-15 -2069 ((-658 (-1173)) $ (-658 (-1173)))) (-15 -2255 ((-658 (-1173)) $ (-658 (-1173))))))) (T -1206)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-1206)))) (-1778 (*1 *1 *2 *3) (-12 (-5 *2 (-877)) (-5 *3 (-592)) (-5 *1 (-1206)))) (-1778 (*1 *1 *2 *3 *2) (-12 (-5 *2 (-877)) (-5 *3 (-592)) (-5 *1 (-1206)))) (-3536 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-1206)))) (-3536 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1206)))) (-4240 (*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206)))) (-2515 (*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206)))) (-3242 (*1 *1) (-5 *1 (-1206))) (-3749 (*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206)))) (-1458 (*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206)))) (-2069 (*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206)))) (-2255 (*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206))))) 
+(-13 (-1119) (-10 -8 (-15 -1683 ($ (-877))) (-15 -1778 ($ (-877) (-592))) (-15 -1778 ($ (-877) (-592) (-877))) (-15 -3536 ((-1285) $ (-592))) (-15 -3536 ((-1285) $)) (-15 -4240 ((-658 (-1173)) $)) (-15 -2515 ((-658 (-1173)) $)) (-15 -3242 ($)) (-15 -3749 ((-658 (-1173)) $)) (-15 -1458 ((-658 (-1173)) $ (-658 (-1173)))) (-15 -2069 ((-658 (-1173)) $ (-658 (-1173)))) (-15 -2255 ((-658 (-1173)) $ (-658 (-1173)))))) 
+((-1641 (((-141) $ $) NIL)) (-2709 (((-1173) $ (-1173)) 15) (((-1173) $) 14)) (-3388 (((-1173) $ (-1173)) 13)) (-2820 (($ $ (-1173)) NIL)) (-2125 (((-3 (-1173) "failed") $) 11)) (-4169 (((-1173) $) 8)) (-3463 (((-3 (-1173) "failed") $) 12)) (-4393 (((-1173) $) 9)) (-1774 (($ (-414)) NIL) (($ (-414) (-1173)) NIL)) (-4095 (((-414) $) NIL)) (-2685 (((-1173) $) NIL)) (-2690 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4342 (((-1285) $) NIL)) (-1568 (((-141) $) 17)) (-1683 (((-877) $) NIL)) (-2607 (($ $) NIL)) (-3255 (((-141) $ $) NIL))) 
+(((-1207) (-13 (-389 (-414) (-1173)) (-10 -8 (-15 -2709 ((-1173) $ (-1173))) (-15 -2709 ((-1173) $)) (-15 -4169 ((-1173) $)) (-15 -2125 ((-3 (-1173) "failed") $)) (-15 -3463 ((-3 (-1173) "failed") $)) (-15 -1568 ((-141) $))))) (T -1207)) 
+((-2709 (*1 *2 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1207)))) (-2709 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1207)))) (-4169 (*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1207)))) (-2125 (*1 *2 *1) (|partial| -12 (-5 *2 (-1173)) (-5 *1 (-1207)))) (-3463 (*1 *2 *1) (|partial| -12 (-5 *2 (-1173)) (-5 *1 (-1207)))) (-1568 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1207))))) 
+(-13 (-389 (-414) (-1173)) (-10 -8 (-15 -2709 ((-1173) $ (-1173))) (-15 -2709 ((-1173) $)) (-15 -4169 ((-1173) $)) (-15 -2125 ((-3 (-1173) "failed") $)) (-15 -3463 ((-3 (-1173) "failed") $)) (-15 -1568 ((-141) $)))) 
+((-3940 (((-3 (-592) "failed") |#1|) 19)) (-4071 (((-3 (-592) "failed") |#1|) 13)) (-3756 (((-592) (-1173)) 28))) 
+(((-1208 |#1|) (-10 -7 (-15 -3940 ((-3 (-592) "failed") |#1|)) (-15 -4071 ((-3 (-592) "failed") |#1|)) (-15 -3756 ((-592) (-1173)))) (-1075)) (T -1208)) 
+((-3756 (*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-592)) (-5 *1 (-1208 *4)) (-4 *4 (-1075)))) (-4071 (*1 *2 *3) (|partial| -12 (-5 *2 (-592)) (-5 *1 (-1208 *3)) (-4 *3 (-1075)))) (-3940 (*1 *2 *3) (|partial| -12 (-5 *2 (-592)) (-5 *1 (-1208 *3)) (-4 *3 (-1075))))) 
+(-10 -7 (-15 -3940 ((-3 (-592) "failed") |#1|)) (-15 -4071 ((-3 (-592) "failed") |#1|)) (-15 -3756 ((-592) (-1173)))) 
+((-4091 (((-1150 (-237))) 8))) 
+(((-1209) (-10 -7 (-15 -4091 ((-1150 (-237)))))) (T -1209)) 
+((-4091 (*1 *2) (-12 (-5 *2 (-1150 (-237))) (-5 *1 (-1209))))) 
+(-10 -7 (-15 -4091 ((-1150 (-237))))) 
+((-1435 (($) 11)) (-1630 (($ $) 35)) (-1617 (($ $) 33)) (-1533 (($ $) 25)) (-1642 (($ $) 17)) (-2892 (($ $) 15)) (-1636 (($ $) 19)) (-1552 (($ $) 30)) (-1624 (($ $) 34)) (-1540 (($ $) 29))) 
+(((-1210 |#1|) (-10 -8 (-15 -1435 (|#1|)) (-15 -1630 (|#1| |#1|)) (-15 -1617 (|#1| |#1|)) (-15 -1642 (|#1| |#1|)) (-15 -2892 (|#1| |#1|)) (-15 -1636 (|#1| |#1|)) (-15 -1624 (|#1| |#1|)) (-15 -1533 (|#1| |#1|)) (-15 -1552 (|#1| |#1|)) (-15 -1540 (|#1| |#1|))) (-1211)) (T -1210)) 
+NIL 
+(-10 -8 (-15 -1435 (|#1|)) (-15 -1630 (|#1| |#1|)) (-15 -1617 (|#1| |#1|)) (-15 -1642 (|#1| |#1|)) (-15 -2892 (|#1| |#1|)) (-15 -1636 (|#1| |#1|)) (-15 -1624 (|#1| |#1|)) (-15 -1533 (|#1| |#1|)) (-15 -1552 (|#1| |#1|)) (-15 -1540 (|#1| |#1|))) 
+((-1588 (($ $) 26)) (-1507 (($ $) 11)) (-1575 (($ $) 27)) (-1495 (($ $) 10)) (-1601 (($ $) 28)) (-1521 (($ $) 9)) (-1435 (($) 16)) (-4546 (($ $) 19)) (-1430 (($ $) 18)) (-1609 (($ $) 29)) (-1527 (($ $) 8)) (-1594 (($ $) 30)) (-1515 (($ $) 7)) (-1581 (($ $) 31)) (-1501 (($ $) 6)) (-1630 (($ $) 20)) (-1546 (($ $) 32)) (-1617 (($ $) 21)) (-1533 (($ $) 33)) (-1642 (($ $) 22)) (-1559 (($ $) 34)) (-2892 (($ $) 23)) (-1567 (($ $) 35)) (-1636 (($ $) 24)) (-1552 (($ $) 36)) (-1624 (($ $) 25)) (-1540 (($ $) 37)) (** (($ $ $) 17))) 
+(((-1211) (-1311)) (T -1211)) 
+((-1435 (*1 *1) (-4 *1 (-1211)))) 
+(-13 (-1214) (-116) (-526) (-40) (-301) (-10 -8 (-15 -1435 ($)))) 
+(((-40) . T) ((-116) . T) ((-301) . T) ((-526) . T) ((-1214) . T)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-2324 ((|#1| $) 17)) (-2836 (($ |#1| (-658 $)) 23) (($ (-658 |#1|)) 27) (($ |#1|) 25)) (-2126 (((-141) $ (-790)) 46)) (-3047 ((|#1| $ |#1|) 14 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 13 (|has| $ (-6 -4626)))) (-3001 (($) NIL T CONST)) (-4004 (((-658 |#1|) $) 50 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 41)) (-3055 (((-141) $ $) 32 (|has| |#1| (-1119)))) (-4345 (((-141) $ (-790)) 39)) (-4467 (((-658 |#1|) $) 51 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 49 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-3987 (($ (-1 |#1| |#1|) $) 24 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 22)) (-2554 (((-141) $ (-790)) 38)) (-4063 (((-658 |#1|) $) 36)) (-3683 (((-141) $) 35)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-3002 (((-141) (-1 (-141) |#1|) $) 48 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 73)) (-2943 (((-141) $) 9)) (-2890 (($) 10)) (-3927 ((|#1| $ "value") NIL)) (-2920 (((-592) $ $) 31)) (-1996 (((-658 $) $) 57)) (-1620 (((-141) $ $) 75)) (-3713 (((-658 $) $) 70)) (-2511 (($ $) 71)) (-3228 (((-141) $) 54)) (-3452 (((-790) (-1 (-141) |#1|) $) 20 (|has| $ (-6 -4625))) (((-790) |#1| $) 16 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4599 (($ $) 56)) (-1683 (((-877) $) 59 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 12)) (-2936 (((-141) $ $) 29 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 47 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 28 (|has| |#1| (-1119)))) (-1699 (((-790) $) 37 (|has| $ (-6 -4625))))) 
+(((-1212 |#1|) (-13 (-1038 |#1|) (-10 -8 (-6 -4625) (-6 -4626) (-15 -2836 ($ |#1| (-658 $))) (-15 -2836 ($ (-658 |#1|))) (-15 -2836 ($ |#1|)) (-15 -3228 ((-141) $)) (-15 -2511 ($ $)) (-15 -3713 ((-658 $) $)) (-15 -1620 ((-141) $ $)) (-15 -1996 ((-658 $) $)))) (-1119)) (T -1212)) 
+((-3228 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1212 *3)) (-4 *3 (-1119)))) (-2836 (*1 *1 *2 *3) (-12 (-5 *3 (-658 (-1212 *2))) (-5 *1 (-1212 *2)) (-4 *2 (-1119)))) (-2836 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1212 *3)))) (-2836 (*1 *1 *2) (-12 (-5 *1 (-1212 *2)) (-4 *2 (-1119)))) (-2511 (*1 *1 *1) (-12 (-5 *1 (-1212 *2)) (-4 *2 (-1119)))) (-3713 (*1 *2 *1) (-12 (-5 *2 (-658 (-1212 *3))) (-5 *1 (-1212 *3)) (-4 *3 (-1119)))) (-1620 (*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1212 *3)) (-4 *3 (-1119)))) (-1996 (*1 *2 *1) (-12 (-5 *2 (-658 (-1212 *3))) (-5 *1 (-1212 *3)) (-4 *3 (-1119))))) 
+(-13 (-1038 |#1|) (-10 -8 (-6 -4625) (-6 -4626) (-15 -2836 ($ |#1| (-658 $))) (-15 -2836 ($ (-658 |#1|))) (-15 -2836 ($ |#1|)) (-15 -3228 ((-141) $)) (-15 -2511 ($ $)) (-15 -3713 ((-658 $) $)) (-15 -1620 ((-141) $ $)) (-15 -1996 ((-658 $) $)))) 
+((-1507 (($ $) 15)) (-1521 (($ $) 12)) (-1527 (($ $) 10)) (-1515 (($ $) 17))) 
+(((-1213 |#1|) (-10 -8 (-15 -1515 (|#1| |#1|)) (-15 -1527 (|#1| |#1|)) (-15 -1521 (|#1| |#1|)) (-15 -1507 (|#1| |#1|))) (-1214)) (T -1213)) 
+NIL 
+(-10 -8 (-15 -1515 (|#1| |#1|)) (-15 -1527 (|#1| |#1|)) (-15 -1521 (|#1| |#1|)) (-15 -1507 (|#1| |#1|))) 
+((-1507 (($ $) 11)) (-1495 (($ $) 10)) (-1521 (($ $) 9)) (-1527 (($ $) 8)) (-1515 (($ $) 7)) (-1501 (($ $) 6))) 
+(((-1214) (-1311)) (T -1214)) 
+((-1507 (*1 *1 *1) (-4 *1 (-1214))) (-1495 (*1 *1 *1) (-4 *1 (-1214))) (-1521 (*1 *1 *1) (-4 *1 (-1214))) (-1527 (*1 *1 *1) (-4 *1 (-1214))) (-1515 (*1 *1 *1) (-4 *1 (-1214))) (-1501 (*1 *1 *1) (-4 *1 (-1214)))) 
+(-13 (-10 -8 (-15 -1501 ($ $)) (-15 -1515 ($ $)) (-15 -1527 ($ $)) (-15 -1521 ($ $)) (-15 -1495 ($ $)) (-15 -1507 ($ $)))) 
+((-1519 ((|#2| |#2|) 85)) (-2952 (((-141) |#2|) 25)) (-3996 ((|#2| |#2|) 29)) (-4506 ((|#2| |#2|) 31)) (-1689 ((|#2| |#2| (-1191)) 79) ((|#2| |#2|) 80)) (-2438 (((-191 |#2|) |#2|) 27)) (-2771 ((|#2| |#2| (-1191)) 81) ((|#2| |#2|) 82))) 
+(((-1215 |#1| |#2|) (-10 -7 (-15 -1689 (|#2| |#2|)) (-15 -1689 (|#2| |#2| (-1191))) (-15 -2771 (|#2| |#2|)) (-15 -2771 (|#2| |#2| (-1191))) (-15 -1519 (|#2| |#2|)) (-15 -3996 (|#2| |#2|)) (-15 -4506 (|#2| |#2|)) (-15 -2952 ((-141) |#2|)) (-15 -2438 ((-191 |#2|) |#2|))) (-13 (-477) (-869) (-1065 (-592)) (-654 (-592))) (-13 (-27) (-1211) (-456 |#1|))) (T -1215)) 
+((-2438 (*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-191 *3)) (-5 *1 (-1215 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) (-2952 (*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-141)) (-5 *1 (-1215 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) (-4506 (*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) (-3996 (*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) (-1519 (*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) (-2771 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))))) (-2771 (*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) (-1689 (*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))))) (-1689 (*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3)))))) 
+(-10 -7 (-15 -1689 (|#2| |#2|)) (-15 -1689 (|#2| |#2| (-1191))) (-15 -2771 (|#2| |#2|)) (-15 -2771 (|#2| |#2| (-1191))) (-15 -1519 (|#2| |#2|)) (-15 -3996 (|#2| |#2|)) (-15 -4506 (|#2| |#2|)) (-15 -2952 ((-141) |#2|)) (-15 -2438 ((-191 |#2|) |#2|))) 
+((-4252 ((|#4| |#4| |#1|) 27)) (-2430 ((|#4| |#4| |#1|) 28))) 
+(((-1216 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4252 (|#4| |#4| |#1|)) (-15 -2430 (|#4| |#4| |#1|))) (-582) (-399 |#1|) (-399 |#1|) (-704 |#1| |#2| |#3|)) (T -1216)) 
+((-2430 (*1 *2 *2 *3) (-12 (-4 *3 (-582)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-1216 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) (-4252 (*1 *2 *2 *3) (-12 (-4 *3 (-582)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-1216 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(-10 -7 (-15 -4252 (|#4| |#4| |#1|)) (-15 -2430 (|#4| |#4| |#1|))) 
+((-3527 ((|#2| |#2|) 144)) (-2634 ((|#2| |#2|) 142)) (-3889 ((|#2| |#2|) 134)) (-4498 ((|#2| |#2|) 131)) (-4425 ((|#2| |#2|) 139)) (-3953 ((|#2| |#2|) 127)) (-1785 ((|#2| |#2|) 59)) (-3205 ((|#2| |#2|) 109)) (-1849 ((|#2| |#2|) 89)) (-2980 ((|#2| |#2|) 141)) (-2453 ((|#2| |#2|) 129)) (-3285 ((|#2| |#2|) 149)) (-4600 ((|#2| |#2|) 147)) (-4038 ((|#2| |#2|) 148)) (-2456 ((|#2| |#2|) 146)) (-4108 ((|#2| |#2|) 158)) (-1886 ((|#2| |#2|) 48 (-12 (|has| |#2| (-633 (-914 |#1|))) (|has| |#2| (-908 |#1|)) (|has| |#1| (-633 (-914 |#1|))) (|has| |#1| (-908 |#1|))))) (-2216 ((|#2| |#2|) 90)) (-1534 ((|#2| |#2|) 150)) (-3098 ((|#2| |#2|) 151)) (-3117 ((|#2| |#2|) 140)) (-2419 ((|#2| |#2|) 128)) (-3935 ((|#2| |#2|) 145)) (-1989 ((|#2| |#2|) 143)) (-1931 ((|#2| |#2|) 135)) (-2240 ((|#2| |#2|) 133)) (-2575 ((|#2| |#2|) 137)) (-2702 ((|#2| |#2|) 125))) 
+(((-1217 |#1| |#2|) (-10 -7 (-15 -3098 (|#2| |#2|)) (-15 -1849 (|#2| |#2|)) (-15 -4108 (|#2| |#2|)) (-15 -3205 (|#2| |#2|)) (-15 -1785 (|#2| |#2|)) (-15 -2216 (|#2| |#2|)) (-15 -1534 (|#2| |#2|)) (-15 -2702 (|#2| |#2|)) (-15 -2575 (|#2| |#2|)) (-15 -1931 (|#2| |#2|)) (-15 -3935 (|#2| |#2|)) (-15 -2419 (|#2| |#2|)) (-15 -3117 (|#2| |#2|)) (-15 -2453 (|#2| |#2|)) (-15 -2980 (|#2| |#2|)) (-15 -3953 (|#2| |#2|)) (-15 -4425 (|#2| |#2|)) (-15 -3889 (|#2| |#2|)) (-15 -3527 (|#2| |#2|)) (-15 -4498 (|#2| |#2|)) (-15 -2634 (|#2| |#2|)) (-15 -2240 (|#2| |#2|)) (-15 -1989 (|#2| |#2|)) (-15 -2456 (|#2| |#2|)) (-15 -4600 (|#2| |#2|)) (-15 -4038 (|#2| |#2|)) (-15 -3285 (|#2| |#2|)) (IF (|has| |#1| (-908 |#1|)) (IF (|has| |#1| (-633 (-914 |#1|))) (IF (|has| |#2| (-633 (-914 |#1|))) (IF (|has| |#2| (-908 |#1|)) (-15 -1886 (|#2| |#2|)) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) (-13 (-869) (-477)) (-13 (-456 |#1|) (-1211))) (T -1217)) 
+((-1886 (*1 *2 *2) (-12 (-4 *3 (-633 (-914 *3))) (-4 *3 (-908 *3)) (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-633 (-914 *3))) (-4 *2 (-908 *3)) (-4 *2 (-13 (-456 *3) (-1211))))) (-3285 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-4038 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-4600 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2456 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-1989 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2240 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2634 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-4498 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-3527 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-3889 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-4425 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-3953 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2980 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2453 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-3117 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2419 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-3935 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-1931 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2575 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2702 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-1534 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-2216 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-1785 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-3205 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-4108 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-1849 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) (-3098 (*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(-10 -7 (-15 -3098 (|#2| |#2|)) (-15 -1849 (|#2| |#2|)) (-15 -4108 (|#2| |#2|)) (-15 -3205 (|#2| |#2|)) (-15 -1785 (|#2| |#2|)) (-15 -2216 (|#2| |#2|)) (-15 -1534 (|#2| |#2|)) (-15 -2702 (|#2| |#2|)) (-15 -2575 (|#2| |#2|)) (-15 -1931 (|#2| |#2|)) (-15 -3935 (|#2| |#2|)) (-15 -2419 (|#2| |#2|)) (-15 -3117 (|#2| |#2|)) (-15 -2453 (|#2| |#2|)) (-15 -2980 (|#2| |#2|)) (-15 -3953 (|#2| |#2|)) (-15 -4425 (|#2| |#2|)) (-15 -3889 (|#2| |#2|)) (-15 -3527 (|#2| |#2|)) (-15 -4498 (|#2| |#2|)) (-15 -2634 (|#2| |#2|)) (-15 -2240 (|#2| |#2|)) (-15 -1989 (|#2| |#2|)) (-15 -2456 (|#2| |#2|)) (-15 -4600 (|#2| |#2|)) (-15 -4038 (|#2| |#2|)) (-15 -3285 (|#2| |#2|)) (IF (|has| |#1| (-908 |#1|)) (IF (|has| |#1| (-633 (-914 |#1|))) (IF (|has| |#2| (-633 (-914 |#1|))) (IF (|has| |#2| (-908 |#1|)) (-15 -1886 (|#2| |#2|)) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) 
+((-4135 (((-141) |#5| $) 59) (((-141) $) 101)) (-2244 ((|#5| |#5| $) 74)) (-3113 (($ (-1 (-141) |#5|) $) NIL) (((-3 |#5| "failed") $ |#4|) 118)) (-1903 (((-658 |#5|) (-658 |#5|) $ (-1 |#5| |#5| |#5|) (-1 (-141) |#5| |#5|)) 72)) (-4368 (((-3 $ "failed") (-658 |#5|)) 125)) (-1366 (((-3 $ "failed") $) 111)) (-2226 ((|#5| |#5| $) 93)) (-2172 (((-141) |#5| $ (-1 (-141) |#5| |#5|)) 30)) (-3092 ((|#5| |#5| $) 97)) (-3657 ((|#5| (-1 |#5| |#5| |#5|) $ |#5| |#5|) NIL) ((|#5| (-1 |#5| |#5| |#5|) $ |#5|) NIL) ((|#5| (-1 |#5| |#5| |#5|) $) NIL) ((|#5| |#5| $ (-1 |#5| |#5| |#5|) (-1 (-141) |#5| |#5|)) 68)) (-1643 (((-2 (|:| -3511 (-658 |#5|)) (|:| -1774 (-658 |#5|))) $) 54)) (-2479 (((-141) |#5| $) 57) (((-141) $) 102)) (-3259 ((|#4| $) 107)) (-4255 (((-3 |#5| "failed") $) 109)) (-1712 (((-658 |#5|) $) 48)) (-2346 (((-141) |#5| $) 66) (((-141) $) 106)) (-1751 ((|#5| |#5| $) 80)) (-3085 (((-141) $ $) 26)) (-4442 (((-141) |#5| $) 62) (((-141) $) 104)) (-1803 ((|#5| |#5| $) 77)) (-1918 (((-3 |#5| "failed") $) 108)) (-2807 (($ $ |#5|) 126)) (-4525 (((-790) $) 51)) (-4466 (($ (-658 |#5|)) 123)) (-2613 (($ $ |#4|) 121)) (-4152 (($ $ |#4|) 120)) (-2965 (($ $) 119)) (-1683 (((-877) $) NIL) (((-658 |#5|) $) 112)) (-1857 (((-790) $) 129)) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#5|))) "failed") (-658 |#5|) (-1 (-141) |#5| |#5|)) 42) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#5|))) "failed") (-658 |#5|) (-1 (-141) |#5|) (-1 (-141) |#5| |#5|)) 44)) (-4408 (((-141) $ (-1 (-141) |#5| (-658 |#5|))) 99)) (-1596 (((-658 |#4|) $) 114)) (-3069 (((-141) |#4| $) 117)) (-3255 (((-141) $ $) 19))) 
+(((-1218 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -1857 ((-790) |#1|)) (-15 -2807 (|#1| |#1| |#5|)) (-15 -3113 ((-3 |#5| "failed") |#1| |#4|)) (-15 -3069 ((-141) |#4| |#1|)) (-15 -1596 ((-658 |#4|) |#1|)) (-15 -1366 ((-3 |#1| "failed") |#1|)) (-15 -4255 ((-3 |#5| "failed") |#1|)) (-15 -1918 ((-3 |#5| "failed") |#1|)) (-15 -3092 (|#5| |#5| |#1|)) (-15 -2965 (|#1| |#1|)) (-15 -2226 (|#5| |#5| |#1|)) (-15 -1751 (|#5| |#5| |#1|)) (-15 -1803 (|#5| |#5| |#1|)) (-15 -2244 (|#5| |#5| |#1|)) (-15 -1903 ((-658 |#5|) (-658 |#5|) |#1| (-1 |#5| |#5| |#5|) (-1 (-141) |#5| |#5|))) (-15 -3657 (|#5| |#5| |#1| (-1 |#5| |#5| |#5|) (-1 (-141) |#5| |#5|))) (-15 -2346 ((-141) |#1|)) (-15 -4442 ((-141) |#1|)) (-15 -4135 ((-141) |#1|)) (-15 -4408 ((-141) |#1| (-1 (-141) |#5| (-658 |#5|)))) (-15 -2346 ((-141) |#5| |#1|)) (-15 -4442 ((-141) |#5| |#1|)) (-15 -4135 ((-141) |#5| |#1|)) (-15 -2172 ((-141) |#5| |#1| (-1 (-141) |#5| |#5|))) (-15 -2479 ((-141) |#1|)) (-15 -2479 ((-141) |#5| |#1|)) (-15 -1643 ((-2 (|:| -3511 (-658 |#5|)) (|:| -1774 (-658 |#5|))) |#1|)) (-15 -4525 ((-790) |#1|)) (-15 -1712 ((-658 |#5|) |#1|)) (-15 -1387 ((-3 (-2 (|:| |bas| |#1|) (|:| -3349 (-658 |#5|))) "failed") (-658 |#5|) (-1 (-141) |#5|) (-1 (-141) |#5| |#5|))) (-15 -1387 ((-3 (-2 (|:| |bas| |#1|) (|:| -3349 (-658 |#5|))) "failed") (-658 |#5|) (-1 (-141) |#5| |#5|))) (-15 -3085 ((-141) |#1| |#1|)) (-15 -2613 (|#1| |#1| |#4|)) (-15 -4152 (|#1| |#1| |#4|)) (-15 -3259 (|#4| |#1|)) (-15 -4368 ((-3 |#1| "failed") (-658 |#5|))) (-15 -1683 ((-658 |#5|) |#1|)) (-15 -4466 (|#1| (-658 |#5|))) (-15 -3657 (|#5| (-1 |#5| |#5| |#5|) |#1|)) (-15 -3657 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5|)) (-15 -3113 (|#1| (-1 (-141) |#5|) |#1|)) (-15 -3657 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5| |#5|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) (-1219 |#2| |#3| |#4| |#5|) (-582) (-815) (-869) (-1089 |#2| |#3| |#4|)) (T -1218)) 
+NIL 
+(-10 -8 (-15 -1857 ((-790) |#1|)) (-15 -2807 (|#1| |#1| |#5|)) (-15 -3113 ((-3 |#5| "failed") |#1| |#4|)) (-15 -3069 ((-141) |#4| |#1|)) (-15 -1596 ((-658 |#4|) |#1|)) (-15 -1366 ((-3 |#1| "failed") |#1|)) (-15 -4255 ((-3 |#5| "failed") |#1|)) (-15 -1918 ((-3 |#5| "failed") |#1|)) (-15 -3092 (|#5| |#5| |#1|)) (-15 -2965 (|#1| |#1|)) (-15 -2226 (|#5| |#5| |#1|)) (-15 -1751 (|#5| |#5| |#1|)) (-15 -1803 (|#5| |#5| |#1|)) (-15 -2244 (|#5| |#5| |#1|)) (-15 -1903 ((-658 |#5|) (-658 |#5|) |#1| (-1 |#5| |#5| |#5|) (-1 (-141) |#5| |#5|))) (-15 -3657 (|#5| |#5| |#1| (-1 |#5| |#5| |#5|) (-1 (-141) |#5| |#5|))) (-15 -2346 ((-141) |#1|)) (-15 -4442 ((-141) |#1|)) (-15 -4135 ((-141) |#1|)) (-15 -4408 ((-141) |#1| (-1 (-141) |#5| (-658 |#5|)))) (-15 -2346 ((-141) |#5| |#1|)) (-15 -4442 ((-141) |#5| |#1|)) (-15 -4135 ((-141) |#5| |#1|)) (-15 -2172 ((-141) |#5| |#1| (-1 (-141) |#5| |#5|))) (-15 -2479 ((-141) |#1|)) (-15 -2479 ((-141) |#5| |#1|)) (-15 -1643 ((-2 (|:| -3511 (-658 |#5|)) (|:| -1774 (-658 |#5|))) |#1|)) (-15 -4525 ((-790) |#1|)) (-15 -1712 ((-658 |#5|) |#1|)) (-15 -1387 ((-3 (-2 (|:| |bas| |#1|) (|:| -3349 (-658 |#5|))) "failed") (-658 |#5|) (-1 (-141) |#5|) (-1 (-141) |#5| |#5|))) (-15 -1387 ((-3 (-2 (|:| |bas| |#1|) (|:| -3349 (-658 |#5|))) "failed") (-658 |#5|) (-1 (-141) |#5| |#5|))) (-15 -3085 ((-141) |#1| |#1|)) (-15 -2613 (|#1| |#1| |#4|)) (-15 -4152 (|#1| |#1| |#4|)) (-15 -3259 (|#4| |#1|)) (-15 -4368 ((-3 |#1| "failed") (-658 |#5|))) (-15 -1683 ((-658 |#5|) |#1|)) (-15 -4466 (|#1| (-658 |#5|))) (-15 -3657 (|#5| (-1 |#5| |#5| |#5|) |#1|)) (-15 -3657 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5|)) (-15 -3113 (|#1| (-1 (-141) |#5|) |#1|)) (-15 -3657 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5| |#5|)) (-15 -1683 ((-877) |#1|)) (-15 -3255 ((-141) |#1| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) 78)) (-2248 (((-658 $) (-658 |#4|)) 79)) (-4085 (((-658 |#3|) $) 32)) (-4325 (((-141) $) 25)) (-2988 (((-141) $) 16 (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) 94) (((-141) $) 90)) (-2244 ((|#4| |#4| $) 85)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) 26)) (-2126 (((-141) $ (-790)) 43)) (-3113 (($ (-1 (-141) |#4|) $) 64 (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) 72)) (-3001 (($) 44 T CONST)) (-3239 (((-141) $) 21 (|has| |#1| (-582)))) (-3478 (((-141) $ $) 23 (|has| |#1| (-582)))) (-2398 (((-141) $ $) 22 (|has| |#1| (-582)))) (-1529 (((-141) $) 24 (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 86)) (-4521 (((-658 |#4|) (-658 |#4|) $) 17 (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) 18 (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) 35)) (-2400 (($ (-658 |#4|)) 34)) (-1366 (((-3 $ "failed") $) 75)) (-2226 ((|#4| |#4| $) 82)) (-1360 (($ $) 67 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#4| $) 66 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#4|) $) 63 (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) 95)) (-3092 ((|#4| |#4| $) 80)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 87)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) 98)) (-4004 (((-658 |#4|) $) 51 (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) 97) (((-141) $) 96)) (-3259 ((|#3| $) 33)) (-4345 (((-141) $ (-790)) 42)) (-4467 (((-658 |#4|) $) 52 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) 54 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) 46)) (-2290 (((-658 |#3|) $) 31)) (-2645 (((-141) |#3| $) 30)) (-2554 (((-141) $ (-790)) 41)) (-2685 (((-1173) $) 9)) (-4255 (((-3 |#4| "failed") $) 76)) (-1712 (((-658 |#4|) $) 100)) (-2346 (((-141) |#4| $) 92) (((-141) $) 88)) (-1751 ((|#4| |#4| $) 83)) (-3085 (((-141) $ $) 103)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) 93) (((-141) $) 89)) (-1803 ((|#4| |#4| $) 84)) (-2951 (((-1137) $) 10)) (-1918 (((-3 |#4| "failed") $) 77)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) 60)) (-2778 (((-3 $ "failed") $ |#4|) 71)) (-2807 (($ $ |#4|) 70)) (-3002 (((-141) (-1 (-141) |#4|) $) 49 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) 58 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) 56 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) 55 (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) 37)) (-2943 (((-141) $) 40)) (-2890 (($) 39)) (-4525 (((-790) $) 99)) (-3452 (((-790) |#4| $) 53 (-12 (|has| |#4| (-1119)) (|has| $ (-6 -4625)))) (((-790) (-1 (-141) |#4|) $) 50 (|has| $ (-6 -4625)))) (-4599 (($ $) 38)) (-1778 (((-565) $) 68 (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) 59)) (-2613 (($ $ |#3|) 27)) (-4152 (($ $ |#3|) 29)) (-2965 (($ $) 81)) (-2507 (($ $ |#3|) 28)) (-1683 (((-877) $) 11) (((-658 |#4|) $) 36)) (-1857 (((-790) $) 69 (|has| |#3| (-394)))) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) 101)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) 91)) (-3369 (((-141) (-1 (-141) |#4|) $) 48 (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) 74)) (-3069 (((-141) |#3| $) 73)) (-3255 (((-141) $ $) 6)) (-1699 (((-790) $) 45 (|has| $ (-6 -4625))))) 
+(((-1219 |#1| |#2| |#3| |#4|) (-1311) (-582) (-815) (-869) (-1089 |t#1| |t#2| |t#3|)) (T -1219)) 
+((-3085 (*1 *2 *1 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) (-1387 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1 (-141) *8 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |bas| *1) (|:| -3349 (-658 *8)))) (-5 *3 (-658 *8)) (-4 *1 (-1219 *5 *6 *7 *8)))) (-1387 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 (-141) *9)) (-5 *5 (-1 (-141) *9 *9)) (-4 *9 (-1089 *6 *7 *8)) (-4 *6 (-582)) (-4 *7 (-815)) (-4 *8 (-869)) (-5 *2 (-2 (|:| |bas| *1) (|:| -3349 (-658 *9)))) (-5 *3 (-658 *9)) (-4 *1 (-1219 *6 *7 *8 *9)))) (-1712 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-658 *6)))) (-4525 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-790)))) (-1643 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-2 (|:| -3511 (-658 *6)) (|:| -1774 (-658 *6)))))) (-2479 (*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *6 *3)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-2479 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) (-2172 (*1 *2 *3 *1 *4) (-12 (-5 *4 (-1 (-141) *3 *3)) (-4 *1 (-1219 *5 *6 *7 *3)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-141)))) (-4135 (*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *6 *3)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-4442 (*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *6 *3)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-2346 (*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *6 *3)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-4408 (*1 *2 *1 *3) (-12 (-5 *3 (-1 (-141) *7 (-658 *7))) (-4 *1 (-1219 *4 *5 *6 *7)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)))) (-4135 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) (-4442 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) (-2346 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) (-3657 (*1 *2 *2 *1 *3 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *4 (-1 (-141) *2 *2)) (-4 *1 (-1219 *5 *6 *7 *2)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *2 (-1089 *5 *6 *7)))) (-1903 (*1 *2 *2 *1 *3 *4) (-12 (-5 *2 (-658 *8)) (-5 *3 (-1 *8 *8 *8)) (-5 *4 (-1 (-141) *8 *8)) (-4 *1 (-1219 *5 *6 *7 *8)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)))) (-2244 (*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-1803 (*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-1751 (*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-2226 (*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-2965 (*1 *1 *1) (-12 (-4 *1 (-1219 *2 *3 *4 *5)) (-4 *2 (-582)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-1089 *2 *3 *4)))) (-3092 (*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-2248 (*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1219 *4 *5 *6 *7)))) (-2660 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-658 (-2 (|:| -3511 *1) (|:| -1774 (-658 *7))))) (-5 *3 (-658 *7)) (-4 *1 (-1219 *4 *5 *6 *7)))) (-1918 (*1 *2 *1) (|partial| -12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-4255 (*1 *2 *1) (|partial| -12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-1366 (*1 *1 *1) (|partial| -12 (-4 *1 (-1219 *2 *3 *4 *5)) (-4 *2 (-582)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-1089 *2 *3 *4)))) (-1596 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-658 *5)))) (-3069 (*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *3 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *3 (-869)) (-4 *6 (-1089 *4 *5 *3)) (-5 *2 (-141)))) (-3113 (*1 *2 *1 *3) (|partial| -12 (-4 *1 (-1219 *4 *5 *3 *2)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *3 (-869)) (-4 *2 (-1089 *4 *5 *3)))) (-2778 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-2807 (*1 *1 *1 *2) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) (-1857 (*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *5 (-394)) (-5 *2 (-790))))) 
+(-13 (-1005 |t#1| |t#2| |t#3| |t#4|) (-10 -8 (-6 -4625) (-6 -4626) (-15 -3085 ((-141) $ $)) (-15 -1387 ((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |t#4|))) "failed") (-658 |t#4|) (-1 (-141) |t#4| |t#4|))) (-15 -1387 ((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |t#4|))) "failed") (-658 |t#4|) (-1 (-141) |t#4|) (-1 (-141) |t#4| |t#4|))) (-15 -1712 ((-658 |t#4|) $)) (-15 -4525 ((-790) $)) (-15 -1643 ((-2 (|:| -3511 (-658 |t#4|)) (|:| -1774 (-658 |t#4|))) $)) (-15 -2479 ((-141) |t#4| $)) (-15 -2479 ((-141) $)) (-15 -2172 ((-141) |t#4| $ (-1 (-141) |t#4| |t#4|))) (-15 -4135 ((-141) |t#4| $)) (-15 -4442 ((-141) |t#4| $)) (-15 -2346 ((-141) |t#4| $)) (-15 -4408 ((-141) $ (-1 (-141) |t#4| (-658 |t#4|)))) (-15 -4135 ((-141) $)) (-15 -4442 ((-141) $)) (-15 -2346 ((-141) $)) (-15 -3657 (|t#4| |t#4| $ (-1 |t#4| |t#4| |t#4|) (-1 (-141) |t#4| |t#4|))) (-15 -1903 ((-658 |t#4|) (-658 |t#4|) $ (-1 |t#4| |t#4| |t#4|) (-1 (-141) |t#4| |t#4|))) (-15 -2244 (|t#4| |t#4| $)) (-15 -1803 (|t#4| |t#4| $)) (-15 -1751 (|t#4| |t#4| $)) (-15 -2226 (|t#4| |t#4| $)) (-15 -2965 ($ $)) (-15 -3092 (|t#4| |t#4| $)) (-15 -2248 ((-658 $) (-658 |t#4|))) (-15 -2660 ((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |t#4|)))) (-658 |t#4|))) (-15 -1918 ((-3 |t#4| "failed") $)) (-15 -4255 ((-3 |t#4| "failed") $)) (-15 -1366 ((-3 $ "failed") $)) (-15 -1596 ((-658 |t#3|) $)) (-15 -3069 ((-141) |t#3| $)) (-15 -3113 ((-3 |t#4| "failed") $ |t#3|)) (-15 -2778 ((-3 $ "failed") $ |t#4|)) (-15 -2807 ($ $ |t#4|)) (IF (|has| |t#3| (-394)) (-15 -1857 ((-790) $)) |noBranch|))) 
+(((-39) . T) ((-125) . T) ((-632 (-658 |#4|)) . T) ((-632 (-877)) . T) ((-175 |#4|) . T) ((-633 (-565)) |has| |#4| (-633 (-565))) ((-325 |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-523 |#4|) . T) ((-547 |#4| |#4|) -12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))) ((-1005 |#1| |#2| |#3| |#4|) . T) ((-1119) . T) ((-1225) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1191)) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-2012 (((-980 |#1|) $ (-790)) 16) (((-980 |#1|) $ (-790) (-790)) NIL)) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-790) $ (-1191)) NIL) (((-790) $ (-1191) (-790)) NIL)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2027 (((-141) $) NIL)) (-4526 (($ $ (-658 (-1191)) (-658 (-558 (-1191)))) NIL) (($ $ (-1191) (-558 (-1191))) NIL) (($ |#1| (-558 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-3162 (($ $ (-1191)) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191) |#1|) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-4320 (($ (-1 $) (-1191) |#1|) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2807 (($ $ (-790)) NIL)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2806 (($ $ (-1191) $) NIL) (($ $ (-658 (-1191)) (-658 $)) NIL) (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL)) (-3644 (($ $ (-1191)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL)) (-4525 (((-558 (-1191)) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL (|has| |#1| (-194))) (($ $) NIL (|has| |#1| (-582))) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-1191)) NIL) (($ (-980 |#1|)) NIL)) (-1937 ((|#1| $ (-558 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (((-980 |#1|) $ (-790)) NIL)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-1191)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-1220 |#1|) (-13 (-757 |#1| (-1191)) (-10 -8 (-15 -1937 ((-980 |#1|) $ (-790))) (-15 -1683 ($ (-1191))) (-15 -1683 ($ (-980 |#1|))) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $ (-1191) |#1|)) (-15 -4320 ($ (-1 $) (-1191) |#1|))) |noBranch|))) (-1075)) (T -1220)) 
+((-1937 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-980 *4)) (-5 *1 (-1220 *4)) (-4 *4 (-1075)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1220 *3)) (-4 *3 (-1075)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-980 *3)) (-4 *3 (-1075)) (-5 *1 (-1220 *3)))) (-3162 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *1 (-1220 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)))) (-4320 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1220 *4))) (-5 *3 (-1191)) (-5 *1 (-1220 *4)) (-4 *4 (-43 (-433 (-592)))) (-4 *4 (-1075))))) 
+(-13 (-757 |#1| (-1191)) (-10 -8 (-15 -1937 ((-980 |#1|) $ (-790))) (-15 -1683 ($ (-1191))) (-15 -1683 ($ (-980 |#1|))) (IF (|has| |#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $ (-1191) |#1|)) (-15 -4320 ($ (-1 $) (-1191) |#1|))) |noBranch|))) 
+((-2073 (($ |#1| (-658 (-658 (-971 (-237)))) (-141)) 15)) (-2405 (((-141) $ (-141)) 14)) (-4435 (((-141) $) 13)) (-2736 (((-658 (-658 (-971 (-237)))) $) 10)) (-4381 ((|#1| $) 8)) (-2308 (((-141) $) 12))) 
+(((-1221 |#1|) (-10 -8 (-15 -4381 (|#1| $)) (-15 -2736 ((-658 (-658 (-971 (-237)))) $)) (-15 -2308 ((-141) $)) (-15 -4435 ((-141) $)) (-15 -2405 ((-141) $ (-141))) (-15 -2073 ($ |#1| (-658 (-658 (-971 (-237)))) (-141)))) (-1003)) (T -1221)) 
+((-2073 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-141)) (-5 *1 (-1221 *2)) (-4 *2 (-1003)))) (-2405 (*1 *2 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1221 *3)) (-4 *3 (-1003)))) (-4435 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1221 *3)) (-4 *3 (-1003)))) (-2308 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1221 *3)) (-4 *3 (-1003)))) (-2736 (*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *1 (-1221 *3)) (-4 *3 (-1003)))) (-4381 (*1 *2 *1) (-12 (-5 *1 (-1221 *2)) (-4 *2 (-1003))))) 
+(-10 -8 (-15 -4381 (|#1| $)) (-15 -2736 ((-658 (-658 (-971 (-237)))) $)) (-15 -2308 ((-141) $)) (-15 -4435 ((-141) $)) (-15 -2405 ((-141) $ (-141))) (-15 -2073 ($ |#1| (-658 (-658 (-971 (-237)))) (-141)))) 
+((-2673 (((-971 (-237)) (-971 (-237))) 25)) (-1831 (((-971 (-237)) (-237) (-237) (-237) (-237)) 10)) (-2735 (((-658 (-971 (-237))) (-971 (-237)) (-971 (-237)) (-971 (-237)) (-237) (-658 (-658 (-237)))) 35)) (-1729 (((-237) (-971 (-237)) (-971 (-237))) 21)) (-2746 (((-971 (-237)) (-971 (-237)) (-971 (-237))) 22)) (-3900 (((-658 (-658 (-237))) (-592)) 31)) (-3306 (((-971 (-237)) (-971 (-237)) (-971 (-237))) 20)) (-3300 (((-971 (-237)) (-971 (-237)) (-971 (-237))) 19)) (* (((-971 (-237)) (-237) (-971 (-237))) 18))) 
+(((-1222) (-10 -7 (-15 -1831 ((-971 (-237)) (-237) (-237) (-237) (-237))) (-15 * ((-971 (-237)) (-237) (-971 (-237)))) (-15 -3300 ((-971 (-237)) (-971 (-237)) (-971 (-237)))) (-15 -3306 ((-971 (-237)) (-971 (-237)) (-971 (-237)))) (-15 -1729 ((-237) (-971 (-237)) (-971 (-237)))) (-15 -2746 ((-971 (-237)) (-971 (-237)) (-971 (-237)))) (-15 -2673 ((-971 (-237)) (-971 (-237)))) (-15 -3900 ((-658 (-658 (-237))) (-592))) (-15 -2735 ((-658 (-971 (-237))) (-971 (-237)) (-971 (-237)) (-971 (-237)) (-237) (-658 (-658 (-237))))))) (T -1222)) 
+((-2735 (*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-658 (-658 (-237)))) (-5 *4 (-237)) (-5 *2 (-658 (-971 *4))) (-5 *1 (-1222)) (-5 *3 (-971 *4)))) (-3900 (*1 *2 *3) (-12 (-5 *3 (-592)) (-5 *2 (-658 (-658 (-237)))) (-5 *1 (-1222)))) (-2673 (*1 *2 *2) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)))) (-2746 (*1 *2 *2 *2) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)))) (-1729 (*1 *2 *3 *3) (-12 (-5 *3 (-971 (-237))) (-5 *2 (-237)) (-5 *1 (-1222)))) (-3306 (*1 *2 *2 *2) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)))) (-3300 (*1 *2 *2 *2) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-971 (-237))) (-5 *3 (-237)) (-5 *1 (-1222)))) (-1831 (*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)) (-5 *3 (-237))))) 
+(-10 -7 (-15 -1831 ((-971 (-237)) (-237) (-237) (-237) (-237))) (-15 * ((-971 (-237)) (-237) (-971 (-237)))) (-15 -3300 ((-971 (-237)) (-971 (-237)) (-971 (-237)))) (-15 -3306 ((-971 (-237)) (-971 (-237)) (-971 (-237)))) (-15 -1729 ((-237) (-971 (-237)) (-971 (-237)))) (-15 -2746 ((-971 (-237)) (-971 (-237)) (-971 (-237)))) (-15 -2673 ((-971 (-237)) (-971 (-237)))) (-15 -3900 ((-658 (-658 (-237))) (-592))) (-15 -2735 ((-658 (-971 (-237))) (-971 (-237)) (-971 (-237)) (-971 (-237)) (-237) (-658 (-658 (-237)))))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3113 ((|#1| $ (-790)) 13)) (-4233 (((-790) $) 12)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1683 (((-986 |#1|) $) 10) (($ (-986 |#1|)) 9) (((-877) $) 23 (|has| |#1| (-1119)))) (-3255 (((-141) $ $) 16 (|has| |#1| (-1119))))) 
+(((-1223 |#1|) (-13 (-632 (-986 |#1|)) (-10 -8 (-15 -1683 ($ (-986 |#1|))) (-15 -3113 (|#1| $ (-790))) (-15 -4233 ((-790) $)) (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|))) (-1225)) (T -1223)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-986 *3)) (-4 *3 (-1225)) (-5 *1 (-1223 *3)))) (-3113 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *1 (-1223 *2)) (-4 *2 (-1225)))) (-4233 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1223 *3)) (-4 *3 (-1225))))) 
+(-13 (-632 (-986 |#1|)) (-10 -8 (-15 -1683 ($ (-986 |#1|))) (-15 -3113 (|#1| $ (-790))) (-15 -4233 ((-790) $)) (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|))) 
+((-2420 (((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|)) (-592)) 79)) (-3216 (((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|))) 73)) (-3021 (((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|))) 58))) 
+(((-1224 |#1|) (-10 -7 (-15 -3216 ((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|)))) (-15 -3021 ((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|)))) (-15 -2420 ((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|)) (-592)))) (-373)) (T -1224)) 
+((-2420 (*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-373)) (-5 *2 (-444 (-1187 (-1187 *5)))) (-5 *1 (-1224 *5)) (-5 *3 (-1187 (-1187 *5))))) (-3021 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 (-1187 (-1187 *4)))) (-5 *1 (-1224 *4)) (-5 *3 (-1187 (-1187 *4))))) (-3216 (*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 (-1187 (-1187 *4)))) (-5 *1 (-1224 *4)) (-5 *3 (-1187 (-1187 *4)))))) 
+(-10 -7 (-15 -3216 ((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|)))) (-15 -3021 ((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|)))) (-15 -2420 ((-444 (-1187 (-1187 |#1|))) (-1187 (-1187 |#1|)) (-592)))) 
+NIL 
+(((-1225) (-1311)) (T -1225)) 
+NIL 
+(-13 (-10 -7 (-6 -2623))) 
+((-1641 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-1417 (($ (-790) (-790)) NIL)) (-4596 (($ $ $) NIL)) (-2245 (($ (-1227)) NIL) (($ $) NIL)) (-4034 (((-141) $) NIL)) (-2668 (($ $ (-592) (-592)) NIL)) (-1664 (($ $ (-592) (-592)) NIL)) (-2019 (($ $ (-592) (-592) (-592) (-592)) NIL)) (-1574 (($ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-2854 (($ $ (-592) (-592) $) NIL)) (-3932 (((-592) $ (-592) (-592) (-592)) 17) (($ $ (-658 (-592)) (-658 (-592)) $) NIL)) (-2547 (($ $ (-592) (-1227)) NIL)) (-2242 (($ $ (-592) (-1227)) NIL)) (-3223 (($ (-790) (-592)) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) NIL (|has| (-592) (-323)))) (-2747 (((-1227) $ (-592)) NIL)) (-4175 (((-790) $) NIL (|has| (-592) (-582)))) (-1426 (((-592) $ (-592) (-592) (-592)) 16)) (-1695 (($ (-592) (-592)) 19)) (-3959 (((-592) $ (-592) (-592)) 14)) (-1794 (((-592) $) NIL (|has| (-592) (-194)))) (-4004 (((-658 (-592)) $) NIL)) (-3178 (((-790) $) NIL (|has| (-592) (-582)))) (-3555 (((-658 (-1227)) $) NIL (|has| (-592) (-582)))) (-4292 (((-790) $) 10)) (-3242 (($ (-790) (-790) (-592)) 20)) (-4298 (((-790) $) 11)) (-4345 (((-141) $ (-790)) NIL)) (-3781 (((-592) $) NIL (|has| (-592) (-6 (-4627 "*"))))) (-4577 (((-592) $) 7)) (-4280 (((-592) $) 8)) (-4467 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-1898 (((-592) $) 12)) (-3005 (((-592) $) 13)) (-4186 (($ (-658 (-658 (-592)))) NIL) (($ (-790) (-790) (-1 (-592) (-592) (-592))) NIL)) (-3987 (($ (-1 (-592) (-592)) $) NIL)) (-2731 (($ (-1 (-592) (-592)) $) NIL) (($ (-1 (-592) (-592) (-592)) $ $) NIL) (($ (-1 (-592) (-592) (-592)) $ $ (-592)) NIL)) (-4601 (((-658 (-658 (-592))) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| (-592) (-1119)))) (-3183 (((-3 $ "failed") $) NIL (|has| (-592) (-388)))) (-2083 (($ $ $) NIL)) (-2951 (((-1137) $) NIL (|has| (-592) (-1119)))) (-1892 (($ $ (-592)) NIL)) (-3616 (((-3 $ "failed") $ (-592)) NIL (|has| (-592) (-582)))) (-3002 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-592)))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-310 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-592) (-592)) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-658 (-592)) (-658 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 18)) (-3927 (((-592) $ (-592) (-592)) 15) (((-592) $ (-592) (-592) (-592)) NIL) (($ $ (-658 (-592)) (-658 (-592))) NIL)) (-2933 (($ (-658 (-592))) NIL) (($ (-658 $)) NIL)) (-2940 (((-141) $) NIL)) (-1625 (((-592) $) NIL (|has| (-592) (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625))) (((-790) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4599 (($ $) NIL)) (-3430 (((-658 (-1227)) $) NIL (|has| (-592) (-323)))) (-2000 (((-1227) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| (-592) (-1119))) (($ (-1227)) NIL)) (-3369 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3313 (($ $ (-592)) NIL (|has| (-592) (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-592) (-388)))) (* (($ $ $) NIL) (($ (-592) $) NIL) (($ $ (-592)) NIL) (($ (-592) $) NIL) (((-1227) $ (-1227)) NIL) (((-1227) (-1227) $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1226) (-13 (-704 (-592) (-1227) (-1227)) (-10 -8 (-15 -1695 ($ (-592) (-592)))))) (T -1226)) 
+((-1695 (*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1226))))) 
+(-13 (-704 (-592) (-1227) (-1227)) (-10 -8 (-15 -1695 ($ (-592) (-592))))) 
+((-1641 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) (-592) (-592)) $) NIL) (((-141) $) NIL (|has| (-592) (-869)))) (-2831 (($ (-1 (-141) (-592) (-592)) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-592) (-869))))) (-3960 (($ (-1 (-141) (-592) (-592)) $) NIL) (($ $) NIL (|has| (-592) (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-592) $ (-592) (-592)) 15 (|has| $ (-6 -4626))) (((-592) $ (-1246 (-592)) (-592)) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4459 (($ (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119)))) (($ (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-592) (-1 (-592) (-592) (-592)) $ (-592) (-592)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119)))) (((-592) (-1 (-592) (-592) (-592)) $ (-592)) NIL (|has| $ (-6 -4625))) (((-592) (-1 (-592) (-592) (-592)) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-592) $ (-592) (-592)) 14 (|has| $ (-6 -4626)))) (-3959 (((-592) $ (-592)) 12)) (-1721 (((-592) (-1 (-141) (-592)) $) NIL) (((-592) (-592) $) NIL (|has| (-592) (-1119))) (((-592) (-592) $ (-592)) NIL (|has| (-592) (-1119)))) (-4004 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) (-592)) 11)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 9 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| (-592) (-869)))) (-4491 (($ (-1 (-141) (-592) (-592)) $ $) NIL) (($ $ $) NIL (|has| (-592) (-869)))) (-4467 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-592) (-869)))) (-3987 (($ (-1 (-592) (-592)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-592) (-592)) $) NIL) (($ (-1 (-592) (-592) (-592)) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| (-592) (-1119)))) (-3666 (($ (-592) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| (-592) (-1119)))) (-1918 (((-592) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-592) "failed") (-1 (-141) (-592)) $) NIL)) (-1892 (($ $ (-592)) 16 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-592)))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-310 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-592) (-592)) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-658 (-592)) (-658 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4210 (((-658 (-592)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 10)) (-3927 (((-592) $ (-592) (-592)) NIL) (((-592) $ (-592)) 13) (($ $ (-1246 (-592))) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625))) (((-790) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-592) (-633 (-565))))) (-4466 (($ (-658 (-592))) NIL)) (-2266 (($ $ (-592)) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| (-592) (-1119)))) (-3369 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3255 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3279 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-592) (-869)))) (-1699 (((-790) $) 7 (|has| $ (-6 -4625))))) 
+(((-1227) (-19 (-592))) (T -1227)) 
+NIL 
+(-19 (-592)) 
+((-1641 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-1417 (($ (-790) (-790)) NIL)) (-4596 (($ $ $) NIL)) (-2245 (($ (-1229)) NIL) (($ $) NIL)) (-4034 (((-141) $) NIL)) (-2668 (($ $ (-592) (-592)) NIL)) (-1664 (($ $ (-592) (-592)) NIL)) (-2019 (($ $ (-592) (-592) (-592) (-592)) NIL)) (-1574 (($ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-2854 (($ $ (-592) (-592) $) NIL)) (-3932 (((-592) $ (-592) (-592) (-592)) 17) (($ $ (-658 (-592)) (-658 (-592)) $) NIL)) (-2547 (($ $ (-592) (-1229)) NIL)) (-2242 (($ $ (-592) (-1229)) NIL)) (-3223 (($ (-790) (-592)) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) NIL (|has| (-592) (-323)))) (-2747 (((-1229) $ (-592)) NIL)) (-4175 (((-790) $) NIL (|has| (-592) (-582)))) (-1426 (((-592) $ (-592) (-592) (-592)) 16)) (-1695 (($ (-592) (-592)) 19)) (-3959 (((-592) $ (-592) (-592)) 14)) (-1794 (((-592) $) NIL (|has| (-592) (-194)))) (-4004 (((-658 (-592)) $) NIL)) (-3178 (((-790) $) NIL (|has| (-592) (-582)))) (-3555 (((-658 (-1229)) $) NIL (|has| (-592) (-582)))) (-4292 (((-790) $) 10)) (-3242 (($ (-790) (-790) (-592)) 20)) (-4298 (((-790) $) 11)) (-4345 (((-141) $ (-790)) NIL)) (-3781 (((-592) $) NIL (|has| (-592) (-6 (-4627 "*"))))) (-4577 (((-592) $) 7)) (-4280 (((-592) $) 8)) (-4467 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-1898 (((-592) $) 12)) (-3005 (((-592) $) 13)) (-4186 (($ (-658 (-658 (-592)))) NIL) (($ (-790) (-790) (-1 (-592) (-592) (-592))) NIL)) (-3987 (($ (-1 (-592) (-592)) $) NIL)) (-2731 (($ (-1 (-592) (-592)) $) NIL) (($ (-1 (-592) (-592) (-592)) $ $) NIL) (($ (-1 (-592) (-592) (-592)) $ $ (-592)) NIL)) (-4601 (((-658 (-658 (-592))) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| (-592) (-1119)))) (-3183 (((-3 $ "failed") $) NIL (|has| (-592) (-388)))) (-2083 (($ $ $) NIL)) (-2951 (((-1137) $) NIL (|has| (-592) (-1119)))) (-1892 (($ $ (-592)) NIL)) (-3616 (((-3 $ "failed") $ (-592)) NIL (|has| (-592) (-582)))) (-3002 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-592)))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-310 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-592) (-592)) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-658 (-592)) (-658 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 18)) (-3927 (((-592) $ (-592) (-592)) 15) (((-592) $ (-592) (-592) (-592)) NIL) (($ $ (-658 (-592)) (-658 (-592))) NIL)) (-2933 (($ (-658 (-592))) NIL) (($ (-658 $)) NIL)) (-2940 (((-141) $) NIL)) (-1625 (((-592) $) NIL (|has| (-592) (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625))) (((-790) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4599 (($ $) NIL)) (-3430 (((-658 (-1229)) $) NIL (|has| (-592) (-323)))) (-2000 (((-1229) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| (-592) (-1119))) (($ (-1229)) NIL)) (-3369 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3313 (($ $ (-592)) NIL (|has| (-592) (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-592) (-388)))) (* (($ $ $) NIL) (($ (-592) $) NIL) (($ $ (-592)) NIL) (($ (-592) $) NIL) (((-1229) $ (-1229)) NIL) (((-1229) (-1229) $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1228) (-13 (-704 (-592) (-1229) (-1229)) (-10 -8 (-15 -1695 ($ (-592) (-592)))))) (T -1228)) 
+((-1695 (*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1228))))) 
+(-13 (-704 (-592) (-1229) (-1229)) (-10 -8 (-15 -1695 ($ (-592) (-592))))) 
+((-1641 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) (-592) (-592)) $) NIL) (((-141) $) NIL (|has| (-592) (-869)))) (-2831 (($ (-1 (-141) (-592) (-592)) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-592) (-869))))) (-3960 (($ (-1 (-141) (-592) (-592)) $) NIL) (($ $) NIL (|has| (-592) (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-592) $ (-592) (-592)) 15 (|has| $ (-6 -4626))) (((-592) $ (-1246 (-592)) (-592)) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4459 (($ (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119)))) (($ (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-592) (-1 (-592) (-592) (-592)) $ (-592) (-592)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119)))) (((-592) (-1 (-592) (-592) (-592)) $ (-592)) NIL (|has| $ (-6 -4625))) (((-592) (-1 (-592) (-592) (-592)) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-592) $ (-592) (-592)) 14 (|has| $ (-6 -4626)))) (-3959 (((-592) $ (-592)) 12)) (-1721 (((-592) (-1 (-141) (-592)) $) NIL) (((-592) (-592) $) NIL (|has| (-592) (-1119))) (((-592) (-592) $ (-592)) NIL (|has| (-592) (-1119)))) (-4004 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) (-592)) 11)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 9 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| (-592) (-869)))) (-4491 (($ (-1 (-141) (-592) (-592)) $ $) NIL) (($ $ $) NIL (|has| (-592) (-869)))) (-4467 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-592) (-869)))) (-3987 (($ (-1 (-592) (-592)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-592) (-592)) $) NIL) (($ (-1 (-592) (-592) (-592)) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| (-592) (-1119)))) (-3666 (($ (-592) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| (-592) (-1119)))) (-1918 (((-592) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-592) "failed") (-1 (-141) (-592)) $) NIL)) (-1892 (($ $ (-592)) 16 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-592)))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-310 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-592) (-592)) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-658 (-592)) (-658 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4210 (((-658 (-592)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 10)) (-3927 (((-592) $ (-592) (-592)) NIL) (((-592) $ (-592)) 13) (($ $ (-1246 (-592))) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625))) (((-790) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-592) (-633 (-565))))) (-4466 (($ (-658 (-592))) NIL)) (-2266 (($ $ (-592)) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| (-592) (-1119)))) (-3369 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3255 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3279 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-592) (-869)))) (-1699 (((-790) $) 7 (|has| $ (-6 -4625))))) 
+(((-1229) (-19 (-592))) (T -1229)) 
+NIL 
+(-19 (-592)) 
+((-1641 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-1417 (($ (-790) (-790)) NIL)) (-4596 (($ $ $) NIL)) (-2245 (($ (-1231)) NIL) (($ $) NIL)) (-4034 (((-141) $) NIL)) (-2668 (($ $ (-592) (-592)) NIL)) (-1664 (($ $ (-592) (-592)) NIL)) (-2019 (($ $ (-592) (-592) (-592) (-592)) NIL)) (-1574 (($ $) NIL)) (-3120 (((-141) $) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-2854 (($ $ (-592) (-592) $) NIL)) (-3932 (((-592) $ (-592) (-592) (-592)) 17) (($ $ (-658 (-592)) (-658 (-592)) $) NIL)) (-2547 (($ $ (-592) (-1231)) NIL)) (-2242 (($ $ (-592) (-1231)) NIL)) (-3223 (($ (-790) (-592)) NIL)) (-3001 (($) NIL T CONST)) (-3052 (($ $) NIL (|has| (-592) (-323)))) (-2747 (((-1231) $ (-592)) NIL)) (-4175 (((-790) $) NIL (|has| (-592) (-582)))) (-1426 (((-592) $ (-592) (-592) (-592)) 16)) (-1695 (($ (-592) (-592)) 19)) (-3959 (((-592) $ (-592) (-592)) 14)) (-1794 (((-592) $) NIL (|has| (-592) (-194)))) (-4004 (((-658 (-592)) $) NIL)) (-3178 (((-790) $) NIL (|has| (-592) (-582)))) (-3555 (((-658 (-1231)) $) NIL (|has| (-592) (-582)))) (-4292 (((-790) $) 10)) (-3242 (($ (-790) (-790) (-592)) 20)) (-4298 (((-790) $) 11)) (-4345 (((-141) $ (-790)) NIL)) (-3781 (((-592) $) NIL (|has| (-592) (-6 (-4627 "*"))))) (-4577 (((-592) $) 7)) (-4280 (((-592) $) 8)) (-4467 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-1898 (((-592) $) 12)) (-3005 (((-592) $) 13)) (-4186 (($ (-658 (-658 (-592)))) NIL) (($ (-790) (-790) (-1 (-592) (-592) (-592))) NIL)) (-3987 (($ (-1 (-592) (-592)) $) NIL)) (-2731 (($ (-1 (-592) (-592)) $) NIL) (($ (-1 (-592) (-592) (-592)) $ $) NIL) (($ (-1 (-592) (-592) (-592)) $ $ (-592)) NIL)) (-4601 (((-658 (-658 (-592))) $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| (-592) (-1119)))) (-3183 (((-3 $ "failed") $) NIL (|has| (-592) (-388)))) (-2083 (($ $ $) NIL)) (-2951 (((-1137) $) NIL (|has| (-592) (-1119)))) (-1892 (($ $ (-592)) NIL)) (-3616 (((-3 $ "failed") $ (-592)) NIL (|has| (-592) (-582)))) (-3002 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-592)))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-310 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-592) (-592)) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-658 (-592)) (-658 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 18)) (-3927 (((-592) $ (-592) (-592)) 15) (((-592) $ (-592) (-592) (-592)) NIL) (($ $ (-658 (-592)) (-658 (-592))) NIL)) (-2933 (($ (-658 (-592))) NIL) (($ (-658 $)) NIL)) (-2940 (((-141) $) NIL)) (-1625 (((-592) $) NIL (|has| (-592) (-6 (-4627 "*"))))) (-3452 (((-790) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625))) (((-790) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4599 (($ $) NIL)) (-3430 (((-658 (-1231)) $) NIL (|has| (-592) (-323)))) (-2000 (((-1231) $ (-592)) NIL)) (-1683 (((-877) $) NIL (|has| (-592) (-1119))) (($ (-1231)) NIL)) (-3369 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3951 (((-141) $) NIL)) (-3255 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3313 (($ $ (-592)) NIL (|has| (-592) (-388)))) (-3306 (($ $ $) NIL) (($ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| (-592) (-388)))) (* (($ $ $) NIL) (($ (-592) $) NIL) (($ $ (-592)) NIL) (($ (-592) $) NIL) (((-1231) $ (-1231)) NIL) (((-1231) (-1231) $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1230) (-13 (-704 (-592) (-1231) (-1231)) (-10 -8 (-15 -1695 ($ (-592) (-592)))))) (T -1230)) 
+((-1695 (*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1230))))) 
+(-13 (-704 (-592) (-1231) (-1231)) (-10 -8 (-15 -1695 ($ (-592) (-592))))) 
+((-1641 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) (-592) (-592)) $) NIL) (((-141) $) NIL (|has| (-592) (-869)))) (-2831 (($ (-1 (-141) (-592) (-592)) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| (-592) (-869))))) (-3960 (($ (-1 (-141) (-592) (-592)) $) NIL) (($ $) NIL (|has| (-592) (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 (((-592) $ (-592) (-592)) 15 (|has| $ (-6 -4626))) (((-592) $ (-1246 (-592)) (-592)) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4459 (($ (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119)))) (($ (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3657 (((-592) (-1 (-592) (-592) (-592)) $ (-592) (-592)) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119)))) (((-592) (-1 (-592) (-592) (-592)) $ (-592)) NIL (|has| $ (-6 -4625))) (((-592) (-1 (-592) (-592) (-592)) $) NIL (|has| $ (-6 -4625)))) (-1426 (((-592) $ (-592) (-592)) 14 (|has| $ (-6 -4626)))) (-3959 (((-592) $ (-592)) 12)) (-1721 (((-592) (-1 (-141) (-592)) $) NIL) (((-592) (-592) $) NIL (|has| (-592) (-1119))) (((-592) (-592) $ (-592)) NIL (|has| (-592) (-1119)))) (-4004 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3242 (($ (-790) (-592)) 11)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) 9 (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| (-592) (-869)))) (-4491 (($ (-1 (-141) (-592) (-592)) $ $) NIL) (($ $ $) NIL (|has| (-592) (-869)))) (-4467 (((-658 (-592)) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| (-592) (-869)))) (-3987 (($ (-1 (-592) (-592)) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 (-592) (-592)) $) NIL) (($ (-1 (-592) (-592) (-592)) $ $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL (|has| (-592) (-1119)))) (-3666 (($ (-592) $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| (-592) (-1119)))) (-1918 (((-592) $) NIL (|has| (-592) (-869)))) (-4050 (((-3 (-592) "failed") (-1 (-141) (-592)) $) NIL)) (-1892 (($ $ (-592)) 16 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 (-592)))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-310 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-592) (-592)) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119)))) (($ $ (-658 (-592)) (-658 (-592))) NIL (-12 (|has| (-592) (-325 (-592))) (|has| (-592) (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-4210 (((-658 (-592)) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) 10)) (-3927 (((-592) $ (-592) (-592)) NIL) (((-592) $ (-592)) 13) (($ $ (-1246 (-592))) NIL)) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-3452 (((-790) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625))) (((-790) (-592) $) NIL (-12 (|has| $ (-6 -4625)) (|has| (-592) (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| (-592) (-633 (-565))))) (-4466 (($ (-658 (-592))) NIL)) (-2266 (($ $ (-592)) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| (-592) (-1119)))) (-3369 (((-141) (-1 (-141) (-592)) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3273 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3255 (((-141) $ $) NIL (|has| (-592) (-1119)))) (-3279 (((-141) $ $) NIL (|has| (-592) (-869)))) (-3266 (((-141) $ $) NIL (|has| (-592) (-869)))) (-1699 (((-790) $) 7 (|has| $ (-6 -4625))))) 
+(((-1231) (-19 (-592))) (T -1231)) 
+NIL 
+(-19 (-592)) 
+((-2357 (((-141)) 14)) (-2859 (((-1285) (-658 |#1|) (-658 |#1|)) 18) (((-1285) (-658 |#1|)) 19)) (-4345 (((-141) |#1| |#1|) 30 (|has| |#1| (-869)))) (-2554 (((-141) |#1| |#1| (-1 (-141) |#1| |#1|)) 26) (((-3 (-141) "failed") |#1| |#1|) 24)) (-3795 ((|#1| (-658 |#1|)) 31 (|has| |#1| (-869))) ((|#1| (-658 |#1|) (-1 (-141) |#1| |#1|)) 27)) (-4327 (((-2 (|:| -2781 (-658 |#1|)) (|:| -2369 (-658 |#1|)))) 16))) 
+(((-1232 |#1|) (-10 -7 (-15 -2859 ((-1285) (-658 |#1|))) (-15 -2859 ((-1285) (-658 |#1|) (-658 |#1|))) (-15 -4327 ((-2 (|:| -2781 (-658 |#1|)) (|:| -2369 (-658 |#1|))))) (-15 -2554 ((-3 (-141) "failed") |#1| |#1|)) (-15 -2554 ((-141) |#1| |#1| (-1 (-141) |#1| |#1|))) (-15 -3795 (|#1| (-658 |#1|) (-1 (-141) |#1| |#1|))) (-15 -2357 ((-141))) (IF (|has| |#1| (-869)) (PROGN (-15 -3795 (|#1| (-658 |#1|))) (-15 -4345 ((-141) |#1| |#1|))) |noBranch|)) (-1119)) (T -1232)) 
+((-4345 (*1 *2 *3 *3) (-12 (-5 *2 (-141)) (-5 *1 (-1232 *3)) (-4 *3 (-869)) (-4 *3 (-1119)))) (-3795 (*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-1119)) (-4 *2 (-869)) (-5 *1 (-1232 *2)))) (-2357 (*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1232 *3)) (-4 *3 (-1119)))) (-3795 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *2)) (-5 *4 (-1 (-141) *2 *2)) (-5 *1 (-1232 *2)) (-4 *2 (-1119)))) (-2554 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-1 (-141) *3 *3)) (-4 *3 (-1119)) (-5 *2 (-141)) (-5 *1 (-1232 *3)))) (-2554 (*1 *2 *3 *3) (|partial| -12 (-5 *2 (-141)) (-5 *1 (-1232 *3)) (-4 *3 (-1119)))) (-4327 (*1 *2) (-12 (-5 *2 (-2 (|:| -2781 (-658 *3)) (|:| -2369 (-658 *3)))) (-5 *1 (-1232 *3)) (-4 *3 (-1119)))) (-2859 (*1 *2 *3 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1119)) (-5 *2 (-1285)) (-5 *1 (-1232 *4)))) (-2859 (*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1119)) (-5 *2 (-1285)) (-5 *1 (-1232 *4))))) 
+(-10 -7 (-15 -2859 ((-1285) (-658 |#1|))) (-15 -2859 ((-1285) (-658 |#1|) (-658 |#1|))) (-15 -4327 ((-2 (|:| -2781 (-658 |#1|)) (|:| -2369 (-658 |#1|))))) (-15 -2554 ((-3 (-141) "failed") |#1| |#1|)) (-15 -2554 ((-141) |#1| |#1| (-1 (-141) |#1| |#1|))) (-15 -3795 (|#1| (-658 |#1|) (-1 (-141) |#1| |#1|))) (-15 -2357 ((-141))) (IF (|has| |#1| (-869)) (PROGN (-15 -3795 (|#1| (-658 |#1|))) (-15 -4345 ((-141) |#1| |#1|))) |noBranch|)) 
+((-2683 (((-1285) (-658 (-1191)) (-658 (-1191))) 12) (((-1285) (-658 (-1191))) 10)) (-4431 (((-1285)) 13)) (-1652 (((-2 (|:| -2369 (-658 (-1191))) (|:| -2781 (-658 (-1191))))) 17))) 
+(((-1233) (-10 -7 (-15 -2683 ((-1285) (-658 (-1191)))) (-15 -2683 ((-1285) (-658 (-1191)) (-658 (-1191)))) (-15 -1652 ((-2 (|:| -2369 (-658 (-1191))) (|:| -2781 (-658 (-1191)))))) (-15 -4431 ((-1285))))) (T -1233)) 
+((-4431 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1233)))) (-1652 (*1 *2) (-12 (-5 *2 (-2 (|:| -2369 (-658 (-1191))) (|:| -2781 (-658 (-1191))))) (-5 *1 (-1233)))) (-2683 (*1 *2 *3 *3) (-12 (-5 *3 (-658 (-1191))) (-5 *2 (-1285)) (-5 *1 (-1233)))) (-2683 (*1 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-5 *2 (-1285)) (-5 *1 (-1233))))) 
+(-10 -7 (-15 -2683 ((-1285) (-658 (-1191)))) (-15 -2683 ((-1285) (-658 (-1191)) (-658 (-1191)))) (-15 -1652 ((-2 (|:| -2369 (-658 (-1191))) (|:| -2781 (-658 (-1191)))))) (-15 -4431 ((-1285)))) 
+((-3743 (($ $) 16)) (-2802 (((-141) $) 23))) 
+(((-1234 |#1|) (-10 -8 (-15 -3743 (|#1| |#1|)) (-15 -2802 ((-141) |#1|))) (-1235)) (T -1234)) 
+NIL 
+(-10 -8 (-15 -3743 (|#1| |#1|)) (-15 -2802 ((-141) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 50)) (-3164 (((-444 $) $) 51)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-2802 (((-141) $) 52)) (-3558 (((-141) $) 30)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 48)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-4500 (((-444 $) $) 49)) (-3616 (((-3 $ "failed") $ $) 41)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42)) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23))) 
+(((-1235) (-1311)) (T -1235)) 
+((-2802 (*1 *2 *1) (-12 (-4 *1 (-1235)) (-5 *2 (-141)))) (-3164 (*1 *2 *1) (-12 (-5 *2 (-444 *1)) (-4 *1 (-1235)))) (-3743 (*1 *1 *1) (-4 *1 (-1235))) (-4500 (*1 *2 *1) (-12 (-5 *2 (-444 *1)) (-4 *1 (-1235))))) 
+(-13 (-477) (-10 -8 (-15 -2802 ((-141) $)) (-15 -3164 ((-444 $) $)) (-15 -3743 ($ $)) (-15 -4500 ((-444 $) $)))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-125) . T) ((-140 $ $) . T) ((-158) . T) ((-632 (-877)) . T) ((-194) . T) ((-307) . T) ((-477) . T) ((-582) . T) ((-661 $) . T) ((-678) . T) ((-734 $) . T) ((-743) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-4177 (((-1237 |#1|) (-1237 |#1|) (-1237 |#1|)) 15))) 
+(((-1236 |#1|) (-10 -7 (-15 -4177 ((-1237 |#1|) (-1237 |#1|) (-1237 |#1|)))) (-1075)) (T -1236)) 
+((-4177 (*1 *2 *2 *2) (-12 (-5 *2 (-1237 *3)) (-4 *3 (-1075)) (-5 *1 (-1236 *3))))) 
+(-10 -7 (-15 -4177 ((-1237 |#1|) (-1237 |#1|) (-1237 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) NIL)) (-3395 (((-1252 (QUOTE |x|) |#1|) $ (-790)) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-790)) NIL) (($ $ (-790) (-790)) NIL)) (-2982 (((-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|))) $) NIL)) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|)))) NIL) (($ (-1171 |#1|)) NIL)) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-3621 (($ $) NIL)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-2410 (($ $) NIL)) (-2012 (((-980 |#1|) $ (-790)) NIL) (((-980 |#1|) $ (-790) (-790)) NIL)) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-790) $) NIL) (((-790) $ (-790)) NIL)) (-3558 (((-141) $) NIL)) (-2669 (($ $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3368 (($ (-592) (-592) $) NIL)) (-3990 (($ $ (-944)) NIL)) (-1376 (($ (-1 |#1| (-592)) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-4006 (($ $) NIL)) (-3121 (($ $) NIL)) (-3884 (($ (-592) (-592) $) NIL)) (-3162 (($ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 (QUOTE |x|))) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-2860 (($ $ (-592) (-592)) NIL)) (-2807 (($ $ (-790)) NIL)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3325 (($ $) NIL)) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-790)))))) (-3927 ((|#1| $ (-790)) NIL) (($ $ $) NIL (|has| (-790) (-1131)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $ (-1276 (QUOTE |x|))) NIL)) (-4525 (((-790) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582))) (($ |#1|) NIL (|has| |#1| (-194))) (($ (-1252 (QUOTE |x|) |#1|)) NIL) (($ (-1276 (QUOTE |x|))) NIL)) (-1647 (((-1171 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) NIL)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) NIL)) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-790)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-790)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) NIL T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1237 |#1|) (-13 (-1270 |#1|) (-10 -8 (-15 -1683 ($ (-1252 (QUOTE |x|) |#1|))) (-15 -3395 ((-1252 (QUOTE |x|) |#1|) $ (-790))) (-15 -1683 ($ (-1276 (QUOTE |x|)))) (-15 -3644 ($ $ (-1276 (QUOTE |x|)))) (-15 -3121 ($ $)) (-15 -4006 ($ $)) (-15 -2669 ($ $)) (-15 -3325 ($ $)) (-15 -2860 ($ $ (-592) (-592))) (-15 -3621 ($ $)) (-15 -3368 ($ (-592) (-592) $)) (-15 -3884 ($ (-592) (-592) $)) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 (QUOTE |x|)))) |noBranch|))) (-1075)) (T -1237)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1252 (QUOTE |x|) *3)) (-4 *3 (-1075)) (-5 *1 (-1237 *3)))) (-3395 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1252 (QUOTE |x|) *4)) (-5 *1 (-1237 *4)) (-4 *4 (-1075)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 (QUOTE |x|))) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 (QUOTE |x|))) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) (-3121 (*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) (-4006 (*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) (-2669 (*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) (-3325 (*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) (-2860 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) (-3621 (*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) (-3368 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) (-3884 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 (QUOTE |x|))) (-5 *1 (-1237 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075))))) 
+(-13 (-1270 |#1|) (-10 -8 (-15 -1683 ($ (-1252 (QUOTE |x|) |#1|))) (-15 -3395 ((-1252 (QUOTE |x|) |#1|) $ (-790))) (-15 -1683 ($ (-1276 (QUOTE |x|)))) (-15 -3644 ($ $ (-1276 (QUOTE |x|)))) (-15 -3121 ($ $)) (-15 -4006 ($ $)) (-15 -2669 ($ $)) (-15 -3325 ($ $)) (-15 -2860 ($ $ (-592) (-592))) (-15 -3621 ($ $)) (-15 -3368 ($ (-592) (-592) $)) (-15 -3884 ($ (-592) (-592) $)) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 (QUOTE |x|)))) |noBranch|))) 
+((-2731 (((-1243 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1243 |#1| |#3| |#5|)) 23))) 
+(((-1238 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2731 ((-1243 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1243 |#1| |#3| |#5|)))) (-1075) (-1075) (-1191) (-1191) |#1| |#2|) (T -1238)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1243 *5 *7 *9)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-14 *7 (-1191)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1243 *6 *8 *10)) (-5 *1 (-1238 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1191))))) 
+(-10 -7 (-15 -2731 ((-1243 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1243 |#1| |#3| |#5|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 (-1103)) $) 70)) (-3983 (((-1191) $) 98)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2306 (($ $ (-592)) 93) (($ $ (-592) (-592)) 92)) (-2982 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) 100)) (-1588 (($ $) 127 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 110 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 155 (|has| |#1| (-388)))) (-3164 (((-444 $) $) 156 (|has| |#1| (-388)))) (-1442 (($ $) 109 (|has| |#1| (-43 (-433 (-592)))))) (-3652 (((-141) $ $) 146 (|has| |#1| (-388)))) (-1575 (($ $) 126 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 111 (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) 167)) (-1601 (($ $) 125 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 112 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) 16 T CONST)) (-1586 (($ $ $) 150 (|has| |#1| (-388)))) (-4593 (($ $) 59)) (-3371 (((-3 $ "failed") $) 33)) (-3247 (((-433 (-980 |#1|)) $ (-592)) 165 (|has| |#1| (-582))) (((-433 (-980 |#1|)) $ (-592) (-592)) 164 (|has| |#1| (-582)))) (-1599 (($ $ $) 149 (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 144 (|has| |#1| (-388)))) (-2802 (((-141) $) 157 (|has| |#1| (-388)))) (-2273 (((-141) $) 69)) (-1435 (($) 137 (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-592) $) 95) (((-592) $ (-592)) 94)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 108 (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) 96)) (-1376 (($ (-1 |#1| (-592)) $) 166)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 153 (|has| |#1| (-388)))) (-2027 (((-141) $) 61)) (-4526 (($ |#1| (-592)) 60) (($ $ (-1103) (-592)) 72) (($ $ (-658 (-1103)) (-658 (-592))) 71)) (-2731 (($ (-1 |#1| |#1|) $) 62)) (-4546 (($ $) 134 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 138 (|has| |#1| (-388)))) (-2750 (($ (-658 $)) 142 (|has| |#1| (-388))) (($ $ $) 141 (|has| |#1| (-388)))) (-2685 (((-1173) $) 9)) (-4552 (($ $) 158 (|has| |#1| (-388)))) (-3162 (($ $) 163 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 162 (-3836 (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-987)) (|has| |#1| (-1211)) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-43 (-433 (-592)))))))) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 143 (|has| |#1| (-388)))) (-3548 (($ (-658 $)) 140 (|has| |#1| (-388))) (($ $ $) 139 (|has| |#1| (-388)))) (-4500 (((-444 $) $) 154 (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 152 (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 151 (|has| |#1| (-388)))) (-2807 (($ $ (-592)) 90)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 145 (|has| |#1| (-388)))) (-1430 (($ $) 135 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-592)))))) (-2769 (((-790) $) 147 (|has| |#1| (-388)))) (-3927 ((|#1| $ (-592)) 99) (($ $ $) 76 (|has| (-592) (-1131)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 148 (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) 84 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-1191) (-790)) 83 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191))) 82 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-1191)) 81 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-790)) 79 (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (-4525 (((-592) $) 63)) (-1609 (($ $) 124 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 113 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 123 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 114 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 122 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 115 (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 68)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 46 (|has| |#1| (-194))) (($ (-433 (-592))) 56 (|has| |#1| (-43 (-433 (-592))))) (($ $) 48 (|has| |#1| (-582)))) (-1937 ((|#1| $ (-592)) 58)) (-1517 (((-3 $ "failed") $) 47 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-2838 ((|#1| $) 97)) (-1630 (($ $) 133 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 121 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-1617 (($ $) 132 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 120 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 131 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 119 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-592)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-592)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 130 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 118 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 129 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 117 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 128 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 116 (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 159 (|has| |#1| (-388)))) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) 88 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-1191) (-790)) 87 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191))) 86 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-1191)) 85 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-790)) 80 (|has| |#1| (-15 * (|#1| (-592) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388))) (($ $ $) 161 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 160 (|has| |#1| (-388))) (($ $ $) 136 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 107 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1239 |#1|) (-1311) (-1075)) (T -1239)) 
+((-2881 (*1 *1 *2) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))) (-4 *3 (-1075)) (-4 *1 (-1239 *3)))) (-1376 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-592))) (-4 *1 (-1239 *3)) (-4 *3 (-1075)))) (-3247 (*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1239 *4)) (-4 *4 (-1075)) (-4 *4 (-582)) (-5 *2 (-433 (-980 *4))))) (-3247 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1239 *4)) (-4 *4 (-1075)) (-4 *4 (-582)) (-5 *2 (-433 (-980 *4))))) (-3162 (*1 *1 *1) (-12 (-4 *1 (-1239 *2)) (-4 *2 (-1075)) (-4 *2 (-43 (-433 (-592)))))) (-3162 (*1 *1 *1 *2) (-3836 (-12 (-5 *2 (-1191)) (-4 *1 (-1239 *3)) (-4 *3 (-1075)) (-12 (-4 *3 (-29 (-592))) (-4 *3 (-987)) (-4 *3 (-1211)) (-4 *3 (-43 (-433 (-592)))))) (-12 (-5 *2 (-1191)) (-4 *1 (-1239 *3)) (-4 *3 (-1075)) (-12 (|has| *3 (-15 -4085 ((-658 *2) *3))) (|has| *3 (-15 -3162 (*3 *3 *2))) (-4 *3 (-43 (-433 (-592))))))))) 
+(-13 (-1257 |t#1| (-592)) (-10 -8 (-15 -2881 ($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |t#1|))))) (-15 -1376 ($ (-1 |t#1| (-592)) $)) (IF (|has| |t#1| (-582)) (PROGN (-15 -3247 ((-433 (-980 |t#1|)) $ (-592))) (-15 -3247 ((-433 (-980 |t#1|)) $ (-592) (-592)))) |noBranch|) (IF (|has| |t#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $)) (IF (|has| |t#1| (-15 -3162 (|t#1| |t#1| (-1191)))) (IF (|has| |t#1| (-15 -4085 ((-658 (-1191)) |t#1|))) (-15 -3162 ($ $ (-1191))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1211)) (IF (|has| |t#1| (-987)) (IF (|has| |t#1| (-29 (-592))) (-15 -3162 ($ $ (-1191))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1030)) (-6 (-1211))) |noBranch|) (IF (|has| |t#1| (-388)) (-6 (-388)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-592)) . T) ((-25) . T) ((-43 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-40) |has| |#1| (-43 (-433 (-592)))) ((-116) |has| |#1| (-43 (-433 (-592)))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-247) |has| |#1| (-15 * (|#1| (-592) |#1|))) ((-260) |has| |#1| (-388)) ((-301) |has| |#1| (-43 (-433 (-592)))) ((-303 $ $) |has| (-592) (-1131)) ((-307) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-323) |has| |#1| (-388)) ((-388) |has| |#1| (-388)) ((-477) |has| |#1| (-388)) ((-526) |has| |#1| (-43 (-433 (-592)))) ((-582) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-661 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) |has| |#1| (-388)) ((-734 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-743) . T) ((-922 (-1191)) -12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))) ((-1002 |#1| (-592) (-1103)) . T) ((-943) |has| |#1| (-388)) ((-1030) |has| |#1| (-43 (-433 (-592)))) ((-1081 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1211) |has| |#1| (-43 (-433 (-592)))) ((-1214) |has| |#1| (-43 (-433 (-592)))) ((-1235) |has| |#1| (-388)) ((-1257 |#1| (-592)) . T)) 
+((-2272 (((-141) $) 12)) (-4368 (((-3 |#3| "failed") $) 17) (((-3 (-1191) "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 (-592) "failed") $) NIL)) (-2400 ((|#3| $) 14) (((-1191) $) NIL) (((-433 (-592)) $) NIL) (((-592) $) NIL))) 
+(((-1240 |#1| |#2| |#3|) (-10 -8 (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-1191) |#1|)) (-15 -4368 ((-3 (-1191) "failed") |#1|)) (-15 -2400 (|#3| |#1|)) (-15 -4368 ((-3 |#3| "failed") |#1|)) (-15 -2272 ((-141) |#1|))) (-1241 |#2| |#3|) (-1075) (-1270 |#2|)) (T -1240)) 
+NIL 
+(-10 -8 (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -2400 ((-1191) |#1|)) (-15 -4368 ((-3 (-1191) "failed") |#1|)) (-15 -2400 (|#3| |#1|)) (-15 -4368 ((-3 |#3| "failed") |#1|)) (-15 -2272 ((-141) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-1505 ((|#2| $) 219 (-1732 (|has| |#2| (-323)) (|has| |#1| (-388))))) (-4085 (((-658 (-1103)) $) 70)) (-3983 (((-1191) $) 98)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2306 (($ $ (-592)) 93) (($ $ (-592) (-592)) 92)) (-2982 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) 100)) (-1444 ((|#2| $) 255)) (-2919 (((-3 |#2| "failed") $) 251)) (-1986 ((|#2| $) 252)) (-1588 (($ $) 127 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 110 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) 18)) (-4043 (((-444 (-1187 $)) (-1187 $)) 228 (-1732 (|has| |#2| (-931)) (|has| |#1| (-388))))) (-3743 (($ $) 154 (|has| |#1| (-388)))) (-3164 (((-444 $) $) 155 (|has| |#1| (-388)))) (-1442 (($ $) 109 (|has| |#1| (-43 (-433 (-592)))))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 225 (-1732 (|has| |#2| (-931)) (|has| |#1| (-388))))) (-3652 (((-141) $ $) 145 (|has| |#1| (-388)))) (-1575 (($ $) 126 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 111 (|has| |#1| (-43 (-433 (-592)))))) (-3940 (((-592) $) 237 (-1732 (|has| |#2| (-842)) (|has| |#1| (-388))))) (-2881 (($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) 166)) (-1601 (($ $) 125 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 112 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#2| "failed") $) 258) (((-3 (-592) "failed") $) 247 (-1732 (|has| |#2| (-1065 (-592))) (|has| |#1| (-388)))) (((-3 (-433 (-592)) "failed") $) 245 (-1732 (|has| |#2| (-1065 (-592))) (|has| |#1| (-388)))) (((-3 (-1191) "failed") $) 230 (-1732 (|has| |#2| (-1065 (-1191))) (|has| |#1| (-388))))) (-2400 ((|#2| $) 257) (((-592) $) 248 (-1732 (|has| |#2| (-1065 (-592))) (|has| |#1| (-388)))) (((-433 (-592)) $) 246 (-1732 (|has| |#2| (-1065 (-592))) (|has| |#1| (-388)))) (((-1191) $) 231 (-1732 (|has| |#2| (-1065 (-1191))) (|has| |#1| (-388))))) (-3792 (($ $) 254) (($ (-592) $) 253)) (-1586 (($ $ $) 149 (|has| |#1| (-388)))) (-4593 (($ $) 59)) (-3945 (((-706 |#2|) (-706 $)) 209 (|has| |#1| (-388))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) 208 (|has| |#1| (-388))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 207 (-1732 (|has| |#2| (-654 (-592))) (|has| |#1| (-388)))) (((-706 (-592)) (-706 $)) 206 (-1732 (|has| |#2| (-654 (-592))) (|has| |#1| (-388))))) (-3371 (((-3 $ "failed") $) 33)) (-3247 (((-433 (-980 |#1|)) $ (-592)) 164 (|has| |#1| (-582))) (((-433 (-980 |#1|)) $ (-592) (-592)) 163 (|has| |#1| (-582)))) (-4290 (($) 221 (-1732 (|has| |#2| (-574)) (|has| |#1| (-388))))) (-1599 (($ $ $) 148 (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 143 (|has| |#1| (-388)))) (-2802 (((-141) $) 156 (|has| |#1| (-388)))) (-1691 (((-141) $) 235 (-1732 (|has| |#2| (-842)) (|has| |#1| (-388))))) (-2273 (((-141) $) 69)) (-1435 (($) 137 (|has| |#1| (-43 (-433 (-592)))))) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 213 (-1732 (|has| |#2| (-908 (-405))) (|has| |#1| (-388)))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 212 (-1732 (|has| |#2| (-908 (-592))) (|has| |#1| (-388))))) (-4346 (((-592) $) 95) (((-592) $ (-592)) 94)) (-3558 (((-141) $) 30)) (-3838 (($ $) 217 (|has| |#1| (-388)))) (-1448 ((|#2| $) 215 (|has| |#1| (-388)))) (-4422 (($ $ (-592)) 108 (|has| |#1| (-43 (-433 (-592)))))) (-3921 (((-3 $ "failed") $) 249 (-1732 (|has| |#2| (-1165)) (|has| |#1| (-388))))) (-1324 (((-141) $) 236 (-1732 (|has| |#2| (-842)) (|has| |#1| (-388))))) (-3990 (($ $ (-944)) 96)) (-1376 (($ (-1 |#1| (-592)) $) 165)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 152 (|has| |#1| (-388)))) (-2027 (((-141) $) 61)) (-4526 (($ |#1| (-592)) 60) (($ $ (-1103) (-592)) 72) (($ $ (-658 (-1103)) (-658 (-592))) 71)) (-1837 (($ $ $) 239 (-1732 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3319 (($ $ $) 240 (-1732 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-2731 (($ (-1 |#1| |#1|) $) 62) (($ (-1 |#2| |#2|) $) 201 (|has| |#1| (-388)))) (-4546 (($ $) 134 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-2750 (($ (-658 $)) 141 (|has| |#1| (-388))) (($ $ $) 140 (|has| |#1| (-388)))) (-1994 (($ (-592) |#2|) 256)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 157 (|has| |#1| (-388)))) (-3162 (($ $) 162 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 161 (-3836 (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-987)) (|has| |#1| (-1211)) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-43 (-433 (-592)))))))) (-3703 (($) 250 (-1732 (|has| |#2| (-1165)) (|has| |#1| (-388))) CONST)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 142 (|has| |#1| (-388)))) (-3548 (($ (-658 $)) 139 (|has| |#1| (-388))) (($ $ $) 138 (|has| |#1| (-388)))) (-3856 (($ $) 220 (-1732 (|has| |#2| (-323)) (|has| |#1| (-388))))) (-2039 ((|#2| $) 223 (-1732 (|has| |#2| (-574)) (|has| |#1| (-388))))) (-1416 (((-444 (-1187 $)) (-1187 $)) 226 (-1732 (|has| |#2| (-931)) (|has| |#1| (-388))))) (-3339 (((-444 (-1187 $)) (-1187 $)) 227 (-1732 (|has| |#2| (-931)) (|has| |#1| (-388))))) (-4500 (((-444 $) $) 153 (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 150 (|has| |#1| (-388)))) (-2807 (($ $ (-592)) 90)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 144 (|has| |#1| (-388)))) (-1430 (($ $) 135 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-592))))) (($ $ (-1191) |#2|) 200 (-1732 (|has| |#2| (-547 (-1191) |#2|)) (|has| |#1| (-388)))) (($ $ (-658 (-1191)) (-658 |#2|)) 199 (-1732 (|has| |#2| (-547 (-1191) |#2|)) (|has| |#1| (-388)))) (($ $ (-658 (-310 |#2|))) 198 (-1732 (|has| |#2| (-325 |#2|)) (|has| |#1| (-388)))) (($ $ (-310 |#2|)) 197 (-1732 (|has| |#2| (-325 |#2|)) (|has| |#1| (-388)))) (($ $ |#2| |#2|) 196 (-1732 (|has| |#2| (-325 |#2|)) (|has| |#1| (-388)))) (($ $ (-658 |#2|) (-658 |#2|)) 195 (-1732 (|has| |#2| (-325 |#2|)) (|has| |#1| (-388))))) (-2769 (((-790) $) 146 (|has| |#1| (-388)))) (-3927 ((|#1| $ (-592)) 99) (($ $ $) 76 (|has| (-592) (-1131))) (($ $ |#2|) 194 (-1732 (|has| |#2| (-303 |#2| |#2|)) (|has| |#1| (-388))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 147 (|has| |#1| (-388)))) (-3644 (($ $ (-1 |#2| |#2|)) 205 (|has| |#1| (-388))) (($ $ (-1 |#2| |#2|) (-790)) 204 (|has| |#1| (-388))) (($ $ (-790)) 79 (-3836 (-1732 (|has| |#2| (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $) 77 (-3836 (-1732 (|has| |#2| (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) 84 (-3836 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))))) (($ $ (-1191) (-790)) 83 (-3836 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))))) (($ $ (-658 (-1191))) 82 (-3836 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))))) (($ $ (-1191)) 81 (-3836 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))))) (-2782 (($ $) 218 (|has| |#1| (-388)))) (-1456 ((|#2| $) 216 (|has| |#1| (-388)))) (-4525 (((-592) $) 63)) (-1609 (($ $) 124 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 113 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 123 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 114 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 122 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 115 (|has| |#1| (-43 (-433 (-592)))))) (-1778 (((-237) $) 234 (-1732 (|has| |#2| (-1049)) (|has| |#1| (-388)))) (((-405) $) 233 (-1732 (|has| |#2| (-1049)) (|has| |#1| (-388)))) (((-565) $) 232 (-1732 (|has| |#2| (-633 (-565))) (|has| |#1| (-388)))) (((-914 (-405)) $) 211 (-1732 (|has| |#2| (-633 (-914 (-405)))) (|has| |#1| (-388)))) (((-914 (-592)) $) 210 (-1732 (|has| |#2| (-633 (-914 (-592)))) (|has| |#1| (-388))))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 224 (-1732 (-1732 (|has| $ (-169)) (|has| |#2| (-931))) (|has| |#1| (-388))))) (-1700 (($ $) 68)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 46 (|has| |#1| (-194))) (($ |#2|) 259) (($ (-1191)) 229 (-1732 (|has| |#2| (-1065 (-1191))) (|has| |#1| (-388)))) (($ (-433 (-592))) 56 (|has| |#1| (-43 (-433 (-592))))) (($ $) 48 (|has| |#1| (-582)))) (-1937 ((|#1| $ (-592)) 58)) (-1517 (((-3 $ "failed") $) 47 (-3836 (-1732 (-3836 (|has| |#2| (-169)) (-1732 (|has| $ (-169)) (|has| |#2| (-931)))) (|has| |#1| (-388))) (|has| |#1| (-169))))) (-4010 (((-790)) 28)) (-2838 ((|#1| $) 97)) (-2744 ((|#2| $) 222 (-1732 (|has| |#2| (-574)) (|has| |#1| (-388))))) (-1630 (($ $) 133 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 121 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-1617 (($ $) 132 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 120 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 131 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 119 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-592)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-592)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 130 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 118 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 129 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 117 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 128 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 116 (|has| |#1| (-43 (-433 (-592)))))) (-1392 (($ $) 238 (-1732 (|has| |#2| (-842)) (|has| |#1| (-388))))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 158 (|has| |#1| (-388)))) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-1 |#2| |#2|)) 203 (|has| |#1| (-388))) (($ $ (-1 |#2| |#2|) (-790)) 202 (|has| |#1| (-388))) (($ $ (-790)) 80 (-3836 (-1732 (|has| |#2| (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $) 78 (-3836 (-1732 (|has| |#2| (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) 88 (-3836 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))))) (($ $ (-1191) (-790)) 87 (-3836 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))))) (($ $ (-658 (-1191))) 86 (-3836 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))))) (($ $ (-1191)) 85 (-3836 (-1732 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))))) (-3286 (((-141) $ $) 242 (-1732 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3273 (((-141) $ $) 243 (-1732 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 241 (-1732 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3266 (((-141) $ $) 244 (-1732 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388))) (($ $ $) 160 (|has| |#1| (-388))) (($ |#2| |#2|) 214 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 159 (|has| |#1| (-388))) (($ $ $) 136 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 107 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ $ |#2|) 193 (|has| |#1| (-388))) (($ |#2| $) 192 (|has| |#1| (-388))) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1241 |#1| |#2|) (-1311) (-1075) (-1270 |t#1|)) (T -1241)) 
+((-4525 (*1 *2 *1) (-12 (-4 *1 (-1241 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1270 *3)) (-5 *2 (-592)))) (-1683 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *1 (-1241 *3 *2)) (-4 *2 (-1270 *3)))) (-1994 (*1 *1 *2 *3) (-12 (-5 *2 (-592)) (-4 *4 (-1075)) (-4 *1 (-1241 *4 *3)) (-4 *3 (-1270 *4)))) (-1444 (*1 *2 *1) (-12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1270 *3)))) (-3792 (*1 *1 *1) (-12 (-4 *1 (-1241 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-1270 *2)))) (-3792 (*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-1241 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1270 *3)))) (-1986 (*1 *2 *1) (-12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1270 *3)))) (-2919 (*1 *2 *1) (|partial| -12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1270 *3))))) 
+(-13 (-1239 |t#1|) (-1065 |t#2|) (-10 -8 (-15 -1994 ($ (-592) |t#2|)) (-15 -4525 ((-592) $)) (-15 -1444 (|t#2| $)) (-15 -3792 ($ $)) (-15 -3792 ($ (-592) $)) (-15 -1683 ($ |t#2|)) (-15 -1986 (|t#2| $)) (-15 -2919 ((-3 |t#2| "failed") $)) (IF (|has| |t#1| (-388)) (-6 (-1021 |t#2|)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-592)) . T) ((-25) . T) ((-43 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-43 |#1|) |has| |#1| (-194)) ((-43 |#2|) |has| |#1| (-388)) ((-43 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-40) |has| |#1| (-43 (-433 (-592)))) ((-116) |has| |#1| (-43 (-433 (-592)))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-140 |#1| |#1|) . T) ((-140 |#2| |#2|) |has| |#1| (-388)) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-158) . T) ((-169) -3836 (-12 (|has| |#1| (-388)) (|has| |#2| (-169))) (|has| |#1| (-169))) ((-171) -3836 (-12 (|has| |#1| (-388)) (|has| |#2| (-171))) (|has| |#1| (-171))) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-633 (-237)) -12 (|has| |#1| (-388)) (|has| |#2| (-1049))) ((-633 (-405)) -12 (|has| |#1| (-388)) (|has| |#2| (-1049))) ((-633 (-565)) -12 (|has| |#1| (-388)) (|has| |#2| (-633 (-565)))) ((-633 (-914 (-405))) -12 (|has| |#1| (-388)) (|has| |#2| (-633 (-914 (-405))))) ((-633 (-914 (-592))) -12 (|has| |#1| (-388)) (|has| |#2| (-633 (-914 (-592))))) ((-245 |#2|) |has| |#1| (-388)) ((-247) -3836 (-12 (|has| |#1| (-388)) (|has| |#2| (-247))) (|has| |#1| (-15 * (|#1| (-592) |#1|)))) ((-260) |has| |#1| (-388)) ((-301) |has| |#1| (-43 (-433 (-592)))) ((-303 |#2| $) -12 (|has| |#1| (-388)) (|has| |#2| (-303 |#2| |#2|))) ((-303 $ $) |has| (-592) (-1131)) ((-307) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-323) |has| |#1| (-388)) ((-325 |#2|) -12 (|has| |#1| (-388)) (|has| |#2| (-325 |#2|))) ((-388) |has| |#1| (-388)) ((-358 |#2|) |has| |#1| (-388)) ((-403 |#2|) |has| |#1| (-388)) ((-426 |#2|) |has| |#1| (-388)) ((-477) |has| |#1| (-388)) ((-526) |has| |#1| (-43 (-433 (-592)))) ((-547 (-1191) |#2|) -12 (|has| |#1| (-388)) (|has| |#2| (-547 (-1191) |#2|))) ((-547 |#2| |#2|) -12 (|has| |#1| (-388)) (|has| |#2| (-325 |#2|))) ((-582) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-661 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-661 |#1|) . T) ((-661 |#2|) |has| |#1| (-388)) ((-661 $) . T) ((-678) |has| |#1| (-388)) ((-654 (-592)) -12 (|has| |#1| (-388)) (|has| |#2| (-654 (-592)))) ((-654 |#2|) |has| |#1| (-388)) ((-734 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-734 |#1|) |has| |#1| (-194)) ((-734 |#2|) |has| |#1| (-388)) ((-734 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-743) . T) ((-813) -12 (|has| |#1| (-388)) (|has| |#2| (-842))) ((-814) -12 (|has| |#1| (-388)) (|has| |#2| (-842))) ((-816) -12 (|has| |#1| (-388)) (|has| |#2| (-842))) ((-817) -12 (|has| |#1| (-388)) (|has| |#2| (-842))) ((-842) -12 (|has| |#1| (-388)) (|has| |#2| (-842))) ((-867) -12 (|has| |#1| (-388)) (|has| |#2| (-842))) ((-869) -3836 (-12 (|has| |#1| (-388)) (|has| |#2| (-869))) (-12 (|has| |#1| (-388)) (|has| |#2| (-842)))) ((-922 (-1191)) -3836 (-12 (|has| |#1| (-388)) (|has| |#2| (-922 (-1191)))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))) ((-908 (-405)) -12 (|has| |#1| (-388)) (|has| |#2| (-908 (-405)))) ((-908 (-592)) -12 (|has| |#1| (-388)) (|has| |#2| (-908 (-592)))) ((-906 |#2|) |has| |#1| (-388)) ((-931) -12 (|has| |#1| (-388)) (|has| |#2| (-931))) ((-1002 |#1| (-592) (-1103)) . T) ((-943) |has| |#1| (-388)) ((-1021 |#2|) |has| |#1| (-388)) ((-1030) |has| |#1| (-43 (-433 (-592)))) ((-1049) -12 (|has| |#1| (-388)) (|has| |#2| (-1049))) ((-1065 (-433 (-592))) -12 (|has| |#1| (-388)) (|has| |#2| (-1065 (-592)))) ((-1065 (-592)) -12 (|has| |#1| (-388)) (|has| |#2| (-1065 (-592)))) ((-1065 (-1191)) -12 (|has| |#1| (-388)) (|has| |#2| (-1065 (-1191)))) ((-1065 |#2|) . T) ((-1081 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-1081 |#1|) . T) ((-1081 |#2|) |has| |#1| (-388)) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) -12 (|has| |#1| (-388)) (|has| |#2| (-1165))) ((-1211) |has| |#1| (-43 (-433 (-592)))) ((-1214) |has| |#1| (-43 (-433 (-592)))) ((-1225) |has| |#1| (-388)) ((-1235) |has| |#1| (-388)) ((-1239 |#1|) . T) ((-1257 |#1| (-592)) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 70)) (-1505 ((|#2| $) NIL (-12 (|has| |#2| (-323)) (|has| |#1| (-388))))) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 88)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-592)) 97) (($ $ (-592) (-592)) 99)) (-2982 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) 47)) (-1444 ((|#2| $) 11)) (-2919 (((-3 |#2| "failed") $) 30)) (-1986 ((|#2| $) 31)) (-1588 (($ $) 192 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 168 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| |#2| (-931)) (|has| |#1| (-388))))) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (-12 (|has| |#2| (-931)) (|has| |#1| (-388))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) 188 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 164 (|has| |#1| (-43 (-433 (-592)))))) (-3940 (((-592) $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-388))))) (-2881 (($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) 57)) (-1601 (($ $) 196 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 172 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) 144) (((-3 (-592) "failed") $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#1| (-388)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#1| (-388)))) (((-3 (-1191) "failed") $) NIL (-12 (|has| |#2| (-1065 (-1191))) (|has| |#1| (-388))))) (-2400 ((|#2| $) 143) (((-592) $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#1| (-388)))) (((-433 (-592)) $) NIL (-12 (|has| |#2| (-1065 (-592))) (|has| |#1| (-388)))) (((-1191) $) NIL (-12 (|has| |#2| (-1065 (-1191))) (|has| |#1| (-388))))) (-3792 (($ $) 61) (($ (-592) $) 24)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3945 (((-706 |#2|) (-706 $)) NIL (|has| |#1| (-388))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL (|has| |#1| (-388))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#1| (-388)))) (((-706 (-592)) (-706 $)) NIL (-12 (|has| |#2| (-654 (-592))) (|has| |#1| (-388))))) (-3371 (((-3 $ "failed") $) 77)) (-3247 (((-433 (-980 |#1|)) $ (-592)) 112 (|has| |#1| (-582))) (((-433 (-980 |#1|)) $ (-592) (-592)) 114 (|has| |#1| (-582)))) (-4290 (($) NIL (-12 (|has| |#2| (-574)) (|has| |#1| (-388))))) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-1691 (((-141) $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-388))))) (-2273 (((-141) $) 64)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| |#2| (-908 (-405))) (|has| |#1| (-388)))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| |#2| (-908 (-592))) (|has| |#1| (-388))))) (-4346 (((-592) $) 93) (((-592) $ (-592)) 95)) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL (|has| |#1| (-388)))) (-1448 ((|#2| $) 151 (|has| |#1| (-388)))) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3921 (((-3 $ "failed") $) NIL (-12 (|has| |#2| (-1165)) (|has| |#1| (-388))))) (-1324 (((-141) $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-388))))) (-3990 (($ $ (-944)) 136)) (-1376 (($ (-1 |#1| (-592)) $) 132)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-592)) 19) (($ $ (-1103) (-592)) NIL) (($ $ (-658 (-1103)) (-658 (-592))) NIL)) (-1837 (($ $ $) NIL (-12 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3319 (($ $ $) NIL (-12 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-2731 (($ (-1 |#1| |#1|) $) 129) (($ (-1 |#2| |#2|) $) NIL (|has| |#1| (-388)))) (-4546 (($ $) 162 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-1994 (($ (-592) |#2|) 10)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 145 (|has| |#1| (-388)))) (-3162 (($ $) 214 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 219 (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211)))))) (-3703 (($) NIL (-12 (|has| |#2| (-1165)) (|has| |#1| (-388))) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-3856 (($ $) NIL (-12 (|has| |#2| (-323)) (|has| |#1| (-388))))) (-2039 ((|#2| $) NIL (-12 (|has| |#2| (-574)) (|has| |#1| (-388))))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| |#2| (-931)) (|has| |#1| (-388))))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| |#2| (-931)) (|has| |#1| (-388))))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-2807 (($ $ (-592)) 126)) (-3616 (((-3 $ "failed") $ $) 116 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-1430 (($ $) 160 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) 85 (|has| |#1| (-15 ** (|#1| |#1| (-592))))) (($ $ (-1191) |#2|) NIL (-12 (|has| |#2| (-547 (-1191) |#2|)) (|has| |#1| (-388)))) (($ $ (-658 (-1191)) (-658 |#2|)) NIL (-12 (|has| |#2| (-547 (-1191) |#2|)) (|has| |#1| (-388)))) (($ $ (-658 (-310 |#2|))) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#1| (-388)))) (($ $ (-310 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#1| (-388)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#1| (-388)))) (($ $ (-658 |#2|) (-658 |#2|)) NIL (-12 (|has| |#2| (-325 |#2|)) (|has| |#1| (-388))))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ (-592)) 91) (($ $ $) 79 (|has| (-592) (-1131))) (($ $ |#2|) NIL (-12 (|has| |#2| (-303 |#2| |#2|)) (|has| |#1| (-388))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-3644 (($ $ (-1 |#2| |#2|)) NIL (|has| |#1| (-388))) (($ $ (-1 |#2| |#2|) (-790)) NIL (|has| |#1| (-388))) (($ $ (-790)) NIL (-3836 (-12 (|has| |#2| (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $) 137 (-3836 (-12 (|has| |#2| (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-3836 (-12 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191) (-790)) NIL (-3836 (-12 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-658 (-1191))) NIL (-3836 (-12 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191)) 140 (-3836 (-12 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))))) (-2782 (($ $) NIL (|has| |#1| (-388)))) (-1456 ((|#2| $) 152 (|has| |#1| (-388)))) (-4525 (((-592) $) 12)) (-1609 (($ $) 198 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 174 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 194 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 170 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 190 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 166 (|has| |#1| (-43 (-433 (-592)))))) (-1778 (((-237) $) NIL (-12 (|has| |#2| (-1049)) (|has| |#1| (-388)))) (((-405) $) NIL (-12 (|has| |#2| (-1049)) (|has| |#1| (-388)))) (((-565) $) NIL (-12 (|has| |#2| (-633 (-565))) (|has| |#1| (-388)))) (((-914 (-405)) $) NIL (-12 (|has| |#2| (-633 (-914 (-405)))) (|has| |#1| (-388)))) (((-914 (-592)) $) NIL (-12 (|has| |#2| (-633 (-914 (-592)))) (|has| |#1| (-388))))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#2| (-931)) (|has| |#1| (-388))))) (-1700 (($ $) 124)) (-1683 (((-877) $) 242) (($ (-592)) 23) (($ |#1|) 21 (|has| |#1| (-194))) (($ |#2|) 20) (($ (-1191)) NIL (-12 (|has| |#2| (-1065 (-1191))) (|has| |#1| (-388)))) (($ (-433 (-592))) 155 (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582)))) (-1937 ((|#1| $ (-592)) 74)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#2| (-931)) (|has| |#1| (-388))) (-12 (|has| |#2| (-169)) (|has| |#1| (-388))) (|has| |#1| (-169))))) (-4010 (((-790)) 142)) (-2838 ((|#1| $) 90)) (-2744 ((|#2| $) NIL (-12 (|has| |#2| (-574)) (|has| |#1| (-388))))) (-1630 (($ $) 204 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 180 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) 200 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 176 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 208 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 184 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-592)) 122 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-592)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 210 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 186 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 206 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 182 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 202 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 178 (|has| |#1| (-43 (-433 (-592)))))) (-1392 (($ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-388))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 13 T CONST)) (-4257 (($) 17 T CONST)) (-1940 (($ $ (-1 |#2| |#2|)) NIL (|has| |#1| (-388))) (($ $ (-1 |#2| |#2|) (-790)) NIL (|has| |#1| (-388))) (($ $ (-790)) NIL (-3836 (-12 (|has| |#2| (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $) NIL (-3836 (-12 (|has| |#2| (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-3836 (-12 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191) (-790)) NIL (-3836 (-12 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-658 (-1191))) NIL (-3836 (-12 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| |#2| (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))))) (-3286 (((-141) $ $) NIL (-12 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3273 (((-141) $ $) NIL (-12 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3255 (((-141) $ $) 63)) (-3279 (((-141) $ $) NIL (-12 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3266 (((-141) $ $) NIL (-12 (|has| |#2| (-869)) (|has| |#1| (-388))))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) 149 (|has| |#1| (-388))) (($ |#2| |#2|) 150 (|has| |#1| (-388)))) (-3306 (($ $) 213) (($ $ $) 68)) (-3300 (($ $ $) 66)) (** (($ $ (-944)) NIL) (($ $ (-790)) 73) (($ $ (-592)) 146 (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 158 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 69) (($ $ |#1|) NIL) (($ |#1| $) 139) (($ $ |#2|) 148 (|has| |#1| (-388))) (($ |#2| $) 147 (|has| |#1| (-388))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1242 |#1| |#2|) (-1241 |#1| |#2|) (-1075) (-1270 |#1|)) (T -1242)) 
 NIL 
 (-1241 |#1| |#2|) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 11)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) NIL (|has| |#1| (-562)))) (-2525 (($ $ (-413 (-572))) NIL) (($ $ (-413 (-572)) (-413 (-572))) NIL)) (-2640 (((-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|))) $) NIL)) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-2844 (($ $) NIL (|has| |#1| (-368)))) (-1466 (((-424 $) $) NIL (|has| |#1| (-368)))) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3112 (((-121) $ $) NIL (|has| |#1| (-368)))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-769) (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#1|)))) NIL)) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-1222 |#1| |#2| |#3|) "failed") $) 19) (((-3 (-1250 |#1| |#2| |#3|) "failed") $) 22)) (-1318 (((-1222 |#1| |#2| |#3|) $) NIL) (((-1250 |#1| |#2| |#3|) $) NIL)) (-2190 (($ $ $) NIL (|has| |#1| (-368)))) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-4329 (((-413 (-572)) $) 57)) (-2208 (($ $ $) NIL (|has| |#1| (-368)))) (-1889 (($ (-413 (-572)) (-1222 |#1| |#2| |#3|)) NIL)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) NIL (|has| |#1| (-368)))) (-1526 (((-121) $) NIL (|has| |#1| (-368)))) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-413 (-572)) $) NIL) (((-413 (-572)) $ (-413 (-572))) NIL)) (-3893 (((-121) $) NIL)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) NIL) (($ $ (-413 (-572))) NIL)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-413 (-572))) 29) (($ $ (-1082) (-413 (-572))) NIL) (($ $ (-638 (-1082)) (-638 (-413 (-572)))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1629 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-4170 (((-1222 |#1| |#2| |#3|) $) 60)) (-2475 (((-3 (-1222 |#1| |#2| |#3|) "failed") $) NIL)) (-1885 (((-1222 |#1| |#2| |#3|) $) NIL)) (-1658 (((-1152) $) NIL)) (-4350 (($ $) NIL (|has| |#1| (-368)))) (-2774 (($ $) 38 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) NIL (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 |#2|)) 39 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) NIL (|has| |#1| (-368)))) (-3069 (($ (-638 $)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-4304 (((-424 $) $) NIL (|has| |#1| (-368)))) (-3087 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-368))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) NIL (|has| |#1| (-368)))) (-1977 (($ $ (-413 (-572))) NIL)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4354 (((-3 (-638 $) "failed") (-638 $) $) NIL (|has| |#1| (-368)))) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))))) (-4029 (((-769) $) NIL (|has| |#1| (-368)))) (-3277 ((|#1| $ (-413 (-572))) NIL) (($ $ $) NIL (|has| (-413 (-572)) (-1110)))) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) NIL (|has| |#1| (-368)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) 36 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $ (-1255 |#2|)) 37)) (-4316 (((-413 (-572)) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) NIL)) (-3972 (((-856) $) 87) (($ (-572)) NIL) (($ |#1|) NIL (|has| |#1| (-174))) (($ (-1222 |#1| |#2| |#3|)) 16) (($ (-1250 |#1| |#2| |#3|)) 17) (($ (-1255 |#2|)) 35) (($ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562)))) (-1958 ((|#1| $ (-413 (-572))) NIL)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) 12)) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-413 (-572))) 62 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-413 (-572))))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368)))) (-2378 (($) 31 T CONST)) (-3255 (($) 26 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-413 (-572)) |#1|))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 33)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ (-572)) NIL (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1243 |#1| |#2| |#3|) (-13 (-1241 |#1| (-1222 |#1| |#2| |#3|)) (-1044 (-1250 |#1| |#2| |#3|)) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) (-1054) (-1170) |#1|) (T -1243)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3)))) 
-(-13 (-1241 |#1| (-1222 |#1| |#2| |#3|)) (-1044 (-1250 |#1| |#2| |#3|)) (-10 -8 (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 32)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL)) (-3946 (($ $) NIL)) (-3686 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 (-572) "failed") $) NIL (|has| (-1243 |#2| |#3| |#4|) (-1044 (-572)))) (((-3 (-413 (-572)) "failed") $) NIL (|has| (-1243 |#2| |#3| |#4|) (-1044 (-413 (-572))))) (((-3 (-1243 |#2| |#3| |#4|) "failed") $) 20)) (-1318 (((-572) $) NIL (|has| (-1243 |#2| |#3| |#4|) (-1044 (-572)))) (((-413 (-572)) $) NIL (|has| (-1243 |#2| |#3| |#4|) (-1044 (-413 (-572))))) (((-1243 |#2| |#3| |#4|) $) NIL)) (-4383 (($ $) 33)) (-1799 (((-3 $ "failed") $) 25)) (-3988 (($ $) NIL (|has| (-1243 |#2| |#3| |#4|) (-457)))) (-3977 (($ $ (-1243 |#2| |#3| |#4|) (-316 |#2| |#3| |#4|) $) NIL)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) 11)) (-4581 (((-121) $) NIL)) (-4328 (($ (-1243 |#2| |#3| |#4|) (-316 |#2| |#3| |#4|)) 23)) (-1784 (((-316 |#2| |#3| |#4|) $) NIL)) (-3918 (($ (-1 (-316 |#2| |#3| |#4|) (-316 |#2| |#3| |#4|)) $) NIL)) (-3828 (($ (-1 (-1243 |#2| |#3| |#4|) (-1243 |#2| |#3| |#4|)) $) NIL)) (-2022 (((-3 (-841 |#2|) "failed") $) 72)) (-4368 (($ $) NIL)) (-4373 (((-1243 |#2| |#3| |#4|) $) 18)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4357 (((-121) $) NIL)) (-4362 (((-1243 |#2| |#3| |#4|) $) NIL)) (-1803 (((-3 $ "failed") $ (-1243 |#2| |#3| |#4|)) NIL (|has| (-1243 |#2| |#3| |#4|) (-562))) (((-3 $ "failed") $ $) NIL)) (-3476 (((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1243 |#2| |#3| |#4|)) (|:| |%expon| (-316 |#2| |#3| |#4|)) (|:| |%expTerms| (-638 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#2|)))))) (|:| |%type| (-1152))) "failed") $) 55)) (-4316 (((-316 |#2| |#3| |#4|) $) 14)) (-3694 (((-1243 |#2| |#3| |#4|) $) NIL (|has| (-1243 |#2| |#3| |#4|) (-457)))) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ (-1243 |#2| |#3| |#4|)) NIL) (($ $) NIL) (($ (-413 (-572))) NIL (-1841 (|has| (-1243 |#2| |#3| |#4|) (-43 (-413 (-572)))) (|has| (-1243 |#2| |#3| |#4|) (-1044 (-413 (-572))))))) (-3193 (((-638 (-1243 |#2| |#3| |#4|)) $) NIL)) (-1958 (((-1243 |#2| |#3| |#4|) $ (-316 |#2| |#3| |#4|)) NIL)) (-2779 (((-3 $ "failed") $) NIL (|has| (-1243 |#2| |#3| |#4|) (-149)))) (-2140 (((-769)) NIL)) (-2565 (($ $ $ (-769)) NIL (|has| (-1243 |#2| |#3| |#4|) (-174)))) (-3774 (((-121) $ $) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 60 T CONST)) (-3255 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ (-1243 |#2| |#3| |#4|)) NIL (|has| (-1243 |#2| |#3| |#4|) (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ (-1243 |#2| |#3| |#4|)) NIL) (($ (-1243 |#2| |#3| |#4|) $) NIL) (($ (-413 (-572)) $) NIL (|has| (-1243 |#2| |#3| |#4|) (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| (-1243 |#2| |#3| |#4|) (-43 (-413 (-572))))))) 
-(((-1244 |#1| |#2| |#3| |#4|) (-13 (-326 (-1243 |#2| |#3| |#4|) (-316 |#2| |#3| |#4|)) (-562) (-10 -8 (-15 -2022 ((-3 (-841 |#2|) "failed") $)) (-15 -3476 ((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1243 |#2| |#3| |#4|)) (|:| |%expon| (-316 |#2| |#3| |#4|)) (|:| |%expTerms| (-638 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#2|)))))) (|:| |%type| (-1152))) "failed") $)))) (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457)) (-13 (-27) (-1190) (-436 |#1|)) (-1170) |#2|) (T -1244)) 
-((-2022 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457))) (-5 *2 (-841 *4)) (-5 *1 (-1244 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1190) (-436 *3))) (-14 *5 (-1170)) (-14 *6 *4))) (-3476 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457))) (-5 *2 (-2 (|:| |%term| (-2 (|:| |%coef| (-1243 *4 *5 *6)) (|:| |%expon| (-316 *4 *5 *6)) (|:| |%expTerms| (-638 (-2 (|:| |k| (-413 (-572))) (|:| |c| *4)))))) (|:| |%type| (-1152)))) (-5 *1 (-1244 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1190) (-436 *3))) (-14 *5 (-1170)) (-14 *6 *4)))) 
-(-13 (-326 (-1243 |#2| |#3| |#4|) (-316 |#2| |#3| |#4|)) (-562) (-10 -8 (-15 -2022 ((-3 (-841 |#2|) "failed") $)) (-15 -3476 ((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1243 |#2| |#3| |#4|)) (|:| |%expon| (-316 |#2| |#3| |#4|)) (|:| |%expTerms| (-638 (-2 (|:| |k| (-413 (-572))) (|:| |c| |#2|)))))) (|:| |%type| (-1152))) "failed") $)))) 
-((-2148 ((|#2| $) 28)) (-4230 ((|#2| $) 18)) (-4232 (($ $) 35)) (-4390 (($ $ (-572)) 63)) (-1946 (((-121) $ (-769)) 32)) (-4436 ((|#2| $ |#2|) 60)) (-2656 ((|#2| $ |#2|) 58)) (-3283 ((|#2| $ "value" |#2|) NIL) ((|#2| $ "first" |#2|) 51) (($ $ "rest" $) 55) ((|#2| $ "last" |#2|) 53)) (-2155 (($ $ (-638 $)) 59)) (-4066 ((|#2| $) 17)) (-1651 (($ $) NIL) (($ $ (-769)) 41)) (-2202 (((-638 $) $) 25)) (-1303 (((-121) $ $) 49)) (-2157 (((-121) $ (-769)) 31)) (-3524 (((-121) $ (-769)) 30)) (-3113 (((-121) $) 27)) (-3253 ((|#2| $) 23) (($ $ (-769)) 45)) (-3277 ((|#2| $ "value") NIL) ((|#2| $ "first") 10) (($ $ "rest") 16) ((|#2| $ "last") 13)) (-1791 (((-121) $) 21)) (-2619 (($ $) 38)) (-3316 (($ $) 64)) (-1471 (((-769) $) 40)) (-3622 (($ $) 39)) (-4500 (($ $ $) 57) (($ |#2| $) NIL)) (-4118 (((-638 $) $) 26)) (-1324 (((-121) $ $) 47)) (-4032 (((-769) $) 34))) 
-(((-1245 |#1| |#2|) (-10 -8 (-15 -4390 (|#1| |#1| (-572))) (-15 -3283 (|#2| |#1| "last" |#2|)) (-15 -2656 (|#2| |#1| |#2|)) (-15 -3283 (|#1| |#1| "rest" |#1|)) (-15 -3283 (|#2| |#1| "first" |#2|)) (-15 -3316 (|#1| |#1|)) (-15 -2619 (|#1| |#1|)) (-15 -1471 ((-769) |#1|)) (-15 -3622 (|#1| |#1|)) (-15 -4230 (|#2| |#1|)) (-15 -4066 (|#2| |#1|)) (-15 -4232 (|#1| |#1|)) (-15 -3253 (|#1| |#1| (-769))) (-15 -3277 (|#2| |#1| "last")) (-15 -3253 (|#2| |#1|)) (-15 -1651 (|#1| |#1| (-769))) (-15 -3277 (|#1| |#1| "rest")) (-15 -1651 (|#1| |#1|)) (-15 -3277 (|#2| |#1| "first")) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#1|)) (-15 -4436 (|#2| |#1| |#2|)) (-15 -3283 (|#2| |#1| "value" |#2|)) (-15 -2155 (|#1| |#1| (-638 |#1|))) (-15 -1303 ((-121) |#1| |#1|)) (-15 -1791 ((-121) |#1|)) (-15 -3277 (|#2| |#1| "value")) (-15 -2148 (|#2| |#1|)) (-15 -3113 ((-121) |#1|)) (-15 -2202 ((-638 |#1|) |#1|)) (-15 -4118 ((-638 |#1|) |#1|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -4032 ((-769) |#1|)) (-15 -1946 ((-121) |#1| (-769))) (-15 -2157 ((-121) |#1| (-769))) (-15 -3524 ((-121) |#1| (-769)))) (-1246 |#2|) (-1204)) (T -1245)) 
-NIL 
-(-10 -8 (-15 -4390 (|#1| |#1| (-572))) (-15 -3283 (|#2| |#1| "last" |#2|)) (-15 -2656 (|#2| |#1| |#2|)) (-15 -3283 (|#1| |#1| "rest" |#1|)) (-15 -3283 (|#2| |#1| "first" |#2|)) (-15 -3316 (|#1| |#1|)) (-15 -2619 (|#1| |#1|)) (-15 -1471 ((-769) |#1|)) (-15 -3622 (|#1| |#1|)) (-15 -4230 (|#2| |#1|)) (-15 -4066 (|#2| |#1|)) (-15 -4232 (|#1| |#1|)) (-15 -3253 (|#1| |#1| (-769))) (-15 -3277 (|#2| |#1| "last")) (-15 -3253 (|#2| |#1|)) (-15 -1651 (|#1| |#1| (-769))) (-15 -3277 (|#1| |#1| "rest")) (-15 -1651 (|#1| |#1|)) (-15 -3277 (|#2| |#1| "first")) (-15 -4500 (|#1| |#2| |#1|)) (-15 -4500 (|#1| |#1| |#1|)) (-15 -4436 (|#2| |#1| |#2|)) (-15 -3283 (|#2| |#1| "value" |#2|)) (-15 -2155 (|#1| |#1| (-638 |#1|))) (-15 -1303 ((-121) |#1| |#1|)) (-15 -1791 ((-121) |#1|)) (-15 -3277 (|#2| |#1| "value")) (-15 -2148 (|#2| |#1|)) (-15 -3113 ((-121) |#1|)) (-15 -2202 ((-638 |#1|) |#1|)) (-15 -4118 ((-638 |#1|) |#1|)) (-15 -1324 ((-121) |#1| |#1|)) (-15 -4032 ((-769) |#1|)) (-15 -1946 ((-121) |#1| (-769))) (-15 -2157 ((-121) |#1| (-769))) (-15 -3524 ((-121) |#1| (-769)))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-2148 ((|#1| $) 45)) (-4230 ((|#1| $) 62)) (-4232 (($ $) 64)) (-4390 (($ $ (-572)) 49 (|has| $ (-6 -4603)))) (-1946 (((-121) $ (-769)) 8)) (-4436 ((|#1| $ |#1|) 36 (|has| $ (-6 -4603)))) (-3749 (($ $ $) 53 (|has| $ (-6 -4603)))) (-2656 ((|#1| $ |#1|) 51 (|has| $ (-6 -4603)))) (-4055 ((|#1| $ |#1|) 55 (|has| $ (-6 -4603)))) (-3283 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4603))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4603))) (($ $ "rest" $) 52 (|has| $ (-6 -4603))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4603)))) (-2155 (($ $ (-638 $)) 38 (|has| $ (-6 -4603)))) (-4066 ((|#1| $) 63)) (-2211 (($) 7 T CONST)) (-1651 (($ $) 70) (($ $ (-769)) 68)) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-2202 (((-638 $) $) 47)) (-1303 (((-121) $ $) 39 (|has| |#1| (-1098)))) (-2157 (((-121) $ (-769)) 9)) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35)) (-3524 (((-121) $ (-769)) 10)) (-2699 (((-638 |#1|) $) 42)) (-3113 (((-121) $) 46)) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-3253 ((|#1| $) 67) (($ $ (-769)) 65)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 73) (($ $ (-769)) 71)) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66)) (-3537 (((-572) $ $) 41)) (-1791 (((-121) $) 43)) (-2619 (($ $) 59)) (-3316 (($ $) 56 (|has| $ (-6 -4603)))) (-1471 (((-769) $) 60)) (-3622 (($ $) 61)) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-1607 (($ $) 13)) (-2977 (($ $ $) 58 (|has| $ (-6 -4603))) (($ $ |#1|) 57 (|has| $ (-6 -4603)))) (-4500 (($ $ $) 75) (($ |#1| $) 74)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-4118 (((-638 $) $) 48)) (-3432 (((-121) $ $) 40 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1246 |#1|) (-1290) (-1204)) (T -1246)) 
-((-4500 (*1 *1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-4500 (*1 *1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-1837 (*1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 "first") (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-1837 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) (-1651 (*1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3277 (*1 *1 *1 *2) (-12 (-5 *2 "rest") (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) (-1651 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) (-3253 (*1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3277 (*1 *2 *1 *3) (-12 (-5 *3 "last") (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3253 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) (-4232 (*1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-4066 (*1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-4230 (*1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3622 (*1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-1471 (*1 *2 *1) (-12 (-4 *1 (-1246 *3)) (-4 *3 (-1204)) (-5 *2 (-769)))) (-2619 (*1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-2977 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-2977 (*1 *1 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3316 (*1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-4055 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3283 (*1 *2 *1 *3 *2) (-12 (-5 *3 "first") (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3749 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3283 (*1 *1 *1 *2 *1) (-12 (-5 *2 "rest") (|has| *1 (-6 -4603)) (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) (-2656 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-3283 (*1 *2 *1 *3 *2) (-12 (-5 *3 "last") (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) (-4390 (*1 *1 *1 *2) (-12 (-5 *2 (-572)) (|has| *1 (-6 -4603)) (-4 *1 (-1246 *3)) (-4 *3 (-1204))))) 
-(-13 (-1017 |t#1|) (-10 -8 (-15 -4500 ($ $ $)) (-15 -4500 ($ |t#1| $)) (-15 -1837 (|t#1| $)) (-15 -3277 (|t#1| $ "first")) (-15 -1837 ($ $ (-769))) (-15 -1651 ($ $)) (-15 -3277 ($ $ "rest")) (-15 -1651 ($ $ (-769))) (-15 -3253 (|t#1| $)) (-15 -3277 (|t#1| $ "last")) (-15 -3253 ($ $ (-769))) (-15 -4232 ($ $)) (-15 -4066 (|t#1| $)) (-15 -4230 (|t#1| $)) (-15 -3622 ($ $)) (-15 -1471 ((-769) $)) (-15 -2619 ($ $)) (IF (|has| $ (-6 -4603)) (PROGN (-15 -2977 ($ $ $)) (-15 -2977 ($ $ |t#1|)) (-15 -3316 ($ $)) (-15 -4055 (|t#1| $ |t#1|)) (-15 -3283 (|t#1| $ "first" |t#1|)) (-15 -3749 ($ $ $)) (-15 -3283 ($ $ "rest" $)) (-15 -2656 (|t#1| $ |t#1|)) (-15 -3283 (|t#1| $ "last" |t#1|)) (-15 -4390 ($ $ (-572)))) |noBranch|))) 
-(((-39) . T) ((-105) |has| |#1| (-1098)) ((-612 (-856)) |has| |#1| (-1098)) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-503 |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-1017 |#1|) . T) ((-1098) |has| |#1| (-1098)) ((-1204) . T)) 
-((-3828 ((|#4| (-1 |#2| |#1|) |#3|) 17))) 
-(((-1247 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3828 (|#4| (-1 |#2| |#1|) |#3|))) (-1054) (-1054) (-1249 |#1|) (-1249 |#2|)) (T -1247)) 
-((-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-4 *2 (-1249 *6)) (-5 *1 (-1247 *5 *6 *4 *2)) (-4 *4 (-1249 *5))))) 
-(-10 -7 (-15 -3828 (|#4| (-1 |#2| |#1|) |#3|))) 
-((-1342 (((-121) $) 15)) (-4284 (($ $) 90)) (-4224 (($ $) 66)) (-4273 (($ $) 86)) (-4217 (($ $) 62)) (-4295 (($ $) 94)) (-4233 (($ $) 70)) (-3539 (($ $) 60)) (-4179 (($ $) 58)) (-4302 (($ $) 96)) (-4237 (($ $) 72)) (-4289 (($ $) 92)) (-4228 (($ $) 68)) (-4278 (($ $) 88)) (-4220 (($ $) 64)) (-3972 (((-856) $) 46) (($ (-572)) NIL) (($ (-413 (-572))) NIL) (($ $) NIL) (($ |#2|) NIL)) (-4321 (($ $) 102)) (-4251 (($ $) 78)) (-4308 (($ $) 98)) (-4241 (($ $) 74)) (-4333 (($ $) 106)) (-4263 (($ $) 82)) (-2104 (($ $) 108)) (-4268 (($ $) 84)) (-4327 (($ $) 104)) (-4257 (($ $) 80)) (-4314 (($ $) 100)) (-4246 (($ $) 76)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ |#2|) 50) (($ $ $) 53) (($ $ (-413 (-572))) 56))) 
-(((-1248 |#1| |#2|) (-10 -8 (-15 ** (|#1| |#1| (-413 (-572)))) (-15 -4224 (|#1| |#1|)) (-15 -4217 (|#1| |#1|)) (-15 -4233 (|#1| |#1|)) (-15 -4237 (|#1| |#1|)) (-15 -4228 (|#1| |#1|)) (-15 -4220 (|#1| |#1|)) (-15 -4246 (|#1| |#1|)) (-15 -4257 (|#1| |#1|)) (-15 -4268 (|#1| |#1|)) (-15 -4263 (|#1| |#1|)) (-15 -4241 (|#1| |#1|)) (-15 -4251 (|#1| |#1|)) (-15 -4278 (|#1| |#1|)) (-15 -4289 (|#1| |#1|)) (-15 -4302 (|#1| |#1|)) (-15 -4295 (|#1| |#1|)) (-15 -4273 (|#1| |#1|)) (-15 -4284 (|#1| |#1|)) (-15 -4314 (|#1| |#1|)) (-15 -4327 (|#1| |#1|)) (-15 -2104 (|#1| |#1|)) (-15 -4333 (|#1| |#1|)) (-15 -4308 (|#1| |#1|)) (-15 -4321 (|#1| |#1|)) (-15 -3539 (|#1| |#1|)) (-15 -4179 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| |#2|)) (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| (-572))) (-15 ** (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-923))) (-15 -1342 ((-121) |#1|)) (-15 -3972 ((-856) |#1|))) (-1249 |#2|) (-1054)) (T -1248)) 
-NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-413 (-572)))) (-15 -4224 (|#1| |#1|)) (-15 -4217 (|#1| |#1|)) (-15 -4233 (|#1| |#1|)) (-15 -4237 (|#1| |#1|)) (-15 -4228 (|#1| |#1|)) (-15 -4220 (|#1| |#1|)) (-15 -4246 (|#1| |#1|)) (-15 -4257 (|#1| |#1|)) (-15 -4268 (|#1| |#1|)) (-15 -4263 (|#1| |#1|)) (-15 -4241 (|#1| |#1|)) (-15 -4251 (|#1| |#1|)) (-15 -4278 (|#1| |#1|)) (-15 -4289 (|#1| |#1|)) (-15 -4302 (|#1| |#1|)) (-15 -4295 (|#1| |#1|)) (-15 -4273 (|#1| |#1|)) (-15 -4284 (|#1| |#1|)) (-15 -4314 (|#1| |#1|)) (-15 -4327 (|#1| |#1|)) (-15 -2104 (|#1| |#1|)) (-15 -4333 (|#1| |#1|)) (-15 -4308 (|#1| |#1|)) (-15 -4321 (|#1| |#1|)) (-15 -3539 (|#1| |#1|)) (-15 -4179 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| |#2|)) (-15 -3972 (|#1| |#2|)) (-15 -3972 (|#1| |#1|)) (-15 -3972 (|#1| (-413 (-572)))) (-15 -3972 (|#1| (-572))) (-15 ** (|#1| |#1| (-769))) (-15 ** (|#1| |#1| (-923))) (-15 -1342 ((-121) |#1|)) (-15 -3972 ((-856) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-3456 (((-638 (-1082)) $) 70)) (-3342 (((-1170) $) 98)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 50 (|has| |#1| (-562)))) (-3946 (($ $) 51 (|has| |#1| (-562)))) (-3686 (((-121) $) 53 (|has| |#1| (-562)))) (-2525 (($ $ (-769)) 93) (($ $ (-769) (-769)) 92)) (-2640 (((-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|))) $) 100)) (-4284 (($ $) 127 (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) 110 (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) 18)) (-4190 (($ $) 109 (|has| |#1| (-43 (-413 (-572)))))) (-4273 (($ $) 126 (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) 111 (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|)))) 147) (($ (-1150 |#1|)) 145)) (-4295 (($ $) 125 (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) 112 (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) 16 T CONST)) (-4383 (($ $) 59)) (-1799 (((-3 $ "failed") $) 33)) (-2531 (($ $) 144)) (-1896 (((-959 |#1|) $ (-769)) 142) (((-959 |#1|) $ (-769) (-769)) 141)) (-1347 (((-121) $) 69)) (-4184 (($) 137 (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-769) $) 95) (((-769) $ (-769)) 94)) (-3893 (((-121) $) 30)) (-1451 (($ $ (-572)) 108 (|has| |#1| (-43 (-413 (-572)))))) (-3965 (($ $ (-923)) 96)) (-4324 (($ (-1 |#1| (-572)) $) 143)) (-4581 (((-121) $) 61)) (-4328 (($ |#1| (-769)) 60) (($ $ (-1082) (-769)) 72) (($ $ (-638 (-1082)) (-638 (-769))) 71)) (-3828 (($ (-1 |#1| |#1|) $) 62)) (-3539 (($ $) 134 (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) 64)) (-4373 ((|#1| $) 65)) (-1658 (((-1152) $) 9)) (-2774 (($ $) 139 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 138 (-1841 (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-966)) (|has| |#1| (-1190)) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-43 (-413 (-572)))))))) (-2607 (((-1116) $) 10)) (-1977 (($ $ (-769)) 90)) (-1803 (((-3 $ "failed") $ $) 49 (|has| |#1| (-562)))) (-4179 (($ $) 135 (|has| |#1| (-43 (-413 (-572)))))) (-4485 (((-1150 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-769)))))) (-3277 ((|#1| $ (-769)) 99) (($ $ $) 76 (|has| (-769) (-1110)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) 84 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (($ $ (-1170) (-769)) 83 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (($ $ (-638 (-1170))) 82 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (($ $ (-1170)) 81 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (($ $ (-769)) 79 (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (-4316 (((-769) $) 63)) (-4302 (($ $) 124 (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) 113 (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) 123 (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) 114 (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) 122 (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) 115 (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 68)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ (-413 (-572))) 56 (|has| |#1| (-43 (-413 (-572))))) (($ $) 48 (|has| |#1| (-562))) (($ |#1|) 46 (|has| |#1| (-174)))) (-3193 (((-1150 |#1|) $) 146)) (-1958 ((|#1| $ (-769)) 58)) (-2779 (((-3 $ "failed") $) 47 (|has| |#1| (-149)))) (-2140 (((-769)) 28)) (-1694 ((|#1| $) 97)) (-4321 (($ $) 133 (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) 121 (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) 52 (|has| |#1| (-562)))) (-4308 (($ $) 132 (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) 120 (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) 131 (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) 119 (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-769)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-769)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) 130 (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) 118 (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) 129 (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) 117 (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) 128 (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) 116 (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) 88 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (($ $ (-1170) (-769)) 87 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (($ $ (-638 (-1170))) 86 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (($ $ (-1170)) 85 (-12 (|has| |#1| (-901 (-1170))) (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (($ $ (-769)) 80 (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 57 (|has| |#1| (-368)))) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ |#1|) 140 (|has| |#1| (-368))) (($ $ $) 136 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 107 (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-413 (-572)) $) 55 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) 54 (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1249 |#1|) (-1290) (-1054)) (T -1249)) 
-((-4521 (*1 *1 *2) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-769)) (|:| |c| *3)))) (-4 *3 (-1054)) (-4 *1 (-1249 *3)))) (-3193 (*1 *2 *1) (-12 (-4 *1 (-1249 *3)) (-4 *3 (-1054)) (-5 *2 (-1150 *3)))) (-4521 (*1 *1 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-4 *1 (-1249 *3)))) (-2531 (*1 *1 *1) (-12 (-4 *1 (-1249 *2)) (-4 *2 (-1054)))) (-4324 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-572))) (-4 *1 (-1249 *3)) (-4 *3 (-1054)))) (-1896 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-1249 *4)) (-4 *4 (-1054)) (-5 *2 (-959 *4)))) (-1896 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-4 *1 (-1249 *4)) (-4 *4 (-1054)) (-5 *2 (-959 *4)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-1249 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) (-2774 (*1 *1 *1) (-12 (-4 *1 (-1249 *2)) (-4 *2 (-1054)) (-4 *2 (-43 (-413 (-572)))))) (-2774 (*1 *1 *1 *2) (-1841 (-12 (-5 *2 (-1170)) (-4 *1 (-1249 *3)) (-4 *3 (-1054)) (-12 (-4 *3 (-29 (-572))) (-4 *3 (-966)) (-4 *3 (-1190)) (-4 *3 (-43 (-413 (-572)))))) (-12 (-5 *2 (-1170)) (-4 *1 (-1249 *3)) (-4 *3 (-1054)) (-12 (|has| *3 (-15 -3456 ((-638 *2) *3))) (|has| *3 (-15 -2774 (*3 *3 *2))) (-4 *3 (-43 (-413 (-572))))))))) 
-(-13 (-1236 |t#1| (-769)) (-10 -8 (-15 -4521 ($ (-1150 (-2 (|:| |k| (-769)) (|:| |c| |t#1|))))) (-15 -3193 ((-1150 |t#1|) $)) (-15 -4521 ($ (-1150 |t#1|))) (-15 -2531 ($ $)) (-15 -4324 ($ (-1 |t#1| (-572)) $)) (-15 -1896 ((-959 |t#1|) $ (-769))) (-15 -1896 ((-959 |t#1|) $ (-769) (-769))) (IF (|has| |t#1| (-368)) (-15 ** ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-43 (-413 (-572)))) (PROGN (-15 -2774 ($ $)) (IF (|has| |t#1| (-15 -2774 (|t#1| |t#1| (-1170)))) (IF (|has| |t#1| (-15 -3456 ((-638 (-1170)) |t#1|))) (-15 -2774 ($ $ (-1170))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1190)) (IF (|has| |t#1| (-966)) (IF (|has| |t#1| (-29 (-572))) (-15 -2774 ($ $ (-1170))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1009)) (-6 (-1190))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-769)) . T) ((-25) . T) ((-43 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-43 |#1|) |has| |#1| (-174)) ((-43 $) |has| |#1| (-562)) ((-40) |has| |#1| (-43 (-413 (-572)))) ((-98) |has| |#1| (-43 (-413 (-572)))) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-138) . T) ((-149) |has| |#1| (-149)) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-227) |has| |#1| (-15 * (|#1| (-769) |#1|))) ((-281) |has| |#1| (-43 (-413 (-572)))) ((-283 $ $) |has| (-769) (-1110)) ((-287) |has| |#1| (-562)) ((-506) |has| |#1| (-43 (-413 (-572)))) ((-562) |has| |#1| (-562)) ((-641 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-713 |#1|) |has| |#1| (-174)) ((-713 $) |has| |#1| (-562)) ((-722) . T) ((-901 (-1170)) -12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170)))) ((-981 |#1| (-769) (-1082)) . T) ((-1009) |has| |#1| (-43 (-413 (-572)))) ((-1060 (-413 (-572))) |has| |#1| (-43 (-413 (-572)))) ((-1060 |#1|) . T) ((-1060 $) -1841 (|has| |#1| (-562)) (|has| |#1| (-174))) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1190) |has| |#1| (-43 (-413 (-572)))) ((-1193) |has| |#1| (-43 (-413 (-572)))) ((-1236 |#1| (-769)) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 86)) (-2970 (((-1231 |#2| |#1|) $ (-769)) 73)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) 135 (|has| |#1| (-562)))) (-2525 (($ $ (-769)) 120) (($ $ (-769) (-769)) 122)) (-2640 (((-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|))) $) 42)) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|)))) 53) (($ (-1150 |#1|)) NIL)) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3851 (($ $) 126)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2531 (($ $) 133)) (-1896 (((-959 |#1|) $ (-769)) 63) (((-959 |#1|) $ (-769) (-769)) 65)) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-769) $) NIL) (((-769) $ (-769)) NIL)) (-3893 (((-121) $) NIL)) (-1973 (($ $) 110)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3628 (($ (-572) (-572) $) 128)) (-3965 (($ $ (-923)) 132)) (-4324 (($ (-1 |#1| (-572)) $) 104)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) 15) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) 92)) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-3358 (($ $) 108)) (-2606 (($ $) 106)) (-3959 (($ (-572) (-572) $) 130)) (-2774 (($ $) 143 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 149 (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 |#2|)) 144 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-3130 (($ $ (-572) (-572)) 114)) (-1977 (($ $ (-769)) 116)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2827 (($ $) 112)) (-4485 (((-1150 |#1|) $ |#1|) 94 (|has| |#1| (-15 ** (|#1| |#1| (-769)))))) (-3277 ((|#1| $ (-769)) 89) (($ $ $) 124 (|has| (-769) (-1110)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) 101 (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) 96 (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $ (-1255 |#2|)) 97)) (-4316 (((-769) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 118)) (-3972 (((-856) $) NIL) (($ (-572)) 24) (($ (-413 (-572))) 141 (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562))) (($ |#1|) 23 (|has| |#1| (-174))) (($ (-1231 |#2| |#1|)) 79) (($ (-1255 |#2|)) 20)) (-3193 (((-1150 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) 88)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) 87)) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-769)) 85 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-769)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 17 T CONST)) (-3255 (($) 13 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) 100)) (-1367 (($ $ $) 18)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ |#1|) 138 (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 99) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1250 |#1| |#2| |#3|) (-13 (-1249 |#1|) (-10 -8 (-15 -3972 ($ (-1231 |#2| |#1|))) (-15 -2970 ((-1231 |#2| |#1|) $ (-769))) (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (-15 -2606 ($ $)) (-15 -3358 ($ $)) (-15 -1973 ($ $)) (-15 -2827 ($ $)) (-15 -3130 ($ $ (-572) (-572))) (-15 -3851 ($ $)) (-15 -3628 ($ (-572) (-572) $)) (-15 -3959 ($ (-572) (-572) $)) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) (-1054) (-1170) |#1|) (T -1250)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1231 *4 *3)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3) (-5 *1 (-1250 *3 *4 *5)))) (-2970 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1231 *5 *4)) (-5 *1 (-1250 *4 *5 *6)) (-4 *4 (-1054)) (-14 *5 (-1170)) (-14 *6 *4))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) (-2606 (*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) (-3358 (*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) (-1973 (*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) (-2827 (*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) (-3130 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3))) (-3851 (*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) (-3628 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3))) (-3959 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3)))) 
-(-13 (-1249 |#1|) (-10 -8 (-15 -3972 ($ (-1231 |#2| |#1|))) (-15 -2970 ((-1231 |#2| |#1|) $ (-769))) (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (-15 -2606 ($ $)) (-15 -3358 ($ $)) (-15 -1973 ($ $)) (-15 -2827 ($ $)) (-15 -3130 ($ $ (-572) (-572))) (-15 -3851 ($ $)) (-15 -3628 ($ (-572) (-572) $)) (-15 -3959 ($ (-572) (-572) $)) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) 
-((-3143 (((-1 (-1150 |#1|) (-638 (-1150 |#1|))) (-1 |#2| (-638 |#2|))) 24)) (-3981 (((-1 (-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) (-1 |#2| |#2| |#2|)) 16)) (-3968 (((-1 (-1150 |#1|) (-1150 |#1|)) (-1 |#2| |#2|)) 13)) (-4096 ((|#2| (-1 |#2| |#2| |#2|) |#1| |#1|) 48)) (-1423 ((|#2| (-1 |#2| |#2|) |#1|) 46)) (-2993 ((|#2| (-1 |#2| (-638 |#2|)) (-638 |#1|)) 54)) (-1929 (((-638 |#2|) (-638 |#1|) (-638 (-1 |#2| (-638 |#2|)))) 61)) (-3535 ((|#2| |#2| |#2|) 43))) 
-(((-1251 |#1| |#2|) (-10 -7 (-15 -3968 ((-1 (-1150 |#1|) (-1150 |#1|)) (-1 |#2| |#2|))) (-15 -3981 ((-1 (-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) (-1 |#2| |#2| |#2|))) (-15 -3143 ((-1 (-1150 |#1|) (-638 (-1150 |#1|))) (-1 |#2| (-638 |#2|)))) (-15 -3535 (|#2| |#2| |#2|)) (-15 -1423 (|#2| (-1 |#2| |#2|) |#1|)) (-15 -4096 (|#2| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2993 (|#2| (-1 |#2| (-638 |#2|)) (-638 |#1|))) (-15 -1929 ((-638 |#2|) (-638 |#1|) (-638 (-1 |#2| (-638 |#2|)))))) (-43 (-413 (-572))) (-1249 |#1|)) (T -1251)) 
-((-1929 (*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-1 *6 (-638 *6)))) (-4 *5 (-43 (-413 (-572)))) (-4 *6 (-1249 *5)) (-5 *2 (-638 *6)) (-5 *1 (-1251 *5 *6)))) (-2993 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-638 *2))) (-5 *4 (-638 *5)) (-4 *5 (-43 (-413 (-572)))) (-4 *2 (-1249 *5)) (-5 *1 (-1251 *5 *2)))) (-4096 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1249 *4)) (-5 *1 (-1251 *4 *2)) (-4 *4 (-43 (-413 (-572)))))) (-1423 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *2)) (-4 *2 (-1249 *4)) (-5 *1 (-1251 *4 *2)) (-4 *4 (-43 (-413 (-572)))))) (-3535 (*1 *2 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1251 *3 *2)) (-4 *2 (-1249 *3)))) (-3143 (*1 *2 *3) (-12 (-5 *3 (-1 *5 (-638 *5))) (-4 *5 (-1249 *4)) (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-1 (-1150 *4) (-638 (-1150 *4)))) (-5 *1 (-1251 *4 *5)))) (-3981 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5 *5)) (-4 *5 (-1249 *4)) (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-1 (-1150 *4) (-1150 *4) (-1150 *4))) (-5 *1 (-1251 *4 *5)))) (-3968 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1249 *4)) (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-1 (-1150 *4) (-1150 *4))) (-5 *1 (-1251 *4 *5))))) 
-(-10 -7 (-15 -3968 ((-1 (-1150 |#1|) (-1150 |#1|)) (-1 |#2| |#2|))) (-15 -3981 ((-1 (-1150 |#1|) (-1150 |#1|) (-1150 |#1|)) (-1 |#2| |#2| |#2|))) (-15 -3143 ((-1 (-1150 |#1|) (-638 (-1150 |#1|))) (-1 |#2| (-638 |#2|)))) (-15 -3535 (|#2| |#2| |#2|)) (-15 -1423 (|#2| (-1 |#2| |#2|) |#1|)) (-15 -4096 (|#2| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2993 (|#2| (-1 |#2| (-638 |#2|)) (-638 |#1|))) (-15 -1929 ((-638 |#2|) (-638 |#1|) (-638 (-1 |#2| (-638 |#2|)))))) 
-((-2358 ((|#2| |#4| (-769)) 30)) (-1542 ((|#4| |#2|) 25)) (-4180 ((|#4| (-413 |#2|)) 51 (|has| |#1| (-562)))) (-4157 (((-1 |#4| (-638 |#4|)) |#3|) 45))) 
-(((-1252 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1542 (|#4| |#2|)) (-15 -2358 (|#2| |#4| (-769))) (-15 -4157 ((-1 |#4| (-638 |#4|)) |#3|)) (IF (|has| |#1| (-562)) (-15 -4180 (|#4| (-413 |#2|))) |noBranch|)) (-1054) (-1234 |#1|) (-650 |#2|) (-1249 |#1|)) (T -1252)) 
-((-4180 (*1 *2 *3) (-12 (-5 *3 (-413 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-562)) (-4 *4 (-1054)) (-4 *2 (-1249 *4)) (-5 *1 (-1252 *4 *5 *6 *2)) (-4 *6 (-650 *5)))) (-4157 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-1234 *4)) (-5 *2 (-1 *6 (-638 *6))) (-5 *1 (-1252 *4 *5 *3 *6)) (-4 *3 (-650 *5)) (-4 *6 (-1249 *4)))) (-2358 (*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-1054)) (-4 *2 (-1234 *5)) (-5 *1 (-1252 *5 *2 *6 *3)) (-4 *6 (-650 *2)) (-4 *3 (-1249 *5)))) (-1542 (*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *3 (-1234 *4)) (-4 *2 (-1249 *4)) (-5 *1 (-1252 *4 *3 *5 *2)) (-4 *5 (-650 *3))))) 
-(-10 -7 (-15 -1542 (|#4| |#2|)) (-15 -2358 (|#2| |#4| (-769))) (-15 -4157 ((-1 |#4| (-638 |#4|)) |#3|)) (IF (|has| |#1| (-562)) (-15 -4180 (|#4| (-413 |#2|))) |noBranch|)) 
-((-3542 ((|#2| (-1 |#3| |#3|) (-638 |#1|)) 67))) 
-(((-1253 |#1| |#2| |#3|) (-10 -7 (-15 -3542 (|#2| (-1 |#3| |#3|) (-638 |#1|)))) (-368) (-1249 |#1|) (-1249 (-1164 |#1|))) (T -1253)) 
-((-3542 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *6)) (-5 *4 (-638 *5)) (-4 *5 (-368)) (-4 *6 (-1249 (-1164 *5))) (-4 *2 (-1249 *5)) (-5 *1 (-1253 *5 *2 *6))))) 
-(-10 -7 (-15 -3542 (|#2| (-1 |#3| |#3|) (-638 |#1|)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-3456 (((-638 (-1082)) $) NIL)) (-3342 (((-1170) $) 79)) (-2970 (((-1231 |#2| |#1|) $ (-769)) 68)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) NIL (|has| |#1| (-562)))) (-3946 (($ $) NIL (|has| |#1| (-562)))) (-3686 (((-121) $) 128 (|has| |#1| (-562)))) (-2525 (($ $ (-769)) 113) (($ $ (-769) (-769)) 115)) (-2640 (((-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|))) $) 38)) (-4284 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4224 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-1572 (((-3 $ "failed") $ $) NIL)) (-4190 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4273 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4217 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4521 (($ (-1150 (-2 (|:| |k| (-769)) (|:| |c| |#1|)))) 51) (($ (-1150 |#1|)) NIL)) (-4295 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4233 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2211 (($) NIL T CONST)) (-3851 (($ $) 119)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-2531 (($ $) 126)) (-1896 (((-959 |#1|) $ (-769)) 59) (((-959 |#1|) $ (-769) (-769)) 61)) (-1347 (((-121) $) NIL)) (-4184 (($) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3377 (((-769) $) NIL) (((-769) $ (-769)) NIL)) (-3893 (((-121) $) NIL)) (-1973 (($ $) 103)) (-1451 (($ $ (-572)) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3628 (($ (-572) (-572) $) 121)) (-3965 (($ $ (-923)) 125)) (-4324 (($ (-1 |#1| (-572)) $) 97)) (-4581 (((-121) $) NIL)) (-4328 (($ |#1| (-769)) 12) (($ $ (-1082) (-769)) NIL) (($ $ (-638 (-1082)) (-638 (-769))) NIL)) (-3828 (($ (-1 |#1| |#1|) $) 85)) (-3539 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4368 (($ $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-3358 (($ $) 101)) (-2606 (($ $) 99)) (-3959 (($ (-572) (-572) $) 123)) (-2774 (($ $) 136 (|has| |#1| (-43 (-413 (-572))))) (($ $ (-1170)) 139 (-1841 (-12 (|has| |#1| (-15 -2774 (|#1| |#1| (-1170)))) (|has| |#1| (-15 -3456 ((-638 (-1170)) |#1|))) (|has| |#1| (-43 (-413 (-572))))) (-12 (|has| |#1| (-29 (-572))) (|has| |#1| (-43 (-413 (-572)))) (|has| |#1| (-966)) (|has| |#1| (-1190))))) (($ $ (-1255 |#2|)) 137 (|has| |#1| (-43 (-413 (-572)))))) (-2607 (((-1116) $) NIL)) (-3130 (($ $ (-572) (-572)) 107)) (-1977 (($ $ (-769)) 109)) (-1803 (((-3 $ "failed") $ $) NIL (|has| |#1| (-562)))) (-4179 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2827 (($ $) 105)) (-4485 (((-1150 |#1|) $ |#1|) 87 (|has| |#1| (-15 ** (|#1| |#1| (-769)))))) (-3277 ((|#1| $ (-769)) 82) (($ $ $) 117 (|has| (-769) (-1110)))) (-3139 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) 92 (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) 89 (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $ (-1255 |#2|)) 90)) (-4316 (((-769) $) NIL)) (-4302 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4237 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4289 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4228 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4278 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4220 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-2424 (($ $) 111)) (-3972 (((-856) $) NIL) (($ (-572)) 18) (($ (-413 (-572))) 134 (|has| |#1| (-43 (-413 (-572))))) (($ $) NIL (|has| |#1| (-562))) (($ |#1|) 17 (|has| |#1| (-174))) (($ (-1231 |#2| |#1|)) 73) (($ (-1255 |#2|)) 14)) (-3193 (((-1150 |#1|) $) NIL)) (-1958 ((|#1| $ (-769)) 81)) (-2779 (((-3 $ "failed") $) NIL (|has| |#1| (-149)))) (-2140 (((-769)) NIL)) (-1694 ((|#1| $) 80)) (-4321 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4251 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3774 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4308 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4241 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4333 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4263 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-3410 ((|#1| $ (-769)) 78 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-769)))) (|has| |#1| (-15 -3972 (|#1| (-1170))))))) (-2104 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4268 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4327 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4257 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4314 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4246 (($ $) NIL (|has| |#1| (-43 (-413 (-572)))))) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 44 T CONST)) (-3255 (($) 9 T CONST)) (-1557 (($ $ (-638 (-1170)) (-638 (-769))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170) (-769)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-638 (-1170))) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-1170)) NIL (-12 (|has| |#1| (-15 * (|#1| (-769) |#1|))) (|has| |#1| (-901 (-1170))))) (($ $ (-769)) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-769) |#1|))))) (-1324 (((-121) $ $) NIL)) (-1379 (($ $ |#1|) NIL (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) 94)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL) (($ $ |#1|) 131 (|has| |#1| (-368))) (($ $ $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572)))))) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 93) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-413 (-572)) $) NIL (|has| |#1| (-43 (-413 (-572))))) (($ $ (-413 (-572))) NIL (|has| |#1| (-43 (-413 (-572))))))) 
-(((-1254 |#1| |#2|) (-13 (-1249 |#1|) (-10 -8 (-15 -3972 ($ (-1231 |#2| |#1|))) (-15 -2970 ((-1231 |#2| |#1|) $ (-769))) (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (-15 -2606 ($ $)) (-15 -3358 ($ $)) (-15 -1973 ($ $)) (-15 -2827 ($ $)) (-15 -3130 ($ $ (-572) (-572))) (-15 -3851 ($ $)) (-15 -3628 ($ (-572) (-572) $)) (-15 -3959 ($ (-572) (-572) $)) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) (-1054) (-1170)) (T -1254)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-1231 *4 *3)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-5 *1 (-1254 *3 *4)))) (-2970 (*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1231 *5 *4)) (-5 *1 (-1254 *4 *5)) (-4 *4 (-1054)) (-14 *5 (-1170)))) (-3972 (*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)))) (-3139 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)))) (-2606 (*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170)))) (-3358 (*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170)))) (-1973 (*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170)))) (-2827 (*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170)))) (-3130 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-1170)))) (-3851 (*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170)))) (-3628 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-1170)))) (-3959 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-1170)))) (-2774 (*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054))))) 
-(-13 (-1249 |#1|) (-10 -8 (-15 -3972 ($ (-1231 |#2| |#1|))) (-15 -2970 ((-1231 |#2| |#1|) $ (-769))) (-15 -3972 ($ (-1255 |#2|))) (-15 -3139 ($ $ (-1255 |#2|))) (-15 -2606 ($ $)) (-15 -3358 ($ $)) (-15 -1973 ($ $)) (-15 -2827 ($ $)) (-15 -3130 ($ $ (-572) (-572))) (-15 -3851 ($ $)) (-15 -3628 ($ (-572) (-572) $)) (-15 -3959 ($ (-572) (-572) $)) (IF (|has| |#1| (-43 (-413 (-572)))) (-15 -2774 ($ $ (-1255 |#2|))) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-3342 (((-1170)) 12)) (-1658 (((-1152) $) 17)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 11) (((-1170) $) 8)) (-1324 (((-121) $ $) 14))) 
-(((-1255 |#1|) (-13 (-1098) (-612 (-1170)) (-10 -8 (-15 -3972 ((-1170) $)) (-15 -3342 ((-1170))))) (-1170)) (T -1255)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-1255 *3)) (-14 *3 *2))) (-3342 (*1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1255 *3)) (-14 *3 *2)))) 
-(-13 (-1098) (-612 (-1170)) (-10 -8 (-15 -3972 ((-1170) $)) (-15 -3342 ((-1170))))) 
-((-4169 (($ (-769)) 16)) (-3349 (((-685 |#2|) $ $) 37)) (-3169 ((|#2| $) 46)) (-3200 ((|#2| $) 45)) (-1436 ((|#2| $ $) 33)) (-3780 (($ $ $) 42)) (-1373 (($ $) 20) (($ $ $) 26)) (-1367 (($ $ $) 13)) (* (($ (-572) $) 23) (($ |#2| $) 29) (($ $ |#2|) 28))) 
-(((-1256 |#1| |#2|) (-10 -8 (-15 -3169 (|#2| |#1|)) (-15 -3200 (|#2| |#1|)) (-15 -3780 (|#1| |#1| |#1|)) (-15 -3349 ((-685 |#2|) |#1| |#1|)) (-15 -1436 (|#2| |#1| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 -4169 (|#1| (-769))) (-15 -1367 (|#1| |#1| |#1|))) (-1257 |#2|) (-1204)) (T -1256)) 
-NIL 
-(-10 -8 (-15 -3169 (|#2| |#1|)) (-15 -3200 (|#2| |#1|)) (-15 -3780 (|#1| |#1| |#1|)) (-15 -3349 ((-685 |#2|) |#1| |#1|)) (-15 -1436 (|#2| |#1| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-572) |#1|)) (-15 -1373 (|#1| |#1| |#1|)) (-15 -1373 (|#1| |#1|)) (-15 -4169 (|#1| (-769))) (-15 -1367 (|#1| |#1| |#1|))) 
-((-2262 (((-121) $ $) 18 (|has| |#1| (-1098)))) (-4169 (($ (-769)) 105 (|has| |#1| (-23)))) (-2430 (((-1264) $ (-572) (-572)) 37 (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4603))) (($ $) 81 (-12 (|has| |#1| (-848)) (|has| $ (-6 -4603))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) 8)) (-3283 ((|#1| $ (-572) |#1|) 49 (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) 53 (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4602)))) (-2211 (($) 7 T CONST)) (-2985 (($ $) 83 (|has| $ (-6 -4603)))) (-1656 (($ $) 93)) (-1643 (($ $) 73 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-3445 (($ |#1| $) 72 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) 50 (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) 48)) (-4014 (((-572) (-1 (-121) |#1|) $) 90) (((-572) |#1| $) 89 (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) 88 (|has| |#1| (-1098)))) (-2010 (((-638 |#1|) $) 30 (|has| $ (-6 -4602)))) (-3349 (((-685 |#1|) $ $) 98 (|has| |#1| (-1054)))) (-1364 (($ (-769) |#1|) 64)) (-2157 (((-121) $ (-769)) 9)) (-3940 (((-572) $) 40 (|has| (-572) (-848)))) (-1771 (($ $ $) 80 (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) 29 (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2026 (((-572) $) 41 (|has| (-572) (-848)))) (-4238 (($ $ $) 79 (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3169 ((|#1| $) 95 (-12 (|has| |#1| (-1054)) (|has| |#1| (-1009))))) (-3524 (((-121) $ (-769)) 10)) (-3200 ((|#1| $) 96 (-12 (|has| |#1| (-1054)) (|has| |#1| (-1009))))) (-1658 (((-1152) $) 22 (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) 55) (($ $ $ (-572)) 54)) (-2739 (((-638 (-572)) $) 43)) (-1601 (((-121) (-572) $) 44)) (-2607 (((-1116) $) 21 (|has| |#1| (-1098)))) (-1837 ((|#1| $) 39 (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3299 (($ $ |#1|) 38 (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) 26 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) 25 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) 23 (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) 14)) (-3167 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) 45)) (-4037 (((-121) $) 11)) (-1665 (($) 12)) (-3277 ((|#1| $ (-572) |#1|) 47) ((|#1| $ (-572)) 46) (($ $ (-1225 (-572))) 58)) (-1436 ((|#1| $ $) 99 (|has| |#1| (-1054)))) (-1940 (($ $ (-572)) 57) (($ $ (-1225 (-572))) 56)) (-3780 (($ $ $) 97 (|has| |#1| (-1054)))) (-1571 (((-769) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4602))) (((-769) |#1| $) 28 (-12 (|has| |#1| (-1098)) (|has| $ (-6 -4602))))) (-2907 (($ $ $ (-572)) 84 (|has| $ (-6 -4603)))) (-1607 (($ $) 13)) (-4081 (((-545) $) 74 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 65)) (-4500 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-638 $)) 60)) (-3972 (((-856) $) 20 (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) 77 (|has| |#1| (-848)))) (-1338 (((-121) $ $) 76 (|has| |#1| (-848)))) (-1324 (((-121) $ $) 19 (|has| |#1| (-1098)))) (-1343 (((-121) $ $) 78 (|has| |#1| (-848)))) (-1334 (((-121) $ $) 75 (|has| |#1| (-848)))) (-1373 (($ $) 104 (|has| |#1| (-21))) (($ $ $) 103 (|has| |#1| (-21)))) (-1367 (($ $ $) 106 (|has| |#1| (-25)))) (* (($ (-572) $) 102 (|has| |#1| (-21))) (($ |#1| $) 101 (|has| |#1| (-722))) (($ $ |#1|) 100 (|has| |#1| (-722)))) (-4032 (((-769) $) 6 (|has| $ (-6 -4602))))) 
-(((-1257 |#1|) (-1290) (-1204)) (T -1257)) 
-((-1367 (*1 *1 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-25)))) (-4169 (*1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1257 *3)) (-4 *3 (-23)) (-4 *3 (-1204)))) (-1373 (*1 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-21)))) (-1373 (*1 *1 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-21)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-1257 *3)) (-4 *3 (-1204)) (-4 *3 (-21)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-722)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-722)))) (-1436 (*1 *2 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-1054)))) (-3349 (*1 *2 *1 *1) (-12 (-4 *1 (-1257 *3)) (-4 *3 (-1204)) (-4 *3 (-1054)) (-5 *2 (-685 *3)))) (-3780 (*1 *1 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-1054)))) (-3200 (*1 *2 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-1009)) (-4 *2 (-1054)))) (-3169 (*1 *2 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-1009)) (-4 *2 (-1054))))) 
-(-13 (-19 |t#1|) (-10 -8 (IF (|has| |t#1| (-25)) (-15 -1367 ($ $ $)) |noBranch|) (IF (|has| |t#1| (-23)) (-15 -4169 ($ (-769))) |noBranch|) (IF (|has| |t#1| (-21)) (PROGN (-15 -1373 ($ $)) (-15 -1373 ($ $ $)) (-15 * ($ (-572) $))) |noBranch|) (IF (|has| |t#1| (-722)) (PROGN (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|))) |noBranch|) (IF (|has| |t#1| (-1054)) (PROGN (-15 -1436 (|t#1| $ $)) (-15 -3349 ((-685 |t#1|) $ $)) (-15 -3780 ($ $ $))) |noBranch|) (IF (|has| |t#1| (-1009)) (IF (|has| |t#1| (-1054)) (PROGN (-15 -3200 (|t#1| $)) (-15 -3169 (|t#1| $))) |noBranch|) |noBranch|))) 
-(((-39) . T) ((-105) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-612 (-856)) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-155 |#1|) . T) ((-613 (-545)) |has| |#1| (-613 (-545))) ((-283 (-572) |#1|) . T) ((-285 (-572) |#1|) . T) ((-305 |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-379 |#1|) . T) ((-503 |#1|) . T) ((-605 (-572) |#1|) . T) ((-527 |#1| |#1|) -12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))) ((-644 |#1|) . T) ((-19 |#1|) . T) ((-848) |has| |#1| (-848)) ((-1098) -1841 (|has| |#1| (-1098)) (|has| |#1| (-848))) ((-1204) . T)) 
-((-1911 (((-1259 |#2|) (-1 |#2| |#1| |#2|) (-1259 |#1|) |#2|) 13)) (-3116 ((|#2| (-1 |#2| |#1| |#2|) (-1259 |#1|) |#2|) 15)) (-3828 (((-3 (-1259 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1259 |#1|)) 28) (((-1259 |#2|) (-1 |#2| |#1|) (-1259 |#1|)) 18))) 
-(((-1258 |#1| |#2|) (-10 -7 (-15 -1911 ((-1259 |#2|) (-1 |#2| |#1| |#2|) (-1259 |#1|) |#2|)) (-15 -3116 (|#2| (-1 |#2| |#1| |#2|) (-1259 |#1|) |#2|)) (-15 -3828 ((-1259 |#2|) (-1 |#2| |#1|) (-1259 |#1|))) (-15 -3828 ((-3 (-1259 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1259 |#1|)))) (-1204) (-1204)) (T -1258)) 
-((-3828 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *6 "failed") *5)) (-5 *4 (-1259 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1259 *6)) (-5 *1 (-1258 *5 *6)))) (-3828 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1259 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1259 *6)) (-5 *1 (-1258 *5 *6)))) (-3116 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1259 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-1258 *5 *2)))) (-1911 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-1259 *6)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-5 *2 (-1259 *5)) (-5 *1 (-1258 *6 *5))))) 
-(-10 -7 (-15 -1911 ((-1259 |#2|) (-1 |#2| |#1| |#2|) (-1259 |#1|) |#2|)) (-15 -3116 (|#2| (-1 |#2| |#1| |#2|) (-1259 |#1|) |#2|)) (-15 -3828 ((-1259 |#2|) (-1 |#2| |#1|) (-1259 |#1|))) (-15 -3828 ((-3 (-1259 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1259 |#1|)))) 
-((-2262 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-4169 (($ (-769)) NIL (|has| |#1| (-23)))) (-3156 (($ (-638 |#1|)) 9)) (-2430 (((-1264) $ (-572) (-572)) NIL (|has| $ (-6 -4603)))) (-2041 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-848)))) (-4131 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4603))) (($ $) NIL (-12 (|has| $ (-6 -4603)) (|has| |#1| (-848))))) (-3008 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-848)))) (-1946 (((-121) $ (-769)) NIL)) (-3283 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603))) ((|#1| $ (-1225 (-572)) |#1|) NIL (|has| $ (-6 -4603)))) (-2561 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-2211 (($) NIL T CONST)) (-2985 (($ $) NIL (|has| $ (-6 -4603)))) (-1656 (($ $) NIL)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-3445 (($ |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-3116 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4602))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4602)))) (-3037 ((|#1| $ (-572) |#1|) NIL (|has| $ (-6 -4603)))) (-4212 ((|#1| $ (-572)) NIL)) (-4014 (((-572) (-1 (-121) |#1|) $) NIL) (((-572) |#1| $) NIL (|has| |#1| (-1098))) (((-572) |#1| $ (-572)) NIL (|has| |#1| (-1098)))) (-2010 (((-638 |#1|) $) 15 (|has| $ (-6 -4602)))) (-3349 (((-685 |#1|) $ $) NIL (|has| |#1| (-1054)))) (-1364 (($ (-769) |#1|) NIL)) (-2157 (((-121) $ (-769)) NIL)) (-3940 (((-572) $) NIL (|has| (-572) (-848)))) (-1771 (($ $ $) NIL (|has| |#1| (-848)))) (-4475 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-848)))) (-4467 (((-638 |#1|) $) NIL (|has| $ (-6 -4602)))) (-3002 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2026 (((-572) $) NIL (|has| (-572) (-848)))) (-4238 (($ $ $) NIL (|has| |#1| (-848)))) (-2435 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3169 ((|#1| $) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1054))))) (-3524 (((-121) $ (-769)) NIL)) (-3200 ((|#1| $) NIL (-12 (|has| |#1| (-1009)) (|has| |#1| (-1054))))) (-1658 (((-1152) $) NIL (|has| |#1| (-1098)))) (-2603 (($ |#1| $ (-572)) NIL) (($ $ $ (-572)) NIL)) (-2739 (((-638 (-572)) $) NIL)) (-1601 (((-121) (-572) $) NIL)) (-2607 (((-1116) $) NIL (|has| |#1| (-1098)))) (-1837 ((|#1| $) NIL (|has| (-572) (-848)))) (-3361 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3299 (($ $ |#1|) NIL (|has| $ (-6 -4603)))) (-2109 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 (-290 |#1|))) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-290 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098)))) (($ $ (-638 |#1|) (-638 |#1|)) NIL (-12 (|has| |#1| (-305 |#1|)) (|has| |#1| (-1098))))) (-3598 (((-121) $ $) NIL)) (-3167 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2957 (((-638 |#1|) $) NIL)) (-4037 (((-121) $) NIL)) (-1665 (($) NIL)) (-3277 ((|#1| $ (-572) |#1|) NIL) ((|#1| $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-1436 ((|#1| $ $) NIL (|has| |#1| (-1054)))) (-1940 (($ $ (-572)) NIL) (($ $ (-1225 (-572))) NIL)) (-3780 (($ $ $) NIL (|has| |#1| (-1054)))) (-1571 (((-769) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602))) (((-769) |#1| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#1| (-1098))))) (-2907 (($ $ $ (-572)) NIL (|has| $ (-6 -4603)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) 19 (|has| |#1| (-613 (-545))))) (-3921 (($ (-638 |#1|)) 8)) (-4500 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-638 $)) NIL)) (-3972 (((-856) $) NIL (|has| |#1| (-1098)))) (-3501 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4602)))) (-1349 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1338 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1324 (((-121) $ $) NIL (|has| |#1| (-1098)))) (-1343 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1334 (((-121) $ $) NIL (|has| |#1| (-848)))) (-1373 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1367 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-572) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-722))) (($ $ |#1|) NIL (|has| |#1| (-722)))) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1259 |#1|) (-13 (-1257 |#1|) (-10 -8 (-15 -3156 ($ (-638 |#1|))))) (-1204)) (T -1259)) 
-((-3156 (*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-1259 *3))))) 
-(-13 (-1257 |#1|) (-10 -8 (-15 -3156 ($ (-638 |#1|))))) 
-((-2262 (((-121) $ $) NIL)) (-3324 (((-1152) $ (-1152)) 87) (((-1152) $ (-1152) (-1152)) 85) (((-1152) $ (-1152) (-638 (-1152))) 84)) (-3003 (($) 56)) (-2920 (((-1264) $ (-477) (-923)) 42)) (-1810 (((-1264) $ (-923) (-1152)) 70) (((-1264) $ (-923) (-875)) 71)) (-2953 (((-1264) $ (-923) (-385) (-385)) 45)) (-3493 (((-1264) $ (-1152)) 66)) (-3212 (((-1264) $ (-923) (-1152)) 75)) (-1355 (((-1264) $ (-923) (-385) (-385)) 46)) (-2643 (((-1264) $ (-923) (-923)) 43)) (-3319 (((-1264) $) 67)) (-3137 (((-1264) $ (-923) (-1152)) 74)) (-2426 (((-1264) $ (-477) (-923)) 30)) (-4161 (((-1264) $ (-923) (-1152)) 73)) (-4530 (((-638 (-258)) $) 22) (($ $ (-638 (-258))) 23)) (-2203 (((-1264) $ (-769) (-769)) 40)) (-2330 (($ $) 57) (($ (-477) (-638 (-258))) 58)) (-1658 (((-1152) $) NIL)) (-4111 (((-572) $) 37)) (-2607 (((-1116) $) NIL)) (-3213 (((-1259 (-3 (-477) "undefined")) $) 36)) (-2065 (((-1259 (-2 (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)) (|:| -4161 (-572)) (|:| -4058 (-572)) (|:| |spline| (-572)) (|:| -1753 (-572)) (|:| |axesColor| (-875)) (|:| -1810 (-572)) (|:| |unitsColor| (-875)) (|:| |showing| (-572)))) $) 35)) (-2761 (((-1264) $ (-923) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-875) (-572) (-875) (-572)) 65)) (-2030 (((-638 (-950 (-217))) $) NIL)) (-2839 (((-477) $ (-923)) 32)) (-2183 (((-1264) $ (-769) (-769) (-923) (-923)) 39)) (-2392 (((-1264) $ (-1152)) 76)) (-4058 (((-1264) $ (-923) (-1152)) 72)) (-3972 (((-856) $) 82)) (-2371 (((-1264) $) 77)) (-1753 (((-1264) $ (-923) (-1152)) 68) (((-1264) $ (-923) (-875)) 69)) (-1324 (((-121) $ $) NIL))) 
-(((-1260) (-13 (-1098) (-10 -8 (-15 -2030 ((-638 (-950 (-217))) $)) (-15 -3003 ($)) (-15 -2330 ($ $)) (-15 -4530 ((-638 (-258)) $)) (-15 -4530 ($ $ (-638 (-258)))) (-15 -2330 ($ (-477) (-638 (-258)))) (-15 -2761 ((-1264) $ (-923) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-875) (-572) (-875) (-572))) (-15 -2065 ((-1259 (-2 (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)) (|:| -4161 (-572)) (|:| -4058 (-572)) (|:| |spline| (-572)) (|:| -1753 (-572)) (|:| |axesColor| (-875)) (|:| -1810 (-572)) (|:| |unitsColor| (-875)) (|:| |showing| (-572)))) $)) (-15 -3213 ((-1259 (-3 (-477) "undefined")) $)) (-15 -3493 ((-1264) $ (-1152))) (-15 -2426 ((-1264) $ (-477) (-923))) (-15 -2839 ((-477) $ (-923))) (-15 -1753 ((-1264) $ (-923) (-1152))) (-15 -1753 ((-1264) $ (-923) (-875))) (-15 -1810 ((-1264) $ (-923) (-1152))) (-15 -1810 ((-1264) $ (-923) (-875))) (-15 -4161 ((-1264) $ (-923) (-1152))) (-15 -3137 ((-1264) $ (-923) (-1152))) (-15 -4058 ((-1264) $ (-923) (-1152))) (-15 -2392 ((-1264) $ (-1152))) (-15 -2371 ((-1264) $)) (-15 -2183 ((-1264) $ (-769) (-769) (-923) (-923))) (-15 -1355 ((-1264) $ (-923) (-385) (-385))) (-15 -2953 ((-1264) $ (-923) (-385) (-385))) (-15 -3212 ((-1264) $ (-923) (-1152))) (-15 -2203 ((-1264) $ (-769) (-769))) (-15 -2920 ((-1264) $ (-477) (-923))) (-15 -2643 ((-1264) $ (-923) (-923))) (-15 -3324 ((-1152) $ (-1152))) (-15 -3324 ((-1152) $ (-1152) (-1152))) (-15 -3324 ((-1152) $ (-1152) (-638 (-1152)))) (-15 -3319 ((-1264) $)) (-15 -4111 ((-572) $)) (-15 -3972 ((-856) $))))) (T -1260)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1260)))) (-2030 (*1 *2 *1) (-12 (-5 *2 (-638 (-950 (-217)))) (-5 *1 (-1260)))) (-3003 (*1 *1) (-5 *1 (-1260))) (-2330 (*1 *1 *1) (-5 *1 (-1260))) (-4530 (*1 *2 *1) (-12 (-5 *2 (-638 (-258))) (-5 *1 (-1260)))) (-4530 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-258))) (-5 *1 (-1260)))) (-2330 (*1 *1 *2 *3) (-12 (-5 *2 (-477)) (-5 *3 (-638 (-258))) (-5 *1 (-1260)))) (-2761 (*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (-12 (-5 *3 (-923)) (-5 *4 (-217)) (-5 *5 (-572)) (-5 *6 (-875)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2065 (*1 *2 *1) (-12 (-5 *2 (-1259 (-2 (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)) (|:| -4161 (-572)) (|:| -4058 (-572)) (|:| |spline| (-572)) (|:| -1753 (-572)) (|:| |axesColor| (-875)) (|:| -1810 (-572)) (|:| |unitsColor| (-875)) (|:| |showing| (-572))))) (-5 *1 (-1260)))) (-3213 (*1 *2 *1) (-12 (-5 *2 (-1259 (-3 (-477) "undefined"))) (-5 *1 (-1260)))) (-3493 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2426 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-477)) (-5 *4 (-923)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2839 (*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-5 *2 (-477)) (-5 *1 (-1260)))) (-1753 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-1753 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-875)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-1810 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-1810 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-875)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-4161 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-3137 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-4058 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2392 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2371 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2183 (*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-769)) (-5 *4 (-923)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-1355 (*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-923)) (-5 *4 (-385)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2953 (*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-923)) (-5 *4 (-385)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-3212 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2203 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2920 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-477)) (-5 *4 (-923)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-2643 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1264)) (-5 *1 (-1260)))) (-3324 (*1 *2 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1260)))) (-3324 (*1 *2 *1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1260)))) (-3324 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-1152)) (-5 *1 (-1260)))) (-3319 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1260)))) (-4111 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1260))))) 
-(-13 (-1098) (-10 -8 (-15 -2030 ((-638 (-950 (-217))) $)) (-15 -3003 ($)) (-15 -2330 ($ $)) (-15 -4530 ((-638 (-258)) $)) (-15 -4530 ($ $ (-638 (-258)))) (-15 -2330 ($ (-477) (-638 (-258)))) (-15 -2761 ((-1264) $ (-923) (-217) (-217) (-217) (-217) (-572) (-572) (-572) (-572) (-875) (-572) (-875) (-572))) (-15 -2065 ((-1259 (-2 (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)) (|:| -4161 (-572)) (|:| -4058 (-572)) (|:| |spline| (-572)) (|:| -1753 (-572)) (|:| |axesColor| (-875)) (|:| -1810 (-572)) (|:| |unitsColor| (-875)) (|:| |showing| (-572)))) $)) (-15 -3213 ((-1259 (-3 (-477) "undefined")) $)) (-15 -3493 ((-1264) $ (-1152))) (-15 -2426 ((-1264) $ (-477) (-923))) (-15 -2839 ((-477) $ (-923))) (-15 -1753 ((-1264) $ (-923) (-1152))) (-15 -1753 ((-1264) $ (-923) (-875))) (-15 -1810 ((-1264) $ (-923) (-1152))) (-15 -1810 ((-1264) $ (-923) (-875))) (-15 -4161 ((-1264) $ (-923) (-1152))) (-15 -3137 ((-1264) $ (-923) (-1152))) (-15 -4058 ((-1264) $ (-923) (-1152))) (-15 -2392 ((-1264) $ (-1152))) (-15 -2371 ((-1264) $)) (-15 -2183 ((-1264) $ (-769) (-769) (-923) (-923))) (-15 -1355 ((-1264) $ (-923) (-385) (-385))) (-15 -2953 ((-1264) $ (-923) (-385) (-385))) (-15 -3212 ((-1264) $ (-923) (-1152))) (-15 -2203 ((-1264) $ (-769) (-769))) (-15 -2920 ((-1264) $ (-477) (-923))) (-15 -2643 ((-1264) $ (-923) (-923))) (-15 -3324 ((-1152) $ (-1152))) (-15 -3324 ((-1152) $ (-1152) (-1152))) (-15 -3324 ((-1152) $ (-1152) (-638 (-1152)))) (-15 -3319 ((-1264) $)) (-15 -4111 ((-572) $)) (-15 -3972 ((-856) $)))) 
-((-2262 (((-121) $ $) NIL)) (-4423 (((-1264) $ (-385)) 138) (((-1264) $ (-385) (-385) (-385)) 139)) (-3324 (((-1152) $ (-1152)) 146) (((-1152) $ (-1152) (-1152)) 144) (((-1152) $ (-1152) (-638 (-1152))) 143)) (-4471 (($) 49)) (-2469 (((-1264) $ (-385) (-385) (-385) (-385) (-385)) 114) (((-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))) $) 112) (((-1264) $ (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) 113) (((-1264) $ (-572) (-572) (-385) (-385) (-385)) 115) (((-1264) $ (-385) (-385)) 116) (((-1264) $ (-385) (-385) (-385)) 123)) (-2620 (((-385)) 96) (((-385) (-385)) 97)) (-1984 (((-385)) 91) (((-385) (-385)) 93)) (-3810 (((-385)) 94) (((-385) (-385)) 95)) (-2537 (((-385)) 100) (((-385) (-385)) 101)) (-3823 (((-385)) 98) (((-385) (-385)) 99)) (-2953 (((-1264) $ (-385) (-385)) 140)) (-3493 (((-1264) $ (-1152)) 124)) (-4410 (((-1129 (-217)) $) 50) (($ $ (-1129 (-217))) 51)) (-2623 (((-1264) $ (-1152)) 152)) (-2434 (((-1264) $ (-1152)) 153)) (-3406 (((-1264) $ (-385) (-385)) 122) (((-1264) $ (-572) (-572)) 137)) (-2643 (((-1264) $ (-923) (-923)) 130)) (-3319 (((-1264) $) 110)) (-1684 (((-1264) $ (-1152)) 151)) (-2510 (((-1264) $ (-1152)) 107)) (-4530 (((-638 (-258)) $) 52) (($ $ (-638 (-258))) 53)) (-2203 (((-1264) $ (-769) (-769)) 129)) (-2832 (((-1264) $ (-769) (-950 (-217))) 158)) (-4419 (($ $) 56) (($ (-1129 (-217)) (-1152)) 57) (($ (-1129 (-217)) (-638 (-258))) 58)) (-2872 (((-1264) $ (-385) (-385) (-385)) 104)) (-1658 (((-1152) $) NIL)) (-4111 (((-572) $) 102)) (-3440 (((-1264) $ (-385)) 141)) (-3256 (((-1264) $ (-385)) 156)) (-2607 (((-1116) $) NIL)) (-2662 (((-1264) $ (-385)) 155)) (-1871 (((-1264) $ (-1152)) 109)) (-2183 (((-1264) $ (-769) (-769) (-923) (-923)) 128)) (-4002 (((-1264) $ (-1152)) 106)) (-2392 (((-1264) $ (-1152)) 108)) (-3051 (((-1264) $ (-159) (-159)) 127)) (-3972 (((-856) $) 135)) (-2371 (((-1264) $) 111)) (-1344 (((-1264) $ (-1152)) 154)) (-1753 (((-1264) $ (-1152)) 105)) (-1324 (((-121) $ $) NIL))) 
-(((-1261) (-13 (-1098) (-10 -8 (-15 -1984 ((-385))) (-15 -1984 ((-385) (-385))) (-15 -3810 ((-385))) (-15 -3810 ((-385) (-385))) (-15 -2620 ((-385))) (-15 -2620 ((-385) (-385))) (-15 -3823 ((-385))) (-15 -3823 ((-385) (-385))) (-15 -2537 ((-385))) (-15 -2537 ((-385) (-385))) (-15 -4471 ($)) (-15 -4419 ($ $)) (-15 -4419 ($ (-1129 (-217)) (-1152))) (-15 -4419 ($ (-1129 (-217)) (-638 (-258)))) (-15 -4410 ((-1129 (-217)) $)) (-15 -4410 ($ $ (-1129 (-217)))) (-15 -2832 ((-1264) $ (-769) (-950 (-217)))) (-15 -4530 ((-638 (-258)) $)) (-15 -4530 ($ $ (-638 (-258)))) (-15 -2203 ((-1264) $ (-769) (-769))) (-15 -2643 ((-1264) $ (-923) (-923))) (-15 -3493 ((-1264) $ (-1152))) (-15 -2183 ((-1264) $ (-769) (-769) (-923) (-923))) (-15 -2469 ((-1264) $ (-385) (-385) (-385) (-385) (-385))) (-15 -2469 ((-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))) $)) (-15 -2469 ((-1264) $ (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))))) (-15 -2469 ((-1264) $ (-572) (-572) (-385) (-385) (-385))) (-15 -2469 ((-1264) $ (-385) (-385))) (-15 -2469 ((-1264) $ (-385) (-385) (-385))) (-15 -2392 ((-1264) $ (-1152))) (-15 -1753 ((-1264) $ (-1152))) (-15 -4002 ((-1264) $ (-1152))) (-15 -2510 ((-1264) $ (-1152))) (-15 -1871 ((-1264) $ (-1152))) (-15 -3406 ((-1264) $ (-385) (-385))) (-15 -3406 ((-1264) $ (-572) (-572))) (-15 -4423 ((-1264) $ (-385))) (-15 -4423 ((-1264) $ (-385) (-385) (-385))) (-15 -2953 ((-1264) $ (-385) (-385))) (-15 -1684 ((-1264) $ (-1152))) (-15 -2662 ((-1264) $ (-385))) (-15 -3256 ((-1264) $ (-385))) (-15 -2623 ((-1264) $ (-1152))) (-15 -2434 ((-1264) $ (-1152))) (-15 -1344 ((-1264) $ (-1152))) (-15 -2872 ((-1264) $ (-385) (-385) (-385))) (-15 -3440 ((-1264) $ (-385))) (-15 -3319 ((-1264) $)) (-15 -3051 ((-1264) $ (-159) (-159))) (-15 -3324 ((-1152) $ (-1152))) (-15 -3324 ((-1152) $ (-1152) (-1152))) (-15 -3324 ((-1152) $ (-1152) (-638 (-1152)))) (-15 -2371 ((-1264) $)) (-15 -4111 ((-572) $))))) (T -1261)) 
-((-1984 (*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-1984 (*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-3810 (*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-3810 (*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-2620 (*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-2620 (*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-3823 (*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-3823 (*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-2537 (*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-2537 (*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) (-4471 (*1 *1) (-5 *1 (-1261))) (-4419 (*1 *1 *1) (-5 *1 (-1261))) (-4419 (*1 *1 *2 *3) (-12 (-5 *2 (-1129 (-217))) (-5 *3 (-1152)) (-5 *1 (-1261)))) (-4419 (*1 *1 *2 *3) (-12 (-5 *2 (-1129 (-217))) (-5 *3 (-638 (-258))) (-5 *1 (-1261)))) (-4410 (*1 *2 *1) (-12 (-5 *2 (-1129 (-217))) (-5 *1 (-1261)))) (-4410 (*1 *1 *1 *2) (-12 (-5 *2 (-1129 (-217))) (-5 *1 (-1261)))) (-2832 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-769)) (-5 *4 (-950 (-217))) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-4530 (*1 *2 *1) (-12 (-5 *2 (-638 (-258))) (-5 *1 (-1261)))) (-4530 (*1 *1 *1 *2) (-12 (-5 *2 (-638 (-258))) (-5 *1 (-1261)))) (-2203 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2643 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-3493 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2183 (*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-769)) (-5 *4 (-923)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2469 (*1 *2 *1 *3 *3 *3 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2469 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) (-5 *1 (-1261)))) (-2469 (*1 *2 *1 *3) (-12 (-5 *3 (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2469 (*1 *2 *1 *3 *3 *4 *4 *4) (-12 (-5 *3 (-572)) (-5 *4 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2469 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2469 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2392 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-1753 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-4002 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2510 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-1871 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-3406 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-3406 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-4423 (*1 *2 *1 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-4423 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2953 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-1684 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2662 (*1 *2 *1 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-3256 (*1 *2 *1 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2623 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2434 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-1344 (*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-2872 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-3440 (*1 *2 *1 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-3319 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1261)))) (-3051 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-159)) (-5 *2 (-1264)) (-5 *1 (-1261)))) (-3324 (*1 *2 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1261)))) (-3324 (*1 *2 *1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1261)))) (-3324 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-1152)) (-5 *1 (-1261)))) (-2371 (*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1261)))) (-4111 (*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1261))))) 
-(-13 (-1098) (-10 -8 (-15 -1984 ((-385))) (-15 -1984 ((-385) (-385))) (-15 -3810 ((-385))) (-15 -3810 ((-385) (-385))) (-15 -2620 ((-385))) (-15 -2620 ((-385) (-385))) (-15 -3823 ((-385))) (-15 -3823 ((-385) (-385))) (-15 -2537 ((-385))) (-15 -2537 ((-385) (-385))) (-15 -4471 ($)) (-15 -4419 ($ $)) (-15 -4419 ($ (-1129 (-217)) (-1152))) (-15 -4419 ($ (-1129 (-217)) (-638 (-258)))) (-15 -4410 ((-1129 (-217)) $)) (-15 -4410 ($ $ (-1129 (-217)))) (-15 -2832 ((-1264) $ (-769) (-950 (-217)))) (-15 -4530 ((-638 (-258)) $)) (-15 -4530 ($ $ (-638 (-258)))) (-15 -2203 ((-1264) $ (-769) (-769))) (-15 -2643 ((-1264) $ (-923) (-923))) (-15 -3493 ((-1264) $ (-1152))) (-15 -2183 ((-1264) $ (-769) (-769) (-923) (-923))) (-15 -2469 ((-1264) $ (-385) (-385) (-385) (-385) (-385))) (-15 -2469 ((-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))) $)) (-15 -2469 ((-1264) $ (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217))))) (-15 -2469 ((-1264) $ (-572) (-572) (-385) (-385) (-385))) (-15 -2469 ((-1264) $ (-385) (-385))) (-15 -2469 ((-1264) $ (-385) (-385) (-385))) (-15 -2392 ((-1264) $ (-1152))) (-15 -1753 ((-1264) $ (-1152))) (-15 -4002 ((-1264) $ (-1152))) (-15 -2510 ((-1264) $ (-1152))) (-15 -1871 ((-1264) $ (-1152))) (-15 -3406 ((-1264) $ (-385) (-385))) (-15 -3406 ((-1264) $ (-572) (-572))) (-15 -4423 ((-1264) $ (-385))) (-15 -4423 ((-1264) $ (-385) (-385) (-385))) (-15 -2953 ((-1264) $ (-385) (-385))) (-15 -1684 ((-1264) $ (-1152))) (-15 -2662 ((-1264) $ (-385))) (-15 -3256 ((-1264) $ (-385))) (-15 -2623 ((-1264) $ (-1152))) (-15 -2434 ((-1264) $ (-1152))) (-15 -1344 ((-1264) $ (-1152))) (-15 -2872 ((-1264) $ (-385) (-385) (-385))) (-15 -3440 ((-1264) $ (-385))) (-15 -3319 ((-1264) $)) (-15 -3051 ((-1264) $ (-159) (-159))) (-15 -3324 ((-1152) $ (-1152))) (-15 -3324 ((-1152) $ (-1152) (-1152))) (-15 -3324 ((-1152) $ (-1152) (-638 (-1152)))) (-15 -2371 ((-1264) $)) (-15 -4111 ((-572) $)))) 
-((-4463 (((-638 (-1152)) (-638 (-1152))) 94) (((-638 (-1152))) 89)) (-3269 (((-638 (-1152))) 87)) (-1482 (((-638 (-923)) (-638 (-923))) 62) (((-638 (-923))) 59)) (-1690 (((-638 (-769)) (-638 (-769))) 56) (((-638 (-769))) 52)) (-2899 (((-1264)) 64)) (-4114 (((-923) (-923)) 80) (((-923)) 79)) (-2131 (((-923) (-923)) 78) (((-923)) 77)) (-2156 (((-875) (-875)) 74) (((-875)) 73)) (-2463 (((-217)) 84) (((-217) (-385)) 86)) (-2965 (((-923)) 81) (((-923) (-923)) 82)) (-1904 (((-923) (-923)) 76) (((-923)) 75)) (-3517 (((-875) (-875)) 68) (((-875)) 66)) (-2500 (((-875) (-875)) 70) (((-875)) 69)) (-2411 (((-875) (-875)) 72) (((-875)) 71))) 
-(((-1262) (-10 -7 (-15 -3517 ((-875))) (-15 -3517 ((-875) (-875))) (-15 -2500 ((-875))) (-15 -2500 ((-875) (-875))) (-15 -2411 ((-875))) (-15 -2411 ((-875) (-875))) (-15 -2156 ((-875))) (-15 -2156 ((-875) (-875))) (-15 -1904 ((-923))) (-15 -1904 ((-923) (-923))) (-15 -1690 ((-638 (-769)))) (-15 -1690 ((-638 (-769)) (-638 (-769)))) (-15 -1482 ((-638 (-923)))) (-15 -1482 ((-638 (-923)) (-638 (-923)))) (-15 -2899 ((-1264))) (-15 -4463 ((-638 (-1152)))) (-15 -4463 ((-638 (-1152)) (-638 (-1152)))) (-15 -3269 ((-638 (-1152)))) (-15 -2131 ((-923))) (-15 -4114 ((-923))) (-15 -2131 ((-923) (-923))) (-15 -4114 ((-923) (-923))) (-15 -2965 ((-923) (-923))) (-15 -2965 ((-923))) (-15 -2463 ((-217) (-385))) (-15 -2463 ((-217))))) (T -1262)) 
-((-2463 (*1 *2) (-12 (-5 *2 (-217)) (-5 *1 (-1262)))) (-2463 (*1 *2 *3) (-12 (-5 *3 (-385)) (-5 *2 (-217)) (-5 *1 (-1262)))) (-2965 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) (-2965 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) (-4114 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) (-2131 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) (-4114 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) (-2131 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) (-3269 (*1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1262)))) (-4463 (*1 *2 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1262)))) (-4463 (*1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1262)))) (-2899 (*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1262)))) (-1482 (*1 *2 *2) (-12 (-5 *2 (-638 (-923))) (-5 *1 (-1262)))) (-1482 (*1 *2) (-12 (-5 *2 (-638 (-923))) (-5 *1 (-1262)))) (-1690 (*1 *2 *2) (-12 (-5 *2 (-638 (-769))) (-5 *1 (-1262)))) (-1690 (*1 *2) (-12 (-5 *2 (-638 (-769))) (-5 *1 (-1262)))) (-1904 (*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) (-1904 (*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) (-2156 (*1 *2 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) (-2156 (*1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) (-2411 (*1 *2 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) (-2411 (*1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) (-2500 (*1 *2 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) (-2500 (*1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) (-3517 (*1 *2 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) (-3517 (*1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262))))) 
-(-10 -7 (-15 -3517 ((-875))) (-15 -3517 ((-875) (-875))) (-15 -2500 ((-875))) (-15 -2500 ((-875) (-875))) (-15 -2411 ((-875))) (-15 -2411 ((-875) (-875))) (-15 -2156 ((-875))) (-15 -2156 ((-875) (-875))) (-15 -1904 ((-923))) (-15 -1904 ((-923) (-923))) (-15 -1690 ((-638 (-769)))) (-15 -1690 ((-638 (-769)) (-638 (-769)))) (-15 -1482 ((-638 (-923)))) (-15 -1482 ((-638 (-923)) (-638 (-923)))) (-15 -2899 ((-1264))) (-15 -4463 ((-638 (-1152)))) (-15 -4463 ((-638 (-1152)) (-638 (-1152)))) (-15 -3269 ((-638 (-1152)))) (-15 -2131 ((-923))) (-15 -4114 ((-923))) (-15 -2131 ((-923) (-923))) (-15 -4114 ((-923) (-923))) (-15 -2965 ((-923) (-923))) (-15 -2965 ((-923))) (-15 -2463 ((-217) (-385))) (-15 -2463 ((-217)))) 
-((-2114 (((-477) (-638 (-638 (-950 (-217)))) (-638 (-258))) 17) (((-477) (-638 (-638 (-950 (-217))))) 16) (((-477) (-638 (-638 (-950 (-217)))) (-875) (-875) (-923) (-638 (-258))) 15)) (-2698 (((-1260) (-638 (-638 (-950 (-217)))) (-638 (-258))) 23) (((-1260) (-638 (-638 (-950 (-217)))) (-875) (-875) (-923) (-638 (-258))) 22)) (-3972 (((-1260) (-477)) 34))) 
-(((-1263) (-10 -7 (-15 -2114 ((-477) (-638 (-638 (-950 (-217)))) (-875) (-875) (-923) (-638 (-258)))) (-15 -2114 ((-477) (-638 (-638 (-950 (-217)))))) (-15 -2114 ((-477) (-638 (-638 (-950 (-217)))) (-638 (-258)))) (-15 -2698 ((-1260) (-638 (-638 (-950 (-217)))) (-875) (-875) (-923) (-638 (-258)))) (-15 -2698 ((-1260) (-638 (-638 (-950 (-217)))) (-638 (-258)))) (-15 -3972 ((-1260) (-477))))) (T -1263)) 
-((-3972 (*1 *2 *3) (-12 (-5 *3 (-477)) (-5 *2 (-1260)) (-5 *1 (-1263)))) (-2698 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-1263)))) (-2698 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-875)) (-5 *5 (-923)) (-5 *6 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-1263)))) (-2114 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-638 (-258))) (-5 *2 (-477)) (-5 *1 (-1263)))) (-2114 (*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *2 (-477)) (-5 *1 (-1263)))) (-2114 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-875)) (-5 *5 (-923)) (-5 *6 (-638 (-258))) (-5 *2 (-477)) (-5 *1 (-1263))))) 
-(-10 -7 (-15 -2114 ((-477) (-638 (-638 (-950 (-217)))) (-875) (-875) (-923) (-638 (-258)))) (-15 -2114 ((-477) (-638 (-638 (-950 (-217)))))) (-15 -2114 ((-477) (-638 (-638 (-950 (-217)))) (-638 (-258)))) (-15 -2698 ((-1260) (-638 (-638 (-950 (-217)))) (-875) (-875) (-923) (-638 (-258)))) (-15 -2698 ((-1260) (-638 (-638 (-950 (-217)))) (-638 (-258)))) (-15 -3972 ((-1260) (-477)))) 
-((-3166 (($) 7)) (-3972 (((-856) $) 10))) 
-(((-1264) (-10 -8 (-15 -3166 ($)) (-15 -3972 ((-856) $)))) (T -1264)) 
-((-3972 (*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1264)))) (-3166 (*1 *1) (-5 *1 (-1264)))) 
-(-10 -8 (-15 -3166 ($)) (-15 -3972 ((-856) $))) 
-((-1379 (($ $ |#2|) 10))) 
-(((-1265 |#1| |#2|) (-10 -8 (-15 -1379 (|#1| |#1| |#2|))) (-1266 |#2|) (-368)) (T -1265)) 
-NIL 
-(-10 -8 (-15 -1379 (|#1| |#1| |#2|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-2502 (((-140)) 25)) (-3972 (((-856) $) 11)) (-2378 (($) 17 T CONST)) (-1324 (((-121) $ $) 6)) (-1379 (($ $ |#1|) 26)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
-(((-1266 |#1|) (-1290) (-368)) (T -1266)) 
-((-1379 (*1 *1 *1 *2) (-12 (-4 *1 (-1266 *2)) (-4 *2 (-368)))) (-2502 (*1 *2) (-12 (-4 *1 (-1266 *3)) (-4 *3 (-368)) (-5 *2 (-140))))) 
-(-13 (-713 |t#1|) (-10 -8 (-15 -1379 ($ $ |t#1|)) (-15 -2502 ((-140))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-713 |#1|) . T) ((-1060 |#1|) . T) ((-1098) . T)) 
-((-1720 (((-638 (-1199 |#1|)) (-1170) (-1199 |#1|)) 78)) (-3831 (((-1150 (-1150 (-959 |#1|))) (-1170) (-1150 (-959 |#1|))) 57)) (-4120 (((-1 (-1150 (-1199 |#1|)) (-1150 (-1199 |#1|))) (-769) (-1199 |#1|) (-1150 (-1199 |#1|))) 68)) (-2266 (((-1 (-1150 (-959 |#1|)) (-1150 (-959 |#1|))) (-769)) 59)) (-3225 (((-1 (-1166 (-959 |#1|)) (-959 |#1|)) (-1170)) 27)) (-2257 (((-1 (-1150 (-959 |#1|)) (-1150 (-959 |#1|))) (-769)) 58))) 
-(((-1267 |#1|) (-10 -7 (-15 -2266 ((-1 (-1150 (-959 |#1|)) (-1150 (-959 |#1|))) (-769))) (-15 -2257 ((-1 (-1150 (-959 |#1|)) (-1150 (-959 |#1|))) (-769))) (-15 -3831 ((-1150 (-1150 (-959 |#1|))) (-1170) (-1150 (-959 |#1|)))) (-15 -3225 ((-1 (-1166 (-959 |#1|)) (-959 |#1|)) (-1170))) (-15 -1720 ((-638 (-1199 |#1|)) (-1170) (-1199 |#1|))) (-15 -4120 ((-1 (-1150 (-1199 |#1|)) (-1150 (-1199 |#1|))) (-769) (-1199 |#1|) (-1150 (-1199 |#1|))))) (-368)) (T -1267)) 
-((-4120 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-769)) (-4 *6 (-368)) (-5 *4 (-1199 *6)) (-5 *2 (-1 (-1150 *4) (-1150 *4))) (-5 *1 (-1267 *6)) (-5 *5 (-1150 *4)))) (-1720 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-4 *5 (-368)) (-5 *2 (-638 (-1199 *5))) (-5 *1 (-1267 *5)) (-5 *4 (-1199 *5)))) (-3225 (*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-1166 (-959 *4)) (-959 *4))) (-5 *1 (-1267 *4)) (-4 *4 (-368)))) (-3831 (*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-4 *5 (-368)) (-5 *2 (-1150 (-1150 (-959 *5)))) (-5 *1 (-1267 *5)) (-5 *4 (-1150 (-959 *5))))) (-2257 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-1150 (-959 *4)) (-1150 (-959 *4)))) (-5 *1 (-1267 *4)) (-4 *4 (-368)))) (-2266 (*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-1150 (-959 *4)) (-1150 (-959 *4)))) (-5 *1 (-1267 *4)) (-4 *4 (-368))))) 
-(-10 -7 (-15 -2266 ((-1 (-1150 (-959 |#1|)) (-1150 (-959 |#1|))) (-769))) (-15 -2257 ((-1 (-1150 (-959 |#1|)) (-1150 (-959 |#1|))) (-769))) (-15 -3831 ((-1150 (-1150 (-959 |#1|))) (-1170) (-1150 (-959 |#1|)))) (-15 -3225 ((-1 (-1166 (-959 |#1|)) (-959 |#1|)) (-1170))) (-15 -1720 ((-638 (-1199 |#1|)) (-1170) (-1199 |#1|))) (-15 -4120 ((-1 (-1150 (-1199 |#1|)) (-1150 (-1199 |#1|))) (-769) (-1199 |#1|) (-1150 (-1199 |#1|))))) 
-((-4122 (((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) |#2|) 74)) (-1778 (((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|)))) 73))) 
-(((-1268 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1778 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))))) (-15 -4122 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) |#2|))) (-353) (-1234 |#1|) (-1234 |#2|) (-415 |#2| |#3|)) (T -1268)) 
-((-4122 (*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-1268 *4 *3 *5 *6)) (-4 *6 (-415 *3 *5)))) (-1778 (*1 *2) (-12 (-4 *3 (-353)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -2237 (-685 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-685 *4)))) (-5 *1 (-1268 *3 *4 *5 *6)) (-4 *6 (-415 *4 *5))))) 
-(-10 -7 (-15 -1778 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))))) (-15 -4122 ((-2 (|:| -2237 (-685 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-685 |#2|))) |#2|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 41)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) NIL)) (-3893 (((-121) $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-3972 (((-856) $) 62) (($ (-572)) NIL) ((|#4| $) 52) (($ |#4|) 47) (($ |#1|) NIL (|has| |#1| (-174)))) (-2140 (((-769)) NIL)) (-2733 (((-1264) (-769)) 16)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 26 T CONST)) (-3255 (($) 65 T CONST)) (-1324 (((-121) $ $) 67)) (-1379 (((-3 $ "failed") $ $) NIL (|has| |#1| (-368)))) (-1373 (($ $) 69) (($ $ $) NIL)) (-1367 (($ $ $) 45)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 71) (($ |#1| $) NIL (|has| |#1| (-174))) (($ $ |#1|) NIL (|has| |#1| (-174))))) 
-(((-1269 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-13 (-1054) (-10 -8 (IF (|has| |#1| (-174)) (-6 (-43 |#1|)) |noBranch|) (-15 -3972 (|#4| $)) (IF (|has| |#1| (-368)) (-15 -1379 ((-3 $ "failed") $ $)) |noBranch|) (-15 -3972 ($ |#4|)) (-15 -2733 ((-1264) (-769))))) (-1054) (-848) (-794) (-956 |#1| |#3| |#2|) (-638 |#2|) (-638 (-769)) (-769)) (T -1269)) 
-((-3972 (*1 *2 *1) (-12 (-4 *2 (-956 *3 *5 *4)) (-5 *1 (-1269 *3 *4 *5 *2 *6 *7 *8)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-794)) (-14 *6 (-638 *4)) (-14 *7 (-638 (-769))) (-14 *8 (-769)))) (-1379 (*1 *1 *1 *1) (|partial| -12 (-4 *2 (-368)) (-4 *2 (-1054)) (-4 *3 (-848)) (-4 *4 (-794)) (-14 *6 (-638 *3)) (-5 *1 (-1269 *2 *3 *4 *5 *6 *7 *8)) (-4 *5 (-956 *2 *4 *3)) (-14 *7 (-638 (-769))) (-14 *8 (-769)))) (-3972 (*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-794)) (-14 *6 (-638 *4)) (-5 *1 (-1269 *3 *4 *5 *2 *6 *7 *8)) (-4 *2 (-956 *3 *5 *4)) (-14 *7 (-638 (-769))) (-14 *8 (-769)))) (-2733 (*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-1054)) (-4 *5 (-848)) (-4 *6 (-794)) (-14 *8 (-638 *5)) (-5 *2 (-1264)) (-5 *1 (-1269 *4 *5 *6 *7 *8 *9 *10)) (-4 *7 (-956 *4 *6 *5)) (-14 *9 (-638 *3)) (-14 *10 *3)))) 
-(-13 (-1054) (-10 -8 (IF (|has| |#1| (-174)) (-6 (-43 |#1|)) |noBranch|) (-15 -3972 (|#4| $)) (IF (|has| |#1| (-368)) (-15 -1379 ((-3 $ "failed") $ $)) |noBranch|) (-15 -3972 ($ |#4|)) (-15 -2733 ((-1264) (-769))))) 
-((-2262 (((-121) $ $) NIL)) (-4125 (((-638 (-2 (|:| -2371 $) (|:| -1428 (-638 |#4|)))) (-638 |#4|)) NIL)) (-4165 (((-638 $) (-638 |#4|)) 87)) (-3456 (((-638 |#3|) $) NIL)) (-3049 (((-121) $) NIL)) (-3289 (((-121) $) NIL (|has| |#1| (-562)))) (-3366 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1872 ((|#4| |#4| $) NIL)) (-3008 (((-2 (|:| |under| $) (|:| -1716 $) (|:| |upper| $)) $ |#3|) NIL)) (-1946 (((-121) $ (-769)) NIL)) (-2561 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602))) (((-3 |#4| "failed") $ |#3|) NIL)) (-2211 (($) NIL T CONST)) (-3097 (((-121) $) NIL (|has| |#1| (-562)))) (-3760 (((-121) $ $) NIL (|has| |#1| (-562)))) (-3819 (((-121) $ $) NIL (|has| |#1| (-562)))) (-4331 (((-121) $) NIL (|has| |#1| (-562)))) (-4577 (((-638 |#4|) (-638 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 27)) (-3683 (((-638 |#4|) (-638 |#4|) $) 24 (|has| |#1| (-562)))) (-2320 (((-638 |#4|) (-638 |#4|) $) NIL (|has| |#1| (-562)))) (-3376 (((-3 $ "failed") (-638 |#4|)) NIL)) (-1318 (($ (-638 |#4|)) NIL)) (-1651 (((-3 $ "failed") $) 69)) (-2242 ((|#4| |#4| $) 74)) (-1643 (($ $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-3445 (($ |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-2492 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-562)))) (-2240 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-1673 ((|#4| |#4| $) NIL)) (-3116 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4602))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4602))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3725 (((-2 (|:| -2371 (-638 |#4|)) (|:| -1428 (-638 |#4|))) $) NIL)) (-2010 (((-638 |#4|) $) NIL (|has| $ (-6 -4602)))) (-3824 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1792 ((|#3| $) 75)) (-2157 (((-121) $ (-769)) NIL)) (-4467 (((-638 |#4|) $) 28 (|has| $ (-6 -4602)))) (-3002 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098))))) (-3904 (((-3 $ "failed") (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 31) (((-3 $ "failed") (-638 |#4|)) 34)) (-2435 (($ (-1 |#4| |#4|) $) NIL (|has| $ (-6 -4603)))) (-3828 (($ (-1 |#4| |#4|) $) NIL)) (-4062 (((-638 |#3|) $) NIL)) (-1346 (((-121) |#3| $) NIL)) (-3524 (((-121) $ (-769)) NIL)) (-1658 (((-1152) $) NIL)) (-3253 (((-3 |#4| "failed") $) NIL)) (-3727 (((-638 |#4|) $) 49)) (-1483 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2788 ((|#4| |#4| $) 73)) (-1843 (((-121) $ $) 84)) (-2566 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-562)))) (-1994 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4498 ((|#4| |#4| $) NIL)) (-2607 (((-1116) $) NIL)) (-1837 (((-3 |#4| "failed") $) 68)) (-3361 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1928 (((-3 $ "failed") $ |#4|) NIL)) (-1977 (($ $ |#4|) NIL)) (-2109 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-4485 (($ $ (-638 |#4|) (-638 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-290 |#4|)) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098)))) (($ $ (-638 (-290 |#4|))) NIL (-12 (|has| |#4| (-305 |#4|)) (|has| |#4| (-1098))))) (-3598 (((-121) $ $) NIL)) (-4037 (((-121) $) 66)) (-1665 (($) 41)) (-4316 (((-769) $) NIL)) (-1571 (((-769) |#4| $) NIL (-12 (|has| $ (-6 -4602)) (|has| |#4| (-1098)))) (((-769) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1607 (($ $) NIL)) (-4081 (((-545) $) NIL (|has| |#4| (-613 (-545))))) (-3921 (($ (-638 |#4|)) NIL)) (-1826 (($ $ |#3|) NIL)) (-2291 (($ $ |#3|) NIL)) (-3134 (($ $) NIL)) (-1650 (($ $ |#3|) NIL)) (-3972 (((-856) $) NIL) (((-638 |#4|) $) 56)) (-2498 (((-769) $) NIL (|has| |#3| (-374)))) (-2813 (((-3 $ "failed") (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 39) (((-3 $ "failed") (-638 |#4|)) 40)) (-3954 (((-638 $) (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 64) (((-638 $) (-638 |#4|)) 65)) (-1586 (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4| |#4|)) 23) (((-3 (-2 (|:| |bas| $) (|:| -1615 (-638 |#4|))) "failed") (-638 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2057 (((-121) $ (-1 (-121) |#4| (-638 |#4|))) NIL)) (-3501 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4602)))) (-1502 (((-638 |#3|) $) NIL)) (-2213 (((-121) |#3| $) NIL)) (-1324 (((-121) $ $) NIL)) (-4032 (((-769) $) NIL (|has| $ (-6 -4602))))) 
-(((-1270 |#1| |#2| |#3| |#4|) (-13 (-1198 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3904 ((-3 $ "failed") (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3904 ((-3 $ "failed") (-638 |#4|))) (-15 -2813 ((-3 $ "failed") (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2813 ((-3 $ "failed") (-638 |#4|))) (-15 -3954 ((-638 $) (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3954 ((-638 $) (-638 |#4|))))) (-562) (-794) (-848) (-1068 |#1| |#2| |#3|)) (T -1270)) 
-((-3904 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-638 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1270 *5 *6 *7 *8)))) (-3904 (*1 *1 *2) (|partial| -12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1270 *3 *4 *5 *6)))) (-2813 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-638 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1270 *5 *6 *7 *8)))) (-2813 (*1 *1 *2) (|partial| -12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1270 *3 *4 *5 *6)))) (-3954 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1068 *6 *7 *8)) (-4 *6 (-562)) (-4 *7 (-794)) (-4 *8 (-848)) (-5 *2 (-638 (-1270 *6 *7 *8 *9))) (-5 *1 (-1270 *6 *7 *8 *9)))) (-3954 (*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 (-1270 *4 *5 *6 *7))) (-5 *1 (-1270 *4 *5 *6 *7))))) 
-(-13 (-1198 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3904 ((-3 $ "failed") (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3904 ((-3 $ "failed") (-638 |#4|))) (-15 -2813 ((-3 $ "failed") (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2813 ((-3 $ "failed") (-638 |#4|))) (-15 -3954 ((-638 $) (-638 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3954 ((-638 $) (-638 |#4|))))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-1572 (((-3 $ "failed") $ $) 18)) (-2211 (($) 16 T CONST)) (-1799 (((-3 $ "failed") $) 33)) (-3893 (((-121) $) 30)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#1|) 37)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ |#1|) 39) (($ |#1| $) 38))) 
-(((-1271 |#1|) (-1290) (-1054)) (T -1271)) 
-((-3972 (*1 *1 *2) (-12 (-4 *1 (-1271 *2)) (-4 *2 (-1054))))) 
-(-13 (-1054) (-120 |t#1| |t#1|) (-10 -8 (-15 -3972 ($ |t#1|)) (IF (|has| |t#1| (-174)) (-6 (-43 |t#1|)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-174)) ((-105) . T) ((-120 |#1| |#1|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 |#1|) |has| |#1| (-174)) ((-722) . T) ((-1060 |#1|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2199 (((-638 |#1|) $) 45)) (-2007 (($ $ (-769)) 39)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2850 (($ $ (-769)) 17 (|has| |#2| (-174))) (($ $ $) 18 (|has| |#2| (-174)))) (-2211 (($) NIL T CONST)) (-3754 (($ $ $) 61) (($ $ (-820 |#1|)) 48) (($ $ |#1|) 52)) (-3376 (((-3 (-820 |#1|) "failed") $) NIL)) (-1318 (((-820 |#1|) $) NIL)) (-4383 (($ $) 32)) (-1799 (((-3 $ "failed") $) NIL)) (-1842 (((-121) $) NIL)) (-2597 (($ $) NIL)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4518 (($ (-820 |#1|) |#2|) 31)) (-4076 (($ $) 33)) (-1435 (((-2 (|:| |k| (-820 |#1|)) (|:| |c| |#2|)) $) 11)) (-3383 (((-820 |#1|) $) NIL)) (-2460 (((-820 |#1|) $) 34)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-3561 (($ $ $) 60) (($ $ (-820 |#1|)) 50) (($ $ |#1|) 54)) (-2081 (((-638 (-2 (|:| |k| (-820 |#1|)) (|:| |c| |#2|))) $) NIL)) (-4136 (((-2 (|:| |k| (-820 |#1|)) (|:| |c| |#2|)) $) NIL)) (-4368 (((-820 |#1|) $) 28)) (-4373 ((|#2| $) 30)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4316 (((-769) $) 36)) (-2580 (((-121) $) 40)) (-3211 ((|#2| $) NIL)) (-3972 (((-856) $) NIL) (($ (-820 |#1|)) 24) (($ |#1|) 25) (($ |#2|) NIL) (($ (-572)) NIL)) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-820 |#1|)) NIL)) (-4513 ((|#2| $ $) 63) ((|#2| $ (-820 |#1|)) NIL)) (-2140 (((-769)) NIL)) (-4174 (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (-2378 (($) 12 T CONST)) (-3255 (($) 14 T CONST)) (-1324 (((-121) $ $) 38)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 21)) (** (($ $ (-769)) NIL) (($ $ (-923)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ |#2| $) 20) (($ $ |#2|) 59) (($ |#2| (-820 |#1|)) NIL) (($ |#1| $) 27) (($ $ $) NIL))) 
-(((-1272 |#1| |#2|) (-13 (-388 |#2| (-820 |#1|)) (-1278 |#1| |#2|)) (-848) (-1054)) (T -1272)) 
-NIL 
-(-13 (-388 |#2| (-820 |#1|)) (-1278 |#1| |#2|)) 
-((-3539 ((|#3| |#3| (-769)) 23)) (-4179 ((|#3| |#3| (-769)) 28)) (-2823 ((|#3| |#3| |#3| (-769)) 29))) 
-(((-1273 |#1| |#2| |#3|) (-10 -7 (-15 -4179 (|#3| |#3| (-769))) (-15 -3539 (|#3| |#3| (-769))) (-15 -2823 (|#3| |#3| |#3| (-769)))) (-13 (-1054) (-713 (-413 (-572)))) (-848) (-1278 |#2| |#1|)) (T -1273)) 
-((-2823 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-1054) (-713 (-413 (-572))))) (-4 *5 (-848)) (-5 *1 (-1273 *4 *5 *2)) (-4 *2 (-1278 *5 *4)))) (-3539 (*1 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-1054) (-713 (-413 (-572))))) (-4 *5 (-848)) (-5 *1 (-1273 *4 *5 *2)) (-4 *2 (-1278 *5 *4)))) (-4179 (*1 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-1054) (-713 (-413 (-572))))) (-4 *5 (-848)) (-5 *1 (-1273 *4 *5 *2)) (-4 *2 (-1278 *5 *4))))) 
-(-10 -7 (-15 -4179 (|#3| |#3| (-769))) (-15 -3539 (|#3| |#3| (-769))) (-15 -2823 (|#3| |#3| |#3| (-769)))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2199 (((-638 |#1|) $) 39)) (-1572 (((-3 $ "failed") $ $) 18)) (-2850 (($ $ $) 42 (|has| |#2| (-174))) (($ $ (-769)) 41 (|has| |#2| (-174)))) (-2211 (($) 16 T CONST)) (-3754 (($ $ |#1|) 53) (($ $ (-820 |#1|)) 52) (($ $ $) 51)) (-3376 (((-3 (-820 |#1|) "failed") $) 63)) (-1318 (((-820 |#1|) $) 62)) (-1799 (((-3 $ "failed") $) 33)) (-1842 (((-121) $) 44)) (-2597 (($ $) 43)) (-3893 (((-121) $) 30)) (-4581 (((-121) $) 49)) (-4518 (($ (-820 |#1|) |#2|) 50)) (-4076 (($ $) 48)) (-1435 (((-2 (|:| |k| (-820 |#1|)) (|:| |c| |#2|)) $) 59)) (-3383 (((-820 |#1|) $) 60)) (-3828 (($ (-1 |#2| |#2|) $) 40)) (-3561 (($ $ |#1|) 56) (($ $ (-820 |#1|)) 55) (($ $ $) 54)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-2580 (((-121) $) 46)) (-3211 ((|#2| $) 45)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#2|) 67) (($ (-820 |#1|)) 64) (($ |#1|) 47)) (-4513 ((|#2| $ (-820 |#1|)) 58) ((|#2| $ $) 57)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ |#2| $) 66) (($ $ |#2|) 65) (($ |#1| $) 61))) 
-(((-1274 |#1| |#2|) (-1290) (-848) (-1054)) (T -1274)) 
-((* (*1 *1 *1 *2) (-12 (-4 *1 (-1274 *3 *2)) (-4 *3 (-848)) (-4 *2 (-1054)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) (-3383 (*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-820 *3)))) (-1435 (*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-2 (|:| |k| (-820 *3)) (|:| |c| *4))))) (-4513 (*1 *2 *1 *3) (-12 (-5 *3 (-820 *4)) (-4 *1 (-1274 *4 *2)) (-4 *4 (-848)) (-4 *2 (-1054)))) (-4513 (*1 *2 *1 *1) (-12 (-4 *1 (-1274 *3 *2)) (-4 *3 (-848)) (-4 *2 (-1054)))) (-3561 (*1 *1 *1 *2) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) (-3561 (*1 *1 *1 *2) (-12 (-5 *2 (-820 *3)) (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)))) (-3561 (*1 *1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) (-3754 (*1 *1 *1 *2) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) (-3754 (*1 *1 *1 *2) (-12 (-5 *2 (-820 *3)) (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)))) (-3754 (*1 *1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) (-4518 (*1 *1 *2 *3) (-12 (-5 *2 (-820 *4)) (-4 *4 (-848)) (-4 *1 (-1274 *4 *3)) (-4 *3 (-1054)))) (-4581 (*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-121)))) (-4076 (*1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) (-3972 (*1 *1 *2) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) (-2580 (*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-121)))) (-3211 (*1 *2 *1) (-12 (-4 *1 (-1274 *3 *2)) (-4 *3 (-848)) (-4 *2 (-1054)))) (-1842 (*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-121)))) (-2597 (*1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) (-2850 (*1 *1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)) (-4 *3 (-174)))) (-2850 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-4 *4 (-174)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)))) (-2199 (*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-638 *3))))) 
-(-13 (-1054) (-1271 |t#2|) (-1044 (-820 |t#1|)) (-10 -8 (-15 * ($ |t#1| $)) (-15 * ($ $ |t#2|)) (-15 -3383 ((-820 |t#1|) $)) (-15 -1435 ((-2 (|:| |k| (-820 |t#1|)) (|:| |c| |t#2|)) $)) (-15 -4513 (|t#2| $ (-820 |t#1|))) (-15 -4513 (|t#2| $ $)) (-15 -3561 ($ $ |t#1|)) (-15 -3561 ($ $ (-820 |t#1|))) (-15 -3561 ($ $ $)) (-15 -3754 ($ $ |t#1|)) (-15 -3754 ($ $ (-820 |t#1|))) (-15 -3754 ($ $ $)) (-15 -4518 ($ (-820 |t#1|) |t#2|)) (-15 -4581 ((-121) $)) (-15 -4076 ($ $)) (-15 -3972 ($ |t#1|)) (-15 -2580 ((-121) $)) (-15 -3211 (|t#2| $)) (-15 -1842 ((-121) $)) (-15 -2597 ($ $)) (IF (|has| |t#2| (-174)) (PROGN (-15 -2850 ($ $ $)) (-15 -2850 ($ $ (-769)))) |noBranch|) (-15 -3828 ($ (-1 |t#2| |t#2|) $)) (-15 -2199 ((-638 |t#1|) $)) (IF (|has| |t#2| (-6 -4595)) (-6 -4595) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#2|) |has| |#2| (-174)) ((-105) . T) ((-120 |#2| |#2|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#2|) . T) ((-641 $) . T) ((-713 |#2|) |has| |#2| (-174)) ((-722) . T) ((-1044 (-820 |#1|)) . T) ((-1060 |#2|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1271 |#2|) . T)) 
-((-2376 (((-121) $) 13)) (-2213 (((-121) $) 12)) (-2611 (($ $) 17) (($ $ (-769)) 18))) 
-(((-1275 |#1| |#2|) (-10 -8 (-15 -2611 (|#1| |#1| (-769))) (-15 -2611 (|#1| |#1|)) (-15 -2376 ((-121) |#1|)) (-15 -2213 ((-121) |#1|))) (-1276 |#2|) (-368)) (T -1275)) 
-NIL 
-(-10 -8 (-15 -2611 (|#1| |#1| (-769))) (-15 -2611 (|#1| |#1|)) (-15 -2376 ((-121) |#1|)) (-15 -2213 ((-121) |#1|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-4109 (((-2 (|:| -3029 $) (|:| -4589 $) (|:| |associate| $)) $) 40)) (-3946 (($ $) 39)) (-3686 (((-121) $) 37)) (-2376 (((-121) $) 90)) (-1486 (((-769)) 86)) (-1572 (((-3 $ "failed") $ $) 18)) (-2844 (($ $) 71)) (-1466 (((-424 $) $) 70)) (-3112 (((-121) $ $) 57)) (-2211 (($) 16 T CONST)) (-3376 (((-3 |#1| "failed") $) 97)) (-1318 ((|#1| $) 96)) (-2190 (($ $ $) 53)) (-1799 (((-3 $ "failed") $) 33)) (-2208 (($ $ $) 54)) (-3326 (((-2 (|:| -4513 (-638 $)) (|:| -2307 $)) (-638 $)) 49)) (-4486 (($ $ (-769)) 83 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374)))) (($ $) 82 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-1526 (((-121) $) 69)) (-3377 (((-834 (-923)) $) 80 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-3893 (((-121) $) 30)) (-3570 (((-3 (-638 $) "failed") (-638 $) $) 50)) (-1629 (($ $ $) 45) (($ (-638 $)) 44)) (-1658 (((-1152) $) 9)) (-4350 (($ $) 68)) (-1336 (((-121) $) 89)) (-2607 (((-1116) $) 10)) (-3905 (((-1166 $) (-1166 $) (-1166 $)) 43)) (-3069 (($ $ $) 47) (($ (-638 $)) 46)) (-4304 (((-424 $) $) 72)) (-2728 (((-834 (-923))) 87)) (-3087 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2307 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1803 (((-3 $ "failed") $ $) 41)) (-4354 (((-3 (-638 $) "failed") (-638 $) $) 48)) (-4029 (((-769) $) 56)) (-2541 (((-2 (|:| -3043 $) (|:| -2492 $)) $ $) 55)) (-3158 (((-3 (-769) "failed") $ $) 81 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2502 (((-140)) 95)) (-4316 (((-834 (-923)) $) 88)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ $) 42) (($ (-413 (-572))) 63) (($ |#1|) 98)) (-2779 (((-3 $ "failed") $) 79 (-1841 (|has| |#1| (-149)) (|has| |#1| (-374))))) (-2140 (((-769)) 28)) (-3774 (((-121) $ $) 38)) (-2213 (((-121) $) 91)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32) (($ $ (-572)) 67)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-2611 (($ $) 85 (|has| |#1| (-374))) (($ $ (-769)) 84 (|has| |#1| (-374)))) (-1324 (((-121) $ $) 6)) (-1379 (($ $ $) 62) (($ $ |#1|) 94)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31) (($ $ (-572)) 66)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ $ (-413 (-572))) 65) (($ (-413 (-572)) $) 64) (($ $ |#1|) 93) (($ |#1| $) 92))) 
-(((-1276 |#1|) (-1290) (-368)) (T -1276)) 
-((-2213 (*1 *2 *1) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-121)))) (-2376 (*1 *2 *1) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-121)))) (-1336 (*1 *2 *1) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-121)))) (-4316 (*1 *2 *1) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-834 (-923))))) (-2728 (*1 *2) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-834 (-923))))) (-1486 (*1 *2) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-769)))) (-2611 (*1 *1 *1) (-12 (-4 *1 (-1276 *2)) (-4 *2 (-368)) (-4 *2 (-374)))) (-2611 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-4 *3 (-374))))) 
-(-13 (-368) (-1044 |t#1|) (-1266 |t#1|) (-10 -8 (IF (|has| |t#1| (-151)) (-6 (-151)) |noBranch|) (IF (|has| |t#1| (-149)) (-6 (-408)) |noBranch|) (-15 -2213 ((-121) $)) (-15 -2376 ((-121) $)) (-15 -1336 ((-121) $)) (-15 -4316 ((-834 (-923)) $)) (-15 -2728 ((-834 (-923)))) (-15 -1486 ((-769))) (IF (|has| |t#1| (-374)) (PROGN (-6 (-408)) (-15 -2611 ($ $)) (-15 -2611 ($ $ (-769)))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-413 (-572))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-413 (-572)) (-413 (-572))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-138) . T) ((-149) -1841 (|has| |#1| (-374)) (|has| |#1| (-149))) ((-151) |has| |#1| (-151)) ((-612 (-856)) . T) ((-174) . T) ((-240) . T) ((-287) . T) ((-303) . T) ((-368) . T) ((-408) -1841 (|has| |#1| (-374)) (|has| |#1| (-149))) ((-457) . T) ((-562) . T) ((-641 (-413 (-572))) . T) ((-641 |#1|) . T) ((-641 $) . T) ((-713 (-413 (-572))) . T) ((-713 |#1|) . T) ((-713 $) . T) ((-722) . T) ((-922) . T) ((-1044 |#1|) . T) ((-1060 (-413 (-572))) . T) ((-1060 |#1|) . T) ((-1060 $) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1214) . T) ((-1266 |#1|) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2199 (((-638 |#1|) $) 84)) (-2007 (($ $ (-769)) 87)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2850 (($ $ $) NIL (|has| |#2| (-174))) (($ $ (-769)) NIL (|has| |#2| (-174)))) (-2211 (($) NIL T CONST)) (-3754 (($ $ |#1|) NIL) (($ $ (-820 |#1|)) NIL) (($ $ $) NIL)) (-3376 (((-3 (-820 |#1|) "failed") $) NIL) (((-3 (-894 |#1|) "failed") $) NIL)) (-1318 (((-820 |#1|) $) NIL) (((-894 |#1|) $) NIL)) (-4383 (($ $) 86)) (-1799 (((-3 $ "failed") $) NIL)) (-1842 (((-121) $) 75)) (-2597 (($ $) 79)) (-1642 (($ $ $ (-769)) 88)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4518 (($ (-820 |#1|) |#2|) NIL) (($ (-894 |#1|) |#2|) 25)) (-4076 (($ $) 101)) (-1435 (((-2 (|:| |k| (-820 |#1|)) (|:| |c| |#2|)) $) NIL)) (-3383 (((-820 |#1|) $) NIL)) (-2460 (((-820 |#1|) $) NIL)) (-3828 (($ (-1 |#2| |#2|) $) NIL)) (-3561 (($ $ |#1|) NIL) (($ $ (-820 |#1|)) NIL) (($ $ $) NIL)) (-3539 (($ $ (-769)) 95 (|has| |#2| (-713 (-413 (-572)))))) (-2081 (((-638 (-2 (|:| |k| (-894 |#1|)) (|:| |c| |#2|))) $) NIL)) (-4136 (((-2 (|:| |k| (-894 |#1|)) (|:| |c| |#2|)) $) NIL)) (-4368 (((-894 |#1|) $) 69)) (-4373 ((|#2| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-4179 (($ $ (-769)) 92 (|has| |#2| (-713 (-413 (-572)))))) (-4316 (((-769) $) 85)) (-2580 (((-121) $) 70)) (-3211 ((|#2| $) 74)) (-3972 (((-856) $) 56) (($ (-572)) NIL) (($ |#2|) 50) (($ (-820 |#1|)) NIL) (($ |#1|) 58) (($ (-894 |#1|)) NIL) (($ (-660 |#1| |#2|)) 42) (((-1272 |#1| |#2|) $) 63) (((-1281 |#1| |#2|) $) 68)) (-3193 (((-638 |#2|) $) NIL)) (-1958 ((|#2| $ (-894 |#1|)) NIL)) (-4513 ((|#2| $ (-820 |#1|)) NIL) ((|#2| $ $) NIL)) (-2140 (((-769)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 21 T CONST)) (-3255 (($) 24 T CONST)) (-2019 (((-3 (-660 |#1| |#2|) "failed") $) 100)) (-1324 (((-121) $ $) 64)) (-1373 (($ $) 94) (($ $ $) 93)) (-1367 (($ $ $) 20)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 43) (($ |#2| $) 19) (($ $ |#2|) NIL) (($ |#1| $) NIL) (($ |#2| (-894 |#1|)) NIL))) 
-(((-1277 |#1| |#2|) (-13 (-1278 |#1| |#2|) (-388 |#2| (-894 |#1|)) (-10 -8 (-15 -3972 ($ (-660 |#1| |#2|))) (-15 -3972 ((-1272 |#1| |#2|) $)) (-15 -3972 ((-1281 |#1| |#2|) $)) (-15 -2019 ((-3 (-660 |#1| |#2|) "failed") $)) (-15 -1642 ($ $ $ (-769))) (IF (|has| |#2| (-713 (-413 (-572)))) (PROGN (-15 -4179 ($ $ (-769))) (-15 -3539 ($ $ (-769)))) |noBranch|))) (-848) (-174)) (T -1277)) 
-((-3972 (*1 *1 *2) (-12 (-5 *2 (-660 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *1 (-1277 *3 *4)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1272 *3 *4)) (-5 *1 (-1277 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) (-3972 (*1 *2 *1) (-12 (-5 *2 (-1281 *3 *4)) (-5 *1 (-1277 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) (-2019 (*1 *2 *1) (|partial| -12 (-5 *2 (-660 *3 *4)) (-5 *1 (-1277 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) (-1642 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1277 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) (-4179 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1277 *3 *4)) (-4 *4 (-713 (-413 (-572)))) (-4 *3 (-848)) (-4 *4 (-174)))) (-3539 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1277 *3 *4)) (-4 *4 (-713 (-413 (-572)))) (-4 *3 (-848)) (-4 *4 (-174))))) 
-(-13 (-1278 |#1| |#2|) (-388 |#2| (-894 |#1|)) (-10 -8 (-15 -3972 ($ (-660 |#1| |#2|))) (-15 -3972 ((-1272 |#1| |#2|) $)) (-15 -3972 ((-1281 |#1| |#2|) $)) (-15 -2019 ((-3 (-660 |#1| |#2|) "failed") $)) (-15 -1642 ($ $ $ (-769))) (IF (|has| |#2| (-713 (-413 (-572)))) (PROGN (-15 -4179 ($ $ (-769))) (-15 -3539 ($ $ (-769)))) |noBranch|))) 
-((-2262 (((-121) $ $) 7)) (-1342 (((-121) $) 15)) (-2199 (((-638 |#1|) $) 39)) (-2007 (($ $ (-769)) 68)) (-1572 (((-3 $ "failed") $ $) 18)) (-2850 (($ $ $) 42 (|has| |#2| (-174))) (($ $ (-769)) 41 (|has| |#2| (-174)))) (-2211 (($) 16 T CONST)) (-3754 (($ $ |#1|) 53) (($ $ (-820 |#1|)) 52) (($ $ $) 51)) (-3376 (((-3 (-820 |#1|) "failed") $) 63)) (-1318 (((-820 |#1|) $) 62)) (-1799 (((-3 $ "failed") $) 33)) (-1842 (((-121) $) 44)) (-2597 (($ $) 43)) (-3893 (((-121) $) 30)) (-4581 (((-121) $) 49)) (-4518 (($ (-820 |#1|) |#2|) 50)) (-4076 (($ $) 48)) (-1435 (((-2 (|:| |k| (-820 |#1|)) (|:| |c| |#2|)) $) 59)) (-3383 (((-820 |#1|) $) 60)) (-2460 (((-820 |#1|) $) 70)) (-3828 (($ (-1 |#2| |#2|) $) 40)) (-3561 (($ $ |#1|) 56) (($ $ (-820 |#1|)) 55) (($ $ $) 54)) (-1658 (((-1152) $) 9)) (-2607 (((-1116) $) 10)) (-4316 (((-769) $) 69)) (-2580 (((-121) $) 46)) (-3211 ((|#2| $) 45)) (-3972 (((-856) $) 11) (($ (-572)) 27) (($ |#2|) 67) (($ (-820 |#1|)) 64) (($ |#1|) 47)) (-4513 ((|#2| $ (-820 |#1|)) 58) ((|#2| $ $) 57)) (-2140 (((-769)) 28)) (-4174 (($ $ (-923)) 25) (($ $ (-769)) 32)) (-2378 (($) 17 T CONST)) (-3255 (($) 29 T CONST)) (-1324 (((-121) $ $) 6)) (-1373 (($ $) 21) (($ $ $) 20)) (-1367 (($ $ $) 13)) (** (($ $ (-923)) 24) (($ $ (-769)) 31)) (* (($ (-923) $) 12) (($ (-769) $) 14) (($ (-572) $) 19) (($ $ $) 23) (($ |#2| $) 66) (($ $ |#2|) 65) (($ |#1| $) 61))) 
-(((-1278 |#1| |#2|) (-1290) (-848) (-1054)) (T -1278)) 
-((-2460 (*1 *2 *1) (-12 (-4 *1 (-1278 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-820 *3)))) (-4316 (*1 *2 *1) (-12 (-4 *1 (-1278 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-769)))) (-2007 (*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1278 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054))))) 
-(-13 (-1274 |t#1| |t#2|) (-10 -8 (-15 -2460 ((-820 |t#1|) $)) (-15 -4316 ((-769) $)) (-15 -2007 ($ $ (-769))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#2|) |has| |#2| (-174)) ((-105) . T) ((-120 |#2| |#2|) . T) ((-138) . T) ((-612 (-856)) . T) ((-641 |#2|) . T) ((-641 $) . T) ((-713 |#2|) |has| |#2| (-174)) ((-722) . T) ((-1044 (-820 |#1|)) . T) ((-1060 |#2|) . T) ((-1054) . T) ((-1061) . T) ((-1110) . T) ((-1098) . T) ((-1271 |#2|) . T) ((-1274 |#1| |#2|) . T)) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2199 (((-638 (-1170)) $) NIL)) (-3086 (($ (-1272 (-1170) |#1|)) NIL)) (-2007 (($ $ (-769)) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2850 (($ $ $) NIL (|has| |#1| (-174))) (($ $ (-769)) NIL (|has| |#1| (-174)))) (-2211 (($) NIL T CONST)) (-3754 (($ $ (-1170)) NIL) (($ $ (-820 (-1170))) NIL) (($ $ $) NIL)) (-3376 (((-3 (-820 (-1170)) "failed") $) NIL)) (-1318 (((-820 (-1170)) $) NIL)) (-1799 (((-3 $ "failed") $) NIL)) (-1842 (((-121) $) NIL)) (-2597 (($ $) NIL)) (-3893 (((-121) $) NIL)) (-4581 (((-121) $) NIL)) (-4518 (($ (-820 (-1170)) |#1|) NIL)) (-4076 (($ $) NIL)) (-1435 (((-2 (|:| |k| (-820 (-1170))) (|:| |c| |#1|)) $) NIL)) (-3383 (((-820 (-1170)) $) NIL)) (-2460 (((-820 (-1170)) $) NIL)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-3561 (($ $ (-1170)) NIL) (($ $ (-820 (-1170))) NIL) (($ $ $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2534 (((-1272 (-1170) |#1|) $) NIL)) (-4316 (((-769) $) NIL)) (-2580 (((-121) $) NIL)) (-3211 ((|#1| $) NIL)) (-3972 (((-856) $) NIL) (($ (-572)) NIL) (($ |#1|) NIL) (($ (-820 (-1170))) NIL) (($ (-1170)) NIL)) (-4513 ((|#1| $ (-820 (-1170))) NIL) ((|#1| $ $) NIL)) (-2140 (((-769)) NIL)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) NIL T CONST)) (-3816 (((-638 (-2 (|:| |k| (-1170)) (|:| |c| $))) $) NIL)) (-3255 (($) NIL T CONST)) (-1324 (((-121) $ $) NIL)) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) NIL)) (** (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-1170) $) NIL))) 
-(((-1279 |#1|) (-13 (-1278 (-1170) |#1|) (-10 -8 (-15 -2534 ((-1272 (-1170) |#1|) $)) (-15 -3086 ($ (-1272 (-1170) |#1|))) (-15 -3816 ((-638 (-2 (|:| |k| (-1170)) (|:| |c| $))) $)))) (-1054)) (T -1279)) 
-((-2534 (*1 *2 *1) (-12 (-5 *2 (-1272 (-1170) *3)) (-5 *1 (-1279 *3)) (-4 *3 (-1054)))) (-3086 (*1 *1 *2) (-12 (-5 *2 (-1272 (-1170) *3)) (-4 *3 (-1054)) (-5 *1 (-1279 *3)))) (-3816 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |k| (-1170)) (|:| |c| (-1279 *3))))) (-5 *1 (-1279 *3)) (-4 *3 (-1054))))) 
-(-13 (-1278 (-1170) |#1|) (-10 -8 (-15 -2534 ((-1272 (-1170) |#1|) $)) (-15 -3086 ($ (-1272 (-1170) |#1|))) (-15 -3816 ((-638 (-2 (|:| |k| (-1170)) (|:| |c| $))) $)))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2211 (($) NIL T CONST)) (-3376 (((-3 |#2| "failed") $) NIL)) (-1318 ((|#2| $) NIL)) (-4383 (($ $) NIL)) (-1799 (((-3 $ "failed") $) 34)) (-1842 (((-121) $) 29)) (-2597 (($ $) 30)) (-3893 (((-121) $) NIL)) (-3475 (((-769) $) NIL)) (-3658 (((-638 $) $) NIL)) (-4581 (((-121) $) NIL)) (-4518 (($ |#2| |#1|) NIL)) (-3383 ((|#2| $) 19)) (-2460 ((|#2| $) 16)) (-3828 (($ (-1 |#1| |#1|) $) NIL)) (-2081 (((-638 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) NIL)) (-4136 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) NIL)) (-4368 ((|#2| $) NIL)) (-4373 ((|#1| $) NIL)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2580 (((-121) $) 27)) (-3211 ((|#1| $) 28)) (-3972 (((-856) $) 53) (($ (-572)) 38) (($ |#1|) 33) (($ |#2|) NIL)) (-3193 (((-638 |#1|) $) NIL)) (-1958 ((|#1| $ |#2|) NIL)) (-4513 ((|#1| $ |#2|) 24)) (-2140 (((-769)) 14)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 25 T CONST)) (-3255 (($) 11 T CONST)) (-1324 (((-121) $ $) 26)) (-1379 (($ $ |#1|) 55 (|has| |#1| (-368)))) (-1373 (($ $) NIL) (($ $ $) NIL)) (-1367 (($ $ $) 42)) (** (($ $ (-923)) NIL) (($ $ (-769)) 44)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) NIL) (($ $ $) 43) (($ |#1| $) 39) (($ $ |#1|) NIL) (($ |#1| |#2|) NIL)) (-4032 (((-769) $) 15))) 
-(((-1280 |#1| |#2|) (-13 (-1054) (-1271 |#1|) (-388 |#1| |#2|) (-10 -8 (-15 * ($ $ |#1|)) (-15 -4032 ((-769) $)) (-15 -3972 ($ |#2|)) (-15 -2460 (|#2| $)) (-15 -3383 (|#2| $)) (-15 -4383 ($ $)) (-15 -4513 (|#1| $ |#2|)) (-15 -2580 ((-121) $)) (-15 -3211 (|#1| $)) (-15 -1842 ((-121) $)) (-15 -2597 ($ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-368)) (-15 -1379 ($ $ |#1|)) |noBranch|) (IF (|has| |#1| (-6 -4595)) (-6 -4595) |noBranch|) (IF (|has| |#1| (-6 -4599)) (-6 -4599) |noBranch|) (IF (|has| |#1| (-6 -4600)) (-6 -4600) |noBranch|))) (-1054) (-844)) (T -1280)) 
-((* (*1 *1 *1 *2) (-12 (-5 *1 (-1280 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-844)))) (-4383 (*1 *1 *1) (-12 (-5 *1 (-1280 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-844)))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-1280 *3 *4)) (-4 *4 (-844)))) (-3972 (*1 *1 *2) (-12 (-5 *1 (-1280 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-844)))) (-4032 (*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1280 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-844)))) (-2460 (*1 *2 *1) (-12 (-4 *2 (-844)) (-5 *1 (-1280 *3 *2)) (-4 *3 (-1054)))) (-3383 (*1 *2 *1) (-12 (-4 *2 (-844)) (-5 *1 (-1280 *3 *2)) (-4 *3 (-1054)))) (-4513 (*1 *2 *1 *3) (-12 (-4 *2 (-1054)) (-5 *1 (-1280 *2 *3)) (-4 *3 (-844)))) (-2580 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1280 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-844)))) (-3211 (*1 *2 *1) (-12 (-4 *2 (-1054)) (-5 *1 (-1280 *2 *3)) (-4 *3 (-844)))) (-1842 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1280 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-844)))) (-2597 (*1 *1 *1) (-12 (-5 *1 (-1280 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-844)))) (-1379 (*1 *1 *1 *2) (-12 (-5 *1 (-1280 *2 *3)) (-4 *2 (-368)) (-4 *2 (-1054)) (-4 *3 (-844))))) 
-(-13 (-1054) (-1271 |#1|) (-388 |#1| |#2|) (-10 -8 (-15 * ($ $ |#1|)) (-15 -4032 ((-769) $)) (-15 -3972 ($ |#2|)) (-15 -2460 (|#2| $)) (-15 -3383 (|#2| $)) (-15 -4383 ($ $)) (-15 -4513 (|#1| $ |#2|)) (-15 -2580 ((-121) $)) (-15 -3211 (|#1| $)) (-15 -1842 ((-121) $)) (-15 -2597 ($ $)) (-15 -3828 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-368)) (-15 -1379 ($ $ |#1|)) |noBranch|) (IF (|has| |#1| (-6 -4595)) (-6 -4595) |noBranch|) (IF (|has| |#1| (-6 -4599)) (-6 -4599) |noBranch|) (IF (|has| |#1| (-6 -4600)) (-6 -4600) |noBranch|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) NIL)) (-2199 (((-638 |#1|) $) 119)) (-3086 (($ (-1272 |#1| |#2|)) 43)) (-2007 (($ $ (-769)) 31)) (-1572 (((-3 $ "failed") $ $) NIL)) (-2850 (($ $ $) 47 (|has| |#2| (-174))) (($ $ (-769)) 45 (|has| |#2| (-174)))) (-2211 (($) NIL T CONST)) (-3754 (($ $ |#1|) 101) (($ $ (-820 |#1|)) 102) (($ $ $) 25)) (-3376 (((-3 (-820 |#1|) "failed") $) NIL)) (-1318 (((-820 |#1|) $) NIL)) (-1799 (((-3 $ "failed") $) 109)) (-1842 (((-121) $) 104)) (-2597 (($ $) 105)) (-3893 (((-121) $) NIL)) (-4581 (((-121) $) NIL)) (-4518 (($ (-820 |#1|) |#2|) 19)) (-4076 (($ $) NIL)) (-1435 (((-2 (|:| |k| (-820 |#1|)) (|:| |c| |#2|)) $) NIL)) (-3383 (((-820 |#1|) $) 110)) (-2460 (((-820 |#1|) $) 113)) (-3828 (($ (-1 |#2| |#2|) $) 118)) (-3561 (($ $ |#1|) 99) (($ $ (-820 |#1|)) 100) (($ $ $) 55)) (-1658 (((-1152) $) NIL)) (-2607 (((-1116) $) NIL)) (-2534 (((-1272 |#1| |#2|) $) 83)) (-4316 (((-769) $) 116)) (-2580 (((-121) $) 69)) (-3211 ((|#2| $) 27)) (-3972 (((-856) $) 62) (($ (-572)) 76) (($ |#2|) 73) (($ (-820 |#1|)) 17) (($ |#1|) 72)) (-4513 ((|#2| $ (-820 |#1|)) 103) ((|#2| $ $) 26)) (-2140 (((-769)) 107)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 14 T CONST)) (-3816 (((-638 (-2 (|:| |k| |#1|) (|:| |c| $))) $) 52)) (-3255 (($) 28 T CONST)) (-1324 (((-121) $ $) 13)) (-1373 (($ $) 87) (($ $ $) 90)) (-1367 (($ $ $) 54)) (** (($ $ (-923)) NIL) (($ $ (-769)) 48)) (* (($ (-923) $) NIL) (($ (-769) $) 46) (($ (-572) $) 93) (($ $ $) 21) (($ |#2| $) 18) (($ $ |#2|) 20) (($ |#1| $) 81))) 
-(((-1281 |#1| |#2|) (-13 (-1278 |#1| |#2|) (-10 -8 (-15 -2534 ((-1272 |#1| |#2|) $)) (-15 -3086 ($ (-1272 |#1| |#2|))) (-15 -3816 ((-638 (-2 (|:| |k| |#1|) (|:| |c| $))) $)))) (-848) (-1054)) (T -1281)) 
-((-2534 (*1 *2 *1) (-12 (-5 *2 (-1272 *3 *4)) (-5 *1 (-1281 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)))) (-3086 (*1 *1 *2) (-12 (-5 *2 (-1272 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *1 (-1281 *3 *4)))) (-3816 (*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |k| *3) (|:| |c| (-1281 *3 *4))))) (-5 *1 (-1281 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054))))) 
-(-13 (-1278 |#1| |#2|) (-10 -8 (-15 -2534 ((-1272 |#1| |#2|) $)) (-15 -3086 ($ (-1272 |#1| |#2|))) (-15 -3816 ((-638 (-2 (|:| |k| |#1|) (|:| |c| $))) $)))) 
-((-2301 (((-638 (-1150 |#1|)) (-1 (-638 (-1150 |#1|)) (-638 (-1150 |#1|))) (-572)) 15) (((-1150 |#1|) (-1 (-1150 |#1|) (-1150 |#1|))) 11))) 
-(((-1282 |#1|) (-10 -7 (-15 -2301 ((-1150 |#1|) (-1 (-1150 |#1|) (-1150 |#1|)))) (-15 -2301 ((-638 (-1150 |#1|)) (-1 (-638 (-1150 |#1|)) (-638 (-1150 |#1|))) (-572)))) (-1204)) (T -1282)) 
-((-2301 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-638 (-1150 *5)) (-638 (-1150 *5)))) (-5 *4 (-572)) (-5 *2 (-638 (-1150 *5))) (-5 *1 (-1282 *5)) (-4 *5 (-1204)))) (-2301 (*1 *2 *3) (-12 (-5 *3 (-1 (-1150 *4) (-1150 *4))) (-5 *2 (-1150 *4)) (-5 *1 (-1282 *4)) (-4 *4 (-1204))))) 
-(-10 -7 (-15 -2301 ((-1150 |#1|) (-1 (-1150 |#1|) (-1150 |#1|)))) (-15 -2301 ((-638 (-1150 |#1|)) (-1 (-638 (-1150 |#1|)) (-638 (-1150 |#1|))) (-572)))) 
-((-1820 (((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|))) 145) (((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121)) 144) (((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121)) 143) (((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121) (-121)) 142) (((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-1051 |#1| |#2|)) 127)) (-2394 (((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|))) 70) (((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|)) (-121)) 69) (((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|)) (-121) (-121)) 68)) (-1466 (((-638 (-1139 |#1| (-538 (-858 |#3|)) (-858 |#3|) (-781 |#1| (-858 |#3|)))) (-1051 |#1| |#2|)) 59)) (-2641 (((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|))) 112) (((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121)) 111) (((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121)) 110) (((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121) (-121)) 109) (((-638 (-638 (-1030 (-413 |#1|)))) (-1051 |#1| |#2|)) 104)) (-1640 (((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|))) 117) (((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121)) 116) (((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121)) 115) (((-638 (-638 (-1030 (-413 |#1|)))) (-1051 |#1| |#2|)) 114)) (-4081 (((-638 (-781 |#1| (-858 |#3|))) (-1139 |#1| (-538 (-858 |#3|)) (-858 |#3|) (-781 |#1| (-858 |#3|)))) 96) (((-1166 (-1030 (-413 |#1|))) (-1166 |#1|)) 87) (((-959 (-1030 (-413 |#1|))) (-781 |#1| (-858 |#3|))) 94) (((-959 (-1030 (-413 |#1|))) (-959 |#1|)) 92) (((-781 |#1| (-858 |#3|)) (-781 |#1| (-858 |#2|))) 32))) 
-(((-1283 |#1| |#2| |#3|) (-10 -7 (-15 -2394 ((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|)) (-121) (-121))) (-15 -2394 ((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|)) (-121))) (-15 -2394 ((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|)))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-1051 |#1| |#2|))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121) (-121))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-1051 |#1| |#2|))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121) (-121))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)))) (-15 -1640 ((-638 (-638 (-1030 (-413 |#1|)))) (-1051 |#1| |#2|))) (-15 -1640 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121))) (-15 -1640 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121))) (-15 -1640 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)))) (-15 -1466 ((-638 (-1139 |#1| (-538 (-858 |#3|)) (-858 |#3|) (-781 |#1| (-858 |#3|)))) (-1051 |#1| |#2|))) (-15 -4081 ((-781 |#1| (-858 |#3|)) (-781 |#1| (-858 |#2|)))) (-15 -4081 ((-959 (-1030 (-413 |#1|))) (-959 |#1|))) (-15 -4081 ((-959 (-1030 (-413 |#1|))) (-781 |#1| (-858 |#3|)))) (-15 -4081 ((-1166 (-1030 (-413 |#1|))) (-1166 |#1|))) (-15 -4081 ((-638 (-781 |#1| (-858 |#3|))) (-1139 |#1| (-538 (-858 |#3|)) (-858 |#3|) (-781 |#1| (-858 |#3|)))))) (-13 (-846) (-303) (-151) (-1028)) (-638 (-1170)) (-638 (-1170))) (T -1283)) 
-((-4081 (*1 *2 *3) (-12 (-5 *3 (-1139 *4 (-538 (-858 *6)) (-858 *6) (-781 *4 (-858 *6)))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-781 *4 (-858 *6)))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))))) (-4081 (*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-1166 (-1030 (-413 *4)))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170))))) (-4081 (*1 *2 *3) (-12 (-5 *3 (-781 *4 (-858 *6))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *6 (-638 (-1170))) (-5 *2 (-959 (-1030 (-413 *4)))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))))) (-4081 (*1 *2 *3) (-12 (-5 *3 (-959 *4)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-959 (-1030 (-413 *4)))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170))))) (-4081 (*1 *2 *3) (-12 (-5 *3 (-781 *4 (-858 *5))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-781 *4 (-858 *6))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) (-1466 (*1 *2 *3) (-12 (-5 *3 (-1051 *4 *5)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-638 (-1139 *4 (-538 (-858 *6)) (-858 *6) (-781 *4 (-858 *6))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) (-1640 (*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *4))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170))))) (-1640 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-1640 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-1640 (*1 *2 *3) (-12 (-5 *3 (-1051 *4 *5)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-638 (-638 (-1030 (-413 *4))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) (-2641 (*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *4))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170))))) (-2641 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-2641 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-2641 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-2641 (*1 *2 *3) (-12 (-5 *3 (-1051 *4 *5)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-638 (-638 (-1030 (-413 *4))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) (-1820 (*1 *2 *3) (-12 (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *4)) (|:| -3160 (-638 (-959 *4)))))) (-5 *1 (-1283 *4 *5 *6)) (-5 *3 (-638 (-959 *4))) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170))))) (-1820 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1283 *5 *6 *7)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-1820 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1283 *5 *6 *7)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-1820 (*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1283 *5 *6 *7)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-1820 (*1 *2 *3) (-12 (-5 *3 (-1051 *4 *5)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *4)) (|:| -3160 (-638 (-959 *4)))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) (-2394 (*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-1051 *4 *5))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170))))) (-2394 (*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) (-2394 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170)))))) 
-(-10 -7 (-15 -2394 ((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|)) (-121) (-121))) (-15 -2394 ((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|)) (-121))) (-15 -2394 ((-638 (-1051 |#1| |#2|)) (-638 (-959 |#1|)))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-1051 |#1| |#2|))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121) (-121))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121) (-121))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)) (-121))) (-15 -1820 ((-638 (-2 (|:| -3950 (-1166 |#1|)) (|:| -3160 (-638 (-959 |#1|))))) (-638 (-959 |#1|)))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-1051 |#1| |#2|))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121) (-121))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121))) (-15 -2641 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)))) (-15 -1640 ((-638 (-638 (-1030 (-413 |#1|)))) (-1051 |#1| |#2|))) (-15 -1640 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121) (-121))) (-15 -1640 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)) (-121))) (-15 -1640 ((-638 (-638 (-1030 (-413 |#1|)))) (-638 (-959 |#1|)))) (-15 -1466 ((-638 (-1139 |#1| (-538 (-858 |#3|)) (-858 |#3|) (-781 |#1| (-858 |#3|)))) (-1051 |#1| |#2|))) (-15 -4081 ((-781 |#1| (-858 |#3|)) (-781 |#1| (-858 |#2|)))) (-15 -4081 ((-959 (-1030 (-413 |#1|))) (-959 |#1|))) (-15 -4081 ((-959 (-1030 (-413 |#1|))) (-781 |#1| (-858 |#3|)))) (-15 -4081 ((-1166 (-1030 (-413 |#1|))) (-1166 |#1|))) (-15 -4081 ((-638 (-781 |#1| (-858 |#3|))) (-1139 |#1| (-538 (-858 |#3|)) (-858 |#3|) (-781 |#1| (-858 |#3|)))))) 
-((-3336 (((-3 (-1259 (-413 (-572))) "failed") (-1259 |#1|) |#1|) 17)) (-3171 (((-121) (-1259 |#1|)) 11)) (-4255 (((-3 (-1259 (-572)) "failed") (-1259 |#1|)) 14))) 
-(((-1284 |#1|) (-10 -7 (-15 -3171 ((-121) (-1259 |#1|))) (-15 -4255 ((-3 (-1259 (-572)) "failed") (-1259 |#1|))) (-15 -3336 ((-3 (-1259 (-413 (-572))) "failed") (-1259 |#1|) |#1|))) (-634 (-572))) (T -1284)) 
-((-3336 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1259 *4)) (-4 *4 (-634 (-572))) (-5 *2 (-1259 (-413 (-572)))) (-5 *1 (-1284 *4)))) (-4255 (*1 *2 *3) (|partial| -12 (-5 *3 (-1259 *4)) (-4 *4 (-634 (-572))) (-5 *2 (-1259 (-572))) (-5 *1 (-1284 *4)))) (-3171 (*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-634 (-572))) (-5 *2 (-121)) (-5 *1 (-1284 *4))))) 
-(-10 -7 (-15 -3171 ((-121) (-1259 |#1|))) (-15 -4255 ((-3 (-1259 (-572)) "failed") (-1259 |#1|))) (-15 -3336 ((-3 (-1259 (-413 (-572))) "failed") (-1259 |#1|) |#1|))) 
-((-2262 (((-121) $ $) NIL)) (-1342 (((-121) $) 11)) (-1572 (((-3 $ "failed") $ $) NIL)) (-1685 (((-769)) 8)) (-2211 (($) NIL T CONST)) (-1799 (((-3 $ "failed") $) 43)) (-3286 (($) 36)) (-3893 (((-121) $) NIL)) (-3961 (((-3 $ "failed") $) 29)) (-3633 (((-923) $) 15)) (-1658 (((-1152) $) NIL)) (-1773 (($) 25 T CONST)) (-1763 (($ (-923)) 37)) (-2607 (((-1116) $) NIL)) (-3587 (((-638 $)) NIL)) (-4081 (((-572) $) 13)) (-3972 (((-856) $) 22) (($ (-572)) 19)) (-2140 (((-769)) 9)) (-4174 (($ $ (-923)) NIL) (($ $ (-769)) NIL)) (-2378 (($) 23 T CONST)) (-3255 (($) 24 T CONST)) (-1324 (((-121) $ $) 27)) (-1373 (($ $) 38) (($ $ $) 35)) (-1367 (($ $ $) 26)) (** (($ $ (-923)) NIL) (($ $ (-769)) 40)) (* (($ (-923) $) NIL) (($ (-769) $) NIL) (($ (-572) $) 32) (($ $ $) 31))) 
-(((-1285 |#1|) (-13 (-174) (-374) (-613 (-572)) (-1144)) (-923)) (T -1285)) 
-NIL 
-(-13 (-174) (-374) (-613 (-572)) (-1144)) 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-NIL 
-((-1290 3635135 3635140 3635145 "NIL" NIL T NIL (NIL) NIL NIL NIL) (-3 3635120 3635125 3635130 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-2 3635105 3635110 3635115 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-1 3635090 3635095 3635100 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (0 3635075 3635080 3635085 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-1285 3634180 3634950 3635027 "ZMOD" 3635032 NIL ZMOD (NIL NIL) -8 NIL NIL) (-1284 3633290 3633454 3633663 "ZLINDEP" 3634012 NIL ZLINDEP (NIL T) -7 NIL NIL) (-1283 3622594 3624358 3626330 "ZDSOLVE" 3631420 NIL ZDSOLVE (NIL T NIL NIL) -7 NIL NIL) (-1282 3621840 3621981 3622170 "YSTREAM" 3622440 NIL YSTREAM (NIL T) -7 NIL NIL) (-1281 3619605 3621141 3621345 "XRPOLY" 3621683 NIL XRPOLY (NIL T T) -8 NIL NIL) (-1280 3616059 3617388 3617968 "XPR" 3619072 NIL XPR (NIL T T) -8 NIL NIL) (-1279 3613769 3615390 3615594 "XPOLY" 3615890 NIL XPOLY (NIL T) -8 NIL NIL) (-1278 3611573 3612951 3613007 "XPOLYC" 3613295 NIL XPOLYC (NIL T T) -9 NIL 3613408) (-1277 3607947 3610092 3610479 "XPBWPOLY" 3611232 NIL XPBWPOLY (NIL T T) -8 NIL NIL) (-1276 3603825 3606135 3606178 "XF" 3606799 NIL XF (NIL T) -9 NIL 3607196) (-1275 3603446 3603534 3603703 "XF-" 3603708 NIL XF- (NIL T T) -8 NIL NIL) (-1274 3598795 3600094 3600150 "XFALG" 3602322 NIL XFALG (NIL T T) -9 NIL 3603109) (-1273 3597928 3598032 3598237 "XEXPPKG" 3598687 NIL XEXPPKG (NIL T T T) -7 NIL NIL) (-1272 3596025 3597778 3597874 "XDPOLY" 3597879 NIL XDPOLY (NIL T T) -8 NIL NIL) (-1271 3594897 3595507 3595551 "XALG" 3595614 NIL XALG (NIL T) -9 NIL 3595733) (-1270 3588366 3592874 3593368 "WUTSET" 3594489 NIL WUTSET (NIL T T T T) -8 NIL NIL) (-1269 3586175 3586982 3587333 "WP" 3588149 NIL WP (NIL T T T T NIL NIL NIL) -8 NIL NIL) (-1268 3585061 3585259 3585554 "WFFINTBS" 3585972 NIL WFFINTBS (NIL T T T T) -7 NIL NIL) (-1267 3582965 3583392 3583854 "WEIER" 3584633 NIL WEIER (NIL T) -7 NIL NIL) (-1266 3582111 3582535 3582578 "VSPACE" 3582714 NIL VSPACE (NIL T) -9 NIL 3582788) (-1265 3581949 3581976 3582067 "VSPACE-" 3582072 NIL VSPACE- (NIL T T) -8 NIL NIL) (-1264 3581695 3581738 3581809 "VOID" 3581900 T VOID (NIL) -8 NIL NIL) (-1263 3579831 3580190 3580596 "VIEW" 3581311 T VIEW (NIL) -7 NIL NIL) (-1262 3576256 3576894 3577631 "VIEWDEF" 3579116 T VIEWDEF (NIL) -7 NIL NIL) (-1261 3565595 3567804 3569977 "VIEW3D" 3574105 T VIEW3D (NIL) -8 NIL NIL) (-1260 3557877 3559506 3561085 "VIEW2D" 3564038 T VIEW2D (NIL) -8 NIL NIL) (-1259 3553285 3557647 3557739 "VECTOR" 3557820 NIL VECTOR (NIL T) -8 NIL NIL) (-1258 3551862 3552121 3552439 "VECTOR2" 3553015 NIL VECTOR2 (NIL T T) -7 NIL NIL) (-1257 3545427 3549673 3549717 "VECTCAT" 3550712 NIL VECTCAT (NIL T) -9 NIL 3551292) (-1256 3544441 3544695 3545085 "VECTCAT-" 3545090 NIL VECTCAT- (NIL T T) -8 NIL NIL) (-1255 3543922 3544092 3544212 "VARIABLE" 3544356 NIL VARIABLE (NIL NIL) -8 NIL NIL) (-1254 3535964 3541755 3542233 "UTSZ" 3543492 NIL UTSZ (NIL T NIL) -8 NIL NIL) (-1253 3535570 3535620 3535754 "UTSSOL" 3535908 NIL UTSSOL (NIL T T T) -7 NIL NIL) (-1252 3534402 3534556 3534817 "UTSODETL" 3535397 NIL UTSODETL (NIL T T T T) -7 NIL NIL) (-1251 3531842 3532302 3532826 "UTSODE" 3533943 NIL UTSODE (NIL T T) -7 NIL NIL) (-1250 3523675 3529470 3529958 "UTS" 3531412 NIL UTS (NIL T NIL NIL) -8 NIL NIL) (-1249 3514961 3520321 3520365 "UTSCAT" 3521477 NIL UTSCAT (NIL T) -9 NIL 3522228) (-1248 3512316 3513031 3514020 "UTSCAT-" 3514025 NIL UTSCAT- (NIL T T) -8 NIL NIL) (-1247 3511943 3511986 3512119 "UTS2" 3512267 NIL UTS2 (NIL T T T T) -7 NIL NIL) (-1246 3506257 3508816 3508860 "URAGG" 3510930 NIL URAGG (NIL T) -9 NIL 3511652) (-1245 3503196 3504059 3505182 "URAGG-" 3505187 NIL URAGG- (NIL T T) -8 NIL NIL) (-1244 3498874 3501810 3502282 "UPXSSING" 3502860 NIL UPXSSING (NIL T T NIL NIL) -8 NIL NIL) (-1243 3490761 3497991 3498272 "UPXS" 3498651 NIL UPXS (NIL T NIL NIL) -8 NIL NIL) (-1242 3483789 3490665 3490737 "UPXSCONS" 3490742 NIL UPXSCONS (NIL T T) -8 NIL NIL) (-1241 3474001 3480826 3480889 "UPXSCCA" 3481545 NIL UPXSCCA (NIL T T) -9 NIL 3481787) (-1240 3473639 3473724 3473898 "UPXSCCA-" 3473903 NIL UPXSCCA- (NIL T T T) -8 NIL NIL) (-1239 3463783 3470381 3470425 "UPXSCAT" 3471073 NIL UPXSCAT (NIL T) -9 NIL 3471675) (-1238 3463213 3463292 3463471 "UPXS2" 3463698 NIL UPXS2 (NIL T T NIL NIL NIL NIL) -7 NIL NIL) (-1237 3461867 3462120 3462471 "UPSQFREE" 3462956 NIL UPSQFREE (NIL T T) -7 NIL NIL) (-1236 3455702 3458752 3458808 "UPSCAT" 3459969 NIL UPSCAT (NIL T T) -9 NIL 3460737) (-1235 3454906 3455113 3455440 "UPSCAT-" 3455445 NIL UPSCAT- (NIL T T T) -8 NIL NIL) (-1234 3440895 3448935 3448979 "UPOLYC" 3451080 NIL UPOLYC (NIL T) -9 NIL 3452295) (-1233 3432224 3434649 3437796 "UPOLYC-" 3437801 NIL UPOLYC- (NIL T T) -8 NIL NIL) (-1232 3431851 3431894 3432027 "UPOLYC2" 3432175 NIL UPOLYC2 (NIL T T T T) -7 NIL NIL) (-1231 3423262 3431417 3431555 "UP" 3431761 NIL UP (NIL NIL T) -8 NIL NIL) (-1230 3422601 3422708 3422872 "UPMP" 3423151 NIL UPMP (NIL T T) -7 NIL NIL) (-1229 3422154 3422235 3422374 "UPDIVP" 3422514 NIL UPDIVP (NIL T T) -7 NIL NIL) (-1228 3420722 3420971 3421287 "UPDECOMP" 3421903 NIL UPDECOMP (NIL T T) -7 NIL NIL) (-1227 3419953 3420065 3420251 "UPCDEN" 3420606 NIL UPCDEN (NIL T T T) -7 NIL NIL) (-1226 3419472 3419541 3419690 "UP2" 3419878 NIL UP2 (NIL NIL T NIL T) -7 NIL NIL) (-1225 3417993 3418680 3418955 "UNISEG" 3419232 NIL UNISEG (NIL T) -8 NIL NIL) (-1224 3417210 3417337 3417541 "UNISEG2" 3417837 NIL UNISEG2 (NIL T T) -7 NIL NIL) (-1223 3416270 3416450 3416676 "UNIFACT" 3417026 NIL UNIFACT (NIL T) -7 NIL NIL) (-1222 3400154 3415449 3415699 "ULS" 3416078 NIL ULS (NIL T NIL NIL) -8 NIL NIL) (-1221 3388109 3400058 3400130 "ULSCONS" 3400135 NIL ULSCONS (NIL T T) -8 NIL NIL) (-1220 3370774 3382791 3382854 "ULSCCAT" 3383574 NIL ULSCCAT (NIL T T) -9 NIL 3383871) (-1219 3369824 3370069 3370457 "ULSCCAT-" 3370462 NIL ULSCCAT- (NIL T T T) -8 NIL NIL) (-1218 3359760 3366272 3366316 "ULSCAT" 3367179 NIL ULSCAT (NIL T) -9 NIL 3367902) (-1217 3359190 3359269 3359448 "ULS2" 3359675 NIL ULS2 (NIL T T NIL NIL NIL NIL) -7 NIL NIL) (-1216 3351328 3357181 3357681 "UFPS" 3358725 NIL UFPS (NIL T) -8 NIL NIL) (-1215 3351025 3351082 3351180 "UFPS1" 3351265 NIL UFPS1 (NIL T) -7 NIL NIL) (-1214 3349418 3350385 3350416 "UFD" 3350628 T UFD (NIL) -9 NIL 3350742) (-1213 3349212 3349258 3349353 "UFD-" 3349358 NIL UFD- (NIL T) -8 NIL NIL) (-1212 3348294 3348477 3348693 "UDVO" 3349018 T UDVO (NIL) -7 NIL NIL) (-1211 3346112 3346521 3346991 "UDPO" 3347859 NIL UDPO (NIL T) -7 NIL NIL) (-1210 3342075 3346057 3346093 "U8VEC" 3346098 T U8VEC (NIL) -8 NIL NIL) (-1209 3338269 3341839 3341937 "U8MAT" 3341999 T U8MAT (NIL) -8 NIL NIL) (-1208 3334232 3338214 3338250 "U32VEC" 3338255 T U32VEC (NIL) -8 NIL NIL) (-1207 3330426 3333996 3334094 "U32MAT" 3334156 T U32MAT (NIL) -8 NIL NIL) (-1206 3326389 3330371 3330407 "U16VEC" 3330412 T U16VEC (NIL) -8 NIL NIL) (-1205 3322583 3326153 3326251 "U16MAT" 3326313 T U16MAT (NIL) -8 NIL NIL) (-1204 3322515 3322520 3322551 "TYPE" 3322556 T TYPE (NIL) -9 NIL NIL) (-1203 3321486 3321688 3321928 "TWOFACT" 3322309 NIL TWOFACT (NIL T) -7 NIL NIL) (-1202 3320558 3320889 3321088 "TUPLE" 3321322 NIL TUPLE (NIL T) -8 NIL NIL) (-1201 3318249 3318768 3319307 "TUBETOOL" 3320041 T TUBETOOL (NIL) -7 NIL NIL) (-1200 3317098 3317303 3317544 "TUBE" 3318042 NIL TUBE (NIL T) -8 NIL NIL) (-1199 3311818 3316072 3316354 "TS" 3316851 NIL TS (NIL T) -8 NIL NIL) (-1198 3300492 3304577 3304675 "TSETCAT" 3309944 NIL TSETCAT (NIL T T T T) -9 NIL 3311474) (-1197 3295227 3296824 3298715 "TSETCAT-" 3298720 NIL TSETCAT- (NIL T T T T T) -8 NIL NIL) (-1196 3289497 3290344 3291282 "TRMANIP" 3294367 NIL TRMANIP (NIL T T) -7 NIL NIL) (-1195 3288938 3289001 3289164 "TRIMAT" 3289429 NIL TRIMAT (NIL T T T T) -7 NIL NIL) (-1194 3286734 3286971 3287335 "TRIGMNIP" 3288687 NIL TRIGMNIP (NIL T T) -7 NIL NIL) (-1193 3286253 3286366 3286397 "TRIGCAT" 3286610 T TRIGCAT (NIL) -9 NIL NIL) (-1192 3285922 3286001 3286142 "TRIGCAT-" 3286147 NIL TRIGCAT- (NIL T) -8 NIL NIL) (-1191 3282825 3284780 3285061 "TREE" 3285676 NIL TREE (NIL T) -8 NIL NIL) (-1190 3282098 3282626 3282657 "TRANFUN" 3282692 T TRANFUN (NIL) -9 NIL 3282758) (-1189 3281377 3281568 3281848 "TRANFUN-" 3281853 NIL TRANFUN- (NIL T) -8 NIL NIL) (-1188 3281181 3281213 3281274 "TOPSP" 3281338 T TOPSP (NIL) -7 NIL NIL) (-1187 3280529 3280644 3280798 "TOOLSIGN" 3281062 NIL TOOLSIGN (NIL T) -7 NIL NIL) (-1186 3279164 3279706 3279945 "TEXTFILE" 3280312 T TEXTFILE (NIL) -8 NIL NIL) (-1185 3277029 3277543 3277981 "TEX" 3278748 T TEX (NIL) -8 NIL NIL) (-1184 3276810 3276841 3276913 "TEX1" 3276992 NIL TEX1 (NIL T) -7 NIL NIL) (-1183 3276458 3276521 3276611 "TEMUTL" 3276742 T TEMUTL (NIL) -7 NIL NIL) (-1182 3274612 3274892 3275217 "TBCMPPK" 3276181 NIL TBCMPPK (NIL T T) -7 NIL NIL) (-1181 3266357 3272617 3272674 "TBAGG" 3273074 NIL TBAGG (NIL T T) -9 NIL 3273285) (-1180 3261427 3262915 3264669 "TBAGG-" 3264674 NIL TBAGG- (NIL T T T) -8 NIL NIL) (-1179 3260811 3260918 3261063 "TANEXP" 3261316 NIL TANEXP (NIL T) -7 NIL NIL) (-1178 3254324 3260668 3260761 "TABLE" 3260766 NIL TABLE (NIL T T) -8 NIL NIL) (-1177 3253737 3253835 3253973 "TABLEAU" 3254221 NIL TABLEAU (NIL T) -8 NIL NIL) (-1176 3248345 3249565 3250813 "TABLBUMP" 3252523 NIL TABLBUMP (NIL T) -7 NIL NIL) (-1175 3244808 3245503 3246286 "SYSSOLP" 3247596 NIL SYSSOLP (NIL T) -7 NIL NIL) (-1174 3241942 3242550 3243188 "SYMTAB" 3244192 T SYMTAB (NIL) -8 NIL NIL) (-1173 3237191 3238093 3239076 "SYMS" 3240981 T SYMS (NIL) -8 NIL NIL) (-1172 3234423 3236655 3236882 "SYMPOLY" 3236999 NIL SYMPOLY (NIL T) -8 NIL NIL) (-1171 3233940 3234015 3234138 "SYMFUNC" 3234335 NIL SYMFUNC (NIL T) -7 NIL NIL) (-1170 3229918 3231177 3231999 "SYMBOL" 3233140 T SYMBOL (NIL) -8 NIL NIL) (-1169 3223457 3225146 3226866 "SWITCH" 3228220 T SWITCH (NIL) -8 NIL NIL) (-1168 3216683 3222280 3222582 "SUTS" 3223213 NIL SUTS (NIL T NIL NIL) -8 NIL NIL) (-1167 3208569 3215800 3216081 "SUPXS" 3216460 NIL SUPXS (NIL T NIL NIL) -8 NIL NIL) (-1166 3200054 3208187 3208313 "SUP" 3208478 NIL SUP (NIL T) -8 NIL NIL) (-1165 3199213 3199340 3199557 "SUPFRACF" 3199922 NIL SUPFRACF (NIL T T T T) -7 NIL NIL) (-1164 3189785 3199015 3199129 "SUPEXPR" 3199134 NIL SUPEXPR (NIL T) -8 NIL NIL) (-1163 3189406 3189465 3189578 "SUP2" 3189720 NIL SUP2 (NIL T T) -7 NIL NIL) (-1162 3187819 3188093 3188456 "SUMRF" 3189105 NIL SUMRF (NIL T) -7 NIL NIL) (-1161 3187133 3187199 3187398 "SUMFS" 3187740 NIL SUMFS (NIL T T) -7 NIL NIL) (-1160 3171057 3186312 3186562 "SULS" 3186941 NIL SULS (NIL T NIL NIL) -8 NIL NIL) (-1159 3170379 3170582 3170722 "SUCH" 3170965 NIL SUCH (NIL T T) -8 NIL NIL) (-1158 3164273 3165285 3166244 "SUBSPACE" 3169467 NIL SUBSPACE (NIL NIL T) -8 NIL NIL) (-1157 3163705 3163795 3163958 "SUBRESP" 3164162 NIL SUBRESP (NIL T T) -7 NIL NIL) (-1156 3157074 3158370 3159681 "STTF" 3162441 NIL STTF (NIL T) -7 NIL NIL) (-1155 3151247 3152367 3153514 "STTFNC" 3155974 NIL STTFNC (NIL T) -7 NIL NIL) (-1154 3142566 3144433 3146225 "STTAYLOR" 3149490 NIL STTAYLOR (NIL T) -7 NIL NIL) (-1153 3135822 3142430 3142513 "STRTBL" 3142518 NIL STRTBL (NIL T) -8 NIL NIL) (-1152 3131213 3135777 3135808 "STRING" 3135813 T STRING (NIL) -8 NIL NIL) (-1151 3126077 3130555 3130586 "STRICAT" 3130645 T STRICAT (NIL) -9 NIL 3130707) (-1150 3118804 3123604 3124222 "STREAM" 3125494 NIL STREAM (NIL T) -8 NIL NIL) (-1149 3118314 3118391 3118535 "STREAM3" 3118721 NIL STREAM3 (NIL T T T) -7 NIL NIL) (-1148 3117296 3117479 3117714 "STREAM2" 3118127 NIL STREAM2 (NIL T T) -7 NIL NIL) (-1147 3116984 3117036 3117129 "STREAM1" 3117238 NIL STREAM1 (NIL T) -7 NIL NIL) (-1146 3116628 3116694 3116801 "STNSR" 3116912 NIL STNSR (NIL T) -7 NIL NIL) (-1145 3115644 3115825 3116056 "STINPROD" 3116444 NIL STINPROD (NIL T) -7 NIL NIL) (-1144 3115221 3115405 3115436 "STEP" 3115516 T STEP (NIL) -9 NIL 3115594) (-1143 3108776 3115120 3115197 "STBL" 3115202 NIL STBL (NIL T T NIL) -8 NIL NIL) (-1142 3103990 3108028 3108072 "STAGG" 3108225 NIL STAGG (NIL T) -9 NIL 3108314) (-1141 3101692 3102294 3103166 "STAGG-" 3103171 NIL STAGG- (NIL T T) -8 NIL NIL) (-1140 3095184 3096753 3097868 "STACK" 3100612 NIL STACK (NIL T) -8 NIL NIL) (-1139 3087909 3093325 3093781 "SREGSET" 3094814 NIL SREGSET (NIL T T T T) -8 NIL NIL) (-1138 3080335 3081703 3083216 "SRDCMPK" 3086515 NIL SRDCMPK (NIL T T T T T) -7 NIL NIL) (-1137 3073313 3077773 3077804 "SRAGG" 3079107 T SRAGG (NIL) -9 NIL 3079715) (-1136 3072330 3072585 3072964 "SRAGG-" 3072969 NIL SRAGG- (NIL T) -8 NIL NIL) (-1135 3066778 3071253 3071677 "SQMATRIX" 3071953 NIL SQMATRIX (NIL NIL T) -8 NIL NIL) (-1134 3060534 3063496 3064223 "SPLTREE" 3066123 NIL SPLTREE (NIL T T) -8 NIL NIL) (-1133 3056524 3057190 3057836 "SPLNODE" 3059960 NIL SPLNODE (NIL T T) -8 NIL NIL) (-1132 3055570 3055803 3055834 "SPFCAT" 3056278 T SPFCAT (NIL) -9 NIL NIL) (-1131 3054307 3054517 3054781 "SPECOUT" 3055328 T SPECOUT (NIL) -7 NIL NIL) (-1130 3046277 3048024 3048068 "SPACEC" 3052441 NIL SPACEC (NIL T) -9 NIL 3054257) (-1129 3044448 3046209 3046258 "SPACE3" 3046263 NIL SPACE3 (NIL T) -8 NIL NIL) (-1128 3043202 3043373 3043663 "SORTPAK" 3044254 NIL SORTPAK (NIL T T) -7 NIL NIL) (-1127 3041252 3041555 3041974 "SOLVETRA" 3042866 NIL SOLVETRA (NIL T) -7 NIL NIL) (-1126 3040263 3040485 3040759 "SOLVESER" 3041025 NIL SOLVESER (NIL T) -7 NIL NIL) (-1125 3035483 3036364 3037366 "SOLVERAD" 3039315 NIL SOLVERAD (NIL T) -7 NIL NIL) (-1124 3031298 3031907 3032636 "SOLVEFOR" 3034850 NIL SOLVEFOR (NIL T T) -7 NIL NIL) (-1123 3025601 3030646 3030744 "SNTSCAT" 3030749 NIL SNTSCAT (NIL T T T T) -9 NIL 3030819) (-1122 3019699 3023926 3024316 "SMTS" 3025292 NIL SMTS (NIL T T T) -8 NIL NIL) (-1121 3014103 3019587 3019664 "SMP" 3019669 NIL SMP (NIL T T) -8 NIL NIL) (-1120 3012262 3012563 3012961 "SMITH" 3013800 NIL SMITH (NIL T T T T) -7 NIL NIL) (-1119 3005204 3009402 3009506 "SMATCAT" 3010857 NIL SMATCAT (NIL NIL T T T) -9 NIL 3011404) (-1118 3002144 3002967 3004145 "SMATCAT-" 3004150 NIL SMATCAT- (NIL T NIL T T T) -8 NIL NIL) (-1117 2999897 3001414 3001458 "SKAGG" 3001719 NIL SKAGG (NIL T) -9 NIL 3001854) (-1116 2995955 2999001 2999279 "SINT" 2999641 T SINT (NIL) -8 NIL NIL) (-1115 2995727 2995765 2995831 "SIMPAN" 2995911 T SIMPAN (NIL) -7 NIL NIL) (-1114 2994565 2994786 2995061 "SIGNRF" 2995486 NIL SIGNRF (NIL T) -7 NIL NIL) (-1113 2993370 2993521 2993812 "SIGNEF" 2994394 NIL SIGNEF (NIL T T) -7 NIL NIL) (-1112 2991062 2991516 2992021 "SHP" 2992912 NIL SHP (NIL T NIL) -7 NIL NIL) (-1111 2984843 2990963 2991039 "SHDP" 2991044 NIL SHDP (NIL NIL NIL T) -8 NIL NIL) (-1110 2984331 2984523 2984554 "SGROUP" 2984706 T SGROUP (NIL) -9 NIL 2984793) (-1109 2984101 2984153 2984257 "SGROUP-" 2984262 NIL SGROUP- (NIL T) -8 NIL NIL) (-1108 2980937 2981634 2982357 "SGCF" 2983400 T SGCF (NIL) -7 NIL NIL) (-1107 2975338 2980383 2980481 "SFRTCAT" 2980486 NIL SFRTCAT (NIL T T T T) -9 NIL 2980525) (-1106 2968762 2969777 2970913 "SFRGCD" 2974321 NIL SFRGCD (NIL T T T T T) -7 NIL NIL) (-1105 2961890 2962961 2964147 "SFQCMPK" 2967695 NIL SFQCMPK (NIL T T T T T) -7 NIL NIL) (-1104 2961512 2961601 2961711 "SFORT" 2961831 NIL SFORT (NIL T T) -8 NIL NIL) (-1103 2960657 2961352 2961473 "SEXOF" 2961478 NIL SEXOF (NIL T T T T T) -8 NIL NIL) (-1102 2959791 2960538 2960606 "SEX" 2960611 T SEX (NIL) -8 NIL NIL) (-1101 2954566 2955255 2955351 "SEXCAT" 2959122 NIL SEXCAT (NIL T T T T T) -9 NIL 2959741) (-1100 2951701 2954500 2954548 "SET" 2954553 NIL SET (NIL T) -8 NIL NIL) (-1099 2949935 2950414 2950719 "SETMN" 2951442 NIL SETMN (NIL NIL NIL) -8 NIL NIL) (-1098 2949540 2949666 2949697 "SETCAT" 2949814 T SETCAT (NIL) -9 NIL 2949899) (-1097 2949320 2949372 2949471 "SETCAT-" 2949476 NIL SETCAT- (NIL T) -8 NIL NIL) (-1096 2948983 2949133 2949164 "SETCATD" 2949223 T SETCATD (NIL) -9 NIL 2949270) (-1095 2945369 2947443 2947487 "SETAGG" 2948357 NIL SETAGG (NIL T) -9 NIL 2948697) (-1094 2944827 2944943 2945180 "SETAGG-" 2945185 NIL SETAGG- (NIL T T) -8 NIL NIL) (-1093 2944030 2944323 2944385 "SEGXCAT" 2944671 NIL SEGXCAT (NIL T T) -9 NIL 2944791) (-1092 2943090 2943700 2943880 "SEG" 2943885 NIL SEG (NIL T) -8 NIL NIL) (-1091 2941996 2942209 2942253 "SEGCAT" 2942835 NIL SEGCAT (NIL T) -9 NIL 2943073) (-1090 2941047 2941377 2941576 "SEGBIND" 2941832 NIL SEGBIND (NIL T) -8 NIL NIL) (-1089 2940668 2940727 2940840 "SEGBIND2" 2940982 NIL SEGBIND2 (NIL T T) -7 NIL NIL) (-1088 2939889 2940015 2940218 "SEG2" 2940513 NIL SEG2 (NIL T T) -7 NIL NIL) (-1087 2939326 2939824 2939871 "SDVAR" 2939876 NIL SDVAR (NIL T) -8 NIL NIL) (-1086 2931570 2939096 2939226 "SDPOL" 2939231 NIL SDPOL (NIL T) -8 NIL NIL) (-1085 2927593 2928622 2929269 "SD" 2930970 NIL SD (NIL T) -8 NIL NIL) (-1084 2926186 2926452 2926771 "SCPKG" 2927308 NIL SCPKG (NIL T) -7 NIL NIL) (-1083 2925407 2925540 2925719 "SCACHE" 2926041 NIL SCACHE (NIL T) -7 NIL NIL) (-1082 2924846 2925167 2925252 "SAOS" 2925344 T SAOS (NIL) -8 NIL NIL) (-1081 2924411 2924446 2924619 "SAERFFC" 2924805 NIL SAERFFC (NIL T T T) -7 NIL NIL) (-1080 2918255 2924308 2924388 "SAE" 2924393 NIL SAE (NIL T T NIL) -8 NIL NIL) (-1079 2917848 2917883 2918042 "SAEFACT" 2918214 NIL SAEFACT (NIL T T T) -7 NIL NIL) (-1078 2916169 2916483 2916884 "RURPK" 2917514 NIL RURPK (NIL T NIL) -7 NIL NIL) (-1077 2914805 2915084 2915396 "RULESET" 2916003 NIL RULESET (NIL T T T) -8 NIL NIL) (-1076 2911992 2912495 2912960 "RULE" 2914486 NIL RULE (NIL T T T) -8 NIL NIL) (-1075 2911631 2911786 2911869 "RULECOLD" 2911944 NIL RULECOLD (NIL NIL) -8 NIL NIL) (-1074 2906480 2907274 2908194 "RSETGCD" 2910830 NIL RSETGCD (NIL T T T T T) -7 NIL NIL) (-1073 2895743 2900788 2900886 "RSETCAT" 2905005 NIL RSETCAT (NIL T T T T) -9 NIL 2906102) (-1072 2893670 2894209 2895033 "RSETCAT-" 2895038 NIL RSETCAT- (NIL T T T T T) -8 NIL NIL) (-1071 2886057 2887432 2888952 "RSDCMPK" 2892269 NIL RSDCMPK (NIL T T T T T) -7 NIL NIL) (-1070 2884061 2884502 2884577 "RRCC" 2885663 NIL RRCC (NIL T T) -9 NIL 2886007) (-1069 2883412 2883586 2883865 "RRCC-" 2883870 NIL RRCC- (NIL T T T) -8 NIL NIL) (-1068 2857554 2867185 2867253 "RPOLCAT" 2877919 NIL RPOLCAT (NIL T T T) -9 NIL 2881068) (-1067 2849054 2851392 2854514 "RPOLCAT-" 2854519 NIL RPOLCAT- (NIL T T T T) -8 NIL NIL) (-1066 2840113 2847265 2847747 "ROUTINE" 2848594 T ROUTINE (NIL) -8 NIL NIL) (-1065 2836813 2839664 2839813 "ROMAN" 2839986 T ROMAN (NIL) -8 NIL NIL) (-1064 2835088 2835673 2835933 "ROIRC" 2836618 NIL ROIRC (NIL T T) -8 NIL NIL) (-1063 2831426 2833726 2833757 "RNS" 2834061 T RNS (NIL) -9 NIL 2834335) (-1062 2829935 2830318 2830852 "RNS-" 2830927 NIL RNS- (NIL T) -8 NIL NIL) (-1061 2829357 2829765 2829796 "RNG" 2829801 T RNG (NIL) -9 NIL 2829822) (-1060 2828748 2829110 2829154 "RMODULE" 2829216 NIL RMODULE (NIL T) -9 NIL 2829258) (-1059 2827584 2827678 2828014 "RMCAT2" 2828649 NIL RMCAT2 (NIL NIL NIL T T T T T T T T) -7 NIL NIL) (-1058 2824293 2826762 2827085 "RMATRIX" 2827320 NIL RMATRIX (NIL NIL NIL T) -8 NIL NIL) (-1057 2817239 2819473 2819589 "RMATCAT" 2822948 NIL RMATCAT (NIL NIL NIL T T T) -9 NIL 2823925) (-1056 2816614 2816761 2817068 "RMATCAT-" 2817073 NIL RMATCAT- (NIL T NIL NIL T T T) -8 NIL NIL) (-1055 2816181 2816256 2816384 "RINTERP" 2816533 NIL RINTERP (NIL NIL T) -7 NIL NIL) (-1054 2815224 2815788 2815819 "RING" 2815931 T RING (NIL) -9 NIL 2816026) (-1053 2815016 2815060 2815157 "RING-" 2815162 NIL RING- (NIL T) -8 NIL NIL) (-1052 2813857 2814094 2814352 "RIDIST" 2814780 T RIDIST (NIL) -7 NIL NIL) (-1051 2805173 2813325 2813531 "RGCHAIN" 2813705 NIL RGCHAIN (NIL T NIL) -8 NIL NIL) (-1050 2803973 2804214 2804493 "RFP" 2804928 NIL RFP (NIL T) -7 NIL NIL) (-1049 2800967 2801581 2802251 "RF" 2803337 NIL RF (NIL T) -7 NIL NIL) (-1048 2800613 2800676 2800779 "RFFACTOR" 2800898 NIL RFFACTOR (NIL T) -7 NIL NIL) (-1047 2800338 2800373 2800470 "RFFACT" 2800572 NIL RFFACT (NIL T) -7 NIL NIL) (-1046 2798455 2798819 2799201 "RFDIST" 2799978 T RFDIST (NIL) -7 NIL NIL) (-1045 2797908 2798000 2798163 "RETSOL" 2798357 NIL RETSOL (NIL T T) -7 NIL NIL) (-1044 2797495 2797575 2797619 "RETRACT" 2797812 NIL RETRACT (NIL T) -9 NIL NIL) (-1043 2797344 2797369 2797456 "RETRACT-" 2797461 NIL RETRACT- (NIL T T) -8 NIL NIL) (-1042 2790210 2796997 2797124 "RESULT" 2797239 T RESULT (NIL) -8 NIL NIL) (-1041 2788790 2789479 2789678 "RESRING" 2790113 NIL RESRING (NIL T T T T NIL) -8 NIL NIL) (-1040 2788426 2788475 2788573 "RESLATC" 2788727 NIL RESLATC (NIL T) -7 NIL NIL) (-1039 2788132 2788166 2788273 "REPSQ" 2788385 NIL REPSQ (NIL T) -7 NIL NIL) (-1038 2785554 2786134 2786736 "REP" 2787552 T REP (NIL) -7 NIL NIL) (-1037 2785252 2785286 2785397 "REPDB" 2785513 NIL REPDB (NIL T) -7 NIL NIL) (-1036 2779170 2780549 2781768 "REP2" 2784068 NIL REP2 (NIL T) -7 NIL NIL) (-1035 2775551 2776232 2777038 "REP1" 2778399 NIL REP1 (NIL T) -7 NIL NIL) (-1034 2768277 2773692 2774148 "REGSET" 2775181 NIL REGSET (NIL T T T T) -8 NIL NIL) (-1033 2767092 2767427 2767676 "REF" 2768063 NIL REF (NIL T) -8 NIL NIL) (-1032 2766469 2766572 2766739 "REDORDER" 2766976 NIL REDORDER (NIL T T) -7 NIL NIL) (-1031 2763331 2763797 2764406 "RECOP" 2766003 NIL RECOP (NIL T T) -7 NIL NIL) (-1030 2759271 2762544 2762771 "RECLOS" 2763159 NIL RECLOS (NIL T) -8 NIL NIL) (-1029 2758323 2758504 2758719 "REALSOLV" 2759078 T REALSOLV (NIL) -7 NIL NIL) (-1028 2758168 2758209 2758240 "REAL" 2758245 T REAL (NIL) -9 NIL 2758280) (-1027 2754651 2755453 2756337 "REAL0Q" 2757333 NIL REAL0Q (NIL T) -7 NIL NIL) (-1026 2750252 2751240 2752301 "REAL0" 2753632 NIL REAL0 (NIL T) -7 NIL NIL) (-1025 2749657 2749729 2749936 "RDIV" 2750174 NIL RDIV (NIL T T T T T) -7 NIL NIL) (-1024 2748725 2748899 2749112 "RDIST" 2749479 NIL RDIST (NIL T) -7 NIL NIL) (-1023 2747322 2747609 2747981 "RDETRS" 2748433 NIL RDETRS (NIL T T) -7 NIL NIL) (-1022 2745134 2745588 2746126 "RDETR" 2746864 NIL RDETR (NIL T T) -7 NIL NIL) (-1021 2743745 2744023 2744427 "RDEEFS" 2744850 NIL RDEEFS (NIL T T) -7 NIL NIL) (-1020 2742240 2742546 2742978 "RDEEF" 2743433 NIL RDEEF (NIL T T) -7 NIL NIL) (-1019 2736431 2739366 2739397 "RCFIELD" 2740692 T RCFIELD (NIL) -9 NIL 2741423) (-1018 2734495 2734999 2735695 "RCFIELD-" 2735770 NIL RCFIELD- (NIL T) -8 NIL NIL) (-1017 2730853 2732632 2732676 "RCAGG" 2733760 NIL RCAGG (NIL T) -9 NIL 2734223) (-1016 2730481 2730575 2730738 "RCAGG-" 2730743 NIL RCAGG- (NIL T T) -8 NIL NIL) (-1015 2729817 2729928 2730093 "RATRET" 2730365 NIL RATRET (NIL T) -7 NIL NIL) (-1014 2729370 2729437 2729558 "RATFACT" 2729745 NIL RATFACT (NIL T) -7 NIL NIL) (-1013 2728678 2728798 2728950 "RANDSRC" 2729240 T RANDSRC (NIL) -7 NIL NIL) (-1012 2728412 2728456 2728529 "RADUTIL" 2728627 T RADUTIL (NIL) -7 NIL NIL) (-1011 2721398 2727143 2727463 "RADIX" 2728126 NIL RADIX (NIL NIL) -8 NIL NIL) (-1010 2712909 2721240 2721370 "RADFF" 2721375 NIL RADFF (NIL T T T NIL NIL) -8 NIL NIL) (-1009 2712555 2712630 2712661 "RADCAT" 2712821 T RADCAT (NIL) -9 NIL NIL) (-1008 2712337 2712385 2712485 "RADCAT-" 2712490 NIL RADCAT- (NIL T) -8 NIL NIL) (-1007 2705582 2707200 2708354 "QUEUE" 2711218 NIL QUEUE (NIL T) -8 NIL NIL) (-1006 2702069 2705515 2705563 "QUAT" 2705568 NIL QUAT (NIL T) -8 NIL NIL) (-1005 2701700 2701743 2701874 "QUATCT2" 2702020 NIL QUATCT2 (NIL T T T T) -7 NIL NIL) (-1004 2695424 2698808 2698851 "QUATCAT" 2699642 NIL QUATCAT (NIL T) -9 NIL 2700400) (-1003 2691563 2692600 2693990 "QUATCAT-" 2694086 NIL QUATCAT- (NIL T T) -8 NIL NIL) (-1002 2689115 2690673 2690717 "QUAGG" 2691098 NIL QUAGG (NIL T) -9 NIL 2691273) (-1001 2688035 2688508 2688682 "QFORM" 2688987 NIL QFORM (NIL NIL T) -8 NIL NIL) (-1000 2679250 2684517 2684560 "QFCAT" 2685228 NIL QFCAT (NIL T) -9 NIL 2686217) (-999 2674820 2676021 2677613 "QFCAT-" 2677708 NIL QFCAT- (NIL T T) -8 NIL NIL) (-998 2674454 2674497 2674626 "QFCAT2" 2674771 NIL QFCAT2 (NIL T T T T) -7 NIL NIL) (-997 2673914 2674024 2674154 "QEQUAT" 2674344 T QEQUAT (NIL) -8 NIL NIL) (-996 2667062 2668133 2669317 "QCMPACK" 2672847 NIL QCMPACK (NIL T T T T T) -7 NIL NIL) (-995 2664642 2665063 2665489 "QALGSET" 2666719 NIL QALGSET (NIL T T T T) -8 NIL NIL) (-994 2663887 2664061 2664293 "QALGSET2" 2664462 NIL QALGSET2 (NIL NIL NIL) -7 NIL NIL) (-993 2662578 2662801 2663118 "PWFFINTB" 2663660 NIL PWFFINTB (NIL T T T T) -7 NIL NIL) (-992 2660760 2660928 2661282 "PUSHVAR" 2662392 NIL PUSHVAR (NIL T T T T) -7 NIL NIL) (-991 2656677 2657731 2657773 "PTRANFN" 2659657 NIL PTRANFN (NIL T) -9 NIL NIL) (-990 2655079 2655370 2655692 "PTPACK" 2656388 NIL PTPACK (NIL T) -7 NIL NIL) (-989 2654711 2654768 2654877 "PTFUNC2" 2655016 NIL PTFUNC2 (NIL T T) -7 NIL NIL) (-988 2649211 2653545 2653587 "PTCAT" 2653960 NIL PTCAT (NIL T) -9 NIL 2654122) (-987 2648869 2648904 2649028 "PSQFR" 2649170 NIL PSQFR (NIL T T T T) -7 NIL NIL) (-986 2647456 2647756 2648092 "PSEUDLIN" 2648565 NIL PSEUDLIN (NIL T) -7 NIL NIL) (-985 2634232 2636596 2638917 "PSETPK" 2645219 NIL PSETPK (NIL T T T T) -7 NIL NIL) (-984 2627276 2629990 2630087 "PSETCAT" 2633108 NIL PSETCAT (NIL T T T T) -9 NIL 2633921) (-983 2625112 2625746 2626567 "PSETCAT-" 2626572 NIL PSETCAT- (NIL T T T T T) -8 NIL NIL) (-982 2624461 2624625 2624654 "PSCURVE" 2624922 T PSCURVE (NIL) -9 NIL 2625089) (-981 2620850 2622376 2622442 "PSCAT" 2623286 NIL PSCAT (NIL T T T) -9 NIL 2623526) (-980 2619913 2620129 2620529 "PSCAT-" 2620534 NIL PSCAT- (NIL T T T T) -8 NIL NIL) (-979 2618566 2619198 2619412 "PRTITION" 2619719 T PRTITION (NIL) -8 NIL NIL) (-978 2615730 2616379 2616420 "PRSPCAT" 2617934 NIL PRSPCAT (NIL T) -9 NIL 2618502) (-977 2604830 2607036 2609223 "PRS" 2613593 NIL PRS (NIL T T) -7 NIL NIL) (-976 2602728 2604214 2604255 "PRQAGG" 2604438 NIL PRQAGG (NIL T) -9 NIL 2604540) (-975 2601997 2602653 2602710 "PROJSP" 2602715 NIL PROJSP (NIL NIL T) -8 NIL NIL) (-974 2601179 2601920 2601972 "PROJPLPS" 2601977 NIL PROJPLPS (NIL T) -8 NIL NIL) (-973 2600438 2601116 2601161 "PROJPL" 2601166 NIL PROJPL (NIL T) -8 NIL NIL) (-972 2594173 2598636 2599440 "PRODUCT" 2599680 NIL PRODUCT (NIL T T) -8 NIL NIL) (-971 2591448 2593637 2593868 "PR" 2593987 NIL PR (NIL T T) -8 NIL NIL) (-970 2590000 2590157 2590452 "PRJALGPK" 2591288 NIL PRJALGPK (NIL T NIL T T T) -7 NIL NIL) (-969 2589796 2589828 2589887 "PRINT" 2589961 T PRINT (NIL) -7 NIL NIL) (-968 2589136 2589253 2589405 "PRIMES" 2589676 NIL PRIMES (NIL T) -7 NIL NIL) (-967 2587201 2587602 2588068 "PRIMELT" 2588715 NIL PRIMELT (NIL T) -7 NIL NIL) (-966 2586929 2586978 2587007 "PRIMCAT" 2587131 T PRIMCAT (NIL) -9 NIL NIL) (-965 2583096 2586867 2586912 "PRIMARR" 2586917 NIL PRIMARR (NIL T) -8 NIL NIL) (-964 2582103 2582281 2582509 "PRIMARR2" 2582914 NIL PRIMARR2 (NIL T T) -7 NIL NIL) (-963 2581746 2581802 2581913 "PREASSOC" 2582041 NIL PREASSOC (NIL T T) -7 NIL NIL) (-962 2581221 2581353 2581382 "PPCURVE" 2581587 T PPCURVE (NIL) -9 NIL 2581723) (-961 2575619 2576770 2577949 "POLYVEC" 2580062 T POLYVEC (NIL) -7 NIL NIL) (-960 2572980 2573379 2573970 "POLYROOT" 2575201 NIL POLYROOT (NIL T T T T T) -7 NIL NIL) (-959 2566881 2572586 2572745 "POLY" 2572854 NIL POLY (NIL T) -8 NIL NIL) (-958 2566264 2566322 2566556 "POLYLIFT" 2566817 NIL POLYLIFT (NIL T T T T T) -7 NIL NIL) (-957 2562539 2562988 2563617 "POLYCATQ" 2565809 NIL POLYCATQ (NIL T T T T T) -7 NIL NIL) (-956 2549501 2554901 2554967 "POLYCAT" 2558481 NIL POLYCAT (NIL T T T) -9 NIL 2560394) (-955 2542951 2544812 2547196 "POLYCAT-" 2547201 NIL POLYCAT- (NIL T T T T) -8 NIL NIL) (-954 2542538 2542606 2542726 "POLY2UP" 2542877 NIL POLY2UP (NIL NIL T) -7 NIL NIL) (-953 2542170 2542227 2542336 "POLY2" 2542475 NIL POLY2 (NIL T T) -7 NIL NIL) (-952 2540857 2541096 2541371 "POLUTIL" 2541945 NIL POLUTIL (NIL T T) -7 NIL NIL) (-951 2539212 2539489 2539820 "POLTOPOL" 2540579 NIL POLTOPOL (NIL NIL T) -7 NIL NIL) (-950 2534734 2539148 2539194 "POINT" 2539199 NIL POINT (NIL T) -8 NIL NIL) (-949 2532921 2533278 2533653 "PNTHEORY" 2534379 T PNTHEORY (NIL) -7 NIL NIL) (-948 2531340 2531637 2532049 "PMTOOLS" 2532619 NIL PMTOOLS (NIL T T T) -7 NIL NIL) (-947 2530933 2531011 2531128 "PMSYM" 2531256 NIL PMSYM (NIL T) -7 NIL NIL) (-946 2530441 2530510 2530685 "PMQFCAT" 2530858 NIL PMQFCAT (NIL T T T) -7 NIL NIL) (-945 2529796 2529906 2530062 "PMPRED" 2530318 NIL PMPRED (NIL T) -7 NIL NIL) (-944 2529192 2529278 2529439 "PMPREDFS" 2529697 NIL PMPREDFS (NIL T T T) -7 NIL NIL) (-943 2527837 2528045 2528429 "PMPLCAT" 2528955 NIL PMPLCAT (NIL T T T T T) -7 NIL NIL) (-942 2527369 2527448 2527600 "PMLSAGG" 2527752 NIL PMLSAGG (NIL T T T) -7 NIL NIL) (-941 2526844 2526920 2527101 "PMKERNEL" 2527287 NIL PMKERNEL (NIL T T) -7 NIL NIL) (-940 2526461 2526536 2526649 "PMINS" 2526763 NIL PMINS (NIL T) -7 NIL NIL) (-939 2525889 2525958 2526174 "PMFS" 2526386 NIL PMFS (NIL T T T) -7 NIL NIL) (-938 2525117 2525235 2525440 "PMDOWN" 2525766 NIL PMDOWN (NIL T T T) -7 NIL NIL) (-937 2524280 2524439 2524621 "PMASS" 2524955 T PMASS (NIL) -7 NIL NIL) (-936 2523554 2523665 2523828 "PMASSFS" 2524166 NIL PMASSFS (NIL T T) -7 NIL NIL) (-935 2521314 2521567 2521950 "PLPKCRV" 2523278 NIL PLPKCRV (NIL T T T NIL T) -7 NIL NIL) (-934 2520969 2521037 2521131 "PLOTTOOL" 2521240 T PLOTTOOL (NIL) -7 NIL NIL) (-933 2515591 2516780 2517928 "PLOT" 2519841 T PLOT (NIL) -8 NIL NIL) (-932 2511405 2512439 2513360 "PLOT3D" 2514690 T PLOT3D (NIL) -8 NIL NIL) (-931 2510317 2510494 2510729 "PLOT1" 2511209 NIL PLOT1 (NIL T) -7 NIL NIL) (-930 2485736 2490401 2495246 "PLEQN" 2505589 NIL PLEQN (NIL T T T T) -7 NIL NIL) (-929 2484976 2485646 2485713 "PLCS" 2485718 NIL PLCS (NIL T T) -8 NIL NIL) (-928 2484127 2484861 2484932 "PLACESPS" 2484937 NIL PLACESPS (NIL T) -8 NIL NIL) (-927 2483334 2484040 2484097 "PLACES" 2484102 NIL PLACES (NIL T) -8 NIL NIL) (-926 2480058 2480722 2480781 "PLACESC" 2482699 NIL PLACESC (NIL T T) -9 NIL 2483270) (-925 2479376 2479498 2479678 "PINTERP" 2479923 NIL PINTERP (NIL NIL T) -7 NIL NIL) (-924 2479069 2479116 2479219 "PINTERPA" 2479323 NIL PINTERPA (NIL T T) -7 NIL NIL) (-923 2478296 2478863 2478956 "PI" 2478996 T PI (NIL) -8 NIL NIL) (-922 2476683 2477668 2477697 "PID" 2477879 T PID (NIL) -9 NIL 2478013) (-921 2476408 2476445 2476533 "PICOERCE" 2476640 NIL PICOERCE (NIL T) -7 NIL NIL) (-920 2475729 2475867 2476043 "PGROEB" 2476264 NIL PGROEB (NIL T) -7 NIL NIL) (-919 2471316 2472130 2473035 "PGE" 2474844 T PGE (NIL) -7 NIL NIL) (-918 2469440 2469686 2470052 "PGCD" 2471033 NIL PGCD (NIL T T T T) -7 NIL NIL) (-917 2468778 2468881 2469042 "PFRPAC" 2469324 NIL PFRPAC (NIL T) -7 NIL NIL) (-916 2465393 2467326 2467679 "PFR" 2468457 NIL PFR (NIL T) -8 NIL NIL) (-915 2463782 2464026 2464351 "PFOTOOLS" 2465140 NIL PFOTOOLS (NIL T T) -7 NIL NIL) (-914 2458647 2459312 2460061 "PFORP" 2463124 NIL PFORP (NIL T T T NIL) -7 NIL NIL) (-913 2457180 2457419 2457770 "PFOQ" 2458404 NIL PFOQ (NIL T T T) -7 NIL NIL) (-912 2455653 2455865 2456228 "PFO" 2456964 NIL PFO (NIL T T T T T) -7 NIL NIL) (-911 2452151 2455542 2455611 "PF" 2455616 NIL PF (NIL NIL) -8 NIL NIL) (-910 2449576 2450857 2450886 "PFECAT" 2451471 T PFECAT (NIL) -9 NIL 2451854) (-909 2449021 2449175 2449389 "PFECAT-" 2449394 NIL PFECAT- (NIL T) -8 NIL NIL) (-908 2447625 2447876 2448177 "PFBRU" 2448770 NIL PFBRU (NIL T T) -7 NIL NIL) (-907 2445492 2445843 2446275 "PFBR" 2447276 NIL PFBR (NIL T T T T) -7 NIL NIL) (-906 2441348 2442872 2443546 "PERM" 2444851 NIL PERM (NIL T) -8 NIL NIL) (-905 2436615 2437555 2438425 "PERMGRP" 2440511 NIL PERMGRP (NIL T) -8 NIL NIL) (-904 2434686 2435679 2435721 "PERMCAT" 2436167 NIL PERMCAT (NIL T) -9 NIL 2436470) (-903 2434339 2434380 2434504 "PERMAN" 2434639 NIL PERMAN (NIL NIL T) -7 NIL NIL) (-902 2431785 2433908 2434039 "PENDTREE" 2434241 NIL PENDTREE (NIL T) -8 NIL NIL) (-901 2429853 2430631 2430673 "PDRING" 2431330 NIL PDRING (NIL T) -9 NIL 2431616) (-900 2428956 2429174 2429536 "PDRING-" 2429541 NIL PDRING- (NIL T T) -8 NIL NIL) (-899 2426098 2426848 2427539 "PDEPROB" 2428285 T PDEPROB (NIL) -8 NIL NIL) (-898 2423645 2424147 2424702 "PDEPACK" 2425563 T PDEPACK (NIL) -7 NIL NIL) (-897 2422557 2422747 2422998 "PDECOMP" 2423444 NIL PDECOMP (NIL T T) -7 NIL NIL) (-896 2420161 2420978 2421007 "PDECAT" 2421794 T PDECAT (NIL) -9 NIL 2422507) (-895 2419912 2419945 2420035 "PCOMP" 2420122 NIL PCOMP (NIL T T) -7 NIL NIL) (-894 2418117 2418713 2419010 "PBWLB" 2419641 NIL PBWLB (NIL T) -8 NIL NIL) (-893 2410622 2412190 2413528 "PATTERN" 2416800 NIL PATTERN (NIL T) -8 NIL NIL) (-892 2410254 2410311 2410420 "PATTERN2" 2410559 NIL PATTERN2 (NIL T T) -7 NIL NIL) (-891 2408011 2408399 2408856 "PATTERN1" 2409843 NIL PATTERN1 (NIL T T) -7 NIL NIL) (-890 2405406 2405960 2406441 "PATRES" 2407576 NIL PATRES (NIL T T) -8 NIL NIL) (-889 2404970 2405037 2405169 "PATRES2" 2405333 NIL PATRES2 (NIL T T T) -7 NIL NIL) (-888 2402853 2403258 2403665 "PATMATCH" 2404637 NIL PATMATCH (NIL T T T) -7 NIL NIL) (-887 2402388 2402571 2402613 "PATMAB" 2402720 NIL PATMAB (NIL T) -9 NIL 2402803) (-886 2400933 2401242 2401500 "PATLRES" 2402193 NIL PATLRES (NIL T T T) -8 NIL NIL) (-885 2400480 2400603 2400645 "PATAB" 2400650 NIL PATAB (NIL T) -9 NIL 2400820) (-884 2397961 2398493 2399066 "PARTPERM" 2399927 T PARTPERM (NIL) -7 NIL NIL) (-883 2397582 2397645 2397747 "PARSURF" 2397892 NIL PARSURF (NIL T) -8 NIL NIL) (-882 2397214 2397271 2397380 "PARSU2" 2397519 NIL PARSU2 (NIL T T) -7 NIL NIL) (-881 2396835 2396898 2397000 "PARSCURV" 2397145 NIL PARSCURV (NIL T) -8 NIL NIL) (-880 2396467 2396524 2396633 "PARSC2" 2396772 NIL PARSC2 (NIL T T) -7 NIL NIL) (-879 2396106 2396164 2396261 "PARPCURV" 2396403 NIL PARPCURV (NIL T) -8 NIL NIL) (-878 2395738 2395795 2395904 "PARPC2" 2396043 NIL PARPC2 (NIL T T) -7 NIL NIL) (-877 2394218 2394336 2394655 "PARAMP" 2395593 NIL PARAMP (NIL T NIL T T T T T) -7 NIL NIL) (-876 2393738 2393824 2393943 "PAN2EXPR" 2394119 T PAN2EXPR (NIL) -7 NIL NIL) (-875 2392544 2392859 2393087 "PALETTE" 2393530 T PALETTE (NIL) -8 NIL NIL) (-874 2380177 2382343 2384459 "PAFF" 2390492 NIL PAFF (NIL T NIL T) -7 NIL NIL) (-873 2367173 2369501 2371712 "PAFFFF" 2378030 NIL PAFFFF (NIL T NIL T) -7 NIL NIL) (-872 2361012 2366430 2366625 "PADICRC" 2367027 NIL PADICRC (NIL NIL T) -8 NIL NIL) (-871 2354209 2360356 2360541 "PADICRAT" 2360859 NIL PADICRAT (NIL NIL) -8 NIL NIL) (-870 2352513 2354146 2354191 "PADIC" 2354196 NIL PADIC (NIL NIL) -8 NIL NIL) (-869 2349713 2351287 2351328 "PADICCT" 2351909 NIL PADICCT (NIL NIL) -9 NIL 2352191) (-868 2348670 2348870 2349138 "PADEPAC" 2349500 NIL PADEPAC (NIL T NIL NIL) -7 NIL NIL) (-867 2347882 2348015 2348221 "PADE" 2348532 NIL PADE (NIL T T T) -7 NIL NIL) (-866 2344359 2347500 2347619 "PACRAT" 2347783 T PACRAT (NIL) -8 NIL NIL) (-865 2340420 2343470 2343499 "PACRATC" 2343504 T PACRATC (NIL) -9 NIL 2343584) (-864 2336542 2338507 2338536 "PACPERC" 2339482 T PACPERC (NIL) -9 NIL 2339922) (-863 2333187 2336316 2336407 "PACOFF" 2336483 NIL PACOFF (NIL T) -8 NIL NIL) (-862 2329857 2332542 2332571 "PACFFC" 2332576 T PACFFC (NIL) -9 NIL 2332597) (-861 2325947 2329540 2329641 "PACEXT" 2329788 NIL PACEXT (NIL NIL) -8 NIL NIL) (-860 2321325 2324842 2324871 "PACEXTC" 2324876 T PACEXTC (NIL) -9 NIL 2324920) (-859 2319333 2320165 2320480 "OWP" 2321094 NIL OWP (NIL T NIL NIL NIL) -8 NIL NIL) (-858 2318417 2318938 2319110 "OVAR" 2319201 NIL OVAR (NIL NIL) -8 NIL NIL) (-857 2317681 2317802 2317963 "OUT" 2318276 T OUT (NIL) -7 NIL NIL) (-856 2306727 2308906 2311076 "OUTFORM" 2315531 T OUTFORM (NIL) -8 NIL NIL) (-855 2306135 2306456 2306545 "OSI" 2306658 T OSI (NIL) -8 NIL NIL) (-854 2304882 2305109 2305393 "ORTHPOL" 2305883 NIL ORTHPOL (NIL T) -7 NIL NIL) (-853 2302244 2304539 2304679 "OREUP" 2304825 NIL OREUP (NIL NIL T NIL NIL) -8 NIL NIL) (-852 2299631 2301933 2302061 "ORESUP" 2302186 NIL ORESUP (NIL T NIL NIL) -8 NIL NIL) (-851 2297139 2297645 2298210 "OREPCTO" 2299116 NIL OREPCTO (NIL T T) -7 NIL NIL) (-850 2291009 2293220 2293262 "OREPCAT" 2295610 NIL OREPCAT (NIL T) -9 NIL 2296710) (-849 2288156 2288938 2289996 "OREPCAT-" 2290001 NIL OREPCAT- (NIL T T) -8 NIL NIL) (-848 2287332 2287604 2287633 "ORDSET" 2287942 T ORDSET (NIL) -9 NIL 2288106) (-847 2286851 2286973 2287166 "ORDSET-" 2287171 NIL ORDSET- (NIL T) -8 NIL NIL) (-846 2285460 2286261 2286290 "ORDRING" 2286492 T ORDRING (NIL) -9 NIL 2286617) (-845 2285105 2285199 2285343 "ORDRING-" 2285348 NIL ORDRING- (NIL T) -8 NIL NIL) (-844 2284479 2284960 2284989 "ORDMON" 2284994 T ORDMON (NIL) -9 NIL 2285015) (-843 2283641 2283788 2283983 "ORDFUNS" 2284328 NIL ORDFUNS (NIL NIL T) -7 NIL NIL) (-842 2283127 2283510 2283539 "ORDFIN" 2283544 T ORDFIN (NIL) -9 NIL 2283565) (-841 2279639 2281719 2282125 "ORDCOMP" 2282754 NIL ORDCOMP (NIL T) -8 NIL NIL) (-840 2278905 2279032 2279218 "ORDCOMP2" 2279499 NIL ORDCOMP2 (NIL T T) -7 NIL NIL) (-839 2275413 2276295 2277132 "OPTPROB" 2278088 T OPTPROB (NIL) -8 NIL NIL) (-838 2272215 2272854 2273558 "OPTPACK" 2274729 T OPTPACK (NIL) -7 NIL NIL) (-837 2269927 2270667 2270696 "OPTCAT" 2271515 T OPTCAT (NIL) -9 NIL 2272165) (-836 2269695 2269734 2269800 "OPQUERY" 2269881 T OPQUERY (NIL) -7 NIL NIL) (-835 2266821 2268012 2268513 "OP" 2269227 NIL OP (NIL T) -8 NIL NIL) (-834 2263586 2265624 2265990 "ONECOMP" 2266488 NIL ONECOMP (NIL T) -8 NIL NIL) (-833 2262891 2263006 2263180 "ONECOMP2" 2263458 NIL ONECOMP2 (NIL T T) -7 NIL NIL) (-832 2262310 2262416 2262546 "OMSERVER" 2262781 T OMSERVER (NIL) -7 NIL NIL) (-831 2259197 2261749 2261790 "OMSAGG" 2261851 NIL OMSAGG (NIL T) -9 NIL 2261915) (-830 2257820 2258083 2258365 "OMPKG" 2258935 T OMPKG (NIL) -7 NIL NIL) (-829 2257249 2257352 2257381 "OM" 2257680 T OM (NIL) -9 NIL NIL) (-828 2255787 2256800 2256968 "OMLO" 2257131 NIL OMLO (NIL T T) -8 NIL NIL) (-827 2254712 2254859 2255086 "OMEXPR" 2255613 NIL OMEXPR (NIL T) -7 NIL NIL) (-826 2254030 2254258 2254394 "OMERR" 2254596 T OMERR (NIL) -8 NIL NIL) (-825 2253208 2253451 2253611 "OMERRK" 2253890 T OMERRK (NIL) -8 NIL NIL) (-824 2252686 2252885 2252993 "OMENC" 2253120 T OMENC (NIL) -8 NIL NIL) (-823 2246581 2247766 2248937 "OMDEV" 2251535 T OMDEV (NIL) -8 NIL NIL) (-822 2245650 2245821 2246015 "OMCONN" 2246407 T OMCONN (NIL) -8 NIL NIL) (-821 2244261 2245247 2245276 "OINTDOM" 2245281 T OINTDOM (NIL) -9 NIL 2245302) (-820 2239912 2241167 2241911 "OFMONOID" 2243549 NIL OFMONOID (NIL T) -8 NIL NIL) (-819 2239350 2239849 2239894 "ODVAR" 2239899 NIL ODVAR (NIL T) -8 NIL NIL) (-818 2236477 2238849 2239033 "ODR" 2239226 NIL ODR (NIL T T NIL) -8 NIL NIL) (-817 2228775 2236253 2236379 "ODPOL" 2236384 NIL ODPOL (NIL T) -8 NIL NIL) (-816 2222526 2228647 2228752 "ODP" 2228757 NIL ODP (NIL NIL T NIL) -8 NIL NIL) (-815 2221292 2221507 2221782 "ODETOOLS" 2222300 NIL ODETOOLS (NIL T T) -7 NIL NIL) (-814 2218261 2218917 2219633 "ODESYS" 2220625 NIL ODESYS (NIL T T) -7 NIL NIL) (-813 2213145 2214053 2215077 "ODERTRIC" 2217337 NIL ODERTRIC (NIL T T) -7 NIL NIL) (-812 2212571 2212653 2212847 "ODERED" 2213057 NIL ODERED (NIL T T T T T) -7 NIL NIL) (-811 2209459 2210007 2210684 "ODERAT" 2211994 NIL ODERAT (NIL T T) -7 NIL NIL) (-810 2206419 2206883 2207480 "ODEPRRIC" 2208988 NIL ODEPRRIC (NIL T T T T) -7 NIL NIL) (-809 2204290 2204857 2205366 "ODEPROB" 2205930 T ODEPROB (NIL) -8 NIL NIL) (-808 2200812 2201295 2201942 "ODEPRIM" 2203769 NIL ODEPRIM (NIL T T T T) -7 NIL NIL) (-807 2200061 2200163 2200423 "ODEPAL" 2200704 NIL ODEPAL (NIL T T T T) -7 NIL NIL) (-806 2196223 2197014 2197878 "ODEPACK" 2199217 T ODEPACK (NIL) -7 NIL NIL) (-805 2195256 2195363 2195592 "ODEINT" 2196112 NIL ODEINT (NIL T T) -7 NIL NIL) (-804 2189357 2190782 2192229 "ODEIFTBL" 2193829 T ODEIFTBL (NIL) -8 NIL NIL) (-803 2184692 2185478 2186437 "ODEEF" 2188516 NIL ODEEF (NIL T T) -7 NIL NIL) (-802 2184027 2184116 2184346 "ODECONST" 2184597 NIL ODECONST (NIL T T T) -7 NIL NIL) (-801 2182177 2182812 2182841 "ODECAT" 2183446 T ODECAT (NIL) -9 NIL 2183977) (-800 2178976 2181882 2182004 "OCT" 2182087 NIL OCT (NIL T) -8 NIL NIL) (-799 2178614 2178657 2178784 "OCTCT2" 2178927 NIL OCTCT2 (NIL T T T T) -7 NIL NIL) (-798 2173394 2175882 2175923 "OC" 2177020 NIL OC (NIL T) -9 NIL 2177870) (-797 2170621 2171369 2172359 "OC-" 2172453 NIL OC- (NIL T T) -8 NIL NIL) (-796 2169998 2170440 2170469 "OCAMON" 2170474 T OCAMON (NIL) -9 NIL 2170495) (-795 2169450 2169857 2169886 "OASGP" 2169891 T OASGP (NIL) -9 NIL 2169911) (-794 2168736 2169199 2169228 "OAMONS" 2169268 T OAMONS (NIL) -9 NIL 2169311) (-793 2168175 2168582 2168611 "OAMON" 2168616 T OAMON (NIL) -9 NIL 2168636) (-792 2167478 2167970 2167999 "OAGROUP" 2168004 T OAGROUP (NIL) -9 NIL 2168024) (-791 2167168 2167218 2167306 "NUMTUBE" 2167422 NIL NUMTUBE (NIL T) -7 NIL NIL) (-790 2160741 2162259 2163795 "NUMQUAD" 2165652 T NUMQUAD (NIL) -7 NIL NIL) (-789 2156497 2157485 2158510 "NUMODE" 2159736 T NUMODE (NIL) -7 NIL NIL) (-788 2153877 2154731 2154760 "NUMINT" 2155683 T NUMINT (NIL) -9 NIL 2156447) (-787 2152825 2153022 2153240 "NUMFMT" 2153679 T NUMFMT (NIL) -7 NIL NIL) (-786 2139203 2142145 2144669 "NUMERIC" 2150340 NIL NUMERIC (NIL T) -7 NIL NIL) (-785 2133606 2138651 2138747 "NTSCAT" 2138752 NIL NTSCAT (NIL T T T T) -9 NIL 2138791) (-784 2132802 2132967 2133159 "NTPOLFN" 2133446 NIL NTPOLFN (NIL T) -7 NIL NIL) (-783 2120598 2129629 2130440 "NSUP" 2132024 NIL NSUP (NIL T) -8 NIL NIL) (-782 2120230 2120287 2120396 "NSUP2" 2120535 NIL NSUP2 (NIL T T) -7 NIL NIL) (-781 2110179 2120004 2120137 "NSMP" 2120142 NIL NSMP (NIL T T) -8 NIL NIL) (-780 2098271 2109761 2109925 "NSDPS" 2110047 NIL NSDPS (NIL T) -8 NIL NIL) (-779 2096703 2097004 2097361 "NREP" 2097959 NIL NREP (NIL T) -7 NIL NIL) (-778 2093792 2094340 2094989 "NPOLYGON" 2096145 NIL NPOLYGON (NIL T T T NIL) -7 NIL NIL) (-777 2092383 2092635 2092993 "NPCOEF" 2093535 NIL NPCOEF (NIL T T T T T) -7 NIL NIL) (-776 2091665 2092167 2092251 "NOTTING" 2092331 NIL NOTTING (NIL T) -8 NIL NIL) (-775 2090731 2090846 2091062 "NORMRETR" 2091546 NIL NORMRETR (NIL T T T T NIL) -7 NIL NIL) (-774 2088772 2089062 2089471 "NORMPK" 2090439 NIL NORMPK (NIL T T T T T) -7 NIL NIL) (-773 2088457 2088485 2088609 "NORMMA" 2088738 NIL NORMMA (NIL T T T T) -7 NIL NIL) (-772 2088284 2088414 2088443 "NONE" 2088448 T NONE (NIL) -8 NIL NIL) (-771 2088073 2088102 2088171 "NONE1" 2088248 NIL NONE1 (NIL T) -7 NIL NIL) (-770 2087556 2087618 2087804 "NODE1" 2088005 NIL NODE1 (NIL T T) -7 NIL NIL) (-769 2085850 2086719 2086974 "NNI" 2087321 T NNI (NIL) -8 NIL NIL) (-768 2084270 2084583 2084947 "NLINSOL" 2085518 NIL NLINSOL (NIL T) -7 NIL NIL) (-767 2080438 2081405 2082327 "NIPROB" 2083368 T NIPROB (NIL) -8 NIL NIL) (-766 2079195 2079429 2079731 "NFINTBAS" 2080200 NIL NFINTBAS (NIL T T) -7 NIL NIL) (-765 2078924 2078967 2079048 "NEWTON" 2079146 NIL NEWTON (NIL T) -7 NIL NIL) (-764 2077632 2077863 2078144 "NCODIV" 2078692 NIL NCODIV (NIL T T) -7 NIL NIL) (-763 2077394 2077431 2077506 "NCNTFRAC" 2077589 NIL NCNTFRAC (NIL T) -7 NIL NIL) (-762 2075574 2075938 2076358 "NCEP" 2077019 NIL NCEP (NIL T) -7 NIL NIL) (-761 2074484 2075223 2075252 "NASRING" 2075362 T NASRING (NIL) -9 NIL 2075436) (-760 2074279 2074323 2074417 "NASRING-" 2074422 NIL NASRING- (NIL T) -8 NIL NIL) (-759 2073431 2073930 2073959 "NARNG" 2074076 T NARNG (NIL) -9 NIL 2074167) (-758 2073123 2073190 2073324 "NARNG-" 2073329 NIL NARNG- (NIL T) -8 NIL NIL) (-757 2072002 2072209 2072444 "NAGSP" 2072908 T NAGSP (NIL) -7 NIL NIL) (-756 2063274 2064958 2066631 "NAGS" 2070349 T NAGS (NIL) -7 NIL NIL) (-755 2061822 2062130 2062461 "NAGF07" 2062963 T NAGF07 (NIL) -7 NIL NIL) (-754 2056360 2057651 2058958 "NAGF04" 2060535 T NAGF04 (NIL) -7 NIL NIL) (-753 2049328 2050942 2052575 "NAGF02" 2054747 T NAGF02 (NIL) -7 NIL NIL) (-752 2044552 2045652 2046769 "NAGF01" 2048231 T NAGF01 (NIL) -7 NIL NIL) (-751 2038180 2039746 2041331 "NAGE04" 2042987 T NAGE04 (NIL) -7 NIL NIL) (-750 2029349 2031470 2033600 "NAGE02" 2036070 T NAGE02 (NIL) -7 NIL NIL) (-749 2025302 2026249 2027213 "NAGE01" 2028405 T NAGE01 (NIL) -7 NIL NIL) (-748 2023097 2023631 2024189 "NAGD03" 2024764 T NAGD03 (NIL) -7 NIL NIL) (-747 2014847 2016775 2018729 "NAGD02" 2021163 T NAGD02 (NIL) -7 NIL NIL) (-746 2008658 2010083 2011523 "NAGD01" 2013427 T NAGD01 (NIL) -7 NIL NIL) (-745 2004867 2005689 2006526 "NAGC06" 2007841 T NAGC06 (NIL) -7 NIL NIL) (-744 2003332 2003664 2004020 "NAGC05" 2004531 T NAGC05 (NIL) -7 NIL NIL) (-743 2002708 2002827 2002971 "NAGC02" 2003208 T NAGC02 (NIL) -7 NIL NIL) (-742 2001767 2002324 2002365 "NAALG" 2002444 NIL NAALG (NIL T) -9 NIL 2002505) (-741 2001602 2001631 2001721 "NAALG-" 2001726 NIL NAALG- (NIL T T) -8 NIL NIL) (-740 1992478 2000718 2000993 "MYUP" 2001373 NIL MYUP (NIL NIL T) -8 NIL NIL) (-739 1982841 1990934 1991305 "MYEXPR" 1992173 NIL MYEXPR (NIL NIL T) -8 NIL NIL) (-738 1976791 1977899 1979086 "MULTSQFR" 1981737 NIL MULTSQFR (NIL T T T T) -7 NIL NIL) (-737 1976110 1976185 1976369 "MULTFACT" 1976703 NIL MULTFACT (NIL T T T T) -7 NIL NIL) (-736 1969235 1973144 1973198 "MTSCAT" 1974268 NIL MTSCAT (NIL T T) -9 NIL 1974782) (-735 1968947 1969001 1969093 "MTHING" 1969175 NIL MTHING (NIL T) -7 NIL NIL) (-734 1968739 1968772 1968832 "MSYSCMD" 1968907 T MSYSCMD (NIL) -7 NIL NIL) (-733 1964851 1967494 1967814 "MSET" 1968452 NIL MSET (NIL T) -8 NIL NIL) (-732 1961945 1964411 1964453 "MSETAGG" 1964458 NIL MSETAGG (NIL T) -9 NIL 1964492) (-731 1957723 1959336 1960075 "MRING" 1961251 NIL MRING (NIL T T) -8 NIL NIL) (-730 1957289 1957356 1957487 "MRF2" 1957650 NIL MRF2 (NIL T T T) -7 NIL NIL) (-729 1956907 1956942 1957086 "MRATFAC" 1957248 NIL MRATFAC (NIL T T T T) -7 NIL NIL) (-728 1954519 1954814 1955245 "MPRFF" 1956612 NIL MPRFF (NIL T T T T) -7 NIL NIL) (-727 1948533 1954373 1954470 "MPOLY" 1954475 NIL MPOLY (NIL NIL T) -8 NIL NIL) (-726 1948023 1948058 1948266 "MPCPF" 1948492 NIL MPCPF (NIL T T T T) -7 NIL NIL) (-725 1947537 1947580 1947764 "MPC3" 1947974 NIL MPC3 (NIL T T T T T T T) -7 NIL NIL) (-724 1946732 1946813 1947034 "MPC2" 1947452 NIL MPC2 (NIL T T T T T T T) -7 NIL NIL) (-723 1945033 1945370 1945760 "MONOTOOL" 1946392 NIL MONOTOOL (NIL T T) -7 NIL NIL) (-722 1944156 1944491 1944520 "MONOID" 1944797 T MONOID (NIL) -9 NIL 1944969) (-721 1943534 1943697 1943940 "MONOID-" 1943945 NIL MONOID- (NIL T) -8 NIL NIL) (-720 1934415 1940445 1940505 "MONOGEN" 1941179 NIL MONOGEN (NIL T T) -9 NIL 1941632) (-719 1931633 1932368 1933368 "MONOGEN-" 1933487 NIL MONOGEN- (NIL T T T) -8 NIL NIL) (-718 1930491 1930911 1930940 "MONADWU" 1931332 T MONADWU (NIL) -9 NIL 1931570) (-717 1929863 1930022 1930270 "MONADWU-" 1930275 NIL MONADWU- (NIL T) -8 NIL NIL) (-716 1929247 1929465 1929494 "MONAD" 1929701 T MONAD (NIL) -9 NIL 1929813) (-715 1928932 1929010 1929142 "MONAD-" 1929147 NIL MONAD- (NIL T) -8 NIL NIL) (-714 1927183 1927845 1928124 "MOEBIUS" 1928685 NIL MOEBIUS (NIL T) -8 NIL NIL) (-713 1926574 1926952 1926993 "MODULE" 1926998 NIL MODULE (NIL T) -9 NIL 1927024) (-712 1926142 1926238 1926428 "MODULE-" 1926433 NIL MODULE- (NIL T T) -8 NIL NIL) (-711 1923811 1924506 1924833 "MODRING" 1925966 NIL MODRING (NIL T T NIL NIL NIL) -8 NIL NIL) (-710 1920757 1921922 1922440 "MODOP" 1923343 NIL MODOP (NIL T T) -8 NIL NIL) (-709 1918944 1919396 1919737 "MODMONOM" 1920556 NIL MODMONOM (NIL T T NIL) -8 NIL NIL) (-708 1908564 1917140 1917561 "MODMON" 1918574 NIL MODMON (NIL T T) -8 NIL NIL) (-707 1905690 1907408 1907684 "MODFIELD" 1908439 NIL MODFIELD (NIL T T NIL NIL NIL) -8 NIL NIL) (-706 1904694 1904971 1905161 "MMLFORM" 1905520 T MMLFORM (NIL) -8 NIL NIL) (-705 1904220 1904263 1904442 "MMAP" 1904645 NIL MMAP (NIL T T T T T T) -7 NIL NIL) (-704 1902445 1903222 1903264 "MLO" 1903687 NIL MLO (NIL T) -9 NIL 1903928) (-703 1899812 1900327 1900929 "MLIFT" 1901926 NIL MLIFT (NIL T T T T) -7 NIL NIL) (-702 1899203 1899287 1899441 "MKUCFUNC" 1899723 NIL MKUCFUNC (NIL T T T) -7 NIL NIL) (-701 1898802 1898872 1898995 "MKRECORD" 1899126 NIL MKRECORD (NIL T T) -7 NIL NIL) (-700 1897850 1898011 1898239 "MKFUNC" 1898613 NIL MKFUNC (NIL T) -7 NIL NIL) (-699 1897238 1897342 1897498 "MKFLCFN" 1897733 NIL MKFLCFN (NIL T) -7 NIL NIL) (-698 1896664 1897031 1897120 "MKCHSET" 1897182 NIL MKCHSET (NIL T) -8 NIL NIL) (-697 1895941 1896043 1896228 "MKBCFUNC" 1896557 NIL MKBCFUNC (NIL T T T T) -7 NIL NIL) (-696 1892625 1895495 1895631 "MINT" 1895825 T MINT (NIL) -8 NIL NIL) (-695 1891437 1891680 1891957 "MHROWRED" 1892380 NIL MHROWRED (NIL T) -7 NIL NIL) (-694 1886704 1889878 1890304 "MFLOAT" 1891031 T MFLOAT (NIL) -8 NIL NIL) (-693 1886061 1886137 1886308 "MFINFACT" 1886616 NIL MFINFACT (NIL T T T T) -7 NIL NIL) (-692 1882376 1883224 1884108 "MESH" 1885197 T MESH (NIL) -7 NIL NIL) (-691 1880766 1881078 1881431 "MDDFACT" 1882063 NIL MDDFACT (NIL T) -7 NIL NIL) (-690 1877648 1879959 1880001 "MDAGG" 1880256 NIL MDAGG (NIL T) -9 NIL 1880399) (-689 1867289 1876941 1877148 "MCMPLX" 1877461 T MCMPLX (NIL) -8 NIL NIL) (-688 1866426 1866572 1866773 "MCDEN" 1867138 NIL MCDEN (NIL T T) -7 NIL NIL) (-687 1864316 1864586 1864966 "MCALCFN" 1866156 NIL MCALCFN (NIL T T T T) -7 NIL NIL) (-686 1861928 1862451 1863013 "MATSTOR" 1863787 NIL MATSTOR (NIL T) -7 NIL NIL) (-685 1857794 1861304 1861550 "MATRIX" 1861715 NIL MATRIX (NIL T) -8 NIL NIL) (-684 1853570 1854273 1855006 "MATLIN" 1857154 NIL MATLIN (NIL T T T T) -7 NIL NIL) (-683 1843081 1846349 1846427 "MATCAT" 1851709 NIL MATCAT (NIL T T T) -9 NIL 1853271) (-682 1839119 1840234 1841702 "MATCAT-" 1841707 NIL MATCAT- (NIL T T T T) -8 NIL NIL) (-681 1837713 1837866 1838199 "MATCAT2" 1838954 NIL MATCAT2 (NIL T T T T T T T T) -7 NIL NIL) (-680 1836453 1836719 1837034 "MAPPKG4" 1837444 NIL MAPPKG4 (NIL T T) -7 NIL NIL) (-679 1834565 1834889 1835273 "MAPPKG3" 1836128 NIL MAPPKG3 (NIL T T T) -7 NIL NIL) (-678 1833546 1833719 1833941 "MAPPKG2" 1834389 NIL MAPPKG2 (NIL T T) -7 NIL NIL) (-677 1832045 1832329 1832656 "MAPPKG1" 1833252 NIL MAPPKG1 (NIL T) -7 NIL NIL) (-676 1831656 1831714 1831837 "MAPHACK3" 1831981 NIL MAPHACK3 (NIL T T T) -7 NIL NIL) (-675 1831248 1831309 1831423 "MAPHACK2" 1831588 NIL MAPHACK2 (NIL T T) -7 NIL NIL) (-674 1830686 1830789 1830931 "MAPHACK1" 1831139 NIL MAPHACK1 (NIL T) -7 NIL NIL) (-673 1823854 1824795 1825892 "MAMA" 1829682 NIL MAMA (NIL T T T T) -7 NIL NIL) (-672 1821960 1822554 1822858 "MAGMA" 1823582 NIL MAGMA (NIL T) -8 NIL NIL) (-671 1820196 1820568 1820623 "MAGCDOC" 1821560 NIL MAGCDOC (NIL T T) -9 NIL NIL) (-670 1816671 1818437 1818897 "M3D" 1819769 NIL M3D (NIL T) -8 NIL NIL) (-669 1810865 1815071 1815113 "LZSTAGG" 1815895 NIL LZSTAGG (NIL T) -9 NIL 1816190) (-668 1806839 1807996 1809453 "LZSTAGG-" 1809458 NIL LZSTAGG- (NIL T T) -8 NIL NIL) (-667 1803953 1804730 1805217 "LWORD" 1806384 NIL LWORD (NIL T) -8 NIL NIL) (-666 1797108 1803724 1803858 "LSQM" 1803863 NIL LSQM (NIL NIL T) -8 NIL NIL) (-665 1796332 1796471 1796699 "LSPP" 1796963 NIL LSPP (NIL T T T T) -7 NIL NIL) (-664 1794144 1794445 1794901 "LSMP" 1796021 NIL LSMP (NIL T T T T) -7 NIL NIL) (-663 1790923 1791597 1792327 "LSMP1" 1793446 NIL LSMP1 (NIL T) -7 NIL NIL) (-662 1784880 1790113 1790155 "LSAGG" 1790217 NIL LSAGG (NIL T) -9 NIL 1790295) (-661 1781575 1782499 1783712 "LSAGG-" 1783717 NIL LSAGG- (NIL T T) -8 NIL NIL) (-660 1779201 1780719 1780968 "LPOLY" 1781370 NIL LPOLY (NIL T T) -8 NIL NIL) (-659 1778783 1778868 1778991 "LPEFRAC" 1779110 NIL LPEFRAC (NIL T) -7 NIL NIL) (-658 1776347 1776596 1777028 "LPARSPT" 1778525 NIL LPARSPT (NIL T NIL T T T T T) -7 NIL NIL) (-657 1774822 1775149 1775509 "LOP" 1776019 NIL LOP (NIL T) -7 NIL NIL) (-656 1773171 1773918 1774170 "LO" 1774655 NIL LO (NIL T T T) -8 NIL NIL) (-655 1772822 1772934 1772963 "LOGIC" 1773074 T LOGIC (NIL) -9 NIL 1773155) (-654 1772684 1772707 1772778 "LOGIC-" 1772783 NIL LOGIC- (NIL T) -8 NIL NIL) (-653 1771877 1772017 1772210 "LODOOPS" 1772540 NIL LODOOPS (NIL T T) -7 NIL NIL) (-652 1769289 1771793 1771859 "LODO" 1771864 NIL LODO (NIL T NIL) -8 NIL NIL) (-651 1767829 1768064 1768416 "LODOF" 1769037 NIL LODOF (NIL T T) -7 NIL NIL) (-650 1764228 1766669 1766711 "LODOCAT" 1767149 NIL LODOCAT (NIL T) -9 NIL 1767359) (-649 1763961 1764019 1764146 "LODOCAT-" 1764151 NIL LODOCAT- (NIL T T) -8 NIL NIL) (-648 1761270 1763802 1763920 "LODO2" 1763925 NIL LODO2 (NIL T T) -8 NIL NIL) (-647 1758694 1761207 1761252 "LODO1" 1761257 NIL LODO1 (NIL T) -8 NIL NIL) (-646 1757554 1757719 1758031 "LODEEF" 1758517 NIL LODEEF (NIL T T T) -7 NIL NIL) (-645 1750381 1754546 1754587 "LOCPOWC" 1756049 NIL LOCPOWC (NIL T) -9 NIL 1756626) (-644 1745705 1748543 1748585 "LNAGG" 1749532 NIL LNAGG (NIL T) -9 NIL 1749975) (-643 1744852 1745066 1745408 "LNAGG-" 1745413 NIL LNAGG- (NIL T T) -8 NIL NIL) (-642 1741015 1741777 1742416 "LMOPS" 1744267 NIL LMOPS (NIL T T NIL) -8 NIL NIL) (-641 1740409 1740771 1740813 "LMODULE" 1740874 NIL LMODULE (NIL T) -9 NIL 1740916) (-640 1737661 1740054 1740177 "LMDICT" 1740319 NIL LMDICT (NIL T) -8 NIL NIL) (-639 1736818 1736952 1737139 "LISYSER" 1737523 NIL LISYSER (NIL T T) -7 NIL NIL) (-638 1730055 1735768 1736064 "LIST" 1736555 NIL LIST (NIL T) -8 NIL NIL) (-637 1729580 1729654 1729793 "LIST3" 1729975 NIL LIST3 (NIL T T T) -7 NIL NIL) (-636 1728587 1728765 1728993 "LIST2" 1729398 NIL LIST2 (NIL T T) -7 NIL NIL) (-635 1726721 1727033 1727432 "LIST2MAP" 1728234 NIL LIST2MAP (NIL T T) -7 NIL NIL) (-634 1725426 1726106 1726148 "LINEXP" 1726403 NIL LINEXP (NIL T) -9 NIL 1726552) (-633 1724073 1724333 1724630 "LINDEP" 1725178 NIL LINDEP (NIL T T) -7 NIL NIL) (-632 1720840 1721559 1722336 "LIMITRF" 1723328 NIL LIMITRF (NIL T) -7 NIL NIL) (-631 1719116 1719411 1719827 "LIMITPS" 1720535 NIL LIMITPS (NIL T T) -7 NIL NIL) (-630 1713575 1718631 1718857 "LIE" 1718939 NIL LIE (NIL T T) -8 NIL NIL) (-629 1712624 1713067 1713108 "LIECAT" 1713248 NIL LIECAT (NIL T) -9 NIL 1713398) (-628 1712465 1712492 1712580 "LIECAT-" 1712585 NIL LIECAT- (NIL T T) -8 NIL NIL) (-627 1704999 1711844 1712027 "LIB" 1712302 T LIB (NIL) -8 NIL NIL) (-626 1700636 1701517 1702452 "LGROBP" 1704116 NIL LGROBP (NIL NIL T) -7 NIL NIL) (-625 1698117 1698441 1698852 "LF" 1700309 NIL LF (NIL T T) -7 NIL NIL) (-624 1696814 1697544 1697573 "LFCAT" 1697848 T LFCAT (NIL) -9 NIL 1698023) (-623 1693718 1694346 1695034 "LEXTRIPK" 1696178 NIL LEXTRIPK (NIL T NIL) -7 NIL NIL) (-622 1690424 1691288 1691791 "LEXP" 1693298 NIL LEXP (NIL T T NIL) -8 NIL NIL) (-621 1688822 1689135 1689536 "LEADCDET" 1690106 NIL LEADCDET (NIL T T T T) -7 NIL NIL) (-620 1688012 1688086 1688315 "LAZM3PK" 1688743 NIL LAZM3PK (NIL T T T T T T) -7 NIL NIL) (-619 1682928 1686095 1686630 "LAUPOL" 1687527 NIL LAUPOL (NIL T T) -8 NIL NIL) (-618 1682493 1682537 1682705 "LAPLACE" 1682878 NIL LAPLACE (NIL T T) -7 NIL NIL) (-617 1680423 1681596 1681846 "LA" 1682327 NIL LA (NIL T T T) -8 NIL NIL) (-616 1679479 1680073 1680115 "LALG" 1680177 NIL LALG (NIL T) -9 NIL 1680236) (-615 1679193 1679252 1679388 "LALG-" 1679393 NIL LALG- (NIL T T) -8 NIL NIL) (-614 1678097 1678284 1678583 "KOVACIC" 1678993 NIL KOVACIC (NIL T T) -7 NIL NIL) (-613 1677931 1677955 1677997 "KONVERT" 1678059 NIL KONVERT (NIL T) -9 NIL NIL) (-612 1677765 1677789 1677831 "KOERCE" 1677893 NIL KOERCE (NIL T) -9 NIL NIL) (-611 1675501 1676261 1676653 "KERNEL" 1677405 NIL KERNEL (NIL T) -8 NIL NIL) (-610 1675003 1675084 1675214 "KERNEL2" 1675415 NIL KERNEL2 (NIL T T) -7 NIL NIL) (-609 1668686 1673368 1673423 "KDAGG" 1673800 NIL KDAGG (NIL T T) -9 NIL 1674006) (-608 1668215 1668339 1668544 "KDAGG-" 1668549 NIL KDAGG- (NIL T T T) -8 NIL NIL) (-607 1661364 1667876 1668031 "KAFILE" 1668093 NIL KAFILE (NIL T) -8 NIL NIL) (-606 1655823 1660879 1661105 "JORDAN" 1661187 NIL JORDAN (NIL T T) -8 NIL NIL) (-605 1652166 1654066 1654121 "IXAGG" 1655050 NIL IXAGG (NIL T T) -9 NIL 1655505) (-604 1651085 1651391 1651810 "IXAGG-" 1651815 NIL IXAGG- (NIL T T T) -8 NIL NIL) (-603 1646669 1651007 1651066 "IVECTOR" 1651071 NIL IVECTOR (NIL T NIL) -8 NIL NIL) (-602 1645435 1645672 1645938 "ITUPLE" 1646436 NIL ITUPLE (NIL T) -8 NIL NIL) (-601 1643859 1644036 1644344 "ITRIGMNP" 1645257 NIL ITRIGMNP (NIL T T T) -7 NIL NIL) (-600 1642604 1642808 1643091 "ITFUN3" 1643635 NIL ITFUN3 (NIL T T T) -7 NIL NIL) (-599 1642236 1642293 1642402 "ITFUN2" 1642541 NIL ITFUN2 (NIL T T) -7 NIL NIL) (-598 1640029 1641100 1641398 "ITAYLOR" 1641971 NIL ITAYLOR (NIL T) -8 NIL NIL) (-597 1628968 1634168 1635330 "ISUPS" 1638900 NIL ISUPS (NIL T) -8 NIL NIL) (-596 1628072 1628212 1628448 "ISUMP" 1628815 NIL ISUMP (NIL T T T T) -7 NIL NIL) (-595 1623342 1627873 1627952 "ISTRING" 1628025 NIL ISTRING (NIL NIL) -8 NIL NIL) (-594 1622552 1622633 1622849 "IRURPK" 1623256 NIL IRURPK (NIL T T T T T) -7 NIL NIL) (-593 1621488 1621689 1621929 "IRSN" 1622332 T IRSN (NIL) -7 NIL NIL) (-592 1619519 1619874 1620309 "IRRF2F" 1621127 NIL IRRF2F (NIL T) -7 NIL NIL) (-591 1619266 1619304 1619380 "IRREDFFX" 1619475 NIL IRREDFFX (NIL T) -7 NIL NIL) (-590 1617881 1618140 1618439 "IROOT" 1618999 NIL IROOT (NIL T) -7 NIL NIL) (-589 1614517 1615569 1616259 "IR" 1617223 NIL IR (NIL T) -8 NIL NIL) (-588 1612130 1612625 1613191 "IR2" 1613995 NIL IR2 (NIL T T) -7 NIL NIL) (-587 1611202 1611315 1611536 "IR2F" 1612013 NIL IR2F (NIL T T) -7 NIL NIL) (-586 1610993 1611027 1611087 "IPRNTPK" 1611162 T IPRNTPK (NIL) -7 NIL NIL) (-585 1607522 1610882 1610951 "IPF" 1610956 NIL IPF (NIL NIL) -8 NIL NIL) (-584 1605839 1607447 1607504 "IPADIC" 1607509 NIL IPADIC (NIL NIL NIL) -8 NIL NIL) (-583 1605336 1605394 1605584 "INVLAPLA" 1605775 NIL INVLAPLA (NIL T T) -7 NIL NIL) (-582 1594985 1597338 1599724 "INTTR" 1603000 NIL INTTR (NIL T T) -7 NIL NIL) (-581 1591343 1592085 1592942 "INTTOOLS" 1594177 NIL INTTOOLS (NIL T T) -7 NIL NIL) (-580 1590929 1591020 1591137 "INTSLPE" 1591246 T INTSLPE (NIL) -7 NIL NIL) (-579 1588879 1590852 1590911 "INTRVL" 1590916 NIL INTRVL (NIL T) -8 NIL NIL) (-578 1586481 1586993 1587568 "INTRF" 1588364 NIL INTRF (NIL T) -7 NIL NIL) (-577 1585892 1585989 1586131 "INTRET" 1586379 NIL INTRET (NIL T) -7 NIL NIL) (-576 1583889 1584278 1584748 "INTRAT" 1585500 NIL INTRAT (NIL T T) -7 NIL NIL) (-575 1581125 1581708 1582330 "INTPM" 1583378 NIL INTPM (NIL T T) -7 NIL NIL) (-574 1577830 1578429 1579173 "INTPAF" 1580512 NIL INTPAF (NIL T T T) -7 NIL NIL) (-573 1573009 1573971 1575022 "INTPACK" 1576799 T INTPACK (NIL) -7 NIL NIL) (-572 1569863 1572738 1572865 "INT" 1572902 T INT (NIL) -8 NIL NIL) (-571 1569115 1569267 1569475 "INTHERTR" 1569705 NIL INTHERTR (NIL T T) -7 NIL NIL) (-570 1568554 1568634 1568822 "INTHERAL" 1569029 NIL INTHERAL (NIL T T T T) -7 NIL NIL) (-569 1566400 1566843 1567300 "INTHEORY" 1568117 T INTHEORY (NIL) -7 NIL NIL) (-568 1557711 1559331 1561109 "INTG0" 1564753 NIL INTG0 (NIL T T T) -7 NIL NIL) (-567 1538284 1543074 1547884 "INTFTBL" 1552921 T INTFTBL (NIL) -8 NIL NIL) (-566 1536321 1536528 1536929 "INTFRSP" 1538074 NIL INTFRSP (NIL T NIL T T T T T T) -7 NIL NIL) (-565 1535570 1535708 1535881 "INTFACT" 1536180 NIL INTFACT (NIL T) -7 NIL NIL) (-564 1535160 1535202 1535353 "INTERGB" 1535522 NIL INTERGB (NIL T NIL T T T) -7 NIL NIL) (-563 1532545 1532991 1533555 "INTEF" 1534714 NIL INTEF (NIL T T) -7 NIL NIL) (-562 1531002 1531751 1531780 "INTDOM" 1532081 T INTDOM (NIL) -9 NIL 1532288) (-561 1530371 1530545 1530787 "INTDOM-" 1530792 NIL INTDOM- (NIL T) -8 NIL NIL) (-560 1528975 1529080 1529470 "INTDIVP" 1530261 NIL INTDIVP (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-559 1525461 1527391 1527446 "INTCAT" 1528245 NIL INTCAT (NIL T) -9 NIL 1528566) (-558 1524934 1525036 1525164 "INTBIT" 1525353 T INTBIT (NIL) -7 NIL NIL) (-557 1523605 1523759 1524073 "INTALG" 1524779 NIL INTALG (NIL T T T T T) -7 NIL NIL) (-556 1523062 1523152 1523322 "INTAF" 1523509 NIL INTAF (NIL T T) -7 NIL NIL) (-555 1516528 1522872 1523012 "INTABL" 1523017 NIL INTABL (NIL T T T) -8 NIL NIL) (-554 1511473 1514199 1514228 "INS" 1515196 T INS (NIL) -9 NIL 1515879) (-553 1508713 1509484 1510458 "INS-" 1510531 NIL INS- (NIL T) -8 NIL NIL) (-552 1507488 1507715 1508013 "INPSIGN" 1508466 NIL INPSIGN (NIL T T) -7 NIL NIL) (-551 1506606 1506723 1506920 "INPRODPF" 1507368 NIL INPRODPF (NIL T T) -7 NIL NIL) (-550 1505500 1505617 1505854 "INPRODFF" 1506486 NIL INPRODFF (NIL T T T T) -7 NIL NIL) (-549 1504500 1504652 1504912 "INNMFACT" 1505336 NIL INNMFACT (NIL T T T T) -7 NIL NIL) (-548 1503697 1503794 1503982 "INMODGCD" 1504399 NIL INMODGCD (NIL T T NIL NIL) -7 NIL NIL) (-547 1502206 1502450 1502774 "INFSP" 1503442 NIL INFSP (NIL T T T) -7 NIL NIL) (-546 1501390 1501507 1501690 "INFPROD0" 1502086 NIL INFPROD0 (NIL T T) -7 NIL NIL) (-545 1498271 1499455 1499970 "INFORM" 1500883 T INFORM (NIL) -8 NIL NIL) (-544 1497881 1497941 1498039 "INFORM1" 1498206 NIL INFORM1 (NIL T) -7 NIL NIL) (-543 1497404 1497493 1497607 "INFINITY" 1497787 T INFINITY (NIL) -7 NIL NIL) (-542 1495087 1496084 1496427 "INFCLSPT" 1497264 NIL INFCLSPT (NIL T NIL T T T T T T T) -8 NIL NIL) (-541 1492964 1494209 1494503 "INFCLSPS" 1494857 NIL INFCLSPS (NIL T NIL T) -8 NIL NIL) (-540 1485514 1486437 1486658 "INFCLCT" 1492089 NIL INFCLCT (NIL T NIL T T T T T T T) -9 NIL 1492900) (-539 1484132 1484380 1484701 "INEP" 1485262 NIL INEP (NIL T T T) -7 NIL NIL) (-538 1483408 1484029 1484094 "INDE" 1484099 NIL INDE (NIL T) -8 NIL NIL) (-537 1482972 1483040 1483157 "INCRMAPS" 1483335 NIL INCRMAPS (NIL T) -7 NIL NIL) (-536 1478283 1479208 1480152 "INBFF" 1482060 NIL INBFF (NIL T) -7 NIL NIL) (-535 1474630 1478127 1478231 "IMATRIX" 1478236 NIL IMATRIX (NIL T NIL NIL) -8 NIL NIL) (-534 1473340 1473463 1473778 "IMATQF" 1474487 NIL IMATQF (NIL T T T T T T T T) -7 NIL NIL) (-533 1471562 1471789 1472125 "IMATLIN" 1473097 NIL IMATLIN (NIL T T T T) -7 NIL NIL) (-532 1466194 1471486 1471544 "ILIST" 1471549 NIL ILIST (NIL T NIL) -8 NIL NIL) (-531 1464153 1466054 1466167 "IIARRAY2" 1466172 NIL IIARRAY2 (NIL T NIL NIL T T) -8 NIL NIL) (-530 1459469 1464064 1464128 "IFF" 1464133 NIL IFF (NIL NIL NIL) -8 NIL NIL) (-529 1454518 1458761 1458949 "IFARRAY" 1459326 NIL IFARRAY (NIL T NIL) -8 NIL NIL) (-528 1453725 1454422 1454495 "IFAMON" 1454500 NIL IFAMON (NIL T T NIL) -8 NIL NIL) (-527 1453308 1453373 1453428 "IEVALAB" 1453635 NIL IEVALAB (NIL T T) -9 NIL NIL) (-526 1452983 1453051 1453211 "IEVALAB-" 1453216 NIL IEVALAB- (NIL T T T) -8 NIL NIL) (-525 1452641 1452897 1452960 "IDPO" 1452965 NIL IDPO (NIL T T) -8 NIL NIL) (-524 1451918 1452530 1452605 "IDPOAMS" 1452610 NIL IDPOAMS (NIL T T) -8 NIL NIL) (-523 1451252 1451807 1451882 "IDPOAM" 1451887 NIL IDPOAM (NIL T T) -8 NIL NIL) (-522 1450336 1450586 1450640 "IDPC" 1451053 NIL IDPC (NIL T T) -9 NIL 1451202) (-521 1449832 1450228 1450301 "IDPAM" 1450306 NIL IDPAM (NIL T T) -8 NIL NIL) (-520 1449235 1449724 1449797 "IDPAG" 1449802 NIL IDPAG (NIL T T) -8 NIL NIL) (-519 1445490 1446338 1447233 "IDECOMP" 1448392 NIL IDECOMP (NIL NIL NIL) -7 NIL NIL) (-518 1438366 1439415 1440461 "IDEAL" 1444527 NIL IDEAL (NIL T T T T) -8 NIL NIL) (-517 1436383 1437530 1437803 "ICP" 1438157 NIL ICP (NIL T NIL T) -8 NIL NIL) (-516 1435543 1435655 1435855 "ICDEN" 1436267 NIL ICDEN (NIL T T T T) -7 NIL NIL) (-515 1434642 1435023 1435170 "ICARD" 1435416 T ICARD (NIL) -8 NIL NIL) (-514 1432702 1433015 1433420 "IBPTOOLS" 1434319 NIL IBPTOOLS (NIL T T T T) -7 NIL NIL) (-513 1428316 1432322 1432435 "IBITS" 1432621 NIL IBITS (NIL NIL) -8 NIL NIL) (-512 1425039 1425615 1426310 "IBATOOL" 1427733 NIL IBATOOL (NIL T T T) -7 NIL NIL) (-511 1422819 1423280 1423813 "IBACHIN" 1424574 NIL IBACHIN (NIL T T T) -7 NIL NIL) (-510 1420702 1422665 1422768 "IARRAY2" 1422773 NIL IARRAY2 (NIL T NIL NIL) -8 NIL NIL) (-509 1416861 1420628 1420685 "IARRAY1" 1420690 NIL IARRAY1 (NIL T NIL) -8 NIL NIL) (-508 1410791 1415273 1415754 "IAN" 1416400 T IAN (NIL) -8 NIL NIL) (-507 1410302 1410359 1410532 "IALGFACT" 1410728 NIL IALGFACT (NIL T T T T) -7 NIL NIL) (-506 1409829 1409942 1409971 "HYPCAT" 1410178 T HYPCAT (NIL) -9 NIL NIL) (-505 1409367 1409484 1409670 "HYPCAT-" 1409675 NIL HYPCAT- (NIL T) -8 NIL NIL) (-504 1408371 1408648 1408838 "HTMLFORM" 1409197 T HTMLFORM (NIL) -8 NIL NIL) (-503 1405160 1406485 1406527 "HOAGG" 1407508 NIL HOAGG (NIL T) -9 NIL 1408117) (-502 1403754 1404153 1404679 "HOAGG-" 1404684 NIL HOAGG- (NIL T T) -8 NIL NIL) (-501 1397570 1403190 1403358 "HEXADEC" 1403606 T HEXADEC (NIL) -8 NIL NIL) (-500 1396318 1396540 1396803 "HEUGCD" 1397347 NIL HEUGCD (NIL T) -7 NIL NIL) (-499 1395421 1396155 1396285 "HELLFDIV" 1396290 NIL HELLFDIV (NIL T T T T) -8 NIL NIL) (-498 1389138 1390681 1391762 "HEAP" 1394372 NIL HEAP (NIL T) -8 NIL NIL) (-497 1382933 1389053 1389115 "HDP" 1389120 NIL HDP (NIL NIL T) -8 NIL NIL) (-496 1376638 1382568 1382720 "HDMP" 1382834 NIL HDMP (NIL NIL T) -8 NIL NIL) (-495 1375963 1376102 1376266 "HB" 1376494 T HB (NIL) -7 NIL NIL) (-494 1369472 1375809 1375913 "HASHTBL" 1375918 NIL HASHTBL (NIL T T NIL) -8 NIL NIL) (-493 1367219 1369094 1369276 "HACKPI" 1369310 T HACKPI (NIL) -8 NIL NIL) (-492 1349367 1353236 1357239 "GUESSUP" 1363249 NIL GUESSUP (NIL NIL) -7 NIL NIL) (-491 1320464 1327505 1334201 "GUESSP" 1342691 T GUESSP (NIL) -7 NIL NIL) (-490 1287279 1292550 1297934 "GUESS" 1315408 NIL GUESS (NIL T T T T NIL NIL) -7 NIL NIL) (-489 1260784 1267181 1273317 "GUESSINT" 1281163 T GUESSINT (NIL) -7 NIL NIL) (-488 1236155 1241605 1247172 "GUESSF" 1255269 NIL GUESSF (NIL T) -7 NIL NIL) (-487 1235877 1235914 1236009 "GUESSF1" 1236112 NIL GUESSF1 (NIL T) -7 NIL NIL) (-486 1212038 1217572 1223187 "GUESSAN" 1230282 T GUESSAN (NIL) -7 NIL NIL) (-485 1207733 1211891 1212004 "GTSET" 1212009 NIL GTSET (NIL T T T T) -8 NIL NIL) (-484 1201271 1207611 1207709 "GSTBL" 1207714 NIL GSTBL (NIL T T T NIL) -8 NIL NIL) (-483 1193501 1200304 1200568 "GSERIES" 1201063 NIL GSERIES (NIL T NIL NIL) -8 NIL NIL) (-482 1192522 1192975 1193004 "GROUP" 1193265 T GROUP (NIL) -9 NIL 1193424) (-481 1191638 1191861 1192205 "GROUP-" 1192210 NIL GROUP- (NIL T) -8 NIL NIL) (-480 1190007 1190326 1190713 "GROEBSOL" 1191315 NIL GROEBSOL (NIL NIL T T) -7 NIL NIL) (-479 1188946 1189208 1189260 "GRMOD" 1189789 NIL GRMOD (NIL T T) -9 NIL 1189957) (-478 1188714 1188750 1188878 "GRMOD-" 1188883 NIL GRMOD- (NIL T T T) -8 NIL NIL) (-477 1184043 1185068 1186068 "GRIMAGE" 1187734 T GRIMAGE (NIL) -8 NIL NIL) (-476 1182510 1182770 1183094 "GRDEF" 1183739 T GRDEF (NIL) -7 NIL NIL) (-475 1181954 1182070 1182211 "GRAY" 1182389 T GRAY (NIL) -7 NIL NIL) (-474 1181184 1181564 1181616 "GRALG" 1181769 NIL GRALG (NIL T T) -9 NIL 1181862) (-473 1180845 1180918 1181081 "GRALG-" 1181086 NIL GRALG- (NIL T T T) -8 NIL NIL) (-472 1177649 1180430 1180608 "GPOLSET" 1180752 NIL GPOLSET (NIL T T T T) -8 NIL NIL) (-471 1159852 1161342 1162931 "GPAFF" 1176340 NIL GPAFF (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-470 1159206 1159263 1159521 "GOSPER" 1159789 NIL GOSPER (NIL T T T T T) -7 NIL NIL) (-469 1155556 1156392 1157119 "GOPT" 1158499 T GOPT (NIL) -8 NIL NIL) (-468 1151035 1152053 1152961 "GOPT0" 1154668 T GOPT0 (NIL) -8 NIL NIL) (-467 1146794 1147473 1147999 "GMODPOL" 1150734 NIL GMODPOL (NIL NIL T T T NIL T) -8 NIL NIL) (-466 1145799 1145983 1146221 "GHENSEL" 1146606 NIL GHENSEL (NIL T T) -7 NIL NIL) (-465 1139850 1140693 1141720 "GENUPS" 1144883 NIL GENUPS (NIL T T) -7 NIL NIL) (-464 1139547 1139598 1139687 "GENUFACT" 1139793 NIL GENUFACT (NIL T) -7 NIL NIL) (-463 1138959 1139036 1139201 "GENPGCD" 1139465 NIL GENPGCD (NIL T T T T) -7 NIL NIL) (-462 1138433 1138468 1138681 "GENMFACT" 1138918 NIL GENMFACT (NIL T T T T T) -7 NIL NIL) (-461 1137001 1137256 1137563 "GENEEZ" 1138176 NIL GENEEZ (NIL T T) -7 NIL NIL) (-460 1135545 1135822 1136146 "GDRAW" 1136697 T GDRAW (NIL) -7 NIL NIL) (-459 1129412 1135156 1135318 "GDMP" 1135468 NIL GDMP (NIL NIL T T) -8 NIL NIL) (-458 1118796 1123185 1124290 "GCNAALG" 1128396 NIL GCNAALG (NIL T NIL NIL NIL) -8 NIL NIL) (-457 1117213 1118085 1118114 "GCDDOM" 1118369 T GCDDOM (NIL) -9 NIL 1118526) (-456 1116683 1116810 1117025 "GCDDOM-" 1117030 NIL GCDDOM- (NIL T) -8 NIL NIL) (-455 1115357 1115542 1115845 "GB" 1116463 NIL GB (NIL T T T T) -7 NIL NIL) (-454 1103977 1106303 1108695 "GBINTERN" 1113048 NIL GBINTERN (NIL T T T T) -7 NIL NIL) (-453 1101814 1102106 1102527 "GBF" 1103652 NIL GBF (NIL T T T T) -7 NIL NIL) (-452 1100595 1100760 1101027 "GBEUCLID" 1101630 NIL GBEUCLID (NIL T T T T) -7 NIL NIL) (-451 1099944 1100069 1100218 "GAUSSFAC" 1100466 T GAUSSFAC (NIL) -7 NIL NIL) (-450 1098313 1098615 1098928 "GALUTIL" 1099664 NIL GALUTIL (NIL T) -7 NIL NIL) (-449 1096621 1096895 1097219 "GALPOLYU" 1098040 NIL GALPOLYU (NIL T T) -7 NIL NIL) (-448 1093986 1094276 1094683 "GALFACTU" 1096318 NIL GALFACTU (NIL T T T) -7 NIL NIL) (-447 1085792 1087291 1088899 "GALFACT" 1092418 NIL GALFACT (NIL T) -7 NIL NIL) (-446 1083180 1083837 1083866 "FVFUN" 1085022 T FVFUN (NIL) -9 NIL 1085742) (-445 1082446 1082627 1082656 "FVC" 1082947 T FVC (NIL) -9 NIL 1083130) (-444 1082088 1082243 1082324 "FUNCTION" 1082398 NIL FUNCTION (NIL NIL) -8 NIL NIL) (-443 1079758 1080309 1080798 "FT" 1081619 T FT (NIL) -8 NIL NIL) (-442 1078550 1079059 1079262 "FTEM" 1079575 T FTEM (NIL) -8 NIL NIL) (-441 1076808 1077097 1077500 "FSUPFACT" 1078242 NIL FSUPFACT (NIL T T T) -7 NIL NIL) (-440 1075205 1075494 1075826 "FST" 1076496 T FST (NIL) -8 NIL NIL) (-439 1074376 1074482 1074677 "FSRED" 1075087 NIL FSRED (NIL T T) -7 NIL NIL) (-438 1073057 1073312 1073665 "FSPRMELT" 1074092 NIL FSPRMELT (NIL T T) -7 NIL NIL) (-437 1068423 1069128 1069885 "FSPECF" 1072362 NIL FSPECF (NIL T T) -7 NIL NIL) (-436 1050681 1059270 1059311 "FS" 1063159 NIL FS (NIL T) -9 NIL 1065437) (-435 1039331 1042321 1046377 "FS-" 1046674 NIL FS- (NIL T T) -8 NIL NIL) (-434 1038845 1038899 1039076 "FSINT" 1039272 NIL FSINT (NIL T T) -7 NIL NIL) (-433 1037130 1037842 1038143 "FSERIES" 1038626 NIL FSERIES (NIL T T) -8 NIL NIL) (-432 1036144 1036260 1036491 "FSCINT" 1037010 NIL FSCINT (NIL T T) -7 NIL NIL) (-431 1032335 1035089 1035131 "FSAGG" 1035501 NIL FSAGG (NIL T) -9 NIL 1035758) (-430 1030097 1030698 1031494 "FSAGG-" 1031589 NIL FSAGG- (NIL T T) -8 NIL NIL) (-429 1029139 1029282 1029509 "FSAGG2" 1029950 NIL FSAGG2 (NIL T T T T) -7 NIL NIL) (-428 1026794 1027073 1027627 "FS2UPS" 1028857 NIL FS2UPS (NIL T T T T T NIL) -7 NIL NIL) (-427 1026376 1026419 1026574 "FS2" 1026745 NIL FS2 (NIL T T T T) -7 NIL NIL) (-426 1025233 1025404 1025713 "FS2EXPXP" 1026201 NIL FS2EXPXP (NIL T T NIL NIL) -7 NIL NIL) (-425 1024659 1024774 1024926 "FRUTIL" 1025113 NIL FRUTIL (NIL T) -7 NIL NIL) (-424 1016085 1020170 1021520 "FR" 1023341 NIL FR (NIL T) -8 NIL NIL) (-423 1011165 1013803 1013844 "FRNAALG" 1015240 NIL FRNAALG (NIL T) -9 NIL 1015846) (-422 1006844 1007914 1009189 "FRNAALG-" 1009939 NIL FRNAALG- (NIL T T) -8 NIL NIL) (-421 1006482 1006525 1006652 "FRNAAF2" 1006795 NIL FRNAAF2 (NIL T T T T) -7 NIL NIL) (-420 1004840 1005333 1005628 "FRMOD" 1006295 NIL FRMOD (NIL T T T T NIL) -8 NIL NIL) (-419 1002547 1003215 1003533 "FRIDEAL" 1004631 NIL FRIDEAL (NIL T T T T) -8 NIL NIL) (-418 1001738 1001825 1002116 "FRIDEAL2" 1002454 NIL FRIDEAL2 (NIL T T T T T T T T) -7 NIL NIL) (-417 1000981 1001395 1001437 "FRETRCT" 1001442 NIL FRETRCT (NIL T) -9 NIL 1001616) (-416 1000093 1000324 1000675 "FRETRCT-" 1000680 NIL FRETRCT- (NIL T T) -8 NIL NIL) (-415 997298 998518 998578 "FRAMALG" 999460 NIL FRAMALG (NIL T T) -9 NIL 999752) (-414 995431 995887 996517 "FRAMALG-" 996740 NIL FRAMALG- (NIL T T T) -8 NIL NIL) (-413 989332 994914 995186 "FRAC" 995191 NIL FRAC (NIL T) -8 NIL NIL) (-412 988968 989025 989132 "FRAC2" 989269 NIL FRAC2 (NIL T T) -7 NIL NIL) (-411 988604 988661 988768 "FR2" 988905 NIL FR2 (NIL T T) -7 NIL NIL) (-410 983226 986135 986164 "FPS" 987283 T FPS (NIL) -9 NIL 987837) (-409 982675 982784 982948 "FPS-" 983094 NIL FPS- (NIL T) -8 NIL NIL) (-408 980071 981768 981797 "FPC" 982022 T FPC (NIL) -9 NIL 982164) (-407 979864 979904 980001 "FPC-" 980006 NIL FPC- (NIL T) -8 NIL NIL) (-406 978743 979353 979395 "FPATMAB" 979400 NIL FPATMAB (NIL T) -9 NIL 979550) (-405 976443 976919 977345 "FPARFRAC" 978380 NIL FPARFRAC (NIL T T) -8 NIL NIL) (-404 971838 972335 973017 "FORTRAN" 975875 NIL FORTRAN (NIL NIL NIL NIL NIL) -8 NIL NIL) (-403 969554 970054 970593 "FORT" 971319 T FORT (NIL) -7 NIL NIL) (-402 967230 967791 967820 "FORTFN" 968880 T FORTFN (NIL) -9 NIL 969504) (-401 966993 967043 967072 "FORTCAT" 967131 T FORTCAT (NIL) -9 NIL 967193) (-400 965053 965536 965935 "FORMULA" 966614 T FORMULA (NIL) -8 NIL NIL) (-399 964841 964871 964940 "FORMULA1" 965017 NIL FORMULA1 (NIL T) -7 NIL NIL) (-398 964364 964416 964589 "FORDER" 964783 NIL FORDER (NIL T T T T) -7 NIL NIL) (-397 963460 963624 963817 "FOP" 964191 T FOP (NIL) -7 NIL NIL) (-396 962068 962740 962914 "FNLA" 963342 NIL FNLA (NIL NIL NIL T) -8 NIL NIL) (-395 960735 961124 961153 "FNCAT" 961725 T FNCAT (NIL) -9 NIL 962018) (-394 960301 960694 960722 "FNAME" 960727 T FNAME (NIL) -8 NIL NIL) (-393 958954 959927 959956 "FMTC" 959961 T FMTC (NIL) -9 NIL 959997) (-392 955272 956479 957107 "FMONOID" 958359 NIL FMONOID (NIL T) -8 NIL NIL) (-391 954493 955016 955164 "FM" 955169 NIL FM (NIL T T) -8 NIL NIL) (-390 951917 952562 952591 "FMFUN" 953735 T FMFUN (NIL) -9 NIL 954443) (-389 951186 951366 951395 "FMC" 951685 T FMC (NIL) -9 NIL 951867) (-388 948398 949232 949287 "FMCAT" 950482 NIL FMCAT (NIL T T) -9 NIL 950976) (-387 947291 948164 948264 "FM1" 948343 NIL FM1 (NIL T T) -8 NIL NIL) (-386 945065 945481 945975 "FLOATRP" 946842 NIL FLOATRP (NIL T) -7 NIL NIL) (-385 938552 942721 943351 "FLOAT" 944455 T FLOAT (NIL) -8 NIL NIL) (-384 935990 936490 937068 "FLOATCP" 938019 NIL FLOATCP (NIL T) -7 NIL NIL) (-383 934775 935623 935665 "FLINEXP" 935670 NIL FLINEXP (NIL T) -9 NIL 935762) (-382 933929 934164 934492 "FLINEXP-" 934497 NIL FLINEXP- (NIL T T) -8 NIL NIL) (-381 933005 933149 933373 "FLASORT" 933781 NIL FLASORT (NIL T T) -7 NIL NIL) (-380 930221 931063 931116 "FLALG" 932343 NIL FLALG (NIL T T) -9 NIL 932810) (-379 924040 927734 927776 "FLAGG" 929038 NIL FLAGG (NIL T) -9 NIL 929686) (-378 922766 923105 923595 "FLAGG-" 923600 NIL FLAGG- (NIL T T) -8 NIL NIL) (-377 921808 921951 922178 "FLAGG2" 922619 NIL FLAGG2 (NIL T T T T) -7 NIL NIL) (-376 918779 919797 919857 "FINRALG" 920985 NIL FINRALG (NIL T T) -9 NIL 921490) (-375 917939 918168 918507 "FINRALG-" 918512 NIL FINRALG- (NIL T T T) -8 NIL NIL) (-374 917242 917479 917508 "FINITE" 917759 T FINITE (NIL) -9 NIL 917889) (-373 917051 917095 917182 "FINITE-" 917187 NIL FINITE- (NIL T) -8 NIL NIL) (-372 909509 911670 911711 "FINAALG" 915378 NIL FINAALG (NIL T) -9 NIL 916830) (-371 904849 905891 907035 "FINAALG-" 908414 NIL FINAALG- (NIL T T) -8 NIL NIL) (-370 904219 904604 904707 "FILE" 904779 NIL FILE (NIL T) -8 NIL NIL) (-369 902759 903096 903151 "FILECAT" 903929 NIL FILECAT (NIL T T) -9 NIL 904169) (-368 900569 902125 902154 "FIELD" 902194 T FIELD (NIL) -9 NIL 902274) (-367 899189 899574 900085 "FIELD-" 900090 NIL FIELD- (NIL T) -8 NIL NIL) (-366 897002 897824 898171 "FGROUP" 898875 NIL FGROUP (NIL T) -8 NIL NIL) (-365 896092 896256 896476 "FGLMICPK" 896834 NIL FGLMICPK (NIL T NIL) -7 NIL NIL) (-364 891849 896017 896074 "FFX" 896079 NIL FFX (NIL T NIL) -8 NIL NIL) (-363 891389 891456 891578 "FFSQFR" 891777 NIL FFSQFR (NIL T T) -7 NIL NIL) (-362 890990 891051 891186 "FFSLPE" 891322 NIL FFSLPE (NIL T T T) -7 NIL NIL) (-361 886986 887762 888558 "FFPOLY" 890226 NIL FFPOLY (NIL T) -7 NIL NIL) (-360 886490 886526 886735 "FFPOLY2" 886944 NIL FFPOLY2 (NIL T T) -7 NIL NIL) (-359 882267 886409 886472 "FFP" 886477 NIL FFP (NIL T NIL) -8 NIL NIL) (-358 877583 882178 882242 "FF" 882247 NIL FF (NIL NIL NIL) -8 NIL NIL) (-357 872634 876926 877116 "FFNBX" 877437 NIL FFNBX (NIL T NIL) -8 NIL NIL) (-356 867499 871769 872027 "FFNBP" 872488 NIL FFNBP (NIL T NIL) -8 NIL NIL) (-355 862050 866783 866994 "FFNB" 867332 NIL FFNB (NIL NIL NIL) -8 NIL NIL) (-354 860882 861080 861395 "FFINTBAS" 861847 NIL FFINTBAS (NIL T T T) -7 NIL NIL) (-353 857033 859293 859322 "FFIELDC" 859942 T FFIELDC (NIL) -9 NIL 860318) (-352 855696 856066 856563 "FFIELDC-" 856568 NIL FFIELDC- (NIL T) -8 NIL NIL) (-351 855266 855311 855435 "FFHOM" 855638 NIL FFHOM (NIL T T T) -7 NIL NIL) (-350 852964 853448 853965 "FFF" 854781 NIL FFF (NIL T) -7 NIL NIL) (-349 848660 849425 850269 "FFFG" 852188 NIL FFFG (NIL T T) -7 NIL NIL) (-348 847386 847595 847917 "FFFGF" 848438 NIL FFFGF (NIL T T T) -7 NIL NIL) (-347 846137 846334 846582 "FFFACTSE" 847188 NIL FFFACTSE (NIL T T) -7 NIL NIL) (-346 844888 845085 845333 "FFFACTOR" 845939 NIL FFFACTOR (NIL T T) -7 NIL NIL) (-345 840431 844630 844731 "FFCGX" 844831 NIL FFCGX (NIL T NIL) -8 NIL NIL) (-344 835988 840163 840270 "FFCGP" 840374 NIL FFCGP (NIL T NIL) -8 NIL NIL) (-343 831089 835715 835823 "FFCG" 835924 NIL FFCG (NIL NIL NIL) -8 NIL NIL) (-342 812826 822000 822087 "FFCAT" 827252 NIL FFCAT (NIL T T T) -9 NIL 828737) (-341 808024 809071 810385 "FFCAT-" 811615 NIL FFCAT- (NIL T T T T) -8 NIL NIL) (-340 807435 807478 807713 "FFCAT2" 807975 NIL FFCAT2 (NIL T T T T T T T T) -7 NIL NIL) (-339 796605 800411 801629 "FEXPR" 806289 NIL FEXPR (NIL NIL NIL T) -8 NIL NIL) (-338 795607 796042 796084 "FEVALAB" 796168 NIL FEVALAB (NIL T) -9 NIL 796426) (-337 794766 794976 795314 "FEVALAB-" 795319 NIL FEVALAB- (NIL T T) -8 NIL NIL) (-336 793359 794149 794352 "FDIV" 794665 NIL FDIV (NIL T T T T) -8 NIL NIL) (-335 790424 791139 791255 "FDIVCAT" 792823 NIL FDIVCAT (NIL T T T T) -9 NIL 793260) (-334 790186 790213 790383 "FDIVCAT-" 790388 NIL FDIVCAT- (NIL T T T T T) -8 NIL NIL) (-333 789406 789493 789770 "FDIV2" 790093 NIL FDIV2 (NIL T T T T T T T T) -7 NIL NIL) (-332 788092 788351 788640 "FCPAK1" 789137 T FCPAK1 (NIL) -7 NIL NIL) (-331 787220 787592 787733 "FCOMP" 787983 NIL FCOMP (NIL T) -8 NIL NIL) (-330 770848 774263 777826 "FC" 783677 T FC (NIL) -8 NIL NIL) (-329 763347 767435 767476 "FAXF" 769278 NIL FAXF (NIL T) -9 NIL 769969) (-328 760627 761281 762106 "FAXF-" 762571 NIL FAXF- (NIL T T) -8 NIL NIL) (-327 755733 760003 760179 "FARRAY" 760484 NIL FARRAY (NIL T) -8 NIL NIL) (-326 751051 753127 753181 "FAMR" 754204 NIL FAMR (NIL T T) -9 NIL 754661) (-325 749941 750243 750678 "FAMR-" 750683 NIL FAMR- (NIL T T T) -8 NIL NIL) (-324 749529 749572 749723 "FAMR2" 749892 NIL FAMR2 (NIL T T T T T) -7 NIL NIL) (-323 748725 749451 749504 "FAMONOID" 749509 NIL FAMONOID (NIL T) -8 NIL NIL) (-322 746555 747239 747293 "FAMONC" 748234 NIL FAMONC (NIL T T) -9 NIL 748619) (-321 745249 746311 746447 "FAGROUP" 746452 NIL FAGROUP (NIL T) -8 NIL NIL) (-320 743044 743363 743766 "FACUTIL" 744930 NIL FACUTIL (NIL T T T T) -7 NIL NIL) (-319 742460 742569 742715 "FACTRN" 742930 NIL FACTRN (NIL T) -7 NIL NIL) (-318 741559 741744 741966 "FACTFUNC" 742270 NIL FACTFUNC (NIL T) -7 NIL NIL) (-317 740975 741084 741230 "FACTEXT" 741445 NIL FACTEXT (NIL T) -7 NIL NIL) (-316 733295 740226 740438 "EXPUPXS" 740831 NIL EXPUPXS (NIL T NIL NIL) -8 NIL NIL) (-315 730778 731318 731904 "EXPRTUBE" 732729 T EXPRTUBE (NIL) -7 NIL NIL) (-314 729949 730044 730264 "EXPRSOL" 730678 NIL EXPRSOL (NIL T T T T) -7 NIL NIL) (-313 726143 726735 727472 "EXPRODE" 729288 NIL EXPRODE (NIL T T) -7 NIL NIL) (-312 711164 724804 725229 "EXPR" 725750 NIL EXPR (NIL T) -8 NIL NIL) (-311 705571 706158 706971 "EXPR2UPS" 710462 NIL EXPR2UPS (NIL T T) -7 NIL NIL) (-310 705207 705264 705371 "EXPR2" 705508 NIL EXPR2 (NIL T T) -7 NIL NIL) (-309 696545 704337 704635 "EXPEXPAN" 705043 NIL EXPEXPAN (NIL T T NIL NIL) -8 NIL NIL) (-308 696257 696308 696385 "EXP3D" 696488 T EXP3D (NIL) -7 NIL NIL) (-307 696084 696214 696243 "EXIT" 696248 T EXIT (NIL) -8 NIL NIL) (-306 695711 695773 695886 "EVALCYC" 696016 NIL EVALCYC (NIL T) -7 NIL NIL) (-305 695253 695369 695411 "EVALAB" 695581 NIL EVALAB (NIL T) -9 NIL 695685) (-304 694734 694856 695077 "EVALAB-" 695082 NIL EVALAB- (NIL T T) -8 NIL NIL) (-303 692192 693504 693533 "EUCDOM" 694088 T EUCDOM (NIL) -9 NIL 694438) (-302 690597 691039 691629 "EUCDOM-" 691634 NIL EUCDOM- (NIL T) -8 NIL NIL) (-301 678137 680895 683645 "ESTOOLS" 687867 T ESTOOLS (NIL) -7 NIL NIL) (-300 677769 677826 677935 "ESTOOLS2" 678074 NIL ESTOOLS2 (NIL T T) -7 NIL NIL) (-299 677520 677562 677642 "ESTOOLS1" 677721 NIL ESTOOLS1 (NIL T) -7 NIL NIL) (-298 671446 673174 673203 "ES" 675971 T ES (NIL) -9 NIL 677378) (-297 666394 667680 669497 "ES-" 669661 NIL ES- (NIL T) -8 NIL NIL) (-296 662769 663529 664309 "ESCONT" 665634 T ESCONT (NIL) -7 NIL NIL) (-295 662514 662546 662628 "ESCONT1" 662731 NIL ESCONT1 (NIL NIL NIL) -7 NIL NIL) (-294 662189 662239 662339 "ES2" 662458 NIL ES2 (NIL T T) -7 NIL NIL) (-293 661819 661877 661986 "ES1" 662125 NIL ES1 (NIL T T) -7 NIL NIL) (-292 661035 661164 661340 "ERROR" 661663 T ERROR (NIL) -7 NIL NIL) (-291 654550 660894 660985 "EQTBL" 660990 NIL EQTBL (NIL T T) -8 NIL NIL) (-290 647009 649892 651327 "EQ" 653148 NIL -3015 (NIL T) -8 NIL NIL) (-289 646641 646698 646807 "EQ2" 646946 NIL EQ2 (NIL T T) -7 NIL NIL) (-288 641933 642979 644072 "EP" 645580 NIL EP (NIL T) -7 NIL NIL) (-287 641087 641651 641680 "ENTIRER" 641685 T ENTIRER (NIL) -9 NIL 641731) (-286 637543 639042 639412 "EMR" 640886 NIL EMR (NIL T T T NIL NIL NIL) -8 NIL NIL) (-285 636689 636872 636927 "ELTAGG" 637307 NIL ELTAGG (NIL T T) -9 NIL 637517) (-284 636408 636470 636611 "ELTAGG-" 636616 NIL ELTAGG- (NIL T T T) -8 NIL NIL) (-283 636196 636225 636280 "ELTAB" 636364 NIL ELTAB (NIL T T) -9 NIL NIL) (-282 635322 635468 635667 "ELFUTS" 636047 NIL ELFUTS (NIL T T) -7 NIL NIL) (-281 635063 635119 635148 "ELEMFUN" 635253 T ELEMFUN (NIL) -9 NIL NIL) (-280 634933 634954 635022 "ELEMFUN-" 635027 NIL ELEMFUN- (NIL T) -8 NIL NIL) (-279 629863 633066 633108 "ELAGG" 634048 NIL ELAGG (NIL T) -9 NIL 634509) (-278 628148 628582 629245 "ELAGG-" 629250 NIL ELAGG- (NIL T T) -8 NIL NIL) (-277 621018 622817 623643 "EFUPXS" 627425 NIL EFUPXS (NIL T T T T) -8 NIL NIL) (-276 614470 616271 617080 "EFULS" 620295 NIL EFULS (NIL T T T) -8 NIL NIL) (-275 611892 612250 612729 "EFSTRUC" 614102 NIL EFSTRUC (NIL T T) -7 NIL NIL) (-274 600904 602469 604030 "EF" 610407 NIL EF (NIL T T) -7 NIL NIL) (-273 600005 600389 600538 "EAB" 600775 T EAB (NIL) -8 NIL NIL) (-272 599214 599964 599992 "E04UCFA" 599997 T E04UCFA (NIL) -8 NIL NIL) (-271 598423 599173 599201 "E04NAFA" 599206 T E04NAFA (NIL) -8 NIL NIL) (-270 597632 598382 598410 "E04MBFA" 598415 T E04MBFA (NIL) -8 NIL NIL) (-269 596841 597591 597619 "E04JAFA" 597624 T E04JAFA (NIL) -8 NIL NIL) (-268 596052 596800 596828 "E04GCFA" 596833 T E04GCFA (NIL) -8 NIL NIL) (-267 595263 596011 596039 "E04FDFA" 596044 T E04FDFA (NIL) -8 NIL NIL) (-266 594472 595222 595250 "E04DGFA" 595255 T E04DGFA (NIL) -8 NIL NIL) (-265 588651 589997 591361 "E04AGNT" 593128 T E04AGNT (NIL) -7 NIL NIL) (-264 587374 587854 587895 "DVARCAT" 588370 NIL DVARCAT (NIL T) -9 NIL 588569) (-263 586578 586790 587104 "DVARCAT-" 587109 NIL DVARCAT- (NIL T T) -8 NIL NIL) (-262 579547 580029 580778 "DTP" 586109 NIL DTP (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-261 576996 578969 579126 "DSTREE" 579423 NIL DSTREE (NIL T) -8 NIL NIL) (-260 574465 576310 576352 "DSTRCAT" 576571 NIL DSTRCAT (NIL T) -9 NIL 576705) (-259 567319 574264 574393 "DSMP" 574398 NIL DSMP (NIL T T T) -8 NIL NIL) (-258 562129 563264 564332 "DROPT" 566271 T DROPT (NIL) -8 NIL NIL) (-257 561794 561853 561951 "DROPT1" 562064 NIL DROPT1 (NIL T) -7 NIL NIL) (-256 556909 558035 559172 "DROPT0" 560677 T DROPT0 (NIL) -7 NIL NIL) (-255 555254 555579 555965 "DRAWPT" 556543 T DRAWPT (NIL) -7 NIL NIL) (-254 549841 550764 551843 "DRAW" 554228 NIL DRAW (NIL T) -7 NIL NIL) (-253 549474 549527 549645 "DRAWHACK" 549782 NIL DRAWHACK (NIL T) -7 NIL NIL) (-252 548205 548474 548765 "DRAWCX" 549203 T DRAWCX (NIL) -7 NIL NIL) (-251 547721 547789 547940 "DRAWCURV" 548131 NIL DRAWCURV (NIL T T) -7 NIL NIL) (-250 538193 540151 542266 "DRAWCFUN" 545626 T DRAWCFUN (NIL) -7 NIL NIL) (-249 535044 536920 536962 "DQAGG" 537591 NIL DQAGG (NIL T) -9 NIL 537865) (-248 523472 530213 530297 "DPOLCAT" 532149 NIL DPOLCAT (NIL T T T T) -9 NIL 532693) (-247 518311 519657 521615 "DPOLCAT-" 521620 NIL DPOLCAT- (NIL T T T T T) -8 NIL NIL) (-246 511007 518172 518270 "DPMO" 518275 NIL DPMO (NIL NIL T T) -8 NIL NIL) (-245 503606 510787 510954 "DPMM" 510959 NIL DPMM (NIL NIL T T T) -8 NIL NIL) (-244 497311 503241 503393 "DMP" 503507 NIL DMP (NIL NIL T) -8 NIL NIL) (-243 496911 496967 497111 "DLP" 497249 NIL DLP (NIL T) -7 NIL NIL) (-242 490561 496012 496239 "DLIST" 496716 NIL DLIST (NIL T) -8 NIL NIL) (-241 487446 489449 489491 "DLAGG" 490041 NIL DLAGG (NIL T) -9 NIL 490270) (-240 486103 486795 486824 "DIVRING" 486974 T DIVRING (NIL) -9 NIL 487082) (-239 485091 485344 485737 "DIVRING-" 485742 NIL DIVRING- (NIL T) -8 NIL NIL) (-238 483519 484684 484820 "DIV" 484988 NIL DIV (NIL T) -8 NIL NIL) (-237 481013 482081 482123 "DIVCAT" 482957 NIL DIVCAT (NIL T) -9 NIL 483288) (-236 479115 479472 479878 "DISPLAY" 480627 T DISPLAY (NIL) -7 NIL NIL) (-235 476608 477821 478203 "DIRRING" 478766 NIL DIRRING (NIL T) -8 NIL NIL) (-234 470425 476522 476585 "DIRPROD" 476590 NIL DIRPROD (NIL NIL T) -8 NIL NIL) (-233 469273 469476 469741 "DIRPROD2" 470218 NIL DIRPROD2 (NIL NIL T T) -7 NIL NIL) (-232 458725 464797 464851 "DIRPCAT" 465261 NIL DIRPCAT (NIL NIL T) -9 NIL 466090) (-231 456051 456693 457574 "DIRPCAT-" 457911 NIL DIRPCAT- (NIL T NIL T) -8 NIL NIL) (-230 455338 455498 455684 "DIOSP" 455885 T DIOSP (NIL) -7 NIL NIL) (-229 452081 454285 454327 "DIOPS" 454761 NIL DIOPS (NIL T) -9 NIL 454989) (-228 451630 451744 451935 "DIOPS-" 451940 NIL DIOPS- (NIL T T) -8 NIL NIL) (-227 450497 451135 451164 "DIFRING" 451351 T DIFRING (NIL) -9 NIL 451461) (-226 450143 450220 450372 "DIFRING-" 450377 NIL DIFRING- (NIL T) -8 NIL NIL) (-225 447925 449207 449249 "DIFEXT" 449612 NIL DIFEXT (NIL T) -9 NIL 449904) (-224 446210 446638 447304 "DIFEXT-" 447309 NIL DIFEXT- (NIL T T) -8 NIL NIL) (-223 443572 445776 445818 "DIAGG" 445823 NIL DIAGG (NIL T) -9 NIL 445843) (-222 442956 443113 443365 "DIAGG-" 443370 NIL DIAGG- (NIL T T) -8 NIL NIL) (-221 438278 441915 442192 "DHMATRIX" 442725 NIL DHMATRIX (NIL T) -8 NIL NIL) (-220 433489 438092 438166 "DFVEC" 438224 T DFVEC (NIL) -8 NIL NIL) (-219 427090 428440 429877 "DFSFUN" 432072 T DFSFUN (NIL) -7 NIL NIL) (-218 423301 426861 426955 "DFMAT" 427016 T DFMAT (NIL) -8 NIL NIL) (-217 417578 421755 422188 "DFLOAT" 422888 T DFLOAT (NIL) -8 NIL NIL) (-216 415806 416087 416483 "DFINTTLS" 417286 NIL DFINTTLS (NIL T T) -7 NIL NIL) (-215 412825 413827 414227 "DERHAM" 415472 NIL DERHAM (NIL T NIL) -8 NIL NIL) (-214 404438 406355 407790 "DEQUEUE" 411423 NIL DEQUEUE (NIL T) -8 NIL NIL) (-213 403653 403786 403982 "DEGRED" 404300 NIL DEGRED (NIL T T) -7 NIL NIL) (-212 400048 400793 401646 "DEFINTRF" 402881 NIL DEFINTRF (NIL T) -7 NIL NIL) (-211 397575 398044 398643 "DEFINTEF" 399567 NIL DEFINTEF (NIL T T) -7 NIL NIL) (-210 391391 397011 397179 "DECIMAL" 397427 T DECIMAL (NIL) -8 NIL NIL) (-209 388903 389361 389867 "DDFACT" 390935 NIL DDFACT (NIL T T) -7 NIL NIL) (-208 388499 388542 388693 "DBLRESP" 388854 NIL DBLRESP (NIL T T T T) -7 NIL NIL) (-207 386209 386543 386912 "DBASE" 388257 NIL DBASE (NIL T) -8 NIL NIL) (-206 385342 386168 386196 "D03FAFA" 386201 T D03FAFA (NIL) -8 NIL NIL) (-205 384476 385301 385329 "D03EEFA" 385334 T D03EEFA (NIL) -8 NIL NIL) (-204 382426 382892 383381 "D03AGNT" 384007 T D03AGNT (NIL) -7 NIL NIL) (-203 381742 382385 382413 "D02EJFA" 382418 T D02EJFA (NIL) -8 NIL NIL) (-202 381058 381701 381729 "D02CJFA" 381734 T D02CJFA (NIL) -8 NIL NIL) (-201 380374 381017 381045 "D02BHFA" 381050 T D02BHFA (NIL) -8 NIL NIL) (-200 379690 380333 380361 "D02BBFA" 380366 T D02BBFA (NIL) -8 NIL NIL) (-199 372889 374476 376082 "D02AGNT" 378104 T D02AGNT (NIL) -7 NIL NIL) (-198 370658 371180 371726 "D01WGTS" 372363 T D01WGTS (NIL) -7 NIL NIL) (-197 369753 370617 370645 "D01TRNS" 370650 T D01TRNS (NIL) -8 NIL NIL) (-196 368848 369712 369740 "D01GBFA" 369745 T D01GBFA (NIL) -8 NIL NIL) (-195 367943 368807 368835 "D01FCFA" 368840 T D01FCFA (NIL) -8 NIL NIL) (-194 367038 367902 367930 "D01ASFA" 367935 T D01ASFA (NIL) -8 NIL NIL) (-193 366133 366997 367025 "D01AQFA" 367030 T D01AQFA (NIL) -8 NIL NIL) (-192 365228 366092 366120 "D01APFA" 366125 T D01APFA (NIL) -8 NIL NIL) (-191 364323 365187 365215 "D01ANFA" 365220 T D01ANFA (NIL) -8 NIL NIL) (-190 363418 364282 364310 "D01AMFA" 364315 T D01AMFA (NIL) -8 NIL NIL) (-189 362513 363377 363405 "D01ALFA" 363410 T D01ALFA (NIL) -8 NIL NIL) (-188 361608 362472 362500 "D01AKFA" 362505 T D01AKFA (NIL) -8 NIL NIL) (-187 360703 361567 361595 "D01AJFA" 361600 T D01AJFA (NIL) -8 NIL NIL) (-186 354000 355551 357112 "D01AGNT" 359162 T D01AGNT (NIL) -7 NIL NIL) (-185 353337 353465 353617 "CYCLOTOM" 353868 T CYCLOTOM (NIL) -7 NIL NIL) (-184 350072 350785 351512 "CYCLES" 352630 T CYCLES (NIL) -7 NIL NIL) (-183 349384 349518 349689 "CVMP" 349933 NIL CVMP (NIL T) -7 NIL NIL) (-182 347156 347413 347789 "CTRIGMNP" 349112 NIL CTRIGMNP (NIL T T) -7 NIL NIL) (-181 346530 346629 346782 "CSTTOOLS" 347053 NIL CSTTOOLS (NIL T T) -7 NIL NIL) (-180 342329 342986 343744 "CRFP" 345842 NIL CRFP (NIL T T) -7 NIL NIL) (-179 341376 341561 341789 "CRAPACK" 342133 NIL CRAPACK (NIL T) -7 NIL NIL) (-178 340762 340863 341066 "CPMATCH" 341253 NIL CPMATCH (NIL T T T) -7 NIL NIL) (-177 340487 340515 340621 "CPIMA" 340728 NIL CPIMA (NIL T T T) -7 NIL NIL) (-176 336835 337507 338226 "COORDSYS" 339822 NIL COORDSYS (NIL T) -7 NIL NIL) (-175 332696 334838 335330 "CONTFRAC" 336375 NIL CONTFRAC (NIL T) -8 NIL NIL) (-174 331844 332408 332437 "COMRING" 332442 T COMRING (NIL) -9 NIL 332494) (-173 330925 331202 331386 "COMPPROP" 331680 T COMPPROP (NIL) -8 NIL NIL) (-172 330586 330621 330749 "COMPLPAT" 330884 NIL COMPLPAT (NIL T T T) -7 NIL NIL) (-171 320512 330397 330505 "COMPLEX" 330510 NIL COMPLEX (NIL T) -8 NIL NIL) (-170 320148 320205 320312 "COMPLEX2" 320449 NIL COMPLEX2 (NIL T T) -7 NIL NIL) (-169 319866 319901 319999 "COMPFACT" 320107 NIL COMPFACT (NIL T T) -7 NIL NIL) (-168 304073 314418 314459 "COMPCAT" 315463 NIL COMPCAT (NIL T) -9 NIL 316844) (-167 293589 296512 300139 "COMPCAT-" 300495 NIL COMPCAT- (NIL T T) -8 NIL NIL) (-166 293248 293400 293429 "COMPAR" 293490 T COMPAR (NIL) -9 NIL 293539) (-165 292977 293005 293108 "COMMUPC" 293214 NIL COMMUPC (NIL T T T) -7 NIL NIL) (-164 292772 292805 292864 "COMMONOP" 292938 T COMMONOP (NIL) -7 NIL NIL) (-163 292355 292523 292610 "COMM" 292705 T COMM (NIL) -8 NIL NIL) (-162 291603 291797 291826 "COMBOPC" 292164 T COMBOPC (NIL) -9 NIL 292339) (-161 290499 290709 290951 "COMBINAT" 291393 NIL COMBINAT (NIL T) -7 NIL NIL) (-160 286697 287270 287910 "COMBF" 289921 NIL COMBF (NIL T T) -7 NIL NIL) (-159 285483 285813 286048 "COLOR" 286482 T COLOR (NIL) -8 NIL NIL) (-158 285123 285170 285295 "CMPLXRT" 285430 NIL CMPLXRT (NIL T T) -7 NIL NIL) (-157 280625 281653 282733 "CLIP" 284063 T CLIP (NIL) -7 NIL NIL) (-156 278956 279726 279966 "CLIF" 280452 NIL CLIF (NIL NIL T NIL) -8 NIL NIL) (-155 275221 277139 277181 "CLAGG" 278110 NIL CLAGG (NIL T) -9 NIL 278643) (-154 273643 274100 274683 "CLAGG-" 274688 NIL CLAGG- (NIL T T) -8 NIL NIL) (-153 273187 273272 273412 "CINTSLPE" 273552 NIL CINTSLPE (NIL T T) -7 NIL NIL) (-152 270688 271159 271707 "CHVAR" 272715 NIL CHVAR (NIL T T T) -7 NIL NIL) (-151 269906 270470 270499 "CHARZ" 270504 T CHARZ (NIL) -9 NIL 270519) (-150 269660 269700 269778 "CHARPOL" 269860 NIL CHARPOL (NIL T) -7 NIL NIL) (-149 268762 269359 269388 "CHARNZ" 269435 T CHARNZ (NIL) -9 NIL 269491) (-148 266760 267452 267787 "CHAR" 268447 T CHAR (NIL) -8 NIL NIL) (-147 266485 266546 266575 "CFCAT" 266686 T CFCAT (NIL) -9 NIL NIL) (-146 260618 266142 266260 "CDFVEC" 266387 T CDFVEC (NIL) -8 NIL NIL) (-145 256276 260375 260476 "CDFMAT" 260537 T CDFMAT (NIL) -8 NIL NIL) (-144 255517 255628 255811 "CDEN" 256160 NIL CDEN (NIL T T T) -7 NIL NIL) (-143 251462 254670 254950 "CCLASS" 255257 T CCLASS (NIL) -8 NIL NIL) (-142 246515 247491 248244 "CARTEN" 250765 NIL CARTEN (NIL NIL NIL T) -8 NIL NIL) (-141 245623 245771 245992 "CARTEN2" 246362 NIL CARTEN2 (NIL NIL NIL T T) -7 NIL NIL) (-140 243918 244773 245030 "CARD" 245386 T CARD (NIL) -8 NIL NIL) (-139 243289 243617 243646 "CACHSET" 243778 T CACHSET (NIL) -9 NIL 243855) (-138 242784 243080 243109 "CABMON" 243159 T CABMON (NIL) -9 NIL 243215) (-137 240347 242476 242583 "BTREE" 242710 NIL BTREE (NIL T) -8 NIL NIL) (-136 237851 239995 240117 "BTOURN" 240257 NIL BTOURN (NIL T) -8 NIL NIL) (-135 235308 237355 237397 "BTCAT" 237465 NIL BTCAT (NIL T) -9 NIL 237542) (-134 234975 235055 235204 "BTCAT-" 235209 NIL BTCAT- (NIL T T) -8 NIL NIL) (-133 230165 234035 234064 "BTAGG" 234320 T BTAGG (NIL) -9 NIL 234499) (-132 229588 229732 229962 "BTAGG-" 229967 NIL BTAGG- (NIL T) -8 NIL NIL) (-131 226638 228866 229081 "BSTREE" 229405 NIL BSTREE (NIL T) -8 NIL NIL) (-130 225041 225588 225888 "BSD" 226358 T BSD (NIL) -8 NIL NIL) (-129 224179 224305 224489 "BRILL" 224897 NIL BRILL (NIL T) -7 NIL NIL) (-128 220919 222940 222982 "BRAGG" 223631 NIL BRAGG (NIL T) -9 NIL 223888) (-127 219448 219854 220409 "BRAGG-" 220414 NIL BRAGG- (NIL T T) -8 NIL NIL) (-126 212645 218792 218977 "BPADICRT" 219295 NIL BPADICRT (NIL NIL) -8 NIL NIL) (-125 210949 212582 212627 "BPADIC" 212632 NIL BPADIC (NIL NIL) -8 NIL NIL) (-124 210647 210677 210791 "BOUNDZRO" 210913 NIL BOUNDZRO (NIL T T) -7 NIL NIL) (-123 206162 207253 208120 "BOP" 209800 T BOP (NIL) -8 NIL NIL) (-122 203785 204229 204748 "BOP1" 205676 NIL BOP1 (NIL T) -7 NIL NIL) (-121 202113 202828 203122 "BOOLEAN" 203511 T BOOLEAN (NIL) -8 NIL NIL) (-120 201474 201852 201907 "BMODULE" 201912 NIL BMODULE (NIL T T) -9 NIL 201977) (-119 197817 198487 199273 "BLUPPACK" 200806 NIL BLUPPACK (NIL T NIL T T T) -7 NIL NIL) (-118 197209 197694 197763 "BLQT" 197768 T BLQT (NIL) -8 NIL NIL) (-117 195638 196113 196142 "BLMETCT" 196787 T BLMETCT (NIL) -9 NIL 197159) (-116 195037 195519 195586 "BLHN" 195591 T BLHN (NIL) -8 NIL NIL) (-115 189874 191023 192182 "BLAS1" 193898 T BLAS1 (NIL) -7 NIL NIL) (-114 185684 189672 189745 "BITS" 189821 T BITS (NIL) -8 NIL NIL) (-113 184755 185216 185368 "BINFILE" 185552 T BINFILE (NIL) -8 NIL NIL) (-112 178575 184194 184361 "BINARY" 184608 T BINARY (NIL) -8 NIL NIL) (-111 176442 177864 177906 "BGAGG" 178166 NIL BGAGG (NIL T) -9 NIL 178303) (-110 176273 176305 176396 "BGAGG-" 176401 NIL BGAGG- (NIL T T) -8 NIL NIL) (-109 175371 175657 175862 "BFUNCT" 176088 T BFUNCT (NIL) -8 NIL NIL) (-108 174063 174241 174528 "BEZOUT" 175196 NIL BEZOUT (NIL T T T T T) -7 NIL NIL) (-107 173026 173248 173507 "BEZIER" 173837 NIL BEZIER (NIL T) -7 NIL NIL) (-106 169549 171878 172208 "BBTREE" 172729 NIL BBTREE (NIL T) -8 NIL NIL) (-105 169282 169335 169364 "BASTYPE" 169483 T BASTYPE (NIL) -9 NIL NIL) (-104 169135 169163 169236 "BASTYPE-" 169241 NIL BASTYPE- (NIL T) -8 NIL NIL) (-103 168569 168645 168797 "BALFACT" 169046 NIL BALFACT (NIL T T) -7 NIL NIL) (-102 167933 168056 168204 "AXSERV" 168441 T AXSERV (NIL) -7 NIL NIL) (-101 166746 167343 167531 "AUTOMOR" 167778 NIL AUTOMOR (NIL T) -8 NIL NIL) (-100 166458 166463 166492 "ATTREG" 166497 T ATTREG (NIL) -9 NIL NIL) (-99 164737 165155 165507 "ATTRBUT" 166124 T ATTRBUT (NIL) -8 NIL NIL) (-98 164272 164385 164412 "ATRIG" 164613 T ATRIG (NIL) -9 NIL NIL) (-97 164081 164122 164209 "ATRIG-" 164214 NIL ATRIG- (NIL T) -8 NIL NIL) (-96 157641 159210 160321 "ASTACK" 163001 NIL ASTACK (NIL T) -8 NIL NIL) (-95 156148 156445 156809 "ASSOCEQ" 157324 NIL ASSOCEQ (NIL T T) -7 NIL NIL) (-94 155180 155807 155931 "ASP9" 156055 NIL ASP9 (NIL NIL) -8 NIL NIL) (-93 154944 155128 155167 "ASP8" 155172 NIL ASP8 (NIL NIL) -8 NIL NIL) (-92 153814 154549 154691 "ASP80" 154833 NIL ASP80 (NIL NIL) -8 NIL NIL) (-91 152713 153449 153581 "ASP7" 153713 NIL ASP7 (NIL NIL) -8 NIL NIL) (-90 151669 152390 152508 "ASP78" 152626 NIL ASP78 (NIL NIL) -8 NIL NIL) (-89 150640 151349 151466 "ASP77" 151583 NIL ASP77 (NIL NIL) -8 NIL NIL) (-88 149555 150278 150409 "ASP74" 150540 NIL ASP74 (NIL NIL) -8 NIL NIL) (-87 148456 149190 149322 "ASP73" 149454 NIL ASP73 (NIL NIL) -8 NIL NIL) (-86 147411 148133 148251 "ASP6" 148369 NIL ASP6 (NIL NIL) -8 NIL NIL) (-85 146360 147088 147206 "ASP55" 147324 NIL ASP55 (NIL NIL) -8 NIL NIL) (-84 145310 146034 146153 "ASP50" 146272 NIL ASP50 (NIL NIL) -8 NIL NIL) (-83 144398 145011 145121 "ASP4" 145231 NIL ASP4 (NIL NIL) -8 NIL NIL) (-82 143486 144099 144209 "ASP49" 144319 NIL ASP49 (NIL NIL) -8 NIL NIL) (-81 142271 143025 143193 "ASP42" 143375 NIL ASP42 (NIL NIL NIL NIL) -8 NIL NIL) (-80 141049 141804 141974 "ASP41" 142158 NIL ASP41 (NIL NIL NIL NIL) -8 NIL NIL) (-79 140001 140726 140844 "ASP35" 140962 NIL ASP35 (NIL NIL) -8 NIL NIL) (-78 139766 139949 139988 "ASP34" 139993 NIL ASP34 (NIL NIL) -8 NIL NIL) (-77 139503 139570 139646 "ASP33" 139721 NIL ASP33 (NIL NIL) -8 NIL NIL) (-76 138399 139138 139270 "ASP31" 139402 NIL ASP31 (NIL NIL) -8 NIL NIL) (-75 138164 138347 138386 "ASP30" 138391 NIL ASP30 (NIL NIL) -8 NIL NIL) (-74 137899 137968 138044 "ASP29" 138119 NIL ASP29 (NIL NIL) -8 NIL NIL) (-73 137664 137847 137886 "ASP28" 137891 NIL ASP28 (NIL NIL) -8 NIL NIL) (-72 137429 137612 137651 "ASP27" 137656 NIL ASP27 (NIL NIL) -8 NIL NIL) (-71 136513 137127 137238 "ASP24" 137349 NIL ASP24 (NIL NIL) -8 NIL NIL) (-70 135430 136154 136284 "ASP20" 136414 NIL ASP20 (NIL NIL) -8 NIL NIL) (-69 134518 135131 135241 "ASP1" 135351 NIL ASP1 (NIL NIL) -8 NIL NIL) (-68 133462 134192 134311 "ASP19" 134430 NIL ASP19 (NIL NIL) -8 NIL NIL) (-67 133199 133266 133342 "ASP12" 133417 NIL ASP12 (NIL NIL) -8 NIL NIL) (-66 132052 132798 132942 "ASP10" 133086 NIL ASP10 (NIL NIL) -8 NIL NIL) (-65 129957 131896 131987 "ARRAY2" 131992 NIL ARRAY2 (NIL T) -8 NIL NIL) (-64 125779 129605 129719 "ARRAY1" 129874 NIL ARRAY1 (NIL T) -8 NIL NIL) (-63 124811 124984 125205 "ARRAY12" 125602 NIL ARRAY12 (NIL T T) -7 NIL NIL) (-62 119210 121075 121151 "ARR2CAT" 123781 NIL ARR2CAT (NIL T T T) -9 NIL 124539) (-61 116644 117388 118342 "ARR2CAT-" 118347 NIL ARR2CAT- (NIL T T T T) -8 NIL NIL) (-60 115392 115544 115850 "APPRULE" 116480 NIL APPRULE (NIL T T T) -7 NIL NIL) (-59 115043 115091 115210 "APPLYORE" 115338 NIL APPLYORE (NIL T T T) -7 NIL NIL) (-58 114373 114500 114648 "API" 114913 T API (NIL) -7 NIL NIL) (-57 113347 113638 113833 "ANY" 114196 T ANY (NIL) -8 NIL NIL) (-56 112625 112748 112905 "ANY1" 113221 NIL ANY1 (NIL T) -7 NIL NIL) (-55 110144 111062 111389 "ANTISYM" 112349 NIL ANTISYM (NIL T NIL) -8 NIL NIL) (-54 109971 110103 110130 "ANON" 110135 T ANON (NIL) -8 NIL NIL) (-53 104038 108510 108964 "AN" 109535 T AN (NIL) -8 NIL NIL) (-52 100333 101731 101783 "AMR" 102531 NIL AMR (NIL T T) -9 NIL 103125) (-51 99445 99666 100029 "AMR-" 100034 NIL AMR- (NIL T T T) -8 NIL NIL) (-50 84007 99362 99423 "ALIST" 99428 NIL ALIST (NIL T T) -8 NIL NIL) (-49 80844 83601 83770 "ALGSC" 83925 NIL ALGSC (NIL T NIL NIL NIL) -8 NIL NIL) (-48 77402 77956 78562 "ALGPKG" 80285 NIL ALGPKG (NIL T T) -7 NIL NIL) (-47 76679 76780 76964 "ALGMFACT" 77288 NIL ALGMFACT (NIL T T T) -7 NIL NIL) (-46 72427 73111 73762 "ALGMANIP" 76206 NIL ALGMANIP (NIL T T) -7 NIL NIL) (-45 63689 72053 72203 "ALGFF" 72360 NIL ALGFF (NIL T T T NIL) -8 NIL NIL) (-44 62885 63016 63195 "ALGFACT" 63547 NIL ALGFACT (NIL T) -7 NIL NIL) (-43 61870 62480 62519 "ALGEBRA" 62579 NIL ALGEBRA (NIL T) -9 NIL 62638) (-42 61588 61647 61779 "ALGEBRA-" 61784 NIL ALGEBRA- (NIL T T) -8 NIL NIL) (-41 43395 59120 59173 "ALAGG" 59309 NIL ALAGG (NIL T T) -9 NIL 59470) (-40 42930 43043 43070 "AHYP" 43271 T AHYP (NIL) -9 NIL NIL) (-39 41861 42109 42136 "AGG" 42635 T AGG (NIL) -9 NIL 42913) (-38 41295 41457 41671 "AGG-" 41676 NIL AGG- (NIL T) -8 NIL NIL) (-37 38844 39425 39464 "AFSPCAT" 40736 NIL AFSPCAT (NIL T) -9 NIL 41231) (-36 36523 36945 37362 "AF" 38487 NIL AF (NIL T T) -7 NIL NIL) (-35 35863 36452 36506 "AFFSP" 36511 NIL AFFSP (NIL NIL T) -8 NIL NIL) (-34 35120 35790 35839 "AFFPLPS" 35844 NIL AFFPLPS (NIL T) -8 NIL NIL) (-33 34454 35061 35103 "AFFPL" 35108 NIL AFFPL (NIL T) -8 NIL NIL) (-32 31167 31654 32282 "AFALGRES" 33959 NIL AFALGRES (NIL T NIL T T T) -7 NIL NIL) (-31 29813 29990 30304 "AFALGGRO" 30986 NIL AFALGGRO (NIL T NIL T T T) -7 NIL NIL) (-30 29082 29340 29496 "ACPLOT" 29675 T ACPLOT (NIL) -8 NIL NIL) (-29 18442 26425 26477 "ACFS" 27188 NIL ACFS (NIL T) -9 NIL 27427) (-28 16456 16946 17721 "ACFS-" 17726 NIL ACFS- (NIL T T) -8 NIL NIL) (-27 12669 14625 14652 "ACF" 15531 T ACF (NIL) -9 NIL 15944) (-26 11373 11707 12200 "ACF-" 12205 NIL ACF- (NIL T) -8 NIL NIL) (-25 10970 11139 11166 "ABELSG" 11258 T ABELSG (NIL) -9 NIL 11323) (-24 10837 10862 10928 "ABELSG-" 10933 NIL ABELSG- (NIL T) -8 NIL NIL) (-23 10205 10466 10493 "ABELMON" 10663 T ABELMON (NIL) -9 NIL 10775) (-22 9869 9953 10091 "ABELMON-" 10096 NIL ABELMON- (NIL T) -8 NIL NIL) (-21 9202 9548 9575 "ABELGRP" 9700 T ABELGRP (NIL) -9 NIL 9782) (-20 8665 8794 9010 "ABELGRP-" 9015 NIL ABELGRP- (NIL T) -8 NIL NIL) (-19 4333 8027 8067 "A1AGG" 8072 NIL A1AGG (NIL T) -9 NIL 8112) (-18 30 1251 2813 "A1AGG-" 2818 NIL A1AGG- (NIL T T) -8 NIL NIL)) 
\ No newline at end of file
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-1505 (((-1271 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-323)) (|has| |#1| (-388))))) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 10)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-1555 (($ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-1313 (((-141) $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-2306 (($ $ (-592)) NIL) (($ $ (-592) (-592)) NIL)) (-2982 (((-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|))) $) NIL)) (-1444 (((-1271 |#1| |#2| |#3|) $) NIL)) (-2919 (((-3 (-1271 |#1| |#2| |#3|) "failed") $) NIL)) (-1986 (((-1271 |#1| |#2| |#3|) $) NIL)) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3940 (((-592) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))))) (-2881 (($ (-1171 (-2 (|:| |k| (-592)) (|:| |c| |#1|)))) NIL)) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-1271 |#1| |#2| |#3|) "failed") $) NIL) (((-3 (-1191) "failed") $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1065 (-1191))) (|has| |#1| (-388)))) (((-3 (-433 (-592)) "failed") $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388)))) (((-3 (-592) "failed") $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388))))) (-2400 (((-1271 |#1| |#2| |#3|) $) NIL) (((-1191) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1065 (-1191))) (|has| |#1| (-388)))) (((-433 (-592)) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388)))) (((-592) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388))))) (-3792 (($ $) NIL) (($ (-592) $) NIL)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-1271 |#1| |#2| |#3|)) (-706 $)) NIL (|has| |#1| (-388))) (((-2 (|:| -3253 (-706 (-1271 |#1| |#2| |#3|))) (|:| |vec| (-1280 (-1271 |#1| |#2| |#3|)))) (-706 $) (-1280 $)) NIL (|has| |#1| (-388))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-654 (-592))) (|has| |#1| (-388)))) (((-706 (-592)) (-706 $)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-654 (-592))) (|has| |#1| (-388))))) (-3371 (((-3 $ "failed") $) NIL)) (-3247 (((-433 (-980 |#1|)) $ (-592)) NIL (|has| |#1| (-582))) (((-433 (-980 |#1|)) $ (-592) (-592)) NIL (|has| |#1| (-582)))) (-4290 (($) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-574)) (|has| |#1| (-388))))) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-1691 (((-141) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))))) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3412 (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-908 (-592))) (|has| |#1| (-388)))) (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-908 (-405))) (|has| |#1| (-388))))) (-4346 (((-592) $) NIL) (((-592) $ (-592)) NIL)) (-3558 (((-141) $) NIL)) (-3838 (($ $) NIL (|has| |#1| (-388)))) (-1448 (((-1271 |#1| |#2| |#3|) $) NIL (|has| |#1| (-388)))) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3921 (((-3 $ "failed") $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1165)) (|has| |#1| (-388))))) (-1324 (((-141) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))))) (-3990 (($ $ (-944)) NIL)) (-1376 (($ (-1 |#1| (-592)) $) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-592)) 17) (($ $ (-1103) (-592)) NIL) (($ $ (-658 (-1103)) (-658 (-592))) NIL)) (-1837 (($ $ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3319 (($ $ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|)) $) NIL (|has| |#1| (-388)))) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-1994 (($ (-592) (-1271 |#1| |#2| |#3|)) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-3162 (($ $) 25 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 |#2|)) 26 (|has| |#1| (-43 (-433 (-592)))))) (-3703 (($) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1165)) (|has| |#1| (-388))) CONST)) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-3856 (($ $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-323)) (|has| |#1| (-388))))) (-2039 (((-1271 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-574)) (|has| |#1| (-388))))) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-2807 (($ $ (-592)) NIL)) (-3616 (((-3 $ "failed") $ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-592))))) (($ $ (-1191) (-1271 |#1| |#2| |#3|)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-547 (-1191) (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-658 (-1191)) (-658 (-1271 |#1| |#2| |#3|))) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-547 (-1191) (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-658 (-310 (-1271 |#1| |#2| |#3|)))) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-325 (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-310 (-1271 |#1| |#2| |#3|))) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-325 (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-325 (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388)))) (($ $ (-658 (-1271 |#1| |#2| |#3|)) (-658 (-1271 |#1| |#2| |#3|))) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-325 (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388))))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ (-592)) NIL) (($ $ $) NIL (|has| (-592) (-1131))) (($ $ (-1271 |#1| |#2| |#3|)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-303 (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|))) (|has| |#1| (-388))))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-3644 (($ $ (-1 (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|))) NIL (|has| |#1| (-388))) (($ $ (-1 (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|)) (-790)) NIL (|has| |#1| (-388))) (($ $ (-1276 |#2|)) 24) (($ $ (-790)) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $) 23 (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191) (-790)) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-658 (-1191))) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))))) (-2782 (($ $) NIL (|has| |#1| (-388)))) (-1456 (((-1271 |#1| |#2| |#3|) $) NIL (|has| |#1| (-388)))) (-4525 (((-592) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1778 (((-565) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-633 (-565))) (|has| |#1| (-388)))) (((-405) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1049)) (|has| |#1| (-388)))) (((-237) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1049)) (|has| |#1| (-388)))) (((-914 (-405)) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-633 (-914 (-405)))) (|has| |#1| (-388)))) (((-914 (-592)) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-633 (-914 (-592)))) (|has| |#1| (-388))))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))))) (-1700 (($ $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL (|has| |#1| (-194))) (($ (-1271 |#1| |#2| |#3|)) NIL) (($ (-1276 |#2|)) 22) (($ (-1191)) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-1065 (-1191))) (|has| |#1| (-388)))) (($ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582)))) (($ (-433 (-592))) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-1065 (-592))) (|has| |#1| (-388))) (|has| |#1| (-43 (-433 (-592))))))) (-1937 ((|#1| $ (-592)) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-169)) (|has| |#1| (-388))) (|has| |#1| (-169))))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) 11)) (-2744 (((-1271 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-574)) (|has| |#1| (-388))))) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-931)) (|has| |#1| (-388))) (|has| |#1| (-582))))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-592)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-592)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1392 (($ $) NIL (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 19 T CONST)) (-4257 (($) 15 T CONST)) (-1940 (($ $ (-1 (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|))) NIL (|has| |#1| (-388))) (($ $ (-1 (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|)) (-790)) NIL (|has| |#1| (-388))) (($ $ (-790)) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-247)) (|has| |#1| (-388))) (|has| |#1| (-15 * (|#1| (-592) |#1|))))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191) (-790)) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-658 (-1191))) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191)))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-922 (-1191))) (|has| |#1| (-388))) (-12 (|has| |#1| (-15 * (|#1| (-592) |#1|))) (|has| |#1| (-922 (-1191))))))) (-3286 (((-141) $ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3273 (((-141) $ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3266 (((-141) $ $) NIL (-3836 (-12 (|has| (-1271 |#1| |#2| |#3|) (-842)) (|has| |#1| (-388))) (-12 (|has| (-1271 |#1| |#2| |#3|) (-869)) (|has| |#1| (-388)))))) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388))) (($ (-1271 |#1| |#2| |#3|) (-1271 |#1| |#2| |#3|)) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 20)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-1271 |#1| |#2| |#3|)) NIL (|has| |#1| (-388))) (($ (-1271 |#1| |#2| |#3|) $) NIL (|has| |#1| (-388))) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1243 |#1| |#2| |#3|) (-13 (-1241 |#1| (-1271 |#1| |#2| |#3|)) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) (-1075) (-1191) |#1|) (T -1243)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3)))) 
+(-13 (-1241 |#1| (-1271 |#1| |#2| |#3|)) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) 
+((-2112 (((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141)) 10)) (-3082 (((-444 |#1|) |#1|) 21)) (-4500 (((-444 |#1|) |#1|) 20))) 
+(((-1244 |#1|) (-10 -7 (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3082 ((-444 |#1|) |#1|)) (-15 -2112 ((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141)))) (-1255 (-592))) (T -1244)) 
+((-2112 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-5 *2 (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| *3) (|:| -1777 (-592))))))) (-5 *1 (-1244 *3)) (-4 *3 (-1255 (-592))))) (-3082 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1244 *3)) (-4 *3 (-1255 (-592))))) (-4500 (*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1244 *3)) (-4 *3 (-1255 (-592)))))) 
+(-10 -7 (-15 -4500 ((-444 |#1|) |#1|)) (-15 -3082 ((-444 |#1|) |#1|)) (-15 -2112 ((-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| |#1|) (|:| -1777 (-592)))))) |#1| (-141)))) 
+((-2731 (((-1171 |#2|) (-1 |#2| |#1|) (-1246 |#1|)) 23 (|has| |#1| (-867))) (((-1246 |#2|) (-1 |#2| |#1|) (-1246 |#1|)) 17))) 
+(((-1245 |#1| |#2|) (-10 -7 (-15 -2731 ((-1246 |#2|) (-1 |#2| |#1|) (-1246 |#1|))) (IF (|has| |#1| (-867)) (-15 -2731 ((-1171 |#2|) (-1 |#2| |#1|) (-1246 |#1|))) |noBranch|)) (-1225) (-1225)) (T -1245)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1246 *5)) (-4 *5 (-867)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1171 *6)) (-5 *1 (-1245 *5 *6)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1246 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1246 *6)) (-5 *1 (-1245 *5 *6))))) 
+(-10 -7 (-15 -2731 ((-1246 |#2|) (-1 |#2| |#1|) (-1246 |#1|))) (IF (|has| |#1| (-867)) (-15 -2731 ((-1171 |#2|) (-1 |#2| |#1|) (-1246 |#1|))) |noBranch|)) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1896 (($ |#1| |#1|) 9) (($ |#1|) 8)) (-2731 (((-1171 |#1|) (-1 |#1| |#1|) $) 41 (|has| |#1| (-867)))) (-2781 ((|#1| $) 14)) (-3000 ((|#1| $) 10)) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3008 (((-592) $) 18)) (-2369 ((|#1| $) 17)) (-3015 ((|#1| $) 11)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1840 (((-141) $) 16)) (-3098 (((-1171 |#1|) $) 38 (|has| |#1| (-867))) (((-1171 |#1|) (-658 $)) 37 (|has| |#1| (-867)))) (-1778 (($ |#1|) 25)) (-1683 (($ (-1113 |#1|)) 24) (((-877) $) 34 (|has| |#1| (-1119)))) (-3766 (($ |#1| |#1|) 20) (($ |#1|) 19)) (-2408 (($ $ (-592)) 13)) (-3255 (((-141) $ $) 27 (|has| |#1| (-1119))))) 
+(((-1246 |#1|) (-13 (-1112 |#1|) (-10 -8 (-15 -3766 ($ |#1|)) (-15 -1896 ($ |#1|)) (-15 -1683 ($ (-1113 |#1|))) (-15 -1840 ((-141) $)) (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|) (IF (|has| |#1| (-867)) (-6 (-1114 |#1| (-1171 |#1|))) |noBranch|))) (-1225)) (T -1246)) 
+((-3766 (*1 *1 *2) (-12 (-5 *1 (-1246 *2)) (-4 *2 (-1225)))) (-1896 (*1 *1 *2) (-12 (-5 *1 (-1246 *2)) (-4 *2 (-1225)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1113 *3)) (-4 *3 (-1225)) (-5 *1 (-1246 *3)))) (-1840 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1246 *3)) (-4 *3 (-1225))))) 
+(-13 (-1112 |#1|) (-10 -8 (-15 -3766 ($ |#1|)) (-15 -1896 ($ |#1|)) (-15 -1683 ($ (-1113 |#1|))) (-15 -1840 ((-141) $)) (IF (|has| |#1| (-1119)) (-6 (-1119)) |noBranch|) (IF (|has| |#1| (-867)) (-6 (-1114 |#1| (-1171 |#1|))) |noBranch|))) 
+((-2731 (((-1252 |#3| |#4|) (-1 |#4| |#2|) (-1252 |#1| |#2|)) 15))) 
+(((-1247 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 ((-1252 |#3| |#4|) (-1 |#4| |#2|) (-1252 |#1| |#2|)))) (-1191) (-1075) (-1191) (-1075)) (T -1247)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *6)) (-5 *4 (-1252 *5 *6)) (-14 *5 (-1191)) (-4 *6 (-1075)) (-4 *8 (-1075)) (-5 *2 (-1252 *7 *8)) (-5 *1 (-1247 *5 *6 *7 *8)) (-14 *7 (-1191))))) 
+(-10 -7 (-15 -2731 ((-1252 |#3| |#4|) (-1 |#4| |#2|) (-1252 |#1| |#2|)))) 
+((-3626 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) 21)) (-2088 ((|#1| |#3|) 13)) (-2219 ((|#3| |#3|) 19))) 
+(((-1248 |#1| |#2| |#3|) (-10 -7 (-15 -2088 (|#1| |#3|)) (-15 -2219 (|#3| |#3|)) (-15 -3626 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) (-582) (-1021 |#1|) (-1255 |#2|)) (T -1248)) 
+((-3626 (*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-1021 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-1248 *4 *5 *3)) (-4 *3 (-1255 *5)))) (-2219 (*1 *2 *2) (-12 (-4 *3 (-582)) (-4 *4 (-1021 *3)) (-5 *1 (-1248 *3 *4 *2)) (-4 *2 (-1255 *4)))) (-2088 (*1 *2 *3) (-12 (-4 *4 (-1021 *2)) (-4 *2 (-582)) (-5 *1 (-1248 *2 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -2088 (|#1| |#3|)) (-15 -2219 (|#3| |#3|)) (-15 -3626 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) 
+((-3712 (((-3 |#2| "failed") |#2| (-790) |#1|) 29)) (-2528 (((-3 |#2| "failed") |#2| (-790)) 30)) (-1909 (((-3 (-2 (|:| -1961 |#2|) (|:| -1954 |#2|)) "failed") |#2|) 42)) (-3640 (((-658 |#2|) |#2|) 44)) (-2446 (((-3 |#2| "failed") |#2| |#2|) 39))) 
+(((-1249 |#1| |#2|) (-10 -7 (-15 -2528 ((-3 |#2| "failed") |#2| (-790))) (-15 -3712 ((-3 |#2| "failed") |#2| (-790) |#1|)) (-15 -2446 ((-3 |#2| "failed") |#2| |#2|)) (-15 -1909 ((-3 (-2 (|:| -1961 |#2|) (|:| -1954 |#2|)) "failed") |#2|)) (-15 -3640 ((-658 |#2|) |#2|))) (-13 (-582) (-171)) (-1255 |#1|)) (T -1249)) 
+((-3640 (*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-171))) (-5 *2 (-658 *3)) (-5 *1 (-1249 *4 *3)) (-4 *3 (-1255 *4)))) (-1909 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-582) (-171))) (-5 *2 (-2 (|:| -1961 *3) (|:| -1954 *3))) (-5 *1 (-1249 *4 *3)) (-4 *3 (-1255 *4)))) (-2446 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-13 (-582) (-171))) (-5 *1 (-1249 *3 *2)) (-4 *2 (-1255 *3)))) (-3712 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-790)) (-4 *4 (-13 (-582) (-171))) (-5 *1 (-1249 *4 *2)) (-4 *2 (-1255 *4)))) (-2528 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-790)) (-4 *4 (-13 (-582) (-171))) (-5 *1 (-1249 *4 *2)) (-4 *2 (-1255 *4))))) 
+(-10 -7 (-15 -2528 ((-3 |#2| "failed") |#2| (-790))) (-15 -3712 ((-3 |#2| "failed") |#2| (-790) |#1|)) (-15 -2446 ((-3 |#2| "failed") |#2| |#2|)) (-15 -1909 ((-3 (-2 (|:| -1961 |#2|) (|:| -1954 |#2|)) "failed") |#2|)) (-15 -3640 ((-658 |#2|) |#2|))) 
+((-3669 (((-3 (-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) "failed") |#2| |#2|) 31))) 
+(((-1250 |#1| |#2|) (-10 -7 (-15 -3669 ((-3 (-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) "failed") |#2| |#2|))) (-582) (-1255 |#1|)) (T -1250)) 
+((-3669 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-582)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-1250 *4 *3)) (-4 *3 (-1255 *4))))) 
+(-10 -7 (-15 -3669 ((-3 (-2 (|:| -2230 |#2|) (|:| -3027 |#2|)) "failed") |#2| |#2|))) 
+((-2759 ((|#2| |#2| |#2|) 19)) (-3890 ((|#2| |#2| |#2|) 30)) (-3997 ((|#2| |#2| |#2| (-790) (-790)) 36))) 
+(((-1251 |#1| |#2|) (-10 -7 (-15 -2759 (|#2| |#2| |#2|)) (-15 -3890 (|#2| |#2| |#2|)) (-15 -3997 (|#2| |#2| |#2| (-790) (-790)))) (-1075) (-1255 |#1|)) (T -1251)) 
+((-3997 (*1 *2 *2 *2 *3 *3) (-12 (-5 *3 (-790)) (-4 *4 (-1075)) (-5 *1 (-1251 *4 *2)) (-4 *2 (-1255 *4)))) (-3890 (*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-1251 *3 *2)) (-4 *2 (-1255 *3)))) (-2759 (*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-1251 *3 *2)) (-4 *2 (-1255 *3))))) 
+(-10 -7 (-15 -2759 (|#2| |#2| |#2|)) (-15 -3890 (|#2| |#2| |#2|)) (-15 -3997 (|#2| |#2| |#2| (-790) (-790)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2651 (((-1280 |#2|) $ (-790)) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-2085 (($ (-1187 |#2|)) NIL)) (-4492 (((-1187 $) $ (-1103)) NIL) (((-1187 |#2|) $) NIL)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#2| (-582)))) (-1555 (($ $) NIL (|has| |#2| (-582)))) (-1313 (((-141) $) NIL (|has| |#2| (-582)))) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1103))) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3250 (($ $ $) NIL (|has| |#2| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3743 (($ $) NIL (|has| |#2| (-477)))) (-3164 (((-444 $) $) NIL (|has| |#2| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3652 (((-141) $ $) NIL (|has| |#2| (-388)))) (-1696 (($ $ (-790)) NIL)) (-1498 (($ $ (-790)) NIL)) (-1504 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#2| (-477)))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) NIL) (((-3 (-433 (-592)) "failed") $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) NIL (|has| |#2| (-1065 (-592)))) (((-3 (-1103) "failed") $) NIL)) (-2400 ((|#2| $) NIL) (((-433 (-592)) $) NIL (|has| |#2| (-1065 (-433 (-592))))) (((-592) $) NIL (|has| |#2| (-1065 (-592)))) (((-1103) $) NIL)) (-1544 (($ $ $ (-1103)) NIL (|has| |#2| (-194))) ((|#2| $ $) NIL (|has| |#2| (-194)))) (-1586 (($ $ $) NIL (|has| |#2| (-388)))) (-4593 (($ $) NIL)) (-3945 (((-706 (-592)) (-706 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) NIL (|has| |#2| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#2|)) (|:| |vec| (-1280 |#2|))) (-706 $) (-1280 $)) NIL) (((-706 |#2|) (-706 $)) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1599 (($ $ $) NIL (|has| |#2| (-388)))) (-3213 (($ $ $) NIL)) (-2133 (($ $ $) NIL (|has| |#2| (-582)))) (-4369 (((-2 (|:| -1487 |#2|) (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#2| (-388)))) (-3262 (($ $) NIL (|has| |#2| (-477))) (($ $ (-1103)) NIL (|has| |#2| (-477)))) (-4585 (((-658 $) $) NIL)) (-2802 (((-141) $) NIL (|has| |#2| (-931)))) (-4209 (($ $ |#2| (-790) $) NIL)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) NIL (-12 (|has| (-1103) (-908 (-405))) (|has| |#2| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) NIL (-12 (|has| (-1103) (-908 (-592))) (|has| |#2| (-908 (-592)))))) (-4346 (((-790) $ $) NIL (|has| |#2| (-582)))) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-3921 (((-3 $ "failed") $) NIL (|has| |#2| (-1165)))) (-4533 (($ (-1187 |#2|) (-1103)) NIL) (($ (-1187 $) (-1103)) NIL)) (-3990 (($ $ (-790)) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#2| (-388)))) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-4526 (($ |#2| (-790)) 17) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1103)) NIL) (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL)) (-4206 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1837 (($ $ $) NIL (|has| |#2| (-869)))) (-3319 (($ $ $) NIL (|has| |#2| (-869)))) (-2976 (($ (-1 (-790) (-790)) $) NIL)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-2070 (((-1187 |#2|) $) NIL)) (-3254 (((-3 (-1103) "failed") $) NIL)) (-4573 (($ $) NIL)) (-4579 ((|#2| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-2685 (((-1173) $) NIL)) (-3768 (((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790)) NIL)) (-4421 (((-3 (-658 $) "failed") $) NIL)) (-2947 (((-3 (-658 $) "failed") $) NIL)) (-2257 (((-3 (-2 (|:| |var| (-1103)) (|:| -3215 (-790))) "failed") $) NIL)) (-3162 (($ $) NIL (|has| |#2| (-43 (-433 (-592)))))) (-3703 (($) NIL (|has| |#2| (-1165)) CONST)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 ((|#2| $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#2| (-477)))) (-3548 (($ (-658 $)) NIL (|has| |#2| (-477))) (($ $ $) NIL (|has| |#2| (-477)))) (-4550 (($ $ (-790) |#2| $) NIL)) (-1416 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) NIL (|has| |#2| (-931)))) (-4500 (((-444 $) $) NIL (|has| |#2| (-931)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#2| (-388)))) (-3616 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-582))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#2| (-388)))) (-2806 (($ $ (-658 (-310 $))) NIL) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1103) |#2|) NIL) (($ $ (-658 (-1103)) (-658 |#2|)) NIL) (($ $ (-1103) $) NIL) (($ $ (-658 (-1103)) (-658 $)) NIL)) (-2769 (((-790) $) NIL (|has| |#2| (-388)))) (-3927 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-433 $) (-433 $) (-433 $)) NIL (|has| |#2| (-582))) ((|#2| (-433 $) |#2|) NIL (|has| |#2| (-388))) (((-433 $) $ (-433 $)) NIL (|has| |#2| (-582)))) (-4510 (((-3 $ "failed") $ (-790)) NIL)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#2| (-388)))) (-1482 (($ $ (-1103)) NIL (|has| |#2| (-194))) ((|#2| $) NIL (|has| |#2| (-194)))) (-3644 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) $) NIL)) (-4525 (((-790) $) NIL) (((-790) $ (-1103)) NIL) (((-658 (-790)) $ (-658 (-1103))) NIL)) (-1778 (((-914 (-405)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-405)))) (|has| |#2| (-633 (-914 (-405)))))) (((-914 (-592)) $) NIL (-12 (|has| (-1103) (-633 (-914 (-592)))) (|has| |#2| (-633 (-914 (-592)))))) (((-565) $) NIL (-12 (|has| (-1103) (-633 (-565))) (|has| |#2| (-633 (-565)))))) (-1554 ((|#2| $) NIL (|has| |#2| (-477))) (($ $ (-1103)) NIL (|has| |#2| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) NIL (-12 (|has| $ (-169)) (|has| |#2| (-931))))) (-1528 (((-3 $ "failed") $ $) NIL (|has| |#2| (-582))) (((-3 (-433 $) "failed") (-433 $) $) NIL (|has| |#2| (-582)))) (-1683 (((-877) $) 13) (($ (-592)) NIL) (($ |#2|) NIL) (($ (-1103)) NIL) (($ (-1276 |#1|)) 19) (($ (-433 (-592))) NIL (-3836 (|has| |#2| (-43 (-433 (-592)))) (|has| |#2| (-1065 (-433 (-592)))))) (($ $) NIL (|has| |#2| (-582)))) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-790)) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-1517 (((-3 $ "failed") $) NIL (-3836 (-12 (|has| $ (-169)) (|has| |#2| (-931))) (|has| |#2| (-169))))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| |#2| (-194)))) (-2537 (((-141) $ $) NIL (|has| |#2| (-582)))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4257 (($) 14 T CONST)) (-1940 (($ $ (-1103)) NIL) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) NIL) (($ $ (-1191)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1191) (-790)) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) NIL (|has| |#2| (-922 (-1191)))) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-3286 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3255 (((-141) $ $) NIL)) (-3279 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#2| (-869)))) (-3313 (($ $ |#2|) NIL (|has| |#2| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-433 (-592))) NIL (|has| |#2| (-43 (-433 (-592))))) (($ (-433 (-592)) $) NIL (|has| |#2| (-43 (-433 (-592))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-1252 |#1| |#2|) (-13 (-1255 |#2|) (-10 -8 (-15 -1683 ($ (-1276 |#1|))) (-15 -4550 ($ $ (-790) |#2| $)))) (-1191) (-1075)) (T -1252)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *3)) (-14 *3 (-1191)) (-5 *1 (-1252 *3 *4)) (-4 *4 (-1075)))) (-4550 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1252 *4 *3)) (-14 *4 (-1191)) (-4 *3 (-1075))))) 
+(-13 (-1255 |#2|) (-10 -8 (-15 -1683 ($ (-1276 |#1|))) (-15 -4550 ($ $ (-790) |#2| $)))) 
+((-2731 ((|#4| (-1 |#3| |#1|) |#2|) 22))) 
+(((-1253 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#4| (-1 |#3| |#1|) |#2|))) (-1075) (-1255 |#1|) (-1075) (-1255 |#3|)) (T -1253)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-4 *2 (-1255 *6)) (-5 *1 (-1253 *5 *4 *6 *2)) (-4 *4 (-1255 *5))))) 
+(-10 -7 (-15 -2731 (|#4| (-1 |#3| |#1|) |#2|))) 
+((-2651 (((-1280 |#2|) $ (-790)) 113)) (-4085 (((-658 (-1103)) $) 15)) (-4011 (($ (-1280 |#2|)) 115)) (-2085 (($ (-1187 |#2|)) 66)) (-2189 (((-790) $) NIL) (((-790) $ (-658 (-1103))) 18)) (-4043 (((-444 (-1187 $)) (-1187 $)) 185)) (-3743 (($ $) 175)) (-3164 (((-444 $) $) 173)) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 81)) (-1696 (($ $ (-790)) 70)) (-1498 (($ $ (-790)) 72)) (-1504 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) 131)) (-4368 (((-3 |#2| "failed") $) 118) (((-3 (-433 (-592)) "failed") $) NIL) (((-3 (-592) "failed") $) NIL) (((-3 (-1103) "failed") $) NIL)) (-2400 ((|#2| $) 116) (((-433 (-592)) $) NIL) (((-592) $) NIL) (((-1103) $) NIL)) (-2133 (($ $ $) 152)) (-4369 (((-2 (|:| -1487 |#2|) (|:| -2230 $) (|:| -3027 $)) $ $) 154)) (-4346 (((-790) $ $) 170)) (-3921 (((-3 $ "failed") $) 124)) (-4526 (($ |#2| (-790)) NIL) (($ $ (-1103) (-790)) 46) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-4206 (((-790) $) NIL) (((-790) $ (-1103)) 41) (((-658 (-790)) $ (-658 (-1103))) 42)) (-2070 (((-1187 |#2|) $) 58)) (-3254 (((-3 (-1103) "failed") $) 39)) (-3768 (((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790)) 69)) (-3162 (($ $) 196)) (-3703 (($) 120)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 182)) (-1416 (((-444 (-1187 $)) (-1187 $)) 87)) (-3339 (((-444 (-1187 $)) (-1187 $)) 85)) (-4500 (((-444 $) $) 105)) (-2806 (($ $ (-658 (-310 $))) 38) (($ $ (-310 $)) NIL) (($ $ $ $) NIL) (($ $ (-658 $) (-658 $)) NIL) (($ $ (-1103) |#2|) 31) (($ $ (-658 (-1103)) (-658 |#2|)) 28) (($ $ (-1103) $) 25) (($ $ (-658 (-1103)) (-658 $)) 23)) (-2769 (((-790) $) 188)) (-3927 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-433 $) (-433 $) (-433 $)) 148) ((|#2| (-433 $) |#2|) 187) (((-433 $) $ (-433 $)) 169)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 191)) (-3644 (($ $ (-1103)) 141) (($ $ (-658 (-1103))) NIL) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL) (($ $ (-790)) NIL) (($ $) 139) (($ $ (-1191)) NIL) (($ $ (-658 (-1191))) NIL) (($ $ (-1191) (-790)) NIL) (($ $ (-658 (-1191)) (-658 (-790))) NIL) (($ $ (-1 |#2| |#2|) (-790)) NIL) (($ $ (-1 |#2| |#2|)) 138) (($ $ (-1 |#2| |#2|) $) 135)) (-4525 (((-790) $) NIL) (((-790) $ (-1103)) 16) (((-658 (-790)) $ (-658 (-1103))) 20)) (-1554 ((|#2| $) NIL) (($ $ (-1103)) 126)) (-1528 (((-3 $ "failed") $ $) 162) (((-3 (-433 $) "failed") (-433 $) $) 158)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#2|) NIL) (($ (-1103)) 50) (($ (-433 (-592))) NIL) (($ $) NIL))) 
+(((-1254 |#1| |#2|) (-10 -8 (-15 -1683 (|#1| |#1|)) (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|))) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -3743 (|#1| |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -3703 (|#1|)) (-15 -3921 ((-3 |#1| "failed") |#1|)) (-15 -3927 ((-433 |#1|) |#1| (-433 |#1|))) (-15 -2769 ((-790) |#1|)) (-15 -4570 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -3162 (|#1| |#1|)) (-15 -3927 (|#2| (-433 |#1|) |#2|)) (-15 -1504 ((-2 (|:| |primePart| |#1|) (|:| |commonPart| |#1|)) |#1| |#1|)) (-15 -4369 ((-2 (|:| -1487 |#2|) (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -2133 (|#1| |#1| |#1|)) (-15 -1528 ((-3 (-433 |#1|) "failed") (-433 |#1|) |#1|)) (-15 -1528 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4346 ((-790) |#1| |#1|)) (-15 -3927 ((-433 |#1|) (-433 |#1|) (-433 |#1|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) |#1|)) (-15 -1498 (|#1| |#1| (-790))) (-15 -1696 (|#1| |#1| (-790))) (-15 -3768 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| (-790))) (-15 -2085 (|#1| (-1187 |#2|))) (-15 -2070 ((-1187 |#2|) |#1|)) (-15 -4011 (|#1| (-1280 |#2|))) (-15 -2651 ((-1280 |#2|) |#1| (-790))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3927 (|#1| |#1| |#1|)) (-15 -3927 (|#2| |#1| |#2|)) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -4043 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -3339 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -1416 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -3524 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|))) (-15 -1554 (|#1| |#1| (-1103))) (-15 -4085 ((-658 (-1103)) |#1|)) (-15 -2189 ((-790) |#1| (-658 (-1103)))) (-15 -2189 ((-790) |#1|)) (-15 -4526 (|#1| |#1| (-658 (-1103)) (-658 (-790)))) (-15 -4526 (|#1| |#1| (-1103) (-790))) (-15 -4206 ((-658 (-790)) |#1| (-658 (-1103)))) (-15 -4206 ((-790) |#1| (-1103))) (-15 -3254 ((-3 (-1103) "failed") |#1|)) (-15 -4525 ((-658 (-790)) |#1| (-658 (-1103)))) (-15 -4525 ((-790) |#1| (-1103))) (-15 -2400 ((-1103) |#1|)) (-15 -4368 ((-3 (-1103) "failed") |#1|)) (-15 -1683 (|#1| (-1103))) (-15 -2806 (|#1| |#1| (-658 (-1103)) (-658 |#1|))) (-15 -2806 (|#1| |#1| (-1103) |#1|)) (-15 -2806 (|#1| |#1| (-658 (-1103)) (-658 |#2|))) (-15 -2806 (|#1| |#1| (-1103) |#2|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -4525 ((-790) |#1|)) (-15 -4526 (|#1| |#2| (-790))) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4206 ((-790) |#1|)) (-15 -1554 (|#2| |#1|)) (-15 -3644 (|#1| |#1| (-658 (-1103)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1103) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1103)))) (-15 -3644 (|#1| |#1| (-1103))) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) (-1255 |#2|) (-1075)) (T -1254)) 
+NIL 
+(-10 -8 (-15 -1683 (|#1| |#1|)) (-15 -2536 ((-1187 |#1|) (-1187 |#1|) (-1187 |#1|))) (-15 -3164 ((-444 |#1|) |#1|)) (-15 -3743 (|#1| |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -3703 (|#1|)) (-15 -3921 ((-3 |#1| "failed") |#1|)) (-15 -3927 ((-433 |#1|) |#1| (-433 |#1|))) (-15 -2769 ((-790) |#1|)) (-15 -4570 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -3162 (|#1| |#1|)) (-15 -3927 (|#2| (-433 |#1|) |#2|)) (-15 -1504 ((-2 (|:| |primePart| |#1|) (|:| |commonPart| |#1|)) |#1| |#1|)) (-15 -4369 ((-2 (|:| -1487 |#2|) (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| |#1|)) (-15 -2133 (|#1| |#1| |#1|)) (-15 -1528 ((-3 (-433 |#1|) "failed") (-433 |#1|) |#1|)) (-15 -1528 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4346 ((-790) |#1| |#1|)) (-15 -3927 ((-433 |#1|) (-433 |#1|) (-433 |#1|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) |#1|)) (-15 -1498 (|#1| |#1| (-790))) (-15 -1696 (|#1| |#1| (-790))) (-15 -3768 ((-2 (|:| -2230 |#1|) (|:| -3027 |#1|)) |#1| (-790))) (-15 -2085 (|#1| (-1187 |#2|))) (-15 -2070 ((-1187 |#2|) |#1|)) (-15 -4011 (|#1| (-1280 |#2|))) (-15 -2651 ((-1280 |#2|) |#1| (-790))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|))) (-15 -3644 (|#1| |#1| (-1 |#2| |#2|) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1191) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1191)))) (-15 -3644 (|#1| |#1| (-1191))) (-15 -3644 (|#1| |#1|)) (-15 -3644 (|#1| |#1| (-790))) (-15 -3927 (|#1| |#1| |#1|)) (-15 -3927 (|#2| |#1| |#2|)) (-15 -4500 ((-444 |#1|) |#1|)) (-15 -4043 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -3339 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -1416 ((-444 (-1187 |#1|)) (-1187 |#1|))) (-15 -3524 ((-3 (-658 (-1187 |#1|)) "failed") (-658 (-1187 |#1|)) (-1187 |#1|))) (-15 -1554 (|#1| |#1| (-1103))) (-15 -4085 ((-658 (-1103)) |#1|)) (-15 -2189 ((-790) |#1| (-658 (-1103)))) (-15 -2189 ((-790) |#1|)) (-15 -4526 (|#1| |#1| (-658 (-1103)) (-658 (-790)))) (-15 -4526 (|#1| |#1| (-1103) (-790))) (-15 -4206 ((-658 (-790)) |#1| (-658 (-1103)))) (-15 -4206 ((-790) |#1| (-1103))) (-15 -3254 ((-3 (-1103) "failed") |#1|)) (-15 -4525 ((-658 (-790)) |#1| (-658 (-1103)))) (-15 -4525 ((-790) |#1| (-1103))) (-15 -2400 ((-1103) |#1|)) (-15 -4368 ((-3 (-1103) "failed") |#1|)) (-15 -1683 (|#1| (-1103))) (-15 -2806 (|#1| |#1| (-658 (-1103)) (-658 |#1|))) (-15 -2806 (|#1| |#1| (-1103) |#1|)) (-15 -2806 (|#1| |#1| (-658 (-1103)) (-658 |#2|))) (-15 -2806 (|#1| |#1| (-1103) |#2|)) (-15 -2806 (|#1| |#1| (-658 |#1|) (-658 |#1|))) (-15 -2806 (|#1| |#1| |#1| |#1|)) (-15 -2806 (|#1| |#1| (-310 |#1|))) (-15 -2806 (|#1| |#1| (-658 (-310 |#1|)))) (-15 -4525 ((-790) |#1|)) (-15 -4526 (|#1| |#2| (-790))) (-15 -2400 ((-592) |#1|)) (-15 -4368 ((-3 (-592) "failed") |#1|)) (-15 -2400 ((-433 (-592)) |#1|)) (-15 -4368 ((-3 (-433 (-592)) "failed") |#1|)) (-15 -1683 (|#1| |#2|)) (-15 -4368 ((-3 |#2| "failed") |#1|)) (-15 -2400 (|#2| |#1|)) (-15 -4206 ((-790) |#1|)) (-15 -1554 (|#2| |#1|)) (-15 -3644 (|#1| |#1| (-658 (-1103)) (-658 (-790)))) (-15 -3644 (|#1| |#1| (-1103) (-790))) (-15 -3644 (|#1| |#1| (-658 (-1103)))) (-15 -3644 (|#1| |#1| (-1103))) (-15 -1683 (|#1| (-592))) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2651 (((-1280 |#1|) $ (-790)) 219)) (-4085 (((-658 (-1103)) $) 109)) (-4011 (($ (-1280 |#1|)) 218)) (-2085 (($ (-1187 |#1|)) 216)) (-4492 (((-1187 $) $ (-1103)) 124) (((-1187 |#1|) $) 123)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 85 (|has| |#1| (-582)))) (-1555 (($ $) 86 (|has| |#1| (-582)))) (-1313 (((-141) $) 88 (|has| |#1| (-582)))) (-2189 (((-790) $) 111) (((-790) $ (-658 (-1103))) 110)) (-2350 (((-3 $ "failed") $ $) 18)) (-3250 (($ $ $) 203 (|has| |#1| (-582)))) (-4043 (((-444 (-1187 $)) (-1187 $)) 99 (|has| |#1| (-931)))) (-3743 (($ $) 97 (|has| |#1| (-477)))) (-3164 (((-444 $) $) 96 (|has| |#1| (-477)))) (-3524 (((-3 (-658 (-1187 $)) "failed") (-658 (-1187 $)) (-1187 $)) 102 (|has| |#1| (-931)))) (-3652 (((-141) $ $) 188 (|has| |#1| (-388)))) (-1696 (($ $ (-790)) 211)) (-1498 (($ $ (-790)) 210)) (-1504 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) 198 (|has| |#1| (-477)))) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 163) (((-3 (-433 (-592)) "failed") $) 161 (|has| |#1| (-1065 (-433 (-592))))) (((-3 (-592) "failed") $) 159 (|has| |#1| (-1065 (-592)))) (((-3 (-1103) "failed") $) 135)) (-2400 ((|#1| $) 164) (((-433 (-592)) $) 160 (|has| |#1| (-1065 (-433 (-592))))) (((-592) $) 158 (|has| |#1| (-1065 (-592)))) (((-1103) $) 134)) (-1544 (($ $ $ (-1103)) 107 (|has| |#1| (-194))) ((|#1| $ $) 206 (|has| |#1| (-194)))) (-1586 (($ $ $) 192 (|has| |#1| (-388)))) (-4593 (($ $) 153)) (-3945 (((-706 (-592)) (-706 $)) 133 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 (-592))) (|:| |vec| (-1280 (-592)))) (-706 $) (-1280 $)) 132 (|has| |#1| (-654 (-592)))) (((-2 (|:| -3253 (-706 |#1|)) (|:| |vec| (-1280 |#1|))) (-706 $) (-1280 $)) 131) (((-706 |#1|) (-706 $)) 130)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 191 (|has| |#1| (-388)))) (-3213 (($ $ $) 209)) (-2133 (($ $ $) 200 (|has| |#1| (-582)))) (-4369 (((-2 (|:| -1487 |#1|) (|:| -2230 $) (|:| -3027 $)) $ $) 199 (|has| |#1| (-582)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 186 (|has| |#1| (-388)))) (-3262 (($ $) 175 (|has| |#1| (-477))) (($ $ (-1103)) 104 (|has| |#1| (-477)))) (-4585 (((-658 $) $) 108)) (-2802 (((-141) $) 95 (|has| |#1| (-931)))) (-4209 (($ $ |#1| (-790) $) 171)) (-3412 (((-911 (-405) $) $ (-914 (-405)) (-911 (-405) $)) 82 (-12 (|has| (-1103) (-908 (-405))) (|has| |#1| (-908 (-405))))) (((-911 (-592) $) $ (-914 (-592)) (-911 (-592) $)) 81 (-12 (|has| (-1103) (-908 (-592))) (|has| |#1| (-908 (-592)))))) (-4346 (((-790) $ $) 204 (|has| |#1| (-582)))) (-3558 (((-141) $) 30)) (-4036 (((-790) $) 168)) (-3921 (((-3 $ "failed") $) 184 (|has| |#1| (-1165)))) (-4533 (($ (-1187 |#1|) (-1103)) 116) (($ (-1187 $) (-1103)) 115)) (-3990 (($ $ (-790)) 215)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 195 (|has| |#1| (-388)))) (-3108 (((-658 $) $) 125)) (-2027 (((-141) $) 151)) (-4526 (($ |#1| (-790)) 152) (($ $ (-1103) (-790)) 118) (($ $ (-658 (-1103)) (-658 (-790))) 117)) (-1446 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $ (-1103)) 119) (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 213)) (-4206 (((-790) $) 169) (((-790) $ (-1103)) 121) (((-658 (-790)) $ (-658 (-1103))) 120)) (-1837 (($ $ $) 77 (|has| |#1| (-869)))) (-3319 (($ $ $) 76 (|has| |#1| (-869)))) (-2976 (($ (-1 (-790) (-790)) $) 170)) (-2731 (($ (-1 |#1| |#1|) $) 150)) (-2070 (((-1187 |#1|) $) 217)) (-3254 (((-3 (-1103) "failed") $) 122)) (-4573 (($ $) 148)) (-4579 ((|#1| $) 147)) (-1389 (((-2 (|:| |llcmres| $) (|:| |coeff1| $) (|:| |coeff2| $)) $ $) 89 (|has| |#1| (-477)))) (-2750 (($ (-658 $)) 93 (|has| |#1| (-477))) (($ $ $) 92 (|has| |#1| (-477)))) (-2685 (((-1173) $) 9)) (-3768 (((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790)) 212)) (-4421 (((-3 (-658 $) "failed") $) 113)) (-2947 (((-3 (-658 $) "failed") $) 114)) (-2257 (((-3 (-2 (|:| |var| (-1103)) (|:| -3215 (-790))) "failed") $) 112)) (-3162 (($ $) 196 (|has| |#1| (-43 (-433 (-592)))))) (-3703 (($) 183 (|has| |#1| (-1165)) CONST)) (-2951 (((-1137) $) 10)) (-4559 (((-141) $) 165)) (-4565 ((|#1| $) 166)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 94 (|has| |#1| (-477)))) (-3548 (($ (-658 $)) 91 (|has| |#1| (-477))) (($ $ $) 90 (|has| |#1| (-477)))) (-1416 (((-444 (-1187 $)) (-1187 $)) 101 (|has| |#1| (-931)))) (-3339 (((-444 (-1187 $)) (-1187 $)) 100 (|has| |#1| (-931)))) (-4500 (((-444 $) $) 98 (|has| |#1| (-931)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 194 (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 193 (|has| |#1| (-388)))) (-3616 (((-3 $ "failed") $ |#1|) 173 (|has| |#1| (-582))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 187 (|has| |#1| (-388)))) (-2806 (($ $ (-658 (-310 $))) 144) (($ $ (-310 $)) 143) (($ $ $ $) 142) (($ $ (-658 $) (-658 $)) 141) (($ $ (-1103) |#1|) 140) (($ $ (-658 (-1103)) (-658 |#1|)) 139) (($ $ (-1103) $) 138) (($ $ (-658 (-1103)) (-658 $)) 137)) (-2769 (((-790) $) 189 (|has| |#1| (-388)))) (-3927 ((|#1| $ |#1|) 237) (($ $ $) 236) (((-433 $) (-433 $) (-433 $)) 205 (|has| |#1| (-582))) ((|#1| (-433 $) |#1|) 197 (|has| |#1| (-388))) (((-433 $) $ (-433 $)) 185 (|has| |#1| (-582)))) (-4510 (((-3 $ "failed") $ (-790)) 214)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 190 (|has| |#1| (-388)))) (-1482 (($ $ (-1103)) 106 (|has| |#1| (-194))) ((|#1| $) 207 (|has| |#1| (-194)))) (-3644 (($ $ (-1103)) 41) (($ $ (-658 (-1103))) 40) (($ $ (-1103) (-790)) 39) (($ $ (-658 (-1103)) (-658 (-790))) 38) (($ $ (-790)) 234) (($ $) 232) (($ $ (-1191)) 231 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 230 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 229 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) 228 (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) 221) (($ $ (-1 |#1| |#1|)) 220) (($ $ (-1 |#1| |#1|) $) 208)) (-4525 (((-790) $) 149) (((-790) $ (-1103)) 129) (((-658 (-790)) $ (-658 (-1103))) 128)) (-1778 (((-914 (-405)) $) 80 (-12 (|has| (-1103) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405)))))) (((-914 (-592)) $) 79 (-12 (|has| (-1103) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592)))))) (((-565) $) 78 (-12 (|has| (-1103) (-633 (-565))) (|has| |#1| (-633 (-565)))))) (-1554 ((|#1| $) 174 (|has| |#1| (-477))) (($ $ (-1103)) 105 (|has| |#1| (-477)))) (-2288 (((-3 (-1280 $) "failed") (-706 $)) 103 (-1732 (|has| $ (-169)) (|has| |#1| (-931))))) (-1528 (((-3 $ "failed") $ $) 202 (|has| |#1| (-582))) (((-3 (-433 $) "failed") (-433 $) $) 201 (|has| |#1| (-582)))) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 162) (($ (-1103)) 136) (($ (-433 (-592))) 70 (-3836 (|has| |#1| (-1065 (-433 (-592)))) (|has| |#1| (-43 (-433 (-592)))))) (($ $) 83 (|has| |#1| (-582)))) (-1647 (((-658 |#1|) $) 167)) (-1937 ((|#1| $ (-790)) 154) (($ $ (-1103) (-790)) 127) (($ $ (-658 (-1103)) (-658 (-790))) 126)) (-1517 (((-3 $ "failed") $) 71 (-3836 (-1732 (|has| $ (-169)) (|has| |#1| (-931))) (|has| |#1| (-169))))) (-4010 (((-790)) 28)) (-4064 (($ $ $ (-790)) 172 (|has| |#1| (-194)))) (-2537 (((-141) $ $) 87 (|has| |#1| (-582)))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-1103)) 37) (($ $ (-658 (-1103))) 36) (($ $ (-1103) (-790)) 35) (($ $ (-658 (-1103)) (-658 (-790))) 34) (($ $ (-790)) 235) (($ $) 233) (($ $ (-1191)) 227 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191))) 226 (|has| |#1| (-922 (-1191)))) (($ $ (-1191) (-790)) 225 (|has| |#1| (-922 (-1191)))) (($ $ (-658 (-1191)) (-658 (-790))) 224 (|has| |#1| (-922 (-1191)))) (($ $ (-1 |#1| |#1|) (-790)) 223) (($ $ (-1 |#1| |#1|)) 222)) (-3286 (((-141) $ $) 74 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 73 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 6)) (-3279 (((-141) $ $) 75 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 72 (|has| |#1| (-869)))) (-3313 (($ $ |#1|) 155 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 157 (|has| |#1| (-43 (-433 (-592))))) (($ (-433 (-592)) $) 156 (|has| |#1| (-43 (-433 (-592))))) (($ |#1| $) 146) (($ $ |#1|) 145))) 
+(((-1255 |#1|) (-1311) (-1075)) (T -1255)) 
+((-2651 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-1255 *4)) (-4 *4 (-1075)) (-5 *2 (-1280 *4)))) (-4011 (*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1075)) (-4 *1 (-1255 *3)))) (-2070 (*1 *2 *1) (-12 (-4 *1 (-1255 *3)) (-4 *3 (-1075)) (-5 *2 (-1187 *3)))) (-2085 (*1 *1 *2) (-12 (-5 *2 (-1187 *3)) (-4 *3 (-1075)) (-4 *1 (-1255 *3)))) (-3990 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)))) (-4510 (*1 *1 *1 *2) (|partial| -12 (-5 *2 (-790)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)))) (-1446 (*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1255 *3)))) (-3768 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *4 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1255 *4)))) (-1696 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)))) (-1498 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)))) (-3213 (*1 *1 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)))) (-3644 (*1 *1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)))) (-1482 (*1 *2 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-194)))) (-1544 (*1 *2 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-194)))) (-3927 (*1 *2 *2 *2) (-12 (-5 *2 (-433 *1)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)) (-4 *3 (-582)))) (-4346 (*1 *2 *1 *1) (-12 (-4 *1 (-1255 *3)) (-4 *3 (-1075)) (-4 *3 (-582)) (-5 *2 (-790)))) (-3250 (*1 *1 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-582)))) (-1528 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-582)))) (-1528 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-433 *1)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)) (-4 *3 (-582)))) (-2133 (*1 *1 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-582)))) (-4369 (*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -1487 *3) (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1255 *3)))) (-1504 (*1 *2 *1 *1) (-12 (-4 *3 (-477)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| |primePart| *1) (|:| |commonPart| *1))) (-4 *1 (-1255 *3)))) (-3927 (*1 *2 *3 *2) (-12 (-5 *3 (-433 *1)) (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-3162 (*1 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-43 (-433 (-592))))))) 
+(-13 (-977 |t#1| (-790) (-1103)) (-303 |t#1| |t#1|) (-303 $ $) (-247) (-245 |t#1|) (-10 -8 (-15 -2651 ((-1280 |t#1|) $ (-790))) (-15 -4011 ($ (-1280 |t#1|))) (-15 -2070 ((-1187 |t#1|) $)) (-15 -2085 ($ (-1187 |t#1|))) (-15 -3990 ($ $ (-790))) (-15 -4510 ((-3 $ "failed") $ (-790))) (-15 -1446 ((-2 (|:| -2230 $) (|:| -3027 $)) $ $)) (-15 -3768 ((-2 (|:| -2230 $) (|:| -3027 $)) $ (-790))) (-15 -1696 ($ $ (-790))) (-15 -1498 ($ $ (-790))) (-15 -3213 ($ $ $)) (-15 -3644 ($ $ (-1 |t#1| |t#1|) $)) (IF (|has| |t#1| (-1165)) (-6 (-1165)) |noBranch|) (IF (|has| |t#1| (-194)) (PROGN (-15 -1482 (|t#1| $)) (-15 -1544 (|t#1| $ $))) |noBranch|) (IF (|has| |t#1| (-582)) (PROGN (-6 (-303 (-433 $) (-433 $))) (-15 -3927 ((-433 $) (-433 $) (-433 $))) (-15 -4346 ((-790) $ $)) (-15 -3250 ($ $ $)) (-15 -1528 ((-3 $ "failed") $ $)) (-15 -1528 ((-3 (-433 $) "failed") (-433 $) $)) (-15 -2133 ($ $ $)) (-15 -4369 ((-2 (|:| -1487 |t#1|) (|:| -2230 $) (|:| -3027 $)) $ $))) |noBranch|) (IF (|has| |t#1| (-477)) (-15 -1504 ((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $)) |noBranch|) (IF (|has| |t#1| (-388)) (PROGN (-6 (-323)) (-6 -4621) (-15 -3927 (|t#1| (-433 $) |t#1|))) |noBranch|) (IF (|has| |t#1| (-43 (-433 (-592)))) (-15 -3162 ($ $)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-790)) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-388))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-633 (-565)) -12 (|has| (-1103) (-633 (-565))) (|has| |#1| (-633 (-565)))) ((-633 (-914 (-405))) -12 (|has| (-1103) (-633 (-914 (-405)))) (|has| |#1| (-633 (-914 (-405))))) ((-633 (-914 (-592))) -12 (|has| (-1103) (-633 (-914 (-592)))) (|has| |#1| (-633 (-914 (-592))))) ((-245 |#1|) . T) ((-247) . T) ((-303 (-433 $) (-433 $)) |has| |#1| (-582)) ((-303 |#1| |#1|) . T) ((-303 $ $) . T) ((-307) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-388))) ((-323) |has| |#1| (-388)) ((-325 $) . T) ((-346 |#1| (-790)) . T) ((-403 |#1|) . T) ((-437 |#1|) . T) ((-477) -3836 (|has| |#1| (-931)) (|has| |#1| (-477)) (|has| |#1| (-388))) ((-547 (-1103) |#1|) . T) ((-547 (-1103) $) . T) ((-547 $ $) . T) ((-582) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-388))) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) -3836 (|has| |#1| (-931)) (|has| |#1| (-477)) (|has| |#1| (-388))) ((-654 (-592)) |has| |#1| (-654 (-592))) ((-654 |#1|) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-388))) ((-743) . T) ((-869) |has| |#1| (-869)) ((-922 (-1103)) . T) ((-922 (-1191)) |has| |#1| (-922 (-1191))) ((-908 (-405)) -12 (|has| (-1103) (-908 (-405))) (|has| |#1| (-908 (-405)))) ((-908 (-592)) -12 (|has| (-1103) (-908 (-592))) (|has| |#1| (-908 (-592)))) ((-977 |#1| (-790) (-1103)) . T) ((-931) |has| |#1| (-931)) ((-943) |has| |#1| (-388)) ((-1065 (-433 (-592))) |has| |#1| (-1065 (-433 (-592)))) ((-1065 (-592)) |has| |#1| (-1065 (-592))) ((-1065 (-1103)) . T) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-931)) (|has| |#1| (-582)) (|has| |#1| (-477)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1165) |has| |#1| (-1165)) ((-1235) |has| |#1| (-931))) 
+((-4085 (((-658 (-1103)) $) 28)) (-4593 (($ $) 25)) (-4526 (($ |#2| |#3|) NIL) (($ $ (-1103) |#3|) 22) (($ $ (-658 (-1103)) (-658 |#3|)) 20)) (-4573 (($ $) 14)) (-4579 ((|#2| $) 12)) (-4525 ((|#3| $) 10))) 
+(((-1256 |#1| |#2| |#3|) (-10 -8 (-15 -4085 ((-658 (-1103)) |#1|)) (-15 -4526 (|#1| |#1| (-658 (-1103)) (-658 |#3|))) (-15 -4526 (|#1| |#1| (-1103) |#3|)) (-15 -4593 (|#1| |#1|)) (-15 -4526 (|#1| |#2| |#3|)) (-15 -4525 (|#3| |#1|)) (-15 -4573 (|#1| |#1|)) (-15 -4579 (|#2| |#1|))) (-1257 |#2| |#3|) (-1075) (-814)) (T -1256)) 
+NIL 
+(-10 -8 (-15 -4085 ((-658 (-1103)) |#1|)) (-15 -4526 (|#1| |#1| (-658 (-1103)) (-658 |#3|))) (-15 -4526 (|#1| |#1| (-1103) |#3|)) (-15 -4593 (|#1| |#1|)) (-15 -4526 (|#1| |#2| |#3|)) (-15 -4525 (|#3| |#1|)) (-15 -4573 (|#1| |#1|)) (-15 -4579 (|#2| |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 (-1103)) $) 70)) (-3983 (((-1191) $) 98)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2306 (($ $ |#2|) 93) (($ $ |#2| |#2|) 92)) (-2982 (((-1171 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 100)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-4593 (($ $) 59)) (-3371 (((-3 $ "failed") $) 33)) (-2273 (((-141) $) 69)) (-4346 ((|#2| $) 95) ((|#2| $ |#2|) 94)) (-3558 (((-141) $) 30)) (-3990 (($ $ (-944)) 96)) (-2027 (((-141) $) 61)) (-4526 (($ |#1| |#2|) 60) (($ $ (-1103) |#2|) 72) (($ $ (-658 (-1103)) (-658 |#2|)) 71)) (-2731 (($ (-1 |#1| |#1|) $) 62)) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2807 (($ $ |#2|) 90)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582)))) (-2806 (((-1171 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| |#2|))))) (-3927 ((|#1| $ |#2|) 99) (($ $ $) 76 (|has| |#2| (-1131)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) 84 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1191) (-790)) 83 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-658 (-1191))) 82 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1191)) 81 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-790)) 79 (|has| |#1| (-15 * (|#1| |#2| |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (-4525 ((|#2| $) 63)) (-1700 (($ $) 68)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 56 (|has| |#1| (-43 (-433 (-592))))) (($ $) 48 (|has| |#1| (-582))) (($ |#1|) 46 (|has| |#1| (-194)))) (-1937 ((|#1| $ |#2|) 58)) (-1517 (((-3 $ "failed") $) 47 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-2838 ((|#1| $) 97)) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-2642 ((|#1| $ |#2|) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| |#2|))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) 88 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1191) (-790)) 87 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-658 (-1191))) 86 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1191)) 85 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-790)) 80 (|has| |#1| (-15 * (|#1| |#2| |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1257 |#1| |#2|) (-1311) (-1075) (-814)) (T -1257)) 
+((-2982 (*1 *2 *1) (-12 (-4 *1 (-1257 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-1171 (-2 (|:| |k| *4) (|:| |c| *3)))))) (-3927 (*1 *2 *1 *3) (-12 (-4 *1 (-1257 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) (-3983 (*1 *2 *1) (-12 (-4 *1 (-1257 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-1191)))) (-2838 (*1 *2 *1) (-12 (-4 *1 (-1257 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) (-3990 (*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-1257 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)))) (-4346 (*1 *2 *1) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) (-4346 (*1 *2 *1 *2) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) (-2306 (*1 *1 *1 *2) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) (-2306 (*1 *1 *1 *2 *2) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) (-2642 (*1 *2 *1 *3) (-12 (-4 *1 (-1257 *2 *3)) (-4 *3 (-814)) (|has| *2 (-15 ** (*2 *2 *3))) (|has| *2 (-15 -1683 (*2 (-1191)))) (-4 *2 (-1075)))) (-2807 (*1 *1 *1 *2) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) (-2806 (*1 *2 *1 *3) (-12 (-4 *1 (-1257 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (|has| *3 (-15 ** (*3 *3 *4))) (-5 *2 (-1171 *3))))) 
+(-13 (-1002 |t#1| |t#2| (-1103)) (-10 -8 (-15 -2982 ((-1171 (-2 (|:| |k| |t#2|) (|:| |c| |t#1|))) $)) (-15 -3927 (|t#1| $ |t#2|)) (-15 -3983 ((-1191) $)) (-15 -2838 (|t#1| $)) (-15 -3990 ($ $ (-944))) (-15 -4346 (|t#2| $)) (-15 -4346 (|t#2| $ |t#2|)) (-15 -2306 ($ $ |t#2|)) (-15 -2306 ($ $ |t#2| |t#2|)) (IF (|has| |t#1| (-15 -1683 (|t#1| (-1191)))) (IF (|has| |t#1| (-15 ** (|t#1| |t#1| |t#2|))) (-15 -2642 (|t#1| $ |t#2|)) |noBranch|) |noBranch|) (-15 -2807 ($ $ |t#2|)) (IF (|has| |t#2| (-1131)) (-6 (-303 $ $)) |noBranch|) (IF (|has| |t#1| (-15 * (|t#1| |t#2| |t#1|))) (PROGN (-6 (-247)) (IF (|has| |t#1| (-922 (-1191))) (-6 (-922 (-1191))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-15 ** (|t#1| |t#1| |t#2|))) (-15 -2806 ((-1171 |t#1|) $ |t#1|)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) |has| |#1| (-582)) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-247) |has| |#1| (-15 * (|#1| |#2| |#1|))) ((-303 $ $) |has| |#2| (-1131)) ((-307) |has| |#1| (-582)) ((-582) |has| |#1| (-582)) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) |has| |#1| (-582)) ((-743) . T) ((-922 (-1191)) -12 (|has| |#1| (-15 * (|#1| |#2| |#1|))) (|has| |#1| (-922 (-1191)))) ((-1002 |#1| |#2| (-1103)) . T) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-3743 ((|#2| |#2|) 12)) (-3164 (((-444 |#2|) |#2|) 14)) (-2964 (((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-592))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-592)))) 30))) 
+(((-1258 |#1| |#2|) (-10 -7 (-15 -3164 ((-444 |#2|) |#2|)) (-15 -3743 (|#2| |#2|)) (-15 -2964 ((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-592))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-592)))))) (-582) (-13 (-1255 |#1|) (-582) (-10 -8 (-15 -3548 ($ $ $))))) (T -1258)) 
+((-2964 (*1 *2 *2) (-12 (-5 *2 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (-592)))) (-4 *4 (-13 (-1255 *3) (-582) (-10 -8 (-15 -3548 ($ $ $))))) (-4 *3 (-582)) (-5 *1 (-1258 *3 *4)))) (-3743 (*1 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-1258 *3 *2)) (-4 *2 (-13 (-1255 *3) (-582) (-10 -8 (-15 -3548 ($ $ $))))))) (-3164 (*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-444 *3)) (-5 *1 (-1258 *4 *3)) (-4 *3 (-13 (-1255 *4) (-582) (-10 -8 (-15 -3548 ($ $ $)))))))) 
+(-10 -7 (-15 -3164 ((-444 |#2|) |#2|)) (-15 -3743 (|#2| |#2|)) (-15 -2964 ((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-592))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-592)))))) 
+((-2731 (((-1264 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1264 |#1| |#3| |#5|)) 23))) 
+(((-1259 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2731 ((-1264 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1264 |#1| |#3| |#5|)))) (-1075) (-1075) (-1191) (-1191) |#1| |#2|) (T -1259)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1264 *5 *7 *9)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-14 *7 (-1191)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1264 *6 *8 *10)) (-5 *1 (-1259 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1191))))) 
+(-10 -7 (-15 -2731 ((-1264 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1264 |#1| |#3| |#5|)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 (-1103)) $) 70)) (-3983 (((-1191) $) 98)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2306 (($ $ (-433 (-592))) 93) (($ $ (-433 (-592)) (-433 (-592))) 92)) (-2982 (((-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|))) $) 100)) (-1588 (($ $) 127 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 110 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 154 (|has| |#1| (-388)))) (-3164 (((-444 $) $) 155 (|has| |#1| (-388)))) (-1442 (($ $) 109 (|has| |#1| (-43 (-433 (-592)))))) (-3652 (((-141) $ $) 145 (|has| |#1| (-388)))) (-1575 (($ $) 126 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 111 (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-790) (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|)))) 164)) (-1601 (($ $) 125 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 112 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) 16 T CONST)) (-1586 (($ $ $) 149 (|has| |#1| (-388)))) (-4593 (($ $) 59)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 148 (|has| |#1| (-388)))) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 143 (|has| |#1| (-388)))) (-2802 (((-141) $) 156 (|has| |#1| (-388)))) (-2273 (((-141) $) 69)) (-1435 (($) 137 (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-433 (-592)) $) 95) (((-433 (-592)) $ (-433 (-592))) 94)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 108 (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) 96) (($ $ (-433 (-592))) 163)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 152 (|has| |#1| (-388)))) (-2027 (((-141) $) 61)) (-4526 (($ |#1| (-433 (-592))) 60) (($ $ (-1103) (-433 (-592))) 72) (($ $ (-658 (-1103)) (-658 (-433 (-592)))) 71)) (-2731 (($ (-1 |#1| |#1|) $) 62)) (-4546 (($ $) 134 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-2750 (($ (-658 $)) 141 (|has| |#1| (-388))) (($ $ $) 140 (|has| |#1| (-388)))) (-2685 (((-1173) $) 9)) (-4552 (($ $) 157 (|has| |#1| (-388)))) (-3162 (($ $) 162 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 161 (-3836 (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-987)) (|has| |#1| (-1211)) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-43 (-433 (-592)))))))) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 142 (|has| |#1| (-388)))) (-3548 (($ (-658 $)) 139 (|has| |#1| (-388))) (($ $ $) 138 (|has| |#1| (-388)))) (-4500 (((-444 $) $) 153 (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 150 (|has| |#1| (-388)))) (-2807 (($ $ (-433 (-592))) 90)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 144 (|has| |#1| (-388)))) (-1430 (($ $) 135 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))))) (-2769 (((-790) $) 146 (|has| |#1| (-388)))) (-3927 ((|#1| $ (-433 (-592))) 99) (($ $ $) 76 (|has| (-433 (-592)) (-1131)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 147 (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) 84 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-1191) (-790)) 83 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-658 (-1191))) 82 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-1191)) 81 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-790)) 79 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-4525 (((-433 (-592)) $) 63)) (-1609 (($ $) 124 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 113 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 123 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 114 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 122 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 115 (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 68)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 46 (|has| |#1| (-194))) (($ (-433 (-592))) 56 (|has| |#1| (-43 (-433 (-592))))) (($ $) 48 (|has| |#1| (-582)))) (-1937 ((|#1| $ (-433 (-592))) 58)) (-1517 (((-3 $ "failed") $) 47 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-2838 ((|#1| $) 97)) (-1630 (($ $) 133 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 121 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-1617 (($ $) 132 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 120 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 131 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 119 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-433 (-592))) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 130 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 118 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 129 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 117 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 128 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 116 (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 158 (|has| |#1| (-388)))) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) 88 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-1191) (-790)) 87 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-658 (-1191))) 86 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-1191)) 85 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-790)) 80 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388))) (($ $ $) 160 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 159 (|has| |#1| (-388))) (($ $ $) 136 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 107 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1260 |#1|) (-1311) (-1075)) (T -1260)) 
+((-2881 (*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| *4)))) (-4 *4 (-1075)) (-4 *1 (-1260 *4)))) (-3990 (*1 *1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-4 *1 (-1260 *3)) (-4 *3 (-1075)))) (-3162 (*1 *1 *1) (-12 (-4 *1 (-1260 *2)) (-4 *2 (-1075)) (-4 *2 (-43 (-433 (-592)))))) (-3162 (*1 *1 *1 *2) (-3836 (-12 (-5 *2 (-1191)) (-4 *1 (-1260 *3)) (-4 *3 (-1075)) (-12 (-4 *3 (-29 (-592))) (-4 *3 (-987)) (-4 *3 (-1211)) (-4 *3 (-43 (-433 (-592)))))) (-12 (-5 *2 (-1191)) (-4 *1 (-1260 *3)) (-4 *3 (-1075)) (-12 (|has| *3 (-15 -4085 ((-658 *2) *3))) (|has| *3 (-15 -3162 (*3 *3 *2))) (-4 *3 (-43 (-433 (-592))))))))) 
+(-13 (-1257 |t#1| (-433 (-592))) (-10 -8 (-15 -2881 ($ (-790) (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |t#1|))))) (-15 -3990 ($ $ (-433 (-592)))) (IF (|has| |t#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $)) (IF (|has| |t#1| (-15 -3162 (|t#1| |t#1| (-1191)))) (IF (|has| |t#1| (-15 -4085 ((-658 (-1191)) |t#1|))) (-15 -3162 ($ $ (-1191))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1211)) (IF (|has| |t#1| (-987)) (IF (|has| |t#1| (-29 (-592))) (-15 -3162 ($ $ (-1191))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1030)) (-6 (-1211))) |noBranch|) (IF (|has| |t#1| (-388)) (-6 (-388)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-433 (-592))) . T) ((-25) . T) ((-43 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-40) |has| |#1| (-43 (-433 (-592)))) ((-116) |has| |#1| (-43 (-433 (-592)))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-247) |has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) ((-260) |has| |#1| (-388)) ((-301) |has| |#1| (-43 (-433 (-592)))) ((-303 $ $) |has| (-433 (-592)) (-1131)) ((-307) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-323) |has| |#1| (-388)) ((-388) |has| |#1| (-388)) ((-477) |has| |#1| (-388)) ((-526) |has| |#1| (-43 (-433 (-592)))) ((-582) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-661 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) |has| |#1| (-388)) ((-734 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-743) . T) ((-922 (-1191)) -12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191)))) ((-1002 |#1| (-433 (-592)) (-1103)) . T) ((-943) |has| |#1| (-388)) ((-1030) |has| |#1| (-43 (-433 (-592)))) ((-1081 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1211) |has| |#1| (-43 (-433 (-592)))) ((-1214) |has| |#1| (-43 (-433 (-592)))) ((-1235) |has| |#1| (-388)) ((-1257 |#1| (-433 (-592))) . T)) 
+((-2272 (((-141) $) 12)) (-4368 (((-3 |#3| "failed") $) 17)) (-2400 ((|#3| $) 14))) 
+(((-1261 |#1| |#2| |#3|) (-10 -8 (-15 -2400 (|#3| |#1|)) (-15 -4368 ((-3 |#3| "failed") |#1|)) (-15 -2272 ((-141) |#1|))) (-1262 |#2| |#3|) (-1075) (-1239 |#2|)) (T -1261)) 
+NIL 
+(-10 -8 (-15 -2400 (|#3| |#1|)) (-15 -4368 ((-3 |#3| "failed") |#1|)) (-15 -2272 ((-141) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 (-1103)) $) 70)) (-3983 (((-1191) $) 98)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2306 (($ $ (-433 (-592))) 93) (($ $ (-433 (-592)) (-433 (-592))) 92)) (-2982 (((-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|))) $) 100)) (-1588 (($ $) 127 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 110 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 154 (|has| |#1| (-388)))) (-3164 (((-444 $) $) 155 (|has| |#1| (-388)))) (-1442 (($ $) 109 (|has| |#1| (-43 (-433 (-592)))))) (-3652 (((-141) $ $) 145 (|has| |#1| (-388)))) (-1575 (($ $) 126 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 111 (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-790) (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|)))) 164)) (-1601 (($ $) 125 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 112 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#2| "failed") $) 172)) (-2400 ((|#2| $) 171)) (-1586 (($ $ $) 149 (|has| |#1| (-388)))) (-4593 (($ $) 59)) (-3371 (((-3 $ "failed") $) 33)) (-1468 (((-433 (-592)) $) 169)) (-1599 (($ $ $) 148 (|has| |#1| (-388)))) (-2001 (($ (-433 (-592)) |#2|) 170)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 143 (|has| |#1| (-388)))) (-2802 (((-141) $) 156 (|has| |#1| (-388)))) (-2273 (((-141) $) 69)) (-1435 (($) 137 (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-433 (-592)) $) 95) (((-433 (-592)) $ (-433 (-592))) 94)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 108 (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) 96) (($ $ (-433 (-592))) 163)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 152 (|has| |#1| (-388)))) (-2027 (((-141) $) 61)) (-4526 (($ |#1| (-433 (-592))) 60) (($ $ (-1103) (-433 (-592))) 72) (($ $ (-658 (-1103)) (-658 (-433 (-592)))) 71)) (-2731 (($ (-1 |#1| |#1|) $) 62)) (-4546 (($ $) 134 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-2750 (($ (-658 $)) 141 (|has| |#1| (-388))) (($ $ $) 140 (|has| |#1| (-388)))) (-2337 ((|#2| $) 168)) (-2501 (((-3 |#2| "failed") $) 166)) (-1994 ((|#2| $) 167)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 157 (|has| |#1| (-388)))) (-3162 (($ $) 162 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 161 (-3836 (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-987)) (|has| |#1| (-1211)) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-43 (-433 (-592)))))))) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 142 (|has| |#1| (-388)))) (-3548 (($ (-658 $)) 139 (|has| |#1| (-388))) (($ $ $) 138 (|has| |#1| (-388)))) (-4500 (((-444 $) $) 153 (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 150 (|has| |#1| (-388)))) (-2807 (($ $ (-433 (-592))) 90)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 144 (|has| |#1| (-388)))) (-1430 (($ $) 135 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))))) (-2769 (((-790) $) 146 (|has| |#1| (-388)))) (-3927 ((|#1| $ (-433 (-592))) 99) (($ $ $) 76 (|has| (-433 (-592)) (-1131)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 147 (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) 84 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-1191) (-790)) 83 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-658 (-1191))) 82 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-1191)) 81 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-790)) 79 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-4525 (((-433 (-592)) $) 63)) (-1609 (($ $) 124 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 113 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 123 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 114 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 122 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 115 (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 68)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 46 (|has| |#1| (-194))) (($ |#2|) 173) (($ (-433 (-592))) 56 (|has| |#1| (-43 (-433 (-592))))) (($ $) 48 (|has| |#1| (-582)))) (-1937 ((|#1| $ (-433 (-592))) 58)) (-1517 (((-3 $ "failed") $) 47 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-2838 ((|#1| $) 97)) (-1630 (($ $) 133 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 121 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-1617 (($ $) 132 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 120 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 131 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 119 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-433 (-592))) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 130 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 118 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 129 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 117 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 128 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 116 (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 158 (|has| |#1| (-388)))) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) 88 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-1191) (-790)) 87 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-658 (-1191))) 86 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-1191)) 85 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (($ $ (-790)) 80 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388))) (($ $ $) 160 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 159 (|has| |#1| (-388))) (($ $ $) 136 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 107 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1262 |#1| |#2|) (-1311) (-1075) (-1239 |t#1|)) (T -1262)) 
+((-4525 (*1 *2 *1) (-12 (-4 *1 (-1262 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1239 *3)) (-5 *2 (-433 (-592))))) (-1683 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *1 (-1262 *3 *2)) (-4 *2 (-1239 *3)))) (-2001 (*1 *1 *2 *3) (-12 (-5 *2 (-433 (-592))) (-4 *4 (-1075)) (-4 *1 (-1262 *4 *3)) (-4 *3 (-1239 *4)))) (-1468 (*1 *2 *1) (-12 (-4 *1 (-1262 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1239 *3)) (-5 *2 (-433 (-592))))) (-2337 (*1 *2 *1) (-12 (-4 *1 (-1262 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1239 *3)))) (-1994 (*1 *2 *1) (-12 (-4 *1 (-1262 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1239 *3)))) (-2501 (*1 *2 *1) (|partial| -12 (-4 *1 (-1262 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1239 *3))))) 
+(-13 (-1260 |t#1|) (-1065 |t#2|) (-10 -8 (-15 -2001 ($ (-433 (-592)) |t#2|)) (-15 -1468 ((-433 (-592)) $)) (-15 -2337 (|t#2| $)) (-15 -4525 ((-433 (-592)) $)) (-15 -1683 ($ |t#2|)) (-15 -1994 (|t#2| $)) (-15 -2501 ((-3 |t#2| "failed") $)))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-433 (-592))) . T) ((-25) . T) ((-43 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-40) |has| |#1| (-43 (-433 (-592)))) ((-116) |has| |#1| (-43 (-433 (-592)))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-247) |has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) ((-260) |has| |#1| (-388)) ((-301) |has| |#1| (-43 (-433 (-592)))) ((-303 $ $) |has| (-433 (-592)) (-1131)) ((-307) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-323) |has| |#1| (-388)) ((-388) |has| |#1| (-388)) ((-477) |has| |#1| (-388)) ((-526) |has| |#1| (-43 (-433 (-592)))) ((-582) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-661 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-661 |#1|) . T) ((-661 $) . T) ((-678) |has| |#1| (-388)) ((-734 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388))) ((-743) . T) ((-922 (-1191)) -12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191)))) ((-1002 |#1| (-433 (-592)) (-1103)) . T) ((-943) |has| |#1| (-388)) ((-1030) |has| |#1| (-43 (-433 (-592)))) ((-1065 |#2|) . T) ((-1081 (-433 (-592))) -3836 (|has| |#1| (-388)) (|has| |#1| (-43 (-433 (-592))))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-388)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1211) |has| |#1| (-43 (-433 (-592)))) ((-1214) |has| |#1| (-43 (-433 (-592)))) ((-1235) |has| |#1| (-388)) ((-1257 |#1| (-433 (-592))) . T) ((-1260 |#1|) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 96)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-433 (-592))) 106) (($ $ (-433 (-592)) (-433 (-592))) 108)) (-2982 (((-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|))) $) 51)) (-1588 (($ $) 179 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 155 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) 175 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 151 (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-790) (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|)))) 61)) (-1601 (($ $) 183 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 159 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) NIL)) (-2400 ((|#2| $) NIL)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) 79)) (-1468 (((-433 (-592)) $) 12)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-2001 (($ (-433 (-592)) |#2|) 10)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-2273 (((-141) $) 68)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-433 (-592)) $) 103) (((-433 (-592)) $ (-433 (-592))) 104)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) 120) (($ $ (-433 (-592))) 118)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-433 (-592))) 31) (($ $ (-1103) (-433 (-592))) NIL) (($ $ (-658 (-1103)) (-658 (-433 (-592)))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) 115)) (-4546 (($ $) 149 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-2337 ((|#2| $) 11)) (-2501 (((-3 |#2| "failed") $) 41)) (-1994 ((|#2| $) 42)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) 93 (|has| |#1| (-388)))) (-3162 (($ $) 135 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 140 (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211)))))) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-2807 (($ $ (-433 (-592))) 112)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-1430 (($ $) 147 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) 90 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ (-433 (-592))) 100) (($ $ $) 86 (|has| (-433 (-592)) (-1131)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) 127 (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) 124 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-4525 (((-433 (-592)) $) 16)) (-1609 (($ $) 185 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 161 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 181 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 157 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 177 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 153 (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 110)) (-1683 (((-877) $) NIL) (($ (-592)) 35) (($ |#1|) 27 (|has| |#1| (-194))) (($ |#2|) 32) (($ (-433 (-592))) 128 (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582)))) (-1937 ((|#1| $ (-433 (-592))) 99)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) 117)) (-2838 ((|#1| $) 98)) (-1630 (($ $) 191 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 167 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) 187 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 163 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 195 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 171 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-433 (-592))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 197 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 173 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 193 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 169 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 189 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 165 (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 21 T CONST)) (-4257 (($) 17 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-3255 (((-141) $ $) 66)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) 92 (|has| |#1| (-388)))) (-3306 (($ $) 131) (($ $ $) 72)) (-3300 (($ $ $) 70)) (** (($ $ (-944)) NIL) (($ $ (-790)) 76) (($ $ (-592)) 144 (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 145 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 74) (($ $ |#1|) NIL) (($ |#1| $) 126) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1263 |#1| |#2|) (-1262 |#1| |#2|) (-1075) (-1239 |#1|)) (T -1263)) 
+NIL 
+(-1262 |#1| |#2|) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 11)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) NIL (|has| |#1| (-582)))) (-2306 (($ $ (-433 (-592))) NIL) (($ $ (-433 (-592)) (-433 (-592))) NIL)) (-2982 (((-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|))) $) NIL)) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-3743 (($ $) NIL (|has| |#1| (-388)))) (-3164 (((-444 $) $) NIL (|has| |#1| (-388)))) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3652 (((-141) $ $) NIL (|has| |#1| (-388)))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-790) (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#1|)))) NIL)) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-1243 |#1| |#2| |#3|) "failed") $) 19) (((-3 (-1271 |#1| |#2| |#3|) "failed") $) 22)) (-2400 (((-1243 |#1| |#2| |#3|) $) NIL) (((-1271 |#1| |#2| |#3|) $) NIL)) (-1586 (($ $ $) NIL (|has| |#1| (-388)))) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-1468 (((-433 (-592)) $) 57)) (-1599 (($ $ $) NIL (|has| |#1| (-388)))) (-2001 (($ (-433 (-592)) (-1243 |#1| |#2| |#3|)) NIL)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) NIL (|has| |#1| (-388)))) (-2802 (((-141) $) NIL (|has| |#1| (-388)))) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-433 (-592)) $) NIL) (((-433 (-592)) $ (-433 (-592))) NIL)) (-3558 (((-141) $) NIL)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) NIL) (($ $ (-433 (-592))) NIL)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-433 (-592))) 29) (($ $ (-1103) (-433 (-592))) NIL) (($ $ (-658 (-1103)) (-658 (-433 (-592)))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2750 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-2337 (((-1243 |#1| |#2| |#3|) $) 60)) (-2501 (((-3 (-1243 |#1| |#2| |#3|) "failed") $) NIL)) (-1994 (((-1243 |#1| |#2| |#3|) $) NIL)) (-2685 (((-1173) $) NIL)) (-4552 (($ $) NIL (|has| |#1| (-388)))) (-3162 (($ $) 38 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) NIL (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 |#2|)) 39 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) NIL (|has| |#1| (-388)))) (-3548 (($ (-658 $)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-4500 (((-444 $) $) NIL (|has| |#1| (-388)))) (-4159 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-388))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) NIL (|has| |#1| (-388)))) (-2807 (($ $ (-433 (-592))) NIL)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-4539 (((-3 (-658 $) "failed") (-658 $) $) NIL (|has| |#1| (-388)))) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))))) (-2769 (((-790) $) NIL (|has| |#1| (-388)))) (-3927 ((|#1| $ (-433 (-592))) NIL) (($ $ $) NIL (|has| (-433 (-592)) (-1131)))) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) NIL (|has| |#1| (-388)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) 36 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $ (-1276 |#2|)) 37)) (-4525 (((-433 (-592)) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) NIL)) (-1683 (((-877) $) 87) (($ (-592)) NIL) (($ |#1|) NIL (|has| |#1| (-194))) (($ (-1243 |#1| |#2| |#3|)) 16) (($ (-1271 |#1| |#2| |#3|)) 17) (($ (-1276 |#2|)) 35) (($ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582)))) (-1937 ((|#1| $ (-433 (-592))) NIL)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) 12)) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-433 (-592))) 62 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-433 (-592))))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388)))) (-3514 (($) 31 T CONST)) (-4257 (($) 26 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-433 (-592)) |#1|))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 33)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ (-592)) NIL (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1264 |#1| |#2| |#3|) (-13 (-1262 |#1| (-1243 |#1| |#2| |#3|)) (-1065 (-1271 |#1| |#2| |#3|)) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) (-1075) (-1191) |#1|) (T -1264)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1264 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1264 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1264 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3)))) 
+(-13 (-1262 |#1| (-1243 |#1| |#2| |#3|)) (-1065 (-1271 |#1| |#2| |#3|)) (-10 -8 (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 32)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL)) (-1555 (($ $) NIL)) (-1313 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 (-592) "failed") $) NIL (|has| (-1264 |#2| |#3| |#4|) (-1065 (-592)))) (((-3 (-433 (-592)) "failed") $) NIL (|has| (-1264 |#2| |#3| |#4|) (-1065 (-433 (-592))))) (((-3 (-1264 |#2| |#3| |#4|) "failed") $) 20)) (-2400 (((-592) $) NIL (|has| (-1264 |#2| |#3| |#4|) (-1065 (-592)))) (((-433 (-592)) $) NIL (|has| (-1264 |#2| |#3| |#4|) (-1065 (-433 (-592))))) (((-1264 |#2| |#3| |#4|) $) NIL)) (-4593 (($ $) 33)) (-3371 (((-3 $ "failed") $) 25)) (-3262 (($ $) NIL (|has| (-1264 |#2| |#3| |#4|) (-477)))) (-4209 (($ $ (-1264 |#2| |#3| |#4|) (-336 |#2| |#3| |#4|) $) NIL)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) 11)) (-2027 (((-141) $) NIL)) (-4526 (($ (-1264 |#2| |#3| |#4|) (-336 |#2| |#3| |#4|)) 23)) (-4206 (((-336 |#2| |#3| |#4|) $) NIL)) (-2976 (($ (-1 (-336 |#2| |#3| |#4|) (-336 |#2| |#3| |#4|)) $) NIL)) (-2731 (($ (-1 (-1264 |#2| |#3| |#4|) (-1264 |#2| |#3| |#4|)) $) NIL)) (-1722 (((-3 (-862 |#2|) "failed") $) 72)) (-4573 (($ $) NIL)) (-4579 (((-1264 |#2| |#3| |#4|) $) 18)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4559 (((-141) $) NIL)) (-4565 (((-1264 |#2| |#3| |#4|) $) NIL)) (-3616 (((-3 $ "failed") $ (-1264 |#2| |#3| |#4|)) NIL (|has| (-1264 |#2| |#3| |#4|) (-582))) (((-3 $ "failed") $ $) NIL)) (-4057 (((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1264 |#2| |#3| |#4|)) (|:| |%expon| (-336 |#2| |#3| |#4|)) (|:| |%expTerms| (-658 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#2|)))))) (|:| |%type| (-1173))) "failed") $) 55)) (-4525 (((-336 |#2| |#3| |#4|) $) 14)) (-1554 (((-1264 |#2| |#3| |#4|) $) NIL (|has| (-1264 |#2| |#3| |#4|) (-477)))) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ (-1264 |#2| |#3| |#4|)) NIL) (($ $) NIL) (($ (-433 (-592))) NIL (-3836 (|has| (-1264 |#2| |#3| |#4|) (-43 (-433 (-592)))) (|has| (-1264 |#2| |#3| |#4|) (-1065 (-433 (-592))))))) (-1647 (((-658 (-1264 |#2| |#3| |#4|)) $) NIL)) (-1937 (((-1264 |#2| |#3| |#4|) $ (-336 |#2| |#3| |#4|)) NIL)) (-1517 (((-3 $ "failed") $) NIL (|has| (-1264 |#2| |#3| |#4|) (-169)))) (-4010 (((-790)) NIL)) (-4064 (($ $ $ (-790)) NIL (|has| (-1264 |#2| |#3| |#4|) (-194)))) (-2537 (((-141) $ $) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 60 T CONST)) (-4257 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ (-1264 |#2| |#3| |#4|)) NIL (|has| (-1264 |#2| |#3| |#4|) (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ (-1264 |#2| |#3| |#4|)) NIL) (($ (-1264 |#2| |#3| |#4|) $) NIL) (($ (-433 (-592)) $) NIL (|has| (-1264 |#2| |#3| |#4|) (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| (-1264 |#2| |#3| |#4|) (-43 (-433 (-592))))))) 
+(((-1265 |#1| |#2| |#3| |#4|) (-13 (-346 (-1264 |#2| |#3| |#4|) (-336 |#2| |#3| |#4|)) (-582) (-10 -8 (-15 -1722 ((-3 (-862 |#2|) "failed") $)) (-15 -4057 ((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1264 |#2| |#3| |#4|)) (|:| |%expon| (-336 |#2| |#3| |#4|)) (|:| |%expTerms| (-658 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#2|)))))) (|:| |%type| (-1173))) "failed") $)))) (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477)) (-13 (-27) (-1211) (-456 |#1|)) (-1191) |#2|) (T -1265)) 
+((-1722 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477))) (-5 *2 (-862 *4)) (-5 *1 (-1265 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1211) (-456 *3))) (-14 *5 (-1191)) (-14 *6 *4))) (-4057 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477))) (-5 *2 (-2 (|:| |%term| (-2 (|:| |%coef| (-1264 *4 *5 *6)) (|:| |%expon| (-336 *4 *5 *6)) (|:| |%expTerms| (-658 (-2 (|:| |k| (-433 (-592))) (|:| |c| *4)))))) (|:| |%type| (-1173)))) (-5 *1 (-1265 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1211) (-456 *3))) (-14 *5 (-1191)) (-14 *6 *4)))) 
+(-13 (-346 (-1264 |#2| |#3| |#4|) (-336 |#2| |#3| |#4|)) (-582) (-10 -8 (-15 -1722 ((-3 (-862 |#2|) "failed") $)) (-15 -4057 ((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1264 |#2| |#3| |#4|)) (|:| |%expon| (-336 |#2| |#3| |#4|)) (|:| |%expTerms| (-658 (-2 (|:| |k| (-433 (-592))) (|:| |c| |#2|)))))) (|:| |%type| (-1173))) "failed") $)))) 
+((-2324 ((|#2| $) 28)) (-1915 ((|#2| $) 18)) (-3188 (($ $) 35)) (-4143 (($ $ (-592)) 63)) (-2126 (((-141) $ (-790)) 32)) (-3047 ((|#2| $ |#2|) 60)) (-4496 ((|#2| $ |#2|) 58)) (-3932 ((|#2| $ "value" |#2|) NIL) ((|#2| $ "first" |#2|) 51) (($ $ "rest" $) 55) ((|#2| $ "last" |#2|) 53)) (-4294 (($ $ (-658 $)) 59)) (-1765 ((|#2| $) 17)) (-1366 (($ $) NIL) (($ $ (-790)) 41)) (-2774 (((-658 $) $) 25)) (-3055 (((-141) $ $) 49)) (-4345 (((-141) $ (-790)) 31)) (-2554 (((-141) $ (-790)) 30)) (-3683 (((-141) $) 27)) (-4255 ((|#2| $) 23) (($ $ (-790)) 45)) (-3927 ((|#2| $ "value") NIL) ((|#2| $ "first") 10) (($ $ "rest") 16) ((|#2| $ "last") 13)) (-3228 (((-141) $) 21)) (-2399 (($ $) 38)) (-1337 (($ $) 64)) (-3318 (((-790) $) 40)) (-3184 (($ $) 39)) (-2266 (($ $ $) 57) (($ |#2| $) NIL)) (-2493 (((-658 $) $) 26)) (-3255 (((-141) $ $) 47)) (-1699 (((-790) $) 34))) 
+(((-1266 |#1| |#2|) (-10 -8 (-15 -4143 (|#1| |#1| (-592))) (-15 -3932 (|#2| |#1| "last" |#2|)) (-15 -4496 (|#2| |#1| |#2|)) (-15 -3932 (|#1| |#1| "rest" |#1|)) (-15 -3932 (|#2| |#1| "first" |#2|)) (-15 -1337 (|#1| |#1|)) (-15 -2399 (|#1| |#1|)) (-15 -3318 ((-790) |#1|)) (-15 -3184 (|#1| |#1|)) (-15 -1915 (|#2| |#1|)) (-15 -1765 (|#2| |#1|)) (-15 -3188 (|#1| |#1|)) (-15 -4255 (|#1| |#1| (-790))) (-15 -3927 (|#2| |#1| "last")) (-15 -4255 (|#2| |#1|)) (-15 -1366 (|#1| |#1| (-790))) (-15 -3927 (|#1| |#1| "rest")) (-15 -1366 (|#1| |#1|)) (-15 -3927 (|#2| |#1| "first")) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#1|)) (-15 -3047 (|#2| |#1| |#2|)) (-15 -3932 (|#2| |#1| "value" |#2|)) (-15 -4294 (|#1| |#1| (-658 |#1|))) (-15 -3055 ((-141) |#1| |#1|)) (-15 -3228 ((-141) |#1|)) (-15 -3927 (|#2| |#1| "value")) (-15 -2324 (|#2| |#1|)) (-15 -3683 ((-141) |#1|)) (-15 -2774 ((-658 |#1|) |#1|)) (-15 -2493 ((-658 |#1|) |#1|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -1699 ((-790) |#1|)) (-15 -2126 ((-141) |#1| (-790))) (-15 -4345 ((-141) |#1| (-790))) (-15 -2554 ((-141) |#1| (-790)))) (-1267 |#2|) (-1225)) (T -1266)) 
+NIL 
+(-10 -8 (-15 -4143 (|#1| |#1| (-592))) (-15 -3932 (|#2| |#1| "last" |#2|)) (-15 -4496 (|#2| |#1| |#2|)) (-15 -3932 (|#1| |#1| "rest" |#1|)) (-15 -3932 (|#2| |#1| "first" |#2|)) (-15 -1337 (|#1| |#1|)) (-15 -2399 (|#1| |#1|)) (-15 -3318 ((-790) |#1|)) (-15 -3184 (|#1| |#1|)) (-15 -1915 (|#2| |#1|)) (-15 -1765 (|#2| |#1|)) (-15 -3188 (|#1| |#1|)) (-15 -4255 (|#1| |#1| (-790))) (-15 -3927 (|#2| |#1| "last")) (-15 -4255 (|#2| |#1|)) (-15 -1366 (|#1| |#1| (-790))) (-15 -3927 (|#1| |#1| "rest")) (-15 -1366 (|#1| |#1|)) (-15 -3927 (|#2| |#1| "first")) (-15 -2266 (|#1| |#2| |#1|)) (-15 -2266 (|#1| |#1| |#1|)) (-15 -3047 (|#2| |#1| |#2|)) (-15 -3932 (|#2| |#1| "value" |#2|)) (-15 -4294 (|#1| |#1| (-658 |#1|))) (-15 -3055 ((-141) |#1| |#1|)) (-15 -3228 ((-141) |#1|)) (-15 -3927 (|#2| |#1| "value")) (-15 -2324 (|#2| |#1|)) (-15 -3683 ((-141) |#1|)) (-15 -2774 ((-658 |#1|) |#1|)) (-15 -2493 ((-658 |#1|) |#1|)) (-15 -3255 ((-141) |#1| |#1|)) (-15 -1699 ((-790) |#1|)) (-15 -2126 ((-141) |#1| (-790))) (-15 -4345 ((-141) |#1| (-790))) (-15 -2554 ((-141) |#1| (-790)))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-2324 ((|#1| $) 45)) (-1915 ((|#1| $) 62)) (-3188 (($ $) 64)) (-4143 (($ $ (-592)) 49 (|has| $ (-6 -4626)))) (-2126 (((-141) $ (-790)) 8)) (-3047 ((|#1| $ |#1|) 36 (|has| $ (-6 -4626)))) (-3153 (($ $ $) 53 (|has| $ (-6 -4626)))) (-4496 ((|#1| $ |#1|) 51 (|has| $ (-6 -4626)))) (-2101 ((|#1| $ |#1|) 55 (|has| $ (-6 -4626)))) (-3932 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4626))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4626))) (($ $ "rest" $) 52 (|has| $ (-6 -4626))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4626)))) (-4294 (($ $ (-658 $)) 38 (|has| $ (-6 -4626)))) (-1765 ((|#1| $) 63)) (-3001 (($) 7 T CONST)) (-1366 (($ $) 70) (($ $ (-790)) 68)) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-2774 (((-658 $) $) 47)) (-3055 (((-141) $ $) 39 (|has| |#1| (-1119)))) (-4345 (((-141) $ (-790)) 9)) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35)) (-2554 (((-141) $ (-790)) 10)) (-4063 (((-658 |#1|) $) 42)) (-3683 (((-141) $) 46)) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-4255 ((|#1| $) 67) (($ $ (-790)) 65)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 73) (($ $ (-790)) 71)) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66)) (-2920 (((-592) $ $) 41)) (-3228 (((-141) $) 43)) (-2399 (($ $) 59)) (-1337 (($ $) 56 (|has| $ (-6 -4626)))) (-3318 (((-790) $) 60)) (-3184 (($ $) 61)) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4599 (($ $) 13)) (-3619 (($ $ $) 58 (|has| $ (-6 -4626))) (($ $ |#1|) 57 (|has| $ (-6 -4626)))) (-2266 (($ $ $) 75) (($ |#1| $) 74)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-2493 (((-658 $) $) 48)) (-2936 (((-141) $ $) 40 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1267 |#1|) (-1311) (-1225)) (T -1267)) 
+((-2266 (*1 *1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-2266 (*1 *1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-1918 (*1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 "first") (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-1918 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) (-1366 (*1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3927 (*1 *1 *1 *2) (-12 (-5 *2 "rest") (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) (-1366 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) (-4255 (*1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3927 (*1 *2 *1 *3) (-12 (-5 *3 "last") (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-4255 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) (-3188 (*1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-1765 (*1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-1915 (*1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3184 (*1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3318 (*1 *2 *1) (-12 (-4 *1 (-1267 *3)) (-4 *3 (-1225)) (-5 *2 (-790)))) (-2399 (*1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3619 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3619 (*1 *1 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-1337 (*1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-2101 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3932 (*1 *2 *1 *3 *2) (-12 (-5 *3 "first") (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3153 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3932 (*1 *1 *1 *2 *1) (-12 (-5 *2 "rest") (|has| *1 (-6 -4626)) (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) (-4496 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-3932 (*1 *2 *1 *3 *2) (-12 (-5 *3 "last") (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) (-4143 (*1 *1 *1 *2) (-12 (-5 *2 (-592)) (|has| *1 (-6 -4626)) (-4 *1 (-1267 *3)) (-4 *3 (-1225))))) 
+(-13 (-1038 |t#1|) (-10 -8 (-15 -2266 ($ $ $)) (-15 -2266 ($ |t#1| $)) (-15 -1918 (|t#1| $)) (-15 -3927 (|t#1| $ "first")) (-15 -1918 ($ $ (-790))) (-15 -1366 ($ $)) (-15 -3927 ($ $ "rest")) (-15 -1366 ($ $ (-790))) (-15 -4255 (|t#1| $)) (-15 -3927 (|t#1| $ "last")) (-15 -4255 ($ $ (-790))) (-15 -3188 ($ $)) (-15 -1765 (|t#1| $)) (-15 -1915 (|t#1| $)) (-15 -3184 ($ $)) (-15 -3318 ((-790) $)) (-15 -2399 ($ $)) (IF (|has| $ (-6 -4626)) (PROGN (-15 -3619 ($ $ $)) (-15 -3619 ($ $ |t#1|)) (-15 -1337 ($ $)) (-15 -2101 (|t#1| $ |t#1|)) (-15 -3932 (|t#1| $ "first" |t#1|)) (-15 -3153 ($ $ $)) (-15 -3932 ($ $ "rest" $)) (-15 -4496 (|t#1| $ |t#1|)) (-15 -3932 (|t#1| $ "last" |t#1|)) (-15 -4143 ($ $ (-592)))) |noBranch|))) 
+(((-39) . T) ((-125) |has| |#1| (-1119)) ((-632 (-877)) |has| |#1| (-1119)) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-523 |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-1038 |#1|) . T) ((-1119) |has| |#1| (-1119)) ((-1225) . T)) 
+((-2731 ((|#4| (-1 |#2| |#1|) |#3|) 17))) 
+(((-1268 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2731 (|#4| (-1 |#2| |#1|) |#3|))) (-1075) (-1075) (-1270 |#1|) (-1270 |#2|)) (T -1268)) 
+((-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-4 *2 (-1270 *6)) (-5 *1 (-1268 *5 *6 *4 *2)) (-4 *4 (-1270 *5))))) 
+(-10 -7 (-15 -2731 (|#4| (-1 |#2| |#1|) |#3|))) 
+((-2272 (((-141) $) 15)) (-1588 (($ $) 90)) (-1507 (($ $) 66)) (-1575 (($ $) 86)) (-1495 (($ $) 62)) (-1601 (($ $) 94)) (-1521 (($ $) 70)) (-4546 (($ $) 60)) (-1430 (($ $) 58)) (-1609 (($ $) 96)) (-1527 (($ $) 72)) (-1594 (($ $) 92)) (-1515 (($ $) 68)) (-1581 (($ $) 88)) (-1501 (($ $) 64)) (-1683 (((-877) $) 46) (($ (-592)) NIL) (($ (-433 (-592))) NIL) (($ $) NIL) (($ |#2|) NIL)) (-1630 (($ $) 102)) (-1546 (($ $) 78)) (-1617 (($ $) 98)) (-1533 (($ $) 74)) (-1642 (($ $) 106)) (-1559 (($ $) 82)) (-2892 (($ $) 108)) (-1567 (($ $) 84)) (-1636 (($ $) 104)) (-1552 (($ $) 80)) (-1624 (($ $) 100)) (-1540 (($ $) 76)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ |#2|) 50) (($ $ $) 53) (($ $ (-433 (-592))) 56))) 
+(((-1269 |#1| |#2|) (-10 -8 (-15 ** (|#1| |#1| (-433 (-592)))) (-15 -1507 (|#1| |#1|)) (-15 -1495 (|#1| |#1|)) (-15 -1521 (|#1| |#1|)) (-15 -1527 (|#1| |#1|)) (-15 -1515 (|#1| |#1|)) (-15 -1501 (|#1| |#1|)) (-15 -1540 (|#1| |#1|)) (-15 -1552 (|#1| |#1|)) (-15 -1567 (|#1| |#1|)) (-15 -1559 (|#1| |#1|)) (-15 -1533 (|#1| |#1|)) (-15 -1546 (|#1| |#1|)) (-15 -1581 (|#1| |#1|)) (-15 -1594 (|#1| |#1|)) (-15 -1609 (|#1| |#1|)) (-15 -1601 (|#1| |#1|)) (-15 -1575 (|#1| |#1|)) (-15 -1588 (|#1| |#1|)) (-15 -1624 (|#1| |#1|)) (-15 -1636 (|#1| |#1|)) (-15 -2892 (|#1| |#1|)) (-15 -1642 (|#1| |#1|)) (-15 -1617 (|#1| |#1|)) (-15 -1630 (|#1| |#1|)) (-15 -4546 (|#1| |#1|)) (-15 -1430 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| |#2|)) (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| (-592))) (-15 ** (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-944))) (-15 -2272 ((-141) |#1|)) (-15 -1683 ((-877) |#1|))) (-1270 |#2|) (-1075)) (T -1269)) 
+NIL 
+(-10 -8 (-15 ** (|#1| |#1| (-433 (-592)))) (-15 -1507 (|#1| |#1|)) (-15 -1495 (|#1| |#1|)) (-15 -1521 (|#1| |#1|)) (-15 -1527 (|#1| |#1|)) (-15 -1515 (|#1| |#1|)) (-15 -1501 (|#1| |#1|)) (-15 -1540 (|#1| |#1|)) (-15 -1552 (|#1| |#1|)) (-15 -1567 (|#1| |#1|)) (-15 -1559 (|#1| |#1|)) (-15 -1533 (|#1| |#1|)) (-15 -1546 (|#1| |#1|)) (-15 -1581 (|#1| |#1|)) (-15 -1594 (|#1| |#1|)) (-15 -1609 (|#1| |#1|)) (-15 -1601 (|#1| |#1|)) (-15 -1575 (|#1| |#1|)) (-15 -1588 (|#1| |#1|)) (-15 -1624 (|#1| |#1|)) (-15 -1636 (|#1| |#1|)) (-15 -2892 (|#1| |#1|)) (-15 -1642 (|#1| |#1|)) (-15 -1617 (|#1| |#1|)) (-15 -1630 (|#1| |#1|)) (-15 -4546 (|#1| |#1|)) (-15 -1430 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| |#2|)) (-15 -1683 (|#1| |#2|)) (-15 -1683 (|#1| |#1|)) (-15 -1683 (|#1| (-433 (-592)))) (-15 -1683 (|#1| (-592))) (-15 ** (|#1| |#1| (-790))) (-15 ** (|#1| |#1| (-944))) (-15 -2272 ((-141) |#1|)) (-15 -1683 ((-877) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-4085 (((-658 (-1103)) $) 70)) (-3983 (((-1191) $) 98)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 50 (|has| |#1| (-582)))) (-1555 (($ $) 51 (|has| |#1| (-582)))) (-1313 (((-141) $) 53 (|has| |#1| (-582)))) (-2306 (($ $ (-790)) 93) (($ $ (-790) (-790)) 92)) (-2982 (((-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|))) $) 100)) (-1588 (($ $) 127 (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) 110 (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) 18)) (-1442 (($ $) 109 (|has| |#1| (-43 (-433 (-592)))))) (-1575 (($ $) 126 (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) 111 (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|)))) 147) (($ (-1171 |#1|)) 145)) (-1601 (($ $) 125 (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) 112 (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) 16 T CONST)) (-4593 (($ $) 59)) (-3371 (((-3 $ "failed") $) 33)) (-2410 (($ $) 144)) (-2012 (((-980 |#1|) $ (-790)) 142) (((-980 |#1|) $ (-790) (-790)) 141)) (-2273 (((-141) $) 69)) (-1435 (($) 137 (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-790) $) 95) (((-790) $ (-790)) 94)) (-3558 (((-141) $) 30)) (-4422 (($ $ (-592)) 108 (|has| |#1| (-43 (-433 (-592)))))) (-3990 (($ $ (-944)) 96)) (-1376 (($ (-1 |#1| (-592)) $) 143)) (-2027 (((-141) $) 61)) (-4526 (($ |#1| (-790)) 60) (($ $ (-1103) (-790)) 72) (($ $ (-658 (-1103)) (-658 (-790))) 71)) (-2731 (($ (-1 |#1| |#1|) $) 62)) (-4546 (($ $) 134 (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) 64)) (-4579 ((|#1| $) 65)) (-2685 (((-1173) $) 9)) (-3162 (($ $) 139 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 138 (-3836 (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-987)) (|has| |#1| (-1211)) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-43 (-433 (-592)))))))) (-2951 (((-1137) $) 10)) (-2807 (($ $ (-790)) 90)) (-3616 (((-3 $ "failed") $ $) 49 (|has| |#1| (-582)))) (-1430 (($ $) 135 (|has| |#1| (-43 (-433 (-592)))))) (-2806 (((-1171 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-790)))))) (-3927 ((|#1| $ (-790)) 99) (($ $ $) 76 (|has| (-790) (-1131)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) 84 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (($ $ (-1191) (-790)) 83 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (($ $ (-658 (-1191))) 82 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (($ $ (-1191)) 81 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (($ $ (-790)) 79 (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (-4525 (((-790) $) 63)) (-1609 (($ $) 124 (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) 113 (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) 123 (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) 114 (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) 122 (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) 115 (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 68)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ (-433 (-592))) 56 (|has| |#1| (-43 (-433 (-592))))) (($ $) 48 (|has| |#1| (-582))) (($ |#1|) 46 (|has| |#1| (-194)))) (-1647 (((-1171 |#1|) $) 146)) (-1937 ((|#1| $ (-790)) 58)) (-1517 (((-3 $ "failed") $) 47 (|has| |#1| (-169)))) (-4010 (((-790)) 28)) (-2838 ((|#1| $) 97)) (-1630 (($ $) 133 (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) 121 (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) 52 (|has| |#1| (-582)))) (-1617 (($ $) 132 (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) 120 (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) 131 (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) 119 (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-790)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-790)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) 130 (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) 118 (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) 129 (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) 117 (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) 128 (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) 116 (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) 88 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (($ $ (-1191) (-790)) 87 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (($ $ (-658 (-1191))) 86 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (($ $ (-1191)) 85 (-12 (|has| |#1| (-922 (-1191))) (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (($ $ (-790)) 80 (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 57 (|has| |#1| (-388)))) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ |#1|) 140 (|has| |#1| (-388))) (($ $ $) 136 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 107 (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-433 (-592)) $) 55 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) 54 (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1270 |#1|) (-1311) (-1075)) (T -1270)) 
+((-2881 (*1 *1 *2) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-790)) (|:| |c| *3)))) (-4 *3 (-1075)) (-4 *1 (-1270 *3)))) (-1647 (*1 *2 *1) (-12 (-4 *1 (-1270 *3)) (-4 *3 (-1075)) (-5 *2 (-1171 *3)))) (-2881 (*1 *1 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-4 *1 (-1270 *3)))) (-2410 (*1 *1 *1) (-12 (-4 *1 (-1270 *2)) (-4 *2 (-1075)))) (-1376 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-592))) (-4 *1 (-1270 *3)) (-4 *3 (-1075)))) (-2012 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-1270 *4)) (-4 *4 (-1075)) (-5 *2 (-980 *4)))) (-2012 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-4 *1 (-1270 *4)) (-4 *4 (-1075)) (-5 *2 (-980 *4)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-1270 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) (-3162 (*1 *1 *1) (-12 (-4 *1 (-1270 *2)) (-4 *2 (-1075)) (-4 *2 (-43 (-433 (-592)))))) (-3162 (*1 *1 *1 *2) (-3836 (-12 (-5 *2 (-1191)) (-4 *1 (-1270 *3)) (-4 *3 (-1075)) (-12 (-4 *3 (-29 (-592))) (-4 *3 (-987)) (-4 *3 (-1211)) (-4 *3 (-43 (-433 (-592)))))) (-12 (-5 *2 (-1191)) (-4 *1 (-1270 *3)) (-4 *3 (-1075)) (-12 (|has| *3 (-15 -4085 ((-658 *2) *3))) (|has| *3 (-15 -3162 (*3 *3 *2))) (-4 *3 (-43 (-433 (-592))))))))) 
+(-13 (-1257 |t#1| (-790)) (-10 -8 (-15 -2881 ($ (-1171 (-2 (|:| |k| (-790)) (|:| |c| |t#1|))))) (-15 -1647 ((-1171 |t#1|) $)) (-15 -2881 ($ (-1171 |t#1|))) (-15 -2410 ($ $)) (-15 -1376 ($ (-1 |t#1| (-592)) $)) (-15 -2012 ((-980 |t#1|) $ (-790))) (-15 -2012 ((-980 |t#1|) $ (-790) (-790))) (IF (|has| |t#1| (-388)) (-15 ** ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-43 (-433 (-592)))) (PROGN (-15 -3162 ($ $)) (IF (|has| |t#1| (-15 -3162 (|t#1| |t#1| (-1191)))) (IF (|has| |t#1| (-15 -4085 ((-658 (-1191)) |t#1|))) (-15 -3162 ($ $ (-1191))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1211)) (IF (|has| |t#1| (-987)) (IF (|has| |t#1| (-29 (-592))) (-15 -3162 ($ $ (-1191))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1030)) (-6 (-1211))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-790)) . T) ((-25) . T) ((-43 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-43 |#1|) |has| |#1| (-194)) ((-43 $) |has| |#1| (-582)) ((-40) |has| |#1| (-43 (-433 (-592)))) ((-116) |has| |#1| (-43 (-433 (-592)))) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-140 |#1| |#1|) . T) ((-140 $ $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-158) . T) ((-169) |has| |#1| (-169)) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-247) |has| |#1| (-15 * (|#1| (-790) |#1|))) ((-301) |has| |#1| (-43 (-433 (-592)))) ((-303 $ $) |has| (-790) (-1131)) ((-307) |has| |#1| (-582)) ((-526) |has| |#1| (-43 (-433 (-592)))) ((-582) |has| |#1| (-582)) ((-661 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-661 |#1|) . T) ((-661 $) . T) ((-734 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-734 |#1|) |has| |#1| (-194)) ((-734 $) |has| |#1| (-582)) ((-743) . T) ((-922 (-1191)) -12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191)))) ((-1002 |#1| (-790) (-1103)) . T) ((-1030) |has| |#1| (-43 (-433 (-592)))) ((-1081 (-433 (-592))) |has| |#1| (-43 (-433 (-592)))) ((-1081 |#1|) . T) ((-1081 $) -3836 (|has| |#1| (-582)) (|has| |#1| (-194))) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1211) |has| |#1| (-43 (-433 (-592)))) ((-1214) |has| |#1| (-43 (-433 (-592)))) ((-1257 |#1| (-790)) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 86)) (-3395 (((-1252 |#2| |#1|) $ (-790)) 73)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) 135 (|has| |#1| (-582)))) (-2306 (($ $ (-790)) 120) (($ $ (-790) (-790)) 122)) (-2982 (((-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|))) $) 42)) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|)))) 53) (($ (-1171 |#1|)) NIL)) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-3621 (($ $) 126)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-2410 (($ $) 133)) (-2012 (((-980 |#1|) $ (-790)) 63) (((-980 |#1|) $ (-790) (-790)) 65)) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-790) $) NIL) (((-790) $ (-790)) NIL)) (-3558 (((-141) $) NIL)) (-2669 (($ $) 110)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3368 (($ (-592) (-592) $) 128)) (-3990 (($ $ (-944)) 132)) (-1376 (($ (-1 |#1| (-592)) $) 104)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) 15) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) 92)) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-4006 (($ $) 108)) (-3121 (($ $) 106)) (-3884 (($ (-592) (-592) $) 130)) (-3162 (($ $) 143 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 149 (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 |#2|)) 144 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-2860 (($ $ (-592) (-592)) 114)) (-2807 (($ $ (-790)) 116)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3325 (($ $) 112)) (-2806 (((-1171 |#1|) $ |#1|) 94 (|has| |#1| (-15 ** (|#1| |#1| (-790)))))) (-3927 ((|#1| $ (-790)) 89) (($ $ $) 124 (|has| (-790) (-1131)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) 101 (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) 96 (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $ (-1276 |#2|)) 97)) (-4525 (((-790) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 118)) (-1683 (((-877) $) NIL) (($ (-592)) 24) (($ (-433 (-592))) 141 (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582))) (($ |#1|) 23 (|has| |#1| (-194))) (($ (-1252 |#2| |#1|)) 79) (($ (-1276 |#2|)) 20)) (-1647 (((-1171 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) 88)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) 87)) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-790)) 85 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-790)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 17 T CONST)) (-4257 (($) 13 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) 100)) (-3300 (($ $ $) 18)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ |#1|) 138 (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 99) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1271 |#1| |#2| |#3|) (-13 (-1270 |#1|) (-10 -8 (-15 -1683 ($ (-1252 |#2| |#1|))) (-15 -3395 ((-1252 |#2| |#1|) $ (-790))) (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (-15 -3121 ($ $)) (-15 -4006 ($ $)) (-15 -2669 ($ $)) (-15 -3325 ($ $)) (-15 -2860 ($ $ (-592) (-592))) (-15 -3621 ($ $)) (-15 -3368 ($ (-592) (-592) $)) (-15 -3884 ($ (-592) (-592) $)) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) (-1075) (-1191) |#1|) (T -1271)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1252 *4 *3)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3) (-5 *1 (-1271 *3 *4 *5)))) (-3395 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1252 *5 *4)) (-5 *1 (-1271 *4 *5 *6)) (-4 *4 (-1075)) (-14 *5 (-1191)) (-14 *6 *4))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) (-3121 (*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) (-4006 (*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) (-2669 (*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) (-3325 (*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) (-2860 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3))) (-3621 (*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) (-3368 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3))) (-3884 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3)))) 
+(-13 (-1270 |#1|) (-10 -8 (-15 -1683 ($ (-1252 |#2| |#1|))) (-15 -3395 ((-1252 |#2| |#1|) $ (-790))) (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (-15 -3121 ($ $)) (-15 -4006 ($ $)) (-15 -2669 ($ $)) (-15 -3325 ($ $)) (-15 -2860 ($ $ (-592) (-592))) (-15 -3621 ($ $)) (-15 -3368 ($ (-592) (-592) $)) (-15 -3884 ($ (-592) (-592) $)) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) 
+((-1862 (((-1 (-1171 |#1|) (-658 (-1171 |#1|))) (-1 |#2| (-658 |#2|))) 24)) (-4295 (((-1 (-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) (-1 |#2| |#2| |#2|)) 16)) (-4054 (((-1 (-1171 |#1|) (-1171 |#1|)) (-1 |#2| |#2|)) 13)) (-3287 ((|#2| (-1 |#2| |#2| |#2|) |#1| |#1|) 48)) (-3365 ((|#2| (-1 |#2| |#2|) |#1|) 46)) (-2816 ((|#2| (-1 |#2| (-658 |#2|)) (-658 |#1|)) 54)) (-2814 (((-658 |#2|) (-658 |#1|) (-658 (-1 |#2| (-658 |#2|)))) 61)) (-2862 ((|#2| |#2| |#2|) 43))) 
+(((-1272 |#1| |#2|) (-10 -7 (-15 -4054 ((-1 (-1171 |#1|) (-1171 |#1|)) (-1 |#2| |#2|))) (-15 -4295 ((-1 (-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) (-1 |#2| |#2| |#2|))) (-15 -1862 ((-1 (-1171 |#1|) (-658 (-1171 |#1|))) (-1 |#2| (-658 |#2|)))) (-15 -2862 (|#2| |#2| |#2|)) (-15 -3365 (|#2| (-1 |#2| |#2|) |#1|)) (-15 -3287 (|#2| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2816 (|#2| (-1 |#2| (-658 |#2|)) (-658 |#1|))) (-15 -2814 ((-658 |#2|) (-658 |#1|) (-658 (-1 |#2| (-658 |#2|)))))) (-43 (-433 (-592))) (-1270 |#1|)) (T -1272)) 
+((-2814 (*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-1 *6 (-658 *6)))) (-4 *5 (-43 (-433 (-592)))) (-4 *6 (-1270 *5)) (-5 *2 (-658 *6)) (-5 *1 (-1272 *5 *6)))) (-2816 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-658 *2))) (-5 *4 (-658 *5)) (-4 *5 (-43 (-433 (-592)))) (-4 *2 (-1270 *5)) (-5 *1 (-1272 *5 *2)))) (-3287 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1270 *4)) (-5 *1 (-1272 *4 *2)) (-4 *4 (-43 (-433 (-592)))))) (-3365 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *2)) (-4 *2 (-1270 *4)) (-5 *1 (-1272 *4 *2)) (-4 *4 (-43 (-433 (-592)))))) (-2862 (*1 *2 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1272 *3 *2)) (-4 *2 (-1270 *3)))) (-1862 (*1 *2 *3) (-12 (-5 *3 (-1 *5 (-658 *5))) (-4 *5 (-1270 *4)) (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-1 (-1171 *4) (-658 (-1171 *4)))) (-5 *1 (-1272 *4 *5)))) (-4295 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5 *5)) (-4 *5 (-1270 *4)) (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-1 (-1171 *4) (-1171 *4) (-1171 *4))) (-5 *1 (-1272 *4 *5)))) (-4054 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1270 *4)) (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-1 (-1171 *4) (-1171 *4))) (-5 *1 (-1272 *4 *5))))) 
+(-10 -7 (-15 -4054 ((-1 (-1171 |#1|) (-1171 |#1|)) (-1 |#2| |#2|))) (-15 -4295 ((-1 (-1171 |#1|) (-1171 |#1|) (-1171 |#1|)) (-1 |#2| |#2| |#2|))) (-15 -1862 ((-1 (-1171 |#1|) (-658 (-1171 |#1|))) (-1 |#2| (-658 |#2|)))) (-15 -2862 (|#2| |#2| |#2|)) (-15 -3365 (|#2| (-1 |#2| |#2|) |#1|)) (-15 -3287 (|#2| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2816 (|#2| (-1 |#2| (-658 |#2|)) (-658 |#1|))) (-15 -2814 ((-658 |#2|) (-658 |#1|) (-658 (-1 |#2| (-658 |#2|)))))) 
+((-2221 ((|#2| |#4| (-790)) 30)) (-3991 ((|#4| |#2|) 25)) (-4457 ((|#4| (-433 |#2|)) 51 (|has| |#1| (-582)))) (-2118 (((-1 |#4| (-658 |#4|)) |#3|) 45))) 
+(((-1273 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3991 (|#4| |#2|)) (-15 -2221 (|#2| |#4| (-790))) (-15 -2118 ((-1 |#4| (-658 |#4|)) |#3|)) (IF (|has| |#1| (-582)) (-15 -4457 (|#4| (-433 |#2|))) |noBranch|)) (-1075) (-1255 |#1|) (-670 |#2|) (-1270 |#1|)) (T -1273)) 
+((-4457 (*1 *2 *3) (-12 (-5 *3 (-433 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-582)) (-4 *4 (-1075)) (-4 *2 (-1270 *4)) (-5 *1 (-1273 *4 *5 *6 *2)) (-4 *6 (-670 *5)))) (-2118 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-1255 *4)) (-5 *2 (-1 *6 (-658 *6))) (-5 *1 (-1273 *4 *5 *3 *6)) (-4 *3 (-670 *5)) (-4 *6 (-1270 *4)))) (-2221 (*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-1075)) (-4 *2 (-1255 *5)) (-5 *1 (-1273 *5 *2 *6 *3)) (-4 *6 (-670 *2)) (-4 *3 (-1270 *5)))) (-3991 (*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *3 (-1255 *4)) (-4 *2 (-1270 *4)) (-5 *1 (-1273 *4 *3 *5 *2)) (-4 *5 (-670 *3))))) 
+(-10 -7 (-15 -3991 (|#4| |#2|)) (-15 -2221 (|#2| |#4| (-790))) (-15 -2118 ((-1 |#4| (-658 |#4|)) |#3|)) (IF (|has| |#1| (-582)) (-15 -4457 (|#4| (-433 |#2|))) |noBranch|)) 
+((-3016 ((|#2| (-1 |#3| |#3|) (-658 |#1|)) 67))) 
+(((-1274 |#1| |#2| |#3|) (-10 -7 (-15 -3016 (|#2| (-1 |#3| |#3|) (-658 |#1|)))) (-388) (-1270 |#1|) (-1270 (-1185 |#1|))) (T -1274)) 
+((-3016 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *6)) (-5 *4 (-658 *5)) (-4 *5 (-388)) (-4 *6 (-1270 (-1185 *5))) (-4 *2 (-1270 *5)) (-5 *1 (-1274 *5 *2 *6))))) 
+(-10 -7 (-15 -3016 (|#2| (-1 |#3| |#3|) (-658 |#1|)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-4085 (((-658 (-1103)) $) NIL)) (-3983 (((-1191) $) 79)) (-3395 (((-1252 |#2| |#1|) $ (-790)) 68)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) NIL (|has| |#1| (-582)))) (-1555 (($ $) NIL (|has| |#1| (-582)))) (-1313 (((-141) $) 128 (|has| |#1| (-582)))) (-2306 (($ $ (-790)) 113) (($ $ (-790) (-790)) 115)) (-2982 (((-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|))) $) 38)) (-1588 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1507 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2350 (((-3 $ "failed") $ $) NIL)) (-1442 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1575 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1495 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2881 (($ (-1171 (-2 (|:| |k| (-790)) (|:| |c| |#1|)))) 51) (($ (-1171 |#1|)) NIL)) (-1601 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1521 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3001 (($) NIL T CONST)) (-3621 (($ $) 119)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-2410 (($ $) 126)) (-2012 (((-980 |#1|) $ (-790)) 59) (((-980 |#1|) $ (-790) (-790)) 61)) (-2273 (((-141) $) NIL)) (-1435 (($) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4346 (((-790) $) NIL) (((-790) $ (-790)) NIL)) (-3558 (((-141) $) NIL)) (-2669 (($ $) 103)) (-4422 (($ $ (-592)) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3368 (($ (-592) (-592) $) 121)) (-3990 (($ $ (-944)) 125)) (-1376 (($ (-1 |#1| (-592)) $) 97)) (-2027 (((-141) $) NIL)) (-4526 (($ |#1| (-790)) 12) (($ $ (-1103) (-790)) NIL) (($ $ (-658 (-1103)) (-658 (-790))) NIL)) (-2731 (($ (-1 |#1| |#1|) $) 85)) (-4546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-4573 (($ $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-4006 (($ $) 101)) (-3121 (($ $) 99)) (-3884 (($ (-592) (-592) $) 123)) (-3162 (($ $) 136 (|has| |#1| (-43 (-433 (-592))))) (($ $ (-1191)) 139 (-3836 (-12 (|has| |#1| (-15 -3162 (|#1| |#1| (-1191)))) (|has| |#1| (-15 -4085 ((-658 (-1191)) |#1|))) (|has| |#1| (-43 (-433 (-592))))) (-12 (|has| |#1| (-29 (-592))) (|has| |#1| (-43 (-433 (-592)))) (|has| |#1| (-987)) (|has| |#1| (-1211))))) (($ $ (-1276 |#2|)) 137 (|has| |#1| (-43 (-433 (-592)))))) (-2951 (((-1137) $) NIL)) (-2860 (($ $ (-592) (-592)) 107)) (-2807 (($ $ (-790)) 109)) (-3616 (((-3 $ "failed") $ $) NIL (|has| |#1| (-582)))) (-1430 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-3325 (($ $) 105)) (-2806 (((-1171 |#1|) $ |#1|) 87 (|has| |#1| (-15 ** (|#1| |#1| (-790)))))) (-3927 ((|#1| $ (-790)) 82) (($ $ $) 117 (|has| (-790) (-1131)))) (-3644 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) 92 (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) 89 (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $ (-1276 |#2|)) 90)) (-4525 (((-790) $) NIL)) (-1609 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1527 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1594 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1515 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1581 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1501 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1700 (($ $) 111)) (-1683 (((-877) $) NIL) (($ (-592)) 18) (($ (-433 (-592))) 134 (|has| |#1| (-43 (-433 (-592))))) (($ $) NIL (|has| |#1| (-582))) (($ |#1|) 17 (|has| |#1| (-194))) (($ (-1252 |#2| |#1|)) 73) (($ (-1276 |#2|)) 14)) (-1647 (((-1171 |#1|) $) NIL)) (-1937 ((|#1| $ (-790)) 81)) (-1517 (((-3 $ "failed") $) NIL (|has| |#1| (-169)))) (-4010 (((-790)) NIL)) (-2838 ((|#1| $) 80)) (-1630 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1546 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2537 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1617 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1533 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1642 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1559 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-2642 ((|#1| $ (-790)) 78 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-790)))) (|has| |#1| (-15 -1683 (|#1| (-1191))))))) (-2892 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1567 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1636 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1552 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1624 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1540 (($ $) NIL (|has| |#1| (-43 (-433 (-592)))))) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 44 T CONST)) (-4257 (($) 9 T CONST)) (-1940 (($ $ (-658 (-1191)) (-658 (-790))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191) (-790)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-658 (-1191))) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-1191)) NIL (-12 (|has| |#1| (-15 * (|#1| (-790) |#1|))) (|has| |#1| (-922 (-1191))))) (($ $ (-790)) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-790) |#1|))))) (-3255 (((-141) $ $) NIL)) (-3313 (($ $ |#1|) NIL (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) 94)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL) (($ $ |#1|) 131 (|has| |#1| (-388))) (($ $ $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592)))))) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 93) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-433 (-592)) $) NIL (|has| |#1| (-43 (-433 (-592))))) (($ $ (-433 (-592))) NIL (|has| |#1| (-43 (-433 (-592))))))) 
+(((-1275 |#1| |#2|) (-13 (-1270 |#1|) (-10 -8 (-15 -1683 ($ (-1252 |#2| |#1|))) (-15 -3395 ((-1252 |#2| |#1|) $ (-790))) (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (-15 -3121 ($ $)) (-15 -4006 ($ $)) (-15 -2669 ($ $)) (-15 -3325 ($ $)) (-15 -2860 ($ $ (-592) (-592))) (-15 -3621 ($ $)) (-15 -3368 ($ (-592) (-592) $)) (-15 -3884 ($ (-592) (-592) $)) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) (-1075) (-1191)) (T -1275)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-1252 *4 *3)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-5 *1 (-1275 *3 *4)))) (-3395 (*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1252 *5 *4)) (-5 *1 (-1275 *4 *5)) (-4 *4 (-1075)) (-14 *5 (-1191)))) (-1683 (*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)))) (-3644 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)))) (-3121 (*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191)))) (-4006 (*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191)))) (-2669 (*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191)))) (-3325 (*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191)))) (-2860 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-1191)))) (-3621 (*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191)))) (-3368 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-1191)))) (-3884 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-1191)))) (-3162 (*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075))))) 
+(-13 (-1270 |#1|) (-10 -8 (-15 -1683 ($ (-1252 |#2| |#1|))) (-15 -3395 ((-1252 |#2| |#1|) $ (-790))) (-15 -1683 ($ (-1276 |#2|))) (-15 -3644 ($ $ (-1276 |#2|))) (-15 -3121 ($ $)) (-15 -4006 ($ $)) (-15 -2669 ($ $)) (-15 -3325 ($ $)) (-15 -2860 ($ $ (-592) (-592))) (-15 -3621 ($ $)) (-15 -3368 ($ (-592) (-592) $)) (-15 -3884 ($ (-592) (-592) $)) (IF (|has| |#1| (-43 (-433 (-592)))) (-15 -3162 ($ $ (-1276 |#2|))) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-3983 (((-1191)) 12)) (-2685 (((-1173) $) 17)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 11) (((-1191) $) 8)) (-3255 (((-141) $ $) 14))) 
+(((-1276 |#1|) (-13 (-1119) (-632 (-1191)) (-10 -8 (-15 -1683 ((-1191) $)) (-15 -3983 ((-1191))))) (-1191)) (T -1276)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1276 *3)) (-14 *3 *2))) (-3983 (*1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1276 *3)) (-14 *3 *2)))) 
+(-13 (-1119) (-632 (-1191)) (-10 -8 (-15 -1683 ((-1191) $)) (-15 -3983 ((-1191))))) 
+((-1417 (($ (-790)) 16)) (-4363 (((-706 |#2|) $ $) 37)) (-2311 ((|#2| $) 46)) (-4233 ((|#2| $) 45)) (-1729 ((|#2| $ $) 33)) (-2746 (($ $ $) 42)) (-3306 (($ $) 20) (($ $ $) 26)) (-3300 (($ $ $) 13)) (* (($ (-592) $) 23) (($ |#2| $) 29) (($ $ |#2|) 28))) 
+(((-1277 |#1| |#2|) (-10 -8 (-15 -2311 (|#2| |#1|)) (-15 -4233 (|#2| |#1|)) (-15 -2746 (|#1| |#1| |#1|)) (-15 -4363 ((-706 |#2|) |#1| |#1|)) (-15 -1729 (|#2| |#1| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 -1417 (|#1| (-790))) (-15 -3300 (|#1| |#1| |#1|))) (-1278 |#2|) (-1225)) (T -1277)) 
+NIL 
+(-10 -8 (-15 -2311 (|#2| |#1|)) (-15 -4233 (|#2| |#1|)) (-15 -2746 (|#1| |#1| |#1|)) (-15 -4363 ((-706 |#2|) |#1| |#1|)) (-15 -1729 (|#2| |#1| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-592) |#1|)) (-15 -3306 (|#1| |#1| |#1|)) (-15 -3306 (|#1| |#1|)) (-15 -1417 (|#1| (-790))) (-15 -3300 (|#1| |#1| |#1|))) 
+((-1641 (((-141) $ $) 18 (|has| |#1| (-1119)))) (-1417 (($ (-790)) 105 (|has| |#1| (-23)))) (-3898 (((-1285) $ (-592) (-592)) 37 (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) 91) (((-141) $) 85 (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) 82 (|has| $ (-6 -4626))) (($ $) 81 (-12 (|has| |#1| (-869)) (|has| $ (-6 -4626))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) 8)) (-3932 ((|#1| $ (-592) |#1|) 49 (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) 53 (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) 70 (|has| $ (-6 -4625)))) (-3001 (($) 7 T CONST)) (-2512 (($ $) 83 (|has| $ (-6 -4626)))) (-1373 (($ $) 93)) (-1360 (($ $) 73 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-4459 (($ |#1| $) 72 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) (($ (-1 (-141) |#1|) $) 69 (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) 50 (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) 48)) (-1721 (((-592) (-1 (-141) |#1|) $) 90) (((-592) |#1| $) 89 (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) 88 (|has| |#1| (-1119)))) (-4004 (((-658 |#1|) $) 30 (|has| $ (-6 -4625)))) (-4363 (((-706 |#1|) $ $) 98 (|has| |#1| (-1075)))) (-3242 (($ (-790) |#1|) 64)) (-4345 (((-141) $ (-790)) 9)) (-2261 (((-592) $) 40 (|has| (-592) (-869)))) (-1837 (($ $ $) 80 (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) 29 (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) 27 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-1813 (((-592) $) 41 (|has| (-592) (-869)))) (-3319 (($ $ $) 79 (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2311 ((|#1| $) 95 (-12 (|has| |#1| (-1075)) (|has| |#1| (-1030))))) (-2554 (((-141) $ (-790)) 10)) (-4233 ((|#1| $) 96 (-12 (|has| |#1| (-1075)) (|has| |#1| (-1030))))) (-2685 (((-1173) $) 22 (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) 55) (($ $ $ (-592)) 54)) (-3708 (((-658 (-592)) $) 43)) (-3780 (((-141) (-592) $) 44)) (-2951 (((-1137) $) 21 (|has| |#1| (-1119)))) (-1918 ((|#1| $) 39 (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) 66)) (-1892 (($ $ |#1|) 38 (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) 32 (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) 26 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) 25 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) 23 (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) 14)) (-2254 (((-141) |#1| $) 42 (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) 45)) (-2943 (((-141) $) 11)) (-2890 (($) 12)) (-3927 ((|#1| $ (-592) |#1|) 47) ((|#1| $ (-592)) 46) (($ $ (-1246 (-592))) 58)) (-1729 ((|#1| $ $) 99 (|has| |#1| (-1075)))) (-3208 (($ $ (-592)) 57) (($ $ (-1246 (-592))) 56)) (-2746 (($ $ $) 97 (|has| |#1| (-1075)))) (-3452 (((-790) (-1 (-141) |#1|) $) 31 (|has| $ (-6 -4625))) (((-790) |#1| $) 28 (-12 (|has| |#1| (-1119)) (|has| $ (-6 -4625))))) (-2385 (($ $ $ (-592)) 84 (|has| $ (-6 -4626)))) (-4599 (($ $) 13)) (-1778 (((-565) $) 74 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 65)) (-2266 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-658 $)) 60)) (-1683 (((-877) $) 20 (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) 33 (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) 77 (|has| |#1| (-869)))) (-3273 (((-141) $ $) 76 (|has| |#1| (-869)))) (-3255 (((-141) $ $) 19 (|has| |#1| (-1119)))) (-3279 (((-141) $ $) 78 (|has| |#1| (-869)))) (-3266 (((-141) $ $) 75 (|has| |#1| (-869)))) (-3306 (($ $) 104 (|has| |#1| (-21))) (($ $ $) 103 (|has| |#1| (-21)))) (-3300 (($ $ $) 106 (|has| |#1| (-25)))) (* (($ (-592) $) 102 (|has| |#1| (-21))) (($ |#1| $) 101 (|has| |#1| (-743))) (($ $ |#1|) 100 (|has| |#1| (-743)))) (-1699 (((-790) $) 6 (|has| $ (-6 -4625))))) 
+(((-1278 |#1|) (-1311) (-1225)) (T -1278)) 
+((-3300 (*1 *1 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-25)))) (-1417 (*1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1278 *3)) (-4 *3 (-23)) (-4 *3 (-1225)))) (-3306 (*1 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-21)))) (-3306 (*1 *1 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-21)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-1278 *3)) (-4 *3 (-1225)) (-4 *3 (-21)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-743)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-743)))) (-1729 (*1 *2 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-1075)))) (-4363 (*1 *2 *1 *1) (-12 (-4 *1 (-1278 *3)) (-4 *3 (-1225)) (-4 *3 (-1075)) (-5 *2 (-706 *3)))) (-2746 (*1 *1 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-1075)))) (-4233 (*1 *2 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-1030)) (-4 *2 (-1075)))) (-2311 (*1 *2 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-1030)) (-4 *2 (-1075))))) 
+(-13 (-19 |t#1|) (-10 -8 (IF (|has| |t#1| (-25)) (-15 -3300 ($ $ $)) |noBranch|) (IF (|has| |t#1| (-23)) (-15 -1417 ($ (-790))) |noBranch|) (IF (|has| |t#1| (-21)) (PROGN (-15 -3306 ($ $)) (-15 -3306 ($ $ $)) (-15 * ($ (-592) $))) |noBranch|) (IF (|has| |t#1| (-743)) (PROGN (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|))) |noBranch|) (IF (|has| |t#1| (-1075)) (PROGN (-15 -1729 (|t#1| $ $)) (-15 -4363 ((-706 |t#1|) $ $)) (-15 -2746 ($ $ $))) |noBranch|) (IF (|has| |t#1| (-1030)) (IF (|has| |t#1| (-1075)) (PROGN (-15 -4233 (|t#1| $)) (-15 -2311 (|t#1| $))) |noBranch|) |noBranch|))) 
+(((-39) . T) ((-125) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-632 (-877)) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-175 |#1|) . T) ((-633 (-565)) |has| |#1| (-633 (-565))) ((-303 (-592) |#1|) . T) ((-305 (-592) |#1|) . T) ((-325 |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-399 |#1|) . T) ((-523 |#1|) . T) ((-625 (-592) |#1|) . T) ((-547 |#1| |#1|) -12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))) ((-664 |#1|) . T) ((-19 |#1|) . T) ((-869) |has| |#1| (-869)) ((-1119) -3836 (|has| |#1| (-1119)) (|has| |#1| (-869))) ((-1225) . T)) 
+((-1779 (((-1280 |#2|) (-1 |#2| |#1| |#2|) (-1280 |#1|) |#2|) 13)) (-3657 ((|#2| (-1 |#2| |#1| |#2|) (-1280 |#1|) |#2|) 15)) (-2731 (((-3 (-1280 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1280 |#1|)) 28) (((-1280 |#2|) (-1 |#2| |#1|) (-1280 |#1|)) 18))) 
+(((-1279 |#1| |#2|) (-10 -7 (-15 -1779 ((-1280 |#2|) (-1 |#2| |#1| |#2|) (-1280 |#1|) |#2|)) (-15 -3657 (|#2| (-1 |#2| |#1| |#2|) (-1280 |#1|) |#2|)) (-15 -2731 ((-1280 |#2|) (-1 |#2| |#1|) (-1280 |#1|))) (-15 -2731 ((-3 (-1280 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1280 |#1|)))) (-1225) (-1225)) (T -1279)) 
+((-2731 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *6 "failed") *5)) (-5 *4 (-1280 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1280 *6)) (-5 *1 (-1279 *5 *6)))) (-2731 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1280 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1280 *6)) (-5 *1 (-1279 *5 *6)))) (-3657 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1280 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-1279 *5 *2)))) (-1779 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-1280 *6)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-5 *2 (-1280 *5)) (-5 *1 (-1279 *6 *5))))) 
+(-10 -7 (-15 -1779 ((-1280 |#2|) (-1 |#2| |#1| |#2|) (-1280 |#1|) |#2|)) (-15 -3657 (|#2| (-1 |#2| |#1| |#2|) (-1280 |#1|) |#2|)) (-15 -2731 ((-1280 |#2|) (-1 |#2| |#1|) (-1280 |#1|))) (-15 -2731 ((-3 (-1280 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1280 |#1|)))) 
+((-1641 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-1417 (($ (-790)) NIL (|has| |#1| (-23)))) (-3665 (($ (-658 |#1|)) 9)) (-3898 (((-1285) $ (-592) (-592)) NIL (|has| $ (-6 -4626)))) (-4076 (((-141) (-1 (-141) |#1| |#1|) $) NIL) (((-141) $) NIL (|has| |#1| (-869)))) (-2831 (($ (-1 (-141) |#1| |#1|) $) NIL (|has| $ (-6 -4626))) (($ $) NIL (-12 (|has| $ (-6 -4626)) (|has| |#1| (-869))))) (-3960 (($ (-1 (-141) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-869)))) (-2126 (((-141) $ (-790)) NIL)) (-3932 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626))) ((|#1| $ (-1246 (-592)) |#1|) NIL (|has| $ (-6 -4626)))) (-3113 (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3001 (($) NIL T CONST)) (-2512 (($ $) NIL (|has| $ (-6 -4626)))) (-1373 (($ $) NIL)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4459 (($ |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) (($ (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3657 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4625))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4625)))) (-1426 ((|#1| $ (-592) |#1|) NIL (|has| $ (-6 -4626)))) (-3959 ((|#1| $ (-592)) NIL)) (-1721 (((-592) (-1 (-141) |#1|) $) NIL) (((-592) |#1| $) NIL (|has| |#1| (-1119))) (((-592) |#1| $ (-592)) NIL (|has| |#1| (-1119)))) (-4004 (((-658 |#1|) $) 15 (|has| $ (-6 -4625)))) (-4363 (((-706 |#1|) $ $) NIL (|has| |#1| (-1075)))) (-3242 (($ (-790) |#1|) NIL)) (-4345 (((-141) $ (-790)) NIL)) (-2261 (((-592) $) NIL (|has| (-592) (-869)))) (-1837 (($ $ $) NIL (|has| |#1| (-869)))) (-4491 (($ (-1 (-141) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-869)))) (-4467 (((-658 |#1|) $) NIL (|has| $ (-6 -4625)))) (-3133 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-1813 (((-592) $) NIL (|has| (-592) (-869)))) (-3319 (($ $ $) NIL (|has| |#1| (-869)))) (-3987 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2311 ((|#1| $) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1075))))) (-2554 (((-141) $ (-790)) NIL)) (-4233 ((|#1| $) NIL (-12 (|has| |#1| (-1030)) (|has| |#1| (-1075))))) (-2685 (((-1173) $) NIL (|has| |#1| (-1119)))) (-3666 (($ |#1| $ (-592)) NIL) (($ $ $ (-592)) NIL)) (-3708 (((-658 (-592)) $) NIL)) (-3780 (((-141) (-592) $) NIL)) (-2951 (((-1137) $) NIL (|has| |#1| (-1119)))) (-1918 ((|#1| $) NIL (|has| (-592) (-869)))) (-4050 (((-3 |#1| "failed") (-1 (-141) |#1|) $) NIL)) (-1892 (($ $ |#1|) NIL (|has| $ (-6 -4626)))) (-3002 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 (-310 |#1|))) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-310 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119)))) (($ $ (-658 |#1|) (-658 |#1|)) NIL (-12 (|has| |#1| (-325 |#1|)) (|has| |#1| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2254 (((-141) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-4210 (((-658 |#1|) $) NIL)) (-2943 (((-141) $) NIL)) (-2890 (($) NIL)) (-3927 ((|#1| $ (-592) |#1|) NIL) ((|#1| $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-1729 ((|#1| $ $) NIL (|has| |#1| (-1075)))) (-3208 (($ $ (-592)) NIL) (($ $ (-1246 (-592))) NIL)) (-2746 (($ $ $) NIL (|has| |#1| (-1075)))) (-3452 (((-790) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625))) (((-790) |#1| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#1| (-1119))))) (-2385 (($ $ $ (-592)) NIL (|has| $ (-6 -4626)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) 19 (|has| |#1| (-633 (-565))))) (-4466 (($ (-658 |#1|)) 8)) (-2266 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-658 $)) NIL)) (-1683 (((-877) $) NIL (|has| |#1| (-1119)))) (-3369 (((-141) (-1 (-141) |#1|) $) NIL (|has| $ (-6 -4625)))) (-3286 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3273 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3255 (((-141) $ $) NIL (|has| |#1| (-1119)))) (-3279 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3266 (((-141) $ $) NIL (|has| |#1| (-869)))) (-3306 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-3300 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-592) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-743))) (($ $ |#1|) NIL (|has| |#1| (-743)))) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1280 |#1|) (-13 (-1278 |#1|) (-10 -8 (-15 -3665 ($ (-658 |#1|))))) (-1225)) (T -1280)) 
+((-3665 (*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-1280 *3))))) 
+(-13 (-1278 |#1|) (-10 -8 (-15 -3665 ($ (-658 |#1|))))) 
+((-1641 (((-141) $ $) NIL)) (-3802 (((-1173) $ (-1173)) 87) (((-1173) $ (-1173) (-1173)) 85) (((-1173) $ (-1173) (-658 (-1173))) 84)) (-1826 (($) 56)) (-3873 (((-1285) $ (-497) (-944)) 42)) (-3682 (((-1285) $ (-944) (-1173)) 70) (((-1285) $ (-944) (-896)) 71)) (-3399 (((-1285) $ (-944) (-405) (-405)) 45)) (-4116 (((-1285) $ (-1173)) 66)) (-4205 (((-1285) $ (-944) (-1173)) 75)) (-4086 (((-1285) $ (-944) (-405) (-405)) 46)) (-3046 (((-1285) $ (-944) (-944)) 43)) (-3796 (((-1285) $) 67)) (-3067 (((-1285) $ (-944) (-1173)) 74)) (-3783 (((-1285) $ (-497) (-944)) 30)) (-2190 (((-1285) $ (-944) (-1173)) 73)) (-1897 (((-658 (-278)) $) 22) (($ $ (-658 (-278))) 23)) (-2810 (((-1285) $ (-790) (-790)) 40)) (-2691 (($ $) 57) (($ (-497) (-658 (-278))) 58)) (-2685 (((-1173) $) NIL)) (-1350 (((-592) $) 37)) (-2951 (((-1137) $) NIL)) (-4405 (((-1280 (-3 (-497) "undefined")) $) 36)) (-3391 (((-1280 (-2 (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)) (|:| -2190 (-592)) (|:| -2180 (-592)) (|:| |spline| (-592)) (|:| -1436 (-592)) (|:| |axesColor| (-896)) (|:| -3682 (-592)) (|:| |unitsColor| (-896)) (|:| |showing| (-592)))) $) 35)) (-2871 (((-1285) $ (-944) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-896) (-592) (-896) (-592)) 65)) (-3909 (((-658 (-971 (-237))) $) NIL)) (-3636 (((-497) $ (-944)) 32)) (-3719 (((-1285) $ (-790) (-790) (-944) (-944)) 39)) (-2274 (((-1285) $ (-1173)) 76)) (-2180 (((-1285) $ (-944) (-1173)) 72)) (-1683 (((-877) $) 82)) (-3511 (((-1285) $) 77)) (-1436 (((-1285) $ (-944) (-1173)) 68) (((-1285) $ (-944) (-896)) 69)) (-3255 (((-141) $ $) NIL))) 
+(((-1281) (-13 (-1119) (-10 -8 (-15 -3909 ((-658 (-971 (-237))) $)) (-15 -1826 ($)) (-15 -2691 ($ $)) (-15 -1897 ((-658 (-278)) $)) (-15 -1897 ($ $ (-658 (-278)))) (-15 -2691 ($ (-497) (-658 (-278)))) (-15 -2871 ((-1285) $ (-944) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-896) (-592) (-896) (-592))) (-15 -3391 ((-1280 (-2 (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)) (|:| -2190 (-592)) (|:| -2180 (-592)) (|:| |spline| (-592)) (|:| -1436 (-592)) (|:| |axesColor| (-896)) (|:| -3682 (-592)) (|:| |unitsColor| (-896)) (|:| |showing| (-592)))) $)) (-15 -4405 ((-1280 (-3 (-497) "undefined")) $)) (-15 -4116 ((-1285) $ (-1173))) (-15 -3783 ((-1285) $ (-497) (-944))) (-15 -3636 ((-497) $ (-944))) (-15 -1436 ((-1285) $ (-944) (-1173))) (-15 -1436 ((-1285) $ (-944) (-896))) (-15 -3682 ((-1285) $ (-944) (-1173))) (-15 -3682 ((-1285) $ (-944) (-896))) (-15 -2190 ((-1285) $ (-944) (-1173))) (-15 -3067 ((-1285) $ (-944) (-1173))) (-15 -2180 ((-1285) $ (-944) (-1173))) (-15 -2274 ((-1285) $ (-1173))) (-15 -3511 ((-1285) $)) (-15 -3719 ((-1285) $ (-790) (-790) (-944) (-944))) (-15 -4086 ((-1285) $ (-944) (-405) (-405))) (-15 -3399 ((-1285) $ (-944) (-405) (-405))) (-15 -4205 ((-1285) $ (-944) (-1173))) (-15 -2810 ((-1285) $ (-790) (-790))) (-15 -3873 ((-1285) $ (-497) (-944))) (-15 -3046 ((-1285) $ (-944) (-944))) (-15 -3802 ((-1173) $ (-1173))) (-15 -3802 ((-1173) $ (-1173) (-1173))) (-15 -3802 ((-1173) $ (-1173) (-658 (-1173)))) (-15 -3796 ((-1285) $)) (-15 -1350 ((-592) $)) (-15 -1683 ((-877) $))))) (T -1281)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1281)))) (-3909 (*1 *2 *1) (-12 (-5 *2 (-658 (-971 (-237)))) (-5 *1 (-1281)))) (-1826 (*1 *1) (-5 *1 (-1281))) (-2691 (*1 *1 *1) (-5 *1 (-1281))) (-1897 (*1 *2 *1) (-12 (-5 *2 (-658 (-278))) (-5 *1 (-1281)))) (-1897 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-278))) (-5 *1 (-1281)))) (-2691 (*1 *1 *2 *3) (-12 (-5 *2 (-497)) (-5 *3 (-658 (-278))) (-5 *1 (-1281)))) (-2871 (*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (-12 (-5 *3 (-944)) (-5 *4 (-237)) (-5 *5 (-592)) (-5 *6 (-896)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3391 (*1 *2 *1) (-12 (-5 *2 (-1280 (-2 (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)) (|:| -2190 (-592)) (|:| -2180 (-592)) (|:| |spline| (-592)) (|:| -1436 (-592)) (|:| |axesColor| (-896)) (|:| -3682 (-592)) (|:| |unitsColor| (-896)) (|:| |showing| (-592))))) (-5 *1 (-1281)))) (-4405 (*1 *2 *1) (-12 (-5 *2 (-1280 (-3 (-497) "undefined"))) (-5 *1 (-1281)))) (-4116 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3783 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-497)) (-5 *4 (-944)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3636 (*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-5 *2 (-497)) (-5 *1 (-1281)))) (-1436 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-1436 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-896)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3682 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3682 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-896)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-2190 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3067 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-2180 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-2274 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3511 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3719 (*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-790)) (-5 *4 (-944)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-4086 (*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-944)) (-5 *4 (-405)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3399 (*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-944)) (-5 *4 (-405)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-4205 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-2810 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3873 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-497)) (-5 *4 (-944)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3046 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1285)) (-5 *1 (-1281)))) (-3802 (*1 *2 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1281)))) (-3802 (*1 *2 *1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1281)))) (-3802 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-1173)) (-5 *1 (-1281)))) (-3796 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1281)))) (-1350 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1281))))) 
+(-13 (-1119) (-10 -8 (-15 -3909 ((-658 (-971 (-237))) $)) (-15 -1826 ($)) (-15 -2691 ($ $)) (-15 -1897 ((-658 (-278)) $)) (-15 -1897 ($ $ (-658 (-278)))) (-15 -2691 ($ (-497) (-658 (-278)))) (-15 -2871 ((-1285) $ (-944) (-237) (-237) (-237) (-237) (-592) (-592) (-592) (-592) (-896) (-592) (-896) (-592))) (-15 -3391 ((-1280 (-2 (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)) (|:| -2190 (-592)) (|:| -2180 (-592)) (|:| |spline| (-592)) (|:| -1436 (-592)) (|:| |axesColor| (-896)) (|:| -3682 (-592)) (|:| |unitsColor| (-896)) (|:| |showing| (-592)))) $)) (-15 -4405 ((-1280 (-3 (-497) "undefined")) $)) (-15 -4116 ((-1285) $ (-1173))) (-15 -3783 ((-1285) $ (-497) (-944))) (-15 -3636 ((-497) $ (-944))) (-15 -1436 ((-1285) $ (-944) (-1173))) (-15 -1436 ((-1285) $ (-944) (-896))) (-15 -3682 ((-1285) $ (-944) (-1173))) (-15 -3682 ((-1285) $ (-944) (-896))) (-15 -2190 ((-1285) $ (-944) (-1173))) (-15 -3067 ((-1285) $ (-944) (-1173))) (-15 -2180 ((-1285) $ (-944) (-1173))) (-15 -2274 ((-1285) $ (-1173))) (-15 -3511 ((-1285) $)) (-15 -3719 ((-1285) $ (-790) (-790) (-944) (-944))) (-15 -4086 ((-1285) $ (-944) (-405) (-405))) (-15 -3399 ((-1285) $ (-944) (-405) (-405))) (-15 -4205 ((-1285) $ (-944) (-1173))) (-15 -2810 ((-1285) $ (-790) (-790))) (-15 -3873 ((-1285) $ (-497) (-944))) (-15 -3046 ((-1285) $ (-944) (-944))) (-15 -3802 ((-1173) $ (-1173))) (-15 -3802 ((-1173) $ (-1173) (-1173))) (-15 -3802 ((-1173) $ (-1173) (-658 (-1173)))) (-15 -3796 ((-1285) $)) (-15 -1350 ((-592) $)) (-15 -1683 ((-877) $)))) 
+((-1641 (((-141) $ $) NIL)) (-2570 (((-1285) $ (-405)) 138) (((-1285) $ (-405) (-405) (-405)) 139)) (-3802 (((-1173) $ (-1173)) 146) (((-1173) $ (-1173) (-1173)) 144) (((-1173) $ (-1173) (-658 (-1173))) 143)) (-4588 (($) 49)) (-3678 (((-1285) $ (-405) (-405) (-405) (-405) (-405)) 114) (((-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))) $) 112) (((-1285) $ (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) 113) (((-1285) $ (-592) (-592) (-405) (-405) (-405)) 115) (((-1285) $ (-405) (-405)) 116) (((-1285) $ (-405) (-405) (-405)) 123)) (-2426 (((-405)) 96) (((-405) (-405)) 97)) (-2300 (((-405)) 91) (((-405) (-405)) 93)) (-2318 (((-405)) 94) (((-405) (-405)) 95)) (-2489 (((-405)) 100) (((-405) (-405)) 101)) (-2459 (((-405)) 98) (((-405) (-405)) 99)) (-3399 (((-1285) $ (-405) (-405)) 140)) (-4116 (((-1285) $ (-1173)) 124)) (-3540 (((-1150 (-237)) $) 50) (($ $ (-1150 (-237))) 51)) (-2476 (((-1285) $ (-1173)) 152)) (-3966 (((-1285) $ (-1173)) 153)) (-3735 (((-1285) $ (-405) (-405)) 122) (((-1285) $ (-592) (-592)) 137)) (-3046 (((-1285) $ (-944) (-944)) 130)) (-3796 (((-1285) $) 110)) (-1995 (((-1285) $ (-1173)) 151)) (-2122 (((-1285) $ (-1173)) 107)) (-1897 (((-658 (-278)) $) 52) (($ $ (-658 (-278))) 53)) (-2810 (((-1285) $ (-790) (-790)) 129)) (-3443 (((-1285) $ (-790) (-971 (-237))) 158)) (-2466 (($ $) 56) (($ (-1150 (-237)) (-1173)) 57) (($ (-1150 (-237)) (-658 (-278))) 58)) (-3099 (((-1285) $ (-405) (-405) (-405)) 104)) (-2685 (((-1173) $) NIL)) (-1350 (((-592) $) 102)) (-3115 (((-1285) $ (-405)) 141)) (-3598 (((-1285) $ (-405)) 156)) (-2951 (((-1137) $) NIL)) (-1331 (((-1285) $ (-405)) 155)) (-2218 (((-1285) $ (-1173)) 109)) (-3719 (((-1285) $ (-790) (-790) (-944) (-944)) 128)) (-3569 (((-1285) $ (-1173)) 106)) (-2274 (((-1285) $ (-1173)) 108)) (-4386 (((-1285) $ (-179) (-179)) 127)) (-1683 (((-877) $) 135)) (-3511 (((-1285) $) 111)) (-2301 (((-1285) $ (-1173)) 154)) (-1436 (((-1285) $ (-1173)) 105)) (-3255 (((-141) $ $) NIL))) 
+(((-1282) (-13 (-1119) (-10 -8 (-15 -2300 ((-405))) (-15 -2300 ((-405) (-405))) (-15 -2318 ((-405))) (-15 -2318 ((-405) (-405))) (-15 -2426 ((-405))) (-15 -2426 ((-405) (-405))) (-15 -2459 ((-405))) (-15 -2459 ((-405) (-405))) (-15 -2489 ((-405))) (-15 -2489 ((-405) (-405))) (-15 -4588 ($)) (-15 -2466 ($ $)) (-15 -2466 ($ (-1150 (-237)) (-1173))) (-15 -2466 ($ (-1150 (-237)) (-658 (-278)))) (-15 -3540 ((-1150 (-237)) $)) (-15 -3540 ($ $ (-1150 (-237)))) (-15 -3443 ((-1285) $ (-790) (-971 (-237)))) (-15 -1897 ((-658 (-278)) $)) (-15 -1897 ($ $ (-658 (-278)))) (-15 -2810 ((-1285) $ (-790) (-790))) (-15 -3046 ((-1285) $ (-944) (-944))) (-15 -4116 ((-1285) $ (-1173))) (-15 -3719 ((-1285) $ (-790) (-790) (-944) (-944))) (-15 -3678 ((-1285) $ (-405) (-405) (-405) (-405) (-405))) (-15 -3678 ((-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))) $)) (-15 -3678 ((-1285) $ (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))))) (-15 -3678 ((-1285) $ (-592) (-592) (-405) (-405) (-405))) (-15 -3678 ((-1285) $ (-405) (-405))) (-15 -3678 ((-1285) $ (-405) (-405) (-405))) (-15 -2274 ((-1285) $ (-1173))) (-15 -1436 ((-1285) $ (-1173))) (-15 -3569 ((-1285) $ (-1173))) (-15 -2122 ((-1285) $ (-1173))) (-15 -2218 ((-1285) $ (-1173))) (-15 -3735 ((-1285) $ (-405) (-405))) (-15 -3735 ((-1285) $ (-592) (-592))) (-15 -2570 ((-1285) $ (-405))) (-15 -2570 ((-1285) $ (-405) (-405) (-405))) (-15 -3399 ((-1285) $ (-405) (-405))) (-15 -1995 ((-1285) $ (-1173))) (-15 -1331 ((-1285) $ (-405))) (-15 -3598 ((-1285) $ (-405))) (-15 -2476 ((-1285) $ (-1173))) (-15 -3966 ((-1285) $ (-1173))) (-15 -2301 ((-1285) $ (-1173))) (-15 -3099 ((-1285) $ (-405) (-405) (-405))) (-15 -3115 ((-1285) $ (-405))) (-15 -3796 ((-1285) $)) (-15 -4386 ((-1285) $ (-179) (-179))) (-15 -3802 ((-1173) $ (-1173))) (-15 -3802 ((-1173) $ (-1173) (-1173))) (-15 -3802 ((-1173) $ (-1173) (-658 (-1173)))) (-15 -3511 ((-1285) $)) (-15 -1350 ((-592) $))))) (T -1282)) 
+((-2300 (*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2300 (*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2318 (*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2318 (*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2426 (*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2426 (*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2459 (*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2459 (*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2489 (*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-2489 (*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) (-4588 (*1 *1) (-5 *1 (-1282))) (-2466 (*1 *1 *1) (-5 *1 (-1282))) (-2466 (*1 *1 *2 *3) (-12 (-5 *2 (-1150 (-237))) (-5 *3 (-1173)) (-5 *1 (-1282)))) (-2466 (*1 *1 *2 *3) (-12 (-5 *2 (-1150 (-237))) (-5 *3 (-658 (-278))) (-5 *1 (-1282)))) (-3540 (*1 *2 *1) (-12 (-5 *2 (-1150 (-237))) (-5 *1 (-1282)))) (-3540 (*1 *1 *1 *2) (-12 (-5 *2 (-1150 (-237))) (-5 *1 (-1282)))) (-3443 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-790)) (-5 *4 (-971 (-237))) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-1897 (*1 *2 *1) (-12 (-5 *2 (-658 (-278))) (-5 *1 (-1282)))) (-1897 (*1 *1 *1 *2) (-12 (-5 *2 (-658 (-278))) (-5 *1 (-1282)))) (-2810 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3046 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-4116 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3719 (*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-790)) (-5 *4 (-944)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3678 (*1 *2 *1 *3 *3 *3 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3678 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) (-5 *1 (-1282)))) (-3678 (*1 *2 *1 *3) (-12 (-5 *3 (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3678 (*1 *2 *1 *3 *3 *4 *4 *4) (-12 (-5 *3 (-592)) (-5 *4 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3678 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3678 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-2274 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-1436 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3569 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-2122 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-2218 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3735 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3735 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-2570 (*1 *2 *1 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-2570 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3399 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-1995 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-1331 (*1 *2 *1 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3598 (*1 *2 *1 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-2476 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3966 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-2301 (*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3099 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3115 (*1 *2 *1 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3796 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1282)))) (-4386 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-179)) (-5 *2 (-1285)) (-5 *1 (-1282)))) (-3802 (*1 *2 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1282)))) (-3802 (*1 *2 *1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1282)))) (-3802 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-1173)) (-5 *1 (-1282)))) (-3511 (*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1282)))) (-1350 (*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1282))))) 
+(-13 (-1119) (-10 -8 (-15 -2300 ((-405))) (-15 -2300 ((-405) (-405))) (-15 -2318 ((-405))) (-15 -2318 ((-405) (-405))) (-15 -2426 ((-405))) (-15 -2426 ((-405) (-405))) (-15 -2459 ((-405))) (-15 -2459 ((-405) (-405))) (-15 -2489 ((-405))) (-15 -2489 ((-405) (-405))) (-15 -4588 ($)) (-15 -2466 ($ $)) (-15 -2466 ($ (-1150 (-237)) (-1173))) (-15 -2466 ($ (-1150 (-237)) (-658 (-278)))) (-15 -3540 ((-1150 (-237)) $)) (-15 -3540 ($ $ (-1150 (-237)))) (-15 -3443 ((-1285) $ (-790) (-971 (-237)))) (-15 -1897 ((-658 (-278)) $)) (-15 -1897 ($ $ (-658 (-278)))) (-15 -2810 ((-1285) $ (-790) (-790))) (-15 -3046 ((-1285) $ (-944) (-944))) (-15 -4116 ((-1285) $ (-1173))) (-15 -3719 ((-1285) $ (-790) (-790) (-944) (-944))) (-15 -3678 ((-1285) $ (-405) (-405) (-405) (-405) (-405))) (-15 -3678 ((-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))) $)) (-15 -3678 ((-1285) $ (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237))))) (-15 -3678 ((-1285) $ (-592) (-592) (-405) (-405) (-405))) (-15 -3678 ((-1285) $ (-405) (-405))) (-15 -3678 ((-1285) $ (-405) (-405) (-405))) (-15 -2274 ((-1285) $ (-1173))) (-15 -1436 ((-1285) $ (-1173))) (-15 -3569 ((-1285) $ (-1173))) (-15 -2122 ((-1285) $ (-1173))) (-15 -2218 ((-1285) $ (-1173))) (-15 -3735 ((-1285) $ (-405) (-405))) (-15 -3735 ((-1285) $ (-592) (-592))) (-15 -2570 ((-1285) $ (-405))) (-15 -2570 ((-1285) $ (-405) (-405) (-405))) (-15 -3399 ((-1285) $ (-405) (-405))) (-15 -1995 ((-1285) $ (-1173))) (-15 -1331 ((-1285) $ (-405))) (-15 -3598 ((-1285) $ (-405))) (-15 -2476 ((-1285) $ (-1173))) (-15 -3966 ((-1285) $ (-1173))) (-15 -2301 ((-1285) $ (-1173))) (-15 -3099 ((-1285) $ (-405) (-405) (-405))) (-15 -3115 ((-1285) $ (-405))) (-15 -3796 ((-1285) $)) (-15 -4386 ((-1285) $ (-179) (-179))) (-15 -3802 ((-1173) $ (-1173))) (-15 -3802 ((-1173) $ (-1173) (-1173))) (-15 -3802 ((-1173) $ (-1173) (-658 (-1173)))) (-15 -3511 ((-1285) $)) (-15 -1350 ((-592) $)))) 
+((-2395 (((-658 (-1173)) (-658 (-1173))) 94) (((-658 (-1173))) 89)) (-2531 (((-658 (-1173))) 87)) (-2276 (((-658 (-944)) (-658 (-944))) 62) (((-658 (-944))) 59)) (-2146 (((-658 (-790)) (-658 (-790))) 56) (((-658 (-790))) 52)) (-2258 (((-1285)) 64)) (-3734 (((-944) (-944)) 80) (((-944)) 79)) (-3819 (((-944) (-944)) 78) (((-944)) 77)) (-4315 (((-896) (-896)) 74) (((-896)) 73)) (-3559 (((-237)) 84) (((-237) (-405)) 86)) (-3240 (((-944)) 81) (((-944) (-944)) 82)) (-1598 (((-944) (-944)) 76) (((-944)) 75)) (-3773 (((-896) (-896)) 68) (((-896)) 66)) (-1882 (((-896) (-896)) 70) (((-896)) 69)) (-1367 (((-896) (-896)) 72) (((-896)) 71))) 
+(((-1283) (-10 -7 (-15 -3773 ((-896))) (-15 -3773 ((-896) (-896))) (-15 -1882 ((-896))) (-15 -1882 ((-896) (-896))) (-15 -1367 ((-896))) (-15 -1367 ((-896) (-896))) (-15 -4315 ((-896))) (-15 -4315 ((-896) (-896))) (-15 -1598 ((-944))) (-15 -1598 ((-944) (-944))) (-15 -2146 ((-658 (-790)))) (-15 -2146 ((-658 (-790)) (-658 (-790)))) (-15 -2276 ((-658 (-944)))) (-15 -2276 ((-658 (-944)) (-658 (-944)))) (-15 -2258 ((-1285))) (-15 -2395 ((-658 (-1173)))) (-15 -2395 ((-658 (-1173)) (-658 (-1173)))) (-15 -2531 ((-658 (-1173)))) (-15 -3819 ((-944))) (-15 -3734 ((-944))) (-15 -3819 ((-944) (-944))) (-15 -3734 ((-944) (-944))) (-15 -3240 ((-944) (-944))) (-15 -3240 ((-944))) (-15 -3559 ((-237) (-405))) (-15 -3559 ((-237))))) (T -1283)) 
+((-3559 (*1 *2) (-12 (-5 *2 (-237)) (-5 *1 (-1283)))) (-3559 (*1 *2 *3) (-12 (-5 *3 (-405)) (-5 *2 (-237)) (-5 *1 (-1283)))) (-3240 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) (-3240 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) (-3734 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) (-3819 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) (-3734 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) (-3819 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) (-2531 (*1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1283)))) (-2395 (*1 *2 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1283)))) (-2395 (*1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1283)))) (-2258 (*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1283)))) (-2276 (*1 *2 *2) (-12 (-5 *2 (-658 (-944))) (-5 *1 (-1283)))) (-2276 (*1 *2) (-12 (-5 *2 (-658 (-944))) (-5 *1 (-1283)))) (-2146 (*1 *2 *2) (-12 (-5 *2 (-658 (-790))) (-5 *1 (-1283)))) (-2146 (*1 *2) (-12 (-5 *2 (-658 (-790))) (-5 *1 (-1283)))) (-1598 (*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) (-1598 (*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) (-4315 (*1 *2 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) (-4315 (*1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) (-1367 (*1 *2 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) (-1367 (*1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) (-1882 (*1 *2 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) (-1882 (*1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) (-3773 (*1 *2 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) (-3773 (*1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283))))) 
+(-10 -7 (-15 -3773 ((-896))) (-15 -3773 ((-896) (-896))) (-15 -1882 ((-896))) (-15 -1882 ((-896) (-896))) (-15 -1367 ((-896))) (-15 -1367 ((-896) (-896))) (-15 -4315 ((-896))) (-15 -4315 ((-896) (-896))) (-15 -1598 ((-944))) (-15 -1598 ((-944) (-944))) (-15 -2146 ((-658 (-790)))) (-15 -2146 ((-658 (-790)) (-658 (-790)))) (-15 -2276 ((-658 (-944)))) (-15 -2276 ((-658 (-944)) (-658 (-944)))) (-15 -2258 ((-1285))) (-15 -2395 ((-658 (-1173)))) (-15 -2395 ((-658 (-1173)) (-658 (-1173)))) (-15 -2531 ((-658 (-1173)))) (-15 -3819 ((-944))) (-15 -3734 ((-944))) (-15 -3819 ((-944) (-944))) (-15 -3734 ((-944) (-944))) (-15 -3240 ((-944) (-944))) (-15 -3240 ((-944))) (-15 -3559 ((-237) (-405))) (-15 -3559 ((-237)))) 
+((-1330 (((-497) (-658 (-658 (-971 (-237)))) (-658 (-278))) 17) (((-497) (-658 (-658 (-971 (-237))))) 16) (((-497) (-658 (-658 (-971 (-237)))) (-896) (-896) (-944) (-658 (-278))) 15)) (-4044 (((-1281) (-658 (-658 (-971 (-237)))) (-658 (-278))) 23) (((-1281) (-658 (-658 (-971 (-237)))) (-896) (-896) (-944) (-658 (-278))) 22)) (-1683 (((-1281) (-497)) 34))) 
+(((-1284) (-10 -7 (-15 -1330 ((-497) (-658 (-658 (-971 (-237)))) (-896) (-896) (-944) (-658 (-278)))) (-15 -1330 ((-497) (-658 (-658 (-971 (-237)))))) (-15 -1330 ((-497) (-658 (-658 (-971 (-237)))) (-658 (-278)))) (-15 -4044 ((-1281) (-658 (-658 (-971 (-237)))) (-896) (-896) (-944) (-658 (-278)))) (-15 -4044 ((-1281) (-658 (-658 (-971 (-237)))) (-658 (-278)))) (-15 -1683 ((-1281) (-497))))) (T -1284)) 
+((-1683 (*1 *2 *3) (-12 (-5 *3 (-497)) (-5 *2 (-1281)) (-5 *1 (-1284)))) (-4044 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-1284)))) (-4044 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-896)) (-5 *5 (-944)) (-5 *6 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-1284)))) (-1330 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-658 (-278))) (-5 *2 (-497)) (-5 *1 (-1284)))) (-1330 (*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *2 (-497)) (-5 *1 (-1284)))) (-1330 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-896)) (-5 *5 (-944)) (-5 *6 (-658 (-278))) (-5 *2 (-497)) (-5 *1 (-1284))))) 
+(-10 -7 (-15 -1330 ((-497) (-658 (-658 (-971 (-237)))) (-896) (-896) (-944) (-658 (-278)))) (-15 -1330 ((-497) (-658 (-658 (-971 (-237)))))) (-15 -1330 ((-497) (-658 (-658 (-971 (-237)))) (-658 (-278)))) (-15 -4044 ((-1281) (-658 (-658 (-971 (-237)))) (-896) (-896) (-944) (-658 (-278)))) (-15 -4044 ((-1281) (-658 (-658 (-971 (-237)))) (-658 (-278)))) (-15 -1683 ((-1281) (-497)))) 
+((-4191 (($) 7)) (-1683 (((-877) $) 10))) 
+(((-1285) (-10 -8 (-15 -4191 ($)) (-15 -1683 ((-877) $)))) (T -1285)) 
+((-1683 (*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1285)))) (-4191 (*1 *1) (-5 *1 (-1285)))) 
+(-10 -8 (-15 -4191 ($)) (-15 -1683 ((-877) $))) 
+((-3313 (($ $ |#2|) 10))) 
+(((-1286 |#1| |#2|) (-10 -8 (-15 -3313 (|#1| |#1| |#2|))) (-1287 |#2|) (-388)) (T -1286)) 
+NIL 
+(-10 -8 (-15 -3313 (|#1| |#1| |#2|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1936 (((-160)) 25)) (-1683 (((-877) $) 11)) (-3514 (($) 17 T CONST)) (-3255 (((-141) $ $) 6)) (-3313 (($ $ |#1|) 26)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
+(((-1287 |#1|) (-1311) (-388)) (T -1287)) 
+((-3313 (*1 *1 *1 *2) (-12 (-4 *1 (-1287 *2)) (-4 *2 (-388)))) (-1936 (*1 *2) (-12 (-4 *1 (-1287 *3)) (-4 *3 (-388)) (-5 *2 (-160))))) 
+(-13 (-734 |t#1|) (-10 -8 (-15 -3313 ($ $ |t#1|)) (-15 -1936 ((-160))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-734 |#1|) . T) ((-1081 |#1|) . T) ((-1119) . T)) 
+((-2121 (((-658 (-1220 |#1|)) (-1191) (-1220 |#1|)) 78)) (-1327 (((-1171 (-1171 (-980 |#1|))) (-1191) (-1171 (-980 |#1|))) 57)) (-2534 (((-1 (-1171 (-1220 |#1|)) (-1171 (-1220 |#1|))) (-790) (-1220 |#1|) (-1171 (-1220 |#1|))) 68)) (-1450 (((-1 (-1171 (-980 |#1|)) (-1171 (-980 |#1|))) (-790)) 59)) (-2939 (((-1 (-1187 (-980 |#1|)) (-980 |#1|)) (-1191)) 27)) (-4535 (((-1 (-1171 (-980 |#1|)) (-1171 (-980 |#1|))) (-790)) 58))) 
+(((-1288 |#1|) (-10 -7 (-15 -1450 ((-1 (-1171 (-980 |#1|)) (-1171 (-980 |#1|))) (-790))) (-15 -4535 ((-1 (-1171 (-980 |#1|)) (-1171 (-980 |#1|))) (-790))) (-15 -1327 ((-1171 (-1171 (-980 |#1|))) (-1191) (-1171 (-980 |#1|)))) (-15 -2939 ((-1 (-1187 (-980 |#1|)) (-980 |#1|)) (-1191))) (-15 -2121 ((-658 (-1220 |#1|)) (-1191) (-1220 |#1|))) (-15 -2534 ((-1 (-1171 (-1220 |#1|)) (-1171 (-1220 |#1|))) (-790) (-1220 |#1|) (-1171 (-1220 |#1|))))) (-388)) (T -1288)) 
+((-2534 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-790)) (-4 *6 (-388)) (-5 *4 (-1220 *6)) (-5 *2 (-1 (-1171 *4) (-1171 *4))) (-5 *1 (-1288 *6)) (-5 *5 (-1171 *4)))) (-2121 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-4 *5 (-388)) (-5 *2 (-658 (-1220 *5))) (-5 *1 (-1288 *5)) (-5 *4 (-1220 *5)))) (-2939 (*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-1187 (-980 *4)) (-980 *4))) (-5 *1 (-1288 *4)) (-4 *4 (-388)))) (-1327 (*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-4 *5 (-388)) (-5 *2 (-1171 (-1171 (-980 *5)))) (-5 *1 (-1288 *5)) (-5 *4 (-1171 (-980 *5))))) (-4535 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-1171 (-980 *4)) (-1171 (-980 *4)))) (-5 *1 (-1288 *4)) (-4 *4 (-388)))) (-1450 (*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-1171 (-980 *4)) (-1171 (-980 *4)))) (-5 *1 (-1288 *4)) (-4 *4 (-388))))) 
+(-10 -7 (-15 -1450 ((-1 (-1171 (-980 |#1|)) (-1171 (-980 |#1|))) (-790))) (-15 -4535 ((-1 (-1171 (-980 |#1|)) (-1171 (-980 |#1|))) (-790))) (-15 -1327 ((-1171 (-1171 (-980 |#1|))) (-1191) (-1171 (-980 |#1|)))) (-15 -2939 ((-1 (-1187 (-980 |#1|)) (-980 |#1|)) (-1191))) (-15 -2121 ((-658 (-1220 |#1|)) (-1191) (-1220 |#1|))) (-15 -2534 ((-1 (-1171 (-1220 |#1|)) (-1171 (-1220 |#1|))) (-790) (-1220 |#1|) (-1171 (-1220 |#1|))))) 
+((-2583 (((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) |#2|) 74)) (-4023 (((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|)))) 73))) 
+(((-1289 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4023 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))))) (-15 -2583 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) |#2|))) (-373) (-1255 |#1|) (-1255 |#2|) (-435 |#2| |#3|)) (T -1289)) 
+((-2583 (*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-1289 *4 *3 *5 *6)) (-4 *6 (-435 *3 *5)))) (-4023 (*1 *2) (-12 (-4 *3 (-373)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -2195 (-706 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-706 *4)))) (-5 *1 (-1289 *3 *4 *5 *6)) (-4 *6 (-435 *4 *5))))) 
+(-10 -7 (-15 -4023 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))))) (-15 -2583 ((-2 (|:| -2195 (-706 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-706 |#2|))) |#2|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 41)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) NIL)) (-3558 (((-141) $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1683 (((-877) $) 62) (($ (-592)) NIL) ((|#4| $) 52) (($ |#4|) 47) (($ |#1|) NIL (|has| |#1| (-194)))) (-4010 (((-790)) NIL)) (-3583 (((-1285) (-790)) 16)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 26 T CONST)) (-4257 (($) 65 T CONST)) (-3255 (((-141) $ $) 67)) (-3313 (((-3 $ "failed") $ $) NIL (|has| |#1| (-388)))) (-3306 (($ $) 69) (($ $ $) NIL)) (-3300 (($ $ $) 45)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 71) (($ |#1| $) NIL (|has| |#1| (-194))) (($ $ |#1|) NIL (|has| |#1| (-194))))) 
+(((-1290 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-13 (-1075) (-10 -8 (IF (|has| |#1| (-194)) (-6 (-43 |#1|)) |noBranch|) (-15 -1683 (|#4| $)) (IF (|has| |#1| (-388)) (-15 -3313 ((-3 $ "failed") $ $)) |noBranch|) (-15 -1683 ($ |#4|)) (-15 -3583 ((-1285) (-790))))) (-1075) (-869) (-815) (-977 |#1| |#3| |#2|) (-658 |#2|) (-658 (-790)) (-790)) (T -1290)) 
+((-1683 (*1 *2 *1) (-12 (-4 *2 (-977 *3 *5 *4)) (-5 *1 (-1290 *3 *4 *5 *2 *6 *7 *8)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-815)) (-14 *6 (-658 *4)) (-14 *7 (-658 (-790))) (-14 *8 (-790)))) (-3313 (*1 *1 *1 *1) (|partial| -12 (-4 *2 (-388)) (-4 *2 (-1075)) (-4 *3 (-869)) (-4 *4 (-815)) (-14 *6 (-658 *3)) (-5 *1 (-1290 *2 *3 *4 *5 *6 *7 *8)) (-4 *5 (-977 *2 *4 *3)) (-14 *7 (-658 (-790))) (-14 *8 (-790)))) (-1683 (*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-815)) (-14 *6 (-658 *4)) (-5 *1 (-1290 *3 *4 *5 *2 *6 *7 *8)) (-4 *2 (-977 *3 *5 *4)) (-14 *7 (-658 (-790))) (-14 *8 (-790)))) (-3583 (*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-1075)) (-4 *5 (-869)) (-4 *6 (-815)) (-14 *8 (-658 *5)) (-5 *2 (-1285)) (-5 *1 (-1290 *4 *5 *6 *7 *8 *9 *10)) (-4 *7 (-977 *4 *6 *5)) (-14 *9 (-658 *3)) (-14 *10 *3)))) 
+(-13 (-1075) (-10 -8 (IF (|has| |#1| (-194)) (-6 (-43 |#1|)) |noBranch|) (-15 -1683 (|#4| $)) (IF (|has| |#1| (-388)) (-15 -3313 ((-3 $ "failed") $ $)) |noBranch|) (-15 -1683 ($ |#4|)) (-15 -3583 ((-1285) (-790))))) 
+((-1641 (((-141) $ $) NIL)) (-2660 (((-658 (-2 (|:| -3511 $) (|:| -1774 (-658 |#4|)))) (-658 |#4|)) NIL)) (-2248 (((-658 $) (-658 |#4|)) 87)) (-4085 (((-658 |#3|) $) NIL)) (-4325 (((-141) $) NIL)) (-2988 (((-141) $) NIL (|has| |#1| (-582)))) (-4135 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-2244 ((|#4| |#4| $) NIL)) (-3960 (((-2 (|:| |under| $) (|:| -2039 $) (|:| |upper| $)) $ |#3|) NIL)) (-2126 (((-141) $ (-790)) NIL)) (-3113 (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625))) (((-3 |#4| "failed") $ |#3|) NIL)) (-3001 (($) NIL T CONST)) (-3239 (((-141) $) NIL (|has| |#1| (-582)))) (-3478 (((-141) $ $) NIL (|has| |#1| (-582)))) (-2398 (((-141) $ $) NIL (|has| |#1| (-582)))) (-1529 (((-141) $) NIL (|has| |#1| (-582)))) (-1903 (((-658 |#4|) (-658 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) 27)) (-4521 (((-658 |#4|) (-658 |#4|) $) 24 (|has| |#1| (-582)))) (-3718 (((-658 |#4|) (-658 |#4|) $) NIL (|has| |#1| (-582)))) (-4368 (((-3 $ "failed") (-658 |#4|)) NIL)) (-2400 (($ (-658 |#4|)) NIL)) (-1366 (((-3 $ "failed") $) 69)) (-2226 ((|#4| |#4| $) 74)) (-1360 (($ $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-4459 (($ |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (($ (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-3027 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-582)))) (-2172 (((-141) |#4| $ (-1 (-141) |#4| |#4|)) NIL)) (-3092 ((|#4| |#4| $) NIL)) (-3657 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4625))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4625))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-1643 (((-2 (|:| -3511 (-658 |#4|)) (|:| -1774 (-658 |#4|))) $) NIL)) (-4004 (((-658 |#4|) $) NIL (|has| $ (-6 -4625)))) (-2479 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-3259 ((|#3| $) 75)) (-4345 (((-141) $ (-790)) NIL)) (-4467 (((-658 |#4|) $) 28 (|has| $ (-6 -4625)))) (-3133 (((-141) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119))))) (-2510 (((-3 $ "failed") (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|)) 31) (((-3 $ "failed") (-658 |#4|)) 34)) (-3987 (($ (-1 |#4| |#4|) $) NIL (|has| $ (-6 -4626)))) (-2731 (($ (-1 |#4| |#4|) $) NIL)) (-2290 (((-658 |#3|) $) NIL)) (-2645 (((-141) |#3| $) NIL)) (-2554 (((-141) $ (-790)) NIL)) (-2685 (((-1173) $) NIL)) (-4255 (((-3 |#4| "failed") $) NIL)) (-1712 (((-658 |#4|) $) 49)) (-2346 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1751 ((|#4| |#4| $) 73)) (-3085 (((-141) $ $) 84)) (-3480 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-582)))) (-4442 (((-141) |#4| $) NIL) (((-141) $) NIL)) (-1803 ((|#4| |#4| $) NIL)) (-2951 (((-1137) $) NIL)) (-1918 (((-3 |#4| "failed") $) 68)) (-4050 (((-3 |#4| "failed") (-1 (-141) |#4|) $) NIL)) (-2778 (((-3 $ "failed") $ |#4|) NIL)) (-2807 (($ $ |#4|) NIL)) (-3002 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-2806 (($ $ (-658 |#4|) (-658 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-310 |#4|)) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119)))) (($ $ (-658 (-310 |#4|))) NIL (-12 (|has| |#4| (-325 |#4|)) (|has| |#4| (-1119))))) (-1724 (((-141) $ $) NIL)) (-2943 (((-141) $) 66)) (-2890 (($) 41)) (-4525 (((-790) $) NIL)) (-3452 (((-790) |#4| $) NIL (-12 (|has| $ (-6 -4625)) (|has| |#4| (-1119)))) (((-790) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-4599 (($ $) NIL)) (-1778 (((-565) $) NIL (|has| |#4| (-633 (-565))))) (-4466 (($ (-658 |#4|)) NIL)) (-2613 (($ $ |#3|) NIL)) (-4152 (($ $ |#3|) NIL)) (-2965 (($ $) NIL)) (-2507 (($ $ |#3|) NIL)) (-1683 (((-877) $) NIL) (((-658 |#4|) $) 56)) (-1857 (((-790) $) NIL (|has| |#3| (-394)))) (-4261 (((-3 $ "failed") (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|)) 39) (((-3 $ "failed") (-658 |#4|)) 40)) (-1762 (((-658 $) (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|)) 64) (((-658 $) (-658 |#4|)) 65)) (-1387 (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4| |#4|)) 23) (((-3 (-2 (|:| |bas| $) (|:| -3349 (-658 |#4|))) "failed") (-658 |#4|) (-1 (-141) |#4|) (-1 (-141) |#4| |#4|)) NIL)) (-4408 (((-141) $ (-1 (-141) |#4| (-658 |#4|))) NIL)) (-3369 (((-141) (-1 (-141) |#4|) $) NIL (|has| $ (-6 -4625)))) (-1596 (((-658 |#3|) $) NIL)) (-3069 (((-141) |#3| $) NIL)) (-3255 (((-141) $ $) NIL)) (-1699 (((-790) $) NIL (|has| $ (-6 -4625))))) 
+(((-1291 |#1| |#2| |#3| |#4|) (-13 (-1219 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2510 ((-3 $ "failed") (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2510 ((-3 $ "failed") (-658 |#4|))) (-15 -4261 ((-3 $ "failed") (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -4261 ((-3 $ "failed") (-658 |#4|))) (-15 -1762 ((-658 $) (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -1762 ((-658 $) (-658 |#4|))))) (-582) (-815) (-869) (-1089 |#1| |#2| |#3|)) (T -1291)) 
+((-2510 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-658 *8)) (-5 *3 (-1 (-141) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1291 *5 *6 *7 *8)))) (-2510 (*1 *1 *2) (|partial| -12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1291 *3 *4 *5 *6)))) (-4261 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-658 *8)) (-5 *3 (-1 (-141) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1291 *5 *6 *7 *8)))) (-4261 (*1 *1 *2) (|partial| -12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1291 *3 *4 *5 *6)))) (-1762 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *9)) (-5 *4 (-1 (-141) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1089 *6 *7 *8)) (-4 *6 (-582)) (-4 *7 (-815)) (-4 *8 (-869)) (-5 *2 (-658 (-1291 *6 *7 *8 *9))) (-5 *1 (-1291 *6 *7 *8 *9)))) (-1762 (*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 (-1291 *4 *5 *6 *7))) (-5 *1 (-1291 *4 *5 *6 *7))))) 
+(-13 (-1219 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2510 ((-3 $ "failed") (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2510 ((-3 $ "failed") (-658 |#4|))) (-15 -4261 ((-3 $ "failed") (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -4261 ((-3 $ "failed") (-658 |#4|))) (-15 -1762 ((-658 $) (-658 |#4|) (-1 (-141) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -1762 ((-658 $) (-658 |#4|))))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2350 (((-3 $ "failed") $ $) 18)) (-3001 (($) 16 T CONST)) (-3371 (((-3 $ "failed") $) 33)) (-3558 (((-141) $) 30)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#1|) 37)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ |#1|) 39) (($ |#1| $) 38))) 
+(((-1292 |#1|) (-1311) (-1075)) (T -1292)) 
+((-1683 (*1 *1 *2) (-12 (-4 *1 (-1292 *2)) (-4 *2 (-1075))))) 
+(-13 (-1075) (-140 |t#1| |t#1|) (-10 -8 (-15 -1683 ($ |t#1|)) (IF (|has| |t#1| (-194)) (-6 (-43 |t#1|)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-194)) ((-125) . T) ((-140 |#1| |#1|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-734 |#1|) |has| |#1| (-194)) ((-743) . T) ((-1081 |#1|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2692 (((-658 |#1|) $) 45)) (-1394 (($ $ (-790)) 39)) (-2350 (((-3 $ "failed") $ $) NIL)) (-2549 (($ $ (-790)) 17 (|has| |#2| (-194))) (($ $ $) 18 (|has| |#2| (-194)))) (-3001 (($) NIL T CONST)) (-3305 (($ $ $) 61) (($ $ (-841 |#1|)) 48) (($ $ |#1|) 52)) (-4368 (((-3 (-841 |#1|) "failed") $) NIL)) (-2400 (((-841 |#1|) $) NIL)) (-4593 (($ $) 32)) (-3371 (((-3 $ "failed") $) NIL)) (-3053 (((-141) $) NIL)) (-1984 (($ $) NIL)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-1493 (($ (-841 |#1|) |#2|) 31)) (-4103 (($ $) 33)) (-3033 (((-2 (|:| |k| (-841 |#1|)) (|:| |c| |#2|)) $) 11)) (-3281 (((-841 |#1|) $) NIL)) (-3494 (((-841 |#1|) $) 34)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-2141 (($ $ $) 60) (($ $ (-841 |#1|)) 50) (($ $ |#1|) 54)) (-3725 (((-658 (-2 (|:| |k| (-841 |#1|)) (|:| |c| |#2|))) $) NIL)) (-2992 (((-2 (|:| |k| (-841 |#1|)) (|:| |c| |#2|)) $) NIL)) (-4573 (((-841 |#1|) $) 28)) (-4579 ((|#2| $) 30)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-4525 (((-790) $) 36)) (-2752 (((-141) $) 40)) (-4249 ((|#2| $) NIL)) (-1683 (((-877) $) NIL) (($ (-841 |#1|)) 24) (($ |#1|) 25) (($ |#2|) NIL) (($ (-592)) NIL)) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-841 |#1|)) NIL)) (-1487 ((|#2| $ $) 63) ((|#2| $ (-841 |#1|)) NIL)) (-4010 (((-790)) NIL)) (-1424 (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (-3514 (($) 12 T CONST)) (-4257 (($) 14 T CONST)) (-3255 (((-141) $ $) 38)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 21)) (** (($ $ (-790)) NIL) (($ $ (-944)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ |#2| $) 20) (($ $ |#2|) 59) (($ |#2| (-841 |#1|)) NIL) (($ |#1| $) 27) (($ $ $) NIL))) 
+(((-1293 |#1| |#2|) (-13 (-408 |#2| (-841 |#1|)) (-1299 |#1| |#2|)) (-869) (-1075)) (T -1293)) 
+NIL 
+(-13 (-408 |#2| (-841 |#1|)) (-1299 |#1| |#2|)) 
+((-4546 ((|#3| |#3| (-790)) 23)) (-1430 ((|#3| |#3| (-790)) 28)) (-3230 ((|#3| |#3| |#3| (-790)) 29))) 
+(((-1294 |#1| |#2| |#3|) (-10 -7 (-15 -1430 (|#3| |#3| (-790))) (-15 -4546 (|#3| |#3| (-790))) (-15 -3230 (|#3| |#3| |#3| (-790)))) (-13 (-1075) (-734 (-433 (-592)))) (-869) (-1299 |#2| |#1|)) (T -1294)) 
+((-3230 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-1075) (-734 (-433 (-592))))) (-4 *5 (-869)) (-5 *1 (-1294 *4 *5 *2)) (-4 *2 (-1299 *5 *4)))) (-4546 (*1 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-1075) (-734 (-433 (-592))))) (-4 *5 (-869)) (-5 *1 (-1294 *4 *5 *2)) (-4 *2 (-1299 *5 *4)))) (-1430 (*1 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-1075) (-734 (-433 (-592))))) (-4 *5 (-869)) (-5 *1 (-1294 *4 *5 *2)) (-4 *2 (-1299 *5 *4))))) 
+(-10 -7 (-15 -1430 (|#3| |#3| (-790))) (-15 -4546 (|#3| |#3| (-790))) (-15 -3230 (|#3| |#3| |#3| (-790)))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2692 (((-658 |#1|) $) 39)) (-2350 (((-3 $ "failed") $ $) 18)) (-2549 (($ $ $) 42 (|has| |#2| (-194))) (($ $ (-790)) 41 (|has| |#2| (-194)))) (-3001 (($) 16 T CONST)) (-3305 (($ $ |#1|) 53) (($ $ (-841 |#1|)) 52) (($ $ $) 51)) (-4368 (((-3 (-841 |#1|) "failed") $) 63)) (-2400 (((-841 |#1|) $) 62)) (-3371 (((-3 $ "failed") $) 33)) (-3053 (((-141) $) 44)) (-1984 (($ $) 43)) (-3558 (((-141) $) 30)) (-2027 (((-141) $) 49)) (-1493 (($ (-841 |#1|) |#2|) 50)) (-4103 (($ $) 48)) (-3033 (((-2 (|:| |k| (-841 |#1|)) (|:| |c| |#2|)) $) 59)) (-3281 (((-841 |#1|) $) 60)) (-2731 (($ (-1 |#2| |#2|) $) 40)) (-2141 (($ $ |#1|) 56) (($ $ (-841 |#1|)) 55) (($ $ $) 54)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-2752 (((-141) $) 46)) (-4249 ((|#2| $) 45)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#2|) 67) (($ (-841 |#1|)) 64) (($ |#1|) 47)) (-1487 ((|#2| $ (-841 |#1|)) 58) ((|#2| $ $) 57)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ |#2| $) 66) (($ $ |#2|) 65) (($ |#1| $) 61))) 
+(((-1295 |#1| |#2|) (-1311) (-869) (-1075)) (T -1295)) 
+((* (*1 *1 *1 *2) (-12 (-4 *1 (-1295 *3 *2)) (-4 *3 (-869)) (-4 *2 (-1075)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) (-3281 (*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-841 *3)))) (-3033 (*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-2 (|:| |k| (-841 *3)) (|:| |c| *4))))) (-1487 (*1 *2 *1 *3) (-12 (-5 *3 (-841 *4)) (-4 *1 (-1295 *4 *2)) (-4 *4 (-869)) (-4 *2 (-1075)))) (-1487 (*1 *2 *1 *1) (-12 (-4 *1 (-1295 *3 *2)) (-4 *3 (-869)) (-4 *2 (-1075)))) (-2141 (*1 *1 *1 *2) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) (-2141 (*1 *1 *1 *2) (-12 (-5 *2 (-841 *3)) (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)))) (-2141 (*1 *1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) (-3305 (*1 *1 *1 *2) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) (-3305 (*1 *1 *1 *2) (-12 (-5 *2 (-841 *3)) (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)))) (-3305 (*1 *1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) (-1493 (*1 *1 *2 *3) (-12 (-5 *2 (-841 *4)) (-4 *4 (-869)) (-4 *1 (-1295 *4 *3)) (-4 *3 (-1075)))) (-2027 (*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-141)))) (-4103 (*1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) (-1683 (*1 *1 *2) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) (-2752 (*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-141)))) (-4249 (*1 *2 *1) (-12 (-4 *1 (-1295 *3 *2)) (-4 *3 (-869)) (-4 *2 (-1075)))) (-3053 (*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-141)))) (-1984 (*1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) (-2549 (*1 *1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)) (-4 *3 (-194)))) (-2549 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-4 *4 (-194)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)))) (-2692 (*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-658 *3))))) 
+(-13 (-1075) (-1292 |t#2|) (-1065 (-841 |t#1|)) (-10 -8 (-15 * ($ |t#1| $)) (-15 * ($ $ |t#2|)) (-15 -3281 ((-841 |t#1|) $)) (-15 -3033 ((-2 (|:| |k| (-841 |t#1|)) (|:| |c| |t#2|)) $)) (-15 -1487 (|t#2| $ (-841 |t#1|))) (-15 -1487 (|t#2| $ $)) (-15 -2141 ($ $ |t#1|)) (-15 -2141 ($ $ (-841 |t#1|))) (-15 -2141 ($ $ $)) (-15 -3305 ($ $ |t#1|)) (-15 -3305 ($ $ (-841 |t#1|))) (-15 -3305 ($ $ $)) (-15 -1493 ($ (-841 |t#1|) |t#2|)) (-15 -2027 ((-141) $)) (-15 -4103 ($ $)) (-15 -1683 ($ |t#1|)) (-15 -2752 ((-141) $)) (-15 -4249 (|t#2| $)) (-15 -3053 ((-141) $)) (-15 -1984 ($ $)) (IF (|has| |t#2| (-194)) (PROGN (-15 -2549 ($ $ $)) (-15 -2549 ($ $ (-790)))) |noBranch|) (-15 -2731 ($ (-1 |t#2| |t#2|) $)) (-15 -2692 ((-658 |t#1|) $)) (IF (|has| |t#2| (-6 -4618)) (-6 -4618) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#2|) |has| |#2| (-194)) ((-125) . T) ((-140 |#2| |#2|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#2|) . T) ((-661 $) . T) ((-734 |#2|) |has| |#2| (-194)) ((-743) . T) ((-1065 (-841 |#1|)) . T) ((-1081 |#2|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1292 |#2|) . T)) 
+((-1917 (((-141) $) 13)) (-3069 (((-141) $) 12)) (-3417 (($ $) 17) (($ $ (-790)) 18))) 
+(((-1296 |#1| |#2|) (-10 -8 (-15 -3417 (|#1| |#1| (-790))) (-15 -3417 (|#1| |#1|)) (-15 -1917 ((-141) |#1|)) (-15 -3069 ((-141) |#1|))) (-1297 |#2|) (-388)) (T -1296)) 
+NIL 
+(-10 -8 (-15 -3417 (|#1| |#1| (-790))) (-15 -3417 (|#1| |#1|)) (-15 -1917 ((-141) |#1|)) (-15 -3069 ((-141) |#1|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-3620 (((-2 (|:| -4509 $) (|:| -4612 $) (|:| |associate| $)) $) 40)) (-1555 (($ $) 39)) (-1313 (((-141) $) 37)) (-1917 (((-141) $) 90)) (-4424 (((-790)) 86)) (-2350 (((-3 $ "failed") $ $) 18)) (-3743 (($ $) 71)) (-3164 (((-444 $) $) 70)) (-3652 (((-141) $ $) 57)) (-3001 (($) 16 T CONST)) (-4368 (((-3 |#1| "failed") $) 97)) (-2400 ((|#1| $) 96)) (-1586 (($ $ $) 53)) (-3371 (((-3 $ "failed") $) 33)) (-1599 (($ $ $) 54)) (-1491 (((-2 (|:| -1487 (-658 $)) (|:| -2934 $)) (-658 $)) 49)) (-1525 (($ $ (-790)) 83 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394)))) (($ $) 82 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-2802 (((-141) $) 69)) (-4346 (((-855 (-944)) $) 80 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-3558 (((-141) $) 30)) (-2310 (((-3 (-658 $) "failed") (-658 $) $) 50)) (-2750 (($ $ $) 45) (($ (-658 $)) 44)) (-2685 (((-1173) $) 9)) (-4552 (($ $) 68)) (-2142 (((-141) $) 89)) (-2951 (((-1137) $) 10)) (-2536 (((-1187 $) (-1187 $) (-1187 $)) 43)) (-3548 (($ $ $) 47) (($ (-658 $)) 46)) (-4500 (((-444 $) $) 72)) (-3470 (((-855 (-944))) 87)) (-4159 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2934 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3616 (((-3 $ "failed") $ $) 41)) (-4539 (((-3 (-658 $) "failed") (-658 $) $) 48)) (-2769 (((-790) $) 56)) (-4570 (((-2 (|:| -2230 $) (|:| -3027 $)) $ $) 55)) (-2177 (((-3 (-790) "failed") $ $) 81 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-1936 (((-160)) 95)) (-4525 (((-855 (-944)) $) 88)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ $) 42) (($ (-433 (-592))) 63) (($ |#1|) 98)) (-1517 (((-3 $ "failed") $) 79 (-3836 (|has| |#1| (-169)) (|has| |#1| (-394))))) (-4010 (((-790)) 28)) (-2537 (((-141) $ $) 38)) (-3069 (((-141) $) 91)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32) (($ $ (-592)) 67)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3417 (($ $) 85 (|has| |#1| (-394))) (($ $ (-790)) 84 (|has| |#1| (-394)))) (-3255 (((-141) $ $) 6)) (-3313 (($ $ $) 62) (($ $ |#1|) 94)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31) (($ $ (-592)) 66)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ $ (-433 (-592))) 65) (($ (-433 (-592)) $) 64) (($ $ |#1|) 93) (($ |#1| $) 92))) 
+(((-1297 |#1|) (-1311) (-388)) (T -1297)) 
+((-3069 (*1 *2 *1) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-141)))) (-1917 (*1 *2 *1) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-141)))) (-2142 (*1 *2 *1) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-141)))) (-4525 (*1 *2 *1) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-855 (-944))))) (-3470 (*1 *2) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-855 (-944))))) (-4424 (*1 *2) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-790)))) (-3417 (*1 *1 *1) (-12 (-4 *1 (-1297 *2)) (-4 *2 (-388)) (-4 *2 (-394)))) (-3417 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-4 *3 (-394))))) 
+(-13 (-388) (-1065 |t#1|) (-1287 |t#1|) (-10 -8 (IF (|has| |t#1| (-171)) (-6 (-171)) |noBranch|) (IF (|has| |t#1| (-169)) (-6 (-428)) |noBranch|) (-15 -3069 ((-141) $)) (-15 -1917 ((-141) $)) (-15 -2142 ((-141) $)) (-15 -4525 ((-855 (-944)) $)) (-15 -3470 ((-855 (-944)))) (-15 -4424 ((-790))) (IF (|has| |t#1| (-394)) (PROGN (-6 (-428)) (-15 -3417 ($ $)) (-15 -3417 ($ $ (-790)))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-433 (-592))) . T) ((-43 $) . T) ((-125) . T) ((-140 (-433 (-592)) (-433 (-592))) . T) ((-140 |#1| |#1|) . T) ((-140 $ $) . T) ((-158) . T) ((-169) -3836 (|has| |#1| (-394)) (|has| |#1| (-169))) ((-171) |has| |#1| (-171)) ((-632 (-877)) . T) ((-194) . T) ((-260) . T) ((-307) . T) ((-323) . T) ((-388) . T) ((-428) -3836 (|has| |#1| (-394)) (|has| |#1| (-169))) ((-477) . T) ((-582) . T) ((-661 (-433 (-592))) . T) ((-661 |#1|) . T) ((-661 $) . T) ((-678) . T) ((-734 (-433 (-592))) . T) ((-734 |#1|) . T) ((-734 $) . T) ((-743) . T) ((-943) . T) ((-1065 |#1|) . T) ((-1081 (-433 (-592))) . T) ((-1081 |#1|) . T) ((-1081 $) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1235) . T) ((-1287 |#1|) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2692 (((-658 |#1|) $) 84)) (-1394 (($ $ (-790)) 87)) (-2350 (((-3 $ "failed") $ $) NIL)) (-2549 (($ $ $) NIL (|has| |#2| (-194))) (($ $ (-790)) NIL (|has| |#2| (-194)))) (-3001 (($) NIL T CONST)) (-3305 (($ $ |#1|) NIL) (($ $ (-841 |#1|)) NIL) (($ $ $) NIL)) (-4368 (((-3 (-841 |#1|) "failed") $) NIL) (((-3 (-915 |#1|) "failed") $) NIL)) (-2400 (((-841 |#1|) $) NIL) (((-915 |#1|) $) NIL)) (-4593 (($ $) 86)) (-3371 (((-3 $ "failed") $) NIL)) (-3053 (((-141) $) 75)) (-1984 (($ $) 79)) (-3679 (($ $ $ (-790)) 88)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-1493 (($ (-841 |#1|) |#2|) NIL) (($ (-915 |#1|) |#2|) 25)) (-4103 (($ $) 101)) (-3033 (((-2 (|:| |k| (-841 |#1|)) (|:| |c| |#2|)) $) NIL)) (-3281 (((-841 |#1|) $) NIL)) (-3494 (((-841 |#1|) $) NIL)) (-2731 (($ (-1 |#2| |#2|) $) NIL)) (-2141 (($ $ |#1|) NIL) (($ $ (-841 |#1|)) NIL) (($ $ $) NIL)) (-4546 (($ $ (-790)) 95 (|has| |#2| (-734 (-433 (-592)))))) (-3725 (((-658 (-2 (|:| |k| (-915 |#1|)) (|:| |c| |#2|))) $) NIL)) (-2992 (((-2 (|:| |k| (-915 |#1|)) (|:| |c| |#2|)) $) NIL)) (-4573 (((-915 |#1|) $) 69)) (-4579 ((|#2| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-1430 (($ $ (-790)) 92 (|has| |#2| (-734 (-433 (-592)))))) (-4525 (((-790) $) 85)) (-2752 (((-141) $) 70)) (-4249 ((|#2| $) 74)) (-1683 (((-877) $) 56) (($ (-592)) NIL) (($ |#2|) 50) (($ (-841 |#1|)) NIL) (($ |#1|) 58) (($ (-915 |#1|)) NIL) (($ (-681 |#1| |#2|)) 42) (((-1293 |#1| |#2|) $) 63) (((-1302 |#1| |#2|) $) 68)) (-1647 (((-658 |#2|) $) NIL)) (-1937 ((|#2| $ (-915 |#1|)) NIL)) (-1487 ((|#2| $ (-841 |#1|)) NIL) ((|#2| $ $) NIL)) (-4010 (((-790)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 21 T CONST)) (-4257 (($) 24 T CONST)) (-1651 (((-3 (-681 |#1| |#2|) "failed") $) 100)) (-3255 (((-141) $ $) 64)) (-3306 (($ $) 94) (($ $ $) 93)) (-3300 (($ $ $) 20)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 43) (($ |#2| $) 19) (($ $ |#2|) NIL) (($ |#1| $) NIL) (($ |#2| (-915 |#1|)) NIL))) 
+(((-1298 |#1| |#2|) (-13 (-1299 |#1| |#2|) (-408 |#2| (-915 |#1|)) (-10 -8 (-15 -1683 ($ (-681 |#1| |#2|))) (-15 -1683 ((-1293 |#1| |#2|) $)) (-15 -1683 ((-1302 |#1| |#2|) $)) (-15 -1651 ((-3 (-681 |#1| |#2|) "failed") $)) (-15 -3679 ($ $ $ (-790))) (IF (|has| |#2| (-734 (-433 (-592)))) (PROGN (-15 -1430 ($ $ (-790))) (-15 -4546 ($ $ (-790)))) |noBranch|))) (-869) (-194)) (T -1298)) 
+((-1683 (*1 *1 *2) (-12 (-5 *2 (-681 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *1 (-1298 *3 *4)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1293 *3 *4)) (-5 *1 (-1298 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) (-1683 (*1 *2 *1) (-12 (-5 *2 (-1302 *3 *4)) (-5 *1 (-1298 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) (-1651 (*1 *2 *1) (|partial| -12 (-5 *2 (-681 *3 *4)) (-5 *1 (-1298 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) (-3679 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1298 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) (-1430 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1298 *3 *4)) (-4 *4 (-734 (-433 (-592)))) (-4 *3 (-869)) (-4 *4 (-194)))) (-4546 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1298 *3 *4)) (-4 *4 (-734 (-433 (-592)))) (-4 *3 (-869)) (-4 *4 (-194))))) 
+(-13 (-1299 |#1| |#2|) (-408 |#2| (-915 |#1|)) (-10 -8 (-15 -1683 ($ (-681 |#1| |#2|))) (-15 -1683 ((-1293 |#1| |#2|) $)) (-15 -1683 ((-1302 |#1| |#2|) $)) (-15 -1651 ((-3 (-681 |#1| |#2|) "failed") $)) (-15 -3679 ($ $ $ (-790))) (IF (|has| |#2| (-734 (-433 (-592)))) (PROGN (-15 -1430 ($ $ (-790))) (-15 -4546 ($ $ (-790)))) |noBranch|))) 
+((-1641 (((-141) $ $) 7)) (-2272 (((-141) $) 15)) (-2692 (((-658 |#1|) $) 39)) (-1394 (($ $ (-790)) 68)) (-2350 (((-3 $ "failed") $ $) 18)) (-2549 (($ $ $) 42 (|has| |#2| (-194))) (($ $ (-790)) 41 (|has| |#2| (-194)))) (-3001 (($) 16 T CONST)) (-3305 (($ $ |#1|) 53) (($ $ (-841 |#1|)) 52) (($ $ $) 51)) (-4368 (((-3 (-841 |#1|) "failed") $) 63)) (-2400 (((-841 |#1|) $) 62)) (-3371 (((-3 $ "failed") $) 33)) (-3053 (((-141) $) 44)) (-1984 (($ $) 43)) (-3558 (((-141) $) 30)) (-2027 (((-141) $) 49)) (-1493 (($ (-841 |#1|) |#2|) 50)) (-4103 (($ $) 48)) (-3033 (((-2 (|:| |k| (-841 |#1|)) (|:| |c| |#2|)) $) 59)) (-3281 (((-841 |#1|) $) 60)) (-3494 (((-841 |#1|) $) 70)) (-2731 (($ (-1 |#2| |#2|) $) 40)) (-2141 (($ $ |#1|) 56) (($ $ (-841 |#1|)) 55) (($ $ $) 54)) (-2685 (((-1173) $) 9)) (-2951 (((-1137) $) 10)) (-4525 (((-790) $) 69)) (-2752 (((-141) $) 46)) (-4249 ((|#2| $) 45)) (-1683 (((-877) $) 11) (($ (-592)) 27) (($ |#2|) 67) (($ (-841 |#1|)) 64) (($ |#1|) 47)) (-1487 ((|#2| $ (-841 |#1|)) 58) ((|#2| $ $) 57)) (-4010 (((-790)) 28)) (-1424 (($ $ (-944)) 25) (($ $ (-790)) 32)) (-3514 (($) 17 T CONST)) (-4257 (($) 29 T CONST)) (-3255 (((-141) $ $) 6)) (-3306 (($ $) 21) (($ $ $) 20)) (-3300 (($ $ $) 13)) (** (($ $ (-944)) 24) (($ $ (-790)) 31)) (* (($ (-944) $) 12) (($ (-790) $) 14) (($ (-592) $) 19) (($ $ $) 23) (($ |#2| $) 66) (($ $ |#2|) 65) (($ |#1| $) 61))) 
+(((-1299 |#1| |#2|) (-1311) (-869) (-1075)) (T -1299)) 
+((-3494 (*1 *2 *1) (-12 (-4 *1 (-1299 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-841 *3)))) (-4525 (*1 *2 *1) (-12 (-4 *1 (-1299 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-790)))) (-1394 (*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1299 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075))))) 
+(-13 (-1295 |t#1| |t#2|) (-10 -8 (-15 -3494 ((-841 |t#1|) $)) (-15 -4525 ((-790) $)) (-15 -1394 ($ $ (-790))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#2|) |has| |#2| (-194)) ((-125) . T) ((-140 |#2| |#2|) . T) ((-158) . T) ((-632 (-877)) . T) ((-661 |#2|) . T) ((-661 $) . T) ((-734 |#2|) |has| |#2| (-194)) ((-743) . T) ((-1065 (-841 |#1|)) . T) ((-1081 |#2|) . T) ((-1075) . T) ((-1082) . T) ((-1131) . T) ((-1119) . T) ((-1292 |#2|) . T) ((-1295 |#1| |#2|) . T)) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2692 (((-658 (-1191)) $) NIL)) (-4136 (($ (-1293 (-1191) |#1|)) NIL)) (-1394 (($ $ (-790)) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-2549 (($ $ $) NIL (|has| |#1| (-194))) (($ $ (-790)) NIL (|has| |#1| (-194)))) (-3001 (($) NIL T CONST)) (-3305 (($ $ (-1191)) NIL) (($ $ (-841 (-1191))) NIL) (($ $ $) NIL)) (-4368 (((-3 (-841 (-1191)) "failed") $) NIL)) (-2400 (((-841 (-1191)) $) NIL)) (-3371 (((-3 $ "failed") $) NIL)) (-3053 (((-141) $) NIL)) (-1984 (($ $) NIL)) (-3558 (((-141) $) NIL)) (-2027 (((-141) $) NIL)) (-1493 (($ (-841 (-1191)) |#1|) NIL)) (-4103 (($ $) NIL)) (-3033 (((-2 (|:| |k| (-841 (-1191))) (|:| |c| |#1|)) $) NIL)) (-3281 (((-841 (-1191)) $) NIL)) (-3494 (((-841 (-1191)) $) NIL)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-2141 (($ $ (-1191)) NIL) (($ $ (-841 (-1191))) NIL) (($ $ $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3098 (((-1293 (-1191) |#1|) $) NIL)) (-4525 (((-790) $) NIL)) (-2752 (((-141) $) NIL)) (-4249 ((|#1| $) NIL)) (-1683 (((-877) $) NIL) (($ (-592)) NIL) (($ |#1|) NIL) (($ (-841 (-1191))) NIL) (($ (-1191)) NIL)) (-1487 ((|#1| $ (-841 (-1191))) NIL) ((|#1| $ $) NIL)) (-4010 (((-790)) NIL)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) NIL T CONST)) (-4429 (((-658 (-2 (|:| |k| (-1191)) (|:| |c| $))) $) NIL)) (-4257 (($) NIL T CONST)) (-3255 (((-141) $ $) NIL)) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) NIL)) (** (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-1191) $) NIL))) 
+(((-1300 |#1|) (-13 (-1299 (-1191) |#1|) (-10 -8 (-15 -3098 ((-1293 (-1191) |#1|) $)) (-15 -4136 ($ (-1293 (-1191) |#1|))) (-15 -4429 ((-658 (-2 (|:| |k| (-1191)) (|:| |c| $))) $)))) (-1075)) (T -1300)) 
+((-3098 (*1 *2 *1) (-12 (-5 *2 (-1293 (-1191) *3)) (-5 *1 (-1300 *3)) (-4 *3 (-1075)))) (-4136 (*1 *1 *2) (-12 (-5 *2 (-1293 (-1191) *3)) (-4 *3 (-1075)) (-5 *1 (-1300 *3)))) (-4429 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |k| (-1191)) (|:| |c| (-1300 *3))))) (-5 *1 (-1300 *3)) (-4 *3 (-1075))))) 
+(-13 (-1299 (-1191) |#1|) (-10 -8 (-15 -3098 ((-1293 (-1191) |#1|) $)) (-15 -4136 ($ (-1293 (-1191) |#1|))) (-15 -4429 ((-658 (-2 (|:| |k| (-1191)) (|:| |c| $))) $)))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2350 (((-3 $ "failed") $ $) NIL)) (-3001 (($) NIL T CONST)) (-4368 (((-3 |#2| "failed") $) NIL)) (-2400 ((|#2| $) NIL)) (-4593 (($ $) NIL)) (-3371 (((-3 $ "failed") $) 34)) (-3053 (((-141) $) 29)) (-1984 (($ $) 30)) (-3558 (((-141) $) NIL)) (-4036 (((-790) $) NIL)) (-3108 (((-658 $) $) NIL)) (-2027 (((-141) $) NIL)) (-1493 (($ |#2| |#1|) NIL)) (-3281 ((|#2| $) 19)) (-3494 ((|#2| $) 16)) (-2731 (($ (-1 |#1| |#1|) $) NIL)) (-3725 (((-658 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) NIL)) (-2992 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) NIL)) (-4573 ((|#2| $) NIL)) (-4579 ((|#1| $) NIL)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-2752 (((-141) $) 27)) (-4249 ((|#1| $) 28)) (-1683 (((-877) $) 53) (($ (-592)) 38) (($ |#1|) 33) (($ |#2|) NIL)) (-1647 (((-658 |#1|) $) NIL)) (-1937 ((|#1| $ |#2|) NIL)) (-1487 ((|#1| $ |#2|) 24)) (-4010 (((-790)) 14)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 25 T CONST)) (-4257 (($) 11 T CONST)) (-3255 (((-141) $ $) 26)) (-3313 (($ $ |#1|) 55 (|has| |#1| (-388)))) (-3306 (($ $) NIL) (($ $ $) NIL)) (-3300 (($ $ $) 42)) (** (($ $ (-944)) NIL) (($ $ (-790)) 44)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) NIL) (($ $ $) 43) (($ |#1| $) 39) (($ $ |#1|) NIL) (($ |#1| |#2|) NIL)) (-1699 (((-790) $) 15))) 
+(((-1301 |#1| |#2|) (-13 (-1075) (-1292 |#1|) (-408 |#1| |#2|) (-10 -8 (-15 * ($ $ |#1|)) (-15 -1699 ((-790) $)) (-15 -1683 ($ |#2|)) (-15 -3494 (|#2| $)) (-15 -3281 (|#2| $)) (-15 -4593 ($ $)) (-15 -1487 (|#1| $ |#2|)) (-15 -2752 ((-141) $)) (-15 -4249 (|#1| $)) (-15 -3053 ((-141) $)) (-15 -1984 ($ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-388)) (-15 -3313 ($ $ |#1|)) |noBranch|) (IF (|has| |#1| (-6 -4618)) (-6 -4618) |noBranch|) (IF (|has| |#1| (-6 -4622)) (-6 -4622) |noBranch|) (IF (|has| |#1| (-6 -4623)) (-6 -4623) |noBranch|))) (-1075) (-865)) (T -1301)) 
+((* (*1 *1 *1 *2) (-12 (-5 *1 (-1301 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-865)))) (-4593 (*1 *1 *1) (-12 (-5 *1 (-1301 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-865)))) (-2731 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-1301 *3 *4)) (-4 *4 (-865)))) (-1683 (*1 *1 *2) (-12 (-5 *1 (-1301 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-865)))) (-1699 (*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1301 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-865)))) (-3494 (*1 *2 *1) (-12 (-4 *2 (-865)) (-5 *1 (-1301 *3 *2)) (-4 *3 (-1075)))) (-3281 (*1 *2 *1) (-12 (-4 *2 (-865)) (-5 *1 (-1301 *3 *2)) (-4 *3 (-1075)))) (-1487 (*1 *2 *1 *3) (-12 (-4 *2 (-1075)) (-5 *1 (-1301 *2 *3)) (-4 *3 (-865)))) (-2752 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1301 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-865)))) (-4249 (*1 *2 *1) (-12 (-4 *2 (-1075)) (-5 *1 (-1301 *2 *3)) (-4 *3 (-865)))) (-3053 (*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1301 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-865)))) (-1984 (*1 *1 *1) (-12 (-5 *1 (-1301 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-865)))) (-3313 (*1 *1 *1 *2) (-12 (-5 *1 (-1301 *2 *3)) (-4 *2 (-388)) (-4 *2 (-1075)) (-4 *3 (-865))))) 
+(-13 (-1075) (-1292 |#1|) (-408 |#1| |#2|) (-10 -8 (-15 * ($ $ |#1|)) (-15 -1699 ((-790) $)) (-15 -1683 ($ |#2|)) (-15 -3494 (|#2| $)) (-15 -3281 (|#2| $)) (-15 -4593 ($ $)) (-15 -1487 (|#1| $ |#2|)) (-15 -2752 ((-141) $)) (-15 -4249 (|#1| $)) (-15 -3053 ((-141) $)) (-15 -1984 ($ $)) (-15 -2731 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-388)) (-15 -3313 ($ $ |#1|)) |noBranch|) (IF (|has| |#1| (-6 -4618)) (-6 -4618) |noBranch|) (IF (|has| |#1| (-6 -4622)) (-6 -4622) |noBranch|) (IF (|has| |#1| (-6 -4623)) (-6 -4623) |noBranch|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) NIL)) (-2692 (((-658 |#1|) $) 119)) (-4136 (($ (-1293 |#1| |#2|)) 43)) (-1394 (($ $ (-790)) 31)) (-2350 (((-3 $ "failed") $ $) NIL)) (-2549 (($ $ $) 47 (|has| |#2| (-194))) (($ $ (-790)) 45 (|has| |#2| (-194)))) (-3001 (($) NIL T CONST)) (-3305 (($ $ |#1|) 101) (($ $ (-841 |#1|)) 102) (($ $ $) 25)) (-4368 (((-3 (-841 |#1|) "failed") $) NIL)) (-2400 (((-841 |#1|) $) NIL)) (-3371 (((-3 $ "failed") $) 109)) (-3053 (((-141) $) 104)) (-1984 (($ $) 105)) (-3558 (((-141) $) NIL)) (-2027 (((-141) $) NIL)) (-1493 (($ (-841 |#1|) |#2|) 19)) (-4103 (($ $) NIL)) (-3033 (((-2 (|:| |k| (-841 |#1|)) (|:| |c| |#2|)) $) NIL)) (-3281 (((-841 |#1|) $) 110)) (-3494 (((-841 |#1|) $) 113)) (-2731 (($ (-1 |#2| |#2|) $) 118)) (-2141 (($ $ |#1|) 99) (($ $ (-841 |#1|)) 100) (($ $ $) 55)) (-2685 (((-1173) $) NIL)) (-2951 (((-1137) $) NIL)) (-3098 (((-1293 |#1| |#2|) $) 83)) (-4525 (((-790) $) 116)) (-2752 (((-141) $) 69)) (-4249 ((|#2| $) 27)) (-1683 (((-877) $) 62) (($ (-592)) 76) (($ |#2|) 73) (($ (-841 |#1|)) 17) (($ |#1|) 72)) (-1487 ((|#2| $ (-841 |#1|)) 103) ((|#2| $ $) 26)) (-4010 (((-790)) 107)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 14 T CONST)) (-4429 (((-658 (-2 (|:| |k| |#1|) (|:| |c| $))) $) 52)) (-4257 (($) 28 T CONST)) (-3255 (((-141) $ $) 13)) (-3306 (($ $) 87) (($ $ $) 90)) (-3300 (($ $ $) 54)) (** (($ $ (-944)) NIL) (($ $ (-790)) 48)) (* (($ (-944) $) NIL) (($ (-790) $) 46) (($ (-592) $) 93) (($ $ $) 21) (($ |#2| $) 18) (($ $ |#2|) 20) (($ |#1| $) 81))) 
+(((-1302 |#1| |#2|) (-13 (-1299 |#1| |#2|) (-10 -8 (-15 -3098 ((-1293 |#1| |#2|) $)) (-15 -4136 ($ (-1293 |#1| |#2|))) (-15 -4429 ((-658 (-2 (|:| |k| |#1|) (|:| |c| $))) $)))) (-869) (-1075)) (T -1302)) 
+((-3098 (*1 *2 *1) (-12 (-5 *2 (-1293 *3 *4)) (-5 *1 (-1302 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)))) (-4136 (*1 *1 *2) (-12 (-5 *2 (-1293 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *1 (-1302 *3 *4)))) (-4429 (*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |k| *3) (|:| |c| (-1302 *3 *4))))) (-5 *1 (-1302 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075))))) 
+(-13 (-1299 |#1| |#2|) (-10 -8 (-15 -3098 ((-1293 |#1| |#2|) $)) (-15 -4136 ($ (-1293 |#1| |#2|))) (-15 -4429 ((-658 (-2 (|:| |k| |#1|) (|:| |c| $))) $)))) 
+((-3820 (((-658 (-1171 |#1|)) (-1 (-658 (-1171 |#1|)) (-658 (-1171 |#1|))) (-592)) 15) (((-1171 |#1|) (-1 (-1171 |#1|) (-1171 |#1|))) 11))) 
+(((-1303 |#1|) (-10 -7 (-15 -3820 ((-1171 |#1|) (-1 (-1171 |#1|) (-1171 |#1|)))) (-15 -3820 ((-658 (-1171 |#1|)) (-1 (-658 (-1171 |#1|)) (-658 (-1171 |#1|))) (-592)))) (-1225)) (T -1303)) 
+((-3820 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-658 (-1171 *5)) (-658 (-1171 *5)))) (-5 *4 (-592)) (-5 *2 (-658 (-1171 *5))) (-5 *1 (-1303 *5)) (-4 *5 (-1225)))) (-3820 (*1 *2 *3) (-12 (-5 *3 (-1 (-1171 *4) (-1171 *4))) (-5 *2 (-1171 *4)) (-5 *1 (-1303 *4)) (-4 *4 (-1225))))) 
+(-10 -7 (-15 -3820 ((-1171 |#1|) (-1 (-1171 |#1|) (-1171 |#1|)))) (-15 -3820 ((-658 (-1171 |#1|)) (-1 (-658 (-1171 |#1|)) (-658 (-1171 |#1|))) (-592)))) 
+((-2472 (((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|))) 145) (((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141)) 144) (((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141)) 143) (((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141) (-141)) 142) (((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-1072 |#1| |#2|)) 127)) (-2317 (((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|))) 70) (((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|)) (-141)) 69) (((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|)) (-141) (-141)) 68)) (-3164 (((-658 (-1160 |#1| (-558 (-879 |#3|)) (-879 |#3|) (-802 |#1| (-879 |#3|)))) (-1072 |#1| |#2|)) 59)) (-3006 (((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|))) 112) (((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141)) 111) (((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141)) 110) (((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141) (-141)) 109) (((-658 (-658 (-1051 (-433 |#1|)))) (-1072 |#1| |#2|)) 104)) (-3605 (((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|))) 117) (((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141)) 116) (((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141)) 115) (((-658 (-658 (-1051 (-433 |#1|)))) (-1072 |#1| |#2|)) 114)) (-1778 (((-658 (-802 |#1| (-879 |#3|))) (-1160 |#1| (-558 (-879 |#3|)) (-879 |#3|) (-802 |#1| (-879 |#3|)))) 96) (((-1187 (-1051 (-433 |#1|))) (-1187 |#1|)) 87) (((-980 (-1051 (-433 |#1|))) (-802 |#1| (-879 |#3|))) 94) (((-980 (-1051 (-433 |#1|))) (-980 |#1|)) 92) (((-802 |#1| (-879 |#3|)) (-802 |#1| (-879 |#2|))) 32))) 
+(((-1304 |#1| |#2| |#3|) (-10 -7 (-15 -2317 ((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|)) (-141) (-141))) (-15 -2317 ((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|)) (-141))) (-15 -2317 ((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|)))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-1072 |#1| |#2|))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141) (-141))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-1072 |#1| |#2|))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141) (-141))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)))) (-15 -3605 ((-658 (-658 (-1051 (-433 |#1|)))) (-1072 |#1| |#2|))) (-15 -3605 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141))) (-15 -3605 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141))) (-15 -3605 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)))) (-15 -3164 ((-658 (-1160 |#1| (-558 (-879 |#3|)) (-879 |#3|) (-802 |#1| (-879 |#3|)))) (-1072 |#1| |#2|))) (-15 -1778 ((-802 |#1| (-879 |#3|)) (-802 |#1| (-879 |#2|)))) (-15 -1778 ((-980 (-1051 (-433 |#1|))) (-980 |#1|))) (-15 -1778 ((-980 (-1051 (-433 |#1|))) (-802 |#1| (-879 |#3|)))) (-15 -1778 ((-1187 (-1051 (-433 |#1|))) (-1187 |#1|))) (-15 -1778 ((-658 (-802 |#1| (-879 |#3|))) (-1160 |#1| (-558 (-879 |#3|)) (-879 |#3|) (-802 |#1| (-879 |#3|)))))) (-13 (-867) (-323) (-171) (-1049)) (-658 (-1191)) (-658 (-1191))) (T -1304)) 
+((-1778 (*1 *2 *3) (-12 (-5 *3 (-1160 *4 (-558 (-879 *6)) (-879 *6) (-802 *4 (-879 *6)))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-802 *4 (-879 *6)))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))))) (-1778 (*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-1187 (-1051 (-433 *4)))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191))))) (-1778 (*1 *2 *3) (-12 (-5 *3 (-802 *4 (-879 *6))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *6 (-658 (-1191))) (-5 *2 (-980 (-1051 (-433 *4)))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))))) (-1778 (*1 *2 *3) (-12 (-5 *3 (-980 *4)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-980 (-1051 (-433 *4)))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191))))) (-1778 (*1 *2 *3) (-12 (-5 *3 (-802 *4 (-879 *5))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-802 *4 (-879 *6))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) (-3164 (*1 *2 *3) (-12 (-5 *3 (-1072 *4 *5)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-658 (-1160 *4 (-558 (-879 *6)) (-879 *6) (-802 *4 (-879 *6))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) (-3605 (*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *4))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191))))) (-3605 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-3605 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-3605 (*1 *2 *3) (-12 (-5 *3 (-1072 *4 *5)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-658 (-658 (-1051 (-433 *4))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) (-3006 (*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *4))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191))))) (-3006 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-3006 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-3006 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-3006 (*1 *2 *3) (-12 (-5 *3 (-1072 *4 *5)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-658 (-658 (-1051 (-433 *4))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) (-2472 (*1 *2 *3) (-12 (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *4)) (|:| -2231 (-658 (-980 *4)))))) (-5 *1 (-1304 *4 *5 *6)) (-5 *3 (-658 (-980 *4))) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191))))) (-2472 (*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1304 *5 *6 *7)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-2472 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1304 *5 *6 *7)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-2472 (*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1304 *5 *6 *7)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-2472 (*1 *2 *3) (-12 (-5 *3 (-1072 *4 *5)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *4)) (|:| -2231 (-658 (-980 *4)))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) (-2317 (*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-1072 *4 *5))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191))))) (-2317 (*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) (-2317 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191)))))) 
+(-10 -7 (-15 -2317 ((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|)) (-141) (-141))) (-15 -2317 ((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|)) (-141))) (-15 -2317 ((-658 (-1072 |#1| |#2|)) (-658 (-980 |#1|)))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-1072 |#1| |#2|))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141) (-141))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141) (-141))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)) (-141))) (-15 -2472 ((-658 (-2 (|:| -1666 (-1187 |#1|)) (|:| -2231 (-658 (-980 |#1|))))) (-658 (-980 |#1|)))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-1072 |#1| |#2|))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141) (-141))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141))) (-15 -3006 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)))) (-15 -3605 ((-658 (-658 (-1051 (-433 |#1|)))) (-1072 |#1| |#2|))) (-15 -3605 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141) (-141))) (-15 -3605 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)) (-141))) (-15 -3605 ((-658 (-658 (-1051 (-433 |#1|)))) (-658 (-980 |#1|)))) (-15 -3164 ((-658 (-1160 |#1| (-558 (-879 |#3|)) (-879 |#3|) (-802 |#1| (-879 |#3|)))) (-1072 |#1| |#2|))) (-15 -1778 ((-802 |#1| (-879 |#3|)) (-802 |#1| (-879 |#2|)))) (-15 -1778 ((-980 (-1051 (-433 |#1|))) (-980 |#1|))) (-15 -1778 ((-980 (-1051 (-433 |#1|))) (-802 |#1| (-879 |#3|)))) (-15 -1778 ((-1187 (-1051 (-433 |#1|))) (-1187 |#1|))) (-15 -1778 ((-658 (-802 |#1| (-879 |#3|))) (-1160 |#1| (-558 (-879 |#3|)) (-879 |#3|) (-802 |#1| (-879 |#3|)))))) 
+((-1684 (((-3 (-1280 (-433 (-592))) "failed") (-1280 |#1|) |#1|) 17)) (-2358 (((-141) (-1280 |#1|)) 11)) (-3762 (((-3 (-1280 (-592)) "failed") (-1280 |#1|)) 14))) 
+(((-1305 |#1|) (-10 -7 (-15 -2358 ((-141) (-1280 |#1|))) (-15 -3762 ((-3 (-1280 (-592)) "failed") (-1280 |#1|))) (-15 -1684 ((-3 (-1280 (-433 (-592))) "failed") (-1280 |#1|) |#1|))) (-654 (-592))) (T -1305)) 
+((-1684 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1280 *4)) (-4 *4 (-654 (-592))) (-5 *2 (-1280 (-433 (-592)))) (-5 *1 (-1305 *4)))) (-3762 (*1 *2 *3) (|partial| -12 (-5 *3 (-1280 *4)) (-4 *4 (-654 (-592))) (-5 *2 (-1280 (-592))) (-5 *1 (-1305 *4)))) (-2358 (*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-654 (-592))) (-5 *2 (-141)) (-5 *1 (-1305 *4))))) 
+(-10 -7 (-15 -2358 ((-141) (-1280 |#1|))) (-15 -3762 ((-3 (-1280 (-592)) "failed") (-1280 |#1|))) (-15 -1684 ((-3 (-1280 (-433 (-592))) "failed") (-1280 |#1|) |#1|))) 
+((-1641 (((-141) $ $) NIL)) (-2272 (((-141) $) 11)) (-2350 (((-3 $ "failed") $ $) NIL)) (-1403 (((-790)) 8)) (-3001 (($) NIL T CONST)) (-3371 (((-3 $ "failed") $) 43)) (-4290 (($) 36)) (-3558 (((-141) $) NIL)) (-3921 (((-3 $ "failed") $) 29)) (-3546 (((-944) $) 15)) (-2685 (((-1173) $) NIL)) (-3703 (($) 25 T CONST)) (-1825 (($ (-944)) 37)) (-2951 (((-1137) $) NIL)) (-1405 (((-658 $)) NIL)) (-1778 (((-592) $) 13)) (-1683 (((-877) $) 22) (($ (-592)) 19)) (-4010 (((-790)) 9)) (-1424 (($ $ (-944)) NIL) (($ $ (-790)) NIL)) (-3514 (($) 23 T CONST)) (-4257 (($) 24 T CONST)) (-3255 (((-141) $ $) 27)) (-3306 (($ $) 38) (($ $ $) 35)) (-3300 (($ $ $) 26)) (** (($ $ (-944)) NIL) (($ $ (-790)) 40)) (* (($ (-944) $) NIL) (($ (-790) $) NIL) (($ (-592) $) 32) (($ $ $) 31))) 
+(((-1306 |#1|) (-13 (-194) (-394) (-633 (-592)) (-1165)) (-944)) (T -1306)) 
+NIL 
+(-13 (-194) (-394) (-633 (-592)) (-1165)) 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+NIL 
+((-1311 3640255 3640260 3640265 "NIL" NIL T NIL (NIL) NIL NIL NIL) (-3 3640240 3640245 3640250 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-2 3640225 3640230 3640235 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-1 3640210 3640215 3640220 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (0 3640195 3640200 3640205 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-1306 3639300 3640070 3640147 "ZMOD" 3640152 NIL ZMOD (NIL NIL) -8 NIL NIL) (-1305 3638410 3638574 3638783 "ZLINDEP" 3639132 NIL ZLINDEP (NIL T) -7 NIL NIL) (-1304 3627714 3629478 3631450 "ZDSOLVE" 3636540 NIL ZDSOLVE (NIL T NIL NIL) -7 NIL NIL) (-1303 3626960 3627101 3627290 "YSTREAM" 3627560 NIL YSTREAM (NIL T) -7 NIL NIL) (-1302 3624725 3626261 3626465 "XRPOLY" 3626803 NIL XRPOLY (NIL T T) -8 NIL NIL) (-1301 3621179 3622508 3623088 "XPR" 3624192 NIL XPR (NIL T T) -8 NIL NIL) (-1300 3618889 3620510 3620714 "XPOLY" 3621010 NIL XPOLY (NIL T) -8 NIL NIL) (-1299 3616693 3618071 3618127 "XPOLYC" 3618415 NIL XPOLYC (NIL T T) -9 NIL 3618528) (-1298 3613067 3615212 3615599 "XPBWPOLY" 3616352 NIL XPBWPOLY (NIL T T) -8 NIL NIL) (-1297 3608932 3611242 3611285 "XF" 3611906 NIL XF (NIL T) -9 NIL 3612303) (-1296 3608553 3608641 3608810 "XF-" 3608815 NIL XF- (NIL T T) -8 NIL NIL) (-1295 3603902 3605201 3605257 "XFALG" 3607429 NIL XFALG (NIL T T) -9 NIL 3608216) (-1294 3603035 3603139 3603344 "XEXPPKG" 3603794 NIL XEXPPKG (NIL T T T) -7 NIL NIL) (-1293 3601132 3602885 3602981 "XDPOLY" 3602986 NIL XDPOLY (NIL T T) -8 NIL NIL) (-1292 3600004 3600614 3600658 "XALG" 3600721 NIL XALG (NIL T) -9 NIL 3600840) (-1291 3593473 3597981 3598475 "WUTSET" 3599596 NIL WUTSET (NIL T T T T) -8 NIL NIL) (-1290 3591282 3592089 3592440 "WP" 3593256 NIL WP (NIL T T T T NIL NIL NIL) -8 NIL NIL) (-1289 3590168 3590366 3590661 "WFFINTBS" 3591079 NIL WFFINTBS (NIL T T T T) -7 NIL NIL) (-1288 3588072 3588499 3588961 "WEIER" 3589740 NIL WEIER (NIL T) -7 NIL NIL) (-1287 3587218 3587642 3587685 "VSPACE" 3587821 NIL VSPACE (NIL T) -9 NIL 3587895) (-1286 3587056 3587083 3587174 "VSPACE-" 3587179 NIL VSPACE- (NIL T T) -8 NIL NIL) (-1285 3586802 3586845 3586916 "VOID" 3587007 T VOID (NIL) -8 NIL NIL) (-1284 3584938 3585297 3585703 "VIEW" 3586418 T VIEW (NIL) -7 NIL NIL) (-1283 3581363 3582001 3582738 "VIEWDEF" 3584223 T VIEWDEF (NIL) -7 NIL NIL) (-1282 3570702 3572911 3575084 "VIEW3D" 3579212 T VIEW3D (NIL) -8 NIL NIL) (-1281 3562984 3564613 3566192 "VIEW2D" 3569145 T VIEW2D (NIL) -8 NIL NIL) (-1280 3558392 3562754 3562846 "VECTOR" 3562927 NIL VECTOR (NIL T) -8 NIL NIL) (-1279 3556969 3557228 3557546 "VECTOR2" 3558122 NIL VECTOR2 (NIL T T) -7 NIL NIL) (-1278 3550534 3554780 3554824 "VECTCAT" 3555819 NIL VECTCAT (NIL T) -9 NIL 3556399) (-1277 3549548 3549802 3550192 "VECTCAT-" 3550197 NIL VECTCAT- (NIL T T) -8 NIL NIL) (-1276 3549029 3549199 3549319 "VARIABLE" 3549463 NIL VARIABLE (NIL NIL) -8 NIL NIL) (-1275 3541071 3546862 3547340 "UTSZ" 3548599 NIL UTSZ (NIL T NIL) -8 NIL NIL) (-1274 3540677 3540727 3540861 "UTSSOL" 3541015 NIL UTSSOL (NIL T T T) -7 NIL NIL) (-1273 3539509 3539663 3539924 "UTSODETL" 3540504 NIL UTSODETL (NIL T T T T) -7 NIL NIL) (-1272 3536949 3537409 3537933 "UTSODE" 3539050 NIL UTSODE (NIL T T) -7 NIL NIL) (-1271 3528782 3534577 3535065 "UTS" 3536519 NIL UTS (NIL T NIL NIL) -8 NIL NIL) (-1270 3520066 3525426 3525470 "UTSCAT" 3526582 NIL UTSCAT (NIL T) -9 NIL 3527333) (-1269 3517421 3518136 3519125 "UTSCAT-" 3519130 NIL UTSCAT- (NIL T T) -8 NIL NIL) (-1268 3517048 3517091 3517224 "UTS2" 3517372 NIL UTS2 (NIL T T T T) -7 NIL NIL) (-1267 3511362 3513921 3513965 "URAGG" 3516035 NIL URAGG (NIL T) -9 NIL 3516757) (-1266 3508301 3509164 3510287 "URAGG-" 3510292 NIL URAGG- (NIL T T) -8 NIL NIL) (-1265 3503979 3506915 3507387 "UPXSSING" 3507965 NIL UPXSSING (NIL T T NIL NIL) -8 NIL NIL) (-1264 3495866 3503096 3503377 "UPXS" 3503756 NIL UPXS (NIL T NIL NIL) -8 NIL NIL) (-1263 3488894 3495770 3495842 "UPXSCONS" 3495847 NIL UPXSCONS (NIL T T) -8 NIL NIL) (-1262 3479077 3485902 3485965 "UPXSCCA" 3486621 NIL UPXSCCA (NIL T T) -9 NIL 3486863) (-1261 3478715 3478800 3478974 "UPXSCCA-" 3478979 NIL UPXSCCA- (NIL T T T) -8 NIL NIL) (-1260 3468830 3475428 3475472 "UPXSCAT" 3476120 NIL UPXSCAT (NIL T) -9 NIL 3476722) (-1259 3468260 3468339 3468518 "UPXS2" 3468745 NIL UPXS2 (NIL T T NIL NIL NIL NIL) -7 NIL NIL) (-1258 3466914 3467167 3467518 "UPSQFREE" 3468003 NIL UPSQFREE (NIL T T) -7 NIL NIL) (-1257 3460747 3463797 3463853 "UPSCAT" 3465014 NIL UPSCAT (NIL T T) -9 NIL 3465783) (-1256 3459951 3460158 3460485 "UPSCAT-" 3460490 NIL UPSCAT- (NIL T T T) -8 NIL NIL) (-1255 3445628 3453796 3453840 "UPOLYC" 3456020 NIL UPOLYC (NIL T) -9 NIL 3457265) (-1254 3436862 3439318 3442497 "UPOLYC-" 3442502 NIL UPOLYC- (NIL T T) -8 NIL NIL) (-1253 3436489 3436532 3436665 "UPOLYC2" 3436813 NIL UPOLYC2 (NIL T T T T) -7 NIL NIL) (-1252 3427900 3436055 3436193 "UP" 3436399 NIL UP (NIL NIL T) -8 NIL NIL) (-1251 3427239 3427346 3427510 "UPMP" 3427789 NIL UPMP (NIL T T) -7 NIL NIL) (-1250 3426792 3426873 3427012 "UPDIVP" 3427152 NIL UPDIVP (NIL T T) -7 NIL NIL) (-1249 3425360 3425609 3425925 "UPDECOMP" 3426541 NIL UPDECOMP (NIL T T) -7 NIL NIL) (-1248 3424591 3424703 3424889 "UPCDEN" 3425244 NIL UPCDEN (NIL T T T) -7 NIL NIL) (-1247 3424110 3424179 3424328 "UP2" 3424516 NIL UP2 (NIL NIL T NIL T) -7 NIL NIL) (-1246 3422631 3423318 3423593 "UNISEG" 3423870 NIL UNISEG (NIL T) -8 NIL NIL) (-1245 3421848 3421975 3422179 "UNISEG2" 3422475 NIL UNISEG2 (NIL T T) -7 NIL NIL) (-1244 3420908 3421088 3421314 "UNIFACT" 3421664 NIL UNIFACT (NIL T) -7 NIL NIL) (-1243 3404792 3420087 3420337 "ULS" 3420716 NIL ULS (NIL T NIL NIL) -8 NIL NIL) (-1242 3392747 3404696 3404768 "ULSCONS" 3404773 NIL ULSCONS (NIL T T) -8 NIL NIL) (-1241 3375383 3387400 3387463 "ULSCCAT" 3388183 NIL ULSCCAT (NIL T T) -9 NIL 3388480) (-1240 3374433 3374678 3375066 "ULSCCAT-" 3375071 NIL ULSCCAT- (NIL T T T) -8 NIL NIL) (-1239 3364243 3370852 3370896 "ULSCAT" 3371759 NIL ULSCAT (NIL T) -9 NIL 3372482) (-1238 3363673 3363752 3363931 "ULS2" 3364158 NIL ULS2 (NIL T T NIL NIL NIL NIL) -7 NIL NIL) (-1237 3355811 3361664 3362164 "UFPS" 3363208 NIL UFPS (NIL T) -8 NIL NIL) (-1236 3355508 3355565 3355663 "UFPS1" 3355748 NIL UFPS1 (NIL T) -7 NIL NIL) (-1235 3353812 3354855 3354886 "UFD" 3355098 T UFD (NIL) -9 NIL 3355212) (-1234 3353606 3353652 3353747 "UFD-" 3353752 NIL UFD- (NIL T) -8 NIL NIL) (-1233 3352688 3352871 3353087 "UDVO" 3353412 T UDVO (NIL) -7 NIL NIL) (-1232 3350506 3350915 3351385 "UDPO" 3352253 NIL UDPO (NIL T) -7 NIL NIL) (-1231 3346469 3350451 3350487 "U8VEC" 3350492 T U8VEC (NIL) -8 NIL NIL) (-1230 3342663 3346233 3346331 "U8MAT" 3346393 T U8MAT (NIL) -8 NIL NIL) (-1229 3338626 3342608 3342644 "U32VEC" 3342649 T U32VEC (NIL) -8 NIL NIL) (-1228 3334820 3338390 3338488 "U32MAT" 3338550 T U32MAT (NIL) -8 NIL NIL) (-1227 3330783 3334765 3334801 "U16VEC" 3334806 T U16VEC (NIL) -8 NIL NIL) (-1226 3326977 3330547 3330645 "U16MAT" 3330707 T U16MAT (NIL) -8 NIL NIL) (-1225 3326909 3326914 3326945 "TYPE" 3326950 T TYPE (NIL) -9 NIL NIL) (-1224 3325880 3326082 3326322 "TWOFACT" 3326703 NIL TWOFACT (NIL T) -7 NIL NIL) (-1223 3324952 3325283 3325482 "TUPLE" 3325716 NIL TUPLE (NIL T) -8 NIL NIL) (-1222 3322643 3323162 3323701 "TUBETOOL" 3324435 T TUBETOOL (NIL) -7 NIL NIL) (-1221 3321485 3321690 3321932 "TUBE" 3322436 NIL TUBE (NIL T) -8 NIL NIL) (-1220 3316205 3320459 3320741 "TS" 3321238 NIL TS (NIL T) -8 NIL NIL) (-1219 3304877 3308962 3309060 "TSETCAT" 3314329 NIL TSETCAT (NIL T T T T) -9 NIL 3315860) (-1218 3299612 3301209 3303100 "TSETCAT-" 3303105 NIL TSETCAT- (NIL T T T T T) -8 NIL NIL) (-1217 3293882 3294729 3295667 "TRMANIP" 3298752 NIL TRMANIP (NIL T T) -7 NIL NIL) (-1216 3293323 3293386 3293549 "TRIMAT" 3293814 NIL TRIMAT (NIL T T T T) -7 NIL NIL) (-1215 3291119 3291356 3291720 "TRIGMNIP" 3293072 NIL TRIGMNIP (NIL T T) -7 NIL NIL) (-1214 3290638 3290751 3290782 "TRIGCAT" 3290995 T TRIGCAT (NIL) -9 NIL NIL) (-1213 3290307 3290386 3290527 "TRIGCAT-" 3290532 NIL TRIGCAT- (NIL T) -8 NIL NIL) (-1212 3287210 3289165 3289446 "TREE" 3290061 NIL TREE (NIL T) -8 NIL NIL) (-1211 3286481 3287009 3287040 "TRANFUN" 3287075 T TRANFUN (NIL) -9 NIL 3287142) (-1210 3285760 3285951 3286231 "TRANFUN-" 3286236 NIL TRANFUN- (NIL T) -8 NIL NIL) (-1209 3285564 3285596 3285657 "TOPSP" 3285721 T TOPSP (NIL) -7 NIL NIL) (-1208 3284912 3285027 3285181 "TOOLSIGN" 3285445 NIL TOOLSIGN (NIL T) -7 NIL NIL) (-1207 3283547 3284089 3284328 "TEXTFILE" 3284695 T TEXTFILE (NIL) -8 NIL NIL) (-1206 3281412 3281926 3282364 "TEX" 3283131 T TEX (NIL) -8 NIL NIL) (-1205 3281193 3281224 3281296 "TEX1" 3281375 NIL TEX1 (NIL T) -7 NIL NIL) (-1204 3280841 3280904 3280994 "TEMUTL" 3281125 T TEMUTL (NIL) -7 NIL NIL) (-1203 3278995 3279275 3279600 "TBCMPPK" 3280564 NIL TBCMPPK (NIL T T) -7 NIL NIL) (-1202 3270740 3277000 3277057 "TBAGG" 3277457 NIL TBAGG (NIL T T) -9 NIL 3277668) (-1201 3265810 3267298 3269052 "TBAGG-" 3269057 NIL TBAGG- (NIL T T T) -8 NIL NIL) (-1200 3265194 3265301 3265446 "TANEXP" 3265699 NIL TANEXP (NIL T) -7 NIL NIL) (-1199 3258707 3265051 3265144 "TABLE" 3265149 NIL TABLE (NIL T T) -8 NIL NIL) (-1198 3258120 3258218 3258356 "TABLEAU" 3258604 NIL TABLEAU (NIL T) -8 NIL NIL) (-1197 3252728 3253948 3255196 "TABLBUMP" 3256906 NIL TABLBUMP (NIL T) -7 NIL NIL) (-1196 3249191 3249886 3250669 "SYSSOLP" 3251979 NIL SYSSOLP (NIL T) -7 NIL NIL) (-1195 3246325 3246933 3247571 "SYMTAB" 3248575 T SYMTAB (NIL) -8 NIL NIL) (-1194 3241574 3242476 3243459 "SYMS" 3245364 T SYMS (NIL) -8 NIL NIL) (-1193 3238790 3241031 3241261 "SYMPOLY" 3241379 NIL SYMPOLY (NIL T) -8 NIL NIL) (-1192 3238307 3238382 3238505 "SYMFUNC" 3238702 NIL SYMFUNC (NIL T) -7 NIL NIL) (-1191 3234285 3235544 3236366 "SYMBOL" 3237507 T SYMBOL (NIL) -8 NIL NIL) (-1190 3227824 3229513 3231233 "SWITCH" 3232587 T SWITCH (NIL) -8 NIL NIL) (-1189 3221050 3226647 3226949 "SUTS" 3227580 NIL SUTS (NIL T NIL NIL) -8 NIL NIL) (-1188 3212936 3220167 3220448 "SUPXS" 3220827 NIL SUPXS (NIL T NIL NIL) -8 NIL NIL) (-1187 3204421 3212554 3212680 "SUP" 3212845 NIL SUP (NIL T) -8 NIL NIL) (-1186 3203580 3203707 3203924 "SUPFRACF" 3204289 NIL SUPFRACF (NIL T T T T) -7 NIL NIL) (-1185 3194152 3203382 3203496 "SUPEXPR" 3203501 NIL SUPEXPR (NIL T) -8 NIL NIL) (-1184 3193773 3193832 3193945 "SUP2" 3194087 NIL SUP2 (NIL T T) -7 NIL NIL) (-1183 3192186 3192460 3192823 "SUMRF" 3193472 NIL SUMRF (NIL T) -7 NIL NIL) (-1182 3191500 3191566 3191765 "SUMFS" 3192107 NIL SUMFS (NIL T T) -7 NIL NIL) (-1181 3175424 3190679 3190929 "SULS" 3191308 NIL SULS (NIL T NIL NIL) -8 NIL NIL) (-1180 3174746 3174949 3175089 "SUCH" 3175332 NIL SUCH (NIL T T) -8 NIL NIL) (-1179 3168640 3169652 3170611 "SUBSPACE" 3173834 NIL SUBSPACE (NIL NIL T) -8 NIL NIL) (-1178 3168072 3168162 3168325 "SUBRESP" 3168529 NIL SUBRESP (NIL T T) -7 NIL NIL) (-1177 3161441 3162737 3164048 "STTF" 3166808 NIL STTF (NIL T) -7 NIL NIL) (-1176 3155614 3156734 3157881 "STTFNC" 3160341 NIL STTFNC (NIL T) -7 NIL NIL) (-1175 3146933 3148800 3150592 "STTAYLOR" 3153857 NIL STTAYLOR (NIL T) -7 NIL NIL) (-1174 3140189 3146797 3146880 "STRTBL" 3146885 NIL STRTBL (NIL T) -8 NIL NIL) (-1173 3135580 3140144 3140175 "STRING" 3140180 T STRING (NIL) -8 NIL NIL) (-1172 3130444 3134922 3134953 "STRICAT" 3135012 T STRICAT (NIL) -9 NIL 3135074) (-1171 3123171 3127971 3128589 "STREAM" 3129861 NIL STREAM (NIL T) -8 NIL NIL) (-1170 3122681 3122758 3122902 "STREAM3" 3123088 NIL STREAM3 (NIL T T T) -7 NIL NIL) (-1169 3121663 3121846 3122081 "STREAM2" 3122494 NIL STREAM2 (NIL T T) -7 NIL NIL) (-1168 3121351 3121403 3121496 "STREAM1" 3121605 NIL STREAM1 (NIL T) -7 NIL NIL) (-1167 3120995 3121061 3121168 "STNSR" 3121279 NIL STNSR (NIL T) -7 NIL NIL) (-1166 3120011 3120192 3120423 "STINPROD" 3120811 NIL STINPROD (NIL T) -7 NIL NIL) (-1165 3119588 3119772 3119803 "STEP" 3119883 T STEP (NIL) -9 NIL 3119961) (-1164 3113143 3119487 3119564 "STBL" 3119569 NIL STBL (NIL T T NIL) -8 NIL NIL) (-1163 3108357 3112395 3112439 "STAGG" 3112592 NIL STAGG (NIL T) -9 NIL 3112681) (-1162 3106059 3106661 3107533 "STAGG-" 3107538 NIL STAGG- (NIL T T) -8 NIL NIL) (-1161 3099551 3101120 3102235 "STACK" 3104979 NIL STACK (NIL T) -8 NIL NIL) (-1160 3092276 3097692 3098148 "SREGSET" 3099181 NIL SREGSET (NIL T T T T) -8 NIL NIL) (-1159 3084702 3086070 3087583 "SRDCMPK" 3090882 NIL SRDCMPK (NIL T T T T T) -7 NIL NIL) (-1158 3077680 3082140 3082171 "SRAGG" 3083474 T SRAGG (NIL) -9 NIL 3084082) (-1157 3076697 3076952 3077331 "SRAGG-" 3077336 NIL SRAGG- (NIL T) -8 NIL NIL) (-1156 3071145 3075620 3076044 "SQMATRIX" 3076320 NIL SQMATRIX (NIL NIL T) -8 NIL NIL) (-1155 3064901 3067863 3068590 "SPLTREE" 3070490 NIL SPLTREE (NIL T T) -8 NIL NIL) (-1154 3060891 3061557 3062203 "SPLNODE" 3064327 NIL SPLNODE (NIL T T) -8 NIL NIL) (-1153 3059937 3060170 3060201 "SPFCAT" 3060645 T SPFCAT (NIL) -9 NIL NIL) (-1152 3058674 3058884 3059148 "SPECOUT" 3059695 T SPECOUT (NIL) -7 NIL NIL) (-1151 3050644 3052391 3052435 "SPACEC" 3056808 NIL SPACEC (NIL T) -9 NIL 3058624) (-1150 3048815 3050576 3050625 "SPACE3" 3050630 NIL SPACE3 (NIL T) -8 NIL NIL) (-1149 3047569 3047740 3048030 "SORTPAK" 3048621 NIL SORTPAK (NIL T T) -7 NIL NIL) (-1148 3045619 3045922 3046341 "SOLVETRA" 3047233 NIL SOLVETRA (NIL T) -7 NIL NIL) (-1147 3044630 3044852 3045126 "SOLVESER" 3045392 NIL SOLVESER (NIL T) -7 NIL NIL) (-1146 3039850 3040731 3041733 "SOLVERAD" 3043682 NIL SOLVERAD (NIL T) -7 NIL NIL) (-1145 3035665 3036274 3037003 "SOLVEFOR" 3039217 NIL SOLVEFOR (NIL T T) -7 NIL NIL) (-1144 3029967 3035012 3035110 "SNTSCAT" 3035115 NIL SNTSCAT (NIL T T T T) -9 NIL 3035185) (-1143 3024065 3028292 3028682 "SMTS" 3029658 NIL SMTS (NIL T T T) -8 NIL NIL) (-1142 3018469 3023953 3024030 "SMP" 3024035 NIL SMP (NIL T T) -8 NIL NIL) (-1141 3016628 3016929 3017327 "SMITH" 3018166 NIL SMITH (NIL T T T T) -7 NIL NIL) (-1140 3009570 3013768 3013872 "SMATCAT" 3015223 NIL SMATCAT (NIL NIL T T T) -9 NIL 3015770) (-1139 3006510 3007333 3008511 "SMATCAT-" 3008516 NIL SMATCAT- (NIL T NIL T T T) -8 NIL NIL) (-1138 3004263 3005780 3005824 "SKAGG" 3006085 NIL SKAGG (NIL T) -9 NIL 3006220) (-1137 3000244 3003367 3003645 "SINT" 3004007 T SINT (NIL) -8 NIL NIL) (-1136 3000016 3000054 3000120 "SIMPAN" 3000200 T SIMPAN (NIL) -7 NIL NIL) (-1135 2998854 2999075 2999350 "SIGNRF" 2999775 NIL SIGNRF (NIL T) -7 NIL NIL) (-1134 2997659 2997810 2998101 "SIGNEF" 2998683 NIL SIGNEF (NIL T T) -7 NIL NIL) (-1133 2995351 2995805 2996310 "SHP" 2997201 NIL SHP (NIL T NIL) -7 NIL NIL) (-1132 2989132 2995252 2995328 "SHDP" 2995333 NIL SHDP (NIL NIL NIL T) -8 NIL NIL) (-1131 2988620 2988812 2988843 "SGROUP" 2988995 T SGROUP (NIL) -9 NIL 2989082) (-1130 2988390 2988442 2988546 "SGROUP-" 2988551 NIL SGROUP- (NIL T) -8 NIL NIL) (-1129 2985226 2985923 2986646 "SGCF" 2987689 T SGCF (NIL) -7 NIL NIL) (-1128 2979626 2984671 2984769 "SFRTCAT" 2984774 NIL SFRTCAT (NIL T T T T) -9 NIL 2984813) (-1127 2973050 2974065 2975201 "SFRGCD" 2978609 NIL SFRGCD (NIL T T T T T) -7 NIL NIL) (-1126 2966178 2967249 2968435 "SFQCMPK" 2971983 NIL SFQCMPK (NIL T T T T T) -7 NIL NIL) (-1125 2965800 2965889 2965999 "SFORT" 2966119 NIL SFORT (NIL T T) -8 NIL NIL) (-1124 2964945 2965640 2965761 "SEXOF" 2965766 NIL SEXOF (NIL T T T T T) -8 NIL NIL) (-1123 2964079 2964826 2964894 "SEX" 2964899 T SEX (NIL) -8 NIL NIL) (-1122 2958854 2959543 2959639 "SEXCAT" 2963410 NIL SEXCAT (NIL T T T T T) -9 NIL 2964029) (-1121 2955989 2958788 2958836 "SET" 2958841 NIL SET (NIL T) -8 NIL NIL) (-1120 2954223 2954702 2955007 "SETMN" 2955730 NIL SETMN (NIL NIL NIL) -8 NIL NIL) (-1119 2953828 2953954 2953985 "SETCAT" 2954102 T SETCAT (NIL) -9 NIL 2954187) (-1118 2953608 2953660 2953759 "SETCAT-" 2953764 NIL SETCAT- (NIL T) -8 NIL NIL) (-1117 2953271 2953421 2953452 "SETCATD" 2953511 T SETCATD (NIL) -9 NIL 2953558) (-1116 2949657 2951731 2951775 "SETAGG" 2952645 NIL SETAGG (NIL T) -9 NIL 2952985) (-1115 2949115 2949231 2949468 "SETAGG-" 2949473 NIL SETAGG- (NIL T T) -8 NIL NIL) (-1114 2948318 2948611 2948673 "SEGXCAT" 2948959 NIL SEGXCAT (NIL T T) -9 NIL 2949079) (-1113 2947378 2947988 2948168 "SEG" 2948173 NIL SEG (NIL T) -8 NIL NIL) (-1112 2946284 2946497 2946541 "SEGCAT" 2947123 NIL SEGCAT (NIL T) -9 NIL 2947361) (-1111 2945335 2945665 2945864 "SEGBIND" 2946120 NIL SEGBIND (NIL T) -8 NIL NIL) (-1110 2944956 2945015 2945128 "SEGBIND2" 2945270 NIL SEGBIND2 (NIL T T) -7 NIL NIL) (-1109 2944177 2944303 2944506 "SEG2" 2944801 NIL SEG2 (NIL T T) -7 NIL NIL) (-1108 2943614 2944112 2944159 "SDVAR" 2944164 NIL SDVAR (NIL T) -8 NIL NIL) (-1107 2935858 2943384 2943514 "SDPOL" 2943519 NIL SDPOL (NIL T) -8 NIL NIL) (-1106 2931881 2932910 2933557 "SD" 2935258 NIL SD (NIL T) -8 NIL NIL) (-1105 2930474 2930740 2931059 "SCPKG" 2931596 NIL SCPKG (NIL T) -7 NIL NIL) (-1104 2929695 2929828 2930007 "SCACHE" 2930329 NIL SCACHE (NIL T) -7 NIL NIL) (-1103 2929134 2929455 2929540 "SAOS" 2929632 T SAOS (NIL) -8 NIL NIL) (-1102 2928699 2928734 2928907 "SAERFFC" 2929093 NIL SAERFFC (NIL T T T) -7 NIL NIL) (-1101 2922543 2928596 2928676 "SAE" 2928681 NIL SAE (NIL T T NIL) -8 NIL NIL) (-1100 2922136 2922171 2922330 "SAEFACT" 2922502 NIL SAEFACT (NIL T T T) -7 NIL NIL) (-1099 2920457 2920771 2921172 "RURPK" 2921802 NIL RURPK (NIL T NIL) -7 NIL NIL) (-1098 2919093 2919372 2919684 "RULESET" 2920291 NIL RULESET (NIL T T T) -8 NIL NIL) (-1097 2916280 2916783 2917248 "RULE" 2918774 NIL RULE (NIL T T T) -8 NIL NIL) (-1096 2915919 2916074 2916157 "RULECOLD" 2916232 NIL RULECOLD (NIL NIL) -8 NIL NIL) (-1095 2910768 2911562 2912482 "RSETGCD" 2915118 NIL RSETGCD (NIL T T T T T) -7 NIL NIL) (-1094 2900030 2905075 2905173 "RSETCAT" 2909292 NIL RSETCAT (NIL T T T T) -9 NIL 2910389) (-1093 2897957 2898496 2899320 "RSETCAT-" 2899325 NIL RSETCAT- (NIL T T T T T) -8 NIL NIL) (-1092 2890344 2891719 2893239 "RSDCMPK" 2896556 NIL RSDCMPK (NIL T T T T T) -7 NIL NIL) (-1091 2888348 2888789 2888864 "RRCC" 2889950 NIL RRCC (NIL T T) -9 NIL 2890294) (-1090 2887699 2887873 2888152 "RRCC-" 2888157 NIL RRCC- (NIL T T T) -8 NIL NIL) (-1089 2861786 2871417 2871485 "RPOLCAT" 2882151 NIL RPOLCAT (NIL T T T) -9 NIL 2885300) (-1088 2853286 2855624 2858746 "RPOLCAT-" 2858751 NIL RPOLCAT- (NIL T T T T) -8 NIL NIL) (-1087 2844345 2851497 2851979 "ROUTINE" 2852826 T ROUTINE (NIL) -8 NIL NIL) (-1086 2841045 2843896 2844045 "ROMAN" 2844218 T ROMAN (NIL) -8 NIL NIL) (-1085 2839320 2839905 2840165 "ROIRC" 2840850 NIL ROIRC (NIL T T) -8 NIL NIL) (-1084 2835567 2837945 2837976 "RNS" 2838280 T RNS (NIL) -9 NIL 2838554) (-1083 2834076 2834459 2834993 "RNS-" 2835068 NIL RNS- (NIL T) -8 NIL NIL) (-1082 2833498 2833906 2833937 "RNG" 2833942 T RNG (NIL) -9 NIL 2833963) (-1081 2832889 2833251 2833295 "RMODULE" 2833357 NIL RMODULE (NIL T) -9 NIL 2833399) (-1080 2831725 2831819 2832155 "RMCAT2" 2832790 NIL RMCAT2 (NIL NIL NIL T T T T T T T T) -7 NIL NIL) (-1079 2828434 2830903 2831226 "RMATRIX" 2831461 NIL RMATRIX (NIL NIL NIL T) -8 NIL NIL) (-1078 2821380 2823614 2823730 "RMATCAT" 2827089 NIL RMATCAT (NIL NIL NIL T T T) -9 NIL 2828066) (-1077 2820755 2820902 2821209 "RMATCAT-" 2821214 NIL RMATCAT- (NIL T NIL NIL T T T) -8 NIL NIL) (-1076 2820322 2820397 2820525 "RINTERP" 2820674 NIL RINTERP (NIL NIL T) -7 NIL NIL) (-1075 2819365 2819929 2819960 "RING" 2820072 T RING (NIL) -9 NIL 2820167) (-1074 2819157 2819201 2819298 "RING-" 2819303 NIL RING- (NIL T) -8 NIL NIL) (-1073 2817998 2818235 2818493 "RIDIST" 2818921 T RIDIST (NIL) -7 NIL NIL) (-1072 2809314 2817466 2817672 "RGCHAIN" 2817846 NIL RGCHAIN (NIL T NIL) -8 NIL NIL) (-1071 2808114 2808355 2808634 "RFP" 2809069 NIL RFP (NIL T) -7 NIL NIL) (-1070 2805108 2805722 2806392 "RF" 2807478 NIL RF (NIL T) -7 NIL NIL) (-1069 2804754 2804817 2804920 "RFFACTOR" 2805039 NIL RFFACTOR (NIL T) -7 NIL NIL) (-1068 2804479 2804514 2804611 "RFFACT" 2804713 NIL RFFACT (NIL T) -7 NIL NIL) (-1067 2802596 2802960 2803342 "RFDIST" 2804119 T RFDIST (NIL) -7 NIL NIL) (-1066 2802049 2802141 2802304 "RETSOL" 2802498 NIL RETSOL (NIL T T) -7 NIL NIL) (-1065 2801636 2801716 2801760 "RETRACT" 2801953 NIL RETRACT (NIL T) -9 NIL NIL) (-1064 2801485 2801510 2801597 "RETRACT-" 2801602 NIL RETRACT- (NIL T T) -8 NIL NIL) (-1063 2794351 2801138 2801265 "RESULT" 2801380 T RESULT (NIL) -8 NIL NIL) (-1062 2792931 2793620 2793819 "RESRING" 2794254 NIL RESRING (NIL T T T T NIL) -8 NIL NIL) (-1061 2792567 2792616 2792714 "RESLATC" 2792868 NIL RESLATC (NIL T) -7 NIL NIL) (-1060 2792273 2792307 2792414 "REPSQ" 2792526 NIL REPSQ (NIL T) -7 NIL NIL) (-1059 2789695 2790275 2790877 "REP" 2791693 T REP (NIL) -7 NIL NIL) (-1058 2789393 2789427 2789538 "REPDB" 2789654 NIL REPDB (NIL T) -7 NIL NIL) (-1057 2783311 2784690 2785909 "REP2" 2788209 NIL REP2 (NIL T) -7 NIL NIL) (-1056 2779692 2780373 2781179 "REP1" 2782540 NIL REP1 (NIL T) -7 NIL NIL) (-1055 2772418 2777833 2778289 "REGSET" 2779322 NIL REGSET (NIL T T T T) -8 NIL NIL) (-1054 2771233 2771568 2771817 "REF" 2772204 NIL REF (NIL T) -8 NIL NIL) (-1053 2770610 2770713 2770880 "REDORDER" 2771117 NIL REDORDER (NIL T T) -7 NIL NIL) (-1052 2767472 2767938 2768547 "RECOP" 2770144 NIL RECOP (NIL T T) -7 NIL NIL) (-1051 2763412 2766685 2766912 "RECLOS" 2767300 NIL RECLOS (NIL T) -8 NIL NIL) (-1050 2762464 2762645 2762860 "REALSOLV" 2763219 T REALSOLV (NIL) -7 NIL NIL) (-1049 2762309 2762350 2762381 "REAL" 2762386 T REAL (NIL) -9 NIL 2762421) (-1048 2758792 2759594 2760478 "REAL0Q" 2761474 NIL REAL0Q (NIL T) -7 NIL NIL) (-1047 2754393 2755381 2756442 "REAL0" 2757773 NIL REAL0 (NIL T) -7 NIL NIL) (-1046 2753798 2753870 2754077 "RDIV" 2754315 NIL RDIV (NIL T T T T T) -7 NIL NIL) (-1045 2752866 2753040 2753253 "RDIST" 2753620 NIL RDIST (NIL T) -7 NIL NIL) (-1044 2751463 2751750 2752122 "RDETRS" 2752574 NIL RDETRS (NIL T T) -7 NIL NIL) (-1043 2749275 2749729 2750267 "RDETR" 2751005 NIL RDETR (NIL T T) -7 NIL NIL) (-1042 2747886 2748164 2748568 "RDEEFS" 2748991 NIL RDEEFS (NIL T T) -7 NIL NIL) (-1041 2746381 2746687 2747119 "RDEEF" 2747574 NIL RDEEF (NIL T T) -7 NIL NIL) (-1040 2740559 2743494 2743525 "RCFIELD" 2744820 T RCFIELD (NIL) -9 NIL 2745551) (-1039 2738623 2739127 2739823 "RCFIELD-" 2739898 NIL RCFIELD- (NIL T) -8 NIL NIL) (-1038 2734981 2736760 2736804 "RCAGG" 2737888 NIL RCAGG (NIL T) -9 NIL 2738351) (-1037 2734609 2734703 2734866 "RCAGG-" 2734871 NIL RCAGG- (NIL T T) -8 NIL NIL) (-1036 2733945 2734056 2734221 "RATRET" 2734493 NIL RATRET (NIL T) -7 NIL NIL) (-1035 2733498 2733565 2733686 "RATFACT" 2733873 NIL RATFACT (NIL T) -7 NIL NIL) (-1034 2732806 2732926 2733078 "RANDSRC" 2733368 T RANDSRC (NIL) -7 NIL NIL) (-1033 2732540 2732584 2732657 "RADUTIL" 2732755 T RADUTIL (NIL) -7 NIL NIL) (-1032 2725526 2731271 2731591 "RADIX" 2732254 NIL RADIX (NIL NIL) -8 NIL NIL) (-1031 2717037 2725368 2725498 "RADFF" 2725503 NIL RADFF (NIL T T T NIL NIL) -8 NIL NIL) (-1030 2716683 2716758 2716789 "RADCAT" 2716949 T RADCAT (NIL) -9 NIL NIL) (-1029 2716465 2716513 2716613 "RADCAT-" 2716618 NIL RADCAT- (NIL T) -8 NIL NIL) (-1028 2709710 2711328 2712482 "QUEUE" 2715346 NIL QUEUE (NIL T) -8 NIL NIL) (-1027 2706197 2709643 2709691 "QUAT" 2709696 NIL QUAT (NIL T) -8 NIL NIL) (-1026 2705828 2705871 2706002 "QUATCT2" 2706148 NIL QUATCT2 (NIL T T T T) -7 NIL NIL) (-1025 2699552 2702936 2702979 "QUATCAT" 2703770 NIL QUATCAT (NIL T) -9 NIL 2704528) (-1024 2695691 2696728 2698118 "QUATCAT-" 2698214 NIL QUATCAT- (NIL T T) -8 NIL NIL) (-1023 2693243 2694801 2694845 "QUAGG" 2695226 NIL QUAGG (NIL T) -9 NIL 2695401) (-1022 2692163 2692636 2692810 "QFORM" 2693115 NIL QFORM (NIL NIL T) -8 NIL NIL) (-1021 2683289 2688632 2688675 "QFCAT" 2689343 NIL QFCAT (NIL T) -9 NIL 2690332) (-1020 2678856 2680057 2681651 "QFCAT-" 2681747 NIL QFCAT- (NIL T T) -8 NIL NIL) (-1019 2678487 2678530 2678661 "QFCAT2" 2678807 NIL QFCAT2 (NIL T T T T) -7 NIL NIL) (-1018 2677942 2678052 2678184 "QEQUAT" 2678377 T QEQUAT (NIL) -8 NIL NIL) (-1017 2671070 2672141 2673327 "QCMPACK" 2676875 NIL QCMPACK (NIL T T T T T) -7 NIL NIL) (-1016 2668639 2669060 2669488 "QALGSET" 2670727 NIL QALGSET (NIL T T T T) -8 NIL NIL) (-1015 2667874 2668050 2668286 "QALGSET2" 2668457 NIL QALGSET2 (NIL NIL NIL) -7 NIL NIL) (-1014 2666560 2666783 2667102 "PWFFINTB" 2667647 NIL PWFFINTB (NIL T T T T) -7 NIL NIL) (-1013 2664735 2664903 2665259 "PUSHVAR" 2666374 NIL PUSHVAR (NIL T T T T) -7 NIL NIL) (-1012 2660623 2661677 2661721 "PTRANFN" 2663632 NIL PTRANFN (NIL T) -9 NIL NIL) (-1011 2659014 2659305 2659629 "PTPACK" 2660334 NIL PTPACK (NIL T) -7 NIL NIL) (-1010 2658643 2658700 2658811 "PTFUNC2" 2658951 NIL PTFUNC2 (NIL T T) -7 NIL NIL) (-1009 2653136 2657470 2657514 "PTCAT" 2657892 NIL PTCAT (NIL T) -9 NIL 2658054) (-1008 2652791 2652826 2652952 "PSQFR" 2653095 NIL PSQFR (NIL T T T T) -7 NIL NIL) (-1007 2651373 2651673 2652011 "PSEUDLIN" 2652487 NIL PSEUDLIN (NIL T) -7 NIL NIL) (-1006 2638110 2640474 2642797 "PSETPK" 2649136 NIL PSETPK (NIL T T T T) -7 NIL NIL) (-1005 2631132 2633846 2633945 "PSETCAT" 2636986 NIL PSETCAT (NIL T T T T) -9 NIL 2637799) (-1004 2628965 2629599 2630423 "PSETCAT-" 2630428 NIL PSETCAT- (NIL T T T T T) -8 NIL NIL) (-1003 2628308 2628472 2628503 "PSCURVE" 2628775 T PSCURVE (NIL) -9 NIL 2628942) (-1002 2624687 2626213 2626281 "PSCAT" 2627133 NIL PSCAT (NIL T T T) -9 NIL 2627373) (-1001 2623747 2623963 2624366 "PSCAT-" 2624371 NIL PSCAT- (NIL T T T T) -8 NIL NIL) (-1000 2622393 2623025 2623241 "PRTITION" 2623553 T PRTITION (NIL) -8 NIL NIL) (-999 2619557 2620206 2620247 "PRSPCAT" 2621761 NIL PRSPCAT (NIL T) -9 NIL 2622329) (-998 2608657 2610863 2613050 "PRS" 2617420 NIL PRS (NIL T T) -7 NIL NIL) (-997 2606555 2608041 2608082 "PRQAGG" 2608265 NIL PRQAGG (NIL T) -9 NIL 2608367) (-996 2605824 2606480 2606537 "PROJSP" 2606542 NIL PROJSP (NIL NIL T) -8 NIL NIL) (-995 2605006 2605747 2605799 "PROJPLPS" 2605804 NIL PROJPLPS (NIL T) -8 NIL NIL) (-994 2604265 2604943 2604988 "PROJPL" 2604993 NIL PROJPL (NIL T) -8 NIL NIL) (-993 2598000 2602463 2603267 "PRODUCT" 2603507 NIL PRODUCT (NIL T T) -8 NIL NIL) (-992 2595275 2597464 2597695 "PR" 2597814 NIL PR (NIL T T) -8 NIL NIL) (-991 2593827 2593984 2594279 "PRJALGPK" 2595115 NIL PRJALGPK (NIL T NIL T T T) -7 NIL NIL) (-990 2593623 2593655 2593714 "PRINT" 2593788 T PRINT (NIL) -7 NIL NIL) (-989 2592963 2593080 2593232 "PRIMES" 2593503 NIL PRIMES (NIL T) -7 NIL NIL) (-988 2591028 2591429 2591895 "PRIMELT" 2592542 NIL PRIMELT (NIL T) -7 NIL NIL) (-987 2590756 2590805 2590834 "PRIMCAT" 2590958 T PRIMCAT (NIL) -9 NIL NIL) (-986 2586923 2590694 2590739 "PRIMARR" 2590744 NIL PRIMARR (NIL T) -8 NIL NIL) (-985 2585930 2586108 2586336 "PRIMARR2" 2586741 NIL PRIMARR2 (NIL T T) -7 NIL NIL) (-984 2585573 2585629 2585740 "PREASSOC" 2585868 NIL PREASSOC (NIL T T) -7 NIL NIL) (-983 2585048 2585180 2585209 "PPCURVE" 2585414 T PPCURVE (NIL) -9 NIL 2585550) (-982 2579446 2580597 2581776 "POLYVEC" 2583889 T POLYVEC (NIL) -7 NIL NIL) (-981 2576807 2577206 2577797 "POLYROOT" 2579028 NIL POLYROOT (NIL T T T T T) -7 NIL NIL) (-980 2570708 2576413 2576572 "POLY" 2576681 NIL POLY (NIL T) -8 NIL NIL) (-979 2570091 2570149 2570383 "POLYLIFT" 2570644 NIL POLYLIFT (NIL T T T T T) -7 NIL NIL) (-978 2566366 2566815 2567444 "POLYCATQ" 2569636 NIL POLYCATQ (NIL T T T T T) -7 NIL NIL) (-977 2553176 2558673 2558739 "POLYCAT" 2562253 NIL POLYCAT (NIL T T T) -9 NIL 2564166) (-976 2546626 2548487 2550871 "POLYCAT-" 2550876 NIL POLYCAT- (NIL T T T T) -8 NIL NIL) (-975 2546213 2546281 2546401 "POLY2UP" 2546552 NIL POLY2UP (NIL NIL T) -7 NIL NIL) (-974 2545845 2545902 2546011 "POLY2" 2546150 NIL POLY2 (NIL T T) -7 NIL NIL) (-973 2544532 2544771 2545046 "POLUTIL" 2545620 NIL POLUTIL (NIL T T) -7 NIL NIL) (-972 2542887 2543164 2543495 "POLTOPOL" 2544254 NIL POLTOPOL (NIL NIL T) -7 NIL NIL) (-971 2538407 2542821 2542868 "POINT" 2542873 NIL POINT (NIL T) -8 NIL NIL) (-970 2536594 2536951 2537326 "PNTHEORY" 2538052 T PNTHEORY (NIL) -7 NIL NIL) (-969 2535013 2535310 2535722 "PMTOOLS" 2536292 NIL PMTOOLS (NIL T T T) -7 NIL NIL) (-968 2534606 2534684 2534801 "PMSYM" 2534929 NIL PMSYM (NIL T) -7 NIL NIL) (-967 2534114 2534183 2534358 "PMQFCAT" 2534531 NIL PMQFCAT (NIL T T T) -7 NIL NIL) (-966 2533469 2533579 2533735 "PMPRED" 2533991 NIL PMPRED (NIL T) -7 NIL NIL) (-965 2532865 2532951 2533112 "PMPREDFS" 2533370 NIL PMPREDFS (NIL T T T) -7 NIL NIL) (-964 2531510 2531718 2532102 "PMPLCAT" 2532628 NIL PMPLCAT (NIL T T T T T) -7 NIL NIL) (-963 2531042 2531121 2531273 "PMLSAGG" 2531425 NIL PMLSAGG (NIL T T T) -7 NIL NIL) (-962 2530517 2530593 2530774 "PMKERNEL" 2530960 NIL PMKERNEL (NIL T T) -7 NIL NIL) (-961 2530134 2530209 2530322 "PMINS" 2530436 NIL PMINS (NIL T) -7 NIL NIL) (-960 2529562 2529631 2529847 "PMFS" 2530059 NIL PMFS (NIL T T T) -7 NIL NIL) (-959 2528790 2528908 2529113 "PMDOWN" 2529439 NIL PMDOWN (NIL T T T) -7 NIL NIL) (-958 2527953 2528112 2528294 "PMASS" 2528628 T PMASS (NIL) -7 NIL NIL) (-957 2527227 2527338 2527501 "PMASSFS" 2527839 NIL PMASSFS (NIL T T) -7 NIL NIL) (-956 2524987 2525240 2525623 "PLPKCRV" 2526951 NIL PLPKCRV (NIL T T T NIL T) -7 NIL NIL) (-955 2524642 2524710 2524804 "PLOTTOOL" 2524913 T PLOTTOOL (NIL) -7 NIL NIL) (-954 2519264 2520453 2521601 "PLOT" 2523514 T PLOT (NIL) -8 NIL NIL) (-953 2515076 2516110 2517032 "PLOT3D" 2518362 T PLOT3D (NIL) -8 NIL NIL) (-952 2513988 2514165 2514400 "PLOT1" 2514880 NIL PLOT1 (NIL T) -7 NIL NIL) (-951 2489407 2494072 2498917 "PLEQN" 2509260 NIL PLEQN (NIL T T T T) -7 NIL NIL) (-950 2488647 2489317 2489384 "PLCS" 2489389 NIL PLCS (NIL T T) -8 NIL NIL) (-949 2487798 2488532 2488603 "PLACESPS" 2488608 NIL PLACESPS (NIL T) -8 NIL NIL) (-948 2487005 2487711 2487768 "PLACES" 2487773 NIL PLACES (NIL T) -8 NIL NIL) (-947 2483729 2484393 2484452 "PLACESC" 2486370 NIL PLACESC (NIL T T) -9 NIL 2486941) (-946 2483047 2483169 2483349 "PINTERP" 2483594 NIL PINTERP (NIL NIL T) -7 NIL NIL) (-945 2482740 2482787 2482890 "PINTERPA" 2482994 NIL PINTERPA (NIL T T) -7 NIL NIL) (-944 2481967 2482534 2482627 "PI" 2482667 T PI (NIL) -8 NIL NIL) (-943 2480341 2481326 2481355 "PID" 2481537 T PID (NIL) -9 NIL 2481671) (-942 2480066 2480103 2480191 "PICOERCE" 2480298 NIL PICOERCE (NIL T) -7 NIL NIL) (-941 2479387 2479525 2479701 "PGROEB" 2479922 NIL PGROEB (NIL T) -7 NIL NIL) (-940 2474970 2475785 2476691 "PGE" 2478501 T PGE (NIL) -7 NIL NIL) (-939 2473094 2473340 2473706 "PGCD" 2474687 NIL PGCD (NIL T T T T) -7 NIL NIL) (-938 2472432 2472535 2472696 "PFRPAC" 2472978 NIL PFRPAC (NIL T) -7 NIL NIL) (-937 2469047 2470980 2471333 "PFR" 2472111 NIL PFR (NIL T) -8 NIL NIL) (-936 2467436 2467680 2468005 "PFOTOOLS" 2468794 NIL PFOTOOLS (NIL T T) -7 NIL NIL) (-935 2462301 2462966 2463715 "PFORP" 2466778 NIL PFORP (NIL T T T NIL) -7 NIL NIL) (-934 2460834 2461073 2461424 "PFOQ" 2462058 NIL PFOQ (NIL T T T) -7 NIL NIL) (-933 2459307 2459519 2459882 "PFO" 2460618 NIL PFO (NIL T T T T T) -7 NIL NIL) (-932 2455805 2459196 2459265 "PF" 2459270 NIL PF (NIL NIL) -8 NIL NIL) (-931 2453217 2454498 2454527 "PFECAT" 2455112 T PFECAT (NIL) -9 NIL 2455495) (-930 2452662 2452816 2453030 "PFECAT-" 2453035 NIL PFECAT- (NIL T) -8 NIL NIL) (-929 2451266 2451517 2451818 "PFBRU" 2452411 NIL PFBRU (NIL T T) -7 NIL NIL) (-928 2449133 2449484 2449916 "PFBR" 2450917 NIL PFBR (NIL T T T T) -7 NIL NIL) (-927 2444985 2446510 2447185 "PERM" 2448491 NIL PERM (NIL T) -8 NIL NIL) (-926 2440252 2441192 2442062 "PERMGRP" 2444148 NIL PERMGRP (NIL T) -8 NIL NIL) (-925 2438323 2439316 2439358 "PERMCAT" 2439804 NIL PERMCAT (NIL T) -9 NIL 2440107) (-924 2437976 2438017 2438141 "PERMAN" 2438276 NIL PERMAN (NIL NIL T) -7 NIL NIL) (-923 2435422 2437545 2437676 "PENDTREE" 2437878 NIL PENDTREE (NIL T) -8 NIL NIL) (-922 2433490 2434268 2434310 "PDRING" 2434967 NIL PDRING (NIL T) -9 NIL 2435253) (-921 2432593 2432811 2433173 "PDRING-" 2433178 NIL PDRING- (NIL T T) -8 NIL NIL) (-920 2429735 2430485 2431176 "PDEPROB" 2431922 T PDEPROB (NIL) -8 NIL NIL) (-919 2427282 2427784 2428339 "PDEPACK" 2429200 T PDEPACK (NIL) -7 NIL NIL) (-918 2426194 2426384 2426635 "PDECOMP" 2427081 NIL PDECOMP (NIL T T) -7 NIL NIL) (-917 2423798 2424615 2424644 "PDECAT" 2425431 T PDECAT (NIL) -9 NIL 2426144) (-916 2423549 2423582 2423672 "PCOMP" 2423759 NIL PCOMP (NIL T T) -7 NIL NIL) (-915 2421754 2422350 2422647 "PBWLB" 2423278 NIL PBWLB (NIL T) -8 NIL NIL) (-914 2414259 2415827 2417165 "PATTERN" 2420437 NIL PATTERN (NIL T) -8 NIL NIL) (-913 2413891 2413948 2414057 "PATTERN2" 2414196 NIL PATTERN2 (NIL T T) -7 NIL NIL) (-912 2411648 2412036 2412493 "PATTERN1" 2413480 NIL PATTERN1 (NIL T T) -7 NIL NIL) (-911 2409043 2409597 2410078 "PATRES" 2411213 NIL PATRES (NIL T T) -8 NIL NIL) (-910 2408607 2408674 2408806 "PATRES2" 2408970 NIL PATRES2 (NIL T T T) -7 NIL NIL) (-909 2406490 2406895 2407302 "PATMATCH" 2408274 NIL PATMATCH (NIL T T T) -7 NIL NIL) (-908 2406025 2406208 2406250 "PATMAB" 2406357 NIL PATMAB (NIL T) -9 NIL 2406440) (-907 2404570 2404879 2405137 "PATLRES" 2405830 NIL PATLRES (NIL T T T) -8 NIL NIL) (-906 2404117 2404240 2404282 "PATAB" 2404287 NIL PATAB (NIL T) -9 NIL 2404457) (-905 2401598 2402130 2402703 "PARTPERM" 2403564 T PARTPERM (NIL) -7 NIL NIL) (-904 2401219 2401282 2401384 "PARSURF" 2401529 NIL PARSURF (NIL T) -8 NIL NIL) (-903 2400851 2400908 2401017 "PARSU2" 2401156 NIL PARSU2 (NIL T T) -7 NIL NIL) (-902 2400472 2400535 2400637 "PARSCURV" 2400782 NIL PARSCURV (NIL T) -8 NIL NIL) (-901 2400104 2400161 2400270 "PARSC2" 2400409 NIL PARSC2 (NIL T T) -7 NIL NIL) (-900 2399743 2399801 2399898 "PARPCURV" 2400040 NIL PARPCURV (NIL T) -8 NIL NIL) (-899 2399375 2399432 2399541 "PARPC2" 2399680 NIL PARPC2 (NIL T T) -7 NIL NIL) (-898 2397855 2397973 2398292 "PARAMP" 2399230 NIL PARAMP (NIL T NIL T T T T T) -7 NIL NIL) (-897 2397375 2397461 2397580 "PAN2EXPR" 2397756 T PAN2EXPR (NIL) -7 NIL NIL) (-896 2396181 2396496 2396724 "PALETTE" 2397167 T PALETTE (NIL) -8 NIL NIL) (-895 2383814 2385980 2388096 "PAFF" 2394129 NIL PAFF (NIL T NIL T) -7 NIL NIL) (-894 2370810 2373138 2375349 "PAFFFF" 2381667 NIL PAFFFF (NIL T NIL T) -7 NIL NIL) (-893 2364649 2370067 2370262 "PADICRC" 2370664 NIL PADICRC (NIL NIL T) -8 NIL NIL) (-892 2357846 2363993 2364178 "PADICRAT" 2364496 NIL PADICRAT (NIL NIL) -8 NIL NIL) (-891 2356150 2357783 2357828 "PADIC" 2357833 NIL PADIC (NIL NIL) -8 NIL NIL) (-890 2353337 2354911 2354952 "PADICCT" 2355533 NIL PADICCT (NIL NIL) -9 NIL 2355815) (-889 2352294 2352494 2352762 "PADEPAC" 2353124 NIL PADEPAC (NIL T NIL NIL) -7 NIL NIL) (-888 2351506 2351639 2351845 "PADE" 2352156 NIL PADE (NIL T T T) -7 NIL NIL) (-887 2347983 2351124 2351243 "PACRAT" 2351407 T PACRAT (NIL) -8 NIL NIL) (-886 2344031 2347081 2347110 "PACRATC" 2347115 T PACRATC (NIL) -9 NIL 2347195) (-885 2340140 2342105 2342134 "PACPERC" 2343080 T PACPERC (NIL) -9 NIL 2343520) (-884 2336785 2339914 2340005 "PACOFF" 2340081 NIL PACOFF (NIL T) -8 NIL NIL) (-883 2333442 2336127 2336156 "PACFFC" 2336161 T PACFFC (NIL) -9 NIL 2336182) (-882 2329532 2333125 2333226 "PACEXT" 2333373 NIL PACEXT (NIL NIL) -8 NIL NIL) (-881 2324897 2328414 2328443 "PACEXTC" 2328448 T PACEXTC (NIL) -9 NIL 2328492) (-880 2322905 2323737 2324052 "OWP" 2324666 NIL OWP (NIL T NIL NIL NIL) -8 NIL NIL) (-879 2321989 2322510 2322682 "OVAR" 2322773 NIL OVAR (NIL NIL) -8 NIL NIL) (-878 2321253 2321374 2321535 "OUT" 2321848 T OUT (NIL) -7 NIL NIL) (-877 2310299 2312478 2314648 "OUTFORM" 2319103 T OUTFORM (NIL) -8 NIL NIL) (-876 2309707 2310028 2310117 "OSI" 2310230 T OSI (NIL) -8 NIL NIL) (-875 2308454 2308681 2308965 "ORTHPOL" 2309455 NIL ORTHPOL (NIL T) -7 NIL NIL) (-874 2305816 2308111 2308251 "OREUP" 2308397 NIL OREUP (NIL NIL T NIL NIL) -8 NIL NIL) (-873 2303203 2305505 2305633 "ORESUP" 2305758 NIL ORESUP (NIL T NIL NIL) -8 NIL NIL) (-872 2300711 2301217 2301782 "OREPCTO" 2302688 NIL OREPCTO (NIL T T) -7 NIL NIL) (-871 2294581 2296792 2296834 "OREPCAT" 2299182 NIL OREPCAT (NIL T) -9 NIL 2300282) (-870 2291728 2292510 2293568 "OREPCAT-" 2293573 NIL OREPCAT- (NIL T T) -8 NIL NIL) (-869 2290904 2291176 2291205 "ORDSET" 2291514 T ORDSET (NIL) -9 NIL 2291678) (-868 2290423 2290545 2290738 "ORDSET-" 2290743 NIL ORDSET- (NIL T) -8 NIL NIL) (-867 2289032 2289833 2289862 "ORDRING" 2290064 T ORDRING (NIL) -9 NIL 2290189) (-866 2288677 2288771 2288915 "ORDRING-" 2288920 NIL ORDRING- (NIL T) -8 NIL NIL) (-865 2288051 2288532 2288561 "ORDMON" 2288566 T ORDMON (NIL) -9 NIL 2288587) (-864 2287213 2287360 2287555 "ORDFUNS" 2287900 NIL ORDFUNS (NIL NIL T) -7 NIL NIL) (-863 2286699 2287082 2287111 "ORDFIN" 2287116 T ORDFIN (NIL) -9 NIL 2287137) (-862 2283211 2285291 2285697 "ORDCOMP" 2286326 NIL ORDCOMP (NIL T) -8 NIL NIL) (-861 2282477 2282604 2282790 "ORDCOMP2" 2283071 NIL ORDCOMP2 (NIL T T) -7 NIL NIL) (-860 2278985 2279867 2280704 "OPTPROB" 2281660 T OPTPROB (NIL) -8 NIL NIL) (-859 2275787 2276426 2277130 "OPTPACK" 2278301 T OPTPACK (NIL) -7 NIL NIL) (-858 2273499 2274239 2274268 "OPTCAT" 2275087 T OPTCAT (NIL) -9 NIL 2275737) (-857 2273267 2273306 2273372 "OPQUERY" 2273453 T OPQUERY (NIL) -7 NIL NIL) (-856 2270393 2271584 2272085 "OP" 2272799 NIL OP (NIL T) -8 NIL NIL) (-855 2267158 2269196 2269562 "ONECOMP" 2270060 NIL ONECOMP (NIL T) -8 NIL NIL) (-854 2266463 2266578 2266752 "ONECOMP2" 2267030 NIL ONECOMP2 (NIL T T) -7 NIL NIL) (-853 2265882 2265988 2266118 "OMSERVER" 2266353 T OMSERVER (NIL) -7 NIL NIL) (-852 2262769 2265321 2265362 "OMSAGG" 2265423 NIL OMSAGG (NIL T) -9 NIL 2265487) (-851 2261392 2261655 2261937 "OMPKG" 2262507 T OMPKG (NIL) -7 NIL NIL) (-850 2260821 2260924 2260953 "OM" 2261252 T OM (NIL) -9 NIL NIL) (-849 2259359 2260372 2260540 "OMLO" 2260703 NIL OMLO (NIL T T) -8 NIL NIL) (-848 2258284 2258431 2258658 "OMEXPR" 2259185 NIL OMEXPR (NIL T) -7 NIL NIL) (-847 2257602 2257830 2257966 "OMERR" 2258168 T OMERR (NIL) -8 NIL NIL) (-846 2256780 2257023 2257183 "OMERRK" 2257462 T OMERRK (NIL) -8 NIL NIL) (-845 2256258 2256457 2256565 "OMENC" 2256692 T OMENC (NIL) -8 NIL NIL) (-844 2250153 2251338 2252509 "OMDEV" 2255107 T OMDEV (NIL) -8 NIL NIL) (-843 2249222 2249393 2249587 "OMCONN" 2249979 T OMCONN (NIL) -8 NIL NIL) (-842 2247833 2248819 2248848 "OINTDOM" 2248853 T OINTDOM (NIL) -9 NIL 2248874) (-841 2243484 2244739 2245483 "OFMONOID" 2247121 NIL OFMONOID (NIL T) -8 NIL NIL) (-840 2242922 2243421 2243466 "ODVAR" 2243471 NIL ODVAR (NIL T) -8 NIL NIL) (-839 2240049 2242421 2242605 "ODR" 2242798 NIL ODR (NIL T T NIL) -8 NIL NIL) (-838 2232347 2239825 2239951 "ODPOL" 2239956 NIL ODPOL (NIL T) -8 NIL NIL) (-837 2226098 2232219 2232324 "ODP" 2232329 NIL ODP (NIL NIL T NIL) -8 NIL NIL) (-836 2224864 2225079 2225354 "ODETOOLS" 2225872 NIL ODETOOLS (NIL T T) -7 NIL NIL) (-835 2221833 2222489 2223205 "ODESYS" 2224197 NIL ODESYS (NIL T T) -7 NIL NIL) (-834 2216717 2217625 2218649 "ODERTRIC" 2220909 NIL ODERTRIC (NIL T T) -7 NIL NIL) (-833 2216143 2216225 2216419 "ODERED" 2216629 NIL ODERED (NIL T T T T T) -7 NIL NIL) (-832 2213031 2213579 2214256 "ODERAT" 2215566 NIL ODERAT (NIL T T) -7 NIL NIL) (-831 2209991 2210455 2211052 "ODEPRRIC" 2212560 NIL ODEPRRIC (NIL T T T T) -7 NIL NIL) (-830 2207862 2208429 2208938 "ODEPROB" 2209502 T ODEPROB (NIL) -8 NIL NIL) (-829 2204384 2204867 2205514 "ODEPRIM" 2207341 NIL ODEPRIM (NIL T T T T) -7 NIL NIL) (-828 2203633 2203735 2203995 "ODEPAL" 2204276 NIL ODEPAL (NIL T T T T) -7 NIL NIL) (-827 2199795 2200586 2201450 "ODEPACK" 2202789 T ODEPACK (NIL) -7 NIL NIL) (-826 2198828 2198935 2199164 "ODEINT" 2199684 NIL ODEINT (NIL T T) -7 NIL NIL) (-825 2192929 2194354 2195801 "ODEIFTBL" 2197401 T ODEIFTBL (NIL) -8 NIL NIL) (-824 2188264 2189050 2190009 "ODEEF" 2192088 NIL ODEEF (NIL T T) -7 NIL NIL) (-823 2187599 2187688 2187918 "ODECONST" 2188169 NIL ODECONST (NIL T T T) -7 NIL NIL) (-822 2185749 2186384 2186413 "ODECAT" 2187018 T ODECAT (NIL) -9 NIL 2187549) (-821 2182548 2185454 2185576 "OCT" 2185659 NIL OCT (NIL T) -8 NIL NIL) (-820 2182186 2182229 2182356 "OCTCT2" 2182499 NIL OCTCT2 (NIL T T T T) -7 NIL NIL) (-819 2176966 2179454 2179495 "OC" 2180592 NIL OC (NIL T) -9 NIL 2181442) (-818 2174193 2174941 2175931 "OC-" 2176025 NIL OC- (NIL T T) -8 NIL NIL) (-817 2173570 2174012 2174041 "OCAMON" 2174046 T OCAMON (NIL) -9 NIL 2174067) (-816 2173022 2173429 2173458 "OASGP" 2173463 T OASGP (NIL) -9 NIL 2173483) (-815 2172308 2172771 2172800 "OAMONS" 2172840 T OAMONS (NIL) -9 NIL 2172883) (-814 2171747 2172154 2172183 "OAMON" 2172188 T OAMON (NIL) -9 NIL 2172208) (-813 2171050 2171542 2171571 "OAGROUP" 2171576 T OAGROUP (NIL) -9 NIL 2171596) (-812 2170738 2170788 2170877 "NUMTUBE" 2170994 NIL NUMTUBE (NIL T) -7 NIL NIL) (-811 2164311 2165829 2167365 "NUMQUAD" 2169222 T NUMQUAD (NIL) -7 NIL NIL) (-810 2160067 2161055 2162080 "NUMODE" 2163306 T NUMODE (NIL) -7 NIL NIL) (-809 2157447 2158301 2158330 "NUMINT" 2159253 T NUMINT (NIL) -9 NIL 2160017) (-808 2156395 2156592 2156810 "NUMFMT" 2157249 T NUMFMT (NIL) -7 NIL NIL) (-807 2142773 2145715 2148239 "NUMERIC" 2153910 NIL NUMERIC (NIL T) -7 NIL NIL) (-806 2137175 2142220 2142316 "NTSCAT" 2142321 NIL NTSCAT (NIL T T T T) -9 NIL 2142360) (-805 2136371 2136536 2136728 "NTPOLFN" 2137015 NIL NTPOLFN (NIL T) -7 NIL NIL) (-804 2124167 2133198 2134009 "NSUP" 2135593 NIL NSUP (NIL T) -8 NIL NIL) (-803 2123799 2123856 2123965 "NSUP2" 2124104 NIL NSUP2 (NIL T T) -7 NIL NIL) (-802 2113748 2123573 2123706 "NSMP" 2123711 NIL NSMP (NIL T T) -8 NIL NIL) (-801 2101840 2113330 2113494 "NSDPS" 2113616 NIL NSDPS (NIL T) -8 NIL NIL) (-800 2100272 2100573 2100930 "NREP" 2101528 NIL NREP (NIL T) -7 NIL NIL) (-799 2097361 2097909 2098558 "NPOLYGON" 2099714 NIL NPOLYGON (NIL T T T NIL) -7 NIL NIL) (-798 2095952 2096204 2096562 "NPCOEF" 2097104 NIL NPCOEF (NIL T T T T T) -7 NIL NIL) (-797 2095234 2095736 2095820 "NOTTING" 2095900 NIL NOTTING (NIL T) -8 NIL NIL) (-796 2094300 2094415 2094631 "NORMRETR" 2095115 NIL NORMRETR (NIL T T T T NIL) -7 NIL NIL) (-795 2092341 2092631 2093040 "NORMPK" 2094008 NIL NORMPK (NIL T T T T T) -7 NIL NIL) (-794 2092026 2092054 2092178 "NORMMA" 2092307 NIL NORMMA (NIL T T T T) -7 NIL NIL) (-793 2091853 2091983 2092012 "NONE" 2092017 T NONE (NIL) -8 NIL NIL) (-792 2091642 2091671 2091740 "NONE1" 2091817 NIL NONE1 (NIL T) -7 NIL NIL) (-791 2091125 2091187 2091373 "NODE1" 2091574 NIL NODE1 (NIL T T) -7 NIL NIL) (-790 2089419 2090288 2090543 "NNI" 2090890 T NNI (NIL) -8 NIL NIL) (-789 2087839 2088152 2088516 "NLINSOL" 2089087 NIL NLINSOL (NIL T) -7 NIL NIL) (-788 2084007 2084974 2085896 "NIPROB" 2086937 T NIPROB (NIL) -8 NIL NIL) (-787 2082764 2082998 2083300 "NFINTBAS" 2083769 NIL NFINTBAS (NIL T T) -7 NIL NIL) (-786 2082493 2082536 2082617 "NEWTON" 2082715 NIL NEWTON (NIL T) -7 NIL NIL) (-785 2081201 2081432 2081713 "NCODIV" 2082261 NIL NCODIV (NIL T T) -7 NIL NIL) (-784 2080963 2081000 2081075 "NCNTFRAC" 2081158 NIL NCNTFRAC (NIL T) -7 NIL NIL) (-783 2079143 2079507 2079927 "NCEP" 2080588 NIL NCEP (NIL T) -7 NIL NIL) (-782 2078053 2078792 2078821 "NASRING" 2078931 T NASRING (NIL) -9 NIL 2079005) (-781 2077848 2077892 2077986 "NASRING-" 2077991 NIL NASRING- (NIL T) -8 NIL NIL) (-780 2077000 2077499 2077528 "NARNG" 2077645 T NARNG (NIL) -9 NIL 2077736) (-779 2076692 2076759 2076893 "NARNG-" 2076898 NIL NARNG- (NIL T) -8 NIL NIL) (-778 2075571 2075778 2076013 "NAGSP" 2076477 T NAGSP (NIL) -7 NIL NIL) (-777 2066843 2068527 2070200 "NAGS" 2073918 T NAGS (NIL) -7 NIL NIL) (-776 2065391 2065699 2066030 "NAGF07" 2066532 T NAGF07 (NIL) -7 NIL NIL) (-775 2059929 2061220 2062527 "NAGF04" 2064104 T NAGF04 (NIL) -7 NIL NIL) (-774 2052897 2054511 2056144 "NAGF02" 2058316 T NAGF02 (NIL) -7 NIL NIL) (-773 2048121 2049221 2050338 "NAGF01" 2051800 T NAGF01 (NIL) -7 NIL NIL) (-772 2041749 2043315 2044900 "NAGE04" 2046556 T NAGE04 (NIL) -7 NIL NIL) (-771 2032918 2035039 2037169 "NAGE02" 2039639 T NAGE02 (NIL) -7 NIL NIL) (-770 2028871 2029818 2030782 "NAGE01" 2031974 T NAGE01 (NIL) -7 NIL NIL) (-769 2026666 2027200 2027758 "NAGD03" 2028333 T NAGD03 (NIL) -7 NIL NIL) (-768 2018416 2020344 2022298 "NAGD02" 2024732 T NAGD02 (NIL) -7 NIL NIL) (-767 2012227 2013652 2015092 "NAGD01" 2016996 T NAGD01 (NIL) -7 NIL NIL) (-766 2008436 2009258 2010095 "NAGC06" 2011410 T NAGC06 (NIL) -7 NIL NIL) (-765 2006901 2007233 2007589 "NAGC05" 2008100 T NAGC05 (NIL) -7 NIL NIL) (-764 2006277 2006396 2006540 "NAGC02" 2006777 T NAGC02 (NIL) -7 NIL NIL) (-763 2005336 2005893 2005934 "NAALG" 2006013 NIL NAALG (NIL T) -9 NIL 2006074) (-762 2005171 2005200 2005290 "NAALG-" 2005295 NIL NAALG- (NIL T T) -8 NIL NIL) (-761 1996047 2004287 2004562 "MYUP" 2004942 NIL MYUP (NIL NIL T) -8 NIL NIL) (-760 1986410 1994503 1994874 "MYEXPR" 1995742 NIL MYEXPR (NIL NIL T) -8 NIL NIL) (-759 1980360 1981468 1982655 "MULTSQFR" 1985306 NIL MULTSQFR (NIL T T T T) -7 NIL NIL) (-758 1979679 1979754 1979938 "MULTFACT" 1980272 NIL MULTFACT (NIL T T T T) -7 NIL NIL) (-757 1972801 1976710 1976764 "MTSCAT" 1977834 NIL MTSCAT (NIL T T) -9 NIL 1978349) (-756 1972513 1972567 1972659 "MTHING" 1972741 NIL MTHING (NIL T) -7 NIL NIL) (-755 1972305 1972338 1972398 "MSYSCMD" 1972473 T MSYSCMD (NIL) -7 NIL NIL) (-754 1968417 1971060 1971380 "MSET" 1972018 NIL MSET (NIL T) -8 NIL NIL) (-753 1965511 1967977 1968019 "MSETAGG" 1968024 NIL MSETAGG (NIL T) -9 NIL 1968058) (-752 1961289 1962902 1963641 "MRING" 1964817 NIL MRING (NIL T T) -8 NIL NIL) (-751 1960855 1960922 1961053 "MRF2" 1961216 NIL MRF2 (NIL T T T) -7 NIL NIL) (-750 1960473 1960508 1960652 "MRATFAC" 1960814 NIL MRATFAC (NIL T T T T) -7 NIL NIL) (-749 1958085 1958380 1958811 "MPRFF" 1960178 NIL MPRFF (NIL T T T T) -7 NIL NIL) (-748 1952099 1957939 1958036 "MPOLY" 1958041 NIL MPOLY (NIL NIL T) -8 NIL NIL) (-747 1951589 1951624 1951832 "MPCPF" 1952058 NIL MPCPF (NIL T T T T) -7 NIL NIL) (-746 1951103 1951146 1951330 "MPC3" 1951540 NIL MPC3 (NIL T T T T T T T) -7 NIL NIL) (-745 1950298 1950379 1950600 "MPC2" 1951018 NIL MPC2 (NIL T T T T T T T) -7 NIL NIL) (-744 1948599 1948936 1949326 "MONOTOOL" 1949958 NIL MONOTOOL (NIL T T) -7 NIL NIL) (-743 1947722 1948057 1948086 "MONOID" 1948363 T MONOID (NIL) -9 NIL 1948535) (-742 1947100 1947263 1947506 "MONOID-" 1947511 NIL MONOID- (NIL T) -8 NIL NIL) (-741 1937926 1943956 1944016 "MONOGEN" 1944690 NIL MONOGEN (NIL T T) -9 NIL 1945143) (-740 1935144 1935879 1936879 "MONOGEN-" 1936998 NIL MONOGEN- (NIL T T T) -8 NIL NIL) (-739 1934002 1934422 1934451 "MONADWU" 1934843 T MONADWU (NIL) -9 NIL 1935081) (-738 1933374 1933533 1933781 "MONADWU-" 1933786 NIL MONADWU- (NIL T) -8 NIL NIL) (-737 1932758 1932976 1933005 "MONAD" 1933212 T MONAD (NIL) -9 NIL 1933324) (-736 1932443 1932521 1932653 "MONAD-" 1932658 NIL MONAD- (NIL T) -8 NIL NIL) (-735 1930694 1931356 1931635 "MOEBIUS" 1932196 NIL MOEBIUS (NIL T) -8 NIL NIL) (-734 1930085 1930463 1930504 "MODULE" 1930509 NIL MODULE (NIL T) -9 NIL 1930535) (-733 1929653 1929749 1929939 "MODULE-" 1929944 NIL MODULE- (NIL T T) -8 NIL NIL) (-732 1927322 1928017 1928344 "MODRING" 1929477 NIL MODRING (NIL T T NIL NIL NIL) -8 NIL NIL) (-731 1924268 1925433 1925951 "MODOP" 1926854 NIL MODOP (NIL T T) -8 NIL NIL) (-730 1922455 1922907 1923248 "MODMONOM" 1924067 NIL MODMONOM (NIL T T NIL) -8 NIL NIL) (-729 1912075 1920651 1921072 "MODMON" 1922085 NIL MODMON (NIL T T) -8 NIL NIL) (-728 1909201 1910919 1911195 "MODFIELD" 1911950 NIL MODFIELD (NIL T T NIL NIL NIL) -8 NIL NIL) (-727 1908205 1908482 1908672 "MMLFORM" 1909031 T MMLFORM (NIL) -8 NIL NIL) (-726 1907731 1907774 1907953 "MMAP" 1908156 NIL MMAP (NIL T T T T T T) -7 NIL NIL) (-725 1905956 1906733 1906775 "MLO" 1907198 NIL MLO (NIL T) -9 NIL 1907439) (-724 1903323 1903838 1904440 "MLIFT" 1905437 NIL MLIFT (NIL T T T T) -7 NIL NIL) (-723 1902714 1902798 1902952 "MKUCFUNC" 1903234 NIL MKUCFUNC (NIL T T T) -7 NIL NIL) (-722 1902313 1902383 1902506 "MKRECORD" 1902637 NIL MKRECORD (NIL T T) -7 NIL NIL) (-721 1901361 1901522 1901750 "MKFUNC" 1902124 NIL MKFUNC (NIL T) -7 NIL NIL) (-720 1900749 1900853 1901009 "MKFLCFN" 1901244 NIL MKFLCFN (NIL T) -7 NIL NIL) (-719 1900175 1900542 1900631 "MKCHSET" 1900693 NIL MKCHSET (NIL T) -8 NIL NIL) (-718 1899452 1899554 1899739 "MKBCFUNC" 1900068 NIL MKBCFUNC (NIL T T T T) -7 NIL NIL) (-717 1896136 1899006 1899142 "MINT" 1899336 T MINT (NIL) -8 NIL NIL) (-716 1894948 1895191 1895468 "MHROWRED" 1895891 NIL MHROWRED (NIL T) -7 NIL NIL) (-715 1890215 1893389 1893815 "MFLOAT" 1894542 T MFLOAT (NIL) -8 NIL NIL) (-714 1889572 1889648 1889819 "MFINFACT" 1890127 NIL MFINFACT (NIL T T T T) -7 NIL NIL) (-713 1885887 1886735 1887619 "MESH" 1888708 T MESH (NIL) -7 NIL NIL) (-712 1884277 1884589 1884942 "MDDFACT" 1885574 NIL MDDFACT (NIL T) -7 NIL NIL) (-711 1881159 1883470 1883512 "MDAGG" 1883767 NIL MDAGG (NIL T) -9 NIL 1883910) (-710 1870800 1880452 1880659 "MCMPLX" 1880972 T MCMPLX (NIL) -8 NIL NIL) (-709 1869937 1870083 1870284 "MCDEN" 1870649 NIL MCDEN (NIL T T) -7 NIL NIL) (-708 1867827 1868097 1868477 "MCALCFN" 1869667 NIL MCALCFN (NIL T T T T) -7 NIL NIL) (-707 1865439 1865962 1866524 "MATSTOR" 1867298 NIL MATSTOR (NIL T) -7 NIL NIL) (-706 1861305 1864815 1865061 "MATRIX" 1865226 NIL MATRIX (NIL T) -8 NIL NIL) (-705 1857081 1857784 1858517 "MATLIN" 1860665 NIL MATLIN (NIL T T T T) -7 NIL NIL) (-704 1846592 1849860 1849938 "MATCAT" 1855220 NIL MATCAT (NIL T T T) -9 NIL 1856782) (-703 1842630 1843745 1845213 "MATCAT-" 1845218 NIL MATCAT- (NIL T T T T) -8 NIL NIL) (-702 1841224 1841377 1841710 "MATCAT2" 1842465 NIL MATCAT2 (NIL T T T T T T T T) -7 NIL NIL) (-701 1839964 1840230 1840545 "MAPPKG4" 1840955 NIL MAPPKG4 (NIL T T) -7 NIL NIL) (-700 1838076 1838400 1838784 "MAPPKG3" 1839639 NIL MAPPKG3 (NIL T T T) -7 NIL NIL) (-699 1837057 1837230 1837452 "MAPPKG2" 1837900 NIL MAPPKG2 (NIL T T) -7 NIL NIL) (-698 1835556 1835840 1836167 "MAPPKG1" 1836763 NIL MAPPKG1 (NIL T) -7 NIL NIL) (-697 1835167 1835225 1835348 "MAPHACK3" 1835492 NIL MAPHACK3 (NIL T T T) -7 NIL NIL) (-696 1834759 1834820 1834934 "MAPHACK2" 1835099 NIL MAPHACK2 (NIL T T) -7 NIL NIL) (-695 1834197 1834300 1834442 "MAPHACK1" 1834650 NIL MAPHACK1 (NIL T) -7 NIL NIL) (-694 1827365 1828306 1829403 "MAMA" 1833193 NIL MAMA (NIL T T T T) -7 NIL NIL) (-693 1825471 1826065 1826369 "MAGMA" 1827093 NIL MAGMA (NIL T) -8 NIL NIL) (-692 1823707 1824079 1824134 "MAGCDOC" 1825071 NIL MAGCDOC (NIL T T) -9 NIL NIL) (-691 1820182 1821948 1822408 "M3D" 1823280 NIL M3D (NIL T) -8 NIL NIL) (-690 1814376 1818582 1818624 "LZSTAGG" 1819406 NIL LZSTAGG (NIL T) -9 NIL 1819701) (-689 1810350 1811507 1812964 "LZSTAGG-" 1812969 NIL LZSTAGG- (NIL T T) -8 NIL NIL) (-688 1807464 1808241 1808728 "LWORD" 1809895 NIL LWORD (NIL T) -8 NIL NIL) (-687 1800619 1807235 1807369 "LSQM" 1807374 NIL LSQM (NIL NIL T) -8 NIL NIL) (-686 1799843 1799982 1800210 "LSPP" 1800474 NIL LSPP (NIL T T T T) -7 NIL NIL) (-685 1797655 1797956 1798412 "LSMP" 1799532 NIL LSMP (NIL T T T T) -7 NIL NIL) (-684 1794434 1795108 1795838 "LSMP1" 1796957 NIL LSMP1 (NIL T) -7 NIL NIL) (-683 1788391 1793624 1793666 "LSAGG" 1793728 NIL LSAGG (NIL T) -9 NIL 1793806) (-682 1785086 1786010 1787223 "LSAGG-" 1787228 NIL LSAGG- (NIL T T) -8 NIL NIL) (-681 1782712 1784230 1784479 "LPOLY" 1784881 NIL LPOLY (NIL T T) -8 NIL NIL) (-680 1782294 1782379 1782502 "LPEFRAC" 1782621 NIL LPEFRAC (NIL T) -7 NIL NIL) (-679 1779858 1780107 1780539 "LPARSPT" 1782036 NIL LPARSPT (NIL T NIL T T T T T) -7 NIL NIL) (-678 1778762 1779402 1779431 "LORER" 1779545 T LORER (NIL) -9 NIL 1779643) (-677 1777237 1777564 1777924 "LOP" 1778434 NIL LOP (NIL T) -7 NIL NIL) (-676 1775586 1776333 1776585 "LO" 1777070 NIL LO (NIL T T T) -8 NIL NIL) (-675 1775237 1775349 1775378 "LOGIC" 1775489 T LOGIC (NIL) -9 NIL 1775570) (-674 1775099 1775122 1775193 "LOGIC-" 1775198 NIL LOGIC- (NIL T) -8 NIL NIL) (-673 1774292 1774432 1774625 "LODOOPS" 1774955 NIL LODOOPS (NIL T T) -7 NIL NIL) (-672 1771704 1774208 1774274 "LODO" 1774279 NIL LODO (NIL T NIL) -8 NIL NIL) (-671 1770244 1770479 1770831 "LODOF" 1771452 NIL LODOF (NIL T T) -7 NIL NIL) (-670 1766643 1769084 1769126 "LODOCAT" 1769564 NIL LODOCAT (NIL T) -9 NIL 1769774) (-669 1766376 1766434 1766561 "LODOCAT-" 1766566 NIL LODOCAT- (NIL T T) -8 NIL NIL) (-668 1763685 1766217 1766335 "LODO2" 1766340 NIL LODO2 (NIL T T) -8 NIL NIL) (-667 1761109 1763622 1763667 "LODO1" 1763672 NIL LODO1 (NIL T) -8 NIL NIL) (-666 1759969 1760134 1760446 "LODEEF" 1760932 NIL LODEEF (NIL T T T) -7 NIL NIL) (-665 1752782 1756947 1756988 "LOCPOWC" 1758450 NIL LOCPOWC (NIL T) -9 NIL 1759027) (-664 1748106 1750944 1750986 "LNAGG" 1751933 NIL LNAGG (NIL T) -9 NIL 1752376) (-663 1747253 1747467 1747809 "LNAGG-" 1747814 NIL LNAGG- (NIL T T) -8 NIL NIL) (-662 1743416 1744178 1744817 "LMOPS" 1746668 NIL LMOPS (NIL T T NIL) -8 NIL NIL) (-661 1742810 1743172 1743214 "LMODULE" 1743275 NIL LMODULE (NIL T) -9 NIL 1743317) (-660 1740062 1742455 1742578 "LMDICT" 1742720 NIL LMDICT (NIL T) -8 NIL NIL) (-659 1739219 1739353 1739540 "LISYSER" 1739924 NIL LISYSER (NIL T T) -7 NIL NIL) (-658 1732456 1738169 1738465 "LIST" 1738956 NIL LIST (NIL T) -8 NIL NIL) (-657 1731981 1732055 1732194 "LIST3" 1732376 NIL LIST3 (NIL T T T) -7 NIL NIL) (-656 1730988 1731166 1731394 "LIST2" 1731799 NIL LIST2 (NIL T T) -7 NIL NIL) (-655 1729122 1729434 1729833 "LIST2MAP" 1730635 NIL LIST2MAP (NIL T T) -7 NIL NIL) (-654 1727827 1728507 1728549 "LINEXP" 1728804 NIL LINEXP (NIL T) -9 NIL 1728953) (-653 1726474 1726734 1727031 "LINDEP" 1727579 NIL LINDEP (NIL T T) -7 NIL NIL) (-652 1723241 1723960 1724737 "LIMITRF" 1725729 NIL LIMITRF (NIL T) -7 NIL NIL) (-651 1721517 1721812 1722228 "LIMITPS" 1722936 NIL LIMITPS (NIL T T) -7 NIL NIL) (-650 1715976 1721032 1721258 "LIE" 1721340 NIL LIE (NIL T T) -8 NIL NIL) (-649 1715025 1715468 1715509 "LIECAT" 1715649 NIL LIECAT (NIL T) -9 NIL 1715799) (-648 1714866 1714893 1714981 "LIECAT-" 1714986 NIL LIECAT- (NIL T T) -8 NIL NIL) (-647 1707400 1714245 1714428 "LIB" 1714703 T LIB (NIL) -8 NIL NIL) (-646 1703037 1703918 1704853 "LGROBP" 1706517 NIL LGROBP (NIL NIL T) -7 NIL NIL) (-645 1700518 1700842 1701253 "LF" 1702710 NIL LF (NIL T T) -7 NIL NIL) (-644 1699214 1699944 1699973 "LFCAT" 1700248 T LFCAT (NIL) -9 NIL 1700423) (-643 1696118 1696746 1697434 "LEXTRIPK" 1698578 NIL LEXTRIPK (NIL T NIL) -7 NIL NIL) (-642 1692824 1693688 1694191 "LEXP" 1695698 NIL LEXP (NIL T T NIL) -8 NIL NIL) (-641 1691222 1691535 1691936 "LEADCDET" 1692506 NIL LEADCDET (NIL T T T T) -7 NIL NIL) (-640 1690412 1690486 1690715 "LAZM3PK" 1691143 NIL LAZM3PK (NIL T T T T T T) -7 NIL NIL) (-639 1685328 1688495 1689030 "LAUPOL" 1689927 NIL LAUPOL (NIL T T) -8 NIL NIL) (-638 1684893 1684937 1685105 "LAPLACE" 1685278 NIL LAPLACE (NIL T T) -7 NIL NIL) (-637 1682823 1683996 1684246 "LA" 1684727 NIL LA (NIL T T T) -8 NIL NIL) (-636 1681879 1682473 1682515 "LALG" 1682577 NIL LALG (NIL T) -9 NIL 1682636) (-635 1681593 1681652 1681788 "LALG-" 1681793 NIL LALG- (NIL T T) -8 NIL NIL) (-634 1680497 1680684 1680983 "KOVACIC" 1681393 NIL KOVACIC (NIL T T) -7 NIL NIL) (-633 1680331 1680355 1680397 "KONVERT" 1680459 NIL KONVERT (NIL T) -9 NIL NIL) (-632 1680165 1680189 1680231 "KOERCE" 1680293 NIL KOERCE (NIL T) -9 NIL NIL) (-631 1677901 1678661 1679053 "KERNEL" 1679805 NIL KERNEL (NIL T) -8 NIL NIL) (-630 1677403 1677484 1677614 "KERNEL2" 1677815 NIL KERNEL2 (NIL T T) -7 NIL NIL) (-629 1671086 1675768 1675823 "KDAGG" 1676200 NIL KDAGG (NIL T T) -9 NIL 1676406) (-628 1670615 1670739 1670944 "KDAGG-" 1670949 NIL KDAGG- (NIL T T T) -8 NIL NIL) (-627 1663764 1670276 1670431 "KAFILE" 1670493 NIL KAFILE (NIL T) -8 NIL NIL) (-626 1658223 1663279 1663505 "JORDAN" 1663587 NIL JORDAN (NIL T T) -8 NIL NIL) (-625 1654566 1656466 1656521 "IXAGG" 1657450 NIL IXAGG (NIL T T) -9 NIL 1657905) (-624 1653485 1653791 1654210 "IXAGG-" 1654215 NIL IXAGG- (NIL T T T) -8 NIL NIL) (-623 1649069 1653407 1653466 "IVECTOR" 1653471 NIL IVECTOR (NIL T NIL) -8 NIL NIL) (-622 1647835 1648072 1648338 "ITUPLE" 1648836 NIL ITUPLE (NIL T) -8 NIL NIL) (-621 1646259 1646436 1646744 "ITRIGMNP" 1647657 NIL ITRIGMNP (NIL T T T) -7 NIL NIL) (-620 1645004 1645208 1645491 "ITFUN3" 1646035 NIL ITFUN3 (NIL T T T) -7 NIL NIL) (-619 1644636 1644693 1644802 "ITFUN2" 1644941 NIL ITFUN2 (NIL T T) -7 NIL NIL) (-618 1642429 1643500 1643798 "ITAYLOR" 1644371 NIL ITAYLOR (NIL T) -8 NIL NIL) (-617 1631368 1636568 1637730 "ISUPS" 1641300 NIL ISUPS (NIL T) -8 NIL NIL) (-616 1630472 1630612 1630848 "ISUMP" 1631215 NIL ISUMP (NIL T T T T) -7 NIL NIL) (-615 1625742 1630273 1630352 "ISTRING" 1630425 NIL ISTRING (NIL NIL) -8 NIL NIL) (-614 1624952 1625033 1625249 "IRURPK" 1625656 NIL IRURPK (NIL T T T T T) -7 NIL NIL) (-613 1623888 1624089 1624329 "IRSN" 1624732 T IRSN (NIL) -7 NIL NIL) (-612 1621919 1622274 1622709 "IRRF2F" 1623527 NIL IRRF2F (NIL T) -7 NIL NIL) (-611 1621666 1621704 1621780 "IRREDFFX" 1621875 NIL IRREDFFX (NIL T) -7 NIL NIL) (-610 1620281 1620540 1620839 "IROOT" 1621399 NIL IROOT (NIL T) -7 NIL NIL) (-609 1616917 1617969 1618659 "IR" 1619623 NIL IR (NIL T) -8 NIL NIL) (-608 1614530 1615025 1615591 "IR2" 1616395 NIL IR2 (NIL T T) -7 NIL NIL) (-607 1613602 1613715 1613936 "IR2F" 1614413 NIL IR2F (NIL T T) -7 NIL NIL) (-606 1613393 1613427 1613487 "IPRNTPK" 1613562 T IPRNTPK (NIL) -7 NIL NIL) (-605 1609922 1613282 1613351 "IPF" 1613356 NIL IPF (NIL NIL) -8 NIL NIL) (-604 1608239 1609847 1609904 "IPADIC" 1609909 NIL IPADIC (NIL NIL NIL) -8 NIL NIL) (-603 1607736 1607794 1607984 "INVLAPLA" 1608175 NIL INVLAPLA (NIL T T) -7 NIL NIL) (-602 1597385 1599738 1602124 "INTTR" 1605400 NIL INTTR (NIL T T) -7 NIL NIL) (-601 1593743 1594485 1595342 "INTTOOLS" 1596577 NIL INTTOOLS (NIL T T) -7 NIL NIL) (-600 1593329 1593420 1593537 "INTSLPE" 1593646 T INTSLPE (NIL) -7 NIL NIL) (-599 1591279 1593252 1593311 "INTRVL" 1593316 NIL INTRVL (NIL T) -8 NIL NIL) (-598 1588881 1589393 1589968 "INTRF" 1590764 NIL INTRF (NIL T) -7 NIL NIL) (-597 1588292 1588389 1588531 "INTRET" 1588779 NIL INTRET (NIL T) -7 NIL NIL) (-596 1586289 1586678 1587148 "INTRAT" 1587900 NIL INTRAT (NIL T T) -7 NIL NIL) (-595 1583525 1584108 1584730 "INTPM" 1585778 NIL INTPM (NIL T T) -7 NIL NIL) (-594 1580230 1580829 1581573 "INTPAF" 1582912 NIL INTPAF (NIL T T T) -7 NIL NIL) (-593 1575409 1576371 1577422 "INTPACK" 1579199 T INTPACK (NIL) -7 NIL NIL) (-592 1572186 1575138 1575265 "INT" 1575302 T INT (NIL) -8 NIL NIL) (-591 1571438 1571590 1571798 "INTHERTR" 1572028 NIL INTHERTR (NIL T T) -7 NIL NIL) (-590 1570877 1570957 1571145 "INTHERAL" 1571352 NIL INTHERAL (NIL T T T T) -7 NIL NIL) (-589 1568723 1569166 1569623 "INTHEORY" 1570440 T INTHEORY (NIL) -7 NIL NIL) (-588 1560034 1561654 1563432 "INTG0" 1567076 NIL INTG0 (NIL T T T) -7 NIL NIL) (-587 1540607 1545397 1550207 "INTFTBL" 1555244 T INTFTBL (NIL) -8 NIL NIL) (-586 1538644 1538851 1539252 "INTFRSP" 1540397 NIL INTFRSP (NIL T NIL T T T T T T) -7 NIL NIL) (-585 1537893 1538031 1538204 "INTFACT" 1538503 NIL INTFACT (NIL T) -7 NIL NIL) (-584 1537483 1537525 1537676 "INTERGB" 1537845 NIL INTERGB (NIL T NIL T T T) -7 NIL NIL) (-583 1534868 1535314 1535878 "INTEF" 1537037 NIL INTEF (NIL T T) -7 NIL NIL) (-582 1533325 1534074 1534103 "INTDOM" 1534404 T INTDOM (NIL) -9 NIL 1534611) (-581 1532694 1532868 1533110 "INTDOM-" 1533115 NIL INTDOM- (NIL T) -8 NIL NIL) (-580 1531298 1531403 1531793 "INTDIVP" 1532584 NIL INTDIVP (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-579 1527770 1529700 1529755 "INTCAT" 1530554 NIL INTCAT (NIL T) -9 NIL 1530875) (-578 1527243 1527345 1527473 "INTBIT" 1527662 T INTBIT (NIL) -7 NIL NIL) (-577 1525914 1526068 1526382 "INTALG" 1527088 NIL INTALG (NIL T T T T T) -7 NIL NIL) (-576 1525371 1525461 1525631 "INTAF" 1525818 NIL INTAF (NIL T T) -7 NIL NIL) (-575 1518837 1525181 1525321 "INTABL" 1525326 NIL INTABL (NIL T T T) -8 NIL NIL) (-574 1513692 1516495 1516524 "INS" 1517492 T INS (NIL) -9 NIL 1518175) (-573 1510932 1511703 1512677 "INS-" 1512750 NIL INS- (NIL T) -8 NIL NIL) (-572 1509707 1509934 1510232 "INPSIGN" 1510685 NIL INPSIGN (NIL T T) -7 NIL NIL) (-571 1508825 1508942 1509139 "INPRODPF" 1509587 NIL INPRODPF (NIL T T) -7 NIL NIL) (-570 1507719 1507836 1508073 "INPRODFF" 1508705 NIL INPRODFF (NIL T T T T) -7 NIL NIL) (-569 1506719 1506871 1507131 "INNMFACT" 1507555 NIL INNMFACT (NIL T T T T) -7 NIL NIL) (-568 1505916 1506013 1506201 "INMODGCD" 1506618 NIL INMODGCD (NIL T T NIL NIL) -7 NIL NIL) (-567 1504425 1504669 1504993 "INFSP" 1505661 NIL INFSP (NIL T T T) -7 NIL NIL) (-566 1503609 1503726 1503909 "INFPROD0" 1504305 NIL INFPROD0 (NIL T T) -7 NIL NIL) (-565 1500490 1501674 1502189 "INFORM" 1503102 T INFORM (NIL) -8 NIL NIL) (-564 1500100 1500160 1500258 "INFORM1" 1500425 NIL INFORM1 (NIL T) -7 NIL NIL) (-563 1499623 1499712 1499826 "INFINITY" 1500006 T INFINITY (NIL) -7 NIL NIL) (-562 1497306 1498303 1498646 "INFCLSPT" 1499483 NIL INFCLSPT (NIL T NIL T T T T T T T) -8 NIL NIL) (-561 1495183 1496428 1496722 "INFCLSPS" 1497076 NIL INFCLSPS (NIL T NIL T) -8 NIL NIL) (-560 1487733 1488656 1488877 "INFCLCT" 1494308 NIL INFCLCT (NIL T NIL T T T T T T T) -9 NIL 1495119) (-559 1486351 1486599 1486920 "INEP" 1487481 NIL INEP (NIL T T T) -7 NIL NIL) (-558 1485627 1486248 1486313 "INDE" 1486318 NIL INDE (NIL T) -8 NIL NIL) (-557 1485191 1485259 1485376 "INCRMAPS" 1485554 NIL INCRMAPS (NIL T) -7 NIL NIL) (-556 1480502 1481427 1482371 "INBFF" 1484279 NIL INBFF (NIL T) -7 NIL NIL) (-555 1476849 1480346 1480450 "IMATRIX" 1480455 NIL IMATRIX (NIL T NIL NIL) -8 NIL NIL) (-554 1475559 1475682 1475997 "IMATQF" 1476706 NIL IMATQF (NIL T T T T T T T T) -7 NIL NIL) (-553 1473781 1474008 1474344 "IMATLIN" 1475316 NIL IMATLIN (NIL T T T T) -7 NIL NIL) (-552 1468413 1473705 1473763 "ILIST" 1473768 NIL ILIST (NIL T NIL) -8 NIL NIL) (-551 1466372 1468273 1468386 "IIARRAY2" 1468391 NIL IIARRAY2 (NIL T NIL NIL T T) -8 NIL NIL) (-550 1461688 1466283 1466347 "IFF" 1466352 NIL IFF (NIL NIL NIL) -8 NIL NIL) (-549 1456737 1460980 1461168 "IFARRAY" 1461545 NIL IFARRAY (NIL T NIL) -8 NIL NIL) (-548 1455944 1456641 1456714 "IFAMON" 1456719 NIL IFAMON (NIL T T NIL) -8 NIL NIL) (-547 1455527 1455592 1455647 "IEVALAB" 1455854 NIL IEVALAB (NIL T T) -9 NIL NIL) (-546 1455202 1455270 1455430 "IEVALAB-" 1455435 NIL IEVALAB- (NIL T T T) -8 NIL NIL) (-545 1454860 1455116 1455179 "IDPO" 1455184 NIL IDPO (NIL T T) -8 NIL NIL) (-544 1454137 1454749 1454824 "IDPOAMS" 1454829 NIL IDPOAMS (NIL T T) -8 NIL NIL) (-543 1453471 1454026 1454101 "IDPOAM" 1454106 NIL IDPOAM (NIL T T) -8 NIL NIL) (-542 1452555 1452805 1452859 "IDPC" 1453272 NIL IDPC (NIL T T) -9 NIL 1453421) (-541 1452051 1452447 1452520 "IDPAM" 1452525 NIL IDPAM (NIL T T) -8 NIL NIL) (-540 1451454 1451943 1452016 "IDPAG" 1452021 NIL IDPAG (NIL T T) -8 NIL NIL) (-539 1447709 1448557 1449452 "IDECOMP" 1450611 NIL IDECOMP (NIL NIL NIL) -7 NIL NIL) (-538 1440585 1441634 1442680 "IDEAL" 1446746 NIL IDEAL (NIL T T T T) -8 NIL NIL) (-537 1438602 1439749 1440022 "ICP" 1440376 NIL ICP (NIL T NIL T) -8 NIL NIL) (-536 1437762 1437874 1438074 "ICDEN" 1438486 NIL ICDEN (NIL T T T T) -7 NIL NIL) (-535 1436861 1437242 1437389 "ICARD" 1437635 T ICARD (NIL) -8 NIL NIL) (-534 1434921 1435234 1435639 "IBPTOOLS" 1436538 NIL IBPTOOLS (NIL T T T T) -7 NIL NIL) (-533 1430535 1434541 1434654 "IBITS" 1434840 NIL IBITS (NIL NIL) -8 NIL NIL) (-532 1427258 1427834 1428529 "IBATOOL" 1429952 NIL IBATOOL (NIL T T T) -7 NIL NIL) (-531 1425038 1425499 1426032 "IBACHIN" 1426793 NIL IBACHIN (NIL T T T) -7 NIL NIL) (-530 1422921 1424884 1424987 "IARRAY2" 1424992 NIL IARRAY2 (NIL T NIL NIL) -8 NIL NIL) (-529 1419080 1422847 1422904 "IARRAY1" 1422909 NIL IARRAY1 (NIL T NIL) -8 NIL NIL) (-528 1413010 1417492 1417973 "IAN" 1418619 T IAN (NIL) -8 NIL NIL) (-527 1412521 1412578 1412751 "IALGFACT" 1412947 NIL IALGFACT (NIL T T T T) -7 NIL NIL) (-526 1412048 1412161 1412190 "HYPCAT" 1412397 T HYPCAT (NIL) -9 NIL NIL) (-525 1411586 1411703 1411889 "HYPCAT-" 1411894 NIL HYPCAT- (NIL T) -8 NIL NIL) (-524 1410590 1410867 1411057 "HTMLFORM" 1411416 T HTMLFORM (NIL) -8 NIL NIL) (-523 1407379 1408704 1408746 "HOAGG" 1409727 NIL HOAGG (NIL T) -9 NIL 1410336) (-522 1405973 1406372 1406898 "HOAGG-" 1406903 NIL HOAGG- (NIL T T) -8 NIL NIL) (-521 1399789 1405409 1405577 "HEXADEC" 1405825 T HEXADEC (NIL) -8 NIL NIL) (-520 1398537 1398759 1399022 "HEUGCD" 1399566 NIL HEUGCD (NIL T) -7 NIL NIL) (-519 1397640 1398374 1398504 "HELLFDIV" 1398509 NIL HELLFDIV (NIL T T T T) -8 NIL NIL) (-518 1391357 1392900 1393981 "HEAP" 1396591 NIL HEAP (NIL T) -8 NIL NIL) (-517 1385152 1391272 1391334 "HDP" 1391339 NIL HDP (NIL NIL T) -8 NIL NIL) (-516 1378857 1384787 1384939 "HDMP" 1385053 NIL HDMP (NIL NIL T) -8 NIL NIL) (-515 1378182 1378321 1378485 "HB" 1378713 T HB (NIL) -7 NIL NIL) (-514 1371691 1378028 1378132 "HASHTBL" 1378137 NIL HASHTBL (NIL T T NIL) -8 NIL NIL) (-513 1369438 1371313 1371495 "HACKPI" 1371529 T HACKPI (NIL) -8 NIL NIL) (-512 1351586 1355455 1359458 "GUESSUP" 1365468 NIL GUESSUP (NIL NIL) -7 NIL NIL) (-511 1322683 1329724 1336420 "GUESSP" 1344910 T GUESSP (NIL) -7 NIL NIL) (-510 1289498 1294769 1300153 "GUESS" 1317627 NIL GUESS (NIL T T T T NIL NIL) -7 NIL NIL) (-509 1263003 1269400 1275536 "GUESSINT" 1283382 T GUESSINT (NIL) -7 NIL NIL) (-508 1238374 1243824 1249391 "GUESSF" 1257488 NIL GUESSF (NIL T) -7 NIL NIL) (-507 1238096 1238133 1238228 "GUESSF1" 1238331 NIL GUESSF1 (NIL T) -7 NIL NIL) (-506 1214257 1219791 1225406 "GUESSAN" 1232501 T GUESSAN (NIL) -7 NIL NIL) (-505 1209952 1214110 1214223 "GTSET" 1214228 NIL GTSET (NIL T T T T) -8 NIL NIL) (-504 1203490 1209830 1209928 "GSTBL" 1209933 NIL GSTBL (NIL T T T NIL) -8 NIL NIL) (-503 1195720 1202523 1202787 "GSERIES" 1203282 NIL GSERIES (NIL T NIL NIL) -8 NIL NIL) (-502 1194741 1195194 1195223 "GROUP" 1195484 T GROUP (NIL) -9 NIL 1195643) (-501 1193857 1194080 1194424 "GROUP-" 1194429 NIL GROUP- (NIL T) -8 NIL NIL) (-500 1192226 1192545 1192932 "GROEBSOL" 1193534 NIL GROEBSOL (NIL NIL T T) -7 NIL NIL) (-499 1191165 1191427 1191479 "GRMOD" 1192008 NIL GRMOD (NIL T T) -9 NIL 1192176) (-498 1190933 1190969 1191097 "GRMOD-" 1191102 NIL GRMOD- (NIL T T T) -8 NIL NIL) (-497 1186262 1187287 1188287 "GRIMAGE" 1189953 T GRIMAGE (NIL) -8 NIL NIL) (-496 1184729 1184989 1185313 "GRDEF" 1185958 T GRDEF (NIL) -7 NIL NIL) (-495 1184173 1184289 1184430 "GRAY" 1184608 T GRAY (NIL) -7 NIL NIL) (-494 1183403 1183783 1183835 "GRALG" 1183988 NIL GRALG (NIL T T) -9 NIL 1184081) (-493 1183064 1183137 1183300 "GRALG-" 1183305 NIL GRALG- (NIL T T T) -8 NIL NIL) (-492 1179866 1182647 1182826 "GPOLSET" 1182970 NIL GPOLSET (NIL T T T T) -8 NIL NIL) (-491 1162069 1163559 1165148 "GPAFF" 1178557 NIL GPAFF (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-490 1161423 1161480 1161738 "GOSPER" 1162006 NIL GOSPER (NIL T T T T T) -7 NIL NIL) (-489 1157773 1158609 1159336 "GOPT" 1160716 T GOPT (NIL) -8 NIL NIL) (-488 1153252 1154270 1155178 "GOPT0" 1156885 T GOPT0 (NIL) -8 NIL NIL) (-487 1149011 1149690 1150216 "GMODPOL" 1152951 NIL GMODPOL (NIL NIL T T T NIL T) -8 NIL NIL) (-486 1148016 1148200 1148438 "GHENSEL" 1148823 NIL GHENSEL (NIL T T) -7 NIL NIL) (-485 1142067 1142910 1143937 "GENUPS" 1147100 NIL GENUPS (NIL T T) -7 NIL NIL) (-484 1141764 1141815 1141904 "GENUFACT" 1142010 NIL GENUFACT (NIL T) -7 NIL NIL) (-483 1141176 1141253 1141418 "GENPGCD" 1141682 NIL GENPGCD (NIL T T T T) -7 NIL NIL) (-482 1140650 1140685 1140898 "GENMFACT" 1141135 NIL GENMFACT (NIL T T T T T) -7 NIL NIL) (-481 1139218 1139473 1139780 "GENEEZ" 1140393 NIL GENEEZ (NIL T T) -7 NIL NIL) (-480 1137762 1138039 1138363 "GDRAW" 1138914 T GDRAW (NIL) -7 NIL NIL) (-479 1131629 1137373 1137535 "GDMP" 1137685 NIL GDMP (NIL NIL T T) -8 NIL NIL) (-478 1121013 1125402 1126507 "GCNAALG" 1130613 NIL GCNAALG (NIL T NIL NIL NIL) -8 NIL NIL) (-477 1119334 1120282 1120311 "GCDDOM" 1120566 T GCDDOM (NIL) -9 NIL 1120730) (-476 1118548 1118751 1119056 "GCDDOM-" 1119061 NIL GCDDOM- (NIL T) -8 NIL NIL) (-475 1117222 1117407 1117710 "GB" 1118328 NIL GB (NIL T T T T) -7 NIL NIL) (-474 1105842 1108168 1110560 "GBINTERN" 1114913 NIL GBINTERN (NIL T T T T) -7 NIL NIL) (-473 1103679 1103971 1104392 "GBF" 1105517 NIL GBF (NIL T T T T) -7 NIL NIL) (-472 1102460 1102625 1102892 "GBEUCLID" 1103495 NIL GBEUCLID (NIL T T T T) -7 NIL NIL) (-471 1101809 1101934 1102083 "GAUSSFAC" 1102331 T GAUSSFAC (NIL) -7 NIL NIL) (-470 1100178 1100480 1100793 "GALUTIL" 1101529 NIL GALUTIL (NIL T) -7 NIL NIL) (-469 1098486 1098760 1099084 "GALPOLYU" 1099905 NIL GALPOLYU (NIL T T) -7 NIL NIL) (-468 1095851 1096141 1096548 "GALFACTU" 1098183 NIL GALFACTU (NIL T T T) -7 NIL NIL) (-467 1087657 1089156 1090764 "GALFACT" 1094283 NIL GALFACT (NIL T) -7 NIL NIL) (-466 1085045 1085702 1085731 "FVFUN" 1086887 T FVFUN (NIL) -9 NIL 1087607) (-465 1084311 1084492 1084521 "FVC" 1084812 T FVC (NIL) -9 NIL 1084995) (-464 1083953 1084108 1084189 "FUNCTION" 1084263 NIL FUNCTION (NIL NIL) -8 NIL NIL) (-463 1081623 1082174 1082663 "FT" 1083484 T FT (NIL) -8 NIL NIL) (-462 1080415 1080924 1081127 "FTEM" 1081440 T FTEM (NIL) -8 NIL NIL) (-461 1078673 1078962 1079365 "FSUPFACT" 1080107 NIL FSUPFACT (NIL T T T) -7 NIL NIL) (-460 1077070 1077359 1077691 "FST" 1078361 T FST (NIL) -8 NIL NIL) (-459 1076241 1076347 1076542 "FSRED" 1076952 NIL FSRED (NIL T T) -7 NIL NIL) (-458 1074922 1075177 1075530 "FSPRMELT" 1075957 NIL FSPRMELT (NIL T T) -7 NIL NIL) (-457 1070288 1070993 1071750 "FSPECF" 1074227 NIL FSPECF (NIL T T) -7 NIL NIL) (-456 1052519 1061108 1061149 "FS" 1064997 NIL FS (NIL T) -9 NIL 1067275) (-455 1041169 1044159 1048215 "FS-" 1048512 NIL FS- (NIL T T) -8 NIL NIL) (-454 1040683 1040737 1040914 "FSINT" 1041110 NIL FSINT (NIL T T) -7 NIL NIL) (-453 1038968 1039680 1039981 "FSERIES" 1040464 NIL FSERIES (NIL T T) -8 NIL NIL) (-452 1037982 1038098 1038329 "FSCINT" 1038848 NIL FSCINT (NIL T T) -7 NIL NIL) (-451 1034173 1036927 1036969 "FSAGG" 1037339 NIL FSAGG (NIL T) -9 NIL 1037596) (-450 1031935 1032536 1033332 "FSAGG-" 1033427 NIL FSAGG- (NIL T T) -8 NIL NIL) (-449 1030977 1031120 1031347 "FSAGG2" 1031788 NIL FSAGG2 (NIL T T T T) -7 NIL NIL) (-448 1028628 1028907 1029462 "FS2UPS" 1030695 NIL FS2UPS (NIL T T T T T NIL) -7 NIL NIL) (-447 1028210 1028253 1028408 "FS2" 1028579 NIL FS2 (NIL T T T T) -7 NIL NIL) (-446 1027067 1027238 1027547 "FS2EXPXP" 1028035 NIL FS2EXPXP (NIL T T NIL NIL) -7 NIL NIL) (-445 1026493 1026608 1026760 "FRUTIL" 1026947 NIL FRUTIL (NIL T) -7 NIL NIL) (-444 1017919 1022004 1023354 "FR" 1025175 NIL FR (NIL T) -8 NIL NIL) (-443 1012999 1015637 1015678 "FRNAALG" 1017074 NIL FRNAALG (NIL T) -9 NIL 1017680) (-442 1008678 1009748 1011023 "FRNAALG-" 1011773 NIL FRNAALG- (NIL T T) -8 NIL NIL) (-441 1008316 1008359 1008486 "FRNAAF2" 1008629 NIL FRNAAF2 (NIL T T T T) -7 NIL NIL) (-440 1006674 1007167 1007462 "FRMOD" 1008129 NIL FRMOD (NIL T T T T NIL) -8 NIL NIL) (-439 1004381 1005049 1005367 "FRIDEAL" 1006465 NIL FRIDEAL (NIL T T T T) -8 NIL NIL) (-438 1003572 1003659 1003950 "FRIDEAL2" 1004288 NIL FRIDEAL2 (NIL T T T T T T T T) -7 NIL NIL) (-437 1002815 1003229 1003271 "FRETRCT" 1003276 NIL FRETRCT (NIL T) -9 NIL 1003450) (-436 1001927 1002158 1002509 "FRETRCT-" 1002514 NIL FRETRCT- (NIL T T) -8 NIL NIL) (-435 999132 1000352 1000412 "FRAMALG" 1001294 NIL FRAMALG (NIL T T) -9 NIL 1001586) (-434 997265 997721 998351 "FRAMALG-" 998574 NIL FRAMALG- (NIL T T T) -8 NIL NIL) (-433 991166 996748 997020 "FRAC" 997025 NIL FRAC (NIL T) -8 NIL NIL) (-432 990802 990859 990966 "FRAC2" 991103 NIL FRAC2 (NIL T T) -7 NIL NIL) (-431 990438 990495 990602 "FR2" 990739 NIL FR2 (NIL T T) -7 NIL NIL) (-430 985047 987956 987985 "FPS" 989104 T FPS (NIL) -9 NIL 989658) (-429 984496 984605 984769 "FPS-" 984915 NIL FPS- (NIL T) -8 NIL NIL) (-428 981879 983576 983605 "FPC" 983830 T FPC (NIL) -9 NIL 983972) (-427 981672 981712 981809 "FPC-" 981814 NIL FPC- (NIL T) -8 NIL NIL) (-426 980551 981161 981203 "FPATMAB" 981208 NIL FPATMAB (NIL T) -9 NIL 981358) (-425 978251 978727 979153 "FPARFRAC" 980188 NIL FPARFRAC (NIL T T) -8 NIL NIL) (-424 973646 974143 974825 "FORTRAN" 977683 NIL FORTRAN (NIL NIL NIL NIL NIL) -8 NIL NIL) (-423 971362 971862 972401 "FORT" 973127 T FORT (NIL) -7 NIL NIL) (-422 969038 969599 969628 "FORTFN" 970688 T FORTFN (NIL) -9 NIL 971312) (-421 968801 968851 968880 "FORTCAT" 968939 T FORTCAT (NIL) -9 NIL 969001) (-420 966861 967344 967743 "FORMULA" 968422 T FORMULA (NIL) -8 NIL NIL) (-419 966649 966679 966748 "FORMULA1" 966825 NIL FORMULA1 (NIL T) -7 NIL NIL) (-418 966172 966224 966397 "FORDER" 966591 NIL FORDER (NIL T T T T) -7 NIL NIL) (-417 965268 965432 965625 "FOP" 965999 T FOP (NIL) -7 NIL NIL) (-416 963876 964548 964722 "FNLA" 965150 NIL FNLA (NIL NIL NIL T) -8 NIL NIL) (-415 962543 962932 962961 "FNCAT" 963533 T FNCAT (NIL) -9 NIL 963826) (-414 962109 962502 962530 "FNAME" 962535 T FNAME (NIL) -8 NIL NIL) (-413 960762 961735 961764 "FMTC" 961769 T FMTC (NIL) -9 NIL 961805) (-412 957080 958287 958915 "FMONOID" 960167 NIL FMONOID (NIL T) -8 NIL NIL) (-411 956301 956824 956972 "FM" 956977 NIL FM (NIL T T) -8 NIL NIL) (-410 953725 954370 954399 "FMFUN" 955543 T FMFUN (NIL) -9 NIL 956251) (-409 952994 953174 953203 "FMC" 953493 T FMC (NIL) -9 NIL 953675) (-408 950206 951040 951095 "FMCAT" 952290 NIL FMCAT (NIL T T) -9 NIL 952784) (-407 949099 949972 950072 "FM1" 950151 NIL FM1 (NIL T T) -8 NIL NIL) (-406 946873 947289 947783 "FLOATRP" 948650 NIL FLOATRP (NIL T) -7 NIL NIL) (-405 940360 944529 945159 "FLOAT" 946263 T FLOAT (NIL) -8 NIL NIL) (-404 937798 938298 938876 "FLOATCP" 939827 NIL FLOATCP (NIL T) -7 NIL NIL) (-403 936583 937431 937473 "FLINEXP" 937478 NIL FLINEXP (NIL T) -9 NIL 937570) (-402 935737 935972 936300 "FLINEXP-" 936305 NIL FLINEXP- (NIL T T) -8 NIL NIL) (-401 934813 934957 935181 "FLASORT" 935589 NIL FLASORT (NIL T T) -7 NIL NIL) (-400 932029 932871 932924 "FLALG" 934151 NIL FLALG (NIL T T) -9 NIL 934618) (-399 925848 929542 929584 "FLAGG" 930846 NIL FLAGG (NIL T) -9 NIL 931494) (-398 924574 924913 925403 "FLAGG-" 925408 NIL FLAGG- (NIL T T) -8 NIL NIL) (-397 923616 923759 923986 "FLAGG2" 924427 NIL FLAGG2 (NIL T T T T) -7 NIL NIL) (-396 920587 921605 921665 "FINRALG" 922793 NIL FINRALG (NIL T T) -9 NIL 923298) (-395 919747 919976 920315 "FINRALG-" 920320 NIL FINRALG- (NIL T T T) -8 NIL NIL) (-394 919050 919287 919316 "FINITE" 919567 T FINITE (NIL) -9 NIL 919697) (-393 918859 918903 918990 "FINITE-" 918995 NIL FINITE- (NIL T) -8 NIL NIL) (-392 911317 913478 913519 "FINAALG" 917186 NIL FINAALG (NIL T) -9 NIL 918638) (-391 906657 907699 908843 "FINAALG-" 910222 NIL FINAALG- (NIL T T) -8 NIL NIL) (-390 906027 906412 906515 "FILE" 906587 NIL FILE (NIL T) -8 NIL NIL) (-389 904567 904904 904959 "FILECAT" 905737 NIL FILECAT (NIL T T) -9 NIL 905977) (-388 902364 903920 903949 "FIELD" 903989 T FIELD (NIL) -9 NIL 904069) (-387 900984 901369 901880 "FIELD-" 901885 NIL FIELD- (NIL T) -8 NIL NIL) (-386 898797 899619 899966 "FGROUP" 900670 NIL FGROUP (NIL T) -8 NIL NIL) (-385 897887 898051 898271 "FGLMICPK" 898629 NIL FGLMICPK (NIL T NIL) -7 NIL NIL) (-384 893644 897812 897869 "FFX" 897874 NIL FFX (NIL T NIL) -8 NIL NIL) (-383 893184 893251 893373 "FFSQFR" 893572 NIL FFSQFR (NIL T T) -7 NIL NIL) (-382 892785 892846 892981 "FFSLPE" 893117 NIL FFSLPE (NIL T T T) -7 NIL NIL) (-381 888781 889557 890353 "FFPOLY" 892021 NIL FFPOLY (NIL T) -7 NIL NIL) (-380 888285 888321 888530 "FFPOLY2" 888739 NIL FFPOLY2 (NIL T T) -7 NIL NIL) (-379 884062 888204 888267 "FFP" 888272 NIL FFP (NIL T NIL) -8 NIL NIL) (-378 879378 883973 884037 "FF" 884042 NIL FF (NIL NIL NIL) -8 NIL NIL) (-377 874429 878721 878911 "FFNBX" 879232 NIL FFNBX (NIL T NIL) -8 NIL NIL) (-376 869294 873564 873822 "FFNBP" 874283 NIL FFNBP (NIL T NIL) -8 NIL NIL) (-375 863845 868578 868789 "FFNB" 869127 NIL FFNB (NIL NIL NIL) -8 NIL NIL) (-374 862677 862875 863190 "FFINTBAS" 863642 NIL FFINTBAS (NIL T T T) -7 NIL NIL) (-373 858815 861075 861104 "FFIELDC" 861724 T FFIELDC (NIL) -9 NIL 862100) (-372 857478 857848 858345 "FFIELDC-" 858350 NIL FFIELDC- (NIL T) -8 NIL NIL) (-371 857048 857093 857217 "FFHOM" 857420 NIL FFHOM (NIL T T T) -7 NIL NIL) (-370 854746 855230 855747 "FFF" 856563 NIL FFF (NIL T) -7 NIL NIL) (-369 850442 851207 852051 "FFFG" 853970 NIL FFFG (NIL T T) -7 NIL NIL) (-368 849168 849377 849699 "FFFGF" 850220 NIL FFFGF (NIL T T T) -7 NIL NIL) (-367 847919 848116 848364 "FFFACTSE" 848970 NIL FFFACTSE (NIL T T) -7 NIL NIL) (-366 846670 846867 847115 "FFFACTOR" 847721 NIL FFFACTOR (NIL T T) -7 NIL NIL) (-365 842213 846412 846513 "FFCGX" 846613 NIL FFCGX (NIL T NIL) -8 NIL NIL) (-364 837770 841945 842052 "FFCGP" 842156 NIL FFCGP (NIL T NIL) -8 NIL NIL) (-363 832871 837497 837605 "FFCG" 837706 NIL FFCG (NIL NIL NIL) -8 NIL NIL) (-362 814539 823713 823800 "FFCAT" 828965 NIL FFCAT (NIL T T T) -9 NIL 830450) (-361 809737 810784 812098 "FFCAT-" 813328 NIL FFCAT- (NIL T T T T) -8 NIL NIL) (-360 809148 809191 809426 "FFCAT2" 809688 NIL FFCAT2 (NIL T T T T T T T T) -7 NIL NIL) (-359 798318 802124 803342 "FEXPR" 808002 NIL FEXPR (NIL NIL NIL T) -8 NIL NIL) (-358 797320 797755 797797 "FEVALAB" 797881 NIL FEVALAB (NIL T) -9 NIL 798139) (-357 796479 796689 797027 "FEVALAB-" 797032 NIL FEVALAB- (NIL T T) -8 NIL NIL) (-356 795072 795862 796065 "FDIV" 796378 NIL FDIV (NIL T T T T) -8 NIL NIL) (-355 792137 792852 792968 "FDIVCAT" 794536 NIL FDIVCAT (NIL T T T T) -9 NIL 794973) (-354 791899 791926 792096 "FDIVCAT-" 792101 NIL FDIVCAT- (NIL T T T T T) -8 NIL NIL) (-353 791119 791206 791483 "FDIV2" 791806 NIL FDIV2 (NIL T T T T T T T T) -7 NIL NIL) (-352 789805 790064 790353 "FCPAK1" 790850 T FCPAK1 (NIL) -7 NIL NIL) (-351 788933 789305 789446 "FCOMP" 789696 NIL FCOMP (NIL T) -8 NIL NIL) (-350 772561 775976 779539 "FC" 785390 T FC (NIL) -8 NIL NIL) (-349 765047 769135 769176 "FAXF" 770978 NIL FAXF (NIL T) -9 NIL 771669) (-348 762327 762981 763806 "FAXF-" 764271 NIL FAXF- (NIL T T) -8 NIL NIL) (-347 757433 761703 761879 "FARRAY" 762184 NIL FARRAY (NIL T) -8 NIL NIL) (-346 752751 754827 754881 "FAMR" 755904 NIL FAMR (NIL T T) -9 NIL 756361) (-345 751641 751943 752378 "FAMR-" 752383 NIL FAMR- (NIL T T T) -8 NIL NIL) (-344 751229 751272 751423 "FAMR2" 751592 NIL FAMR2 (NIL T T T T T) -7 NIL NIL) (-343 750425 751151 751204 "FAMONOID" 751209 NIL FAMONOID (NIL T) -8 NIL NIL) (-342 748255 748939 748993 "FAMONC" 749934 NIL FAMONC (NIL T T) -9 NIL 750319) (-341 746949 748011 748147 "FAGROUP" 748152 NIL FAGROUP (NIL T) -8 NIL NIL) (-340 744744 745063 745466 "FACUTIL" 746630 NIL FACUTIL (NIL T T T T) -7 NIL NIL) (-339 744160 744269 744415 "FACTRN" 744630 NIL FACTRN (NIL T) -7 NIL NIL) (-338 743259 743444 743666 "FACTFUNC" 743970 NIL FACTFUNC (NIL T) -7 NIL NIL) (-337 742675 742784 742930 "FACTEXT" 743145 NIL FACTEXT (NIL T) -7 NIL NIL) (-336 734995 741926 742138 "EXPUPXS" 742531 NIL EXPUPXS (NIL T NIL NIL) -8 NIL NIL) (-335 732478 733018 733604 "EXPRTUBE" 734429 T EXPRTUBE (NIL) -7 NIL NIL) (-334 731649 731744 731964 "EXPRSOL" 732378 NIL EXPRSOL (NIL T T T T) -7 NIL NIL) (-333 727843 728435 729172 "EXPRODE" 730988 NIL EXPRODE (NIL T T) -7 NIL NIL) (-332 712864 726504 726929 "EXPR" 727450 NIL EXPR (NIL T) -8 NIL NIL) (-331 707271 707858 708671 "EXPR2UPS" 712162 NIL EXPR2UPS (NIL T T) -7 NIL NIL) (-330 706907 706964 707071 "EXPR2" 707208 NIL EXPR2 (NIL T T) -7 NIL NIL) (-329 698245 706037 706335 "EXPEXPAN" 706743 NIL EXPEXPAN (NIL T T NIL NIL) -8 NIL NIL) (-328 697957 698008 698085 "EXP3D" 698188 T EXP3D (NIL) -7 NIL NIL) (-327 697784 697914 697943 "EXIT" 697948 T EXIT (NIL) -8 NIL NIL) (-326 697411 697473 697586 "EVALCYC" 697716 NIL EVALCYC (NIL T) -7 NIL NIL) (-325 696953 697069 697111 "EVALAB" 697281 NIL EVALAB (NIL T) -9 NIL 697385) (-324 696434 696556 696777 "EVALAB-" 696782 NIL EVALAB- (NIL T T) -8 NIL NIL) (-323 693879 695191 695220 "EUCDOM" 695775 T EUCDOM (NIL) -9 NIL 696125) (-322 692284 692726 693316 "EUCDOM-" 693321 NIL EUCDOM- (NIL T) -8 NIL NIL) (-321 679824 682582 685332 "ESTOOLS" 689554 T ESTOOLS (NIL) -7 NIL NIL) (-320 679456 679513 679622 "ESTOOLS2" 679761 NIL ESTOOLS2 (NIL T T) -7 NIL NIL) (-319 679207 679249 679329 "ESTOOLS1" 679408 NIL ESTOOLS1 (NIL T) -7 NIL NIL) (-318 673133 674861 674890 "ES" 677658 T ES (NIL) -9 NIL 679065) (-317 668081 669367 671184 "ES-" 671348 NIL ES- (NIL T) -8 NIL NIL) (-316 664456 665216 665996 "ESCONT" 667321 T ESCONT (NIL) -7 NIL NIL) (-315 664201 664233 664315 "ESCONT1" 664418 NIL ESCONT1 (NIL NIL NIL) -7 NIL NIL) (-314 663876 663926 664026 "ES2" 664145 NIL ES2 (NIL T T) -7 NIL NIL) (-313 663506 663564 663673 "ES1" 663812 NIL ES1 (NIL T T) -7 NIL NIL) (-312 662722 662851 663027 "ERROR" 663350 T ERROR (NIL) -7 NIL NIL) (-311 656237 662581 662672 "EQTBL" 662677 NIL EQTBL (NIL T T) -8 NIL NIL) (-310 648696 651579 653014 "EQ" 654835 NIL -1465 (NIL T) -8 NIL NIL) (-309 648328 648385 648494 "EQ2" 648633 NIL EQ2 (NIL T T) -7 NIL NIL) (-308 643620 644666 645759 "EP" 647267 NIL EP (NIL T) -7 NIL NIL) (-307 642774 643338 643367 "ENTIRER" 643372 T ENTIRER (NIL) -9 NIL 643418) (-306 639230 640729 641099 "EMR" 642573 NIL EMR (NIL T T T NIL NIL NIL) -8 NIL NIL) (-305 638376 638559 638614 "ELTAGG" 638994 NIL ELTAGG (NIL T T) -9 NIL 639204) (-304 638095 638157 638298 "ELTAGG-" 638303 NIL ELTAGG- (NIL T T T) -8 NIL NIL) (-303 637883 637912 637967 "ELTAB" 638051 NIL ELTAB (NIL T T) -9 NIL NIL) (-302 637009 637155 637354 "ELFUTS" 637734 NIL ELFUTS (NIL T T) -7 NIL NIL) (-301 636750 636806 636835 "ELEMFUN" 636940 T ELEMFUN (NIL) -9 NIL NIL) (-300 636620 636641 636709 "ELEMFUN-" 636714 NIL ELEMFUN- (NIL T) -8 NIL NIL) (-299 631550 634753 634795 "ELAGG" 635735 NIL ELAGG (NIL T) -9 NIL 636196) (-298 629835 630269 630932 "ELAGG-" 630937 NIL ELAGG- (NIL T T) -8 NIL NIL) (-297 622675 624474 625302 "EFUPXS" 629111 NIL EFUPXS (NIL T T T T) -8 NIL NIL) (-296 616125 617926 618736 "EFULS" 621951 NIL EFULS (NIL T T T) -8 NIL NIL) (-295 613547 613905 614384 "EFSTRUC" 615757 NIL EFSTRUC (NIL T T) -7 NIL NIL) (-294 602559 604124 605685 "EF" 612062 NIL EF (NIL T T) -7 NIL NIL) (-293 601660 602044 602193 "EAB" 602430 T EAB (NIL) -8 NIL NIL) (-292 600869 601619 601647 "E04UCFA" 601652 T E04UCFA (NIL) -8 NIL NIL) (-291 600078 600828 600856 "E04NAFA" 600861 T E04NAFA (NIL) -8 NIL NIL) (-290 599287 600037 600065 "E04MBFA" 600070 T E04MBFA (NIL) -8 NIL NIL) (-289 598496 599246 599274 "E04JAFA" 599279 T E04JAFA (NIL) -8 NIL NIL) (-288 597707 598455 598483 "E04GCFA" 598488 T E04GCFA (NIL) -8 NIL NIL) (-287 596918 597666 597694 "E04FDFA" 597699 T E04FDFA (NIL) -8 NIL NIL) (-286 596127 596877 596905 "E04DGFA" 596910 T E04DGFA (NIL) -8 NIL NIL) (-285 590306 591652 593016 "E04AGNT" 594783 T E04AGNT (NIL) -7 NIL NIL) (-284 589029 589509 589550 "DVARCAT" 590025 NIL DVARCAT (NIL T) -9 NIL 590224) (-283 588233 588445 588759 "DVARCAT-" 588764 NIL DVARCAT- (NIL T T) -8 NIL NIL) (-282 581202 581684 582433 "DTP" 587764 NIL DTP (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-281 578651 580624 580781 "DSTREE" 581078 NIL DSTREE (NIL T) -8 NIL NIL) (-280 576120 577965 578007 "DSTRCAT" 578226 NIL DSTRCAT (NIL T) -9 NIL 578360) (-279 568974 575919 576048 "DSMP" 576053 NIL DSMP (NIL T T T) -8 NIL NIL) (-278 563784 564919 565987 "DROPT" 567926 T DROPT (NIL) -8 NIL NIL) (-277 563449 563508 563606 "DROPT1" 563719 NIL DROPT1 (NIL T) -7 NIL NIL) (-276 558564 559690 560827 "DROPT0" 562332 T DROPT0 (NIL) -7 NIL NIL) (-275 556909 557234 557620 "DRAWPT" 558198 T DRAWPT (NIL) -7 NIL NIL) (-274 551496 552419 553498 "DRAW" 555883 NIL DRAW (NIL T) -7 NIL NIL) (-273 551129 551182 551300 "DRAWHACK" 551437 NIL DRAWHACK (NIL T) -7 NIL NIL) (-272 549860 550129 550420 "DRAWCX" 550858 T DRAWCX (NIL) -7 NIL NIL) (-271 549376 549444 549595 "DRAWCURV" 549786 NIL DRAWCURV (NIL T T) -7 NIL NIL) (-270 539848 541806 543921 "DRAWCFUN" 547281 T DRAWCFUN (NIL) -7 NIL NIL) (-269 536699 538575 538617 "DQAGG" 539246 NIL DQAGG (NIL T) -9 NIL 539520) (-268 525072 531813 531897 "DPOLCAT" 533749 NIL DPOLCAT (NIL T T T T) -9 NIL 534293) (-267 519911 521257 523215 "DPOLCAT-" 523220 NIL DPOLCAT- (NIL T T T T T) -8 NIL NIL) (-266 512607 519772 519870 "DPMO" 519875 NIL DPMO (NIL NIL T T) -8 NIL NIL) (-265 505206 512387 512554 "DPMM" 512559 NIL DPMM (NIL NIL T T T) -8 NIL NIL) (-264 498911 504841 504993 "DMP" 505107 NIL DMP (NIL NIL T) -8 NIL NIL) (-263 498511 498567 498711 "DLP" 498849 NIL DLP (NIL T) -7 NIL NIL) (-262 492161 497612 497839 "DLIST" 498316 NIL DLIST (NIL T) -8 NIL NIL) (-261 489046 491049 491091 "DLAGG" 491641 NIL DLAGG (NIL T) -9 NIL 491870) (-260 487703 488395 488424 "DIVRING" 488574 T DIVRING (NIL) -9 NIL 488682) (-259 486691 486944 487337 "DIVRING-" 487342 NIL DIVRING- (NIL T) -8 NIL NIL) (-258 485119 486284 486420 "DIV" 486588 NIL DIV (NIL T) -8 NIL NIL) (-257 482613 483681 483723 "DIVCAT" 484557 NIL DIVCAT (NIL T) -9 NIL 484888) (-256 480715 481072 481478 "DISPLAY" 482227 T DISPLAY (NIL) -7 NIL NIL) (-255 478208 479421 479803 "DIRRING" 480366 NIL DIRRING (NIL T) -8 NIL NIL) (-254 472025 478122 478185 "DIRPROD" 478190 NIL DIRPROD (NIL NIL T) -8 NIL NIL) (-253 470873 471076 471341 "DIRPROD2" 471818 NIL DIRPROD2 (NIL NIL T T) -7 NIL NIL) (-252 460325 466397 466451 "DIRPCAT" 466861 NIL DIRPCAT (NIL NIL T) -9 NIL 467690) (-251 457651 458293 459174 "DIRPCAT-" 459511 NIL DIRPCAT- (NIL T NIL T) -8 NIL NIL) (-250 456938 457098 457284 "DIOSP" 457485 T DIOSP (NIL) -7 NIL NIL) (-249 453681 455885 455927 "DIOPS" 456361 NIL DIOPS (NIL T) -9 NIL 456589) (-248 453230 453344 453535 "DIOPS-" 453540 NIL DIOPS- (NIL T T) -8 NIL NIL) (-247 452097 452735 452764 "DIFRING" 452951 T DIFRING (NIL) -9 NIL 453061) (-246 451743 451820 451972 "DIFRING-" 451977 NIL DIFRING- (NIL T) -8 NIL NIL) (-245 449525 450807 450849 "DIFEXT" 451212 NIL DIFEXT (NIL T) -9 NIL 451504) (-244 447810 448238 448904 "DIFEXT-" 448909 NIL DIFEXT- (NIL T T) -8 NIL NIL) (-243 445172 447376 447418 "DIAGG" 447423 NIL DIAGG (NIL T) -9 NIL 447443) (-242 444556 444713 444965 "DIAGG-" 444970 NIL DIAGG- (NIL T T) -8 NIL NIL) (-241 439878 443515 443792 "DHMATRIX" 444325 NIL DHMATRIX (NIL T) -8 NIL NIL) (-240 435089 439692 439766 "DFVEC" 439824 T DFVEC (NIL) -8 NIL NIL) (-239 428690 430040 431477 "DFSFUN" 433672 T DFSFUN (NIL) -7 NIL NIL) (-238 424901 428461 428555 "DFMAT" 428616 T DFMAT (NIL) -8 NIL NIL) (-237 419178 423355 423788 "DFLOAT" 424488 T DFLOAT (NIL) -8 NIL NIL) (-236 417406 417687 418083 "DFINTTLS" 418886 NIL DFINTTLS (NIL T T) -7 NIL NIL) (-235 414425 415427 415827 "DERHAM" 417072 NIL DERHAM (NIL T NIL) -8 NIL NIL) (-234 406038 407955 409390 "DEQUEUE" 413023 NIL DEQUEUE (NIL T) -8 NIL NIL) (-233 405253 405386 405582 "DEGRED" 405900 NIL DEGRED (NIL T T) -7 NIL NIL) (-232 401648 402393 403246 "DEFINTRF" 404481 NIL DEFINTRF (NIL T) -7 NIL NIL) (-231 399175 399644 400243 "DEFINTEF" 401167 NIL DEFINTEF (NIL T T) -7 NIL NIL) (-230 392991 398611 398779 "DECIMAL" 399027 T DECIMAL (NIL) -8 NIL NIL) (-229 390503 390961 391467 "DDFACT" 392535 NIL DDFACT (NIL T T) -7 NIL NIL) (-228 390099 390142 390293 "DBLRESP" 390454 NIL DBLRESP (NIL T T T T) -7 NIL NIL) (-227 387805 388140 388510 "DBASE" 389856 NIL DBASE (NIL T) -8 NIL NIL) (-226 386938 387764 387792 "D03FAFA" 387797 T D03FAFA (NIL) -8 NIL NIL) (-225 386072 386897 386925 "D03EEFA" 386930 T D03EEFA (NIL) -8 NIL NIL) (-224 384022 384488 384977 "D03AGNT" 385603 T D03AGNT (NIL) -7 NIL NIL) (-223 383338 383981 384009 "D02EJFA" 384014 T D02EJFA (NIL) -8 NIL NIL) (-222 382654 383297 383325 "D02CJFA" 383330 T D02CJFA (NIL) -8 NIL NIL) (-221 381970 382613 382641 "D02BHFA" 382646 T D02BHFA (NIL) -8 NIL NIL) (-220 381286 381929 381957 "D02BBFA" 381962 T D02BBFA (NIL) -8 NIL NIL) (-219 374485 376072 377678 "D02AGNT" 379700 T D02AGNT (NIL) -7 NIL NIL) (-218 372254 372776 373322 "D01WGTS" 373959 T D01WGTS (NIL) -7 NIL NIL) (-217 371349 372213 372241 "D01TRNS" 372246 T D01TRNS (NIL) -8 NIL NIL) (-216 370444 371308 371336 "D01GBFA" 371341 T D01GBFA (NIL) -8 NIL NIL) (-215 369539 370403 370431 "D01FCFA" 370436 T D01FCFA (NIL) -8 NIL NIL) (-214 368634 369498 369526 "D01ASFA" 369531 T D01ASFA (NIL) -8 NIL NIL) (-213 367729 368593 368621 "D01AQFA" 368626 T D01AQFA (NIL) -8 NIL NIL) (-212 366824 367688 367716 "D01APFA" 367721 T D01APFA (NIL) -8 NIL NIL) (-211 365919 366783 366811 "D01ANFA" 366816 T D01ANFA (NIL) -8 NIL NIL) (-210 365014 365878 365906 "D01AMFA" 365911 T D01AMFA (NIL) -8 NIL NIL) (-209 364109 364973 365001 "D01ALFA" 365006 T D01ALFA (NIL) -8 NIL NIL) (-208 363204 364068 364096 "D01AKFA" 364101 T D01AKFA (NIL) -8 NIL NIL) (-207 362299 363163 363191 "D01AJFA" 363196 T D01AJFA (NIL) -8 NIL NIL) (-206 355596 357147 358708 "D01AGNT" 360758 T D01AGNT (NIL) -7 NIL NIL) (-205 354933 355061 355213 "CYCLOTOM" 355464 T CYCLOTOM (NIL) -7 NIL NIL) (-204 351668 352381 353108 "CYCLES" 354226 T CYCLES (NIL) -7 NIL NIL) (-203 350980 351114 351285 "CVMP" 351529 NIL CVMP (NIL T) -7 NIL NIL) (-202 348752 349009 349385 "CTRIGMNP" 350708 NIL CTRIGMNP (NIL T T) -7 NIL NIL) (-201 348126 348225 348378 "CSTTOOLS" 348649 NIL CSTTOOLS (NIL T T) -7 NIL NIL) (-200 343925 344582 345340 "CRFP" 347438 NIL CRFP (NIL T T) -7 NIL NIL) (-199 342972 343157 343385 "CRAPACK" 343729 NIL CRAPACK (NIL T) -7 NIL NIL) (-198 342358 342459 342662 "CPMATCH" 342849 NIL CPMATCH (NIL T T T) -7 NIL NIL) (-197 342083 342111 342217 "CPIMA" 342324 NIL CPIMA (NIL T T T) -7 NIL NIL) (-196 338431 339103 339822 "COORDSYS" 341418 NIL COORDSYS (NIL T) -7 NIL NIL) (-195 334292 336434 336926 "CONTFRAC" 337971 NIL CONTFRAC (NIL T) -8 NIL NIL) (-194 333440 334004 334033 "COMRING" 334038 T COMRING (NIL) -9 NIL 334090) (-193 332521 332798 332982 "COMPPROP" 333276 T COMPPROP (NIL) -8 NIL NIL) (-192 332182 332217 332345 "COMPLPAT" 332480 NIL COMPLPAT (NIL T T T) -7 NIL NIL) (-191 322108 331993 332101 "COMPLEX" 332106 NIL COMPLEX (NIL T) -8 NIL NIL) (-190 321744 321801 321908 "COMPLEX2" 322045 NIL COMPLEX2 (NIL T T) -7 NIL NIL) (-189 321462 321497 321595 "COMPFACT" 321703 NIL COMPFACT (NIL T T) -7 NIL NIL) (-188 305593 315938 315979 "COMPCAT" 316983 NIL COMPCAT (NIL T) -9 NIL 318364) (-187 295109 298032 301659 "COMPCAT-" 302015 NIL COMPCAT- (NIL T T) -8 NIL NIL) (-186 294768 294920 294949 "COMPAR" 295010 T COMPAR (NIL) -9 NIL 295059) (-185 294497 294525 294628 "COMMUPC" 294734 NIL COMMUPC (NIL T T T) -7 NIL NIL) (-184 294292 294325 294384 "COMMONOP" 294458 T COMMONOP (NIL) -7 NIL NIL) (-183 293875 294043 294130 "COMM" 294225 T COMM (NIL) -8 NIL NIL) (-182 293123 293317 293346 "COMBOPC" 293684 T COMBOPC (NIL) -9 NIL 293859) (-181 292019 292229 292471 "COMBINAT" 292913 NIL COMBINAT (NIL T) -7 NIL NIL) (-180 288217 288790 289430 "COMBF" 291441 NIL COMBF (NIL T T) -7 NIL NIL) (-179 287003 287333 287568 "COLOR" 288002 T COLOR (NIL) -8 NIL NIL) (-178 286643 286690 286815 "CMPLXRT" 286950 NIL CMPLXRT (NIL T T) -7 NIL NIL) (-177 282145 283173 284253 "CLIP" 285583 T CLIP (NIL) -7 NIL NIL) (-176 280476 281246 281486 "CLIF" 281972 NIL CLIF (NIL NIL T NIL) -8 NIL NIL) (-175 276741 278659 278701 "CLAGG" 279630 NIL CLAGG (NIL T) -9 NIL 280163) (-174 275163 275620 276203 "CLAGG-" 276208 NIL CLAGG- (NIL T T) -8 NIL NIL) (-173 274707 274792 274932 "CINTSLPE" 275072 NIL CINTSLPE (NIL T T) -7 NIL NIL) (-172 272208 272679 273227 "CHVAR" 274235 NIL CHVAR (NIL T T T) -7 NIL NIL) (-171 271426 271990 272019 "CHARZ" 272024 T CHARZ (NIL) -9 NIL 272039) (-170 271180 271220 271298 "CHARPOL" 271380 NIL CHARPOL (NIL T) -7 NIL NIL) (-169 270282 270879 270908 "CHARNZ" 270955 T CHARNZ (NIL) -9 NIL 271011) (-168 268280 268972 269307 "CHAR" 269967 T CHAR (NIL) -8 NIL NIL) (-167 268005 268066 268095 "CFCAT" 268206 T CFCAT (NIL) -9 NIL NIL) (-166 262138 267662 267780 "CDFVEC" 267907 T CDFVEC (NIL) -8 NIL NIL) (-165 257796 261895 261996 "CDFMAT" 262057 T CDFMAT (NIL) -8 NIL NIL) (-164 257037 257148 257331 "CDEN" 257680 NIL CDEN (NIL T T T) -7 NIL NIL) (-163 252982 256190 256470 "CCLASS" 256777 T CCLASS (NIL) -8 NIL NIL) (-162 248035 249011 249764 "CARTEN" 252285 NIL CARTEN (NIL NIL NIL T) -8 NIL NIL) (-161 247143 247291 247512 "CARTEN2" 247882 NIL CARTEN2 (NIL NIL NIL T T) -7 NIL NIL) (-160 245438 246293 246550 "CARD" 246906 T CARD (NIL) -8 NIL NIL) (-159 244809 245137 245166 "CACHSET" 245298 T CACHSET (NIL) -9 NIL 245375) (-158 244304 244600 244629 "CABMON" 244679 T CABMON (NIL) -9 NIL 244735) (-157 241867 243996 244103 "BTREE" 244230 NIL BTREE (NIL T) -8 NIL NIL) (-156 239371 241515 241637 "BTOURN" 241777 NIL BTOURN (NIL T) -8 NIL NIL) (-155 236828 238875 238917 "BTCAT" 238985 NIL BTCAT (NIL T) -9 NIL 239062) (-154 236495 236575 236724 "BTCAT-" 236729 NIL BTCAT- (NIL T T) -8 NIL NIL) (-153 231685 235555 235584 "BTAGG" 235840 T BTAGG (NIL) -9 NIL 236019) (-152 231108 231252 231482 "BTAGG-" 231487 NIL BTAGG- (NIL T) -8 NIL NIL) (-151 228158 230386 230601 "BSTREE" 230925 NIL BSTREE (NIL T) -8 NIL NIL) (-150 226561 227108 227408 "BSD" 227878 T BSD (NIL) -8 NIL NIL) (-149 225699 225825 226009 "BRILL" 226417 NIL BRILL (NIL T) -7 NIL NIL) (-148 222439 224460 224502 "BRAGG" 225151 NIL BRAGG (NIL T) -9 NIL 225408) (-147 220968 221374 221929 "BRAGG-" 221934 NIL BRAGG- (NIL T T) -8 NIL NIL) (-146 214165 220312 220497 "BPADICRT" 220815 NIL BPADICRT (NIL NIL) -8 NIL NIL) (-145 212469 214102 214147 "BPADIC" 214152 NIL BPADIC (NIL NIL) -8 NIL NIL) (-144 212167 212197 212311 "BOUNDZRO" 212433 NIL BOUNDZRO (NIL T T) -7 NIL NIL) (-143 207682 208773 209640 "BOP" 211320 T BOP (NIL) -8 NIL NIL) (-142 205305 205749 206268 "BOP1" 207196 NIL BOP1 (NIL T) -7 NIL NIL) (-141 203633 204348 204642 "BOOLEAN" 205031 T BOOLEAN (NIL) -8 NIL NIL) (-140 202994 203372 203427 "BMODULE" 203432 NIL BMODULE (NIL T T) -9 NIL 203497) (-139 199337 200007 200793 "BLUPPACK" 202326 NIL BLUPPACK (NIL T NIL T T T) -7 NIL NIL) (-138 198729 199214 199283 "BLQT" 199288 T BLQT (NIL) -8 NIL NIL) (-137 197158 197633 197662 "BLMETCT" 198307 T BLMETCT (NIL) -9 NIL 198679) (-136 196557 197039 197106 "BLHN" 197111 T BLHN (NIL) -8 NIL NIL) (-135 191394 192543 193702 "BLAS1" 195418 T BLAS1 (NIL) -7 NIL NIL) (-134 187204 191192 191265 "BITS" 191341 T BITS (NIL) -8 NIL NIL) (-133 186275 186736 186888 "BINFILE" 187072 T BINFILE (NIL) -8 NIL NIL) (-132 180095 185714 185881 "BINARY" 186128 T BINARY (NIL) -8 NIL NIL) (-131 177962 179384 179426 "BGAGG" 179686 NIL BGAGG (NIL T) -9 NIL 179823) (-130 177793 177825 177916 "BGAGG-" 177921 NIL BGAGG- (NIL T T) -8 NIL NIL) (-129 176891 177177 177382 "BFUNCT" 177608 T BFUNCT (NIL) -8 NIL NIL) (-128 175583 175761 176048 "BEZOUT" 176716 NIL BEZOUT (NIL T T T T T) -7 NIL NIL) (-127 174546 174768 175027 "BEZIER" 175357 NIL BEZIER (NIL T) -7 NIL NIL) (-126 171069 173398 173728 "BBTREE" 174249 NIL BBTREE (NIL T) -8 NIL NIL) (-125 170802 170855 170884 "BASTYPE" 171003 T BASTYPE (NIL) -9 NIL NIL) (-124 170655 170683 170756 "BASTYPE-" 170761 NIL BASTYPE- (NIL T) -8 NIL NIL) (-123 170089 170165 170317 "BALFACT" 170566 NIL BALFACT (NIL T T) -7 NIL NIL) (-122 169453 169576 169724 "AXSERV" 169961 T AXSERV (NIL) -7 NIL NIL) (-121 168266 168863 169051 "AUTOMOR" 169298 NIL AUTOMOR (NIL T) -8 NIL NIL) (-120 168200 168205 168234 "ATUNIKN" 168239 T ATUNIKN (NIL) -9 NIL NIL) (-119 167912 167917 167946 "ATTREG" 167951 T ATTREG (NIL) -9 NIL NIL) (-118 166180 166598 166952 "ATTRBUT" 167578 T ATTRBUT (NIL) -8 NIL NIL) (-117 166114 166119 166148 "ATSHMUT" 166153 T ATSHMUT (NIL) -9 NIL NIL) (-116 165641 165754 165783 "ATRIG" 165990 T ATRIG (NIL) -9 NIL NIL) (-115 165447 165488 165578 "ATRIG-" 165583 NIL ATRIG- (NIL T) -8 NIL NIL) (-114 165381 165386 165415 "ATPOSET" 165420 T ATPOSET (NIL) -9 NIL NIL) (-113 165315 165320 165349 "ATNZDIV" 165354 T ATNZDIV (NIL) -9 NIL NIL) (-112 165249 165254 165283 "ATNULSQ" 165288 T ATNULSQ (NIL) -9 NIL NIL) (-111 165183 165188 165217 "ATNOTHR" 165222 T ATNOTHR (NIL) -9 NIL NIL) (-110 165117 165122 165151 "ATMULVA" 165156 T ATMULVA (NIL) -9 NIL NIL) (-109 165051 165056 165085 "ATLUNIT" 165090 T ATLUNIT (NIL) -9 NIL NIL) (-108 164985 164990 165019 "ATLR" 165024 T ATLR (NIL) -9 NIL NIL) (-107 164919 164924 164953 "ATJACID" 164958 T ATJACID (NIL) -9 NIL NIL) (-106 164853 164858 164887 "ATFINAG" 164892 T ATFINAG (NIL) -9 NIL NIL) (-105 164787 164792 164821 "ATCUNOR" 164826 T ATCUNOR (NIL) -9 NIL NIL) (-104 164721 164726 164755 "ATCS" 164760 T ATCS (NIL) -9 NIL NIL) (-103 164655 164660 164689 "ATCENRL" 164694 T ATCENRL (NIL) -9 NIL NIL) (-102 164589 164594 164623 "ATCANON" 164628 T ATCANON (NIL) -9 NIL NIL) (-101 164523 164528 164557 "ATCANCL" 164562 T ATCANCL (NIL) -9 NIL NIL) (-100 164457 164462 164491 "ATARBPR" 164496 T ATARBPR (NIL) -9 NIL NIL) (-99 164393 164398 164425 "ATARBEX" 164430 T ATARBEX (NIL) -9 NIL NIL) (-98 164329 164334 164361 "ATAPPRO" 164366 T ATAPPRO (NIL) -9 NIL NIL) (-97 164265 164270 164297 "ATADDVA" 164302 T ATADDVA (NIL) -9 NIL NIL) (-96 157825 159394 160505 "ASTACK" 163185 NIL ASTACK (NIL T) -8 NIL NIL) (-95 156332 156629 156993 "ASSOCEQ" 157508 NIL ASSOCEQ (NIL T T) -7 NIL NIL) (-94 155364 155991 156115 "ASP9" 156239 NIL ASP9 (NIL NIL) -8 NIL NIL) (-93 155128 155312 155351 "ASP8" 155356 NIL ASP8 (NIL NIL) -8 NIL NIL) (-92 153998 154733 154875 "ASP80" 155017 NIL ASP80 (NIL NIL) -8 NIL NIL) (-91 152897 153633 153765 "ASP7" 153897 NIL ASP7 (NIL NIL) -8 NIL NIL) (-90 151853 152574 152692 "ASP78" 152810 NIL ASP78 (NIL NIL) -8 NIL NIL) (-89 150824 151533 151650 "ASP77" 151767 NIL ASP77 (NIL NIL) -8 NIL NIL) (-88 149739 150462 150593 "ASP74" 150724 NIL ASP74 (NIL NIL) -8 NIL NIL) (-87 148640 149374 149506 "ASP73" 149638 NIL ASP73 (NIL NIL) -8 NIL NIL) (-86 147595 148317 148435 "ASP6" 148553 NIL ASP6 (NIL NIL) -8 NIL NIL) (-85 146544 147272 147390 "ASP55" 147508 NIL ASP55 (NIL NIL) -8 NIL NIL) (-84 145494 146218 146337 "ASP50" 146456 NIL ASP50 (NIL NIL) -8 NIL NIL) (-83 144582 145195 145305 "ASP4" 145415 NIL ASP4 (NIL NIL) -8 NIL NIL) (-82 143670 144283 144393 "ASP49" 144503 NIL ASP49 (NIL NIL) -8 NIL NIL) (-81 142455 143209 143377 "ASP42" 143559 NIL ASP42 (NIL NIL NIL NIL) -8 NIL NIL) (-80 141233 141988 142158 "ASP41" 142342 NIL ASP41 (NIL NIL NIL NIL) -8 NIL NIL) (-79 140185 140910 141028 "ASP35" 141146 NIL ASP35 (NIL NIL) -8 NIL NIL) (-78 139950 140133 140172 "ASP34" 140177 NIL ASP34 (NIL NIL) -8 NIL NIL) (-77 139687 139754 139830 "ASP33" 139905 NIL ASP33 (NIL NIL) -8 NIL NIL) (-76 138583 139322 139454 "ASP31" 139586 NIL ASP31 (NIL NIL) -8 NIL NIL) (-75 138348 138531 138570 "ASP30" 138575 NIL ASP30 (NIL NIL) -8 NIL NIL) (-74 138083 138152 138228 "ASP29" 138303 NIL ASP29 (NIL NIL) -8 NIL NIL) (-73 137848 138031 138070 "ASP28" 138075 NIL ASP28 (NIL NIL) -8 NIL NIL) (-72 137613 137796 137835 "ASP27" 137840 NIL ASP27 (NIL NIL) -8 NIL NIL) (-71 136697 137311 137422 "ASP24" 137533 NIL ASP24 (NIL NIL) -8 NIL NIL) (-70 135614 136338 136468 "ASP20" 136598 NIL ASP20 (NIL NIL) -8 NIL NIL) (-69 134702 135315 135425 "ASP1" 135535 NIL ASP1 (NIL NIL) -8 NIL NIL) (-68 133646 134376 134495 "ASP19" 134614 NIL ASP19 (NIL NIL) -8 NIL NIL) (-67 133383 133450 133526 "ASP12" 133601 NIL ASP12 (NIL NIL) -8 NIL NIL) (-66 132236 132982 133126 "ASP10" 133270 NIL ASP10 (NIL NIL) -8 NIL NIL) (-65 130141 132080 132171 "ARRAY2" 132176 NIL ARRAY2 (NIL T) -8 NIL NIL) (-64 125963 129789 129903 "ARRAY1" 130058 NIL ARRAY1 (NIL T) -8 NIL NIL) (-63 124995 125168 125389 "ARRAY12" 125786 NIL ARRAY12 (NIL T T) -7 NIL NIL) (-62 119394 121259 121335 "ARR2CAT" 123965 NIL ARR2CAT (NIL T T T) -9 NIL 124723) (-61 116828 117572 118526 "ARR2CAT-" 118531 NIL ARR2CAT- (NIL T T T T) -8 NIL NIL) (-60 115576 115728 116034 "APPRULE" 116664 NIL APPRULE (NIL T T T) -7 NIL NIL) (-59 115227 115275 115394 "APPLYORE" 115522 NIL APPLYORE (NIL T T T) -7 NIL NIL) (-58 114399 114556 114733 "API" 115068 T API (NIL) -7 NIL NIL) (-57 113373 113664 113859 "ANY" 114222 T ANY (NIL) -8 NIL NIL) (-56 112651 112774 112931 "ANY1" 113247 NIL ANY1 (NIL T) -7 NIL NIL) (-55 110170 111088 111415 "ANTISYM" 112375 NIL ANTISYM (NIL T NIL) -8 NIL NIL) (-54 109997 110129 110156 "ANON" 110161 T ANON (NIL) -8 NIL NIL) (-53 104064 108536 108990 "AN" 109561 T AN (NIL) -8 NIL NIL) (-52 100359 101757 101809 "AMR" 102557 NIL AMR (NIL T T) -9 NIL 103151) (-51 99471 99692 100055 "AMR-" 100060 NIL AMR- (NIL T T T) -8 NIL NIL) (-50 84033 99388 99449 "ALIST" 99454 NIL ALIST (NIL T T) -8 NIL NIL) (-49 80870 83627 83796 "ALGSC" 83951 NIL ALGSC (NIL T NIL NIL NIL) -8 NIL NIL) (-48 77428 77982 78588 "ALGPKG" 80311 NIL ALGPKG (NIL T T) -7 NIL NIL) (-47 76705 76806 76990 "ALGMFACT" 77314 NIL ALGMFACT (NIL T T T) -7 NIL NIL) (-46 72453 73137 73788 "ALGMANIP" 76232 NIL ALGMANIP (NIL T T) -7 NIL NIL) (-45 63715 72079 72229 "ALGFF" 72386 NIL ALGFF (NIL T T T NIL) -8 NIL NIL) (-44 62911 63042 63221 "ALGFACT" 63573 NIL ALGFACT (NIL T) -7 NIL NIL) (-43 61896 62506 62545 "ALGEBRA" 62605 NIL ALGEBRA (NIL T) -9 NIL 62664) (-42 61614 61673 61805 "ALGEBRA-" 61810 NIL ALGEBRA- (NIL T T) -8 NIL NIL) (-41 43421 59146 59199 "ALAGG" 59335 NIL ALAGG (NIL T T) -9 NIL 59496) (-40 42956 43069 43096 "AHYP" 43297 T AHYP (NIL) -9 NIL NIL) (-39 41887 42135 42162 "AGG" 42661 T AGG (NIL) -9 NIL 42939) (-38 41321 41483 41697 "AGG-" 41702 NIL AGG- (NIL T) -8 NIL NIL) (-37 38870 39451 39490 "AFSPCAT" 40762 NIL AFSPCAT (NIL T) -9 NIL 41257) (-36 36549 36971 37388 "AF" 38513 NIL AF (NIL T T) -7 NIL NIL) (-35 35889 36478 36532 "AFFSP" 36537 NIL AFFSP (NIL NIL T) -8 NIL NIL) (-34 35146 35816 35865 "AFFPLPS" 35870 NIL AFFPLPS (NIL T) -8 NIL NIL) (-33 34480 35087 35129 "AFFPL" 35134 NIL AFFPL (NIL T) -8 NIL NIL) (-32 31193 31680 32308 "AFALGRES" 33985 NIL AFALGRES (NIL T NIL T T T) -7 NIL NIL) (-31 29839 30016 30330 "AFALGGRO" 31012 NIL AFALGGRO (NIL T NIL T T T) -7 NIL NIL) (-30 29108 29366 29522 "ACPLOT" 29701 T ACPLOT (NIL) -8 NIL NIL) (-29 18455 26438 26490 "ACFS" 27201 NIL ACFS (NIL T) -9 NIL 27440) (-28 16469 16959 17734 "ACFS-" 17739 NIL ACFS- (NIL T T) -8 NIL NIL) (-27 12669 14625 14652 "ACF" 15531 T ACF (NIL) -9 NIL 15944) (-26 11373 11707 12200 "ACF-" 12205 NIL ACF- (NIL T) -8 NIL NIL) (-25 10970 11139 11166 "ABELSG" 11258 T ABELSG (NIL) -9 NIL 11323) (-24 10837 10862 10928 "ABELSG-" 10933 NIL ABELSG- (NIL T) -8 NIL NIL) (-23 10205 10466 10493 "ABELMON" 10663 T ABELMON (NIL) -9 NIL 10775) (-22 9869 9953 10091 "ABELMON-" 10096 NIL ABELMON- (NIL T) -8 NIL NIL) (-21 9202 9548 9575 "ABELGRP" 9700 T ABELGRP (NIL) -9 NIL 9782) (-20 8665 8794 9010 "ABELGRP-" 9015 NIL ABELGRP- (NIL T) -8 NIL NIL) (-19 4333 8027 8067 "A1AGG" 8072 NIL A1AGG (NIL T) -9 NIL 8112) (-18 30 1251 2813 "A1AGG-" 2818 NIL A1AGG- (NIL T T) -8 NIL NIL)) 
\ No newline at end of file
diff --git a/src/share/algebra/operation.daase b/src/share/algebra/operation.daase
index ceeb58d..579f94f 100644
--- a/src/share/algebra/operation.daase
+++ b/src/share/algebra/operation.daase
@@ -1,3295 +1,3297 @@
 
-(842917 . 3575754976)        
-(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-1090 (-959 (-572)))) (-5 *3 (-959 (-572))) (-5 *1 (-330)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1090 (-959 (-572)))) (-5 *1 (-330))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-52 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-597 *3)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-4 *3 (-562)) (-5 *2 (-121)) (-5 *1 (-619 *3 *4)) (-4 *4 (-1234 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) ((*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-62 *4 *5 *2)) (-4 *4 (-1204)) (-4 *5 (-379 *4)) (-4 *2 (-379 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *6 *7 *2)) (-4 *6 (-1054)) (-4 *7 (-232 *5 *6)) (-4 *2 (-232 *4 *6))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-959 *4)) (-4 *4 (-13 (-303) (-151))) (-4 *2 (-956 *4 *6 *5)) (-5 *1 (-930 *4 *5 *6 *2)) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794))))) 
-(((*1 *2 *2 *1 *3 *4) (-12 (-5 *2 (-638 *8)) (-5 *3 (-1 *8 *8 *8)) (-5 *4 (-1 (-121) *8 *8)) (-4 *1 (-1198 *5 *6 *7 *8)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-638 *3))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-166)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *6)) (-5 *5 (-1 (-424 (-1166 *6)) (-1166 *6))) (-4 *6 (-368)) (-5 *2 (-638 (-2 (|:| |outval| *7) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 *7)))))) (-5 *1 (-539 *6 *7 *4)) (-4 *7 (-368)) (-4 *4 (-13 (-368) (-846)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))) (-5 *1 (-597 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -2148 *4) (|:| -3073 (-572))))) (-4 *4 (-1098)) (-5 *2 (-1 *4)) (-5 *1 (-1024 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-856))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-1179 *2)) (-4 *2 (-368))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *2 (-1042)) (-5 *1 (-301)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042)))) (-5 *2 (-1042)) (-5 *1 (-301))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-260 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-260 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-260 *2)) (-4 *2 (-1098)))) ((*1 *1 *2) (-12 (-5 *1 (-1191 *2)) (-4 *2 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1191 *3)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-638 (-1191 *2))) (-5 *1 (-1191 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-36 *3 *4)) (-4 *4 (-436 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-769)) (-5 *1 (-123)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-123)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *4)) (-4 *4 (-436 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-123)) (-5 *1 (-164)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *4)) (-4 *4 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-5 *1 (-297 *3)) (-4 *3 (-298)))) ((*1 *2 *2) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *4 (-848)) (-5 *1 (-435 *3 *4)) (-4 *3 (-436 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *4)) (-4 *4 (-436 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-123)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *4)) (-4 *4 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-1230 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-1170)) (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-244 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-1054)) (-5 *2 (-496 *4 *5)) (-5 *1 (-951 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *2 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1135 *4 *2)) (-14 *4 (-923)) (-4 *2 (-13 (-1054) (-10 -7 (-6 (-4604 "*"))))) (-5 *1 (-903 *4 *2))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-638 *8)) (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 *7)) (-5 *4 (-1 *7 (-769) (-769) *8)) (-5 *5 (-1259 *9)) (-5 *6 (-638 (-769))) (-4 *7 (-13 (-562) (-457))) (-4 *8 (-326 *7 (-769))) (-4 *9 (-326 (-413 *7) (-769))) (-5 *2 (-685 (-1166 *7))) (-5 *1 (-348 *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-638 *7)) (-5 *4 (-1 *7 (-769) (-769) *8)) (-5 *5 (-1259 *9)) (-5 *6 (-769)) (-4 *7 (-13 (-562) (-457))) (-4 *8 (-326 *7 *6)) (-4 *9 (-326 (-413 *7) *6)) (-5 *2 (-1150 (-685 (-1166 *7)))) (-5 *1 (-348 *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 *7)) (-5 *4 (-1 *7 (-769) (-769) *8)) (-5 *5 (-1259 *8)) (-5 *6 (-638 (-769))) (-4 *7 (-13 (-562) (-457))) (-4 *8 (-52 *7 (-769))) (-5 *2 (-685 (-1166 *7))) (-5 *1 (-349 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-638 *7)) (-5 *4 (-1 *7 (-769) (-769) *8)) (-5 *5 (-1259 *8)) (-5 *6 (-769)) (-4 *7 (-13 (-562) (-457))) (-4 *8 (-52 *7 *6)) (-5 *2 (-1150 (-685 (-1166 *7)))) (-5 *1 (-349 *7 *8))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-572)))) ((*1 *2 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-572)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-572))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-112)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-545))) (-5 *1 (-545))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-774 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-2 (|:| |val| (-638 *6)) (|:| -1337 *7)))) (-4 *6 (-1068 *3 *4 *5)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-996 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-2 (|:| |val| (-638 *6)) (|:| -1337 *7)))) (-4 *6 (-1068 *3 *4 *5)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1105 *3 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-959 *5)) (-4 *5 (-1054)) (-5 *2 (-496 *4 *5)) (-5 *1 (-951 *4 *5)) (-14 *4 (-638 (-1170)))))) 
-(((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 (-572))))) (-5 *1 (-366 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 (-769))))) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| -4304 *3) (|:| -3751 (-572))))) (-5 *1 (-424 *3)) (-4 *3 (-562)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 (-769))))) (-5 *1 (-820 *3)) (-4 *3 (-848))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-1170))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1177 (-638 *4))) (-4 *4 (-848)) (-5 *2 (-638 (-638 *4))) (-5 *1 (-1176 *4))))) 
-(((*1 *2) (-12 (-4 *3 (-1054)) (-5 *2 (-965 (-708 *3 *4))) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-645 *4)) (-4 *3 (-926 *4 *8)) (-4 *9 (-237 *3)) (-4 *10 (-540 *4 *5 *6 *7 *2 *8 *3 *9 *12)) (-4 *12 (-117)) (-4 *2 (-978 *4)) (-5 *1 (-471 *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-645 *4)) (-4 *2 (-978 *4)) (-5 *1 (-658 *4 *5 *6 *7 *2 *8 *3)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *3 (-926 *4 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-928 *4)) (-4 *4 (-353)) (-5 *2 (-974 *4)) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-927 *4)) (-4 *4 (-368)) (-5 *2 (-973 *4)) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-839)) (-5 *2 (-1042)) (-5 *1 (-838)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-312 (-385)))) (-5 *4 (-638 (-385))) (-5 *2 (-1042)) (-5 *1 (-838))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-303)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-1120 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-327 *3)) (-4 *3 (-1204)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-529 *3 *4)) (-4 *3 (-1204)) (-14 *4 (-572))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| |radicand| (-413 *5)) (|:| |deg| (-769)))) (-5 *1 (-152 *4 *5 *3)) (-4 *3 (-1234 (-413 *5)))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-804))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-1166 (-959 *4))) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) ((*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-4 *3 (-368)) (-5 *2 (-1166 (-959 *3))))) ((*1 *2) (-12 (-5 *2 (-1166 (-413 (-959 *3)))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1208)) (-5 *5 (-572)) (-4 *1 (-671 *3 *6)) (-4 *3 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1264))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-647 (-413 *2))) (-4 *2 (-1234 *4)) (-5 *1 (-811 *4 *2)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))))) ((*1 *2 *3) (-12 (-5 *3 (-648 *2 (-413 *2))) (-4 *2 (-1234 *4)) (-5 *1 (-811 *4 *2)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572)))))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-1035 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-638 (-685 *3))) (-4 *3 (-1054)) (-5 *1 (-1035 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-1035 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-685 *3))) (-4 *3 (-1054)) (-5 *1 (-1035 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *5 *5)) (-4 *5 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-2 (|:| |solns| (-638 *5)) (|:| |maps| (-638 (-2 (|:| |arg| *5) (|:| |res| *5)))))) (-5 *1 (-1124 *3 *5)) (-4 *3 (-1234 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-258))) (-5 *1 (-1260)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-258))) (-5 *1 (-1260)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-258))) (-5 *1 (-1261)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-258))) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-769)) (-4 *4 (-303)) (-4 *6 (-1234 *4)) (-5 *2 (-1259 (-638 *6))) (-5 *1 (-461 *4 *6)) (-5 *5 (-638 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-168 *3)) (-4 *3 (-174)) (-4 *3 (-1063)) (-4 *3 (-1190)) (-5 *2 (-2 (|:| |r| *3) (|:| |phi| *3)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| *8) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 *8))))) (-5 *1 (-930 *5 *6 *7 *8)) (-5 *4 (-769))))) 
-(((*1 *2 *3 *3 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-1 (-638 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-638 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-5 *1 (-500 *2)) (-4 *2 (-1234 (-572)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-121)) (-5 *1 (-182 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 (-171 *4)))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-121)) (-5 *1 (-1194 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4)))))) 
-(((*1 *2) (-12 (-5 *2 (-685 (-911 *3))) (-5 *1 (-355 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) ((*1 *2) (-12 (-5 *2 (-685 *3)) (-5 *1 (-356 *3 *4)) (-4 *3 (-353)) (-14 *4 (-3 (-1166 *3) (-1259 (-638 (-2 (|:| -2148 *3) (|:| -1763 (-1116))))))))) ((*1 *2) (-12 (-5 *2 (-685 *3)) (-5 *1 (-357 *3 *4)) (-4 *3 (-353)) (-14 *4 (-923))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *5)) (-4 *5 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-413 (-572))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-290 *3)) (-5 *5 (-413 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-572))) (-5 *4 (-290 *6)) (-4 *6 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-572))) (-5 *4 (-290 *7)) (-5 *5 (-1225 (-572))) (-4 *7 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-413 (-572)))) (-5 *4 (-290 *8)) (-5 *5 (-1225 (-413 (-572)))) (-5 *6 (-413 (-572))) (-4 *8 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-413 (-572)))) (-5 *7 (-413 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *8))) (-4 *8 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *8 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))) (-4 *3 (-1054)) (-5 *1 (-597 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-598 *3)))) ((*1 *1 *2 *3 *1) (-12 (-5 *2 (-572)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) ((*1 *1 *2) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))) (-4 *3 (-1054)) (-4 *1 (-1218 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-1150 (-2 (|:| |k| (-413 (-572))) (|:| |c| *4)))) (-4 *4 (-1054)) (-4 *1 (-1239 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-4 *1 (-1249 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-769)) (|:| |c| *3)))) (-4 *3 (-1054)) (-4 *1 (-1249 *3))))) 
-(((*1 *1 *2 *2) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-130))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-413 *2)) (-5 *4 (-1 *2 *2)) (-4 *2 (-1234 *5)) (-5 *1 (-723 *5 *2)) (-4 *5 (-368))))) 
-(((*1 *1 *2 *3) (-12 (-4 *1 (-388 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-5 *2 (-1150 *3)) (-5 *1 (-1154 *3)) (-4 *3 (-1054)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-820 *4)) (-4 *4 (-848)) (-4 *1 (-1274 *4 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *5 (-611 *4)) (-5 *6 (-1166 *4)) (-4 *4 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-568 *7 *4 *3)) (-4 *3 (-650 *4)) (-4 *3 (-1098)))) ((*1 *2 *3 *4 *5 *5 *5 *4 *6) (-12 (-5 *5 (-611 *4)) (-5 *6 (-413 (-1166 *4))) (-4 *4 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-568 *7 *4 *3)) (-4 *3 (-650 *4)) (-4 *3 (-1098))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 (-413 *3))) (-5 *1 (-175 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-1259 *5)) (-5 *3 (-769)) (-5 *4 (-1116)) (-4 *5 (-353)) (-5 *1 (-536 *5))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1281 *4 *2)) (-4 *1 (-380 *4 *2)) (-4 *4 (-848)) (-4 *2 (-174)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1274 *3 *2)) (-4 *3 (-848)) (-4 *2 (-1054)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-820 *4)) (-4 *1 (-1274 *4 *2)) (-4 *4 (-848)) (-4 *2 (-1054)))) ((*1 *2 *1 *3) (-12 (-4 *2 (-1054)) (-5 *1 (-1280 *2 *3)) (-4 *3 (-844))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2) (|partial| -12 (-4 *3 (-562)) (-4 *3 (-174)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2237 (-638 *1)))) (-4 *1 (-372 *3)))) ((*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-458 *3 *4 *5 *6)) (|:| -2237 (-638 (-458 *3 *4 *5 *6))))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-426 *3 *2 *4 *5)) (-4 *2 (-13 (-27) (-1190) (-436 *3))) (-14 *4 (-1170)) (-14 *5 *2))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-4 *2 (-13 (-27) (-1190) (-436 *3) (-10 -8 (-15 -3972 ($ *4))))) (-4 *4 (-846)) (-4 *5 (-13 (-1236 *2 *4) (-368) (-1190) (-10 -8 (-15 -3139 ($ $)) (-15 -2774 ($ $))))) (-5 *1 (-428 *3 *2 *4 *5 *6 *7)) (-4 *6 (-991 *5)) (-14 *7 (-1170))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-1116)) (-4 *4 (-353)) (-5 *1 (-536 *4))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-881 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-881 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-950 (-217)) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-883 (-1 (-217) (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-883 (-1 (-217) (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-250)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-881 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-881 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *5)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1090 (-385))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-883 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *6)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-883 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1129 (-217))) (-5 *1 (-254 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-140))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-495))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |answer| *3) (|:| |polypart| *3))) (-5 *1 (-582 *5 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-250)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1260)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-879 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-250)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-879 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1260)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-881 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-881 (-1 (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-950 (-217)) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-883 (-1 (-217) (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-883 (-1 (-217) (-217) (-217)))) (-5 *4 (-1092 (-385))) (-5 *2 (-1261)) (-5 *1 (-250)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-290 *7)) (-5 *4 (-1170)) (-5 *5 (-638 (-258))) (-4 *7 (-436 *6)) (-4 *6 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-1260)) (-5 *1 (-251 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-385))) (-5 *2 (-1260)) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-879 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1260)) (-5 *1 (-254 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-879 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1260)) (-5 *1 (-254 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-881 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1261)) (-5 *1 (-254 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-881 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1261)) (-5 *1 (-254 *5)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1090 (-385))) (-5 *2 (-1261)) (-5 *1 (-254 *3)) (-4 *3 (-13 (-613 (-545)) (-1098))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-883 *6)) (-5 *4 (-1090 (-385))) (-5 *5 (-638 (-258))) (-4 *6 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1261)) (-5 *1 (-254 *6)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-883 *5)) (-5 *4 (-1090 (-385))) (-4 *5 (-13 (-613 (-545)) (-1098))) (-5 *2 (-1261)) (-5 *1 (-254 *5)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-1260)) (-5 *1 (-255)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 (-217))) (-5 *4 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-255)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-950 (-217)))) (-5 *2 (-1260)) (-5 *1 (-255)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-950 (-217)))) (-5 *4 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-255)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-1261)) (-5 *1 (-255)))) ((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-638 (-217))) (-5 *4 (-638 (-258))) (-5 *2 (-1261)) (-5 *1 (-255))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-769)) (-4 *5 (-353)) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-2 (|:| -2237 (-685 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-685 *6))))) (-5 *1 (-511 *5 *6 *7)) (-5 *3 (-2 (|:| -2237 (-685 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-685 *6)))) (-4 *7 (-1234 *6))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1042)) (-5 *1 (-301)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-1042))) (-5 *2 (-1042)) (-5 *1 (-301)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-644 *2)) (-4 *2 (-1204)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-644 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-644 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *1) (-5 *1 (-1066))) ((*1 *2 *3) (-12 (-5 *3 (-1150 (-1150 *4))) (-5 *2 (-1150 *4)) (-5 *1 (-1147 *4)) (-4 *4 (-1204)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-638 *1)) (-4 *1 (-298)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-123)) (-5 *3 (-638 *5)) (-5 *4 (-769)) (-4 *5 (-848)) (-5 *1 (-611 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 *14)) (-4 *14 (-260 *13)) (-4 *13 (-540 *5 *6 *7 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) *3)) (-4 *9 (-978 *5)) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-4 *12 (-237 *11)) (-5 *3 (-769)) (-5 *2 (-572)) (-5 *1 (-262 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *4 (-956 *5 *7 (-858 *6))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *3 (-978 *5)) (-4 *8 (-645 *5)) (-4 *9 (-926 *5 *8)) (-4 *10 (-237 *9)) (-4 *12 (-117)) (-4 *2 (-260 *11)) (-5 *1 (-262 *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (-4 *11 (-540 *5 *6 *4 *7 *3 *8 *9 *10 *12))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1121 (-572) (-611 (-53)))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *3 (-1000 *2)) (-4 *4 (-1234 *3)) (-4 *2 (-303)) (-5 *1 (-419 *2 *3 *4 *5)) (-4 *5 (-13 (-415 *3 *4) (-1044 *3))))) ((*1 *2 *1) (-12 (-4 *3 (-562)) (-4 *3 (-848)) (-5 *2 (-1121 *3 (-611 *1))) (-4 *1 (-436 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1121 (-572) (-611 (-508)))) (-5 *1 (-508)))) ((*1 *2 *1) (-12 (-4 *4 (-174)) (-4 *2 (|SubsetCategory| (-722) *4)) (-5 *1 (-617 *3 *4 *2)) (-4 *3 (-43 *4)))) ((*1 *2 *1) (-12 (-4 *4 (-174)) (-4 *2 (|SubsetCategory| (-722) *4)) (-5 *1 (-656 *3 *4 *2)) (-4 *3 (-713 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *1 (-565 *2)) (-4 *2 (-554))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1182 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1121 (-572) (-611 (-53)))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *3 (-303)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-1259 *6)) (-5 *1 (-419 *3 *4 *5 *6)) (-4 *6 (-13 (-415 *4 *5) (-1044 *4))))) ((*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *3 (-848)) (-5 *2 (-1121 *3 (-611 *1))) (-4 *1 (-436 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1121 (-572) (-611 (-508)))) (-5 *1 (-508)))) ((*1 *2 *1) (-12 (-4 *3 (-174)) (-4 *2 (-43 *3)) (-5 *1 (-617 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-722) *3)))) ((*1 *2 *1) (-12 (-4 *3 (-174)) (-4 *2 (-713 *3)) (-5 *1 (-656 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-722) *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-408)) (-5 *2 (-769)))) ((*1 *1 *1) (-4 *1 (-408)))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-413 *5)) (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-5 *1 (-152 *4 *5 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1172 (-413 (-572)))) (-5 *2 (-413 (-572))) (-5 *1 (-184)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-685 (-312 (-217)))) (-5 *3 (-638 (-1170))) (-5 *4 (-1259 (-312 (-217)))) (-5 *1 (-199)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-290 *3))) (-4 *3 (-305 *3)) (-4 *3 (-1098)) (-4 *3 (-1204)) (-5 *1 (-290 *3)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-305 *2)) (-4 *2 (-1098)) (-4 *2 (-1204)) (-5 *1 (-290 *2)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 *1)) (-4 *1 (-298)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 (-638 *1))) (-4 *1 (-298)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-123))) (-5 *3 (-638 (-1 *1 (-638 *1)))) (-4 *1 (-298)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-123))) (-5 *3 (-638 (-1 *1 *1))) (-4 *1 (-298)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1 *1 *1)) (-4 *1 (-298)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1 *1 (-638 *1))) (-4 *1 (-298)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-638 (-1 *1 (-638 *1)))) (-4 *1 (-298)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-638 (-1 *1 *1))) (-4 *1 (-298)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-290 *3))) (-4 *1 (-305 *3)) (-4 *3 (-1098)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-290 *3)) (-4 *1 (-305 *3)) (-4 *3 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-572))) (-5 *4 (-1172 (-413 (-572)))) (-5 *1 (-306 *2)) (-4 *2 (-43 (-413 (-572)))))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *4)) (-5 *3 (-638 *1)) (-4 *1 (-380 *4 *5)) (-4 *4 (-848)) (-4 *5 (-174)))) ((*1 *1 *1 *2 *1) (-12 (-4 *1 (-380 *2 *3)) (-4 *2 (-848)) (-4 *3 (-174)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-769)) (-5 *4 (-1 *1 *1)) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-1054)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-769)) (-5 *4 (-1 *1 (-638 *1))) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-1054)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-638 (-769))) (-5 *4 (-638 (-1 *1 (-638 *1)))) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-1054)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-638 (-769))) (-5 *4 (-638 (-1 *1 *1))) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-1054)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-123))) (-5 *3 (-638 *1)) (-5 *4 (-1170)) (-4 *1 (-436 *5)) (-4 *5 (-848)) (-4 *5 (-613 (-545))))) ((*1 *1 *1 *2 *1 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1170)) (-4 *1 (-436 *4)) (-4 *4 (-848)) (-4 *4 (-613 (-545))))) ((*1 *1 *1) (-12 (-4 *1 (-436 *2)) (-4 *2 (-848)) (-4 *2 (-613 (-545))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-1170))) (-4 *1 (-436 *3)) (-4 *3 (-848)) (-4 *3 (-613 (-545))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)) (-4 *3 (-613 (-545))))) ((*1 *2 *3 *4) (-12 (-14 *5 (-638 (-1170))) (-4 *3 (-956 *2 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *2)) (-4 *8 (-645 *2)) (-4 *4 (-926 *2 *8)) (-4 *9 (-237 *4)) (-4 *10 (-540 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2 *3 *3 *4) (-12 (-14 *5 (-638 (-1170))) (-4 *3 (-956 *2 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *2)) (-4 *8 (-645 *2)) (-4 *4 (-926 *2 *8)) (-4 *9 (-237 *4)) (-4 *10 (-540 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 *6)) (-4 *6 (-956 *2 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-14 *5 (-638 (-1170))) (-4 *8 (-978 *2)) (-4 *9 (-645 *2)) (-4 *4 (-926 *2 *9)) (-4 *10 (-237 *4)) (-4 *11 (-540 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *1 *1 *2 *3) (-12 (-4 *1 (-527 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1204)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *4)) (-5 *3 (-638 *5)) (-4 *1 (-527 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1204)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-834 *3)) (-4 *3 (-368)) (-5 *1 (-714 *3)))) ((*1 *2 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-244 *5 *2)) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-244 *5 *2)) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-244 *5 *2))) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-244 *5 *2)) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-244 *5 *2)) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-244 *5 *2))) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-904 *2)) (-4 *2 (-1098)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-4 *2 (-368)) (-5 *1 (-935 *2 *3 *5 *6 *4)) (-4 *3 (-326 *2 *5)) (-4 *4 (-978 *2)))) ((*1 *2 *2 *3 *2) (-12 (-5 *2 (-413 (-959 *4))) (-5 *3 (-1170)) (-4 *4 (-562)) (-5 *1 (-1049 *4)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-638 (-1170))) (-5 *4 (-638 (-413 (-959 *5)))) (-5 *2 (-413 (-959 *5))) (-4 *5 (-562)) (-5 *1 (-1049 *5)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-290 (-413 (-959 *4)))) (-5 *2 (-413 (-959 *4))) (-4 *4 (-562)) (-5 *1 (-1049 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-290 (-413 (-959 *4))))) (-5 *2 (-413 (-959 *4))) (-4 *4 (-562)) (-5 *1 (-1049 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1236 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (|has| *3 (-15 ** (*3 *3 *4))) (-5 *2 (-1150 *3))))) 
-(((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)) (-5 *2 (-1166 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)) (-5 *2 (-1166 *3))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3069 (-783 *3)) (|:| |coef2| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -3069 *1) (|:| |coef2| *1))) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-1044 (-572)) (-151))) (-5 *2 (-2 (|:| -3444 (-413 (-959 *5))) (|:| |coeff| (-413 (-959 *5))))) (-5 *1 (-578 *5)) (-5 *3 (-413 (-959 *5)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1119 *3 *4 *2 *5)) (-4 *4 (-1054)) (-4 *5 (-232 *3 *4)) (-4 *2 (-232 *3 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-757))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1054)) (-5 *1 (-320 *4 *5 *2 *6)) (-4 *6 (-956 *2 *4 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-904 *3))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-379 *2)) (-4 *2 (-1204)) (-4 *2 (-848)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-379 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-976 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1130 *2)) (-4 *2 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-1158 *3 *4))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-4 *4 (-353)) (-5 *2 (-769)) (-5 *1 (-350 *4)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-355 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-356 *3 *4)) (-4 *3 (-353)) (-14 *4 (-3 (-1166 *3) (-1259 (-638 (-2 (|:| -2148 *3) (|:| -1763 (-1116))))))))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-357 *3 *4)) (-4 *3 (-353)) (-14 *4 (-923))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-559 *3)) (-4 *3 (-13 (-410) (-1190))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-846)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1070 *4 *3)) (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-121))))) 
-(((*1 *1) (-5 *1 (-1261)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-5 *1 (-1179 *2)) (-4 *2 (-368))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1166 *2)) (-4 *2 (-956 (-413 (-959 *6)) *5 *4)) (-5 *1 (-728 *5 *4 *6 *2)) (-4 *5 (-794)) (-4 *4 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *6 (-562))))) 
-(((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-503 *3)) (-4 *3 (-1204)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-733 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-1140 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1200 *3)) (-4 *3 (-982))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-409 *3)) (-4 *3 (-410)))) ((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-409 *3)) (-4 *3 (-410)))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (|has| *1 (-6 -4593)) (-4 *1 (-410)))) ((*1 *2) (-12 (-4 *1 (-410)) (-5 *2 (-923)))) ((*1 *2 *1) (-12 (-4 *1 (-869 *3)) (-5 *2 (-1150 (-572)))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *2 (-926 *5 *8)) (-5 *1 (-658 *5 *6 *4 *7 *3 *8 *2)) (-4 *4 (-956 *5 *7 (-858 *6))) (-4 *3 (-978 *5)) (-4 *8 (-645 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1262))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-1095 *3)))) ((*1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-130))))) 
-(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 (-2 (|:| -3444 *4) (|:| |coeff| *4)) "failed") *4)) (-4 *4 (-368)) (-5 *1 (-582 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-540 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *10)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-260 *11)))) ((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-540 *3 *4 *5 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *9)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2) (-12 (-5 *2 (-238 (-928 *3))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-238 (-927 *3))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-171 (-572)))))) (-5 *2 (-638 (-638 (-290 (-959 (-171 *4)))))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-290 (-413 (-959 (-171 (-572))))))) (-5 *2 (-638 (-638 (-290 (-959 (-171 *4)))))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-171 (-572))))) (-5 *2 (-638 (-290 (-959 (-171 *4))))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-290 (-413 (-959 (-171 (-572)))))) (-5 *2 (-638 (-290 (-959 (-171 *4))))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846)))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *4 *6) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-572)) (-5 *2 (-1200 (-932))) (-5 *1 (-315)))) ((*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-572)) (-5 *7 (-1152)) (-5 *2 (-1200 (-932))) (-5 *1 (-315)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-217)) (-5 *7 (-572)) (-5 *2 (-1200 (-932))) (-5 *1 (-315)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-217)) (-5 *7 (-572)) (-5 *8 (-1152)) (-5 *2 (-1200 (-932))) (-5 *1 (-315))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-274 *4 *3)) (-4 *3 (-13 (-436 *4) (-1009)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *2 (-638 (-1092 (-217)))) (-5 *1 (-934))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-209 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 *5)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)) (-4 *5 (-174))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-413 (-572))) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-312 (-413 (-572)))) (-5 *1 (-301))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-57)) (-5 *1 (-1183))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *5 *6 *7 *3 *4)) (-4 *4 (-1107 *5 *6 *7 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-403))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4)))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-850 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-562)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-851 *5 *3)) (-4 *3 (-850 *5))))) 
-(((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-3 (-413 (-959 *6)) (-1159 (-1170) (-959 *6)))) (-5 *5 (-769)) (-4 *6 (-457)) (-5 *2 (-638 (-685 (-413 (-959 *6))))) (-5 *1 (-288 *6)) (-5 *4 (-685 (-413 (-959 *6)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-2 (|:| |eigval| (-3 (-413 (-959 *5)) (-1159 (-1170) (-959 *5)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 *4)))) (-4 *5 (-457)) (-5 *2 (-638 (-685 (-413 (-959 *5))))) (-5 *1 (-288 *5)) (-5 *4 (-685 (-413 (-959 *5))))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-1054)) (-4 *2 (-174))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1017 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 *5)) (-4 *5 (-13 (-562) (-457))) (-5 *4 (-769)) (-5 *2 (-413 (-1166 *5))) (-5 *1 (-349 *5 *6)) (-4 *6 (-52 *5 *4)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 (-413 *5))) (-4 *5 (-13 (-562) (-457))) (-5 *4 (-769)) (-5 *2 (-413 (-1166 *5))) (-5 *1 (-349 *5 *6)) (-4 *6 (-52 *5 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1231 *4 *5)) (-5 *3 (-638 *5)) (-14 *4 (-1170)) (-4 *5 (-368)) (-5 *1 (-925 *4 *5)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 *5)) (-4 *5 (-368)) (-5 *2 (-1166 *5)) (-5 *1 (-925 *4 *5)) (-14 *4 (-1170)))) ((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-769)) (-4 *6 (-368)) (-5 *2 (-413 (-959 *6))) (-5 *1 (-1055 *5 *6)) (-14 *5 (-1170))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 *4)) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-638 (-950 *4))) (-4 *1 (-1130 *4)) (-4 *4 (-1054)) (-5 *2 (-769))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *2)) (-4 *2 (-139)) (-5 *1 (-1083 *2)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-572) *2 *2)) (-4 *2 (-139)) (-5 *1 (-1083 *2))))) 
-(((*1 *2 *3 *1) (|partial| -12 (-5 *3 (-893 *4)) (-4 *4 (-1098)) (-4 *2 (-1098)) (-5 *1 (-890 *4 *2))))) 
-(((*1 *1 *1) (-4 *1 (-864)))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-611 (-53)))) (-5 *1 (-53)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-611 (-53))) (-5 *1 (-53)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1166 (-53))) (-5 *3 (-638 (-611 (-53)))) (-5 *1 (-53)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1166 (-53))) (-5 *3 (-611 (-53))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-368) (-846))) (-5 *1 (-180 *2 *3)) (-4 *3 (-1234 (-171 *2))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)))) ((*1 *2 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-368)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *3 (-1234 *2)) (-4 *2 (-174)))) ((*1 *2 *1) (-12 (-4 *4 (-1234 *2)) (-4 *2 (-1000 *3)) (-5 *1 (-419 *3 *2 *4 *5)) (-4 *3 (-303)) (-4 *5 (-13 (-415 *2 *4) (-1044 *2))))) ((*1 *2 *1) (-12 (-4 *4 (-1234 *2)) (-4 *2 (-1000 *3)) (-5 *1 (-420 *3 *2 *4 *5 *6)) (-4 *3 (-303)) (-4 *5 (-415 *2 *4)) (-14 *6 (-1259 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *2 (-13 (-410) (-1044 *5) (-368) (-1190) (-281))) (-5 *1 (-448 *5 *3 *2)) (-4 *3 (-1234 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-611 (-508)))) (-5 *1 (-508)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-611 (-508))) (-5 *1 (-508)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1166 (-508))) (-5 *3 (-638 (-611 (-508)))) (-5 *1 (-508)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1166 (-508))) (-5 *3 (-611 (-508))) (-5 *1 (-508)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-923)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-720 *4 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-773 *4 *2 *5 *3)) (-4 *3 (-1234 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) ((*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) ((*1 *1 *1) (-4 *1 (-1063)))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-413 (-572))) (-5 *1 (-217)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-413 (-572))) (-5 *1 (-217)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-413 (-572))) (-5 *1 (-385)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-413 (-572))) (-5 *1 (-385))))) 
-(((*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1052))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) ((*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1074 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1106 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(((*1 *1 *1 *2 *2 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-932)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *2 *2 *2 *2 *3) (-12 (-5 *2 (-685 *4)) (-5 *3 (-769)) (-4 *4 (-1054)) (-5 *1 (-686 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-413 (-572))) (-5 *1 (-439 *4 *3)) (-4 *3 (-436 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-611 *3)) (-4 *3 (-436 *5)) (-4 *5 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-1166 (-413 (-572)))) (-5 *1 (-439 *5 *3))))) 
-(((*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-638 *9)) (-5 *3 (-1 (-121) *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1068 *6 *7 *8)) (-4 *6 (-562)) (-4 *7 (-794)) (-4 *8 (-848)) (-5 *1 (-985 *6 *7 *8 *9))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1129 (-217))) (-5 *3 (-638 (-258))) (-5 *1 (-1261)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1129 (-217))) (-5 *3 (-1152)) (-5 *1 (-1261)))) ((*1 *1 *1) (-5 *1 (-1261)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (-5 *1 (-265))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-783 *2)) (-4 *2 (-562)) (-4 *2 (-1054)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) ((*1 *2 *3 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *1)))) (-4 *1 (-1073 *4 *5 *6 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-638 *4))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-638 (-1259 *4))) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-4 *3 (-562)) (-5 *2 (-638 (-1259 *3)))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *2 (-13 (-436 *4) (-887 *3) (-613 (-893 *3)))) (-5 *1 (-1076 *3 *4 *2)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))))) ((*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-1159 *2 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3069 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-1131)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-856))) (-5 *2 (-1264)) (-5 *1 (-1131))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-1158 3 *3)))) ((*1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1129 (-217))) (-5 *1 (-1261)))) ((*1 *2 *1) (-12 (-5 *2 (-1129 (-217))) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-121)) (-5 *1 (-830))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-363 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009)))))) 
-(((*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| -12 (-5 *2 (-638 (-1166 *13))) (-5 *3 (-1166 *13)) (-5 *4 (-638 *12)) (-5 *5 (-638 *10)) (-5 *6 (-638 *13)) (-5 *7 (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| *13))))) (-5 *8 (-638 (-769))) (-5 *9 (-1259 (-638 (-1166 *10)))) (-4 *12 (-848)) (-4 *10 (-303)) (-4 *13 (-956 *10 *11 *12)) (-4 *11 (-794)) (-5 *1 (-703 *11 *12 *10 *13))))) 
-(((*1 *2) (-12 (-5 *2 (-1178 (-1085 *3) (-1085 *3))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *2 (-1098)) (-5 *1 (-1182 *3 *2)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1173))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1033 (-841 (-572)))) (-5 *1 (-597 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1234 (-572))) (-5 *1 (-500 *3))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 *2)) (-5 *1 (-179 *2)) (-4 *2 (-303)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-638 (-638 *4))) (-5 *2 (-638 *4)) (-4 *4 (-303)) (-5 *1 (-179 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 (-2 (|:| -2237 (-685 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-685 *7))))) (-5 *5 (-769)) (-4 *8 (-1234 *7)) (-4 *7 (-1234 *6)) (-4 *6 (-353)) (-5 *2 (-2 (|:| -2237 (-685 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-685 *7)))) (-5 *1 (-511 *6 *7 *8)))) ((*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-638 (-638 *7))) (-5 *1 (-453 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-956 *5 *6 *7)) (-5 *2 (-638 (-638 *8))) (-5 *1 (-453 *5 *6 *7 *8)) (-5 *3 (-638 *8))))) 
-(((*1 *2) (-12 (-5 *2 (-1140 (-1152))) (-5 *1 (-397))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1100 (-1170))) (-5 *1 (-58)) (-5 *3 (-1170))))) 
-(((*1 *2) (-12 (-4 *1 (-410)) (-5 *2 (-923)))) ((*1 *1) (-4 *1 (-554))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-694)))) ((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-694)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-905 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1 *2) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *1 *4) (-12 (-5 *3 (-1133 *5 *6)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1098) (-39))) (-4 *6 (-13 (-1098) (-39))) (-5 *2 (-121)) (-5 *1 (-1134 *5 *6))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (|has| *1 (-6 -4603)) (-4 *1 (-1246 *3)) (-4 *3 (-1204))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *3 (-1204)) (-5 *1 (-181 *3 *2)) (-4 *2 (-669 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-572)) (-5 *1 (-454 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1166 (-959 *6))) (-4 *6 (-562)) (-4 *2 (-956 (-413 (-959 *6)) *5 *4)) (-5 *1 (-728 *5 *4 *6 *2)) (-4 *5 (-794)) (-4 *4 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)))))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-794)) (-4 *3 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *5 (-562)) (-5 *1 (-728 *4 *3 *5 *2)) (-4 *2 (-956 (-413 (-959 *5)) *4 *3)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-5 *1 (-992 *4 *5 *3 *2)) (-4 *2 (-956 (-959 *4) *5 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-4 *4 (-1054)) (-4 *5 (-794)) (-5 *1 (-992 *4 *5 *6 *2)) (-4 *2 (-956 (-959 *4) *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-647 (-413 *6))) (-5 *4 (-413 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-811 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-647 (-413 *6))) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-2 (|:| -2237 (-638 (-413 *6))) (|:| -1369 (-685 *5)))) (-5 *1 (-811 *5 *6)) (-5 *4 (-638 (-413 *6))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-648 *6 (-413 *6))) (-5 *4 (-413 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-811 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-648 *6 (-413 *6))) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-2 (|:| -2237 (-638 (-413 *6))) (|:| -1369 (-685 *5)))) (-5 *1 (-811 *5 *6)) (-5 *4 (-638 (-413 *6)))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)))) ((*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-638 (-1170))))) ((*1 *1 *1) (-12 (-5 *1 (-215 *2 *3)) (-4 *2 (-13 (-1054) (-848))) (-14 *3 (-638 (-1170))))) ((*1 *1 *1) (-12 (-5 *1 (-238 *2)) (-4 *2 (-1096)))) ((*1 *1 *1) (-12 (-4 *1 (-388 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-1098)))) ((*1 *1 *1) (-12 (-14 *2 (-638 (-1170))) (-4 *3 (-174)) (-4 *5 (-232 (-4032 *2) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *4) (|:| -3751 *5)) (-2 (|:| -1763 *4) (|:| -3751 *5)))) (-5 *1 (-467 *2 *3 *4 *5 *6 *7)) (-4 *4 (-848)) (-4 *7 (-956 *3 *5 (-858 *2))))) ((*1 *1 *1) (-12 (-4 *1 (-522 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-848)))) ((*1 *1 *1) (-12 (-4 *2 (-562)) (-5 *1 (-619 *2 *3)) (-4 *3 (-1234 *2)))) ((*1 *1 *1) (-12 (-4 *1 (-704 *2)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-731 *2 *3)) (-4 *3 (-848)) (-4 *2 (-1054)) (-4 *3 (-722)))) ((*1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-5 *1 (-1280 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-844))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-173))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1170)) (-5 *2 (-1174)) (-5 *1 (-1173))))) 
-(((*1 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848))) (-5 *2 (-171 *5)) (-5 *1 (-601 *4 *5 *3)) (-4 *5 (-13 (-436 *4) (-1009) (-1190))) (-4 *3 (-13 (-436 (-171 *4)) (-1009) (-1190)))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-956 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-496 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-1054)) (-5 *2 (-959 *5)) (-5 *1 (-951 *4 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *3)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 (-638 *7) (-638 *7))) (-5 *2 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *7))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) ((*1 *2 *1) (-12 (-4 *2 (-1054)) (-5 *1 (-55 *2 *3)) (-14 *3 (-638 (-1170))))) ((*1 *2 *1) (-12 (-5 *2 (-312 *3)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) ((*1 *2 *1) (-12 (-4 *1 (-388 *2 *3)) (-4 *3 (-1098)) (-4 *2 (-1054)))) ((*1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *5 (-232 (-4032 *3) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *4) (|:| -3751 *5)) (-2 (|:| -1763 *4) (|:| -3751 *5)))) (-4 *2 (-174)) (-5 *1 (-467 *3 *2 *4 *5 *6 *7)) (-4 *4 (-848)) (-4 *7 (-956 *2 *5 (-858 *3))))) ((*1 *2 *1) (-12 (-4 *1 (-522 *2 *3)) (-4 *3 (-848)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *2 (-562)) (-5 *1 (-619 *2 *3)) (-4 *3 (-1234 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-704 *2)) (-4 *2 (-1054)))) ((*1 *2 *1) (-12 (-4 *2 (-1054)) (-5 *1 (-731 *2 *3)) (-4 *3 (-848)) (-4 *3 (-722)))) ((*1 *2 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)))) ((*1 *2 *1) (-12 (-4 *1 (-981 *2 *3 *4)) (-4 *3 (-793)) (-4 *4 (-848)) (-4 *2 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-57))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1108))))) 
-(((*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| -12 (-5 *3 (-611 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1170))) (-5 *5 (-1166 *2)) (-4 *2 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *1 (-568 *6 *2 *7)) (-4 *7 (-1098)))) ((*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| -12 (-5 *3 (-611 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1170))) (-5 *5 (-413 (-1166 *2))) (-4 *2 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *1 (-568 *6 *2 *7)) (-4 *7 (-1098))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)))) ((*1 *2 *1) (-12 (-4 *1 (-388 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-4 *6 (-232 (-4032 *3) (-769))) (-14 *7 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *6)) (-2 (|:| -1763 *5) (|:| -3751 *6)))) (-5 *2 (-709 *5 *6 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8)) (-4 *5 (-848)) (-4 *8 (-956 *4 *6 (-858 *3))))) ((*1 *2 *1) (-12 (-4 *2 (-722)) (-4 *2 (-848)) (-5 *1 (-731 *3 *2)) (-4 *3 (-1054)))) ((*1 *1 *1) (-12 (-4 *1 (-981 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *4 (-848))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *7 (-1234 *5)) (-4 *4 (-720 *5 *7)) (-5 *2 (-2 (|:| -1369 (-685 *6)) (|:| |vec| (-1259 *5)))) (-5 *1 (-812 *5 *6 *7 *4 *3)) (-4 *6 (-650 *5)) (-4 *3 (-650 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3)))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) ((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-694))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-910)) (-5 *2 (-424 (-1166 *1))) (-5 *3 (-1166 *1))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-769)) (-5 *1 (-1099 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-326 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) ((*1 *2 *1) (-12 (-4 *1 (-436 *2)) (-4 *2 (-848))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-1092 *3)) (-4 *3 (-956 *7 *6 *4)) (-4 *6 (-794)) (-4 *4 (-848)) (-4 *7 (-562)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-572)))) (-5 *1 (-596 *6 *4 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-562)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-572)))) (-5 *1 (-596 *5 *4 *6 *3)) (-4 *3 (-956 *6 *5 *4)))) ((*1 *1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1161 *4 *2)) (-4 *2 (-13 (-436 *4) (-162) (-27) (-1190))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1090 *2)) (-4 *2 (-13 (-436 *4) (-162) (-27) (-1190))) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1161 *4 *2)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-413 (-959 *5))) (-5 *1 (-1162 *5)) (-5 *3 (-959 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-3 (-413 (-959 *5)) (-312 *5))) (-5 *1 (-1162 *5)) (-5 *3 (-413 (-959 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-959 *5))) (-5 *3 (-959 *5)) (-4 *5 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-413 *3)) (-5 *1 (-1162 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-413 (-959 *5)))) (-5 *3 (-413 (-959 *5))) (-4 *5 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-3 *3 (-312 *5))) (-5 *1 (-1162 *5))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-413 *6)) (|:| |c| (-413 *6)) (|:| -3512 *6))) (-5 *1 (-1022 *5 *6)) (-5 *3 (-413 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-436 *3)) (-4 *3 (-848)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-739 *3 *4)) (-14 *3 (-1170)) (-4 *4 (-13 (-1054) (-848) (-562))))) ((*1 *2 *1) (-12 (-4 *1 (-864)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-623 *5 *6))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-67 *3)) (-14 *3 (-1170)))) ((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-74 *3)) (-14 *3 (-1170)))) ((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-77 *3)) (-14 *3 (-1170)))) ((*1 *2 *1) (-12 (-4 *1 (-401)) (-5 *2 (-1264)))) ((*1 *2 *3) (-12 (-5 *3 (-394)) (-5 *2 (-1264)) (-5 *1 (-403)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-856)) (-5 *2 (-1264)) (-5 *1 (-1131)))) ((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-1131)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-856))) (-5 *2 (-1264)) (-5 *1 (-1131))))) 
-(((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-638 *1)) (-4 *1 (-922))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-572))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-322 *2 *4)) (-4 *4 (-138)) (-4 *2 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-366 *2)) (-4 *2 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-392 *2)) (-4 *2 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *2 (-1098)) (-5 *1 (-642 *2 *4 *5)) (-4 *4 (-23)) (-14 *5 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-820 *2)) (-4 *2 (-848))))) 
-(((*1 *1 *1) (-4 *1 (-240))) ((*1 *1 *1) (-12 (-4 *2 (-174)) (-5 *1 (-286 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1234 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (-1841 (-12 (-5 *1 (-290 *2)) (-4 *2 (-368)) (-4 *2 (-1204))) (-12 (-5 *1 (-290 *2)) (-4 *2 (-482)) (-4 *2 (-1204))))) ((*1 *1 *1) (-4 *1 (-482))) ((*1 *2 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-353)) (-5 *1 (-536 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)) (-4 *2 (-368))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-397))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-565 *3)) (-4 *3 (-554))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-436 *2)) (-4 *2 (-848)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) ((*1 *1 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1166 *9)) (-5 *4 (-638 *7)) (-4 *7 (-848)) (-4 *9 (-956 *8 *6 *7)) (-4 *6 (-794)) (-4 *8 (-303)) (-5 *2 (-638 (-769))) (-5 *1 (-738 *6 *7 *8 *9)) (-5 *5 (-769))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-769)) (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1 *2 *2 *2) (-12 (-5 *2 (-1152)) (-4 *1 (-395))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *3))))) 
-(((*1 *1 *1 *2 *1) (-12 (-5 *1 (-137 *2)) (-4 *2 (-1098)))) ((*1 *1 *2) (-12 (-5 *1 (-137 *2)) (-4 *2 (-1098))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *1 (-106 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-394)) (-5 *2 (-1264)) (-5 *1 (-397)))) ((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-397))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-368)) (-4 *1 (-329 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-1234 *4)) (-4 *4 (-1214)) (-4 *1 (-342 *4 *3 *5)) (-4 *5 (-1234 (-413 *3))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-1259 *1)) (-4 *4 (-174)) (-4 *1 (-372 *4)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-1259 *1)) (-4 *4 (-174)) (-4 *1 (-376 *4 *5)) (-4 *5 (-1234 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-174)) (-4 *1 (-415 *3 *4)) (-4 *4 (-1234 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-174)) (-4 *1 (-423 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-757))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1166 (-413 (-1166 *2)))) (-5 *4 (-611 *2)) (-4 *2 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *1 (-568 *5 *2 *6)) (-4 *6 (-1098)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-956 *4 *5 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1166 *4)) (-4 *4 (-1054)) (-4 *1 (-956 *4 *5 *3)) (-4 *5 (-794)) (-4 *3 (-848)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-1166 *2))) (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-1054)) (-4 *2 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))) (-5 *1 (-957 *5 *4 *6 *7 *2)) (-4 *7 (-956 *6 *5 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-1166 (-413 (-959 *5))))) (-5 *4 (-1170)) (-5 *2 (-413 (-959 *5))) (-5 *1 (-1049 *5)) (-4 *5 (-562))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-864))))) 
-(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 (-443))))) (-5 *1 (-1174))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1106 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-2 (|:| |val| (-638 *8)) (|:| -1337 *9)))) (-5 *5 (-121)) (-4 *8 (-1068 *6 *7 *4)) (-4 *9 (-1073 *6 *7 *4 *8)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *4 (-848)) (-5 *2 (-638 (-2 (|:| |val| *8) (|:| -1337 *9)))) (-5 *1 (-1106 *6 *7 *4 *8 *9))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1241 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1218 *3)) (-5 *2 (-413 (-572)))))) 
-(((*1 *1 *2 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-638 (-923))) (-5 *1 (-156 *4 *2 *5)) (-14 *4 (-923)) (-4 *2 (-368)) (-14 *5 (-1001 *4 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-709 *5 *6 *7)) (-4 *5 (-848)) (-4 *6 (-232 (-4032 *4) (-769))) (-14 *7 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *6)) (-2 (|:| -1763 *5) (|:| -3751 *6)))) (-14 *4 (-638 (-1170))) (-4 *2 (-174)) (-5 *1 (-467 *4 *2 *5 *6 *7 *8)) (-4 *8 (-956 *2 *6 (-858 *4))))) ((*1 *1 *2 *3) (-12 (-4 *1 (-522 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-848)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-4 *2 (-562)) (-5 *1 (-619 *2 *4)) (-4 *4 (-1234 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-704 *2)) (-4 *2 (-1054)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-731 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-722)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *5)) (-5 *3 (-638 (-769))) (-4 *1 (-736 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-848)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-736 *4 *2)) (-4 *4 (-1054)) (-4 *2 (-848)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-850 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *6)) (-5 *3 (-638 (-769))) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-956 *4 *5 *2)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *2 (-848)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *6)) (-5 *3 (-638 *5)) (-4 *1 (-981 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-793)) (-4 *6 (-848)))) ((*1 *1 *1 *2 *3) (-12 (-4 *1 (-981 *4 *3 *2)) (-4 *4 (-1054)) (-4 *3 (-793)) (-4 *2 (-848))))) 
-(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-848)) (-5 *2 (-1177 (-638 *4))) (-5 *1 (-1176 *4)) (-5 *3 (-638 *4))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-572))) (-4 *3 (-1054)) (-5 *1 (-597 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-572))) (-4 *1 (-1218 *3)) (-4 *3 (-1054)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-572))) (-4 *1 (-1249 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 *4)))) (-5 *1 (-890 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) ((*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-638 *1)) (-4 *1 (-1101 *3 *4 *5 *6 *7))))) 
-(((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-685 (-413 *4)))))) 
-(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-567))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-298)) (-5 *3 (-1170)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-298)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-130)) (-5 *2 (-121)) (-5 *1 (-1085 *4)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-959 (-572))) (-5 *2 (-330)) (-5 *1 (-332))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1100 (-1100 *3))) (-5 *1 (-905 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-52 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) ((*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-572)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-248 *4 *3 *5 *6)) (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-273)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1166 *8)) (-5 *4 (-638 *6)) (-4 *6 (-848)) (-4 *8 (-956 *7 *5 *6)) (-4 *5 (-794)) (-4 *7 (-1054)) (-5 *2 (-638 (-769))) (-5 *1 (-320 *5 *6 *7 *8)))) ((*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-923)))) ((*1 *2 *1) (-12 (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-479 *3 *2)) (-4 *3 (-174)) (-4 *2 (-23)))) ((*1 *2 *1) (-12 (-4 *3 (-562)) (-5 *2 (-572)) (-5 *1 (-619 *3 *4)) (-4 *4 (-1234 *3)))) ((*1 *2 *3) (-12 (-4 *1 (-671 *3 *4)) (-4 *3 (-1204)) (-4 *4 (-1204)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-4 *1 (-704 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-850 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-1054)) (-4 *6 (-232 *7 *2)) (-14 *7 *2) (-5 *2 (-769)) (-5 *1 (-914 *5 *3 *6 *7)) (-4 *3 (-326 *5 *6)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 (-769))))) ((*1 *2 *1 *3) (-12 (-4 *1 (-956 *4 *5 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-769)))) ((*1 *2 *3) (-12 (-5 *3 (-1208)) (-5 *2 (-572)) (-5 *1 (-961)))) ((*1 *2 *1) (-12 (-4 *1 (-981 *3 *2 *4)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *2 (-793)))) ((*1 *2 *1) (-12 (-4 *1 (-1096)) (-5 *2 (-923)))) ((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-1220 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1249 *3)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-4 *1 (-1241 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1218 *3)) (-5 *2 (-413 (-572))))) ((*1 *2 *1) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-834 (-923))))) ((*1 *2 *1) (-12 (-4 *1 (-1278 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-769))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1259 *4)) (-4 *4 (-1204)) (-4 *1 (-232 *3 *4))))) 
-(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-171 (-217)) (-171 (-217)))) (-5 *4 (-1092 (-217))) (-5 *2 (-1261)) (-5 *1 (-252))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1166 *1)) (-4 *1 (-864)) (-5 *2 (-638 *1)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-368)) (-5 *2 (-2 (|:| |zeros| (-638 *4)) (|:| -3818 (-572)))) (-5 *1 (-1050 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-312 *4)) (-5 *1 (-182 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 (-171 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3)))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856))))) 
-(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *3 (-562)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-684 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -1862 *6) (|:| |sol?| (-121))) (-572) *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-2 (|:| |answer| (-589 (-413 *7))) (|:| |a0| *6))) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-53))) (-5 *2 (-424 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1234 (-53))))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1234 (-53))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-53))) (-4 *5 (-848)) (-4 *6 (-794)) (-5 *2 (-424 *3)) (-5 *1 (-47 *5 *6 *3)) (-4 *3 (-956 (-53) *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-53))) (-4 *5 (-848)) (-4 *6 (-794)) (-4 *7 (-956 (-53) *6 *5)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-47 *5 *6 *7)) (-5 *3 (-1166 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-169 *4 *3)) (-4 *3 (-1234 (-171 *4))))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-209 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-860)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1166 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-865)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-319 *4)) (-5 *3 (-1166 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-769))) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-769))) (-5 *5 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3) (-12 (-5 *2 (-424 (-171 (-572)))) (-5 *1 (-451)) (-5 *3 (-171 (-572))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-4 *5 (-794)) (-4 *7 (-562)) (-5 *2 (-424 *3)) (-5 *1 (-462 *4 *5 *6 *7 *3)) (-4 *6 (-562)) (-4 *3 (-956 *7 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-303)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-464 *4)) (-5 *3 (-1166 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-4 *7 (-13 (-368) (-151) (-720 *5 *6))) (-5 *2 (-424 *3)) (-5 *1 (-507 *5 *6 *7 *3)) (-4 *3 (-1234 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-424 (-1166 *7)) (-1166 *7))) (-4 *7 (-13 (-303) (-151))) (-4 *5 (-848)) (-4 *6 (-794)) (-5 *2 (-424 *3)) (-5 *1 (-549 *5 *6 *7 *3)) (-4 *3 (-956 *7 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-424 (-1166 *7)) (-1166 *7))) (-4 *7 (-13 (-303) (-151))) (-4 *5 (-848)) (-4 *6 (-794)) (-4 *8 (-956 *7 *6 *5)) (-5 *2 (-424 (-1166 *8))) (-5 *1 (-549 *5 *6 *7 *8)) (-5 *3 (-1166 *8)))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-565 *3)) (-4 *3 (-554)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-647 (-413 *6)))) (-5 *1 (-651 *5 *6)) (-5 *3 (-647 (-413 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-647 (-413 *5)))) (-5 *1 (-651 *4 *5)) (-5 *3 (-647 (-413 *5))))) ((*1 *2 *3) (-12 (-5 *3 (-820 *4)) (-4 *4 (-848)) (-5 *2 (-638 (-667 *4))) (-5 *1 (-667 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-5 *2 (-638 *3)) (-5 *1 (-691 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-693 *4 *5 *6 *3)) (-4 *3 (-956 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-353)) (-4 *7 (-956 *6 *5 *4)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-693 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-4 *6 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-726 *4 *5 *6 *3)) (-4 *3 (-956 (-959 *6) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *6 (-562)) (-5 *2 (-424 *3)) (-5 *1 (-728 *4 *5 *6 *3)) (-4 *3 (-956 (-413 (-959 *6)) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-13 (-303) (-151))) (-5 *2 (-424 *3)) (-5 *1 (-729 *4 *5 *6 *3)) (-4 *3 (-956 (-413 *6) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-13 (-303) (-151))) (-5 *2 (-424 *3)) (-5 *1 (-737 *4 *5 *6 *3)) (-4 *3 (-956 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-956 *6 *5 *4)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-737 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1014 *3)) (-4 *3 (-1234 (-413 (-572)))))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1047 *3)) (-4 *3 (-1234 (-413 (-959 (-572))))))) ((*1 *2 *3) (-12 (-4 *4 (-1234 (-413 (-572)))) (-4 *5 (-13 (-368) (-151) (-720 (-413 (-572)) *4))) (-5 *2 (-424 *3)) (-5 *1 (-1079 *4 *5 *3)) (-4 *3 (-1234 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-1234 (-413 (-959 (-572))))) (-4 *5 (-13 (-368) (-151) (-720 (-413 (-959 (-572))) *4))) (-5 *2 (-424 *3)) (-5 *1 (-1081 *4 *5 *3)) (-4 *3 (-1234 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-457)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-424 (-1166 (-413 *7)))) (-5 *1 (-1165 *4 *5 *6 *7)) (-5 *3 (-1166 (-413 *7))))) ((*1 *2 *1) (-12 (-5 *2 (-424 *1)) (-4 *1 (-1214)))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1223 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-893 *4)) (-4 *4 (-1098)) (-5 *2 (-638 *5)) (-5 *1 (-891 *4 *5)) (-4 *5 (-1204))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-4 *1 (-506))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| -3444 (-413 *6)) (|:| |coeff| (-413 *6)))) (-5 *1 (-582 *5 *6)) (-5 *3 (-413 *6))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-156 *3 *4 *5)) (-14 *3 *2) (-4 *4 (-368)) (-14 *5 (-1001 *3 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-168 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-424 *3)) (-4 *3 (-554)) (-4 *3 (-562)))) ((*1 *2 *1) (-12 (-4 *1 (-554)) (-5 *2 (-413 (-572))))) ((*1 *2 *1) (-12 (-4 *1 (-798 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-834 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-841 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1004 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) ((*1 *2 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-1015 *3)) (-4 *3 (-1044 *2))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-611 *1)) (-4 *1 (-436 *4)) (-4 *4 (-848)) (-4 *4 (-562)) (-5 *2 (-413 (-1166 *1))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-611 *3)) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-1166 (-413 (-1166 *3)))) (-5 *1 (-568 *6 *3 *7)) (-5 *5 (-1166 *3)) (-4 *7 (-1098)))) ((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *2 (-1166 *4)) (-5 *1 (-914 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1255 *5)) (-14 *5 (-1170)) (-4 *6 (-1054)) (-5 *2 (-1231 *5 (-959 *6))) (-5 *1 (-954 *5 *6)) (-5 *3 (-959 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-956 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-1166 *3)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-1166 *1)) (-4 *1 (-956 *4 *5 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *5 *4)) (-5 *2 (-413 (-1166 *3))) (-5 *1 (-957 *5 *4 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-1166 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))) (-4 *7 (-956 *6 *5 *4)) (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-1054)) (-5 *1 (-957 *5 *4 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-562)) (-5 *2 (-413 (-1166 (-413 (-959 *5))))) (-5 *1 (-1049 *5)) (-5 *3 (-413 (-959 *5)))))) 
-(((*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-151) (-27) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-1166 (-413 *5))) (-5 *1 (-614 *4 *5)) (-5 *3 (-413 *5)))) ((*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-151) (-27) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-1166 (-413 *6))) (-5 *1 (-614 *5 *6)) (-5 *3 (-413 *6))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-4 *1 (-506))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-638 (-611 *2))) (-5 *4 (-638 (-1170))) (-4 *2 (-13 (-436 (-171 *5)) (-1009) (-1190))) (-4 *5 (-13 (-562) (-848))) (-5 *1 (-601 *5 *6 *2)) (-4 *6 (-13 (-436 *5) (-1009) (-1190)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-611 *1))) (-4 *1 (-298))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-4 *1 (-506))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-496 *4 *5))) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *2 (-2 (|:| |gblist| (-638 (-244 *4 *5))) (|:| |gvlist| (-638 (-572))))) (-5 *1 (-626 *4 *5))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-424 *3)) (-4 *3 (-562))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-171 (-385))) (-5 *1 (-786 *3)) (-4 *3 (-613 (-385))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-5 *2 (-171 (-385))) (-5 *1 (-786 *3)) (-4 *3 (-613 (-385))))) ((*1 *2 *3) (-12 (-5 *3 (-171 *4)) (-4 *4 (-174)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-171 *5)) (-5 *4 (-923)) (-4 *5 (-174)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-959 (-171 *4))) (-4 *4 (-174)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-959 (-171 *5))) (-5 *4 (-923)) (-4 *5 (-174)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-959 *4)) (-4 *4 (-1054)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-959 *5)) (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-413 (-959 (-171 *4)))) (-4 *4 (-562)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-171 *5)))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-312 *4)) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-312 *5)) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-312 (-171 *4))) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-312 (-171 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *1 *1) (-4 *1 (-506))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-923)) (-5 *1 (-787))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *1 (-589 *2)) (-4 *2 (-1044 *3)) (-4 *2 (-368)))) ((*1 *1 *2 *2) (-12 (-5 *1 (-589 *2)) (-4 *2 (-368)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-625 *4 *2)) (-4 *2 (-13 (-436 *4) (-1009) (-1190))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1090 *2)) (-4 *2 (-13 (-436 *4) (-1009) (-1190))) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-625 *4 *2)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-966)) (-5 *2 (-1170)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1090 *1)) (-4 *1 (-966))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *7)) (-4 *7 (-848)) (-4 *8 (-956 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-5 *2 (-2 (|:| |particular| (-3 (-1259 (-413 *8)) "failed")) (|:| -2237 (-638 (-1259 (-413 *8)))))) (-5 *1 (-665 *5 *6 *7 *8))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *1 *1) (-4 *1 (-506))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *1 *1) (|partial| -12 (-5 *1 (-1134 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39)))))) 
-(((*1 *1) (-5 *1 (-1066)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *1 *1) (-4 *1 (-506))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-1220 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1249 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-820 *3)) (-4 *3 (-848)) (-5 *1 (-667 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-413 (-1166 (-312 *3)))) (-4 *3 (-13 (-562) (-848))) (-5 *1 (-1126 *3))))) 
-(((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-62 *4 *2 *5)) (-4 *4 (-1204)) (-4 *5 (-379 *4)) (-4 *2 (-379 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *6 *2 *7)) (-4 *6 (-1054)) (-4 *7 (-232 *4 *6)) (-4 *2 (-232 *5 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1186)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1186))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-978 *3)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-974 *3))) (-4 *3 (-353)) (-5 *1 (-873 *3 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-973 *3))) (-4 *3 (-368)) (-5 *1 (-874 *3 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-123)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-848)) (-5 *1 (-936 *4 *2)) (-4 *2 (-436 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-1152)) (-5 *2 (-312 (-572))) (-5 *1 (-937))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-258))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-638 (-783 *3))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-457)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-572)) (-5 *1 (-1112 *4 *5))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-1259 *4)) (-4 *4 (-634 (-572))) (-5 *2 (-1259 (-572))) (-5 *1 (-1284 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-3 (-130) (-572))) (-5 *1 (-130))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-923)) (-4 *5 (-848)) (-5 *2 (-638 (-667 *5))) (-5 *1 (-667 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-923)) (-4 *5 (-848)) (-5 *2 (-64 (-638 (-667 *5)))) (-5 *1 (-667 *5))))) 
-(((*1 *1 *1) (-4 *1 (-98))) ((*1 *1 *1 *1) (-5 *1 (-217))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *1 *1 *1) (-5 *1 (-385))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-759)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-669 *3)) (-4 *3 (-1204)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-4 *4 (-860)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1166 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-865)) (-5 *2 (-424 (-1166 *4))) (-5 *1 (-319 *4)) (-5 *3 (-1166 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1044 (-572))) (-4 *1 (-298)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-554)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-906 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-469))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 *5)))) (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-959 *5)))) (-5 *1 (-1175 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *5)))))) (-5 *1 (-768 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *4)))))) (-5 *1 (-768 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *7)) (-5 *5 (-1 (-2 (|:| |particular| (-3 *6 "failed")) (|:| -2237 (-638 *6))) *7 *6)) (-4 *6 (-368)) (-4 *7 (-650 *6)) (-5 *2 (-2 (|:| |particular| (-3 (-1259 *6) "failed")) (|:| -2237 (-638 (-1259 *6))))) (-5 *1 (-814 *6 *7)) (-5 *4 (-1259 *6))))) 
-(((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1044 (-572))) (-4 *1 (-298)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-554)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-906 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-469))))) 
-(((*1 *1) (-12 (-4 *1 (-410)) (-2959 (|has| *1 (-6 -4593))) (-2959 (|has| *1 (-6 -4585))))) ((*1 *2 *1) (-12 (-4 *1 (-431 *2)) (-4 *2 (-1098)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-4 *1 (-848))) ((*1 *2 *1) (-12 (-4 *1 (-976 *2)) (-4 *2 (-848)))) ((*1 *1) (-5 *1 (-1116)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *1 *1) (-4 *1 (-1193)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *1 *1) (-4 *1 (-1193)))) 
-(((*1 *1 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204)))) ((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) ((*1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-457)) (-4 *4 (-848)) (-5 *1 (-581 *4 *2)) (-4 *2 (-281)) (-4 *2 (-436 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) ((*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *1 *1) (-4 *1 (-1193)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| |deg| (-769)) (|:| -2225 *5)))) (-4 *5 (-1234 *4)) (-4 *4 (-353)) (-5 *2 (-638 *5)) (-5 *1 (-209 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| -4304 *5) (|:| -4316 (-572))))) (-5 *4 (-572)) (-4 *5 (-1234 *4)) (-5 *2 (-638 *5)) (-5 *1 (-691 *5))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 (-769))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-923) (-121))) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-923) (-121))) (-5 *1 (-469))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *1 *1) (-4 *1 (-1193)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 *3)) (|:| |logand| (-1166 *3))))) (-5 *1 (-589 *3)) (-4 *3 (-368))))) 
-(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-572)) (-5 *3 (-923)) (-5 *1 (-694)))) ((*1 *2 *2 *2 *3 *4) (-12 (-5 *2 (-685 *5)) (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-368)) (-5 *1 (-986 *5))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-331 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *1 *1) (-4 *1 (-1193)))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-331 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *1 *1) (-4 *1 (-1193)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1 *1)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-1150 *3))) (-5 *1 (-1150 *3)) (-4 *3 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-685 (-959 *4))) (-5 *1 (-1035 *4)) (-4 *4 (-1054))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1042)) (-5 *3 (-1170)) (-5 *1 (-186))))) 
-(((*1 *1 *1) (-4 *1 (-624))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-1204)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-285 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *2 *6 *7)) (-4 *6 (-232 *5 *2)) (-4 *7 (-232 *4 *2)) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *1 *2 *2 *1) (|partial| -12 (-5 *2 (-130)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-1044 (-572)) (-457) (-634 (-572)))) (-5 *2 (-2 (|:| -3631 *3) (|:| |nconst| *3))) (-5 *1 (-575 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5)))))) 
-(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-13 (-368) (-151) (-1044 (-572)))) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -3444 (-413 *5)) (|:| |coeff| (-413 *5)))) (-5 *1 (-576 *4 *5)) (-5 *3 (-413 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-186))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-572)) (-5 *3 (-769)) (-5 *1 (-569))))) 
-(((*1 *1 *1) (-4 *1 (-624))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-312 (-385))) (-5 *1 (-301))))) 
-(((*1 *1) (-5 *1 (-567)))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-856)))) ((*1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-1090 *3)) (-4 *3 (-1204)))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (-12 (-5 *1 (-1225 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *1) (-4 *1 (-624))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-562) (-457))) (-5 *2 (-638 *4)) (-5 *1 (-349 *4 *5)) (-4 *5 (-52 *4 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-638 *1)) (-5 *3 (-638 (-769))) (-5 *4 (-572)) (-4 *1 (-645 *5)) (-4 *5 (-368))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-413 (-572))) (-4 *4 (-1044 (-572))) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-36 *4 *2)) (-4 *2 (-436 *4)))) ((*1 *1 *1 *1) (-5 *1 (-140))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1 *1) (-5 *1 (-217))) ((*1 *1 *1 *2) (-12 (-4 *1 (-240)) (-5 *2 (-572)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-413 (-572))) (-4 *4 (-368)) (-4 *4 (-43 *3)) (-4 *5 (-1249 *4)) (-5 *1 (-276 *4 *5 *2)) (-4 *2 (-1220 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-413 (-572))) (-4 *4 (-368)) (-4 *4 (-43 *3)) (-4 *5 (-1218 *4)) (-5 *1 (-277 *4 *5 *2 *6)) (-4 *2 (-1241 *4 *5)) (-4 *6 (-991 *5)))) ((*1 *1 *1 *1) (-4 *1 (-281))) ((*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-366 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *1) (-5 *1 (-385))) ((*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-5 *1 (-392 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-436 *3)) (-4 *3 (-848)) (-4 *3 (-1110)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-482)) (-5 *2 (-572)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-572)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-545)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-545)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-769)) (-4 *4 (-1098)) (-5 *1 (-677 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-685 *4)) (-5 *3 (-769)) (-4 *4 (-1054)) (-5 *1 (-686 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *3 (-1054)) (-5 *1 (-710 *3 *4)) (-4 *4 (-641 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-572)) (-4 *4 (-1054)) (-5 *1 (-710 *4 *5)) (-4 *5 (-641 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-923)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-718)) (-5 *2 (-769)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-722)) (-5 *2 (-769)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) ((*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-835 *3)) (-4 *3 (-1054)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-572)) (-5 *1 (-835 *4)) (-4 *4 (-1054)))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1009)) (-5 *2 (-413 (-572))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1110)) (-5 *2 (-923)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1119 *3 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-232 *3 *4)) (-4 *6 (-232 *3 *4)) (-4 *4 (-368)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1249 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572)))) ((*1 *1 *1) (-4 *1 (-1009))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1019)))) ((*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-4 *1 (-1019)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1019)) (-5 *2 (-769)))) ((*1 *1 *1) (-4 *1 (-1019)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562))))) 
-(((*1 *1 *1) (-5 *1 (-1066)))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-619 *4 *5)) (-5 *3 (-1 (-2 (|:| |ans| *4) (|:| -1862 *4) (|:| |sol?| (-121))) (-572) *4)) (-4 *4 (-368)) (-4 *5 (-1234 *4)) (-5 *1 (-582 *4 *5))))) 
-(((*1 *2) (-12 (-4 *2 (-13 (-436 *3) (-1009))) (-5 *1 (-274 *3 *2)) (-4 *3 (-13 (-848) (-562))))) ((*1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *1) (-5 *1 (-493))) ((*1 *1) (-4 *1 (-1190)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-413 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-562)) (-4 *4 (-1054)) (-4 *2 (-1249 *4)) (-5 *1 (-1252 *4 *5 *6 *2)) (-4 *6 (-650 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-4 *1 (-281))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *1 *2) (-12 (-5 *2 (-660 *3 *4)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-5 *1 (-622 *3 *4 *5)) (-14 *5 (-923)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-1054) (-713 (-413 (-572))))) (-4 *5 (-848)) (-5 *1 (-1273 *4 *5 *2)) (-4 *2 (-1278 *5 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1277 *3 *4)) (-4 *4 (-713 (-413 (-572)))) (-4 *3 (-848)) (-4 *4 (-174))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| |radval| (-312 (-572))) (|:| |radmult| (-572)) (|:| |radvect| (-638 (-685 (-312 (-572)))))))) (-5 *1 (-1038))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-217)) (-5 *1 (-823))))) 
-(((*1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1) (-4 *1 (-133))) ((*1 *1 *1 *2) (-12 (-4 *1 (-240)) (-5 *2 (-572)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-482)) (-5 *2 (-572)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-722)) (-5 *2 (-769)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1110)) (-5 *2 (-923))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-1170)) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-4 *4 (-13 (-29 *6) (-1190) (-966))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2237 (-638 *4)))) (-5 *1 (-802 *6 *4 *3)) (-4 *3 (-650 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1211 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1218 *3))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-769)) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1257 *3)) (-4 *3 (-23)) (-4 *3 (-1204))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-151)) (-4 *3 (-303)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 *10)) (-5 *1 (-620 *5 *6 *7 *8 *9 *10)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *10 (-1107 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-623 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1139 *5 (-538 (-858 *6)) (-858 *6) (-781 *5 (-858 *6))))) (-5 *1 (-623 *5 *6)))) ((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1034 *5 *6 *7 *8))) (-5 *1 (-1034 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1034 *5 *6 *7 *8))) (-5 *1 (-1034 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-1051 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1139 *5 *6 *7 *8))) (-5 *1 (-1139 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1139 *5 *6 *7 *8))) (-5 *1 (-1139 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1198 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-469))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-611 *7)) (-4 *7 (-13 (-436 *6) (-23) (-1044 *2) (-1044 *5) (-901 *5) (-162))) (-5 *5 (-1170)) (-4 *6 (-1054)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-572)) (-5 *1 (-1031 *6 *7))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-394)) (-5 *1 (-627))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-1234 *4)) (-5 *2 (-1 *6 (-638 *6))) (-5 *1 (-1252 *4 *5 *3 *6)) (-4 *3 (-650 *5)) (-4 *6 (-1249 *4))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-326 *4 *5)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-4 *4 (-1054)) (-5 *1 (-778 *4 *3 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1234 *3)) (-4 *3 (-1054)) (-5 *2 (-1166 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *2 *4 *5 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1098)) (-5 *2 (-638 (-2 (|:| -4320 *3) (|:| -1571 (-769)))))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-638 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-1092 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) ((*1 *1 *1 *2 *2 *2 *2) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1191 *3))) (-5 *1 (-1191 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-589 *2)) (-4 *2 (-13 (-29 *4) (-1190))) (-5 *1 (-587 *4 *2)) (-4 *4 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-589 (-413 (-959 *4)))) (-4 *4 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-312 *4)) (-5 *1 (-592 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-232 *5 (-769))) (-14 *5 (-769)) (-5 *1 (-914 *3 *2 *4 *5)) (-4 *2 (-326 *3 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *2)) (-4 *2 (-174)))) ((*1 *2) (-12 (-4 *2 (-174)) (-5 *1 (-422 *3 *2)) (-4 *3 (-423 *2)))) ((*1 *2) (-12 (-4 *1 (-423 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3 *3) (-12 (-4 *3 (-303)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-684 *3 *4 *5 *6)) (-4 *6 (-683 *3 *4 *5)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-695 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))) (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *2 (-121)) (-5 *1 (-519 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-875)))) ((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 (-121) *6)) (-4 *6 (-13 (-1098) (-1044 *5))) (-4 *5 (-887 *4)) (-4 *4 (-1098)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-938 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1102)) (-5 *1 (-57))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-385)))) ((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-385))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1134 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39)))))) 
-(((*1 *1) (-5 *1 (-443)))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-2 (|:| |k| *4) (|:| |c| *3)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-368)) (-5 *2 (-638 *3)) (-5 *1 (-952 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-140))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-685 *5))) (-5 *4 (-1259 *5)) (-4 *5 (-303)) (-4 *5 (-1054)) (-5 *2 (-685 *5)) (-5 *1 (-1036 *5))))) 
-(((*1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-379 *2)) (-4 *2 (-1204)) (-4 *2 (-848)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (|has| *1 (-6 -4603)) (-4 *1 (-379 *3)) (-4 *3 (-1204))))) 
-(((*1 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-611 *5)) (-4 *5 (-436 *4)) (-4 *4 (-1044 (-572))) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-1166 *5)) (-5 *1 (-36 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-611 *1)) (-4 *1 (-1054)) (-4 *1 (-298)) (-5 *2 (-1166 *1))))) 
-(((*1 *1) (-5 *1 (-330)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-638 (-2 (|:| -2371 *1) (|:| -1428 (-638 *7))))) (-5 *3 (-638 *7)) (-4 *1 (-1198 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-336 *5 *6 *7 *8)) (-4 *5 (-436 *4)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *8 (-342 *5 *6 *7)) (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-2 (|:| -3377 (-769)) (|:| -3616 *8))) (-5 *1 (-912 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-336 (-413 (-572)) *4 *5 *6)) (-4 *4 (-1234 (-413 (-572)))) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 (-413 (-572)) *4 *5)) (-5 *2 (-2 (|:| -3377 (-769)) (|:| -3616 *6))) (-5 *1 (-913 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-354 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-766 *4 *5)) (-4 *5 (-415 *3 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-993 *4 *3 *5 *6)) (-4 *6 (-720 *3 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-1268 *4 *3 *5 *6)) (-4 *6 (-415 *3 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-933))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-769)) (-4 *6 (-368)) (-5 *4 (-1199 *6)) (-5 *2 (-1 (-1150 *4) (-1150 *4))) (-5 *1 (-1267 *6)) (-5 *5 (-1150 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1204)) (-5 *2 (-638 *1)) (-4 *1 (-1017 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-1158 *3 *4))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-841 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1 *1 *2) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-597 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-385)))) ((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-385))))) 
-(((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3190 *3) (|:| |coef1| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-477)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1260)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1261))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-950 *5)) (-4 *5 (-1054)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-769)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)) (-4 *5 (-1054)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-950 *5)) (-4 *5 (-1054)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -3029 *1) (|:| -4589 *1) (|:| |associate| *1))) (-4 *1 (-562))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-5 *2 (-2 (|:| A (-685 *5)) (|:| |eqs| (-638 (-2 (|:| C (-685 *5)) (|:| |g| (-1259 *5)) (|:| -2352 *6) (|:| |rh| *5)))))) (-5 *1 (-814 *5 *6)) (-5 *3 (-685 *5)) (-5 *4 (-1259 *5)) (-4 *6 (-650 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-650 *5)) (-5 *2 (-2 (|:| -1369 (-685 *6)) (|:| |vec| (-1259 *5)))) (-5 *1 (-814 *5 *6)) (-5 *3 (-685 *6)) (-5 *4 (-1259 *5))))) 
-(((*1 *2 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1117 *2)) (-4 *2 (-1204)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-841 (-217)))) (-5 *4 (-217)) (-5 *2 (-638 *4)) (-5 *1 (-265))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-1054)) (-4 *6 (-232 *7 *3)) (-14 *7 *3) (-5 *2 (-638 *5)) (-5 *1 (-914 *4 *5 *6 *7)) (-4 *5 (-326 *4 *6))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-848)) (-5 *1 (-1176 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1150 (-572))) (-5 *1 (-1154 *4)) (-4 *4 (-1054)) (-5 *3 (-572))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-638 *3)) (-4 *3 (-956 *4 *6 *5)) (-4 *4 (-457)) (-4 *5 (-848)) (-4 *6 (-794)) (-5 *1 (-995 *4 *5 *6 *3))))) 
-(((*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1006 *3)) (-4 *3 (-174)) (-5 *1 (-800 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-638 *8))) (-5 *3 (-638 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *5 *6 *7 *8))))) 
-(((*1 *2) (-12 (-4 *2 (-13 (-436 *3) (-1009))) (-5 *1 (-274 *3 *2)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1249 *4)) (-5 *1 (-1251 *4 *2)) (-4 *4 (-43 (-413 (-572))))))) 
-(((*1 *1) (-5 *1 (-443)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *2 (-1264)) (-5 *1 (-1173)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *2 (-1264)) (-5 *1 (-1173)))) ((*1 *2 *3 *4 *1) (-12 (-5 *3 (-1170)) (-5 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *2 (-1264)) (-5 *1 (-1173))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3))))) 
-(((*1 *1 *1) (-4 *1 (-1137)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-298)) (-5 *2 (-638 (-123)))))) 
-(((*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-1 *3 *3)) (-4 *3 (-1234 *6)) (-4 *6 (-13 (-368) (-151) (-1044 *4))) (-5 *4 (-572)) (-5 *2 (-3 (|:| |ans| (-2 (|:| |ans| *3) (|:| |nosol| (-121)))) (|:| -2352 (-2 (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (-5 *1 (-1022 *6 *3))))) 
-(((*1 *1 *1) (-5 *1 (-1066)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-121)) (-5 *1 (-830))))) 
-(((*1 *1 *2 *3) (-12 (-5 *1 (-972 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-5 *1 (-545)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-769)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-794)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-457)) (-4 *5 (-848)) (-5 *1 (-454 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1158 3 (-217))) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-308))))) 
-(((*1 *1 *1) (-5 *1 (-217))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *1 *1) (-5 *1 (-385))) ((*1 *1) (-5 *1 (-385)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-130)))) ((*1 *2 *3) (-12 (-4 *5 (-13 (-613 *2) (-174))) (-5 *2 (-893 *4)) (-5 *1 (-172 *4 *5 *3)) (-4 *4 (-1098)) (-4 *3 (-168 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-1092 (-841 (-385))))) (-5 *2 (-638 (-1092 (-841 (-217))))) (-5 *1 (-301)))) ((*1 *1 *2) (-12 (-5 *2 (-217)) (-5 *1 (-385)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-856)) (-5 *3 (-572)) (-5 *1 (-400)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-174)) (-4 *1 (-415 *3 *4)) (-4 *4 (-1234 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-415 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-1259 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-174)) (-4 *1 (-423 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-1259 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-424 *1)) (-4 *1 (-436 *3)) (-4 *3 (-562)) (-4 *3 (-848)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-472 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-1102)) (-5 *1 (-545)))) ((*1 *2 *1) (-12 (-4 *1 (-613 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (-12 (-4 *3 (-174)) (-4 *1 (-720 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1054)) (-4 *1 (-988 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1065)))) ((*1 *1 *2) (-12 (-5 *2 (-959 *3)) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *5 (-613 (-1170))) (-4 *4 (-794)) (-4 *5 (-848)))) ((*1 *1 *2) (-1841 (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))))) ((*1 *1 *2) (-12 (-5 *2 (-959 (-413 (-572)))) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-638 *7)) (|:| -1337 *8))) (-4 *7 (-1068 *4 *5 *6)) (-4 *8 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1152)) (-5 *1 (-1071 *4 *5 *6 *7 *8)))) ((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-1082)))) ((*1 *1 *2) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *2)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)))) ((*1 *1 *2) (-12 (-4 *1 (-1101 *3 *4 *5 *2 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *2 (-1098)) (-4 *6 (-1098)))) ((*1 *1 *2) (-12 (-4 *1 (-1101 *3 *4 *2 *5 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *2 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)))) ((*1 *1 *2) (-12 (-4 *1 (-1101 *3 *2 *4 *5 *6)) (-4 *3 (-1098)) (-4 *2 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)))) ((*1 *1 *2) (-12 (-4 *1 (-1101 *2 *3 *4 *5 *6)) (-4 *2 (-1098)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-638 *7)) (|:| -1337 *8))) (-4 *7 (-1068 *4 *5 *6)) (-4 *8 (-1107 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1152)) (-5 *1 (-1138 *4 *5 *6 *7 *8)))) ((*1 *1 *2 *3 *2) (-12 (-5 *2 (-856)) (-5 *3 (-572)) (-5 *1 (-1185)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-856)) (-5 *3 (-572)) (-5 *1 (-1185)))) ((*1 *2 *3) (-12 (-5 *3 (-781 *4 (-858 *5))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-781 *4 (-858 *6))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-959 *4)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-959 (-1030 (-413 *4)))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-781 *4 (-858 *6))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *6 (-638 (-1170))) (-5 *2 (-959 (-1030 (-413 *4)))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-1166 (-1030 (-413 *4)))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-1139 *4 (-538 (-858 *6)) (-858 *6) (-781 *4 (-858 *6)))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-781 *4 (-858 *6)))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *1 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) ((*1 *1 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *4 (-848)) (-4 *6 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-738 *5 *4 *6 *3)) (-4 *3 (-956 *6 *5 *4))))) 
-(((*1 *2 *1 *1 *3 *4) (-12 (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1098) (-39))) (-4 *6 (-13 (-1098) (-39))) (-5 *2 (-121)) (-5 *1 (-1133 *5 *6))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *3)) (-5 *1 (-1124 *4 *3)) (-4 *4 (-1234 *3))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-380 *2 *3)) (-4 *2 (-848)) (-4 *3 (-174)))) ((*1 *1 *1) (-12 (-5 *1 (-622 *2 *3 *4)) (-4 *2 (-848)) (-4 *3 (-13 (-174) (-713 (-413 (-572))))) (-14 *4 (-923)))) ((*1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054))))) 
-(((*1 *1) (-5 *1 (-159)))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-1116)) (-5 *2 (-121)) (-5 *1 (-822))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-424 (-1166 *1))) (-5 *1 (-312 *4)) (-5 *3 (-1166 *1)) (-4 *4 (-457)) (-4 *4 (-562)) (-4 *4 (-848)))) ((*1 *2 *3) (-12 (-4 *1 (-910)) (-5 *2 (-424 (-1166 *1))) (-5 *3 (-1166 *1))))) 
-(((*1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *1) (-5 *1 (-824)))) 
-(((*1 *1 *1) (-4 *1 (-869 *2)))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-4 *7 (-1234 (-413 *6))) (-5 *2 (-2 (|:| |answer| *3) (|:| -4223 *3))) (-5 *1 (-570 *5 *6 *7 *3)) (-4 *3 (-342 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |answer| (-413 *6)) (|:| -4223 (-413 *6)) (|:| |specpart| (-413 *6)) (|:| |polypart| *6))) (-5 *1 (-571 *5 *6)) (-5 *3 (-413 *6))))) 
-(((*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-1 (-638 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-638 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-769)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-469))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4 *2 *5) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 (-893 *6))) (-5 *5 (-1 (-890 *6 *8) *8 (-893 *6) (-890 *6 *8))) (-4 *6 (-1098)) (-4 *8 (-13 (-1054) (-613 (-893 *6)) (-1044 *7))) (-5 *2 (-890 *6 *8)) (-4 *7 (-13 (-1054) (-848))) (-5 *1 (-948 *6 *7 *8))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)) (-5 *2 (-1166 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-932))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-638 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-916 *2)) (-4 *2 (-303))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *2 (-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-778 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *5)) (-4 *5 (-326 *4 *6)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-4 *4 (-1054)) (-5 *2 (-2 (|:| -1455 (-572)) (|:| -4393 (-572)) (|:| -3043 (-572)) (|:| |reste| (-572)) (|:| -3707 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-778 *4 *5 *6 *7))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-199))))) 
-(((*1 *1 *1 *1) (-4 *1 (-482))) ((*1 *1 *1 *1) (-4 *1 (-759)))) 
-(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-1259 (-685 *4))) (-5 *1 (-95 *4 *5)) (-5 *3 (-685 *4)) (-4 *5 (-650 *4))))) 
-(((*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| -12 (-5 *5 (-1170)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-638 *4))) (-5 *7 (-1 (-3 (-2 (|:| -3444 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1190) (-27) (-436 *8))) (-4 *8 (-13 (-457) (-848) (-151) (-1044 *3) (-634 *3))) (-5 *3 (-572)) (-5 *2 (-638 *4)) (-5 *1 (-1021 *8 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-638 *3)) (-5 *1 (-594 *5 *6 *7 *8 *3)) (-4 *3 (-1107 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1078 *5 *6)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *4)) (|:| -3160 (-638 (-959 *4)))))) (-5 *1 (-1078 *4 *5)) (-5 *3 (-638 (-959 *4))) (-14 *5 (-638 (-1170))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1078 *5 *6)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170)))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-572)) (-5 *1 (-385))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1150 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-186)))) ((*1 *2 *3) (-12 (-5 *3 (-1150 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-296)))) ((*1 *2 *3) (-12 (-5 *3 (-1150 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-301))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-823)) (-5 *2 (-57)) (-5 *1 (-830))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-248 *2 *3 *4 *5)) (-4 *2 (-1054)) (-4 *3 (-848)) (-4 *4 (-264 *3)) (-4 *5 (-794))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-57)) (-5 *1 (-830))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-850 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-851 *5 *3)) (-4 *3 (-850 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-923))) (-5 *1 (-1099 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-199))))) 
-(((*1 *1 *1 *2) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-368)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-533 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)) (-5 *2 (-121)) (-5 *1 (-995 *3 *4 *5 *6)) (-4 *6 (-956 *3 *5 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-769))))) 
-(((*1 *1 *1) (-5 *1 (-856))) ((*1 *2 *1) (-12 (-4 *1 (-1101 *2 *3 *4 *5 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1151)))) ((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1170))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217) (-217))) (-5 *3 (-1 (-217) (-217) (-217) (-217))) (-5 *1 (-250))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-769)) (-5 *6 (-121)) (-4 *7 (-457)) (-4 *8 (-794)) (-4 *9 (-848)) (-4 *3 (-1068 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *7 *8 *9 *3 *4)) (-4 *4 (-1073 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-769)) (-5 *6 (-121)) (-4 *7 (-457)) (-4 *8 (-794)) (-4 *9 (-848)) (-4 *3 (-1068 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *7 *8 *9 *3 *4)) (-4 *4 (-1107 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *6 *7 *8 *3 *4)) (-4 *4 (-1107 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *5 *6 *7 *3 *4)) (-4 *4 (-1107 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-39)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1280 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-844))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184))))) 
-(((*1 *1) (-5 *1 (-159)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-303)) (-5 *2 (-769))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-133))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-368)) (-5 *1 (-657 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-413 (-959 *4)))) (-5 *1 (-930 *4 *5 *6 *7)) (-4 *7 (-956 *4 *6 *5))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-685 (-572))) (-5 *1 (-1108))))) 
-(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7))))) 
-(((*1 *2 *1 *3) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1066)) (-5 *3 (-1152))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-611 *3)) (-4 *3 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-574 *5 *3 *6)) (-4 *6 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-794)) (-4 *2 (-264 *4))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-769)) (-5 *1 (-123))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-638 (-1 *4 (-638 *4)))) (-4 *4 (-1098)) (-5 *1 (-122 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1098)) (-5 *1 (-122 *4)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-638 (-1 *4 (-638 *4)))) (-5 *1 (-122 *4)) (-4 *4 (-1098))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (-413 *5)) (|:| |c2| (-413 *5)) (|:| |deg| (-769)))) (-5 *1 (-152 *4 *5 *3)) (-4 *3 (-1234 (-413 *5)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-424 *3)) (-4 *3 (-562)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -4304 *4) (|:| -4316 (-572))))) (-4 *4 (-1234 (-572))) (-5 *2 (-769)) (-5 *1 (-447 *4))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-151)) (-4 *3 (-303)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-113)))) ((*1 *2 *1) (-12 (-4 *1 (-139)) (-5 *2 (-769)))) ((*1 *2 *3 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-379 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-379 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-572)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (-4 *1 (-379 *4)) (-4 *4 (-1204)) (-5 *2 (-572)))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-572)) (-5 *3 (-143)))) ((*1 *2 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-572))))) 
-(((*1 *1) (-5 *1 (-143))) ((*1 *1 *1) (-5 *1 (-148))) ((*1 *1 *1) (-4 *1 (-1137)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-572)) (-5 *1 (-577 *3)) (-4 *3 (-1044 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *2 *5 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1033 (-841 (-572)))) (-5 *3 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *4)))) (-4 *4 (-1054)) (-5 *1 (-597 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-959 (-572))) (-5 *2 (-638 *1)) (-4 *1 (-1019)))) ((*1 *2 *3) (-12 (-5 *3 (-959 (-413 (-572)))) (-5 *2 (-638 *1)) (-4 *1 (-1019)))) ((*1 *2 *3) (-12 (-5 *3 (-959 *1)) (-4 *1 (-1019)) (-5 *2 (-638 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 (-572))) (-5 *2 (-638 *1)) (-4 *1 (-1019)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 (-413 (-572)))) (-5 *2 (-638 *1)) (-4 *1 (-1019)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 *1)) (-4 *1 (-1019)) (-5 *2 (-638 *1)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-638 *1)) (-4 *1 (-1070 *4 *3))))) 
-(((*1 *2) (-12 (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-303)) (-5 *1 (-461 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-303)) (-5 *1 (-466 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-303)) (-14 *4 *3) (-14 *5 (-1 *3 *3 (-769))) (-5 *1 (-548 *3 *2 *4 *5)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-677 *2)) (-4 *2 (-1098))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-258)))) ((*1 *1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-258))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *2 *2 *3) (-12 (-4 *1 (-671 *2 *3)) (-4 *2 (-1204)) (-4 *3 (-1204))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-1 (-217) (-217))) (-5 *1 (-699 *3)) (-4 *3 (-613 (-545))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-1 (-217) (-217) (-217))) (-5 *1 (-699 *3)) (-4 *3 (-613 (-545)))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3))))) 
-(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-572)) (-5 *3 (-923)) (-4 *1 (-410)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-4 *1 (-410)))) ((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *2 *6)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-638 *6) "failed") (-572) *6 *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-2 (|:| |answer| (-589 (-413 *7))) (|:| |a0| *6))) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-174))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-638 (-638 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-638 (-3 (|:| |array| (-638 *3)) (|:| |scalar| (-1170))))) (-5 *6 (-638 (-1170))) (-5 *3 (-1170)) (-5 *2 (-1102)) (-5 *1 (-403)))) ((*1 *2 *3 *4 *5 *6 *3) (-12 (-5 *5 (-638 (-638 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-638 (-3 (|:| |array| (-638 *3)) (|:| |scalar| (-1170))))) (-5 *6 (-638 (-1170))) (-5 *3 (-1170)) (-5 *2 (-1102)) (-5 *1 (-403)))) ((*1 *2 *3 *4 *5 *4) (-12 (-5 *4 (-638 (-1170))) (-5 *5 (-1173)) (-5 *3 (-1170)) (-5 *2 (-1102)) (-5 *1 (-403))))) 
-(((*1 *1) (-5 *1 (-443)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-424 (-1166 *1))) (-5 *1 (-312 *4)) (-5 *3 (-1166 *1)) (-4 *4 (-457)) (-4 *4 (-562)) (-4 *4 (-848)))) ((*1 *2 *3) (-12 (-4 *1 (-910)) (-5 *2 (-424 (-1166 *1))) (-5 *3 (-1166 *1))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *2 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *2 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-471 *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-244 *5 *4)) (-5 *3 (-572)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-5 *1 (-873 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-244 *5 *4)) (-5 *3 (-572)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *1 (-874 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5)))) ((*1 *1 *1) (-12 (-4 *1 (-978 *2)) (-4 *2 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-978 *3)) (-4 *3 (-368))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-330)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-330))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -4161 (-769)) (|:| |curves| (-769)) (|:| |polygons| (-769)) (|:| |constructs| (-769))))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-326 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *2 (-457)))) ((*1 *1 *1) (-12 (-4 *1 (-342 *2 *3 *4)) (-4 *2 (-1214)) (-4 *3 (-1234 *2)) (-4 *4 (-1234 (-413 *3))))) ((*1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-457)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *3 (-457)))) ((*1 *1 *1) (-12 (-4 *1 (-956 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-303)) (-4 *3 (-562)) (-5 *1 (-1157 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *1) (-5 *1 (-824)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))))) ((*1 *1 *1) (-5 *1 (-385))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-774 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-436 *6) (-23) (-1044 (-572)) (-1044 *4) (-901 *4) (-162))) (-5 *4 (-1170)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *1 (-1031 *6 *2))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5 *5)) (-4 *5 (-1249 *4)) (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-1 (-1150 *4) (-1150 *4) (-1150 *4))) (-5 *1 (-1251 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-933)) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-933)) (-5 *4 (-413 (-572))) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-933))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-312 (-217))) (-5 *1 (-301)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |num| (-893 *3)) (|:| |den| (-893 *3)))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1 *2 *3 *1) (-12 (-4 *1 (-326 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-647 (-413 *6))) (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-413 *6))) (-5 *1 (-813 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-647 (-413 *7))) (-5 *4 (-1 (-638 *6) *7)) (-5 *5 (-1 (-424 *7) *7)) (-4 *6 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *7 (-1234 *6)) (-5 *2 (-638 (-413 *7))) (-5 *1 (-813 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-648 *6 (-413 *6))) (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-413 *6))) (-5 *1 (-813 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-648 *7 (-413 *7))) (-5 *4 (-1 (-638 *6) *7)) (-5 *5 (-1 (-424 *7) *7)) (-4 *6 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *7 (-1234 *6)) (-5 *2 (-638 (-413 *7))) (-5 *1 (-813 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-647 (-413 *5))) (-4 *5 (-1234 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-413 *5))) (-5 *1 (-813 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-647 (-413 *6))) (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-413 *6))) (-5 *1 (-813 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-648 *5 (-413 *5))) (-4 *5 (-1234 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-413 *5))) (-5 *1 (-813 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-648 *6 (-413 *6))) (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-413 *6))) (-5 *1 (-813 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-956 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |poly| *3) (|:| |mult| *5))) (-5 *1 (-454 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-413 *6)) (-4 *5 (-1214)) (-4 *6 (-1234 *5)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *3) (|:| |radicand| *6))) (-5 *1 (-152 *5 *6 *7)) (-5 *4 (-769)) (-4 *7 (-1234 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-37 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-43 *2)) (-4 *2 (-174)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-368)) (-14 *6 (-1259 (-685 *3))) (-5 *1 (-49 *3 *4 *5 *6)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))))) ((*1 *1 *2) (-12 (-5 *2 (-1121 (-572) (-611 (-53)))) (-5 *1 (-53)))) ((*1 *2 *3) (-12 (-5 *2 (-57)) (-5 *1 (-56 *3)) (-4 *3 (-1204)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-3921) (-694)))) (-5 *1 (-66 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694)))) (-5 *1 (-68 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-339 (-3921 (QUOTE X)) (-3921) (-694))) (-5 *1 (-69 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-339 (-3921) (-3921 (QUOTE X) (QUOTE HESS)) (-694)))) (-5 *1 (-70 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-339 (-3921) (-3921 (QUOTE XC)) (-694))) (-5 *1 (-71 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694)))) (-5 *1 (-76 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) (-5 *1 (-79 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X) (QUOTE EPS)) (-3921 (QUOTE -2301)) (-694)))) (-5 *1 (-80 *3 *4 *5)) (-14 *3 (-1170)) (-14 *4 (-1170)) (-14 *5 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE EPS)) (-3921 (QUOTE YA) (QUOTE YB)) (-694)))) (-5 *1 (-81 *3 *4 *5)) (-14 *3 (-1170)) (-14 *4 (-1170)) (-14 *5 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-339 (-3921) (-3921 (QUOTE X)) (-694))) (-5 *1 (-82 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-339 (-3921) (-3921 (QUOTE X)) (-694))) (-5 *1 (-83 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE XC)) (-694)))) (-5 *1 (-84 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) (-5 *1 (-85 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921) (-3921 (QUOTE X)) (-694)))) (-5 *1 (-86 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694)))) (-5 *1 (-87 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-339 (-3921 (QUOTE X) (QUOTE -2301)) (-3921) (-694)))) (-5 *1 (-88 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-339 (-3921 (QUOTE X)) (-3921) (-694)))) (-5 *1 (-89 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X)) (-3921) (-694)))) (-5 *1 (-90 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694)))) (-5 *1 (-91 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-339 (-3921 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-3921) (-694)))) (-5 *1 (-92 *3)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-339 (-3921 (QUOTE X)) (-3921 (QUOTE -2301)) (-694))) (-5 *1 (-94 *3)) (-14 *3 (-1170)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-1011 2)) (-5 *1 (-112)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-112)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-4 *1 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-142 *3 *4 *5))) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)) (-4 *5 (-174)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *5)) (-4 *5 (-174)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)))) ((*1 *1 *2) (-12 (-5 *2 (-1135 *4 *5)) (-14 *4 (-769)) (-4 *5 (-174)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)))) ((*1 *1 *2) (-12 (-5 *2 (-234 *4 *5)) (-14 *4 (-769)) (-4 *5 (-174)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 (-685 *4))) (-4 *4 (-174)) (-5 *2 (-1259 (-685 (-413 (-959 *4))))) (-5 *1 (-183 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))) (-5 *1 (-207 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1011 10)) (-5 *1 (-210)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-210)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-235 *3)) (-4 *3 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-235 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1 *3 (-923))) (-5 *1 (-235 *3)) (-4 *3 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3 (-923))) (-4 *3 (-1054)) (-5 *1 (-235 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-242 *3)) (-4 *3 (-848)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-242 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1090 (-312 *4))) (-4 *4 (-13 (-848) (-562) (-613 (-385)))) (-5 *2 (-1090 (-385))) (-5 *1 (-253 *4)))) ((*1 *1 *2) (-12 (-4 *1 (-264 *2)) (-4 *2 (-848)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-273)))) ((*1 *2 *1) (-12 (-4 *2 (-1234 *3)) (-5 *1 (-286 *3 *2 *4 *5 *6 *7)) (-4 *3 (-174)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1243 *4 *5 *6)) (-4 *4 (-13 (-27) (-1190) (-436 *3))) (-14 *5 (-1170)) (-14 *6 *4) (-4 *3 (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457))) (-5 *1 (-309 *3 *4 *5 *6)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-330)))) ((*1 *2 *1) (-12 (-5 *2 (-312 *5)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *2 (-329 *4)) (-5 *1 (-351 *3 *4 *2)) (-4 *3 (-329 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *2 (-329 *4)) (-5 *1 (-351 *2 *4 *3)) (-4 *3 (-329 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *2 (-1281 *3 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *2 (-1272 *3 *4)))) ((*1 *1 *2) (-12 (-4 *1 (-380 *2 *3)) (-4 *2 (-848)) (-4 *3 (-174)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-694))) (-4 *1 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-390)))) ((*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-390)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-390)))) ((*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-1152)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-4 *1 (-395)))) ((*1 *2 *3) (-12 (-5 *2 (-400)) (-5 *1 (-399 *3)) (-4 *3 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-400)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-171 (-385))))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-385)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-572)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-171 (-385)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-385))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-572))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-689)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-694)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-290 (-312 (-696)))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-689))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-694))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-696))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-330)) (-5 *1 (-404 *3 *4 *5 *6)) (-14 *3 (-1170)) (-14 *4 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-14 *5 (-638 (-1170))) (-14 *6 (-1174)))) ((*1 *1 *2) (-12 (-5 *2 (-331 *4)) (-4 *4 (-13 (-848) (-21))) (-5 *1 (-433 *3 *4)) (-4 *3 (-13 (-174) (-43 (-413 (-572))))))) ((*1 *1 *2) (-12 (-5 *1 (-433 *2 *3)) (-4 *2 (-13 (-174) (-43 (-413 (-572))))) (-4 *3 (-13 (-848) (-21))))) ((*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-413 *3)))) (-4 *3 (-562)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-959 (-413 *3))) (-4 *3 (-562)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-413 *3)) (-4 *3 (-562)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1121 *3 (-611 *1))) (-4 *3 (-1054)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1102)) (-5 *1 (-440)))) ((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-440)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-440)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-440)))) ((*1 *1 *2) (-12 (-5 *2 (-440)) (-5 *1 (-443)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-443)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-445)))) ((*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-445)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-445)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-694))) (-4 *1 (-445)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1174)) (|:| -1831 (-638 (-330))))) (-4 *1 (-446)))) ((*1 *1 *2) (-12 (-5 *2 (-330)) (-4 *1 (-446)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-4 *1 (-446)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-413 (-959 *3)))) (-4 *3 (-174)) (-14 *6 (-1259 (-685 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *1 (-477)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-477)))) ((*1 *1 *2) (-12 (-5 *2 (-1243 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3) (-5 *1 (-483 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-483 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-1011 16)) (-5 *1 (-501)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-501)))) ((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-504)))) ((*1 *1 *2) (-12 (-5 *2 (-1121 (-572) (-611 (-508)))) (-5 *1 (-508)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-515)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-4 *3 (-174)) (-5 *1 (-606 *3 *2)) (-4 *2 (-742 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-612 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (-12 (-4 *1 (-616 *2)) (-4 *2 (-1054)))) ((*1 *2 *1) (-12 (-5 *2 (-1277 *3 *4)) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) ((*1 *2 *1) (-12 (-5 *2 (-1272 *3 *4)) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) ((*1 *1 *2) (-12 (-4 *3 (-174)) (-5 *1 (-630 *3 *2)) (-4 *2 (-742 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))))) ((*1 *1 *2) (-12 (-5 *2 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *3)))) (-4 *3 (-368)) (-4 *1 (-645 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-672 *3)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-820 *3)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-965 (-965 (-965 *3)))) (-5 *1 (-670 *3)) (-4 *3 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-965 (-965 (-965 *3)))) (-4 *3 (-1098)) (-5 *1 (-670 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-820 *3)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) ((*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-677 *3)) (-4 *3 (-1098)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *2)) (-4 *4 (-379 *3)) (-4 *2 (-379 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-171 (-385))) (-5 *1 (-689)))) ((*1 *1 *2) (-12 (-5 *2 (-171 (-696))) (-5 *1 (-689)))) ((*1 *1 *2) (-12 (-5 *2 (-171 (-694))) (-5 *1 (-689)))) ((*1 *1 *2) (-12 (-5 *2 (-171 (-572))) (-5 *1 (-689)))) ((*1 *1 *2) (-12 (-5 *2 (-171 (-385))) (-5 *1 (-689)))) ((*1 *1 *2) (-12 (-5 *2 (-696)) (-5 *1 (-694)))) ((*1 *2 *1) (-12 (-5 *2 (-385)) (-5 *1 (-694)))) ((*1 *2 *3) (-12 (-5 *3 (-312 (-572))) (-5 *2 (-312 (-696))) (-5 *1 (-696)))) ((*1 *1 *2) (-12 (-5 *1 (-698 *2)) (-4 *2 (-1098)))) ((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-706)))) ((*1 *2 *1) (-12 (-4 *2 (-174)) (-5 *1 (-707 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-708 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -1763 *3) (|:| -3751 *4))) (-5 *1 (-709 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-1098)) (-14 *5 (-1 (-121) *2 *2)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -1763 *3) (|:| -3751 *4))) (-4 *3 (-848)) (-4 *4 (-1098)) (-5 *1 (-709 *3 *4 *5)) (-14 *5 (-1 (-121) *2 *2)))) ((*1 *2 *1) (-12 (-4 *2 (-174)) (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4513 *3) (|:| -4518 *4)))) (-4 *3 (-1054)) (-4 *4 (-722)) (-5 *1 (-731 *3 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-413 (-740 *3 *4))) (-14 *3 (-1170)) (-4 *4 (-13 (-1054) (-848) (-562))) (-5 *1 (-739 *3 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-959 *4)) (-4 *4 (-1054)) (-5 *1 (-740 *3 *4)) (-14 *3 (-1170)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *3)) (-14 *3 (-1170)) (-5 *1 (-740 *3 *4)) (-4 *4 (-1054)))) ((*1 *1 *2) (-12 (-5 *1 (-740 *3 *2)) (-14 *3 (-1170)) (-4 *2 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-761)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) (-5 *1 (-767)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *1 (-767)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *1 (-767)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-767)))) ((*1 *2 *3) (-12 (-5 *2 (-772)) (-5 *1 (-771 *3)) (-4 *3 (-1204)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *1 (-809)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-809)))) ((*1 *2 *1) (-12 (-4 *2 (-901 *3)) (-5 *1 (-818 *3 *2 *4)) (-4 *3 (-1098)) (-14 *4 *3))) ((*1 *1 *2) (-12 (-4 *3 (-1098)) (-14 *4 *3) (-5 *1 (-818 *3 *2 *4)) (-4 *2 (-901 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-825)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))) (-5 *1 (-839)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *1 (-839)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (-5 *1 (-839)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-839)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *3)) (-14 *3 (-1170)) (-5 *1 (-853 *3 *4 *5 *6)) (-4 *4 (-1054)) (-14 *5 (-101 *4)) (-14 *6 (-1 *4 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-855)))) ((*1 *1 *2) (-12 (-5 *2 (-959 *3)) (-4 *3 (-1054)) (-5 *1 (-859 *3 *4 *5 *6)) (-14 *4 (-638 (-1170))) (-14 *5 (-638 (-769))) (-14 *6 (-769)))) ((*1 *2 *1) (-12 (-5 *2 (-959 *3)) (-5 *1 (-859 *3 *4 *5 *6)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))) (-14 *5 (-638 (-769))) (-14 *6 (-769)))) ((*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875)))) ((*1 *2 *3) (-12 (-5 *3 (-959 (-53))) (-5 *2 (-312 (-572))) (-5 *1 (-876)))) ((*1 *2 *3) (-12 (-5 *3 (-413 (-959 (-53)))) (-5 *2 (-312 (-572))) (-5 *1 (-876)))) ((*1 *1 *2) (-12 (-5 *1 (-894 *2)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-820 *3)) (-5 *1 (-894 *3)) (-4 *3 (-848)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *1 (-899)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-899)))) ((*1 *2 *1) (-12 (-5 *2 (-1191 *3)) (-5 *1 (-902 *3)) (-4 *3 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-906 *3))) (-4 *3 (-1098)) (-5 *1 (-905 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-906 *3))) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-906 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-5 *1 (-906 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-413 (-424 *3))) (-4 *3 (-303)) (-5 *1 (-916 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-413 *3)) (-5 *1 (-916 *3)) (-4 *3 (-303)))) ((*1 *2 *3) (-12 (-5 *3 (-493)) (-5 *2 (-312 *4)) (-5 *1 (-921 *4)) (-4 *4 (-13 (-848) (-562))))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-978 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-979)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) ((*1 *2 *3) (-12 (-5 *2 (-1264)) (-5 *1 (-1040 *3)) (-4 *3 (-1204)))) ((*1 *2 *3) (-12 (-5 *3 (-307)) (-5 *1 (-1040 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1041 *3 *4 *5 *2 *6)) (-4 *2 (-956 *3 *4 *5)) (-14 *6 (-638 *2)))) ((*1 *1 *2) (-12 (-4 *1 (-1044 *2)) (-4 *2 (-1204)))) ((*1 *2 *3) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-1049 *3)) (-4 *3 (-562)))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1054)))) ((*1 *2 *1) (-12 (-5 *2 (-685 *5)) (-5 *1 (-1058 *3 *4 *5)) (-14 *3 (-769)) (-14 *4 (-769)) (-4 *5 (-1054)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-848)) (-5 *1 (-1122 *3 *4 *2)) (-4 *2 (-956 *3 (-538 *4) *4)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *2 (-848)) (-5 *1 (-1122 *3 *2 *4)) (-4 *4 (-956 *3 (-538 *2) *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-856)))) ((*1 *2 *1) (-12 (-5 *2 (-685 *4)) (-5 *1 (-1135 *3 *4)) (-14 *3 (-769)) (-4 *4 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-148)) (-4 *1 (-1137)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3)))) ((*1 *2 *3) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-1154 *3)) (-4 *3 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1160 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1167 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1168 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1231 *4 *3)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3) (-5 *1 (-1168 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1169)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1170)))) ((*1 *2 *1) (-12 (-5 *2 (-1178 (-1170) (-443))) (-5 *1 (-1174)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1177 *3)) (-4 *3 (-1098)))) ((*1 *2 *3) (-12 (-5 *2 (-1185)) (-5 *1 (-1184 *3)) (-4 *3 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-1185)))) ((*1 *1 *2) (-12 (-5 *2 (-959 *3)) (-4 *3 (-1054)) (-5 *1 (-1199 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1199 *3)) (-4 *3 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-965 *3)) (-4 *3 (-1204)) (-5 *1 (-1202 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 (QUOTE |x|))) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-1231 (QUOTE |x|) *3)) (-4 *3 (-1054)) (-5 *1 (-1216 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *1 (-1220 *3 *2)) (-4 *2 (-1249 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1222 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1092 *3)) (-4 *3 (-1204)) (-5 *1 (-1225 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *3)) (-14 *3 (-1170)) (-5 *1 (-1231 *3 *4)) (-4 *4 (-1054)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *1 (-1241 *3 *2)) (-4 *2 (-1218 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1231 *4 *3)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3) (-5 *1 (-1250 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)))) ((*1 *1 *2) (-12 (-5 *2 (-1231 *4 *3)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-5 *1 (-1254 *3 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-1255 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1260)))) ((*1 *2 *3) (-12 (-5 *3 (-477)) (-5 *2 (-1260)) (-5 *1 (-1263)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1264)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-794)) (-14 *6 (-638 *4)) (-5 *1 (-1269 *3 *4 *5 *2 *6 *7 *8)) (-4 *2 (-956 *3 *5 *4)) (-14 *7 (-638 (-769))) (-14 *8 (-769)))) ((*1 *2 *1) (-12 (-4 *2 (-956 *3 *5 *4)) (-5 *1 (-1269 *3 *4 *5 *2 *6 *7 *8)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-794)) (-14 *6 (-638 *4)) (-14 *7 (-638 (-769))) (-14 *8 (-769)))) ((*1 *1 *2) (-12 (-4 *1 (-1271 *2)) (-4 *2 (-1054)))) ((*1 *1 *2) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-5 *2 (-1281 *3 *4)) (-5 *1 (-1277 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) ((*1 *2 *1) (-12 (-5 *2 (-1272 *3 *4)) (-5 *1 (-1277 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) ((*1 *1 *2) (-12 (-5 *2 (-660 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *1 (-1277 *3 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-1280 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-844))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-2 (|:| |num| (-1259 *4)) (|:| |den| *4)))))) 
-(((*1 *2 *3 *2) (|partial| -12 (-5 *3 (-923)) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) ((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-923)) (-5 *4 (-769)) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) ((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-923)) (-5 *4 (-638 (-769))) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) ((*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *3 (-923)) (-5 *4 (-638 (-769))) (-5 *5 (-769)) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) ((*1 *2 *3 *2 *4 *5 *6) (|partial| -12 (-5 *3 (-923)) (-5 *4 (-638 (-769))) (-5 *5 (-769)) (-5 *6 (-121)) (-5 *1 (-447 *2)) (-4 *2 (-1234 (-572))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-424 *2)) (-4 *2 (-1234 *5)) (-5 *1 (-449 *5 *2)) (-4 *5 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1249 *4)) (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-1 (-1150 *4) (-1150 *4))) (-5 *1 (-1251 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572)))))))))) (-5 *1 (-1174))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-1054)) (-4 *2 (-1234 *4)) (-5 *1 (-449 *4 *2)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-413 (-1166 (-312 *5)))) (-5 *3 (-1259 (-312 *5))) (-5 *4 (-572)) (-4 *5 (-13 (-562) (-848))) (-5 *1 (-1126 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-1236 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-4 *1 (-1239 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *1 *2 *2) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3))))) 
-(((*1 *1 *1) (|partial| -4 *1 (-1144)))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 (-496 *5 *6))) (-5 *4 (-858 *5)) (-14 *5 (-638 (-1170))) (-5 *2 (-496 *5 *6)) (-5 *1 (-626 *5 *6)) (-4 *6 (-457)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-496 *5 *6))) (-5 *4 (-858 *5)) (-14 *5 (-638 (-1170))) (-5 *2 (-496 *5 *6)) (-5 *1 (-626 *5 *6)) (-4 *6 (-457))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-572)) (-4 *4 (-1054)) (-5 *1 (-1154 *4)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-1170))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-1170))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-504)))) ((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-706))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 (-1270 *4 *5 *6 *7))) (-5 *1 (-1270 *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1068 *6 *7 *8)) (-4 *6 (-562)) (-4 *7 (-794)) (-4 *8 (-848)) (-5 *2 (-638 (-1270 *6 *7 *8 *9))) (-5 *1 (-1270 *6 *7 *8 *9))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-451)) (-5 *3 (-572))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 (-769) *2)) (-5 *4 (-769)) (-4 *2 (-1098)) (-5 *1 (-674 *2)))) ((*1 *2 *2) (-12 (-5 *2 (-1 *3 (-769) *3)) (-4 *3 (-1098)) (-5 *1 (-677 *3))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-413 (-959 *4))) (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-1044 (-572)) (-151))) (-5 *1 (-578 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-171 (-572))))) (-5 *2 (-638 (-171 *4))) (-5 *1 (-384 *4)) (-4 *4 (-13 (-368) (-846))))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-413 (-959 (-171 (-572)))))) (-5 *4 (-638 (-1170))) (-5 *2 (-638 (-638 (-171 *5)))) (-5 *1 (-384 *5)) (-4 *5 (-13 (-368) (-846)))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-638 *2)) (-5 *1 (-122 *2)) (-4 *2 (-1098)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 (-638 *4))) (-4 *4 (-1098)) (-5 *1 (-122 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1098)) (-5 *1 (-122 *4)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-1 *4 (-638 *4))) (-5 *1 (-122 *4)) (-4 *4 (-1098)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-641 *3)) (-4 *3 (-1054)) (-5 *1 (-710 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-835 *3))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569))))) 
-(((*1 *1 *1) (-4 *1 (-562)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-312 (-217)))) (-5 *4 (-769)) (-5 *2 (-685 (-217))) (-5 *1 (-265))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1234 *3)) (-4 *3 (-1054))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-916 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-368) (-846))) (-5 *2 (-638 (-2 (|:| -4547 (-638 *3)) (|:| -3900 *5)))) (-5 *1 (-180 *5 *3)) (-4 *3 (-1234 (-171 *5))))) ((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-638 (-2 (|:| -4547 (-638 *3)) (|:| -3900 *4)))) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-605 *2 *3)) (-4 *3 (-1204)) (-4 *2 (-1098)) (-4 *2 (-848))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1166 *1)) (-4 *1 (-1019))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-113))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-638 (-572)))) (-5 *1 (-930 *4 *5 *6 *7)) (-5 *3 (-572)) (-4 *7 (-956 *4 *6 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-316 *3 *4 *5)) (-4 *3 (-13 (-368) (-848))) (-14 *4 (-1170)) (-14 *5 *3)))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-769))))) 
-(((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-121)) (-5 *5 (-572)) (-4 *6 (-368)) (-4 *6 (-374)) (-4 *6 (-1054)) (-5 *2 (-638 (-638 (-685 *6)))) (-5 *1 (-1036 *6)) (-5 *3 (-638 (-685 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-368)) (-4 *4 (-374)) (-4 *4 (-1054)) (-5 *2 (-638 (-638 (-685 *4)))) (-5 *1 (-1036 *4)) (-5 *3 (-638 (-685 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-368)) (-4 *5 (-374)) (-4 *5 (-1054)) (-5 *2 (-638 (-638 (-685 *5)))) (-5 *1 (-1036 *5)) (-5 *3 (-638 (-685 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-4 *5 (-374)) (-4 *5 (-1054)) (-5 *2 (-638 (-638 (-685 *5)))) (-5 *1 (-1036 *5)) (-5 *3 (-638 (-685 *5)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-923))) (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-769)) (-5 *4 (-572)) (-5 *1 (-450 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-638 (-611 *5))) (-5 *3 (-1170)) (-4 *5 (-436 *4)) (-4 *4 (-848)) (-5 *1 (-581 *4 *5))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -4513 (-413 *5)) (|:| |poly| *3))) (-5 *1 (-152 *4 *5 *3)) (-4 *3 (-1234 (-413 *5)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-965 *3)) (-5 *1 (-1157 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-572))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-965 (-1166 *4))) (-5 *1 (-361 *4)) (-5 *3 (-1166 *4))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-151)) (-4 *2 (-303)) (-4 *2 (-457)) (-4 *3 (-848)) (-4 *4 (-794)) (-5 *1 (-995 *2 *3 *4 *5)) (-4 *5 (-956 *2 *4 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-53)) (-5 *2 (-312 (-572))) (-5 *1 (-1115)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-769))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) ((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933))))) 
-(((*1 *1 *1) (-5 *1 (-1066)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-4 *1 (-155 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -3751 (-769)) (|:| -1694 *4) (|:| |num| *4)))) (-4 *4 (-1234 *3)) (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *4)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-121)) (-5 *1 (-443)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *3 (-638 (-1170))) (-5 *4 (-121)) (-5 *1 (-443)))) ((*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-602 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-629 *2)) (-4 *2 (-174)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-667 *3)) (-4 *3 (-848)) (-5 *1 (-660 *3 *4)) (-4 *4 (-174)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-667 *3)) (-4 *3 (-848)) (-5 *1 (-660 *3 *4)) (-4 *4 (-174)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-667 *3)) (-4 *3 (-848)) (-5 *1 (-660 *3 *4)) (-4 *4 (-174)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-638 *3)))) (-4 *3 (-1098)) (-5 *1 (-670 *3)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-709 *2 *3 *4)) (-4 *2 (-848)) (-4 *3 (-1098)) (-14 *4 (-1 (-121) (-2 (|:| -1763 *2) (|:| -3751 *3)) (-2 (|:| -1763 *2) (|:| -3751 *3)))))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-1170)) (|:| -4320 *4)))) (-4 *4 (-1098)) (-5 *1 (-890 *3 *4)) (-4 *3 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 *5)) (-4 *5 (-13 (-1098) (-39))) (-5 *2 (-638 (-1133 *3 *5))) (-5 *1 (-1133 *3 *5)) (-4 *3 (-13 (-1098) (-39))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| |val| *4) (|:| -1337 *5)))) (-4 *4 (-13 (-1098) (-39))) (-4 *5 (-13 (-1098) (-39))) (-5 *2 (-638 (-1133 *4 *5))) (-5 *1 (-1133 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |val| *3) (|:| -1337 *4))) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1133 *3 *4)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) ((*1 *1 *2 *3 *2 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-13 (-1098) (-39))) (-5 *1 (-1134 *2 *3)) (-4 *2 (-13 (-1098) (-39))))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-638 (-1133 *2 *3))) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))) (-5 *1 (-1134 *2 *3)))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-638 (-1134 *2 *3))) (-5 *1 (-1134 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) ((*1 *1 *2) (-12 (-5 *2 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1134 *3 *4)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-1159 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-121)) (-5 *1 (-341 *3 *4 *5 *6)) (-4 *3 (-342 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1150 (-1150 *4))) (-5 *2 (-1150 *4)) (-5 *1 (-1154 *4)) (-4 *4 (-43 (-413 (-572)))) (-4 *4 (-1054))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-4 *4 (-1054)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-410)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-694))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-175 (-413 (-572)))) (-5 *1 (-126 *3)) (-14 *3 (-572)))) ((*1 *1 *2 *3 *3) (-12 (-5 *3 (-1150 *2)) (-4 *2 (-303)) (-5 *1 (-175 *2)))) ((*1 *1 *2) (-12 (-5 *2 (-413 *3)) (-4 *3 (-303)) (-5 *1 (-175 *3)))) ((*1 *2 *3) (-12 (-5 *2 (-175 (-572))) (-5 *1 (-763 *3)) (-4 *3 (-410)))) ((*1 *2 *1) (-12 (-5 *2 (-175 (-413 (-572)))) (-5 *1 (-871 *3)) (-14 *3 (-572)))) ((*1 *2 *1) (-12 (-14 *3 (-572)) (-5 *2 (-175 (-413 (-572)))) (-5 *1 (-872 *3 *4)) (-4 *4 (-869 *3))))) 
-(((*1 *2 *3) (-12 (-4 *3 (-1234 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-993 *4 *2 *3 *5)) (-4 *4 (-353)) (-4 *5 (-720 *2 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-363 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1152)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-258))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 *4)) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-638 (-1076 *4 *5 *2))) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))) (-5 *1 (-60 *4 *5 *2)))) ((*1 *2 *3 *2 *4) (-12 (-5 *3 (-638 (-1076 *5 *6 *2))) (-5 *4 (-923)) (-4 *5 (-1098)) (-4 *6 (-13 (-1054) (-887 *5) (-848) (-613 (-893 *5)))) (-4 *2 (-13 (-436 *6) (-887 *5) (-613 (-893 *5)))) (-5 *1 (-60 *5 *6 *2))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-140))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-1098)) (-4 *2 (-901 *4)) (-5 *1 (-687 *4 *2 *5 *3)) (-4 *5 (-379 *2)) (-4 *3 (-13 (-379 *4) (-10 -7 (-6 -4602))))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009)))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-457)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1166 *6)) (-4 *6 (-956 *5 *3 *4)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-910)) (-5 *1 (-463 *3 *4 *5 *6)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-910))))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1270 *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-638 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1270 *5 *6 *7 *8))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-1 *5 *5)) (-5 *1 (-805 *4 *5)) (-4 *5 (-13 (-29 *4) (-1190) (-966)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-1054)) (-5 *1 (-449 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-307)) (-5 *1 (-292)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-307)) (-5 *1 (-292)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-307)) (-5 *1 (-292)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-1152))) (-5 *3 (-1152)) (-5 *2 (-307)) (-5 *1 (-292))))) 
-(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-638 (-959 *6))) (-5 *4 (-638 (-1170))) (-4 *6 (-457)) (-5 *2 (-638 (-638 *7))) (-5 *1 (-547 *6 *7 *5)) (-4 *7 (-368)) (-4 *5 (-13 (-368) (-846)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| *7) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 *7))))) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-769)) (-5 *1 (-930 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-121)) (-5 *1 (-449 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-1174))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *2 (-1068 *4 *5 *6)) (-5 *1 (-774 *4 *5 *6 *2 *3)) (-4 *3 (-1073 *4 *5 *6 *2))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-956 *3 *5 *4)) (-5 *1 (-995 *3 *4 *5 *2)) (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-718)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-722)) (-5 *2 (-121))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *7))) (-5 *3 (-1166 *7)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-910)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-907 *4 *5 *6 *7)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *5))) (-5 *3 (-1166 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-910)) (-5 *1 (-908 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-469)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-933))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-545))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1091 *3)) (-4 *3 (-1204))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-638 *7)) (|:| |badPols| (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-5 *2 (-638 *6)) (-5 *1 (-914 *4 *5 *6 *7)) (-4 *5 (-326 *4 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-443))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-968 *2)) (-4 *2 (-554))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-236)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-1264)) (-5 *1 (-236))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-361 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-536 *4))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1166 *9)) (-5 *4 (-638 *7)) (-5 *5 (-638 (-638 *8))) (-4 *7 (-848)) (-4 *8 (-303)) (-4 *9 (-956 *8 *6 *7)) (-4 *6 (-794)) (-5 *2 (-2 (|:| |upol| (-1166 *8)) (|:| |Lval| (-638 *8)) (|:| |Lfact| (-638 (-2 (|:| -4304 (-1166 *8)) (|:| -3751 (-572))))) (|:| |ctpol| *8))) (-5 *1 (-738 *6 *7 *8 *9))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *4 *5 *6)) (-4 *4 (-303)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-452 *4 *5 *6 *2))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-442))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-424 *3)) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4)))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *1 *2 *3 *3 *3 *4) (-12 (-4 *4 (-368)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-4 *1 (-335 *4 *3 *5 *2)) (-4 *2 (-342 *4 *3 *5)))) ((*1 *1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *2 (-368)) (-4 *4 (-1234 *2)) (-4 *5 (-1234 (-413 *4))) (-4 *1 (-335 *2 *4 *5 *6)) (-4 *6 (-342 *2 *4 *5)))) ((*1 *1 *2 *2) (-12 (-4 *2 (-368)) (-4 *3 (-1234 *2)) (-4 *4 (-1234 (-413 *3))) (-4 *1 (-335 *2 *3 *4 *5)) (-4 *5 (-342 *2 *3 *4)))) ((*1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *1 (-335 *3 *4 *5 *2)) (-4 *2 (-342 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-419 *4 (-413 *4) *5 *6)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 *3 *4 *5)) (-4 *3 (-368)) (-4 *1 (-335 *3 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-846))) (-5 *1 (-180 *3 *2)) (-4 *2 (-1234 (-171 *3)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *3)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *3 (-848)) (-4 *3 (-1044 (-572))) (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-436 *3)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $)))))))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-143)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-148))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-385)) (-5 *1 (-1066))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-769)) (-4 *4 (-353)) (-5 *1 (-536 *4))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1064 (-1030 *4) (-1166 (-1030 *4)))) (-5 *3 (-856)) (-5 *1 (-1030 *4)) (-4 *4 (-13 (-846) (-368) (-1028)))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-171 (-385)))) (-5 *1 (-330)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-385))) (-5 *1 (-330)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-572))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-171 (-385))))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-385)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-572)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-171 (-385))))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-385)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-572)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-171 (-385)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-385))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-572))) (-5 *1 (-330)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-689))) (-5 *1 (-330)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-694))) (-5 *1 (-330)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-312 (-696))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-689)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-694)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-312 (-696)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-689)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-694)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-312 (-696)))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-689))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-694))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-696))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-689))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-694))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-685 (-696))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-689))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-694))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-312 (-696))) (-5 *1 (-330)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1152)) (-5 *1 (-330)))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-397))))) 
-(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *6 (-562)) (-5 *2 (-2 (|:| -1614 (-959 *6)) (|:| -2685 (-959 *6)))) (-5 *1 (-728 *4 *5 *6 *3)) (-4 *3 (-956 (-413 (-959 *6)) *4 *5))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-824)) (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1074 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-2 (|:| |val| (-638 *8)) (|:| -1337 *9)))) (-5 *5 (-121)) (-4 *8 (-1068 *6 *7 *4)) (-4 *9 (-1073 *6 *7 *4 *8)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *4 (-848)) (-5 *2 (-638 (-2 (|:| |val| *8) (|:| -1337 *9)))) (-5 *1 (-1074 *6 *7 *4 *8 *9))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-1019)) (-5 *2 (-856))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1101 *2 *3 *4 *5 *6)) (-4 *2 (-1098)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-545))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-783 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1101 *2 *3 *4 *5 *6)) (-4 *2 (-1098)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3190 *3) (|:| |coef2| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-572)) (-4 *6 (-645 *5)) (-4 *5 (-368)) (-5 *2 (-685 *5)) (-5 *1 (-639 *5 *6))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-769)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-794)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-454 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-361 *3)) (-4 *3 (-353))))) 
-(((*1 *2) (-12 (-5 *2 (-2 (|:| -4461 (-638 (-1170))) (|:| -2861 (-638 (-1170))))) (-5 *1 (-1212))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-959 (-572))) (-5 *2 (-330)) (-5 *1 (-332)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-1090 (-959 (-572)))) (-5 *2 (-330)) (-5 *1 (-332)))) ((*1 *1 *2 *2 *2) (-12 (-5 *2 (-769)) (-5 *1 (-670 *3)) (-4 *3 (-1054)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -4304 (-1166 *6)) (|:| -3751 (-572))))) (-4 *6 (-303)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-572)) (-5 *1 (-738 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-186)))) ((*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-296)))) ((*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-301))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *3)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-260 *12))))) 
-(((*1 *2 *3 *4 *4 *4 *5 *4 *6 *6 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *6 (-217)) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-956 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1234 *3))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-57)) (-5 *1 (-830))))) 
-(((*1 *1) (-5 *1 (-148)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-4 *5 (-368)) (-5 *2 (-1150 (-1150 (-959 *5)))) (-5 *1 (-1267 *5)) (-5 *4 (-1150 (-959 *5)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-342 *4 *3 *5)) (-4 *4 (-1214)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-52 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-55 *3 *4)) (-14 *4 (-638 (-1170))))) ((*1 *1 *2 *1 *1 *3) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-64 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-64 *6)) (-5 *1 (-63 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-96 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *7)) (-5 *4 (-142 *5 *6 *7)) (-14 *5 (-572)) (-14 *6 (-769)) (-4 *7 (-174)) (-4 *8 (-174)) (-5 *2 (-142 *5 *6 *8)) (-5 *1 (-141 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-171 *5)) (-4 *5 (-174)) (-4 *6 (-174)) (-5 *2 (-171 *6)) (-5 *1 (-170 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-214 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-312 *3) (-312 *3))) (-4 *3 (-13 (-1054) (-848))) (-5 *1 (-215 *3 *4)) (-14 *4 (-638 (-1170))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-234 *5 *6)) (-14 *5 (-769)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-5 *2 (-234 *5 *7)) (-5 *1 (-233 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-290 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-290 *6)) (-5 *1 (-289 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1204)) (-5 *1 (-290 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1152)) (-5 *5 (-611 *6)) (-4 *6 (-298)) (-4 *2 (-1204)) (-5 *1 (-293 *6 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5)) (-5 *4 (-611 *5)) (-4 *5 (-298)) (-4 *2 (-298)) (-5 *1 (-294 *5 *2)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *1 *1)) (-5 *3 (-611 *1)) (-4 *1 (-298)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-685 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-685 *6)) (-5 *1 (-300 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-312 *5)) (-4 *5 (-848)) (-4 *6 (-848)) (-5 *2 (-312 *6)) (-5 *1 (-310 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-4 *6 (-1054)) (-4 *7 (-1054)) (-4 *5 (-793)) (-4 *2 (-326 *7 *5)) (-5 *1 (-324 *5 *6 *4 *7 *2)) (-4 *4 (-326 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-336 *5 *6 *7 *8)) (-4 *5 (-368)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *8 (-342 *5 *6 *7)) (-4 *9 (-368)) (-4 *10 (-1234 *9)) (-4 *11 (-1234 (-413 *10))) (-5 *2 (-336 *9 *10 *11 *12)) (-5 *1 (-333 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-342 *9 *10 *11)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-338 *3)) (-4 *3 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1214)) (-4 *8 (-1214)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *9 (-1234 *8)) (-4 *2 (-342 *8 *9 *10)) (-5 *1 (-340 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-342 *5 *6 *7)) (-4 *10 (-1234 (-413 *9))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-4 *2 (-379 *6)) (-5 *1 (-377 *5 *4 *6 *2)) (-4 *4 (-379 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-424 *5)) (-4 *5 (-562)) (-4 *6 (-562)) (-5 *2 (-424 *6)) (-5 *1 (-411 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-413 *5)) (-4 *5 (-562)) (-4 *6 (-562)) (-5 *2 (-413 *6)) (-5 *1 (-412 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-419 *5 *6 *7 *8)) (-4 *5 (-303)) (-4 *6 (-1000 *5)) (-4 *7 (-1234 *6)) (-4 *8 (-13 (-415 *6 *7) (-1044 *6))) (-4 *9 (-303)) (-4 *10 (-1000 *9)) (-4 *11 (-1234 *10)) (-5 *2 (-419 *9 *10 *11 *12)) (-5 *1 (-418 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-13 (-415 *10 *11) (-1044 *10))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-174)) (-4 *6 (-174)) (-4 *2 (-423 *6)) (-5 *1 (-421 *4 *5 *2 *6)) (-4 *4 (-423 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-562)) (-5 *1 (-424 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-13 (-1054) (-848))) (-4 *6 (-13 (-1054) (-848))) (-4 *2 (-436 *6)) (-5 *1 (-427 *5 *4 *6 *2)) (-4 *4 (-436 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-431 *6)) (-5 *1 (-429 *5 *4 *6 *2)) (-4 *4 (-431 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-848)) (-5 *1 (-498 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-503 *3)) (-4 *3 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-522 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-848)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-589 *5)) (-4 *5 (-368)) (-4 *6 (-368)) (-5 *2 (-589 *6)) (-5 *1 (-588 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| -3444 *5) (|:| |coeff| *5)) "failed")) (-4 *5 (-368)) (-4 *6 (-368)) (-5 *2 (-2 (|:| -3444 *6) (|:| |coeff| *6))) (-5 *1 (-588 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *2 *5)) (-5 *4 (-3 *5 "failed")) (-4 *5 (-368)) (-4 *2 (-368)) (-5 *1 (-588 *5 *2)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| |mainpart| *5) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (-4 *5 (-368)) (-4 *6 (-368)) (-5 *2 (-2 (|:| |mainpart| *6) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *6) (|:| |logand| *6)))))) (-5 *1 (-588 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-602 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-602 *6)) (-5 *1 (-599 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-602 *6)) (-5 *5 (-602 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-602 *8)) (-5 *1 (-600 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1150 *6)) (-5 *5 (-602 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-1150 *8)) (-5 *1 (-600 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-602 *6)) (-5 *5 (-1150 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-1150 *8)) (-5 *1 (-600 *6 *7 *8)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-638 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-638 *6)) (-5 *1 (-636 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-638 *6)) (-5 *5 (-638 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-638 *8)) (-5 *1 (-637 *6 *7 *8)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1054)) (-4 *8 (-1054)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-4 *2 (-683 *8 *9 *10)) (-5 *1 (-681 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-683 *5 *6 *7)) (-4 *9 (-379 *8)) (-4 *10 (-379 *8)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *8 "failed") *5)) (-4 *5 (-1054)) (-4 *8 (-1054)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-4 *2 (-683 *8 *9 *10)) (-5 *1 (-681 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-683 *5 *6 *7)) (-4 *9 (-379 *8)) (-4 *10 (-379 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-562)) (-4 *7 (-562)) (-4 *6 (-1234 *5)) (-4 *2 (-1234 (-413 *8))) (-5 *1 (-705 *5 *6 *4 *7 *8 *2)) (-4 *4 (-1234 (-413 *6))) (-4 *8 (-1234 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *8)) (-4 *8 (-1054)) (-4 *9 (-1054)) (-4 *5 (-848)) (-4 *6 (-794)) (-4 *2 (-956 *9 *7 *5)) (-5 *1 (-724 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-794)) (-4 *4 (-956 *8 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-848)) (-4 *6 (-848)) (-4 *7 (-794)) (-4 *9 (-1054)) (-4 *2 (-956 *9 *8 *6)) (-5 *1 (-725 *5 *6 *7 *8 *9 *4 *2)) (-4 *8 (-794)) (-4 *4 (-956 *9 *7 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-731 *5 *7)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-4 *7 (-722)) (-5 *2 (-731 *6 *7)) (-5 *1 (-730 *5 *6 *7)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-731 *3 *4)) (-4 *4 (-722)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-783 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-783 *6)) (-5 *1 (-782 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-174)) (-4 *6 (-174)) (-4 *2 (-798 *6)) (-5 *1 (-799 *4 *5 *2 *6)) (-4 *4 (-798 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-834 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-834 *6)) (-5 *1 (-833 *5 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-834 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-834 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *1 (-833 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-841 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-841 *6)) (-5 *1 (-840 *5 *6)))) ((*1 *2 *3 *4 *2 *2) (-12 (-5 *2 (-841 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-841 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *1 (-840 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-879 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-879 *6)) (-5 *1 (-878 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-881 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-881 *6)) (-5 *1 (-880 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-883 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-883 *6)) (-5 *1 (-882 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-890 *5 *6)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-890 *5 *7)) (-5 *1 (-889 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-893 *6)) (-5 *1 (-892 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-959 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-959 *6)) (-5 *1 (-953 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *7)) (-5 *4 (-1 *2 *8)) (-4 *7 (-848)) (-4 *8 (-1054)) (-4 *6 (-794)) (-4 *2 (-13 (-1098) (-10 -8 (-15 -1367 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-769)))))) (-5 *1 (-958 *6 *7 *8 *5 *2)) (-4 *5 (-956 *8 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-965 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-965 *6)) (-5 *1 (-964 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-950 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-950 *6)) (-5 *1 (-989 *5 *6)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-1 *2 (-959 *4))) (-4 *4 (-1054)) (-4 *2 (-956 (-959 *4) *5 *6)) (-4 *5 (-794)) (-4 *6 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-5 *1 (-992 *4 *5 *6 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-562)) (-4 *6 (-562)) (-4 *2 (-1000 *6)) (-5 *1 (-998 *5 *6 *4 *2)) (-4 *4 (-1000 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-174)) (-4 *6 (-174)) (-4 *2 (-1004 *6)) (-5 *1 (-1005 *4 *5 *2 *6)) (-4 *4 (-1004 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-1007 *3)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *5 *5 *5)) (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *5 *5)) (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *10 *7)) (-4 *7 (-1054)) (-4 *10 (-1054)) (-14 *5 (-769)) (-14 *6 (-769)) (-4 *8 (-232 *6 *7)) (-4 *9 (-232 *5 *7)) (-4 *2 (-1057 *5 *6 *10 *11 *12)) (-5 *1 (-1059 *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (-4 *4 (-1057 *5 *6 *7 *8 *9)) (-4 *11 (-232 *6 *10)) (-4 *12 (-232 *5 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1092 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1092 *6)) (-5 *1 (-1088 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1092 *5)) (-4 *5 (-846)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-638 *6)) (-5 *1 (-1088 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1090 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1090 *6)) (-5 *1 (-1089 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 *4 *4)) (-4 *1 (-1093 *4 *2)) (-4 *4 (-846)) (-4 *2 (-1142 *4)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-1140 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1150 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1150 *6)) (-5 *1 (-1148 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1150 *6)) (-5 *5 (-1150 *7)) (-4 *6 (-1204)) (-4 *7 (-1204)) (-4 *8 (-1204)) (-5 *2 (-1150 *8)) (-5 *1 (-1149 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1166 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-5 *2 (-1166 *6)) (-5 *1 (-1163 *5 *6)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *4 *4 *4)) (-4 *1 (-1181 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1222 *5 *7 *9)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-14 *7 (-1170)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1222 *6 *8 *10)) (-5 *1 (-1217 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1170)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1225 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1225 *6)) (-5 *1 (-1224 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1225 *5)) (-4 *5 (-846)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1150 *6)) (-5 *1 (-1224 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *6)) (-5 *4 (-1231 *5 *6)) (-14 *5 (-1170)) (-4 *6 (-1054)) (-4 *8 (-1054)) (-5 *2 (-1231 *7 *8)) (-5 *1 (-1226 *5 *6 *7 *8)) (-14 *7 (-1170)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-4 *2 (-1234 *6)) (-5 *1 (-1232 *5 *4 *6 *2)) (-4 *4 (-1234 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1243 *5 *7 *9)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-14 *7 (-1170)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1243 *6 *8 *10)) (-5 *1 (-1238 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1170)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1054)) (-4 *6 (-1054)) (-4 *2 (-1249 *6)) (-5 *1 (-1247 *5 *6 *4 *2)) (-4 *4 (-1249 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1259 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1259 *6)) (-5 *1 (-1258 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *6 "failed") *5)) (-5 *4 (-1259 *5)) (-4 *5 (-1204)) (-4 *6 (-1204)) (-5 *2 (-1259 *6)) (-5 *1 (-1258 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-1280 *3 *4)) (-4 *4 (-844))))) 
-(((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-2 (|:| -4513 *1) (|:| |gap| (-769)) (|:| -2492 *1))) (-4 *1 (-1068 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -4513 *1) (|:| |gap| (-769)) (|:| -2492 *1))) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-4 *7 (-956 *4 *6 *5)) (-5 *2 (-2 (|:| |sysok| (-121)) (|:| |z0| (-638 *7)) (|:| |n0| (-638 *7)))) (-5 *1 (-930 *4 *5 *6 *7)) (-5 *3 (-638 *7))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-217)) (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1068 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *6 *3)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) ((*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-171 (-217)))) (-5 *2 (-217)) (-5 *1 (-115))))) 
-(((*1 *1 *2 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1152)) (-5 *1 (-997)))) ((*1 *2 *3 *1) (|partial| -12 (-5 *2 (-290 (-1085 *3))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) ((*1 *2 *1 *3) (|partial| -12 (-5 *2 (-290 (-1085 *3))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1092 *4)) (-4 *4 (-1204)) (-5 *1 (-1090 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-353)) (-5 *2 (-424 (-1166 (-1166 *5)))) (-5 *1 (-1203 *5)) (-5 *3 (-1166 (-1166 *5)))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-864)) (-5 *2 (-923))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-638 (-1150 *7))) (-4 *6 (-848)) (-4 *7 (-956 *5 (-538 *6) *6)) (-4 *5 (-1054)) (-5 *2 (-1 (-1150 *7) *7)) (-5 *1 (-1122 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |k| (-1170)) (|:| |c| (-1279 *3))))) (-5 *1 (-1279 *3)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |k| *3) (|:| |c| (-1281 *3 *4))))) (-5 *1 (-1281 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-244 *3 *4)) (-14 *3 (-638 (-1170))) (-4 *4 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-14 *3 (-638 (-1170))) (-5 *1 (-459 *3 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-232 (-4032 *3) (-769))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-496 *3 *4)) (-14 *3 (-638 (-1170))) (-4 *4 (-1054))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-3 (-2 (|:| -3444 *7) (|:| |coeff| *7)) "failed") *7)) (-5 *6 (-638 (-413 *8))) (-4 *7 (-368)) (-4 *8 (-1234 *7)) (-5 *3 (-413 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-582 *7 *8))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-312 (-217)))) (-5 *2 (-121)) (-5 *1 (-265)))) ((*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-121)) (-5 *1 (-265)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-638 *5)) (-4 *1 (-926 *4 *5)) (-4 *4 (-368)) (-4 *5 (-645 *4)) (-5 *2 (-1264))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) ((*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-102)))) ((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-207 (-515))) (-5 *1 (-836))))) 
-(((*1 *1 *1 *2 *1) (-12 (-4 *1 (-1137)) (-5 *2 (-1225 (-572)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-685 *2)) (-4 *4 (-1234 *2)) (-4 *2 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-5 *1 (-512 *2 *4 *5)) (-4 *5 (-415 *2 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *3 (-901 *5)) (-5 *2 (-685 *3)) (-5 *1 (-687 *5 *3 *6 *4)) (-4 *6 (-379 *3)) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4602))))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-50 (-1152) (-772))) (-5 *1 (-123))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-241 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *2 *3) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-856))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1234 (-413 (-572)))) (-5 *1 (-915 *3 *2)) (-4 *2 (-1234 (-413 *3)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1 (-121) *8))) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |goodPols| (-638 *8)) (|:| |badPols| (-638 *8)))) (-5 *1 (-985 *5 *6 *7 *8)) (-5 *4 (-638 *8))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-685 (-413 (-959 (-572))))) (-5 *2 (-685 (-312 (-572)))) (-5 *1 (-1038))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-572)) (|has| *1 (-6 -4593)) (-4 *1 (-410)) (-5 *2 (-923))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-691 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1 (-121) *8))) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |goodPols| (-638 *8)) (|:| |badPols| (-638 *8)))) (-5 *1 (-985 *5 *6 *7 *8)) (-5 *4 (-638 *8))))) 
-(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-893 *4)) (-4 *4 (-1098)) (-5 *1 (-890 *4 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-121)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *7)) (-4 *7 (-848)) (-4 *5 (-910)) (-4 *6 (-794)) (-4 *8 (-956 *5 *6 *7)) (-5 *2 (-424 (-1166 *8))) (-5 *1 (-907 *5 *6 *7 *8)) (-5 *4 (-1166 *8)))) ((*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-1234 *4)) (-5 *2 (-424 (-1166 *5))) (-5 *1 (-908 *4 *5)) (-5 *3 (-1166 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-769))))) 
-(((*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| -12 (-5 *2 (-638 (-1166 *11))) (-5 *3 (-1166 *11)) (-5 *4 (-638 *10)) (-5 *5 (-638 *8)) (-5 *6 (-638 (-769))) (-5 *7 (-1259 (-638 (-1166 *8)))) (-4 *10 (-848)) (-4 *8 (-303)) (-4 *11 (-956 *8 *9 *10)) (-4 *9 (-794)) (-5 *1 (-703 *9 *10 *8 *11))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-4 *5 (-436 *4)) (-5 *2 (-3 (|:| |overq| (-1166 (-413 (-572)))) (|:| |overan| (-1166 (-53))) (|:| -1638 (-121)))) (-5 *1 (-441 *4 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-988 *2)) (-4 *2 (-1054)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1172 (-413 (-572)))) (-5 *2 (-413 (-572))) (-5 *1 (-184))))) 
-(((*1 *1) (-5 *1 (-1066)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1140 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-572))) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-562)) (-4 *8 (-956 *7 *5 *6)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *9) (|:| |radicand| *9))) (-5 *1 (-960 *5 *6 *7 *8 *9)) (-5 *4 (-769)) (-4 *9 (-13 (-368) (-10 -8 (-15 -4487 (*8 $)) (-15 -4492 (*8 $)) (-15 -3972 ($ *8)))))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1170)) (-4 *5 (-613 (-893 (-572)))) (-4 *5 (-887 (-572))) (-4 *5 (-13 (-848) (-1044 (-572)) (-457) (-634 (-572)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-575 *5 *3)) (-4 *3 (-624)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) ((*1 *2 *2 *3 *4 *4) (|partial| -12 (-5 *3 (-1170)) (-5 *4 (-841 *2)) (-4 *2 (-1132)) (-4 *2 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-613 (-893 (-572)))) (-4 *5 (-887 (-572))) (-4 *5 (-13 (-848) (-1044 (-572)) (-457) (-634 (-572)))) (-5 *1 (-575 *5 *2))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-562)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1191 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1117 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1095 *3)) (-4 *3 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1259 *5)) (-4 *5 (-793)) (-5 *2 (-121)) (-5 *1 (-843 *4 *5)) (-14 *4 (-769))))) 
-(((*1 *2 *1 *1 *3) (-12 (-5 *3 (-1 (-121) *5 *5)) (-4 *5 (-13 (-1098) (-39))) (-5 *2 (-121)) (-5 *1 (-1133 *4 *5)) (-4 *4 (-13 (-1098) (-39)))))) 
-(((*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-965 (-217))) (-5 *1 (-115)) (-5 *3 (-217))))) 
-(((*1 *2 *3 *4) (-12 (-5 *2 (-638 (-171 *4))) (-5 *1 (-158 *3 *4)) (-4 *3 (-1234 (-171 (-572)))) (-4 *4 (-13 (-368) (-846))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-638 (-171 *4))) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-638 (-171 *4))) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4)))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 *7)) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) (-769))) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-5 *2 (-638 (-1259 *5))) (-5 *1 (-566 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-978 *5)) (-4 *3 (-237 *11))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-769)) (-5 *1 (-593))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-820 *3)) (-4 *3 (-848))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-312 (-217))) (-5 *1 (-265))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-950 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-369 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-572)) (-4 *1 (-671 *5 *4)) (-4 *5 (-1204)) (-4 *4 (-1204)) (-5 *2 |SortedExponentVector|)))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-923)) (-5 *1 (-1039 *2)) (-4 *2 (-13 (-1098) (-10 -8 (-15 * ($ $ $)))))))) 
-(((*1 *2 *2 *1) (-12 (-5 *2 (-1281 *3 *4)) (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2) (|partial| -12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-820 *3)) (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *5 *6)) (-4 *6 (-613 (-1170))) (-4 *4 (-368)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1159 (-638 (-959 *4)) (-638 (-290 (-959 *4))))) (-5 *1 (-518 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1243 *3 *4 *5)) (-5 *1 (-316 *3 *4 *5)) (-4 *3 (-13 (-368) (-848))) (-14 *4 (-1170)) (-14 *5 *3))) ((*1 *2 *1) (-12 (-4 *1 (-410)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-424 *3)) (-4 *3 (-562)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) ((*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-709 *3 *2 *4)) (-4 *3 (-848)) (-14 *4 (-1 (-121) (-2 (|:| -1763 *3) (|:| -3751 *2)) (-2 (|:| -1763 *3) (|:| -3751 *2))))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *3 (-368)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-533 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-562)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-4 *7 (-1000 *4)) (-4 *2 (-683 *7 *8 *9)) (-5 *1 (-534 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-683 *4 *5 *6)) (-4 *8 (-379 *7)) (-4 *9 (-379 *7)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-368)))) ((*1 *2 *2) (|partial| -12 (-4 *3 (-368)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-684 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) ((*1 *1 *1) (|partial| -12 (-5 *1 (-685 *2)) (-4 *2 (-368)) (-4 *2 (-1054)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-1119 *2 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-232 *2 *3)) (-4 *5 (-232 *2 *3)) (-4 *3 (-368)))) ((*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-1176 *3))))) 
-(((*1 *1 *1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1150 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-303)) (-5 *1 (-918 *3 *4 *5 *2)) (-4 *2 (-956 *5 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1166 *6)) (-4 *6 (-956 *5 *3 *4)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-303)) (-5 *1 (-918 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *6 *4 *5)) (-5 *1 (-918 *4 *5 *6 *2)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1264)) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *7 (-956 *4 *5 *6))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-562)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-1195 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(((*1 *1) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190)))))) 
-(((*1 *2) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *3 *4 *4 *5) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-638 *3)) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-574 *6 *3 *7)) (-4 *7 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-638 (-2 (|:| |totdeg| (-769)) (|:| -1805 *3)))) (-5 *4 (-769)) (-4 *3 (-956 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-454 *5 *6 *7 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1007 *3))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1) (-5 *1 (-143)))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-454 *3 *4 *5 *2)) (-4 *2 (-956 *3 *4 *5))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1264)) (-5 *1 (-207 *4)) (-4 *4 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 (*2 $)) (-15 -3735 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-207 *3)) (-4 *3 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 (*2 $)) (-15 -3735 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-515))))) 
-(((*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-638 *11)) (|:| |todo| (-638 (-2 (|:| |val| *3) (|:| -1337 *11)))))) (-5 *6 (-769)) (-5 *2 (-638 (-2 (|:| |val| (-638 *10)) (|:| -1337 *11)))) (-5 *3 (-638 *10)) (-5 *4 (-638 *11)) (-4 *10 (-1068 *7 *8 *9)) (-4 *11 (-1073 *7 *8 *9 *10)) (-4 *7 (-457)) (-4 *8 (-794)) (-4 *9 (-848)) (-5 *1 (-1071 *7 *8 *9 *10 *11)))) ((*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-638 *11)) (|:| |todo| (-638 (-2 (|:| |val| *3) (|:| -1337 *11)))))) (-5 *6 (-769)) (-5 *2 (-638 (-2 (|:| |val| (-638 *10)) (|:| -1337 *11)))) (-5 *3 (-638 *10)) (-5 *4 (-638 *11)) (-4 *10 (-1068 *7 *8 *9)) (-4 *11 (-1107 *7 *8 *9 *10)) (-4 *7 (-457)) (-4 *8 (-794)) (-4 *9 (-848)) (-5 *1 (-1138 *7 *8 *9 *10 *11))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1166 *1)) (-5 *3 (-1170)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-959 *1)) (-4 *1 (-27)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-848) (-562))))) ((*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-848) (-562))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1166 *2)) (-5 *4 (-1170)) (-4 *2 (-436 *5)) (-5 *1 (-36 *5 *2)) (-4 *5 (-13 (-848) (-562))))) ((*1 *1 *2 *3) (|partial| -12 (-5 *2 (-1166 *1)) (-5 *3 (-923)) (-4 *1 (-1019)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-1166 *1)) (-5 *3 (-923)) (-5 *4 (-856)) (-4 *1 (-1019)))) ((*1 *1 *2 *3) (|partial| -12 (-5 *3 (-923)) (-4 *4 (-13 (-846) (-368))) (-4 *1 (-1070 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *1) (-5 *1 (-143)))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-413 *2)) (-4 *2 (-1234 *5)) (-5 *1 (-808 *5 *2 *3 *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-650 *2)) (-4 *6 (-650 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-413 *2))) (-4 *2 (-1234 *5)) (-5 *1 (-808 *5 *2 *3 *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-650 *2)) (-4 *6 (-650 (-413 *2)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) ((*1 *2 *3) (-12 (-5 *2 (-1166 (-413 (-572)))) (-5 *1 (-949)) (-5 *3 (-572))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-126 *3)) (-14 *3 *2))) ((*1 *1 *1) (-12 (-5 *1 (-126 *2)) (-14 *2 (-572)))) ((*1 *1 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-871 *3)) (-14 *3 *2))) ((*1 *1 *1) (-12 (-5 *1 (-871 *2)) (-14 *2 (-572)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-14 *3 *2) (-5 *1 (-872 *3 *4)) (-4 *4 (-869 *3)))) ((*1 *1 *1) (-12 (-14 *2 (-572)) (-5 *1 (-872 *2 *3)) (-4 *3 (-869 *2)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-1220 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1249 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-1220 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-1249 *2))))) 
-(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-1 (-217) (-217) (-217) (-217))) (-5 *2 (-1 (-950 (-217)) (-217) (-217))) (-5 *1 (-692))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-638 *6))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 *4)))) (-4 *3 (-1098)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-642 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-2 (|:| -2371 (-638 *6)) (|:| -1428 (-638 *6))))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 *6)) (-4 *5 (-1098)) (-4 *6 (-1204)) (-5 *2 (-1 *6 *5)) (-5 *1 (-635 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 *2)) (-4 *5 (-1098)) (-4 *2 (-1204)) (-5 *1 (-635 *5 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *6)) (-5 *4 (-638 *5)) (-4 *6 (-1098)) (-4 *5 (-1204)) (-5 *2 (-1 *5 *6)) (-5 *1 (-635 *6 *5)))) ((*1 *2 *3 *4 *5 *2) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 *2)) (-4 *5 (-1098)) (-4 *2 (-1204)) (-5 *1 (-635 *5 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-1 *6 *5)) (-5 *3 (-638 *5)) (-5 *4 (-638 *6)) (-4 *5 (-1098)) (-4 *6 (-1204)) (-5 *1 (-635 *5 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 *2)) (-5 *6 (-1 *2 *5)) (-4 *5 (-1098)) (-4 *2 (-1204)) (-5 *1 (-635 *5 *2)))) ((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1137)) (-5 *3 (-148)) (-5 *2 (-769))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1186))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-5 *2 (-121)) (-5 *1 (-235 *4)) (-4 *4 (-1054))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-769)) (-5 *1 (-590 *2)) (-4 *2 (-554)))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| -4393 *3) (|:| -3751 (-769)))) (-5 *1 (-590 *3)) (-4 *3 (-554))))) 
-(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-368)) (-5 *1 (-897 *2 *3)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-457)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-307)) (-5 *1 (-830))))) 
-(((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -3444 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-413 *7)) (|:| |a0| *6)) (-2 (|:| -3444 (-413 *7)) (|:| |coeff| (-413 *7))) "failed")) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7))))) 
-(((*1 *2 *3 *4) (-12 (-4 *6 (-562)) (-4 *2 (-956 *3 *5 *4)) (-5 *1 (-728 *5 *4 *6 *2)) (-5 *3 (-413 (-959 *6))) (-4 *5 (-794)) (-4 *4 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)))))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-769))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) *4)) (-4 *9 (-978 *5)) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-4 *3 (-237 *11)) (-4 *12 (-540 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-638 *7)) (-5 *1 (-471 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-4 *13 (-260 *12)))) ((*1 *2 *3 *4 *5 *2) (-12 (-5 *2 (-638 *5)) (-4 *5 (-956 *6 *8 (-858 *7))) (-4 *8 (-232 (-4032 *7) *4)) (-5 *4 (-769)) (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *10 (-645 *6)) (-4 *11 (-926 *6 *10)) (-5 *1 (-566 *6 *7 *5 *8 *9 *10 *11 *3)) (-4 *9 (-978 *6)) (-4 *3 (-237 *11)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-238 (-928 *5))) (-5 *4 (-769)) (-4 *5 (-353)) (-5 *2 (-638 (-244 *6 *5))) (-5 *1 (-873 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-238 (-927 *5))) (-5 *4 (-769)) (-4 *5 (-368)) (-5 *2 (-638 (-244 *6 *5))) (-5 *1 (-874 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-979))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-366 (-123))) (-4 *2 (-1054)) (-5 *1 (-710 *2 *4)) (-4 *4 (-641 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-366 (-123))) (-5 *1 (-835 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-3 "left" "center" "right" "vertical" "horizontal"))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-1150 *3)) (-4 *3 (-1098)) (-4 *3 (-1204))))) 
-(((*1 *1) (-5 *1 (-143)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-769))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1243 *3 *4 *5)) (-4 *3 (-13 (-368) (-848))) (-14 *4 (-1170)) (-14 *5 *3) (-5 *1 (-316 *3 *4 *5)))) ((*1 *2 *3) (-12 (-5 *2 (-1 (-385))) (-5 *1 (-1046)) (-5 *3 (-385))))) 
-(((*1 *1 *2 *2) (-12 (-5 *1 (-879 *2)) (-4 *2 (-1204)))) ((*1 *1 *2 *2 *2) (-12 (-5 *1 (-881 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-950 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-1085 *4)))) (-5 *2 (-121)) (-5 *1 (-1085 *4)) (-4 *4 (-13 (-848) (-562))))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 (-1085 *4))) (-5 *2 (-121)) (-5 *1 (-1085 *4)) (-4 *4 (-13 (-848) (-562))))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-685 *3))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-13 (-1098) (-39))) (-5 *1 (-1133 *3 *2)) (-4 *3 (-13 (-1098) (-39)))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *5 (-611 *4)) (-5 *6 (-1170)) (-4 *4 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-574 *7 *4 *3)) (-4 *3 (-650 *4)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-2 (|:| |num| (-1259 *4)) (|:| |den| *4)))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-322 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-138)) (-4 *3 (-793))))) 
-(((*1 *1) (-5 *1 (-824)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-326 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)) (-4 *2 (-457)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1234 (-572))) (-5 *2 (-638 (-572))) (-5 *1 (-500 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-457)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *3 (-457))))) 
-(((*1 *2 *3 *4 *3 *4 *3 *5 *5) (-12 (-5 *3 (-1116)) (-5 *5 (-217)) (-5 *2 (-638 (-965 *5))) (-5 *1 (-115)) (-5 *4 (-965 *5))))) 
-(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1170)) (-4 *5 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-563 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-385)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-258))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-837)) (-5 *3 (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (-5 *2 (-1042)))) ((*1 *2 *3) (-12 (-4 *1 (-837)) (-5 *3 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *2 (-1042))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *2) (|partial| -12 (-5 *2 (-923)) (-5 *1 (-1099 *3 *4)) (-14 *3 *2) (-14 *4 *2)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-562)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-638 *7)) (|:| |badPols| (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7))))) 
-(((*1 *2 *2 *1) (-12 (-5 *2 (-638 *6)) (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1092 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-121)) (-5 *1 (-295 *4 *5)) (-14 *4 *3) (-14 *5 *3))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1092 (-841 (-217)))) (-5 *3 (-217)) (-5 *2 (-121)) (-5 *1 (-301)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-130))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *5)) (-4 *5 (-634 *4)) (-4 *4 (-562)) (-5 *2 (-121)) (-5 *1 (-633 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-757))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-916 *3)) (-4 *3 (-303))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-1044 (-413 *2)))) (-5 *2 (-572)) (-5 *1 (-124 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1 (-217) (-217) (-217) (-217))) (-5 *1 (-258)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-217) (-217) (-217))) (-5 *1 (-258)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *1 (-258))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)) (-5 *3 (-217))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *3 *3) (-12 (-4 *3 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *3)) (-5 *1 (-1124 *4 *3)) (-4 *4 (-1234 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 *7)) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) (-769))) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-5 *2 (-638 (-1259 *5))) (-5 *1 (-566 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-978 *5)) (-4 *3 (-237 *11))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| |outval| *4) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 *4)))))) (-5 *1 (-779 *4)) (-4 *4 (-13 (-368) (-846)))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3069 (-783 *3)) (|:| |coef1| (-783 *3)) (|:| |coef2| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -3069 *1) (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-4 *3 (-562)) (-5 *2 (-1166 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -1862 *6) (|:| |sol?| (-121))) (-572) *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-413 *7)) (|:| |a0| *6)) (-2 (|:| -3444 (-413 *7)) (|:| |coeff| (-413 *7))) "failed")) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 (-1259 (-572)))) (-5 *1 (-475))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-1170)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-469))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-959 (-572))) (-5 *2 (-330)) (-5 *1 (-332))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-638 *1)) (-4 *1 (-388 *3 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-731 *3 *4))) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) ((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *2 (-638 *3)) (-5 *1 (-914 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) ((*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-956 *3 *4 *5))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *3 (-638 (-875))) (-5 *1 (-477))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-3 (-1 (-217) (-217) (-217) (-217)) "undefined")) (-5 *5 (-1092 (-217))) (-5 *6 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-692)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-217))) (-5 *5 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-692)))) ((*1 *2 *2 *3 *4 *4 *5) (-12 (-5 *2 (-1129 (-217))) (-5 *3 (-1 (-950 (-217)) (-217) (-217))) (-5 *4 (-1092 (-217))) (-5 *5 (-638 (-258))) (-5 *1 (-692))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-562)) (-5 *1 (-977 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *5)) (-4 *5 (-174)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-540 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *10)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-260 *11))))) 
-(((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *2) (-12 (-5 *2 (-769)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1369 (-685 (-413 (-959 *4)))) (|:| |vec| (-638 (-413 (-959 *4)))) (|:| -2667 (-769)) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572))))) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-2 (|:| |partsol| (-1259 (-413 (-959 *4)))) (|:| -2237 (-638 (-1259 (-413 (-959 *4))))))) (-5 *1 (-930 *4 *5 *6 *7)) (-4 *7 (-956 *4 *6 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-37 *3))))) 
-(((*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) ((*1 *2) (-12 (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-873 *3 *4 *5)) (-4 (-863 *3) (-374)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2) (-12 (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1254 (-572) -3512)) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-563 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4)))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-457)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *3) (-12 (-4 *3 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *3)) (-5 *1 (-1124 *4 *3)) (-4 *4 (-1234 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-685 (-413 *4)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *5 *4)) (-5 *1 (-679 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *1 *1 *2) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-638 (-685 (-572)))) (-5 *1 (-1108))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-353)) (-5 *2 (-2 (|:| |cont| *5) (|:| -4547 (-638 (-2 (|:| |irr| *3) (|:| -3341 (-572))))))) (-5 *1 (-209 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-374)) (-5 *2 (-923)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-353)) (-5 *2 (-923)) (-5 *1 (-536 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-856))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 *3 *4)) (-5 *1 (-678 *4 *3)) (-4 *4 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-312 *3)) (-4 *3 (-13 (-1054) (-848))) (-5 *1 (-215 *3 *4)) (-14 *4 (-638 (-1170)))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-322 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-138)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-366 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-392 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-642 *3 *4 *5)) (-4 *4 (-23)) (-14 *5 *4)))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-572)) (-4 *4 (-1054)) (-5 *1 (-1154 *4)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-1170))))) 
-(((*1 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-374)) (-4 *2 (-368))))) 
-(((*1 *1 *1) (-5 *1 (-1066)))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-906 (-572))) (-5 *4 (-572)) (-5 *2 (-685 *4)) (-5 *1 (-1035 *5)) (-4 *5 (-1054)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-685 (-572))) (-5 *1 (-1035 *4)) (-4 *4 (-1054)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-906 (-572)))) (-5 *4 (-572)) (-5 *2 (-638 (-685 *4))) (-5 *1 (-1035 *5)) (-4 *5 (-1054)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-572)))) (-5 *2 (-638 (-685 (-572)))) (-5 *1 (-1035 *4)) (-4 *4 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 (-1166 (-1166 *4)))) (-5 *1 (-1203 *4)) (-5 *3 (-1166 (-1166 *4)))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *2)) (-5 *4 (-769)) (-4 *2 (-1098)) (-5 *1 (-674 *2))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1122 *4 *3 *5))) (-4 *4 (-43 (-413 (-572)))) (-4 *4 (-1054)) (-4 *3 (-848)) (-5 *1 (-1122 *4 *3 *5)) (-4 *5 (-956 *4 (-538 *3) *3)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1199 *4))) (-5 *3 (-1170)) (-5 *1 (-1199 *4)) (-4 *4 (-43 (-413 (-572)))) (-4 *4 (-1054))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-2 (|:| -4200 (-572)) (|:| -4547 (-638 *3)))) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-353)) (-5 *3 (-572)) (-5 *2 (-1178 (-923) (-769)))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-1170)) (-5 *1 (-545)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-700 *3)) (-4 *3 (-613 (-545))))) ((*1 *2 *3 *2 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-700 *3)) (-4 *3 (-613 (-545))))) ((*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-700 *3)) (-4 *3 (-613 (-545))))) ((*1 *2 *3 *2 *4) (-12 (-5 *4 (-638 (-1170))) (-5 *2 (-1170)) (-5 *1 (-700 *3)) (-4 *3 (-613 (-545)))))) 
-(((*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-611 *1)) (-4 *1 (-298))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *2 *2)) (-4 *5 (-368)) (-4 *6 (-1234 (-413 *2))) (-4 *2 (-1234 *5)) (-5 *1 (-208 *5 *2 *6 *3)) (-4 *3 (-342 *5 *2 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-5 *2 (-965 (-1116))) (-5 *1 (-350 *4))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-769)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-794)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-457)) (-4 *5 (-848)) (-5 *1 (-454 *3 *4 *5 *6))))) 
-(((*1 *1 *1 *1) (-4 *1 (-147))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554)))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *2 *3 *4) (-12 (-5 *4 |RationalNumber|) (-5 *2 (-1 (-572))) (-5 *1 (-1052)) (-5 *3 (-572))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1098)) (-4 *4 (-1204)) (-5 *2 (-121)) (-5 *1 (-1150 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-830)) (-5 *3 (-1152))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2 *3) (-12 (-5 *3 (-979)) (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-959 *3))) (-4 *3 (-457)) (-5 *1 (-365 *3 *4)) (-14 *4 (-638 (-1170))))) ((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-455 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-1152)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-455 *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-1152)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-455 *4 *5 *6 *7)))) ((*1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-956 *3 *5 *6)) (-4 *3 (-368)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-564 *3 *4 *5 *6 *7)) (-14 *4 (-638 (-1170))))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-781 *3 (-858 *4)))) (-4 *3 (-457)) (-14 *4 (-638 (-1170))) (-5 *1 (-623 *3 *4))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-1259 *6)) (-5 *1 (-336 *3 *4 *5 *6)) (-4 *6 (-342 *3 *4 *5))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *1 *2 *2 *2 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (-5 *1 (-186))))) 
-(((*1 *1 *1) (-4 *1 (-1063)))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-1 *4 (-572) (-572))) (-4 *4 (-1054)) (-4 *1 (-683 *4 *5 *6)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-856)))) (-5 *1 (-856)))) ((*1 *2 *1) (-12 (-5 *2 (-1135 *3 *4)) (-5 *1 (-1001 *3 *4)) (-14 *3 (-923)) (-4 *4 (-368)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-638 *5))) (-4 *5 (-1054)) (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-145)))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-146)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-218)))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-220)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1205)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1207)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1209))))) 
-(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-312 *4)) (-4 *4 (-13 (-829) (-848) (-1054))) (-5 *2 (-1152)) (-5 *1 (-827 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-312 *5)) (-5 *4 (-121)) (-4 *5 (-13 (-829) (-848) (-1054))) (-5 *2 (-1152)) (-5 *1 (-827 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-823)) (-5 *4 (-312 *5)) (-4 *5 (-13 (-829) (-848) (-1054))) (-5 *2 (-1264)) (-5 *1 (-827 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-823)) (-5 *4 (-312 *6)) (-5 *5 (-121)) (-4 *6 (-13 (-829) (-848) (-1054))) (-5 *2 (-1264)) (-5 *1 (-827 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-829)) (-5 *2 (-1152)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-829)) (-5 *3 (-121)) (-5 *2 (-1152)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-829)) (-5 *3 (-823)) (-5 *2 (-1264)))) ((*1 *2 *3 *1 *4) (-12 (-4 *1 (-829)) (-5 *3 (-823)) (-5 *4 (-121)) (-5 *2 (-1264))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-638 (-572))) (-5 *3 (-121)) (-5 *1 (-1108))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-638 (-173))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-372 *2)) (-4 *2 (-174))))) 
-(((*1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-374)))) ((*1 *2) (-12 (-5 *2 (-1259 (-1099 *3 *4))) (-5 *1 (-1099 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-1128 *4 *2)) (-4 *2 (-13 (-605 (-572) *4) (-10 -7 (-6 -4602) (-6 -4603)))))) ((*1 *2 *2) (-12 (-4 *3 (-848)) (-4 *3 (-1204)) (-5 *1 (-1128 *3 *2)) (-4 *2 (-13 (-605 (-572) *3) (-10 -7 (-6 -4602) (-6 -4603))))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-121)) (-5 *1 (-123))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1166 *1)) (-5 *4 (-1170)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 *1)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-959 *1)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-638 *1)) (-4 *1 (-29 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *2 (-638 *1)) (-4 *1 (-29 *3))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1019)) (-5 *2 (-856))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1152)) (-5 *3 (-772)) (-5 *1 (-123))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-572)) (-4 *4 (-13 (-562) (-151))) (-5 *1 (-546 *4 *2)) (-4 *2 (-1249 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-572)) (-4 *4 (-13 (-368) (-374) (-613 *3))) (-4 *5 (-1234 *4)) (-4 *6 (-720 *4 *5)) (-5 *1 (-550 *4 *5 *6 *2)) (-4 *2 (-1249 *6)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-572)) (-4 *4 (-13 (-368) (-374) (-613 *3))) (-5 *1 (-551 *4 *2)) (-4 *2 (-1249 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-572)) (-4 *4 (-13 (-562) (-151))) (-5 *1 (-1145 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1204)) (-5 *2 (-769)) (-5 *1 (-181 *4 *3)) (-4 *3 (-669 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 *2)) (-14 *6 *2) (-5 *2 (-769)) (-5 *1 (-914 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *4 *4)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-5 *2 (-1 *5 *4)) (-5 *1 (-678 *4 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-647 *4)) (-4 *4 (-342 *5 *6 *7)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-807 *5 *6 *7 *4))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-217) (-217) (-217))) (-5 *4 (-3 (-1 (-217) (-217) (-217) (-217)) "undefined")) (-5 *5 (-1092 (-217))) (-5 *6 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-692))))) 
-(((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-638 *1)) (-4 *1 (-303))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))) (-5 *2 (-638 (-1170))) (-5 *1 (-1076 *3 *4 *5)) (-4 *5 (-13 (-436 *4) (-887 *3) (-613 (-893 *3))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-685 *4)) (-4 *4 (-368)) (-5 *2 (-1166 *4)) (-5 *1 (-539 *4 *5 *6)) (-4 *5 (-368)) (-4 *6 (-13 (-368) (-846)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-298)))) ((*1 *1 *1) (-4 *1 (-298))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) ((*1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *1) (-12 (-4 *4 (-1098)) (-5 *2 (-890 *3 *5)) (-5 *1 (-886 *3 *4 *5)) (-4 *3 (-1098)) (-4 *5 (-662 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-217))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-431 *2)) (-4 *2 (-1098)) (-4 *2 (-374))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *1 (-1154 *3))))) 
-(((*1 *2 *2 *1) (-12 (-5 *2 (-1281 *3 *4)) (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2) (|partial| -12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-820 *3)) (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| *3) (|:| -3341 (-572))))))) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| *3) (|:| -3341 (-572))))))) (-5 *1 (-1223 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1000 *2)) (-4 *2 (-562)) (-5 *1 (-144 *2 *4 *3)) (-4 *3 (-379 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-1000 *2)) (-4 *2 (-562)) (-5 *1 (-516 *2 *4 *5 *3)) (-4 *5 (-379 *2)) (-4 *3 (-379 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-685 *4)) (-4 *4 (-1000 *2)) (-4 *2 (-562)) (-5 *1 (-688 *2 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-1000 *2)) (-4 *2 (-562)) (-5 *1 (-1227 *2 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-327 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-529 *3 *4)) (-4 *3 (-1204)) (-14 *4 *2)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1150 (-1150 *4))) (-5 *2 (-1150 *4)) (-5 *1 (-1154 *4)) (-4 *4 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 *4)))) (-4 *4 (-457)) (-5 *2 (-638 (-3 (-413 (-959 *4)) (-1159 (-1170) (-959 *4))))) (-5 *1 (-288 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-950 *3)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-1131)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-856))) (-5 *2 (-1264)) (-5 *1 (-1131))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1074 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1106 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-303)) (-5 *1 (-695 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-372 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-548 *4 *2 *5 *6)) (-4 *4 (-303)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-769)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *12)) (-5 *1 (-262 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *12)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-5 *2 (-638 (-261 (-541 *3 *4 *5)))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-638 (-261 (-517 *3 *4 *5)))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393))))) 
-(((*1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-121)) (-5 *1 (-265))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-572))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1092 (-572))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6))))) 
-(((*1 *2) (-12 (-4 *2 (-13 (-436 *3) (-1009))) (-5 *1 (-274 *3 *2)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *4 *3 *3) (-12 (-5 *3 (-290 *6)) (-5 *4 (-123)) (-4 *6 (-436 *5)) (-4 *5 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *5 *6)))) ((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-290 *7)) (-5 *4 (-123)) (-5 *5 (-638 *7)) (-4 *7 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *7)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-638 (-290 *7))) (-5 *4 (-638 (-123))) (-5 *5 (-290 *7)) (-4 *7 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 (-290 *8))) (-5 *4 (-638 (-123))) (-5 *5 (-290 *8)) (-5 *6 (-638 *8)) (-4 *8 (-436 *7)) (-4 *7 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *7 *8)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-638 *7)) (-5 *4 (-638 (-123))) (-5 *5 (-290 *7)) (-4 *7 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 (-123))) (-5 *6 (-638 (-290 *8))) (-4 *8 (-436 *7)) (-5 *5 (-290 *8)) (-4 *7 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *7 *8)))) ((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-290 *5)) (-5 *4 (-123)) (-4 *5 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *5)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-123)) (-5 *5 (-290 *3)) (-4 *3 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *3)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-123)) (-5 *5 (-290 *3)) (-4 *3 (-436 *6)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *6 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-290 *3)) (-5 *6 (-638 *3)) (-4 *3 (-436 *7)) (-4 *7 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-57)) (-5 *1 (-313 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-1170)) (-5 *6 (-638 *3)) (-4 *3 (-436 *7)) (-4 *7 (-13 (-848) (-562) (-613 (-545)))) (-4 *2 (-1249 *3)) (-5 *1 (-314 *7 *3 *2 *8)) (-4 *8 (-1249 (-1164 *3))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *6)) (-5 *4 (-638 *5)) (-4 *5 (-368)) (-4 *6 (-1249 (-1164 *5))) (-4 *2 (-1249 *5)) (-5 *1 (-1253 *5 *2 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-572)) (-4 *6 (-645 *5)) (-4 *5 (-368)) (-5 *2 (-685 *5)) (-5 *1 (-639 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1142 *3)) (-4 *3 (-1204)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *1 *1) (-4 *1 (-281))) ((*1 *2 *3) (-12 (-5 *3 (-424 *4)) (-4 *4 (-562)) (-5 *2 (-638 (-2 (|:| -4513 (-769)) (|:| |logand| *4)))) (-5 *1 (-318 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *2 *1) (-12 (-5 *2 (-660 *3 *4)) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-1054) (-713 (-413 (-572))))) (-4 *5 (-848)) (-5 *1 (-1273 *4 *5 *2)) (-4 *2 (-1278 *5 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1277 *3 *4)) (-4 *4 (-713 (-413 (-572)))) (-4 *3 (-848)) (-4 *4 (-174))))) 
-(((*1 *1) (-5 *1 (-121)))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-5 *2 (-572))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-4 *2 (-1098)) (-4 *2 (-848)) (-5 *1 (-122 *2))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1251 *3 *2)) (-4 *2 (-1249 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1166 (-413 (-959 *3)))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (-572))))) (-4 *2 (-562)) (-5 *1 (-424 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| *4) (|:| -3341 (-572))))))) (-4 *4 (-1234 (-572))) (-5 *2 (-424 *4)) (-5 *1 (-447 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-1054)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *1 (-1200 *3)) (-4 *3 (-982))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-694)) (-5 *1 (-301))))) 
-(((*1 *2 *3 *4 *5) (-12 (-4 *6 (-1234 *9)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-303)) (-4 *10 (-956 *9 *7 *8)) (-5 *2 (-2 (|:| |deter| (-638 (-1166 *10))) (|:| |dterm| (-638 (-638 (-2 (|:| -3755 (-769)) (|:| |pcoef| *10))))) (|:| |nfacts| (-638 *6)) (|:| |nlead| (-638 *10)))) (-5 *1 (-777 *6 *7 *8 *9 *10)) (-5 *3 (-1166 *10)) (-5 *4 (-638 *6)) (-5 *5 (-638 *10))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-562)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-684 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-638 (-959 *4))) (-5 *3 (-638 (-1170))) (-4 *4 (-457)) (-5 *1 (-920 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-2 (|:| -1694 *5) (|:| -3821 *5)))) (-5 *1 (-808 *4 *5 *3 *6)) (-4 *3 (-650 *5)) (-4 *6 (-650 (-413 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *4 (-1234 *5)) (-5 *2 (-638 (-2 (|:| -1694 *4) (|:| -3821 *4)))) (-5 *1 (-808 *5 *4 *3 *6)) (-4 *3 (-650 *4)) (-4 *6 (-650 (-413 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-2 (|:| -1694 *5) (|:| -3821 *5)))) (-5 *1 (-808 *4 *5 *6 *3)) (-4 *6 (-650 *5)) (-4 *3 (-650 (-413 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *4 (-1234 *5)) (-5 *2 (-638 (-2 (|:| -1694 *4) (|:| -3821 *4)))) (-5 *1 (-808 *5 *4 *6 *3)) (-4 *6 (-650 *4)) (-4 *3 (-650 (-413 *4)))))) 
-(((*1 *2 *3 *4 *5 *5 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-959 *6)) (-5 *4 (-1170)) (-5 *5 (-841 *7)) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-4 *7 (-13 (-1190) (-29 *6))) (-5 *1 (-216 *6 *7)))) ((*1 *2 *3 *4 *4 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-1166 *6)) (-5 *4 (-841 *6)) (-4 *6 (-13 (-1190) (-29 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-216 *5 *6))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-769)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-214 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-498 *4)) (-4 *4 (-848)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1007 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1140 *4)) (-4 *4 (-1098)))) ((*1 *2 *3 *3) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-1211 *3)) (-4 *3 (-1098)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *3 (-1098)) (-5 *2 (-121)) (-5 *1 (-1211 *3))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-769)) (-4 *4 (-13 (-562) (-151))) (-5 *1 (-1228 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *2 *1 *3) (-12 (-5 *2 (-2 (|:| |k| (-572)) (|:| |c| *4))) (-5 *1 (-780 *4)) (-4 *4 (-368)) (-5 *3 (-572))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-572)) (-5 *3 (-965 (-217))) (-5 *1 (-115))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-329 *3)) (-4 *3 (-368)) (-4 *3 (-374)))) ((*1 *2 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-368)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *3 (-1234 *2)) (-4 *2 (-174)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-923)) (-4 *4 (-353)) (-5 *1 (-536 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *2)) (-5 *4 (-1 (-121) *2 *2)) (-5 *1 (-1211 *2)) (-4 *2 (-1098)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-1098)) (-4 *2 (-848)) (-5 *1 (-1211 *2))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 (-611 *4))) (-4 *4 (-436 *3)) (-4 *3 (-848)) (-5 *1 (-581 *3 *4)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-890 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098))))) 
-(((*1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-1214)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-2 (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (-4 *1 (-342 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-572)) (-5 *2 (-834 (-217))) (-5 *1 (-219)) (-5 *4 (-217))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 (-685 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2 *3 *2 *4 *5) (-12 (-5 *2 (-638 *3)) (-5 *5 (-923)) (-4 *3 (-1234 *4)) (-4 *4 (-303)) (-5 *1 (-466 *4 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-385))) (-5 *1 (-1046))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *4)) (-4 *4 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-679 *4 *5 *6)) (-4 *5 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-638 *2))) (-4 *4 (-368)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-140)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-834 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-841 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-694)))) ((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-694))))) 
-(((*1 *2 *3 *4 *5 *6 *7 *6) (|partial| -12 (-5 *5 (-2 (|:| |contp| *3) (|:| -4547 (-638 (-2 (|:| |irr| *10) (|:| -3341 (-572))))))) (-5 *6 (-638 *3)) (-5 *7 (-638 *8)) (-4 *8 (-848)) (-4 *3 (-303)) (-4 *10 (-956 *3 *9 *8)) (-4 *9 (-794)) (-5 *2 (-2 (|:| |polfac| (-638 *10)) (|:| |correct| *3) (|:| |corrfact| (-638 (-1166 *3))))) (-5 *1 (-621 *8 *9 *3 *10)) (-5 *4 (-638 (-1166 *3)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1135 *3 *4)) (-14 *3 (-923)) (-4 *4 (-368)) (-5 *1 (-1001 *3 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-5 *1 (-1050 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-217))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-214 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-848)) (-5 *2 (-121)) (-5 *1 (-498 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4602)) (-4 *1 (-503 *4)) (-4 *4 (-1204)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-1007 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-1140 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-424 *2)) (-4 *2 (-303)) (-5 *1 (-916 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-151))) (-5 *2 (-57)) (-5 *1 (-917 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-424 (-959 *6))) (-5 *5 (-1170)) (-5 *3 (-959 *6)) (-4 *6 (-13 (-303) (-151))) (-5 *2 (-57)) (-5 *1 (-917 *6))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-638 (-413 *6))) (-5 *3 (-413 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-576 *5 *6))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-298)))) ((*1 *1 *1) (-4 *1 (-298))) ((*1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *1 *1) (|partial| -12 (-5 *1 (-290 *2)) (-4 *2 (-722)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) ((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1173))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-562)) (-4 *4 (-848)) (-5 *1 (-581 *4 *2)) (-4 *2 (-436 *4))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1152)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-258)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-123)) (-5 *1 (-1031 *4 *3)) (-4 *3 (-13 (-436 *4) (-23) (-1044 (-572)) (-1044 (-1170)) (-901 (-1170)) (-162)))))) 
-(((*1 *1 *2 *2 *2 *2) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 *4) (-769)))) (-638 (-469)))) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 (-1170))) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) (-1170) *6)) (|:| C (-1 (-638 *5) (-769)))) (-638 (-469)))) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-14 *9 (-1 *6 *4)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-1 HPSPEC (-638 (-469)))) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 (-1170))))) 
-(((*1 *2) (-12 (-5 *2 (-2 (|:| -2861 (-638 *3)) (|:| -4461 (-638 *3)))) (-5 *1 (-1211 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-368)) (-5 *1 (-282 *3 *2)) (-4 *2 (-1249 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-372 *2)) (-4 *2 (-174))))) 
-(((*1 *1 *1 *2 *1) (-12 (-4 *1 (-135 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-410)) (-4 *3 (-1054)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-410)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-385)) (-5 *2 (-217)) (-5 *1 (-301))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1259 *1)) (-5 *4 (-1 *5 *5)) (-4 *5 (-368)) (-4 *1 (-720 *5 *6)) (-4 *5 (-174)) (-4 *6 (-1234 *5)) (-5 *2 (-685 *5))))) 
-(((*1 *1 *1) (-4 *1 (-624))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-140))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-303)) (-5 *1 (-179 *3))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-396 *3 *4 *5)) (-14 *3 (-769)) (-14 *4 (-769)) (-4 *5 (-174))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457))) (-5 *2 (-2 (|:| |%term| (-2 (|:| |%coef| (-1243 *4 *5 *6)) (|:| |%expon| (-316 *4 *5 *6)) (|:| |%expTerms| (-638 (-2 (|:| |k| (-413 (-572))) (|:| |c| *4)))))) (|:| |%type| (-1152)))) (-5 *1 (-1244 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1190) (-436 *3))) (-14 *5 (-1170)) (-14 *6 *4)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722))))) 
-(((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-638 *10)) (-5 *5 (-121)) (-4 *10 (-1073 *6 *7 *8 *9)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-1068 *6 *7 *8)) (-5 *2 (-638 (-2 (|:| -2352 (-638 *9)) (|:| -1337 *10) (|:| |ineq| (-638 *9))))) (-5 *1 (-996 *6 *7 *8 *9 *10)) (-5 *3 (-638 *9)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-638 *10)) (-5 *5 (-121)) (-4 *10 (-1073 *6 *7 *8 *9)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-1068 *6 *7 *8)) (-5 *2 (-638 (-2 (|:| -2352 (-638 *9)) (|:| -1337 *10) (|:| |ineq| (-638 *9))))) (-5 *1 (-1105 *6 *7 *8 *9 *10)) (-5 *3 (-638 *9))))) 
-(((*1 *2 *3 *2) (|partial| -12 (-5 *2 (-1259 *4)) (-5 *3 (-685 *4)) (-4 *4 (-368)) (-5 *1 (-663 *4)))) ((*1 *2 *3 *2) (|partial| -12 (-4 *4 (-368)) (-4 *5 (-13 (-379 *4) (-10 -7 (-6 -4603)))) (-4 *2 (-13 (-379 *4) (-10 -7 (-6 -4603)))) (-5 *1 (-664 *4 *5 *2 *3)) (-4 *3 (-683 *4 *5 *2)))) ((*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *4 (-638 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-368)) (-5 *1 (-815 *2 *3)) (-4 *3 (-650 *2)))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1259 *6)) (-5 *4 (-1259 (-572))) (-5 *5 (-572)) (-4 *6 (-1098)) (-5 *2 (-1 *6)) (-5 *1 (-1024 *6))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-638 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-985 *5 *6 *7 *8))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-559 *3)) (-4 *3 (-13 (-410) (-1190))) (-5 *2 (-121))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-905 *4)) (-4 *4 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-905 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-562)) (-4 *3 (-956 *7 *5 *6)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *3) (|:| |radicand| (-638 *3)))) (-5 *1 (-960 *5 *6 *7 *3 *8)) (-5 *4 (-769)) (-4 *8 (-13 (-368) (-10 -8 (-15 -4487 (*3 $)) (-15 -4492 (*3 $)) (-15 -3972 ($ *3)))))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875))))) 
-(((*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (-12 (-5 *4 (-572)) (-5 *5 (-1152)) (-5 *6 (-685 (-217))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(((*1 *2 *2 *2 *3 *4) (-12 (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-1054)) (-5 *1 (-851 *5 *2)) (-4 *2 (-850 *5))))) 
-(((*1 *2 *3 *3) (-12 (-4 *2 (-562)) (-4 *2 (-457)) (-5 *1 (-977 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-432 *5 *3)) (-4 *3 (-13 (-1190) (-29 *5)))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-241 *2)) (-4 *2 (-1204))))) 
-(((*1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1173))))) 
-(((*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-965 (-171 (-217)))) (-5 *3 (-1116)) (-5 *4 (-171 (-217))) (-5 *1 (-115))))) 
-(((*1 *2 *3 *4 *4 *5 *4 *3 *6 *3 *4 *7 *8 *9 *10) (-12 (-5 *4 (-572)) (-5 *5 (-1152)) (-5 *6 (-685 (-217))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-394)) (|:| |fp| (-76 PEDERV)))) (-5 *10 (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *2 (-638 (-1170))) (-5 *1 (-265)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 *7)) (-4 *7 (-956 *6 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-5 *2 (-638 *5)) (-5 *1 (-320 *4 *5 *6 *7)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-339 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-393)))) ((*1 *2 *1) (-12 (-4 *1 (-436 *3)) (-4 *3 (-848)) (-5 *2 (-638 (-1170))))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-956 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-638 *5)) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $))))))) ((*1 *2 *1) (-12 (-4 *1 (-981 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-793)) (-4 *5 (-848)) (-5 *2 (-638 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-638 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-5 *2 (-638 (-1170))) (-5 *1 (-1049 *4))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1152)) (-5 *1 (-1186))))) 
-(((*1 *2 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-906 *4)) (-4 *4 (-1098)) (-5 *2 (-638 (-769))) (-5 *1 (-905 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-290 (-959 (-572)))) (-5 *2 (-2 (|:| |varOrder| (-638 (-1170))) (|:| |inhom| (-3 (-638 (-1259 (-769))) "failed")) (|:| |hom| (-638 (-1259 (-769)))))) (-5 *1 (-230))))) 
-(((*1 *2 *3 *2 *3 *2 *3) (-12 (-5 *2 (-965 (-217))) (-5 *3 (-1116)) (-5 *1 (-115))))) 
-(((*1 *2 *3 *3 *4 *5 *5 *5 *4 *4 *4 *3 *4 *4 *6) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-923))) (-5 *5 (-923)) (-4 *6 (-368)) (-4 *7 (-379 *6)) (-4 *8 (-379 *6)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-673 *6 *7 *8 *3)) (-4 *3 (-683 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-638 (-923))) (-5 *4 (-923)) (-4 *6 (-368)) (-4 *7 (-379 *6)) (-4 *8 (-379 *6)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-673 *6 *7 *8 *3)) (-4 *3 (-683 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-638 (-923))) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-685 *4)) (-5 *3 (-923)) (|has| *4 (-6 (-4604 "*"))) (-4 *4 (-1054)) (-5 *1 (-1035 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-638 (-685 *4))) (-5 *3 (-923)) (|has| *4 (-6 (-4604 "*"))) (-4 *4 (-1054)) (-5 *1 (-1035 *4))))) 
-(((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |ir| (-589 (-413 *6))) (|:| |specpart| (-413 *6)) (|:| |polypart| *6))) (-5 *1 (-582 *5 *6)) (-5 *3 (-413 *6))))) 
-(((*1 *1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *3)) (-4 *3 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-669 *3)) (-4 *3 (-1204)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-572)) (-4 *4 (-1098)) (-5 *1 (-733 *4)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-733 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1134 *3 *4))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-589 *2)) (-4 *2 (-368))))) 
-(((*1 *2 *3 *3 *4 *3 *4 *4 *4 *5 *5 *5 *5 *4 *4 *6 *7) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-89 FCNF)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-90 FCNG)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(((*1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-236))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *4 (-638 (-1170))) (-5 *2 (-685 (-312 (-217)))) (-5 *1 (-199)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *6 (-901 *5)) (-5 *2 (-685 *6)) (-5 *1 (-687 *5 *6 *3 *4)) (-4 *3 (-379 *6)) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4602))))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-933)) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-933)) (-5 *4 (-413 (-572))) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)) (-5 *3 (-638 (-950 (-217)))))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 (-217))))) (|:| |xValues| (-1092 (-217))) (|:| |yValues| (-1092 (-217))))) (-5 *1 (-157)) (-5 *3 (-638 (-638 (-950 (-217))))))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-258)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-258))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-312 *5))) (-5 *1 (-1125 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 *5)))) (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-312 *5)))) (-5 *1 (-1125 *5))))) 
-(((*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL)))) (-5 *2 (-1042)) (-5 *1 (-747)))) ((*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7 *8 *8) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-92 BDYVAL)))) (-5 *8 (-394)) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-312 (-217))) (-5 *1 (-265))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-638 *8))) (-5 *3 (-638 *8)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-121)) (-5 *1 (-930 *5 *6 *7 *8))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1264)) (-5 *1 (-454 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-80 FCN JACOBF JACEPS)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-81 G JACOBG JACGEP)))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1166 (-413 (-959 *3)))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-143)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-148))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-368)) (-5 *1 (-282 *3 *2)) (-4 *2 (-1249 *3))))) 
-(((*1 *2 *3 *3) (-12 (-4 *2 (-562)) (-5 *1 (-977 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-873 *3 *4 *5)) (-4 (-863 *3) (-374)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-436 *2)) (-4 *2 (-848)) (-4 *2 (-562)))) ((*1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) ((*1 *1 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-496 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-1054)) (-5 *2 (-244 *4 *5)) (-5 *1 (-951 *4 *5))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *5 (-1044 (-53))) (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-4 *5 (-436 *4)) (-5 *2 (-424 (-1166 (-53)))) (-5 *1 (-441 *4 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-457)) (-5 *2 (-638 (-2 (|:| |eigval| (-3 (-413 (-959 *4)) (-1159 (-1170) (-959 *4)))) (|:| |geneigvec| (-638 (-685 (-413 (-959 *4)))))))) (-5 *1 (-288 *4)) (-5 *3 (-685 (-413 (-959 *4))))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-232 *3 *4)) (-4 *4 (-1054)) (-4 *4 (-1204)))) ((*1 *1 *2) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-4 *5 (-232 (-4032 *3) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *2) (|:| -3751 *5)) (-2 (|:| -1763 *2) (|:| -3751 *5)))) (-5 *1 (-467 *3 *4 *2 *5 *6 *7)) (-4 *2 (-848)) (-4 *7 (-956 *4 *5 (-858 *3))))) ((*1 *2 *2) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-572)) (-5 *1 (-450 *3)) (-4 *3 (-410)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| -1824 (-123)) (|:| |arg| (-638 (-893 *3))))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-638 (-893 *4))) (-5 *1 (-893 *4)) (-4 *4 (-1098))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3 *3 *4 *3 *4 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-781 *5 (-858 *6)))) (-5 *4 (-121)) (-4 *5 (-457)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-1139 *5 (-538 (-858 *6)) (-858 *6) (-781 *5 (-858 *6))))) (-5 *1 (-623 *5 *6))))) 
-(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-273))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |preimage| (-638 *3)) (|:| |image| (-638 *3)))) (-5 *1 (-906 *3)) (-4 *3 (-1098))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *1 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-126 *4)) (-14 *4 *3) (-5 *3 (-572)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572)))) ((*1 *2 *1 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-871 *4)) (-14 *4 *3) (-5 *3 (-572)))) ((*1 *2 *1 *3) (-12 (-14 *4 *3) (-5 *2 (-413 (-572))) (-5 *1 (-872 *4 *5)) (-5 *3 (-572)) (-4 *5 (-869 *4)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1019)) (-5 *2 (-413 (-572))))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1070 *2 *3)) (-4 *2 (-13 (-846) (-368))) (-4 *3 (-1234 *2)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1236 *2 *3)) (-4 *3 (-793)) (|has| *2 (-15 ** (*2 *2 *3))) (|has| *2 (-15 -3972 (*2 (-1170)))) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-99))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-591 *4)) (-4 *4 (-353))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) ((*1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-1261)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-893 *4)) (-5 *3 (-1 (-121) *5)) (-4 *4 (-1098)) (-4 *5 (-1204)) (-5 *1 (-891 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-893 *4)) (-5 *3 (-638 (-1 (-121) *5))) (-4 *4 (-1098)) (-4 *5 (-1204)) (-5 *1 (-891 *4 *5)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-893 *5)) (-5 *3 (-638 (-1170))) (-5 *4 (-1 (-121) (-638 *6))) (-4 *5 (-1098)) (-4 *6 (-1204)) (-5 *1 (-891 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *5)) (-4 *5 (-1204)) (-4 *4 (-848)) (-5 *1 (-944 *4 *2 *5)) (-4 *2 (-436 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-1 (-121) *5))) (-4 *5 (-1204)) (-4 *4 (-848)) (-5 *1 (-944 *4 *2 *5)) (-4 *2 (-436 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-1 (-121) *5)) (-4 *5 (-1204)) (-5 *2 (-312 (-572))) (-5 *1 (-945 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-638 (-1 (-121) *5))) (-4 *5 (-1204)) (-5 *2 (-312 (-572))) (-5 *1 (-945 *5)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-1 (-121) (-638 *6))) (-4 *6 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-1076 *4 *5 *6))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-562)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-1229 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-1170))) (-5 *2 (-638 (-638 *5))) (-5 *1 (-386 *5)) (-4 *5 (-13 (-846) (-368))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-572)))) (-5 *2 (-638 *4)) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368)))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 (-685 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3069 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-131 *3))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-685 (-572))) (-5 *1 (-1108))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-2 (|:| |zeros| (-1150 (-217))) (|:| |ones| (-1150 (-217))) (|:| |singularities| (-1150 (-217))))) (-5 *1 (-109))))) 
-(((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-232 (-4032 *4) (-769))) (-4 *6 (-978 *3)) (-4 *7 (-645 *3)) (-4 *8 (-926 *3 *7)) (-4 *9 (-237 *8)) (-4 *10 (-540 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-4 *2 (-956 *3 *5 (-858 *4))) (-5 *1 (-471 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2) (-12 (-5 *2 (-244 *4 *3)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-244 *4 *3)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174)))) ((*1 *2 *3 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *3 (-1208)) (-5 *1 (-961))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-217))) (-5 *2 (-217)) (-5 *1 (-115))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-96 *3))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-820 *3)))) ((*1 *2 *1) (-12 (-4 *2 (-844)) (-5 *1 (-1280 *3 *2)) (-4 *3 (-1054))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-638 *6))) (-4 *6 (-956 *3 *5 *4)) (-4 *3 (-13 (-303) (-151))) (-4 *4 (-13 (-848) (-613 (-1170)))) (-4 *5 (-794)) (-5 *1 (-930 *3 *4 *5 *6))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-825))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *2 (-3 (-638 *7) "failed" "Infinite" (-572))) (-5 *1 (-31 *4 *5 *3 *6 *7)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *7 (-978 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *2 (-3 (-638 *7) "failed" "Infinite" (-572))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *7 (-978 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 (-1166 *4))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *8 (-978 *4))))) 
-(((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-685 (-413 *4)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-769)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-248 *4 *3 *5 *6)) (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-264 *3)) (-4 *3 (-848)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-353)) (-5 *2 (-923)))) ((*1 *2 *3) (-12 (-5 *3 (-336 *4 *5 *6 *7)) (-4 *4 (-13 (-374) (-368))) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-4 *7 (-342 *4 *5 *6)) (-5 *2 (-769)) (-5 *1 (-398 *4 *5 *6 *7)))) ((*1 *2 *1) (-12 (-4 *1 (-408)) (-5 *2 (-834 (-923))))) ((*1 *2 *1) (-12 (-4 *1 (-410)) (-5 *2 (-572)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-4 *3 (-562)) (-5 *2 (-572)) (-5 *1 (-619 *3 *4)) (-4 *4 (-1234 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-572)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-769)) (-4 *1 (-736 *4 *3)) (-4 *4 (-1054)) (-4 *3 (-848)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-736 *4 *3)) (-4 *4 (-1054)) (-4 *3 (-848)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-869 *3)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-336 *5 *6 *7 *8)) (-4 *5 (-436 *4)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *8 (-342 *5 *6 *7)) (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-769)) (-5 *1 (-912 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-336 (-413 (-572)) *4 *5 *6)) (-4 *4 (-1234 (-413 (-572)))) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 (-413 (-572)) *4 *5)) (-5 *2 (-769)) (-5 *1 (-913 *4 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-336 *6 *7 *4 *8)) (-5 *5 (-1 *9 *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-4 *4 (-1234 (-413 *7))) (-4 *8 (-342 *6 *7 *4)) (-4 *9 (-13 (-374) (-368))) (-5 *2 (-769)) (-5 *1 (-1025 *6 *7 *4 *8 *9)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1234 *3)) (-4 *3 (-1054)) (-4 *3 (-562)) (-5 *2 (-769)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) ((*1 *2 *1) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-385))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-413 (-959 (-385)))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-312 (-385))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-572))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-413 (-959 (-572)))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-312 (-572))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 *2)) (-14 *4 (-638 *2)) (-4 *5 (-393)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-312 *5)) (-4 *5 (-393)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-413 (-959 (-572))))) (-4 *1 (-390)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-413 (-959 (-385))))) (-4 *1 (-390)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-959 (-572)))) (-4 *1 (-390)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-959 (-385)))) (-4 *1 (-390)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-312 (-572)))) (-4 *1 (-390)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-685 (-312 (-385)))) (-4 *1 (-390)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-413 (-959 (-572)))) (-4 *1 (-402)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-413 (-959 (-385)))) (-4 *1 (-402)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-572))) (-4 *1 (-402)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-385))) (-4 *1 (-402)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-312 (-572))) (-4 *1 (-402)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-312 (-385))) (-4 *1 (-402)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-413 (-959 (-572))))) (-4 *1 (-446)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-413 (-959 (-385))))) (-4 *1 (-446)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-959 (-572)))) (-4 *1 (-446)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-959 (-385)))) (-4 *1 (-446)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-312 (-572)))) (-4 *1 (-446)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1259 (-312 (-385)))) (-4 *1 (-446)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-353)) (-4 *5 (-329 *4)) (-4 *6 (-1234 *5)) (-5 *2 (-1166 (-1166 *4))) (-5 *1 (-775 *4 *5 *6 *3 *7)) (-4 *3 (-1234 *6)) (-14 *7 (-923)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *1 (-984 *3 *4 *5 *6)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1044 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (|partial| -1841 (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-2959 (-4 *3 (-43 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-554))) (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-1000 (-572)))) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))))) ((*1 *1 *2) (|partial| -1841 (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-959 (-413 (-572)))) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2 *3 *2 *3) (-12 (-5 *2 (-443)) (-5 *3 (-1170)) (-5 *1 (-1173)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-443)) (-5 *3 (-1170)) (-5 *1 (-1173)))) ((*1 *2 *3 *2 *4 *1) (-12 (-5 *2 (-443)) (-5 *3 (-638 (-1170))) (-5 *4 (-1170)) (-5 *1 (-1173)))) ((*1 *2 *3 *2 *3 *1) (-12 (-5 *2 (-443)) (-5 *3 (-1170)) (-5 *1 (-1173)))) ((*1 *2 *3 *2 *1) (-12 (-5 *2 (-443)) (-5 *3 (-1170)) (-5 *1 (-1174)))) ((*1 *2 *3 *2 *1) (-12 (-5 *2 (-443)) (-5 *3 (-638 (-1170))) (-5 *1 (-1174))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1085 *2)) (-4 *2 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1166 *5)) (-4 *5 (-457)) (-5 *2 (-638 *6)) (-5 *1 (-547 *5 *6 *4)) (-4 *6 (-368)) (-4 *4 (-13 (-368) (-846))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-959 *5)) (-4 *5 (-457)) (-5 *2 (-638 *6)) (-5 *1 (-547 *5 *6 *4)) (-4 *6 (-368)) (-4 *4 (-13 (-368) (-846)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-916 *2)) (-4 *2 (-303))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3)))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-572)) (-5 *2 (-638 (-1208))) (-5 *1 (-961)) (-5 *3 (-1208))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *6 *3)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-590 *2)) (-4 *2 (-554))))) 
-(((*1 *1 *2 *2) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-353)) (-4 *2 (-1054)) (-5 *1 (-708 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3 *1) (|partial| -12 (-5 *3 (-1 (-121) *2)) (-4 *1 (-155 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-1 *4 (-572))) (-4 *4 (-1054)) (-5 *1 (-1154 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-312 *4)) (-5 *1 (-182 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 (-171 *4)))))) ((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) ((*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-638 (-638 *4))) (-5 *1 (-341 *3 *4 *5 *6)) (-4 *3 (-342 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *3 (-374)) (-5 *2 (-638 (-638 *3))))) ((*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *7)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-5 *2 (-638 (-974 *3))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-638 (-973 *3))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-5 *2 (-638 *8)) (-5 *1 (-970 *5 *6 *3 *7 *8)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-841 (-572))) (-5 *1 (-543)))) ((*1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-151)) (-4 *3 (-303)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-385)))) ((*1 *1 *1 *1) (-4 *1 (-554))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) ((*1 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-769))))) 
-(((*1 *2) (-12 (-5 *2 (-841 (-572))) (-5 *1 (-543)))) ((*1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1257 *3)) (-4 *3 (-1204)) (-4 *3 (-1054)) (-5 *2 (-685 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-618 *4 *2)) (-4 *2 (-13 (-1190) (-966) (-29 *4)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-112)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-210)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-501)))) ((*1 *1 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)) (-4 *2 (-303)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572)))) ((*1 *1 *1) (-4 *1 (-1063)))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-638 *8)) (|:| |towers| (-638 (-1034 *5 *6 *7 *8))))) (-5 *1 (-1034 *5 *6 *7 *8)) (-5 *3 (-638 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-638 *8)) (|:| |towers| (-638 (-1139 *5 *6 *7 *8))))) (-5 *1 (-1139 *5 *6 *7 *8)) (-5 *3 (-638 *8))))) 
-(((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-685 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-264 *2)) (-4 *2 (-848)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-858 *3)) (-14 *3 (-638 *2)))) ((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-997)))) ((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-1090 *3)) (-4 *3 (-1204)))) ((*1 *2 *1) (-12 (-4 *1 (-1236 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-1170)))) ((*1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1255 *3)) (-14 *3 *2)))) 
-(((*1 *2) (-12 (-4 *3 (-1054)) (-5 *2 (-965 (-708 *3 *4))) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3)))) ((*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-1208)) (-5 *3 (-923)) (-5 *4 (-769)) (-5 *5 (-572)) (-5 *1 (-961))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2 *3 *4 *5 *5 *5 *6 *4 *4 *4 *5 *4 *5 *7) (-12 (-5 *3 (-1152)) (-5 *5 (-685 (-217))) (-5 *6 (-217)) (-5 *7 (-685 (-572))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-27) (-436 *4))) (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-4 *7 (-1234 (-413 *6))) (-5 *1 (-557 *4 *5 *6 *7 *2)) (-4 *2 (-342 *5 *6 *7))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1259 *4)) (-4 *4 (-634 (-572))) (-5 *2 (-1259 (-413 (-572)))) (-5 *1 (-1284 *4))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1234 *2)) (-4 *2 (-1214)) (-5 *1 (-152 *2 *4 *3)) (-4 *3 (-1234 (-413 *4)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-232 *5 (-769))) (-5 *1 (-914 *4 *3 *2 *5)) (-4 *3 (-326 *4 *2)) (-14 *5 (-769))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *5 *3 *3 *3 *6 *4 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *6 (-217)) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *1) (-5 *1 (-330)))) 
-(((*1 *2 *3 *4 *5 *4 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *7 *4) (-12 (-5 *3 (-1152)) (-5 *5 (-685 (-217))) (-5 *6 (-217)) (-5 *7 (-685 (-572))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-1208)) (-5 *3 (-572)) (-5 *1 (-961))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-922)) (-5 *2 (-2 (|:| -4513 (-638 *1)) (|:| -2307 *1))) (-5 *3 (-638 *1))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-1152)) (-5 *1 (-1260)))) ((*1 *2 *1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1260)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1260)))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-1152)) (-5 *1 (-1261)))) ((*1 *2 *1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1261)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *4 *5 *5 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *2 (-638 (-965 (-217)))) (-5 *1 (-115)) (-5 *4 (-965 (-217)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-959 (-572)))) (-5 *1 (-443)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-685 (-217))) (-5 *2 (-1102)) (-5 *1 (-757)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-685 (-572))) (-5 *2 (-1102)) (-5 *1 (-757))))) 
-(((*1 *1 *1) (-5 *1 (-1066)))) 
-(((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-385))) (-5 *1 (-1046))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1013)))) ((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1013))))) 
-(((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-769)) (-5 *1 (-740 *4 *3)) (-14 *4 (-1170)) (-4 *3 (-1054)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-769)) (-5 *1 (-783 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *1 (-971 *3 *2)) (-4 *2 (-138)) (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *2 (-793)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1166 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-979)) (-4 *2 (-138)) (-5 *1 (-1172 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1231 *4 *3)) (-14 *4 (-1170)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-1 (-589 *3) *3 (-1170))) (-5 *6 (-1 (-3 (-2 (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (-1170))) (-4 *3 (-281)) (-4 *3 (-624)) (-4 *3 (-1044 *4)) (-4 *3 (-436 *7)) (-5 *4 (-1170)) (-4 *7 (-613 (-893 (-572)))) (-4 *7 (-457)) (-4 *7 (-887 (-572))) (-4 *7 (-848)) (-5 *2 (-589 *3)) (-5 *1 (-581 *7 *3))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| -2071 (-424 *3)) (|:| |special| (-424 *3)))) (-5 *1 (-723 *5 *3))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-148))))) 
-(((*1 *2 *3 *3 *4 *4 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-4 *1 (-671 *2 *3)) (-4 *2 (-1204)) (-4 *3 (-1204))))) 
-(((*1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 *4)) (-5 *1 (-1134 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39)))))) 
-(((*1 *2 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-62 *2 *3 *4)) (-4 *2 (-1204)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) ((*1 *1 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-605 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *4)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-5 *2 (-1 *5)) (-5 *1 (-678 *4 *5))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174)))) ((*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-854 *2)) (-4 *2 (-174)))) ((*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-805 *4 *2)) (-4 *2 (-13 (-29 *4) (-1190) (-966))))) ((*1 *1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *2 *3) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-1154 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-368)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-533 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-4 *7 (-1000 *4)) (-4 *2 (-683 *7 *8 *9)) (-5 *1 (-534 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-683 *4 *5 *6)) (-4 *8 (-379 *7)) (-4 *9 (-379 *7)))) ((*1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-303)))) ((*1 *2 *2) (-12 (-4 *3 (-303)) (-4 *3 (-174)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-684 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-303)) (-5 *1 (-695 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-1057 *2 *3 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-232 *3 *4)) (-4 *6 (-232 *2 *4)) (-4 *4 (-303))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-121)) (-5 *1 (-123)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-298)) (-5 *3 (-1170)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-298)) (-5 *3 (-123)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-121)) (-5 *1 (-611 *4)) (-4 *4 (-848)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-611 *4)) (-4 *4 (-848)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-5 *2 (-121)) (-5 *1 (-888 *5 *3 *4)) (-4 *3 (-887 *5)) (-4 *4 (-613 (-893 *5))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-4 *6 (-887 *5)) (-4 *5 (-1098)) (-5 *2 (-121)) (-5 *1 (-888 *5 *6 *4)) (-4 *4 (-613 (-893 *5)))))) 
-(((*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)) (-4 *2 (-436 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-162)) (-5 *2 (-1170)))) ((*1 *1 *1) (-4 *1 (-162)))) 
-(((*1 *2 *3 *3 *2) (|partial| -12 (-5 *2 (-769)) (-4 *3 (-13 (-722) (-374) (-10 -7 (-15 ** (*3 *3 (-572)))))) (-5 *1 (-243 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353)))) ((*1 *1) (-4 *1 (-374))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 *4)) (-5 *1 (-536 *4)) (-4 *4 (-353)))) ((*1 *1 *1) (-4 *1 (-554))) ((*1 *1) (-4 *1 (-554))) ((*1 *1 *1) (-5 *1 (-572))) ((*1 *1 *1) (-5 *1 (-769))) ((*1 *2 *1) (-12 (-5 *2 (-906 *3)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-906 *4)) (-5 *1 (-905 *4)) (-4 *4 (-1098)))) ((*1 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-554)) (-4 *2 (-562))))) 
-(((*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *1 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-37 *2)) (-4 *2 (-368)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1204)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "right") (|has| *1 (-6 -4603)) (-4 *1 (-128 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "left") (|has| *1 (-6 -4603)) (-4 *1 (-128 *3)) (-4 *3 (-1204)))) ((*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-285 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-57)) (-5 *3 (-1170)) (-5 *1 (-627)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 (-1225 (-572))) (|has| *1 (-6 -4603)) (-4 *1 (-644 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-638 (-572))) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-978 *2)) (-4 *2 (-368)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "value") (|has| *1 (-6 -4603)) (-4 *1 (-1017 *2)) (-4 *2 (-1204)))) ((*1 *2 *1 *2) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204)))) ((*1 *2 *1 *3 *2) (-12 (-4 *1 (-1181 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "last") (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "rest") (|has| *1 (-6 -4603)) (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "first") (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1166 (-572))) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1166 (-572))) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) ((*1 *2) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-873 *3 *4 *5)) (-4 (-863 *3) (-374)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 (-572))) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 (-572))) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-432 *5 *3)) (-4 *3 (-13 (-1190) (-29 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-1044 (-572)) (-151))) (-5 *2 (-589 (-413 (-959 *5)))) (-5 *1 (-578 *5)) (-5 *3 (-413 (-959 *5)))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)) (-4 *2 (-848)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-976 *2)) (-4 *2 (-848))))) 
-(((*1 *2 *3 *4 *4 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-37 *2)) (-4 *2 (-368)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1204)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *2 "right") (-4 *1 (-128 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *2 "left") (-4 *1 (-128 *3)) (-4 *3 (-1204)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-638 (-572))) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 (-572)) (-14 *5 (-769)))) ((*1 *2 *1 *3 *3 *3 *3) (-12 (-5 *3 (-572)) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-769)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-572)) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-769)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-769)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *2 (-174)) (-5 *1 (-142 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-769)))) ((*1 *2 *1) (-12 (-4 *2 (-174)) (-5 *1 (-142 *3 *4 *2)) (-14 *3 (-572)) (-14 *4 (-769)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-242 (-1152))) (-5 *1 (-207 *4)) (-4 *4 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ *3)) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-997)) (-5 *1 (-207 *3)) (-4 *3 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))))) ((*1 *2 *1 *3) (-12 (-5 *3 "count") (-5 *2 (-769)) (-5 *1 (-242 *4)) (-4 *4 (-848)))) ((*1 *1 *1 *2) (-12 (-5 *2 "sort") (-5 *1 (-242 *3)) (-4 *3 (-848)))) ((*1 *1 *1 *2) (-12 (-5 *2 "unique") (-5 *1 (-242 *3)) (-4 *3 (-848)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204)))) ((*1 *2 *1 *3 *2) (-12 (-4 *1 (-285 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204)))) ((*1 *2 *1 *2) (-12 (-4 *3 (-174)) (-5 *1 (-286 *3 *2 *4 *5 *6 *7)) (-4 *2 (-1234 *3)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-638 *1)) (-4 *1 (-298)))) ((*1 *1 *2 *1 *1 *1 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) ((*1 *1 *2 *1 *1 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) ((*1 *1 *2 *1 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-298)) (-5 *2 (-123)))) ((*1 *2 *1 *2 *2) (-12 (-4 *1 (-342 *2 *3 *4)) (-4 *2 (-1214)) (-4 *3 (-1234 *2)) (-4 *4 (-1234 (-413 *3))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-423 *2)) (-4 *2 (-174)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1152)) (-5 *1 (-515)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-57)) (-5 *1 (-627)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1225 (-572))) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-769)) (-5 *1 (-670 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-638 (-572))) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-638 (-893 *4))) (-5 *1 (-893 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-904 *2)) (-4 *2 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-906 *4)) (-5 *1 (-905 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-926 *2 *4)) (-4 *4 (-645 *2)) (-4 *2 (-368)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-978 *2)) (-4 *2 (-368)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-234 *4 *2)) (-14 *4 (-923)) (-4 *2 (-368)) (-5 *1 (-1001 *4 *2)))) ((*1 *2 *1 *3) (-12 (-5 *3 "value") (-4 *1 (-1017 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *2 *6 *7)) (-4 *2 (-1054)) (-4 *6 (-232 *5 *2)) (-4 *7 (-232 *4 *2)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1057 *4 *5 *2 *6 *7)) (-4 *6 (-232 *5 *2)) (-4 *7 (-232 *4 *2)) (-4 *2 (-1054)))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-1076 *4 *5 *2)) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-1077 *4 *5 *2)) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)))) ((*1 *1 *1 *1) (-4 *1 (-1137))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-1170)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-413 *1)) (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-413 *1)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)) (-4 *3 (-562)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1236 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) ((*1 *2 *1 *3) (-12 (-5 *3 "last") (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *2 "rest") (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) ((*1 *2 *1 *3) (-12 (-5 *3 "first") (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-923)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-718)) (-5 *2 (-769))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-1259 *1)) (-4 *1 (-864)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-1234 *4)) (-4 *4 (-1054)) (-5 *2 (-1259 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1150 (-572))) (-5 *1 (-1154 *4)) (-4 *4 (-1054)) (-5 *3 (-572))))) 
-(((*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-856))))) 
-(((*1 *2 *1 *3 *3 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-670 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-638 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1262))))) 
-(((*1 *2 *3 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-906 *4)) (-4 *4 (-1098)) (-5 *2 (-638 (-769))) (-5 *1 (-905 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-572))) (-5 *1 (-1052))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-572)) (-4 *5 (-846)) (-4 *5 (-368)) (-5 *2 (-769)) (-5 *1 (-952 *5 *6)) (-4 *6 (-1234 *5))))) 
-(((*1 *2 *3 *4 *4 *4 *3 *3 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-749))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-902 *2)) (-4 *2 (-1098)))) ((*1 *1 *2) (-12 (-5 *1 (-902 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1200 *3)) (-4 *3 (-982))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)) (-4 *2 (-1098)))) ((*1 *1 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1259 *5))) (-5 *4 (-572)) (-5 *2 (-1259 *5)) (-5 *1 (-1036 *5)) (-4 *5 (-368)) (-4 *5 (-374)) (-4 *5 (-1054))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-783 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *1) (-12 (-4 *1 (-474 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) ((*1 *1) (-5 *1 (-545))) ((*1 *1) (-4 *1 (-718))) ((*1 *1) (-4 *1 (-722))) ((*1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) ((*1 *1) (-12 (-5 *1 (-894 *2)) (-4 *2 (-848))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-638 (-545))) (-5 *1 (-545))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) ((*1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-58))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-5 *2 (-1166 *1)) (-4 *1 (-329 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-1166 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *2)) (-4 *3 (-174)) (-4 *3 (-368)) (-4 *2 (-1234 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-353)) (-5 *2 (-1166 *4)) (-5 *1 (-536 *4))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-448 *4 *3 *5)) (-4 *3 (-1234 *4)) (-4 *5 (-13 (-410) (-1044 *4) (-368) (-1190) (-281)))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3)))) ((*1 *2 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-567))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-733 *3)))) ((*1 *1 *2) (-12 (-5 *1 (-733 *2)) (-4 *2 (-1098)))) ((*1 *1) (-12 (-5 *1 (-733 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-361 *3)) (-4 *3 (-353))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-638 (-685 *4))) (-5 *2 (-685 *4)) (-4 *4 (-1054)) (-5 *1 (-1036 *4))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-79 FCN)))) (-5 *2 (-1042)) (-5 *1 (-744))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1166 (-572))) (-5 *4 (-572)) (-5 *2 (-1208)) (-5 *1 (-961))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *8)) (-5 *4 (-685 (-1166 *8))) (-4 *5 (-1054)) (-4 *8 (-1054)) (-4 *6 (-1234 *5)) (-5 *2 (-685 *6)) (-5 *1 (-514 *5 *6 *7 *8)) (-4 *7 (-1234 *6))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-738 *4 *5 *6 *3)) (-4 *3 (-956 *6 *4 *5))))) 
-(((*1 *1 *1 *2 *2) (|partial| -12 (-5 *2 (-923)) (-5 *1 (-1099 *3 *4)) (-14 *3 *2) (-14 *4 *2)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-572)) (-5 *1 (-500 *4)) (-4 *4 (-1234 *2))))) 
-(((*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-121)) (-5 *2 (-1042)) (-5 *1 (-743))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 *6)) (-5 *4 (-1 *6 (-769) (-1259 (-1166 *6)))) (-5 *5 (-638 (-769))) (-4 *6 (-13 (-562) (-457))) (-5 *2 (-685 (-1166 *6))) (-5 *1 (-349 *6 *7)) (-4 *7 (-52 *6 (-769)))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1170))) (-5 *3 (-57)) (-5 *1 (-893 *4)) (-4 *4 (-1098))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-424 *2)) (-4 *2 (-562))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-368)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-764 *3 *4)) (-4 *3 (-704 *4)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-850 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-851 *5 *3)) (-4 *3 (-850 *5))))) 
-(((*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *5 (-121)) (-5 *2 (-1042)) (-5 *1 (-743))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-36 *4 *5)) (-4 *5 (-436 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-160 *4 *5)) (-4 *5 (-436 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-274 *4 *5)) (-4 *5 (-13 (-436 *4) (-1009))))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-297 *4)) (-4 *4 (-298)))) ((*1 *2 *3) (-12 (-4 *1 (-298)) (-5 *3 (-123)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-435 *4 *5)) (-4 *4 (-436 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-437 *4 *5)) (-4 *5 (-436 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-121)) (-5 *1 (-625 *4 *5)) (-4 *5 (-13 (-436 *4) (-1009) (-1190)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-572))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-562)) (-5 *1 (-619 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-1166 (-959 *4)) (-959 *4))) (-5 *1 (-1267 *4)) (-4 *4 (-368))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1152)) (-5 *1 (-301))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-454 *4 *5 *6 *2))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-1098)) (-4 *3 (-901 *6)) (-5 *2 (-685 *3)) (-5 *1 (-687 *6 *3 *7 *4)) (-4 *7 (-379 *3)) (-4 *4 (-13 (-379 *6) (-10 -7 (-6 -4602))))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-890 *4 *5)) (-5 *3 (-890 *4 *6)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-662 *5)) (-5 *1 (-886 *4 *5 *6))))) 
-(((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *3 *3 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-5 *2 (-1166 *3)) (-5 *1 (-1179 *3)) (-4 *3 (-368))))) 
-(((*1 *1) (-5 *1 (-443)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-586))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-5 *2 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-5 *1 (-350 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572)))) ((*1 *2 *1) (-12 (-5 *2 (-1259 (-3 (-477) "undefined"))) (-5 *1 (-1260))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5)) (-4 *5 (-1098)) (-5 *2 (-1 *5 *4)) (-5 *1 (-678 *4 *5)) (-4 *4 (-1098)))) ((*1 *2 *3) (-12 (-4 *4 (-232 *5 (-769))) (-14 *5 (-769)) (-4 *2 (-1054)) (-5 *1 (-914 *2 *3 *4 *5)) (-4 *3 (-326 *2 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-848)) (-5 *1 (-936 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-312 (-572))) (-5 *1 (-937)))) ((*1 *2 *1) (-12 (-4 *1 (-1274 *3 *2)) (-4 *3 (-848)) (-4 *2 (-1054)))) ((*1 *2 *1) (-12 (-4 *2 (-1054)) (-5 *1 (-1280 *2 *3)) (-4 *3 (-844))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-783 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-685 *11)) (-5 *4 (-638 (-413 (-959 *8)))) (-5 *5 (-769)) (-5 *6 (-1152)) (-4 *8 (-13 (-303) (-151))) (-4 *11 (-956 *8 *10 *9)) (-4 *9 (-13 (-848) (-613 (-1170)))) (-4 *10 (-794)) (-5 *2 (-2 (|:| |rgl| (-638 (-2 (|:| |eqzro| (-638 *11)) (|:| |neqzro| (-638 *11)) (|:| |wcond| (-638 (-959 *8))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *8)))) (|:| -2237 (-638 (-1259 (-413 (-959 *8)))))))))) (|:| |rgsz| (-572)))) (-5 *1 (-930 *8 *9 *10 *11)) (-5 *7 (-572))))) 
-(((*1 *2 *3) (-12 (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *2 (-2 (|:| |glbase| (-638 (-244 *4 *5))) (|:| |glval| (-638 (-572))))) (-5 *1 (-626 *4 *5)) (-5 *3 (-638 (-244 *4 *5)))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-58))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856))))) (-5 *1 (-1170))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1166 *1)) (-5 *3 (-1170)) (-4 *1 (-864)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1166 *1)) (-5 *3 (-1170)) (-4 *1 (-864)))) ((*1 *1 *2 *2 *3 *1 *4) (-12 (-5 *2 (-1166 (-866))) (-5 *3 (-923)) (-5 *4 (-1170)) (-5 *1 (-866))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-123)))) ((*1 *2 *1) (-12 (-4 *1 (-369 *2 *3)) (-4 *3 (-1098)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-1152)))) ((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-444 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-1075 *3)) (-14 *3 *2))) ((*1 *1 *1) (-5 *1 (-1170)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) ((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4)))) ((*1 *1 *1) (-4 *1 (-554))) ((*1 *2 *1) (-12 (-5 *2 (-923)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-923)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-820 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-894 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-4 *1 (-1002 *3)) (-4 *3 (-1204)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1202 *3)) (-4 *3 (-1204)))) ((*1 *2 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-1009)) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1234 *4)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-972 *3 *2)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-174)) (-4 *2 (-23)) (-5 *1 (-286 *3 *4 *2 *5 *6 *7)) (-4 *4 (-1234 *3)) (-14 *5 (-1 *4 *4 *2)) (-14 *6 (-1 (-3 *2 "failed") *2 *2)) (-14 *7 (-1 (-3 *4 "failed") *4 *4 *2)))) ((*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-707 *3 *2 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) ((*1 *2) (-12 (-4 *2 (-1234 *3)) (-5 *1 (-708 *3 *2)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-711 *3 *2 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) ((*1 *2) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *2 (-13 (-436 *4) (-887 *3) (-613 (-893 *3)))) (-5 *1 (-1076 *3 *4 *2)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))))) ((*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-1159 *3 *2)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) ((*1 *2 *1) (-12 (-4 *1 (-850 *3)) (-4 *3 (-1054)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1249 *3)) (-4 *3 (-1054)) (-5 *2 (-1150 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-962)) (-5 *2 (-638 (-638 (-950 (-217))))))) ((*1 *2 *1) (-12 (-4 *1 (-982)) (-5 *2 (-638 (-638 (-950 (-217)))))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-121)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)) (-4 *5 (-1054))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *3 (-174)))) ((*1 *2 *3 *3 *2) (-12 (-5 *2 (-572)) (-5 *3 (-1208)) (-5 *1 (-961)))) ((*1 *2 *3 *3) (-12 (-4 *2 (-562)) (-5 *1 (-977 *2 *3)) (-4 *3 (-1234 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-174))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-1259 (-572))) (-5 *3 (-572)) (-5 *1 (-1108)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-1259 (-572))) (-5 *3 (-638 (-572))) (-5 *4 (-572)) (-5 *1 (-1108))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-638 (-959 *4))))) ((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-638 (-959 *4))) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) ((*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-638 (-959 *3))))) ((*1 *2) (-12 (-5 *2 (-638 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) ((*1 *2 *3) (-12 (-5 *3 (-1259 (-458 *4 *5 *6 *7))) (-5 *2 (-638 (-959 *4))) (-5 *1 (-458 *4 *5 *6 *7)) (-4 *4 (-562)) (-4 *4 (-174)) (-14 *5 (-923)) (-14 *6 (-638 (-1170))) (-14 *7 (-1259 (-685 *4)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-848)) (-5 *2 (-2 (|:| |f1| (-638 *4)) (|:| |f2| (-638 (-638 (-638 *4)))) (|:| |f3| (-638 (-638 *4))) (|:| |f4| (-638 (-638 (-638 *4)))))) (-5 *1 (-1176 *4)) (-5 *3 (-638 (-638 (-638 *4))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *2 (-413 (-572))) (-5 *1 (-1026 *4)) (-4 *4 (-1234 (-572)))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-128 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2 *2 *3 *3) (-12 (-5 *2 (-1208)) (-5 *3 (-572)) (-5 *1 (-961))))) 
-(((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-669 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-368)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-37 *4)) (-4 *4 (-368)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-168 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-424 *3)) (-4 *3 (-554)) (-4 *3 (-562)))) ((*1 *2 *1) (-12 (-4 *1 (-554)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-798 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-834 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-841 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-978 *4)) (-4 *4 (-368)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1004 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1015 *3)) (-4 *3 (-1044 (-413 (-572))))))) 
-(((*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-669 *3)) (-4 *3 (-1204)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1064 (-1030 *3) (-1166 (-1030 *3)))) (-5 *1 (-1030 *3)) (-4 *3 (-13 (-846) (-368) (-1028)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-634 (-572))) (-5 *2 (-121)) (-5 *1 (-1284 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-448 *4 *3 *5)) (-4 *3 (-1234 *4)) (-4 *5 (-13 (-410) (-1044 *4) (-368) (-1190) (-281)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-1009)) (-4 *2 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-640 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-605 *4 *3)) (-4 *4 (-1098)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-121))))) 
-(((*1 *1) (-5 *1 (-1264)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-171 *5)) (-4 *5 (-13 (-436 *4) (-1009) (-1190))) (-4 *4 (-13 (-562) (-848))) (-4 *2 (-13 (-436 (-171 *4)) (-1009) (-1190))) (-5 *1 (-601 *4 *5 *2))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-5 *2 (-121)) (-5 *1 (-590 *3)) (-4 *3 (-554))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-3 (-413 (-959 *5)) (-1159 (-1170) (-959 *5)))) (-4 *5 (-457)) (-5 *2 (-638 (-685 (-413 (-959 *5))))) (-5 *1 (-288 *5)) (-5 *4 (-685 (-413 (-959 *5))))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-5 *3 (-572)) (-4 *4 (-353)) (-5 *1 (-536 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1 (-950 (-217)) (-950 (-217)))) (-5 *1 (-258)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-329 *4)) (-4 *4 (-368)) (-5 *2 (-685 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-1259 *3)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-1259 *4)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-1259 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-415 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-415 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-1259 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-423 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-1259 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-685 *5))) (-5 *3 (-685 *5)) (-4 *5 (-368)) (-5 *2 (-1259 *5)) (-5 *1 (-1084 *5))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-638 (-290 *4))) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-353)) (-5 *2 (-769)))) ((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-408)) (-5 *2 (-769))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-21)) (-4 *2 (-1204))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-171 (-217)))) (-5 *1 (-146)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-1259 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-136 *3))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1100 (-1170))) (-5 *1 (-58)) (-5 *3 (-1170))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1100 *3)) (-5 *1 (-906 *3)) (-4 *3 (-374)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1083 *3)) (-4 *3 (-139))))) 
-(((*1 *2 *3 *4 *3 *4 *4 *4 *4) (-12 (-5 *3 (-1208)) (-5 *4 (-572)) (-5 *2 (-1264)) (-5 *1 (-961))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-959 *5)) (-4 *5 (-1054)) (-5 *2 (-244 *4 *5)) (-5 *1 (-951 *4 *5)) (-14 *4 (-638 (-1170)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-1076 *3 *4 *5))) (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))) (-4 *5 (-13 (-436 *4) (-887 *3) (-613 (-893 *3)))) (-5 *1 (-1077 *3 *4 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-757))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-1150 (-217))) (-5 *1 (-186)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-638 (-1170))) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-1150 (-217))) (-5 *1 (-296)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *4 (-638 (-1170))) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-1150 (-217))) (-5 *1 (-296))))) 
-(((*1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 (-638 *5))) (-4 *5 (-1249 *4)) (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-1 (-1150 *4) (-638 (-1150 *4)))) (-5 *1 (-1251 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-558))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-260 *12))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-769)) (-4 *1 (-225 *4)) (-4 *4 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-225 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-227)) (-5 *2 (-769)))) ((*1 *1 *1) (-4 *1 (-227))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-264 *3)) (-4 *3 (-848)))) ((*1 *1 *1) (-12 (-4 *1 (-264 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *4)) (-4 *4 (-1234 *3)))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-368) (-151))) (-5 *1 (-405 *2 *3)) (-4 *3 (-1234 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-483 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *2 *1 *3) (-12 (-4 *2 (-368)) (-4 *2 (-901 *3)) (-5 *1 (-589 *2)) (-5 *3 (-1170)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-589 *2)) (-4 *2 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-856)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *4)) (-5 *3 (-638 (-769))) (-4 *1 (-901 *4)) (-4 *4 (-1098)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-901 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *1 (-901 *3)) (-4 *3 (-1098)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-901 *2)) (-4 *2 (-1098)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1208)) (-5 *3 (-572)) (-5 *1 (-961)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-1208)) (-5 *3 (-769)) (-5 *4 (-572)) (-5 *1 (-961)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1160 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1167 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1168 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 (QUOTE |x|))) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1222 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-685 (-312 (-572))))) (-5 *1 (-1038))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-638 *1)) (-4 *1 (-926 *3 *4))))) 
-(((*1 *2 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1198 *2 *3 *4 *5)) (-4 *2 (-562)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-1068 *2 *3 *4))))) 
-(((*1 *1 *2 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-1076 *4 *5 *2)) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4)))))) ((*1 *1 *2 *2) (-12 (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))) (-5 *1 (-1076 *3 *4 *2)) (-4 *2 (-13 (-436 *4) (-887 *3) (-613 (-893 *3))))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) ((*1 *2 *2) (-12 (-4 *3 (-368)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-673 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-1054)) (-5 *1 (-685 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *4)) (-4 *4 (-1054)) (-4 *1 (-1119 *3 *4 *5 *6)) (-4 *5 (-232 *3 *4)) (-4 *6 (-232 *3 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *1 (-477))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-572)) (-4 *4 (-1054)) (-5 *1 (-1154 *4)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1216 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-1170)) (-14 *5 *3))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-1170))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *4))) (-5 *3 (-1166 *4)) (-4 *4 (-910)) (-5 *1 (-659 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-685 *2)) (-5 *4 (-769)) (-4 *2 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *5 (-1234 *2)) (-5 *1 (-512 *2 *5 *6)) (-4 *6 (-415 *2 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-331 *3)) (-4 *3 (-848))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1170)) (-5 *2 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *1 (-1173))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1234 *6)) (-4 *6 (-13 (-27) (-436 *5))) (-4 *5 (-13 (-848) (-562) (-1044 (-572)))) (-4 *8 (-1234 (-413 *7))) (-5 *2 (-589 *3)) (-5 *1 (-557 *5 *6 *7 *8 *3)) (-4 *3 (-342 *6 *7 *8))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-572)) (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *9 (-645 *6)) (-5 *2 (-638 *9)) (-5 *1 (-658 *6 *7 *4 *8 *3 *9 *10)) (-4 *4 (-956 *6 *8 (-858 *7))) (-4 *3 (-978 *6)) (-4 *10 (-926 *6 *9))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-1054))))) 
-(((*1 *1 *1) (-5 *1 (-53))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-64 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-63 *5 *2)))) ((*1 *2 *3 *1 *2 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1098)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)))) ((*1 *2 *3 *1 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)))) ((*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-2 (|:| -1805 (-1166 *4)) (|:| |deg| (-923)))) (-5 *1 (-213 *4 *5)) (-5 *3 (-1166 *4)) (-4 *5 (-13 (-562) (-848))))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *6 *2)) (-5 *4 (-234 *5 *6)) (-14 *5 (-769)) (-4 *6 (-1204)) (-4 *2 (-1204)) (-5 *1 (-233 *5 *6 *2)))) ((*1 *1 *2 *3) (-12 (-4 *4 (-174)) (-5 *1 (-286 *4 *2 *3 *5 *6 *7)) (-4 *2 (-1234 *4)) (-4 *3 (-23)) (-14 *5 (-1 *2 *2 *3)) (-14 *6 (-1 (-3 *3 "failed") *3 *3)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-312 *2)) (-4 *2 (-562)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-4 *1 (-335 *2 *3 *4 *5)) (-4 *2 (-368)) (-4 *3 (-1234 *2)) (-4 *4 (-1234 (-413 *3))) (-4 *5 (-342 *2 *3 *4)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-377 *5 *4 *2 *6)) (-4 *4 (-379 *5)) (-4 *6 (-379 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1098)) (-4 *2 (-1098)) (-5 *1 (-429 *5 *4 *2 *6)) (-4 *4 (-431 *5)) (-4 *6 (-431 *2)))) ((*1 *1 *1) (-5 *1 (-508))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-638 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-636 *5 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1054)) (-4 *2 (-1054)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-4 *8 (-379 *2)) (-4 *9 (-379 *2)) (-5 *1 (-681 *5 *6 *7 *4 *2 *8 *9 *10)) (-4 *4 (-683 *5 *6 *7)) (-4 *10 (-683 *2 *8 *9)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-707 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-708 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-413 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-368)) (-4 *3 (-174)) (-4 *1 (-720 *3 *4)))) ((*1 *1 *2) (-12 (-4 *3 (-174)) (-4 *1 (-720 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-926 *4 *5)) (-4 *4 (-368)) (-4 *5 (-645 *4)) (-5 *2 (-238 *1)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-965 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-964 *5 *2)))) ((*1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1041 *3 *4 *5 *2 *6)) (-4 *2 (-956 *3 *4 *5)) (-14 *6 (-638 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *7 *2)) (-4 *7 (-1054)) (-4 *2 (-1054)) (-14 *5 (-769)) (-14 *6 (-769)) (-4 *8 (-232 *6 *7)) (-4 *9 (-232 *5 *7)) (-4 *10 (-232 *6 *2)) (-4 *11 (-232 *5 *2)) (-5 *1 (-1059 *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (-4 *4 (-1057 *5 *6 *7 *8 *9)) (-4 *12 (-1057 *5 *6 *2 *10 *11)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1150 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-1148 *5 *2)))) ((*1 *2 *2 *1 *3 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *4 (-1 (-121) *2 *2)) (-4 *1 (-1198 *5 *6 *7 *2)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *2 (-1068 *5 *6 *7)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1259 *5)) (-4 *5 (-1204)) (-4 *2 (-1204)) (-5 *1 (-1258 *5 *2))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1116)) (-5 *2 (-1264)) (-5 *1 (-832))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *2 (-237 *9)) (-4 *10 (-117))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-303)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-611 *6)) (-4 *6 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-1166 (-413 (-1166 *6)))) (-5 *1 (-568 *5 *6 *7)) (-5 *3 (-1166 *6)) (-4 *7 (-1098)))) ((*1 *2 *1) (-12 (-4 *2 (-1234 *3)) (-5 *1 (-708 *3 *2)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-4 *1 (-720 *3 *2)) (-4 *3 (-174)) (-4 *2 (-1234 *3)))) ((*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| -12 (-5 *4 (-1166 *11)) (-5 *6 (-638 *10)) (-5 *7 (-638 (-769))) (-5 *8 (-638 *11)) (-4 *10 (-848)) (-4 *11 (-303)) (-4 *9 (-794)) (-4 *5 (-956 *11 *9 *10)) (-5 *2 (-638 (-1166 *5))) (-5 *1 (-738 *9 *10 *11 *5)) (-5 *3 (-1166 *5)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) ((*1 *2 *1) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) ((*1 *2 *1) (-12 (-4 *2 (-956 *3 *4 *5)) (-5 *1 (-1041 *3 *4 *5 *2 *6)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-14 *6 (-638 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-385)))) ((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-385))))) 
-(((*1 *2 *2 *2 *2 *3) (-12 (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4 *4 *3 *5) (-12 (-5 *4 (-611 *3)) (-5 *5 (-1166 *3)) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-568 *6 *3 *7)) (-4 *7 (-1098)))) ((*1 *2 *3 *4 *4 *4 *3 *5) (-12 (-5 *4 (-611 *3)) (-5 *5 (-413 (-1166 *3))) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-568 *6 *3 *7)) (-4 *7 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-893 *4)) (-4 *4 (-1098)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-891 *4 *5)) (-4 *5 (-1204))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-368)))) ((*1 *2 *1) (-12 (-4 *1 (-978 *2)) (-4 *2 (-368))))) 
-(((*1 *1 *2 *2 *2 *2 *2 *3 *4) (-12 (-5 *2 (-572)) (-5 *3 (-121)) (-5 *4 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *1 (-117))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *3)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *3 (-168 *6)) (-4 (-959 *6) (-887 *5)) (-4 *6 (-13 (-887 *5) (-174))) (-5 *1 (-178 *5 *6 *3)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-890 *4 *1)) (-5 *3 (-893 *4)) (-4 *1 (-887 *4)) (-4 *4 (-1098)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *6)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *6 (-13 (-1098) (-1044 *3))) (-4 *3 (-887 *5)) (-5 *1 (-938 *5 *3 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *3)) (-4 *5 (-1098)) (-4 *3 (-13 (-436 *6) (-613 *4) (-887 *5) (-1044 (-611 $)))) (-5 *4 (-893 *5)) (-4 *6 (-13 (-562) (-848) (-887 *5))) (-5 *1 (-939 *5 *6 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 (-572) *3)) (-5 *4 (-893 (-572))) (-4 *3 (-554)) (-5 *1 (-940 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *6)) (-5 *3 (-611 *6)) (-4 *5 (-1098)) (-4 *6 (-13 (-848) (-1044 (-611 $)) (-613 *4) (-887 *5))) (-5 *4 (-893 *5)) (-5 *1 (-941 *5 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-886 *5 *6 *3)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *6 (-887 *5)) (-4 *3 (-662 *6)) (-5 *1 (-942 *5 *6 *3)))) ((*1 *2 *3 *4 *2 *5) (-12 (-5 *5 (-1 (-890 *6 *3) *8 (-893 *6) (-890 *6 *3))) (-4 *8 (-848)) (-5 *2 (-890 *6 *3)) (-5 *4 (-893 *6)) (-4 *6 (-1098)) (-4 *3 (-13 (-956 *9 *7 *8) (-613 *4))) (-4 *7 (-794)) (-4 *9 (-13 (-1054) (-848) (-887 *6))) (-5 *1 (-943 *6 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *3)) (-4 *5 (-1098)) (-4 *3 (-13 (-956 *8 *6 *7) (-613 *4))) (-5 *4 (-893 *5)) (-4 *7 (-887 *5)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-13 (-1054) (-848) (-887 *5))) (-5 *1 (-943 *5 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 *3)) (-4 *5 (-1098)) (-4 *3 (-1000 *6)) (-4 *6 (-13 (-562) (-887 *5) (-613 *4))) (-5 *4 (-893 *5)) (-5 *1 (-946 *5 *6 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-890 *5 (-1170))) (-5 *3 (-1170)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-5 *1 (-947 *5)))) ((*1 *2 *3 *4 *5 *2 *6) (-12 (-5 *4 (-638 (-893 *7))) (-5 *5 (-1 *9 (-638 *9))) (-5 *6 (-1 (-890 *7 *9) *9 (-893 *7) (-890 *7 *9))) (-4 *7 (-1098)) (-4 *9 (-13 (-1054) (-613 (-893 *7)) (-1044 *8))) (-5 *2 (-890 *7 *9)) (-5 *3 (-638 *9)) (-4 *8 (-13 (-1054) (-848))) (-5 *1 (-948 *7 *8 *9))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (-572))))) (-5 *1 (-424 *3)) (-4 *3 (-562)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-769)) (-4 *3 (-353)) (-4 *5 (-1234 *3)) (-5 *2 (-638 (-1166 *3))) (-5 *1 (-511 *3 *5 *6)) (-4 *6 (-1234 *5))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-227)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-1 *1 (-769))) (-4 *1 (-248 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-1 *1 (-769))) (-4 *1 (-248 *4 *3 *5 *6)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-264 *2)) (-4 *2 (-848))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-2 (|:| |ans| *7) (|:| -1862 *7) (|:| |sol?| (-121))) (-572) *7)) (-5 *6 (-638 (-413 *8))) (-4 *7 (-368)) (-4 *8 (-1234 *7)) (-5 *3 (-413 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-582 *7 *8))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-638 (-638 *4)))) (-5 *2 (-638 (-638 *4))) (-4 *4 (-848)) (-5 *1 (-1176 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-769)) (-5 *1 (-533 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-562)) (-5 *2 (-769)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-769)) (-5 *1 (-684 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-4 *5 (-562)) (-5 *2 (-769))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *9)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-769)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *9)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-769)) (-5 *1 (-1138 *5 *6 *7 *8 *9))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-572))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-513 *2)) (-14 *2 (-572)))) ((*1 *1 *1 *1) (-5 *1 (-1116)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-368)) (-5 *1 (-657 *3))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-1030 *3)) (-4 *3 (-13 (-846) (-368) (-1028))))) ((*1 *2 *3 *1 *2) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2)))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1070 *2 *3)) (-4 *2 (-13 (-846) (-368))) (-4 *3 (-1234 *2))))) 
-(((*1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *2 *1 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-303)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2307 *1))) (-4 *1 (-303))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1272 (-1170) *3)) (-4 *3 (-1054)) (-5 *1 (-1279 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1272 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *1 (-1281 *3 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-932))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-4 *3 (-13 (-27) (-1190) (-436 *6) (-10 -8 (-15 -3972 ($ *7))))) (-4 *7 (-846)) (-4 *8 (-13 (-1236 *3 *7) (-368) (-1190) (-10 -8 (-15 -3139 ($ $)) (-15 -2774 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152)))))) (-5 *1 (-428 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1152)) (-4 *9 (-991 *8)) (-14 *10 (-1170))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *2 *2 *3 *3) (-12 (-5 *3 (-769)) (-4 *4 (-1054)) (-5 *1 (-1230 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-450 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-638 (-611 *6))) (-5 *4 (-1170)) (-5 *2 (-611 *6)) (-4 *6 (-436 *5)) (-4 *5 (-848)) (-5 *1 (-581 *5 *6))))) 
-(((*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1034 *5 *6 *7 *3))) (-5 *1 (-1034 *5 *6 *7 *3)) (-4 *3 (-1068 *5 *6 *7)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-638 *6)) (-4 *1 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1073 *3 *4 *5 *2)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) ((*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1139 *5 *6 *7 *3))) (-5 *1 (-1139 *5 *6 *7 *3)) (-4 *3 (-1068 *5 *6 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 *5)) (-4 *5 (-1234 *3)) (-4 *3 (-303)) (-5 *2 (-121)) (-5 *1 (-461 *3 *5))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-513 *2)) (-14 *2 (-572)))) ((*1 *1 *1) (-5 *1 (-1116)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 *5)) (-5 *4 (-1259 *5)) (-4 *5 (-368)) (-5 *2 (-121)) (-5 *1 (-663 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-5 *2 (-121)) (-5 *1 (-664 *5 *6 *4 *3)) (-4 *3 (-683 *5 *6 *4))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-123)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-123)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-248 *4 *3 *5 *6)) (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-264 *3)) (-4 *3 (-848)) (-5 *2 (-769))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-5 *1 (-657 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1152)) (-5 *1 (-787))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-258))) (-5 *4 (-1170)) (-5 *2 (-121)) (-5 *1 (-258))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-457)))) ((*1 *1 *1 *1) (-4 *1 (-457))) ((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-5 *1 (-500 *2)) (-4 *2 (-1234 (-572))))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-691 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *1 *1) (-5 *1 (-769))) ((*1 *2 *2 *2) (-12 (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-303)) (-5 *1 (-918 *3 *4 *5 *2)) (-4 *2 (-956 *5 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *6 *4 *5)) (-5 *1 (-918 *4 *5 *6 *2)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1166 *6)) (-4 *6 (-956 *5 *3 *4)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-303)) (-5 *1 (-918 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-1166 *7))) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-5 *2 (-1166 *7)) (-5 *1 (-918 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5)))) ((*1 *1 *1 *1) (-5 *1 (-923))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-1208)) (-5 *3 (-572)) (-5 *1 (-961)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-965 (-1208))) (-5 *4 (-572)) (-5 *2 (-1208)) (-5 *1 (-961)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-457)) (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-394)) (-5 *1 (-442)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-394)) (-5 *1 (-442))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-572)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-303)) (-4 *9 (-956 *8 *6 *7)) (-5 *2 (-2 (|:| -1805 (-1166 *9)) (|:| |polval| (-1166 *8)))) (-5 *1 (-738 *6 *7 *8 *9)) (-5 *3 (-1166 *9)) (-5 *4 (-1166 *8))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *12)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-5 *2 (-638 (-261 (-541 *3 *4 *5)))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-638 (-261 (-517 *3 *4 *5)))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-5 *2 (-638 (-2 (|:| -4304 *3) (|:| -4316 *4)))) (-5 *1 (-691 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-312 (-385))) (-5 *2 (-312 (-217))) (-5 *1 (-301))))) 
-(((*1 *1) (-5 *1 (-804)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-96 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-4 *1 (-111 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-214 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-498 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1007 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-1140 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-5 *2 (-685 *4)) (-5 *1 (-815 *4 *5)) (-4 *5 (-650 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-769)) (-4 *5 (-368)) (-5 *2 (-685 *5)) (-5 *1 (-815 *5 *6)) (-4 *6 (-650 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *3 (-848)) (-4 *3 (-1044 (-572))) (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-436 *3)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $)))))))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-199))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098)) (-5 *1 (-676 *5 *6 *2))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-159)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-834 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-841 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-1234 *4)) (-5 *1 (-810 *4 *3 *2 *5)) (-4 *2 (-650 *3)) (-4 *5 (-650 (-413 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-413 *5)) (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *1 (-810 *4 *5 *2 *6)) (-4 *2 (-650 *5)) (-4 *6 (-650 *3))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185))))) 
-(((*1 *1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *2)) (-4 *2 (-956 *3 *4 *5)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-558))))) 
-(((*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-950 (-217))) (-5 *4 (-875)) (-5 *5 (-923)) (-5 *2 (-1264)) (-5 *1 (-477)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-950 (-217))) (-5 *2 (-1264)) (-5 *1 (-477)))) ((*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-638 (-950 (-217)))) (-5 *4 (-875)) (-5 *5 (-923)) (-5 *2 (-1264)) (-5 *1 (-477))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-1054)) (-5 *1 (-449 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-562))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-5 *2 (-638 (-638 (-1166 (-1166 *4))))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-5 *3 (-638 (-1166 (-1166 *4)))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *8 (-978 *4))))) 
-(((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-572)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1204)) (-4 *4 (-379 *2)) (-4 *5 (-379 *2)))) ((*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-285 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-923)) (-5 *1 (-787))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *4 (-368)) (-5 *2 (-638 *1)) (-4 *1 (-37 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-368)) (-5 *2 (-638 *1)) (-4 *1 (-37 *3)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-904 *3)) (-4 *3 (-1098)) (-5 *2 (-1100 *3)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1098)) (-5 *2 (-1100 (-638 *4))) (-5 *1 (-905 *4)) (-5 *3 (-638 *4)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1098)) (-5 *2 (-1100 (-1100 *4))) (-5 *1 (-905 *4)) (-5 *3 (-1100 *4)))) ((*1 *2 *1 *3) (-12 (-5 *2 (-1100 *3)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *4 (-368)) (-5 *2 (-638 *1)) (-4 *1 (-978 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-368)) (-5 *2 (-638 *1)) (-4 *1 (-978 *3))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| |scalar| (-413 (-572))) (|:| |coeff| (-1166 *2)) (|:| |logand| (-1166 *2))))) (-5 *4 (-638 (-2 (|:| |integrand| *2) (|:| |intvar| *2)))) (-4 *2 (-368)) (-5 *1 (-589 *2))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-769))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1166 *4)) (-5 *1 (-536 *4)) (-4 *4 (-353))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-385))) (-5 *1 (-258)))) ((*1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-562)) (-4 *2 (-174)))) ((*1 *2 *1) (-12 (-5 *1 (-424 *2)) (-4 *2 (-562))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3190 *3) (|:| |coef1| (-783 *3)) (|:| |coef2| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-772)) (-5 *1 (-57))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1150 *4)) (-4 *4 (-43 *3)) (-4 *4 (-1054)) (-5 *3 (-413 (-572))) (-5 *1 (-1154 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-856))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *2 (-901 *5)) (-5 *1 (-687 *5 *2 *3 *4)) (-4 *3 (-379 *2)) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4602))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-396 *3 *4 *5)) (-14 *3 (-769)) (-14 *4 (-769)) (-4 *5 (-174))))) 
-(((*1 *1) (-5 *1 (-148))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-1129 (-217))) (-5 *1 (-258))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-217)) (-5 *1 (-301))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-303)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-2 (|:| |Hermite| *3) (|:| |eqMat| *3))) (-5 *1 (-1120 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6))))) 
-(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1170)) (-4 *4 (-1054)) (-4 *4 (-848)) (-5 *2 (-2 (|:| |var| (-611 *1)) (|:| -3751 (-572)))) (-4 *1 (-436 *4)))) ((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-4 *4 (-1054)) (-4 *4 (-848)) (-5 *2 (-2 (|:| |var| (-611 *1)) (|:| -3751 (-572)))) (-4 *1 (-436 *4)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1110)) (-4 *3 (-848)) (-5 *2 (-2 (|:| |var| (-611 *1)) (|:| -3751 (-572)))) (-4 *1 (-436 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-893 *3)) (|:| -3751 (-769)))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-956 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| |var| *5) (|:| -3751 (-769)))))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-2 (|:| |var| *5) (|:| -3751 (-572)))) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $)))))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-37 *3)) (-4 *3 (-368)))) ((*1 *1 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)))) ((*1 *1 *1 *1) (-4 *1 (-482))) ((*1 *1 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) ((*1 *1 *1) (-4 *1 (-864))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-884)))) ((*1 *1 *1) (-12 (-4 *1 (-978 *2)) (-4 *2 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-978 *3)) (-4 *3 (-368)))) ((*1 *1 *1) (-5 *1 (-979))) ((*1 *1 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-1054)) (-5 *2 (-572)) (-5 *1 (-448 *5 *3 *6)) (-4 *3 (-1234 *5)) (-4 *6 (-13 (-410) (-1044 *5) (-368) (-1190) (-281))))) ((*1 *2 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-448 *4 *3 *5)) (-4 *3 (-1234 *4)) (-4 *5 (-13 (-410) (-1044 *4) (-368) (-1190) (-281)))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-923)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-718)) (-5 *2 (-769))))) 
-(((*1 *1) (-12 (-5 *1 (-235 *2)) (-4 *2 (-1054))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-572)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-684 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-1259 *3)) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-379 *2)) (-4 *2 (-1204)) (-4 *2 (-848)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-379 *3)) (-4 *3 (-1204)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-906 *3))) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-4 *6 (-1068 *4 *5 *3)) (-5 *2 (-2 (|:| |under| *1) (|:| -1716 *1) (|:| |upper| *1))) (-4 *1 (-984 *4 *5 *3 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1166 *6)) (-4 *6 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-1166 *7)) (-5 *1 (-320 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-1170)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-469))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *5)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *2 (-326 *5 *7)) (-5 *1 (-119 *5 *6 *2 *7 *4)) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *4 (-117))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *1) (-5 *1 (-1260)))) 
-(((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) ((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-503 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-906 *4)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-905 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-923)) (-5 *2 (-121)) (-5 *1 (-1099 *4 *5)) (-14 *4 *3) (-14 *5 *3))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1259 (-769))) (-5 *1 (-670 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-932))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-923)) (-4 *5 (-562)) (-5 *2 (-685 *5)) (-5 *1 (-963 *5 *3)) (-4 *3 (-650 *5))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-677 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-638 (-572))) (-5 *3 (-685 (-572))) (-5 *1 (-1108))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-562)) (-5 *2 (-1166 *4)) (-5 *1 (-765 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-638 *3)) (-4 *3 (-1204))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-638 *2))) (-5 *4 (-638 *5)) (-4 *5 (-43 (-413 (-572)))) (-4 *2 (-1249 *5)) (-5 *1 (-1251 *5 *2))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-133))) ((*1 *1 *1 *1) (-5 *1 (-1116)))) 
-(((*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-638 (-638 (-217)))) (-5 *4 (-217)) (-5 *2 (-638 (-950 *4))) (-5 *1 (-1201)) (-5 *3 (-950 *4))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1170)) (-5 *2 (-443)) (-5 *1 (-1174))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-368)) (-4 *5 (-1234 *4)) (-5 *2 (-1264)) (-5 *1 (-45 *4 *5 *6 *7)) (-4 *6 (-1234 (-413 *5))) (-14 *7 *6)))) 
-(((*1 *2) (-12 (-5 *2 (-638 (-130))) (-5 *1 (-130))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *1 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204)))) ((*1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-379 *2)) (-4 *2 (-1204)))) ((*1 *1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-1234 *4)) (-4 *4 (-1214)) (-4 *1 (-342 *4 *3 *5)) (-4 *5 (-1234 (-413 *3)))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 *3) (|:| -4320 *4)))) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *1 (-1181 *3 *4)))) ((*1 *1) (-12 (-4 *1 (-1181 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *1 *2 *3) (-12 (-5 *1 (-433 *3 *2)) (-4 *3 (-13 (-174) (-43 (-413 (-572))))) (-4 *2 (-13 (-848) (-21)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *3 (-638 (-572))) (-5 *1 (-884))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-5 *2 (-638 *3)) (-5 *1 (-952 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-907 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-1234 *4)) (-5 *2 (-424 (-1166 *5))) (-5 *1 (-908 *4 *5)) (-5 *3 (-1166 *5))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-241 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204)))) ((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))) (-5 *2 (-1042)) (-5 *1 (-301))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1259 *5)) (-4 *5 (-793)) (-5 *2 (-121)) (-5 *1 (-843 *4 *5)) (-14 *4 (-769))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-769)) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-638 *1)) (-4 *1 (-436 *4)) (-4 *4 (-848)))) ((*1 *1 *2 *1 *1 *1 *1) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)))) ((*1 *1 *2 *1 *1 *1) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1170)) (-4 *1 (-436 *3)) (-4 *3 (-848))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1152)) (-5 *3 (-572)) (-5 *1 (-236))))) 
-(((*1 *1 *2 *1) (-12 (-5 *1 (-131 *2)) (-4 *2 (-848))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1231 *5 *4)) (-5 *1 (-1168 *4 *5 *6)) (-4 *4 (-1054)) (-14 *5 (-1170)) (-14 *6 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1231 (QUOTE |x|) *4)) (-5 *1 (-1216 *4)) (-4 *4 (-1054)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1231 *5 *4)) (-5 *1 (-1250 *4 *5 *6)) (-4 *4 (-1054)) (-14 *5 (-1170)) (-14 *6 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1231 *5 *4)) (-5 *1 (-1254 *4 *5)) (-4 *4 (-1054)) (-14 *5 (-1170))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -4304 *4) (|:| -4316 (-572))))) (-4 *4 (-1234 (-572))) (-5 *2 (-733 (-769))) (-5 *1 (-447 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-424 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-1054)) (-5 *2 (-733 (-769))) (-5 *1 (-449 *4 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-620 *3 *4 *5 *6 *7 *2)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *2 (-1107 *3 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-121)) (-5 *1 (-216 *4 *5)) (-4 *5 (-13 (-1190) (-29 *4)))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-322 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-138))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) ((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-638 (-638 *7))) (-5 *1 (-453 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-956 *5 *6 *7)) (-5 *2 (-638 (-638 *8))) (-5 *1 (-453 *5 *6 *7 *8)) (-5 *3 (-638 *8)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-638 (-638 *7))) (-5 *1 (-453 *4 *5 *6 *7)) (-5 *3 (-638 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-956 *5 *6 *7)) (-5 *2 (-638 (-638 *8))) (-5 *1 (-453 *5 *6 *7 *8)) (-5 *3 (-638 *8))))) 
-(((*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *4 (-572)) (-5 *6 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-57))))) 
-(((*1 *2) (-12 (-4 *3 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *2 (-638 *4)) (-5 *1 (-914 *3 *4 *5 *6)) (-4 *4 (-326 *3 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-1150 *3))) (-5 *2 (-1150 *3)) (-5 *1 (-1154 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054))))) 
-(((*1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1) (-4 *1 (-133))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1) (-5 *1 (-1116)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-567)))) ((*1 *2 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1204)) (-5 *2 (-638 *4))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-168 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-413 (-572))) (-5 *1 (-424 *3)) (-4 *3 (-554)) (-4 *3 (-562)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-554)) (-5 *2 (-413 (-572))))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-798 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-413 (-572))) (-5 *1 (-834 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-413 (-572))) (-5 *1 (-841 *3)) (-4 *3 (-554)) (-4 *3 (-1098)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1004 *3)) (-4 *3 (-174)) (-4 *3 (-554)) (-5 *2 (-413 (-572))))) ((*1 *2 *3) (|partial| -12 (-5 *2 (-413 (-572))) (-5 *1 (-1015 *3)) (-4 *3 (-1044 *2))))) 
-(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-368)) (-5 *1 (-764 *2 *3)) (-4 *2 (-704 *3)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1166 *6)) (-5 *3 (-572)) (-4 *6 (-303)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-738 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5))))) 
-(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190))))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-572)) (-4 *5 (-1054)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-5 *1 (-914 *5 *2 *6 *7)) (-4 *2 (-326 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5)))) ((*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-923)) (-5 *4 (-385)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *1) (-12 (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-886 *3 *4 *5)) (-4 *3 (-1098)) (-4 *5 (-662 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-890 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-848)) (-5 *1 (-936 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-312 (-572))) (-5 *1 (-937))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-210))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-4 *3 (-13 (-27) (-1190) (-436 *6) (-10 -8 (-15 -3972 ($ *7))))) (-4 *7 (-846)) (-4 *8 (-13 (-1236 *3 *7) (-368) (-1190) (-10 -8 (-15 -3139 ($ $)) (-15 -2774 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152)))))) (-5 *1 (-428 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1152)) (-4 *9 (-991 *8)) (-14 *10 (-1170))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-392 *3)) (|:| |mm| (-392 *3)) (|:| |rm| (-392 *3)))) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-820 *3)) (|:| |mm| (-820 *3)) (|:| |rm| (-820 *3)))) (-5 *1 (-820 *3)) (-4 *3 (-848))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-848)) (-5 *1 (-936 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-312 (-572))) (-5 *1 (-937))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1170))))) 
-(((*1 *1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-932)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-932)))) ((*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-950 (-217)) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-1178 (-1085 *3) (-1085 *3))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-121))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1264)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) ((*1 *2) (-12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-121)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *1 (-645 *3)) (-4 *3 (-368)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-5 *1 (-658 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *9 (-926 *3 *8)))) ((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-5 *2 (-121)) (-5 *1 (-658 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *9 (-926 *3 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| |val| (-638 *8)) (|:| -1337 *9)))) (-5 *4 (-769)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-1264)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| |val| (-638 *8)) (|:| -1337 *9)))) (-5 *4 (-769)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-1264)) (-5 *1 (-1138 *5 *6 *7 *8 *9))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *2 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185))))) 
-(((*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-454 *3 *4 *5 *6))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-248 *4 *3 *5 *6)) (-4 *4 (-1054)) (-4 *3 (-848)) (-4 *5 (-264 *3)) (-4 *6 (-794)) (-5 *2 (-638 (-769))))) ((*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-638 (-769)))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-457)) (-4 *3 (-848)) (-4 *4 (-794)) (-5 *1 (-995 *2 *3 *4 *5)) (-4 *5 (-956 *2 *4 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-5 *2 (-1264)) (-5 *1 (-1173)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-1170))) (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) ((*1 *2 *3 *4 *1) (-12 (-5 *4 (-638 (-1170))) (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-477)) (-5 *4 (-923)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2 *1 *2 *3) (|partial| -12 (-5 *2 (-1152)) (-5 *3 (-572)) (-5 *1 (-1066))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (-12 (-5 *3 (-572)) (-5 *5 (-121)) (-5 *6 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)) (-4 *2 (-1190)))) ((*1 *2 *1) (-12 (-5 *1 (-331 *2)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-611 *3)) (-4 *3 (-848))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-385)) (-5 *1 (-1066))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-995 (-413 (-572)) (-858 *3) (-234 *4 (-769)) (-244 *3 (-413 (-572))))) (-14 *3 (-638 (-1170))) (-14 *4 (-769)) (-5 *1 (-994 *3 *4))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-513 *2)) (-14 *2 (-572)))) ((*1 *1 *1 *1) (-5 *1 (-1116)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-424 *3)) (-5 *1 (-916 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-572)) (-5 *5 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *6 (-1054)) (-4 *7 (-232 *8 (-769))) (-14 *8 (-769)) (-5 *2 (-638 (-638 *3))) (-5 *1 (-778 *6 *3 *7 *8)) (-4 *3 (-326 *6 *7))))) 
-(((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE)))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-753)))) ((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-73 IMAGE)))) (-5 *8 (-394)) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *3 *4 *4 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-769)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-794)) (-4 *4 (-956 *5 *6 *7)) (-4 *5 (-457)) (-4 *7 (-848)) (-5 *1 (-454 *5 *6 *7 *4))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1116)) (-5 *2 (-121)) (-5 *1 (-822))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-572)) (|has| *1 (-6 -4603)) (-4 *1 (-379 *3)) (-4 *3 (-1204))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-645 *2)) (-4 *2 (-368))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-57))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-121)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *3)) (-5 *1 (-1124 *4 *3)) (-4 *4 (-1234 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1042)) (-5 *3 (-1170)) (-5 *1 (-265))))) 
-(((*1 *2 *3 *2) (-12 (-4 *2 (-13 (-368) (-846))) (-5 *1 (-180 *2 *3)) (-4 *3 (-1234 (-171 *2))))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-368) (-846))) (-5 *1 (-180 *2 *3)) (-4 *3 (-1234 (-171 *2)))))) 
-(((*1 *1 *1) (-4 *1 (-147))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1262))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-121)) (-5 *5 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *3 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *2 (-121)) (-5 *1 (-495))))) 
-(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-123)) (-5 *4 (-769)) (-4 *5 (-457)) (-4 *5 (-848)) (-4 *5 (-1044 (-572))) (-4 *5 (-562)) (-5 *1 (-46 *5 *2)) (-4 *2 (-436 *5)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *5 (-611 $)) $)) (-15 -4492 ((-1121 *5 (-611 $)) $)) (-15 -3972 ($ (-1121 *5 (-611 $)))))))))) 
-(((*1 *1 *1) (-4 *1 (-1137)))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1108)) (-5 *3 (-572))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-825)) (-5 *3 (-638 (-1170))) (-5 *1 (-826))))) 
-(((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1152)) (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-545)) (-5 *1 (-544 *4)) (-4 *4 (-1204))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-638 (-258))) (-5 *4 (-1170)) (-5 *1 (-257 *2)) (-4 *2 (-1204)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-638 (-258))) (-5 *4 (-1170)) (-5 *2 (-57)) (-5 *1 (-258)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-638 (-469))) (-5 *4 (-1170)) (-5 *2 (-57)) (-5 *1 (-469))))) 
-(((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-670 *3)) (-4 *3 (-1098))))) 
-(((*1 *1) (-5 *1 (-159)))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 (-769)) (-4 *5 (-174))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *8)) (|:| |neqzro| (-638 *8)) (|:| |wcond| (-638 (-959 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *5)))) (|:| -2237 (-638 (-1259 (-413 (-959 *5)))))))))) (-5 *1 (-930 *5 *6 *7 *8)) (-5 *4 (-638 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-5 *4 (-638 (-1170))) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *8)) (|:| |neqzro| (-638 *8)) (|:| |wcond| (-638 (-959 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *5)))) (|:| -2237 (-638 (-1259 (-413 (-959 *5)))))))))) (-5 *1 (-930 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-685 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *7)) (|:| |neqzro| (-638 *7)) (|:| |wcond| (-638 (-959 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *4)))) (|:| -2237 (-638 (-1259 (-413 (-959 *4)))))))))) (-5 *1 (-930 *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *5 (-923)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *9)) (|:| |neqzro| (-638 *9)) (|:| |wcond| (-638 (-959 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *6)))) (|:| -2237 (-638 (-1259 (-413 (-959 *6)))))))))) (-5 *1 (-930 *6 *7 *8 *9)) (-5 *4 (-638 *9)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *4 (-638 (-1170))) (-5 *5 (-923)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *9)) (|:| |neqzro| (-638 *9)) (|:| |wcond| (-638 (-959 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *6)))) (|:| -2237 (-638 (-1259 (-413 (-959 *6)))))))))) (-5 *1 (-930 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-5 *4 (-923)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *8)) (|:| |neqzro| (-638 *8)) (|:| |wcond| (-638 (-959 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *5)))) (|:| -2237 (-638 (-1259 (-413 (-959 *5)))))))))) (-5 *1 (-930 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *4 (-638 *9)) (-5 *5 (-1152)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *6 *7 *8 *9)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *4 (-638 (-1170))) (-5 *5 (-1152)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-5 *4 (-1152)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-685 *10)) (-5 *4 (-638 *10)) (-5 *5 (-923)) (-5 *6 (-1152)) (-4 *10 (-956 *7 *9 *8)) (-4 *7 (-13 (-303) (-151))) (-4 *8 (-13 (-848) (-613 (-1170)))) (-4 *9 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-685 *10)) (-5 *4 (-638 (-1170))) (-5 *5 (-923)) (-5 *6 (-1152)) (-4 *10 (-956 *7 *9 *8)) (-4 *7 (-13 (-303) (-151))) (-4 *8 (-13 (-848) (-613 (-1170)))) (-4 *9 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-685 *9)) (-5 *4 (-923)) (-5 *5 (-1152)) (-4 *9 (-956 *6 *8 *7)) (-4 *6 (-13 (-303) (-151))) (-4 *7 (-13 (-848) (-613 (-1170)))) (-4 *8 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *6 *7 *8 *9))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-787))))) 
-(((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1152)) (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) ((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-685 *4)) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) ((*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-685 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-335 *3 *4 *5 *6)) (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 *3 *4 *5)) (-5 *2 (-2 (|:| -4004 (-419 *4 (-413 *4) *5 *6)) (|:| |principalPart| *6))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |poly| *6) (|:| -2071 (-413 *6)) (|:| |special| (-413 *6)))) (-5 *1 (-723 *5 *6)) (-5 *3 (-413 *6)))) ((*1 *2 *3) (-12 (-4 *4 (-368)) (-5 *2 (-638 *3)) (-5 *1 (-897 *3 *4)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *4 *4) (|partial| -12 (-5 *4 (-769)) (-4 *5 (-368)) (-5 *2 (-2 (|:| -1866 *3) (|:| -1862 *3))) (-5 *1 (-897 *3 *5)) (-4 *3 (-1234 *5)))) ((*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-638 *9)) (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-638 *9)) (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-638 *9)) (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1138 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-638 *9)) (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1138 *5 *6 *7 *8 *9))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 (-638 *7) *7 (-1166 *7))) (-5 *5 (-1 (-424 *7) *7)) (-4 *7 (-1234 *6)) (-4 *6 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-5 *2 (-638 (-2 (|:| |frac| (-413 *7)) (|:| -2352 *3)))) (-5 *1 (-810 *6 *7 *3 *8)) (-4 *3 (-650 *7)) (-4 *8 (-650 (-413 *7))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-424 *6) *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-5 *2 (-638 (-2 (|:| |frac| (-413 *6)) (|:| -2352 (-648 *6 (-413 *6)))))) (-5 *1 (-813 *5 *6)) (-5 *3 (-648 *6 (-413 *6)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-572)))) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| |ans| (-413 *5)) (|:| |nosol| (-121)))) (-5 *1 (-1022 *4 *5)) (-5 *3 (-413 *5))))) 
-(((*1 *2 *3 *4 *5 *3 *6 *3) (-12 (-5 *3 (-572)) (-5 *5 (-171 (-217))) (-5 *6 (-1152)) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *1 *2 *3 *4) (-12 (-14 *5 (-638 (-1170))) (-4 *2 (-174)) (-4 *4 (-232 (-4032 *5) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *3) (|:| -3751 *4)) (-2 (|:| -1763 *3) (|:| -3751 *4)))) (-5 *1 (-467 *5 *2 *3 *4 *6 *7)) (-4 *3 (-848)) (-4 *7 (-956 *2 *4 (-858 *5)))))) 
-(((*1 *2 *3 *4 *5 *4 *4 *4) (-12 (-4 *6 (-848)) (-5 *3 (-638 *6)) (-5 *5 (-638 *3)) (-5 *2 (-2 (|:| |f1| *3) (|:| |f2| (-638 *5)) (|:| |f3| *5) (|:| |f4| (-638 *5)))) (-5 *1 (-1176 *6)) (-5 *4 (-638 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-569)) (-5 *3 (-572))))) 
-(((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-820 *4)) (-4 *4 (-848)) (-5 *2 (-121)) (-5 *1 (-667 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-846))) (-5 *2 (-2 (|:| |start| *3) (|:| -4547 (-424 *3)))) (-5 *1 (-180 *4 *3)) (-4 *3 (-1234 (-171 *4)))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-848)) (-4 *4 (-368)) (-4 *5 (-794)) (-5 *2 (-121)) (-5 *1 (-518 *4 *5 *6 *7)) (-4 *7 (-956 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-248 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-848)) (-4 *5 (-264 *4)) (-4 *6 (-794)) (-5 *2 (-638 *4))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-826))))) 
-(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-755))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-846))) (-5 *1 (-180 *3 *2)) (-4 *2 (-1234 (-171 *3)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1234 *6)) (-4 *6 (-13 (-27) (-436 *5))) (-4 *5 (-13 (-848) (-562) (-1044 (-572)))) (-4 *8 (-1234 (-413 *7))) (-5 *2 (-589 *3)) (-5 *1 (-557 *5 *6 *7 *8 *3)) (-4 *3 (-342 *6 *7 *8))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-2 (|:| |eqzro| (-638 *8)) (|:| |neqzro| (-638 *8)) (|:| |wcond| (-638 (-959 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *5)))) (|:| -2237 (-638 (-1259 (-413 (-959 *5)))))))))) (-5 *4 (-1152)) (-4 *5 (-13 (-303) (-151))) (-4 *8 (-956 *5 *7 *6)) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-572)) (-5 *1 (-930 *5 *6 *7 *8))))) 
-(((*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (-12 (-5 *3 (-1152)) (-5 *5 (-685 (-217))) (-5 *6 (-685 (-572))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-755))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1 *1) (-4 *1 (-624))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *3 (-572)) (-5 *4 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-424 *2)) (-4 *2 (-562))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-457) (-151))) (-5 *2 (-424 *3)) (-5 *1 (-103 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-13 (-457) (-151))) (-5 *2 (-424 *3)) (-5 *1 (-103 *5 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-4 *4 (-353)) (-5 *2 (-1264)) (-5 *1 (-536 *4))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-171 (-217)))) (-5 *2 (-217)) (-5 *1 (-115))))) 
-(((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-755))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-4 *4 (-174)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)) (-4 *3 (-174))))) 
-(((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-611 *3)) (-5 *5 (-1 (-1166 *3) (-1166 *3))) (-4 *3 (-13 (-27) (-436 *6))) (-4 *6 (-13 (-848) (-562))) (-5 *2 (-589 *3)) (-5 *1 (-556 *6 *3))))) 
-(((*1 *1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-174)) (-4 *2 (-562)))) ((*1 *1 *1) (|partial| -4 *1 (-718)))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-33 *3)) (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *4 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1234 *4))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-956 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-457)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *1)))) (-4 *1 (-1073 *4 *5 *6 *3)))) ((*1 *1 *1) (-4 *1 (-1214))) ((*1 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-1237 *3 *2)) (-4 *2 (-13 (-1234 *3) (-562) (-10 -8 (-15 -3069 ($ $ $)))))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-13 (-846) (-368))) (-5 *2 (-121)) (-5 *1 (-1064 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-368)) (-5 *1 (-897 *2 *4)) (-4 *2 (-1234 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1166 *4))) (-4 *4 (-368)) (-5 *2 (-2 (|:| |zeros| (-638 *4)) (|:| -3818 (-572)))) (-5 *1 (-1050 *4))))) 
-(((*1 *2 *3 *4 *4 *5 *4 *4 *5) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-755))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-5 *2 (-477)) (-5 *1 (-1260))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-1092 (-217))) (-5 *2 (-933)) (-5 *1 (-931 *3)) (-4 *3 (-613 (-545))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-933)) (-5 *1 (-931 *3)) (-4 *3 (-613 (-545))))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *1 (-933)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-787))))) 
-(((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-171 (-217)) (-171 (-217)))) (-5 *4 (-1092 (-217))) (-5 *5 (-121)) (-5 *2 (-1261)) (-5 *1 (-252))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-685 *5))) (-5 *4 (-572)) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-121)) (-5 *1 (-1036 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-685 *4))) (-4 *4 (-368)) (-4 *4 (-1054)) (-5 *2 (-121)) (-5 *1 (-1036 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3)))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1259 (-1170))) (-5 *3 (-1259 (-458 *4 *5 *6 *7))) (-5 *1 (-458 *4 *5 *6 *7)) (-4 *4 (-174)) (-14 *5 (-923)) (-14 *6 (-638 (-1170))) (-14 *7 (-1259 (-685 *4))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-1259 (-458 *4 *5 *6 *7))) (-5 *1 (-458 *4 *5 *6 *7)) (-4 *4 (-174)) (-14 *5 (-923)) (-14 *6 (-638 *2)) (-14 *7 (-1259 (-685 *4))))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-458 *3 *4 *5 *6))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-1170))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 *2)) (-14 *6 (-1259 (-685 *3))))) ((*1 *1) (-12 (-5 *1 (-458 *2 *3 *4 *5)) (-4 *2 (-174)) (-14 *3 (-923)) (-14 *4 (-638 (-1170))) (-14 *5 (-1259 (-685 *2)))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-950 *4)) (-4 *1 (-1130 *4)) (-4 *4 (-1054)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-769)) (-5 *4 (-950 (-217))) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1044 (-572))) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-36 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-1166 *4)) (-5 *1 (-167 *3 *4)) (-4 *3 (-168 *4)))) ((*1 *1 *1) (-12 (-4 *1 (-1054)) (-4 *1 (-298)))) ((*1 *2) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-1166 *3)))) ((*1 *2) (-12 (-4 *1 (-720 *3 *2)) (-4 *3 (-174)) (-4 *2 (-1234 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) ((*1 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-864)))) ((*1 *2 *1) (-12 (-4 *1 (-1070 *3 *2)) (-4 *3 (-13 (-846) (-368))) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-57))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562) (-613 (-545)))) (-5 *1 (-1031 *3 *2)) (-4 *2 (-13 (-436 *3) (-23) (-1044 (-572)) (-1044 (-1170)) (-901 (-1170)) (-162)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |gen| *3) (|:| -4179 (-572)))) (-5 *1 (-238 *3)) (-4 *3 (-1096)))) ((*1 *1 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204)))) ((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-977 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-562))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-1054) (-713 (-413 (-572))))) (-4 *5 (-848)) (-5 *1 (-1273 *4 *5 *2)) (-4 *2 (-1278 *5 *4))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1234 *4)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 *2))) (-5 *2 (-893 *3)) (-5 *1 (-1076 *3 *4 *5)) (-4 *5 (-13 (-436 *4) (-887 *3) (-613 *2)))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1166 (-572))) (-5 *2 (-572)) (-5 *1 (-949))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-330))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-923)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-258))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-959 (-572))) (-5 *5 (-638 (-1170))) (-4 *1 (-671 *2 *6)) (-4 *6 (-1204)) (-5 *4 (-1170)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-875)) (-5 *3 (-638 (-258))) (-5 *1 (-256))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-577 *3)) (-4 *3 (-1044 (-572))))) ((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-1270 *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-638 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *1 (-1270 *5 *6 *7 *8))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39)))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-822)) (-5 *2 (-57)) (-5 *1 (-832))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *5)) (-4 *5 (-368)) (-5 *3 (-769)) (-14 *6 (-638 (-1170))) (-4 *8 (-232 (-4032 *6) *3)) (-5 *1 (-119 *5 *6 *7 *8 *4)) (-4 *7 (-326 *5 *8)) (-4 *4 (-117))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *2 (-117))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-638 (-950 *3)))))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-638 (-638 (-950 *4)))) (-5 *3 (-121)) (-4 *4 (-1054)) (-4 *1 (-1130 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-950 *3)))) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) ((*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-638 (-638 (-638 *4)))) (-5 *3 (-121)) (-4 *1 (-1130 *4)) (-4 *4 (-1054)))) ((*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-638 (-638 (-950 *4)))) (-5 *3 (-121)) (-4 *1 (-1130 *4)) (-4 *4 (-1054)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-638 (-638 *5)))) (-5 *3 (-638 (-173))) (-5 *4 (-173)) (-4 *1 (-1130 *5)) (-4 *5 (-1054)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-638 (-638 (-950 *5)))) (-5 *3 (-638 (-173))) (-5 *4 (-173)) (-4 *1 (-1130 *5)) (-4 *5 (-1054))))) 
-(((*1 *2 *3 *4 *4 *2 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-769)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-794)) (-4 *4 (-956 *5 *6 *7)) (-4 *5 (-457)) (-4 *7 (-848)) (-5 *1 (-454 *5 *6 *7 *4))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-5 *2 (-1170)) (-5 *1 (-330))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *2 (-572)) (-5 *1 (-1187 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848))) (-4 *2 (-13 (-436 *4) (-1009) (-1190))) (-5 *1 (-601 *4 *2 *3)) (-4 *3 (-13 (-436 (-171 *4)) (-1009) (-1190)))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-638 (-290 (-959 *4))))) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-290 (-413 (-959 (-572)))))) (-5 *2 (-638 (-638 (-290 (-959 *4))))) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 (-572)))) (-5 *2 (-638 (-290 (-959 *4)))) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-290 (-413 (-959 (-572))))) (-5 *2 (-638 (-290 (-959 *4)))) (-5 *1 (-386 *4)) (-4 *4 (-13 (-846) (-368))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1170)) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-4 *4 (-13 (-29 *6) (-1190) (-966))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2237 (-638 *4)))) (-5 *1 (-646 *6 *4 *3)) (-4 *3 (-650 *4)))) ((*1 *2 *3 *2 *4 *2 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-646 *6 *2 *3)) (-4 *3 (-650 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| |particular| (-3 (-1259 *5) "failed")) (|:| -2237 (-638 (-1259 *5))))) (-5 *1 (-663 *5)) (-5 *4 (-1259 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 *5))) (-4 *5 (-368)) (-5 *2 (-2 (|:| |particular| (-3 (-1259 *5) "failed")) (|:| -2237 (-638 (-1259 *5))))) (-5 *1 (-663 *5)) (-5 *4 (-1259 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 *5)) (-4 *5 (-368)) (-5 *2 (-638 (-2 (|:| |particular| (-3 (-1259 *5) "failed")) (|:| -2237 (-638 (-1259 *5)))))) (-5 *1 (-663 *5)) (-5 *4 (-638 (-1259 *5))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 *5))) (-4 *5 (-368)) (-5 *2 (-638 (-2 (|:| |particular| (-3 (-1259 *5) "failed")) (|:| -2237 (-638 (-1259 *5)))))) (-5 *1 (-663 *5)) (-5 *4 (-638 (-1259 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-664 *5 *6 *4 *3)) (-4 *3 (-683 *5 *6 *4)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-4 *7 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-5 *2 (-638 (-2 (|:| |particular| (-3 *7 "failed")) (|:| -2237 (-638 *7))))) (-5 *1 (-664 *5 *6 *7 *3)) (-5 *4 (-638 *7)) (-4 *3 (-683 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *5)))))) (-5 *1 (-768 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *4)))))) (-5 *1 (-768 *4)))) ((*1 *2 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-770 *5 *2)) (-4 *2 (-13 (-29 *5) (-1190) (-966))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-685 *7)) (-5 *5 (-1170)) (-4 *7 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-2 (|:| |particular| (-1259 *7)) (|:| -2237 (-638 (-1259 *7))))) (-5 *1 (-803 *6 *7)) (-5 *4 (-1259 *7)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-685 *6)) (-5 *4 (-1170)) (-4 *6 (-13 (-29 *5) (-1190) (-966))) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-1259 *6))) (-5 *1 (-803 *5 *6)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-638 (-290 *7))) (-5 *4 (-638 (-123))) (-5 *5 (-1170)) (-4 *7 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-2 (|:| |particular| (-1259 *7)) (|:| -2237 (-638 (-1259 *7))))) (-5 *1 (-803 *6 *7)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-638 *7)) (-5 *4 (-638 (-123))) (-5 *5 (-1170)) (-4 *7 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-2 (|:| |particular| (-1259 *7)) (|:| -2237 (-638 (-1259 *7))))) (-5 *1 (-803 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-290 *7)) (-5 *4 (-123)) (-5 *5 (-1170)) (-4 *7 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-3 (-2 (|:| |particular| *7) (|:| -2237 (-638 *7))) *7 "failed")) (-5 *1 (-803 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-123)) (-5 *5 (-1170)) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-3 (-2 (|:| |particular| *3) (|:| -2237 (-638 *3))) *3 "failed")) (-5 *1 (-803 *6 *3)) (-4 *3 (-13 (-29 *6) (-1190) (-966))))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-290 *2)) (-5 *4 (-123)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-29 *6) (-1190) (-966))) (-5 *1 (-803 *6 *2)) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))))) ((*1 *2 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-290 *2)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-29 *6) (-1190) (-966))) (-4 *6 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-803 *6 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-809)) (-5 *2 (-1042)) (-5 *1 (-806)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-809)) (-5 *4 (-1066)) (-5 *2 (-1042)) (-5 *1 (-806)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1259 (-312 (-385)))) (-5 *4 (-385)) (-5 *5 (-638 *4)) (-5 *2 (-1042)) (-5 *1 (-806)))) ((*1 *2 *3 *4 *4 *5 *4) (-12 (-5 *3 (-1259 (-312 (-385)))) (-5 *4 (-385)) (-5 *5 (-638 *4)) (-5 *2 (-1042)) (-5 *1 (-806)))) ((*1 *2 *3 *4 *4 *5 *6 *4) (-12 (-5 *3 (-1259 (-312 *4))) (-5 *5 (-638 (-385))) (-5 *6 (-312 (-385))) (-5 *4 (-385)) (-5 *2 (-1042)) (-5 *1 (-806)))) ((*1 *2 *3 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1259 (-312 (-385)))) (-5 *4 (-385)) (-5 *5 (-638 *4)) (-5 *2 (-1042)) (-5 *1 (-806)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4) (-12 (-5 *3 (-1259 (-312 *4))) (-5 *5 (-638 (-385))) (-5 *6 (-312 (-385))) (-5 *4 (-385)) (-5 *2 (-1042)) (-5 *1 (-806)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (-12 (-5 *3 (-1259 (-312 *4))) (-5 *5 (-638 (-385))) (-5 *6 (-312 (-385))) (-5 *4 (-385)) (-5 *2 (-1042)) (-5 *1 (-806)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-2 (|:| |particular| *6) (|:| -2237 (-638 *6))) "failed") *7 *6)) (-4 *6 (-368)) (-4 *7 (-650 *6)) (-5 *2 (-2 (|:| |particular| (-1259 *6)) (|:| -2237 (-685 *6)))) (-5 *1 (-814 *6 *7)) (-5 *3 (-685 *6)) (-5 *4 (-1259 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-899)) (-5 *2 (-1042)) (-5 *1 (-898)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-899)) (-5 *4 (-1066)) (-5 *2 (-1042)) (-5 *1 (-898)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (-12 (-5 *4 (-769)) (-5 *6 (-638 (-638 (-312 *3)))) (-5 *7 (-1152)) (-5 *8 (-217)) (-5 *5 (-638 (-312 (-385)))) (-5 *3 (-385)) (-5 *2 (-1042)) (-5 *1 (-898)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (-12 (-5 *4 (-769)) (-5 *6 (-638 (-638 (-312 *3)))) (-5 *7 (-1152)) (-5 *5 (-638 (-312 (-385)))) (-5 *3 (-385)) (-5 *2 (-1042)) (-5 *1 (-898)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-959 (-413 (-572)))) (-5 *2 (-638 (-385))) (-5 *1 (-1029)) (-5 *4 (-385)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-959 (-572))) (-5 *2 (-638 (-385))) (-5 *1 (-1029)) (-5 *4 (-385)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *2 (-638 *4)) (-5 *1 (-1124 *3 *4)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-290 (-312 *4)))) (-5 *1 (-1127 *4)) (-5 *3 (-312 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-290 (-312 *4)))) (-5 *1 (-1127 *4)) (-5 *3 (-290 (-312 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-290 (-312 *5)))) (-5 *1 (-1127 *5)) (-5 *3 (-290 (-312 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-290 (-312 *5)))) (-5 *1 (-1127 *5)) (-5 *3 (-312 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *5))))) (-5 *1 (-1127 *5)) (-5 *3 (-638 (-290 (-312 *5)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 *5)))) (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *5)))))) (-5 *1 (-1175 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-1170))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *5)))))) (-5 *1 (-1175 *5)) (-5 *3 (-638 (-290 (-413 (-959 *5))))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 *4)))) (-4 *4 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *4)))))) (-5 *1 (-1175 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *4)))))) (-5 *1 (-1175 *4)) (-5 *3 (-638 (-290 (-413 (-959 *4))))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-562)) (-5 *2 (-638 (-290 (-413 (-959 *5))))) (-5 *1 (-1175 *5)) (-5 *3 (-413 (-959 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-562)) (-5 *2 (-638 (-290 (-413 (-959 *5))))) (-5 *1 (-1175 *5)) (-5 *3 (-290 (-413 (-959 *5)))))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 (-290 (-413 (-959 *4))))) (-5 *1 (-1175 *4)) (-5 *3 (-413 (-959 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 (-290 (-413 (-959 *4))))) (-5 *1 (-1175 *4)) (-5 *3 (-290 (-413 (-959 *4))))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-950 (-217))) (-5 *2 (-1264)) (-5 *1 (-477))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-413 (-959 *4))) (-5 *1 (-930 *4 *5 *6 *3)) (-4 *3 (-956 *4 *6 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-685 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-685 (-413 (-959 *4)))) (-5 *1 (-930 *4 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-413 (-959 *4)))) (-5 *1 (-930 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-572)) (-5 *6 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789)))) ((*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (-12 (-5 *4 (-572)) (-5 *6 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-572)) (-5 *2 (-638 (-638 (-217)))) (-5 *1 (-1201))))) 
-(((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-159))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-950 *4)) (-4 *4 (-1054)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-647 (-413 *5)))) (-5 *1 (-651 *4 *5)) (-5 *3 (-647 (-413 *5)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-260 *12))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)))) ((*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))) (-5 *1 (-804))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1234 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *2 *3 *4 *4 *3) (|partial| -12 (-5 *4 (-611 *3)) (-4 *3 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-574 *5 *3 *6)) (-4 *6 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *5)) (-5 *1 (-679 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5))))) 
-(((*1 *1 *1) (|partial| -4 *1 (-149))) ((*1 *1 *1) (-4 *1 (-353))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-149)) (-4 *1 (-910))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2) (-12 (-5 *2 (-1178 (-1170) (-130))) (-5 *1 (-130))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-572))) (-5 *4 (-572)) (-5 *2 (-57)) (-5 *1 (-1012))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-841 *3))) (-4 *3 (-13 (-1190) (-966) (-29 *5))) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 *3)) (|:| |f2| (-638 (-841 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-211 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1090 (-841 *3))) (-5 *5 (-1152)) (-4 *3 (-13 (-1190) (-966) (-29 *6))) (-4 *6 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 *3)) (|:| |f2| (-638 (-841 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-211 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1090 (-841 (-312 *5)))) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 (-312 *5))) (|:| |f2| (-638 (-841 (-312 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-212 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-413 (-959 *6))) (-5 *4 (-1090 (-841 (-312 *6)))) (-5 *5 (-1152)) (-4 *6 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 (-312 *6))) (|:| |f2| (-638 (-841 (-312 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-212 *6)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1090 (-841 (-413 (-959 *5))))) (-5 *3 (-413 (-959 *5))) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 (-312 *5))) (|:| |f2| (-638 (-841 (-312 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-212 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1090 (-841 (-413 (-959 *6))))) (-5 *5 (-1152)) (-5 *3 (-413 (-959 *6))) (-4 *6 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |f1| (-841 (-312 *6))) (|:| |f2| (-638 (-841 (-312 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-212 *6)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 *3 (-638 *3))) (-5 *1 (-434 *5 *3)) (-4 *3 (-13 (-1190) (-966) (-29 *5))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-483 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1092 (-841 (-385)))) (-5 *5 (-385)) (-5 *6 (-1066)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3) (-12 (-5 *3 (-767)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1092 (-841 (-385)))) (-5 *5 (-385)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1092 (-841 (-385)))) (-5 *5 (-385)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1092 (-841 (-385)))) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-1092 (-841 (-385))))) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-1092 (-841 (-385))))) (-5 *5 (-385)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-1092 (-841 (-385))))) (-5 *5 (-385)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-1092 (-841 (-385))))) (-5 *5 (-385)) (-5 *6 (-1066)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-841 (-385)))) (-5 *5 (-1152)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-841 (-385)))) (-5 *5 (-1170)) (-5 *2 (-1042)) (-5 *1 (-573)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-572)))) (-4 *5 (-1234 *4)) (-5 *2 (-589 (-413 *5))) (-5 *1 (-576 *4 *5)) (-5 *3 (-413 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-151)) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-3 (-312 *5) (-638 (-312 *5)))) (-5 *1 (-592 *5)))) ((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-736 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-848)) (-4 *3 (-43 (-413 (-572)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-959 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)))) ((*1 *1 *1 *2 *3) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-4 *2 (-848)) (-5 *1 (-1122 *3 *2 *4)) (-4 *4 (-956 *3 (-538 *2) *2)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1160 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1167 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1168 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *1 (-1199 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 (QUOTE |x|))) (-5 *1 (-1216 *3)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-1841 (-12 (-5 *2 (-1170)) (-4 *1 (-1218 *3)) (-4 *3 (-1054)) (-12 (-4 *3 (-29 (-572))) (-4 *3 (-966)) (-4 *3 (-1190)) (-4 *3 (-43 (-413 (-572)))))) (-12 (-5 *2 (-1170)) (-4 *1 (-1218 *3)) (-4 *3 (-1054)) (-12 (|has| *3 (-15 -3456 ((-638 *2) *3))) (|has| *3 (-15 -2774 (*3 *3 *2))) (-4 *3 (-43 (-413 (-572)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1218 *2)) (-4 *2 (-1054)) (-4 *2 (-43 (-413 (-572)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1222 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-43 (-413 (-572)))))) ((*1 *1 *1 *2) (-1841 (-12 (-5 *2 (-1170)) (-4 *1 (-1239 *3)) (-4 *3 (-1054)) (-12 (-4 *3 (-29 (-572))) (-4 *3 (-966)) (-4 *3 (-1190)) (-4 *3 (-43 (-413 (-572)))))) (-12 (-5 *2 (-1170)) (-4 *1 (-1239 *3)) (-4 *3 (-1054)) (-12 (|has| *3 (-15 -3456 ((-638 *2) *3))) (|has| *3 (-15 -2774 (*3 *3 *2))) (-4 *3 (-43 (-413 (-572)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1239 *2)) (-4 *2 (-1054)) (-4 *2 (-43 (-413 (-572)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-1841 (-12 (-5 *2 (-1170)) (-4 *1 (-1249 *3)) (-4 *3 (-1054)) (-12 (-4 *3 (-29 (-572))) (-4 *3 (-966)) (-4 *3 (-1190)) (-4 *3 (-43 (-413 (-572)))))) (-12 (-5 *2 (-1170)) (-4 *1 (-1249 *3)) (-4 *3 (-1054)) (-12 (|has| *3 (-15 -3456 ((-638 *2) *3))) (|has| *3 (-15 -2774 (*3 *3 *2))) (-4 *3 (-43 (-413 (-572)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1249 *2)) (-4 *2 (-1054)) (-4 *2 (-43 (-413 (-572)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1250 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1255 *4)) (-14 *4 (-1170)) (-5 *1 (-1254 *3 *4)) (-4 *3 (-43 (-413 (-572)))) (-4 *3 (-1054))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-2 (|:| |poly| *6) (|:| -2352 *3)))) (-5 *1 (-810 *5 *6 *3 *7)) (-4 *3 (-650 *6)) (-4 *7 (-650 (-413 *6))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-2 (|:| |poly| *6) (|:| -2352 (-648 *6 (-413 *6)))))) (-5 *1 (-813 *5 *6)) (-5 *3 (-648 *6 (-413 *6)))))) 
-(((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (-12 (-5 *1 (-1225 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *1) (-12 (-4 *4 (-1098)) (-5 *2 (-890 *3 *4)) (-5 *1 (-886 *3 *4 *5)) (-4 *3 (-1098)) (-4 *5 (-662 *4))))) 
-(((*1 *2 *3 *4 *5 *5) (-12 (-5 *5 (-769)) (-4 *6 (-1098)) (-4 *7 (-901 *6)) (-5 *2 (-685 *7)) (-5 *1 (-687 *6 *7 *3 *4)) (-4 *3 (-379 *7)) (-4 *4 (-13 (-379 *6) (-10 -7 (-6 -4602))))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |polnum| (-783 *3)) (|:| |polden| *3) (|:| -1951 (-769)))) (-5 *1 (-783 *3)) (-4 *3 (-1054)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| |polnum| *1) (|:| |polden| *1) (|:| -1951 (-769)))) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-368)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *4 (-217)) (-5 *2 (-2 (|:| |brans| (-638 (-638 (-950 *4)))) (|:| |xValues| (-1092 *4)) (|:| |yValues| (-1092 *4)))) (-5 *1 (-157)) (-5 *3 (-638 (-638 (-950 *4))))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-572)) (-5 *4 (-424 *2)) (-4 *2 (-956 *7 *5 *6)) (-5 *1 (-738 *5 *6 *7 *2)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-303))))) 
-(((*1 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-830))))) 
-(((*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (-12 (-5 *3 (-923)) (-5 *4 (-217)) (-5 *5 (-572)) (-5 *6 (-875)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-5 *1 (-567)))) ((*1 *2 *1) (-12 (-4 *1 (-609 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))) (-5 *1 (-804))))) 
-(((*1 *1 *1 *1) (-4 *1 (-298))) ((*1 *1 *1) (-4 *1 (-298)))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *2))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-4 *4 (-1098)) (-4 *5 (-13 (-1054) (-887 *4) (-848) (-613 (-893 *4)))) (-5 *1 (-60 *4 *5 *2)) (-4 *2 (-13 (-436 *5) (-887 *4) (-613 (-893 *4))))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933))))) 
-(((*1 *1) (-4 *1 (-353))) ((*1 *2 *3) (-12 (-5 *3 (-638 *5)) (-4 *5 (-436 *4)) (-4 *4 (-13 (-562) (-848) (-151))) (-5 *2 (-2 (|:| |primelt| *5) (|:| |poly| (-638 (-1166 *5))) (|:| |prim| (-1166 *5)))) (-5 *1 (-438 *4 *5)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-562) (-848) (-151))) (-5 *2 (-2 (|:| |primelt| *3) (|:| |pol1| (-1166 *3)) (|:| |pol2| (-1166 *3)) (|:| |prim| (-1166 *3)))) (-5 *1 (-438 *4 *3)) (-4 *3 (-27)) (-4 *3 (-436 *4)))) ((*1 *2 *3 *4 *3 *4) (-12 (-5 *3 (-959 *5)) (-5 *4 (-1170)) (-4 *5 (-13 (-368) (-151))) (-5 *2 (-2 (|:| |coef1| (-572)) (|:| |coef2| (-572)) (|:| |prim| (-1166 *5)))) (-5 *1 (-967 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-368) (-151))) (-5 *2 (-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 *5))) (|:| |prim| (-1166 *5)))) (-5 *1 (-967 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-959 *6))) (-5 *4 (-638 (-1170))) (-5 *5 (-1170)) (-4 *6 (-13 (-368) (-151))) (-5 *2 (-2 (|:| -4513 (-638 (-572))) (|:| |poly| (-638 (-1166 *6))) (|:| |prim| (-1166 *6)))) (-5 *1 (-967 *6))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *1) (-5 *1 (-443)))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3 *4 *3 *4 *4 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *2 (-978 *3)) (-4 *7 (-645 *3)) (-4 *8 (-926 *3 *7)) (-4 *9 (-237 *8)) (-4 *10 (-117))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (|:| |%expansion| (-309 *5 *3 *6 *7)) (|:| |%problem| (-2 (|:| |func| (-1152)) (|:| |prob| (-1152)))))) (-5 *1 (-426 *5 *3 *6 *7)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-14 *6 (-1170)) (-14 *7 *3)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-327 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-529 *3 *4)) (-14 *4 (-572))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1204)) (-5 *2 (-638 *3))))) 
-(((*1 *2 *3 *4 *3 *5 *5 *3 *5 *4) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1107 *5 *6 *7 *8)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-594 *5 *6 *7 *8 *3))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-1170)) (-5 *6 (-121)) (-4 *7 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-4 *3 (-13 (-1190) (-966) (-29 *7))) (-5 *2 (-3 (|:| |f1| (-841 *3)) (|:| |f2| (-638 (-841 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-211 *7 *3)) (-5 *5 (-841 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-859 *4 *5 *6 *7)) (-4 *4 (-1054)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 *3)) (-14 *7 *3))) ((*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-1054)) (-4 *5 (-848)) (-4 *6 (-794)) (-14 *8 (-638 *5)) (-5 *2 (-1264)) (-5 *1 (-1269 *4 *5 *6 *7 *8 *9 *10)) (-4 *7 (-956 *4 *6 *5)) (-14 *9 (-638 *3)) (-14 *10 *3)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| -12 (-5 *4 (-638 *11)) (-5 *5 (-638 (-1166 *9))) (-5 *6 (-638 *9)) (-5 *7 (-638 *12)) (-5 *8 (-638 (-769))) (-4 *11 (-848)) (-4 *9 (-303)) (-4 *12 (-956 *9 *10 *11)) (-4 *10 (-794)) (-5 *2 (-638 (-1166 *12))) (-5 *1 (-703 *10 *11 *9 *12)) (-5 *3 (-1166 *12))))) 
-(((*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-923)) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) ((*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-834 (-923))) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) ((*1 *2) (-12 (-4 *1 (-329 *3)) (-4 *3 (-368)) (-5 *2 (-923)))) ((*1 *2) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-834 (-923)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-1259 *5)) (-4 *5 (-634 *4)) (-4 *4 (-562)) (-5 *2 (-1259 *4)) (-5 *1 (-633 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-932)))) ((*1 *2 *1) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-823)) (-5 *1 (-822))))) 
-(((*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-982)) (-5 *2 (-1092 (-217)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1 (-950 (-217)) (-950 (-217)))) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-950 (-217)) (-950 (-217)))) (-5 *1 (-258)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-496 *5 *6))) (-5 *3 (-496 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-457)) (-5 *2 (-1259 *6)) (-5 *1 (-626 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-1170)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-469))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-4 *1 (-926 *4 *5)) (-4 *4 (-368)) (-4 *5 (-645 *4)) (-5 *2 (-1264))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-312 (-217)))) (-5 *2 (-121)) (-5 *1 (-265))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848))))) 
-(((*1 *2 *3 *4 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) (-769))) (-4 *9 (-978 *5)) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-4 *3 (-237 *11)) (-4 *12 (-540 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-2 (|:| -3306 (-572)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (-572)))) (-5 *1 (-471 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-5 *4 (-572)) (-4 *13 (-260 *12)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-238 (-928 *5))) (-4 *5 (-353)) (-5 *2 (-2 (|:| -3306 (-572)) (|:| |num| (-244 *6 *5)) (|:| |den| (-244 *6 *5)) (|:| |upTo| (-572)))) (-5 *1 (-873 *5 *6 *7)) (-5 *4 (-572)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-238 (-927 *5))) (-4 *5 (-368)) (-5 *2 (-2 (|:| -3306 (-572)) (|:| |num| (-244 *6 *5)) (|:| |den| (-244 *6 *5)) (|:| |upTo| (-572)))) (-5 *1 (-874 *5 *6 *7)) (-5 *4 (-572)) (-14 *6 (-638 (-1170))) (-4 *7 (-117))))) 
-(((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-769)) (-4 *5 (-368)) (-5 *2 (-413 *6)) (-5 *1 (-867 *5 *4 *6)) (-4 *4 (-1249 *5)) (-4 *6 (-1234 *5)))) ((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-769)) (-5 *4 (-1250 *5 *6 *7)) (-4 *5 (-368)) (-14 *6 (-1170)) (-14 *7 *5) (-5 *2 (-413 (-1231 *6 *5))) (-5 *1 (-868 *5 *6 *7)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-769)) (-5 *4 (-1250 *5 *6 *7)) (-4 *5 (-368)) (-14 *6 (-1170)) (-14 *7 *5) (-5 *2 (-413 (-1231 *6 *5))) (-5 *1 (-868 *5 *6 *7))))) 
-(((*1 *2 *3 *3 *4 *3 *5 *3 *5 *4 *5 *5 *4 *4 *5 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-121)) (-5 *1 (-468))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-638 (-2 (|:| |deg| (-769)) (|:| -2225 *3)))) (-5 *1 (-209 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3 *4 *3 *5) (-12 (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *9 (-645 *6)) (-5 *2 (-2 (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (-638 (-572))))) (-5 *1 (-658 *6 *7 *3 *8 *4 *9 *10)) (-5 *5 (-572)) (-4 *3 (-956 *6 *8 (-858 *7))) (-4 *4 (-978 *6)) (-4 *10 (-926 *6 *9))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385)))) (-5 *1 (-199))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-685 *2)) (-4 *2 (-174)) (-5 *1 (-150 *2)))) ((*1 *2 *3) (-12 (-4 *4 (-174)) (-4 *2 (-1234 *4)) (-5 *1 (-177 *4 *2 *3)) (-4 *3 (-720 *4 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 (-413 (-959 *5)))) (-5 *4 (-1170)) (-5 *2 (-959 *5)) (-5 *1 (-288 *5)) (-4 *5 (-457)))) ((*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 *4)))) (-5 *2 (-959 *4)) (-5 *1 (-288 *4)) (-4 *4 (-457)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *2)) (-4 *3 (-174)) (-4 *2 (-1234 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-685 (-171 (-413 (-572))))) (-5 *2 (-959 (-171 (-413 (-572))))) (-5 *1 (-762 *4)) (-4 *4 (-13 (-368) (-846))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 (-171 (-413 (-572))))) (-5 *4 (-1170)) (-5 *2 (-959 (-171 (-413 (-572))))) (-5 *1 (-762 *5)) (-4 *5 (-13 (-368) (-846))))) ((*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-572)))) (-5 *2 (-959 (-413 (-572)))) (-5 *1 (-779 *4)) (-4 *4 (-13 (-368) (-846))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 (-413 (-572)))) (-5 *4 (-1170)) (-5 *2 (-959 (-413 (-572)))) (-5 *1 (-779 *5)) (-4 *5 (-13 (-368) (-846)))))) 
-(((*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-457)) (-4 *3 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-454 *4 *3 *5 *6)) (-4 *6 (-956 *4 *3 *5))))) 
-(((*1 *2 *3 *4 *5 *6 *3 *3 *3 *3 *6 *3 *7 *8) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-121)) (-5 *6 (-217)) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-73 APROD)))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-78 MSOLVE)))) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-1054))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-469))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-121)) (-5 *1 (-296))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-1234 *3)) (-5 *1 (-405 *3 *2)) (-4 *3 (-13 (-368) (-151)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-5 *2 (-638 *3))))) 
-(((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-875)) (-5 *5 (-923)) (-5 *6 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-1263)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-638 (-258))) (-5 *2 (-1260)) (-5 *1 (-1263))))) 
-(((*1 *2 *3 *4 *3 *4 *5 *3 *4 *3 *3 *3 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-173)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-4 *1 (-904 *3))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-562)) (-5 *1 (-977 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-454 *4 *5 *6 *2))))) 
-(((*1 *2 *3 *4 *2 *3) (-12 (-5 *2 (-965 (-217))) (-5 *3 (-1116)) (-5 *4 (-217)) (-5 *1 (-115))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-57))) (-5 *2 (-1264)) (-5 *1 (-857))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *2 (-13 (-410) (-1044 *5) (-368) (-1190) (-281))) (-5 *1 (-448 *5 *3 *2)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-638 (-638 (-638 *5)))) (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-638 *5)) (-4 *5 (-848)) (-5 *1 (-1176 *5))))) 
-(((*1 *2 *3 *3 *4 *4 *4 *4 *3 *3 *3 *3 *5 *3 *6) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-75 APROD)))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-754))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1134 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-959 (-217))) (-5 *2 (-312 (-385))) (-5 *1 (-301))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-950 *4)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (-5 *1 (-186))))) 
-(((*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |cycle?| (-121)) (|:| -2799 (-769)) (|:| |period| (-769)))) (-5 *1 (-1150 *4)) (-4 *4 (-1204)) (-5 *3 (-769))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-4 *4 (-13 (-562) (-457))) (-5 *2 (-638 *4)) (-5 *1 (-349 *4 *5)) (-4 *5 (-52 *4 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-572)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-454 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-822)) (-5 *4 (-57)) (-5 *2 (-1264)) (-5 *1 (-832))))) 
-(((*1 *1) (-5 *1 (-143))) ((*1 *1 *1) (-5 *1 (-148))) ((*1 *1 *1) (-4 *1 (-1137)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-142 *5 *6 *7)) (-14 *5 (-572)) (-14 *6 (-769)) (-4 *7 (-174)) (-4 *8 (-174)) (-5 *2 (-142 *5 *6 *8)) (-5 *1 (-141 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *9)) (-4 *9 (-1054)) (-4 *5 (-848)) (-4 *6 (-794)) (-4 *8 (-1054)) (-4 *2 (-956 *9 *7 *5)) (-5 *1 (-724 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-794)) (-4 *4 (-956 *8 *6 *5))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 (-572))))) (-5 *2 (-638 (-685 (-312 (-572))))) (-5 *1 (-1038))))) 
-(((*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1074 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1106 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 *8)) (-5 *1 (-970 *5 *6 *3 *7 *8)) (-4 *8 (-978 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 (-2 (|:| |lcmfij| *3) (|:| |totdeg| (-769)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *3 (-794)) (-4 *6 (-956 *4 *3 *5)) (-4 *4 (-457)) (-4 *5 (-848)) (-5 *1 (-454 *4 *3 *5 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 (-572)) (-14 *4 *2) (-4 *5 (-174)))) ((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-923)) (-5 *1 (-167 *3 *4)) (-4 *3 (-168 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-923)))) ((*1 *2) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-923)))) ((*1 *2 *3) (-12 (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-769)) (-5 *1 (-533 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-685 *5)) (-5 *4 (-1259 *5)) (-4 *5 (-368)) (-5 *2 (-769)) (-5 *1 (-663 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4603)))) (-5 *2 (-769)) (-5 *1 (-664 *5 *6 *4 *3)) (-4 *3 (-683 *5 *6 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-562)) (-5 *2 (-769)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-769)) (-5 *1 (-684 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-4 *5 (-562)) (-5 *2 (-769))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-638 (-638 (-950 *3)))))))) 
-(((*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-368) (-151) (-1044 (-572)))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-413 *5))) (-5 *1 (-1023 *4 *5)) (-5 *3 (-413 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-151))) (-5 *1 (-546 *3 *2)) (-4 *2 (-1249 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-4 *4 (-1234 *3)) (-4 *5 (-720 *3 *4)) (-5 *1 (-550 *3 *4 *5 *2)) (-4 *2 (-1249 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-5 *1 (-551 *3 *2)) (-4 *2 (-1249 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-13 (-562) (-151))) (-5 *1 (-1145 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-572))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 *13)) (-4 *13 (-260 *12)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) *2)) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-5 *2 (-769)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *2 (-121)) (-5 *1 (-204))))) 
-(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-14 *5 (-638 (-1170))) (-4 *3 (-956 *2 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *2)) (-4 *8 (-645 *2)) (-4 *4 (-926 *2 *8)) (-4 *9 (-237 *4)) (-4 *10 (-540 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-14 *5 (-638 (-1170))) (-4 *3 (-956 *2 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *2)) (-4 *8 (-645 *2)) (-4 *4 (-926 *2 *8)) (-4 *9 (-237 *4)) (-4 *10 (-540 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 *6)) (-4 *6 (-956 *2 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-14 *5 (-638 (-1170))) (-4 *8 (-978 *2)) (-4 *9 (-645 *2)) (-4 *4 (-926 *2 *9)) (-4 *10 (-237 *4)) (-4 *11 (-540 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-368)) (-5 *1 (-471 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-244 *5 *2)) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-244 *5 *2)) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-244 *5 *2))) (-5 *4 (-928 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-353)) (-5 *1 (-873 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-244 *5 *2)) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-244 *5 *2)) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-244 *5 *2))) (-5 *4 (-927 *2)) (-14 *5 (-638 (-1170))) (-4 *2 (-368)) (-5 *1 (-874 *2 *5 *6)) (-4 *6 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-185)) (-5 *3 (-572)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-784 *2)) (-4 *2 (-174)))) ((*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572))))) 
-(((*1 *2) (-12 (-4 *3 (-374)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *9)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-5 *2 (-638 (-928 *3))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-638 (-927 *3))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *1 *2 *3) (-12 (-4 *4 (-368)) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-645 *4)) (-4 *8 (-926 *4 *7)) (-4 *1 (-540 *4 *5 *3 *6 *2 *7 *8 *9 *10)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *2 (-978 *4)) (-4 *9 (-237 *8)) (-4 *10 (-117)))) ((*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (-12 (-5 *3 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *8)) (-5 *4 (-33 *8)) (-5 *9 (-1170)) (-4 *8 (-368)) (-5 *5 (-769)) (-4 *12 (-232 (-4032 *10) *5)) (-4 *13 (-645 *8)) (-4 *14 (-926 *8 *13)) (-4 *1 (-540 *8 *10 *11 *12 *2 *13 *14 *7 *6)) (-4 *11 (-956 *8 *12 (-858 *10))) (-4 *2 (-978 *8)) (-4 *7 (-237 *14)) (-4 *6 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-4 *3 (-368)) (-4 *1 (-926 *3 *4)) (-4 *4 (-645 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-926 *3 *4)) (-4 *4 (-645 *3)))) ((*1 *1) (-5 *1 (-1082)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-219)))) ((*1 *1 *1) (-4 *1 (-624))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-959 (-171 *4))) (-4 *4 (-174)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-959 (-171 *5))) (-5 *4 (-923)) (-4 *5 (-174)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-959 *4)) (-4 *4 (-1054)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-959 *5)) (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 (-171 *4)))) (-4 *4 (-562)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-959 (-171 *5)))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-312 *4)) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-312 *5)) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-312 (-171 *4))) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-312 (-171 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 (-385))) (-5 *2 (-171 (-385))) (-5 *1 (-786 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-469))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1225 *3)) (-4 *3 (-1204))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-638 (-217))) (-5 *1 (-198))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1166 *3)) (-5 *1 (-916 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-496 *4 *5))) (-5 *3 (-638 (-858 *4))) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *1 (-480 *4 *5 *6)) (-4 *6 (-457))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *6 (-1152)) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-638 (-1170))) (-5 *2 (-638 (-638 (-385)))) (-5 *1 (-1029)) (-5 *5 (-385)))) ((*1 *2 *3) (-12 (-5 *3 (-1051 *4 *5)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-638 (-638 (-1030 (-413 *4))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *4))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-322 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-138)) (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 *4)))))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| -4513 *3) (|:| -4518 *4)))) (-5 *1 (-731 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-722)))) ((*1 *2 *1) (-12 (-4 *1 (-1236 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-5 *2 (-1150 (-2 (|:| |k| *4) (|:| |c| *3))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-959 (-217))) (-5 *2 (-217)) (-5 *1 (-301))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 (-413 *3))) (-5 *1 (-175 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-457)) (-5 *2 (-638 (-2 (|:| |eigval| (-3 (-413 (-959 *4)) (-1159 (-1170) (-959 *4)))) (|:| |eigmult| (-769)) (|:| |eigvec| (-638 (-685 (-413 (-959 *4)))))))) (-5 *1 (-288 *4)) (-5 *3 (-685 (-413 (-959 *4))))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *3)))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)) (-4 *2 (-554)))) ((*1 *1 *1) (-4 *1 (-1063)))) 
-(((*1 *1 *1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-769))))) 
-(((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *6 (-1152)) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *1 *2 *3 *1) (-12 (-14 *4 (-638 (-1170))) (-4 *2 (-174)) (-4 *3 (-232 (-4032 *4) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *3)) (-2 (|:| -1763 *5) (|:| -3751 *3)))) (-5 *1 (-467 *4 *2 *5 *3 *6 *7)) (-4 *5 (-848)) (-4 *7 (-956 *2 *3 (-858 *4)))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 (-638 *2) *2 *2 *2)) (-4 *2 (-1098)) (-5 *1 (-106 *2)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1098)) (-5 *1 (-106 *2))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-330))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-554)) (-5 *1 (-161 *2))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *3)) (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) ((*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-841 (-385))) (-5 *2 (-841 (-217))) (-5 *1 (-301))))) 
-(((*1 *2 *2 *3 *3 *4) (-12 (-5 *3 (-769)) (-4 *2 (-13 (-562) (-457))) (-5 *1 (-349 *2 *4)) (-4 *4 (-52 *2 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1046))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-385))) (-5 *5 (-1152)) (-5 *6 (-638 (-258))) (-5 *2 (-1264)) (-5 *1 (-460)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-385))) (-5 *5 (-1152)) (-5 *2 (-1264)) (-5 *1 (-460)))) ((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-385))) (-5 *5 (-1152)) (-5 *6 (-638 (-258))) (-5 *2 (-1264)) (-5 *1 (-460)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-1090 (-385))) (-5 *5 (-1152)) (-5 *2 (-1264)) (-5 *1 (-460))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-442))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-353)) (-4 *4 (-329 *3)) (-4 *5 (-1234 *4)) (-5 *1 (-775 *3 *4 *5 *2 *6)) (-4 *2 (-1234 *5)) (-14 *6 (-923)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-4 *3 (-374)))) ((*1 *1 *1) (-12 (-4 *1 (-1276 *2)) (-4 *2 (-368)) (-4 *2 (-374))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-121)) (-5 *1 (-930 *4 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-121)) (-5 *1 (-930 *4 *5 *6 *7)) (-4 *7 (-956 *4 *6 *5))))) 
-(((*1 *1 *1) (-5 *1 (-1066)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-217)))) ((*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) ((*1 *1 *1) (-4 *1 (-554))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-595 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1098)) (-5 *2 (-1116)))) ((*1 *2 *1) (-12 (-5 *2 (-1116)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *3 *4) (-12 (-5 *2 (-2 (|:| |part1| *3) (|:| |part2| *4))) (-5 *1 (-701 *3 *4)) (-4 *3 (-1204)) (-4 *4 (-1204))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-644 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-209 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-638 *3)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-638 *3)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-769))) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-769))) (-5 *5 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-769)) (-5 *2 (-424 *3)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1014 *3)) (-4 *3 (-1234 (-413 (-572)))))) ((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-1223 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-1152)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *4 (-1068 *6 *7 *8)) (-5 *2 (-1264)) (-5 *1 (-774 *6 *7 *8 *4 *5)) (-4 *5 (-1073 *6 *7 *8 *4))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-385) (-385))) (-5 *4 (-385)) (-5 *2 (-2 (|:| -2148 *4) (|:| -3900 *4) (|:| |totalpts| (-572)) (|:| |success| (-121)))) (-5 *1 (-790)) (-5 *5 (-572))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 (-171 (-413 (-572))))) (-5 *2 (-638 (-2 (|:| |outval| (-171 *4)) (|:| |outmult| (-572)) (|:| |outvect| (-638 (-685 (-171 *4))))))) (-5 *1 (-762 *4)) (-4 *4 (-13 (-368) (-846)))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-1280 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-844))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-121)) (-5 *1 (-893 *4)) (-4 *4 (-1098))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-303)) (-4 *3 (-1000 *2)) (-4 *4 (-1234 *3)) (-5 *1 (-419 *2 *3 *4 *5)) (-4 *5 (-13 (-415 *3 *4) (-1044 *3)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 (-638 (-638 *4)))) (-5 *3 (-638 *4)) (-4 *4 (-848)) (-5 *1 (-1176 *4))))) 
-(((*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-13 (-368) (-151) (-1044 (-572)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-413 *6)) (|:| |h| *6) (|:| |c1| (-413 *6)) (|:| |c2| (-413 *6)) (|:| -3512 *6))) (-5 *1 (-1023 *5 *6)) (-5 *3 (-413 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-1264)) (-5 *1 (-454 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-151))) (-5 *1 (-546 *3 *2)) (-4 *2 (-1249 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-4 *4 (-1234 *3)) (-4 *5 (-720 *3 *4)) (-5 *1 (-550 *3 *4 *5 *2)) (-4 *2 (-1249 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-5 *1 (-551 *3 *2)) (-4 *2 (-1249 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-13 (-562) (-151))) (-5 *1 (-1145 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-5 *3 (-638 *7)) (-4 *1 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3))))) 
-(((*1 *2 *3 *3 *4 *5 *3 *3 *4 *4 *4 *6) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *1) (-5 *1 (-477)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (-572)))) (-4 *4 (-13 (-1234 *3) (-562) (-10 -8 (-15 -3069 ($ $ $))))) (-4 *3 (-562)) (-5 *1 (-1237 *3 *4))))) 
-(((*1 *2) (-12 (-4 *3 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-1264)) (-5 *1 (-439 *3 *4)) (-4 *4 (-436 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-173)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1098)) (-5 *2 (-1264)) (-5 *1 (-1211 *4)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1098)) (-5 *2 (-1264)) (-5 *1 (-1211 *4))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1152)) (-4 *1 (-369 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-1054)) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1280 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-844))))) 
-(((*1 *1 *2) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-685 (-413 (-959 (-572))))) (-5 *2 (-638 (-312 (-572)))) (-5 *1 (-1038))))) 
-(((*1 *2 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353))))) 
-(((*1 *2 *3 *3) (-12 (-4 *3 (-1214)) (-4 *5 (-1234 *3)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-121)) (-5 *1 (-341 *4 *3 *5 *6)) (-4 *4 (-342 *3 *5 *6)))) ((*1 *2 *3 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-858 *5))) (-14 *5 (-638 (-1170))) (-4 *6 (-457)) (-5 *2 (-638 (-638 (-244 *5 *6)))) (-5 *1 (-480 *5 *6 *7)) (-5 *3 (-638 (-244 *5 *6))) (-4 *7 (-457))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-33 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1166 *5)) (-4 *5 (-368)) (-5 *2 (-638 *6)) (-5 *1 (-539 *5 *6 *4)) (-4 *6 (-368)) (-4 *4 (-13 (-368) (-846)))))) 
-(((*1 *2 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-769)))) (-5 *1 (-905 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *2 (-638 *8)) (-5 *1 (-970 *4 *5 *6 *7 *8)) (-4 *8 (-978 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-186)))) ((*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-296)))) ((*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-217)))) (-5 *2 (-217)) (-5 *1 (-301))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-984 *4 *5 *6 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4)))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-326 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-793)) (-4 *3 (-174))))) 
-(((*1 *2 *3 *4 *4 *3 *3 *5) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-1166 *3)) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-568 *6 *3 *7)) (-4 *7 (-1098)))) ((*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-413 (-1166 *3))) (-4 *3 (-13 (-436 *6) (-27) (-1190))) (-4 *6 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-568 *6 *3 *7)) (-4 *7 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4602)) (-4 *1 (-155 *3)) (-4 *3 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-669 *3)) (-4 *3 (-1204)))) ((*1 *2 *1 *3) (|partial| -12 (-4 *1 (-1198 *4 *5 *3 *2)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *3 (-848)) (-4 *2 (-1068 *4 *5 *3)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *1 (-1202 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *1 *2) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-469))))) 
-(((*1 *1) (-5 *1 (-217))) ((*1 *1) (-5 *1 (-385)))) 
-(((*1 *1 *1) (-12 (-4 *1 (-669 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1170)) (-4 *5 (-613 (-893 (-572)))) (-4 *5 (-887 (-572))) (-4 *5 (-13 (-848) (-1044 (-572)) (-457) (-634 (-572)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-575 *5 *3)) (-4 *3 (-624)) (-4 *3 (-13 (-27) (-1190) (-436 *5)))))) 
-(((*1 *2 *2 *2 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-611 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1170))) (-4 *2 (-13 (-436 *5) (-27) (-1190))) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *1 (-574 *5 *2 *6)) (-4 *6 (-1098))))) 
-(((*1 *2 *3 *2) (-12 (-4 *1 (-788)) (-5 *2 (-1042)) (-5 *3 (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) ((*1 *2 *3 *2) (-12 (-4 *1 (-788)) (-5 *2 (-1042)) (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217))))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-175 *2)) (-4 *2 (-303)))) ((*1 *2 *1) (-12 (-5 *1 (-916 *2)) (-4 *2 (-303)))) ((*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)) (-4 *2 (-303)))) ((*1 *2 *1) (-12 (-4 *1 (-1063)) (-5 *2 (-572))))) 
-(((*1 *2 *3 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-3 *3 (-638 *1))) (-4 *1 (-1073 *4 *5 *6 *3))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1150 *4)) (-5 *3 (-1 (-638 *4) *4)) (-4 *4 (-1204)) (-5 *1 (-1146 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1100 *3)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-1100 *3)) (-5 *1 (-906 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *3 (-901 *5)) (-5 *2 (-1259 *3)) (-5 *1 (-687 *5 *3 *6 *4)) (-4 *6 (-379 *3)) (-4 *4 (-13 (-379 *5) (-10 -7 (-6 -4602))))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-368)) (-5 *1 (-653 *4 *2)) (-4 *2 (-650 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-825))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-303)))) ((*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-392 *3)) (|:| |rm| (-392 *3)))) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3043 (-769)) (|:| -2492 (-769)))) (-5 *1 (-769)))) ((*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-3 (-820 *3) "failed")) (|:| |rm| (-3 (-820 *3) "failed")))) (-5 *1 (-820 *3)) (-4 *3 (-848)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *1 (-590 *2)) (-4 *2 (-554))))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-820 *3)) (-4 *3 (-848)) (-5 *1 (-667 *3))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *7)) (-5 *4 (-1166 *7)) (-4 *5 (-1054)) (-4 *7 (-1054)) (-4 *2 (-1234 *5)) (-5 *1 (-514 *5 *2 *6 *7)) (-4 *6 (-1234 *2))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) ((*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-1174))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 G)))) (-5 *2 (-1042)) (-5 *1 (-746))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *6 (-13 (-562) (-848))) (-5 *2 (-638 (-312 *6))) (-5 *1 (-213 *5 *6)) (-5 *3 (-312 *6)) (-4 *5 (-1054)))) ((*1 *2 *1) (-12 (-5 *1 (-424 *2)) (-4 *2 (-562)))) ((*1 *2 *3) (-12 (-5 *3 (-589 *5)) (-4 *5 (-13 (-29 *4) (-1190))) (-4 *4 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-638 *5)) (-5 *1 (-587 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-589 (-413 (-959 *4)))) (-4 *4 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-638 (-312 *4))) (-5 *1 (-592 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *2)) (-4 *3 (-846)) (-4 *2 (-1142 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1093 *4 *2)) (-4 *4 (-846)) (-4 *2 (-1142 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190))))) ((*1 *2 *1) (-12 (-5 *2 (-1272 (-1170) *3)) (-5 *1 (-1279 *3)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-5 *2 (-1272 *3 *4)) (-5 *1 (-1281 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-848)) (-5 *2 (-638 (-638 *4))) (-5 *1 (-1176 *4)) (-5 *3 (-638 *4))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-562)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-1195 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1249 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-685 *7)) (-5 *3 (-638 *7)) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *1 (-930 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *3 (-237 *10)) (-4 *11 (-540 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *2 (-2 (|:| |num| (-638 *6)) (|:| |den| *6))) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-238 (-928 *5))) (-5 *4 (-769)) (-4 *5 (-353)) (-5 *2 (-638 (-413 (-244 *6 *5)))) (-5 *1 (-873 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-238 (-928 *4))) (-4 *4 (-353)) (-5 *2 (-2 (|:| |num| (-638 (-244 *5 *4))) (|:| |den| (-244 *5 *4)))) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-238 (-927 *5))) (-5 *4 (-769)) (-4 *5 (-368)) (-5 *2 (-638 (-413 (-244 *6 *5)))) (-5 *1 (-874 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-238 (-927 *4))) (-4 *4 (-368)) (-5 *2 (-2 (|:| |num| (-638 (-244 *5 *4))) (|:| |den| (-244 *5 *4)))) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-2 (|:| |adjMat| *3) (|:| |detMat| *4))) (-5 *1 (-684 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-174)) (-4 *2 (-1054)) (-5 *1 (-710 *2 *3)) (-4 *3 (-641 *2)))) ((*1 *1 *1) (-12 (-4 *2 (-174)) (-4 *2 (-1054)) (-5 *1 (-710 *2 *3)) (-4 *3 (-641 *2)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-174)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-174)) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *1 *1) (-4 *1 (-1063))) ((*1 *1 *1 *2 *2) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793))))) 
-(((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1137)) (-5 *3 (-148)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174))))) 
-(((*1 *1 *2 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-906 *3))) (-5 *1 (-905 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-413 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-13 (-368) (-151) (-1044 (-572)))) (-5 *1 (-576 *3 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-856))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *5 *5 *5 *3 *5 *5 *3 *6 *3 *3 *3) (-12 (-5 *5 (-685 (-217))) (-5 *6 (-685 (-572))) (-5 *3 (-572)) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1259 (-638 (-572)))) (-5 *1 (-495)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1204)) (-5 *1 (-602 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) ((*1 *1 *2 *3 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3))) ((*1 *1 *1 *1) (-12 (-5 *1 (-670 *2)) (-4 *2 (-1054)) (-4 *2 (-1098))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-567))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1170)) (-5 *3 (-385)) (-5 *1 (-1066))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-537 *3)) (-4 *3 (-13 (-722) (-25)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *6) (-12 (-5 *3 (-312 (-572))) (-5 *4 (-1 (-217) (-217))) (-5 *5 (-1092 (-217))) (-5 *6 (-638 (-258))) (-5 *2 (-1129 (-217))) (-5 *1 (-692))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-290 (-841 *3))) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-3 (-841 *3) (-2 (|:| |leftHandLimit| (-3 (-841 *3) "failed")) (|:| |rightHandLimit| (-3 (-841 *3) "failed"))) "failed")) (-5 *1 (-631 *5 *3)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-290 *3)) (-5 *5 (-1152)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-841 *3)) (-5 *1 (-631 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-290 (-841 (-959 *5)))) (-4 *5 (-457)) (-5 *2 (-3 (-841 (-413 (-959 *5))) (-2 (|:| |leftHandLimit| (-3 (-841 (-413 (-959 *5))) "failed")) (|:| |rightHandLimit| (-3 (-841 (-413 (-959 *5))) "failed"))) "failed")) (-5 *1 (-632 *5)) (-5 *3 (-413 (-959 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-290 (-413 (-959 *5)))) (-5 *3 (-413 (-959 *5))) (-4 *5 (-457)) (-5 *2 (-3 (-841 *3) (-2 (|:| |leftHandLimit| (-3 (-841 *3) "failed")) (|:| |rightHandLimit| (-3 (-841 *3) "failed"))) "failed")) (-5 *1 (-632 *5)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-290 (-413 (-959 *6)))) (-5 *5 (-1152)) (-5 *3 (-413 (-959 *6))) (-4 *6 (-457)) (-5 *2 (-841 *3)) (-5 *1 (-632 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-825))))) 
-(((*1 *1 *1) (-5 *1 (-217))) ((*1 *1 *1) (-5 *1 (-385))) ((*1 *1) (-5 *1 (-385)))) 
-(((*1 *2) (-12 (-4 *1 (-353)) (-5 *2 (-638 (-2 (|:| -4304 (-572)) (|:| -3751 (-572)))))))) 
-(((*1 *2) (-12 (-14 *4 (-769)) (-4 *5 (-1204)) (-5 *2 (-140)) (-5 *1 (-231 *3 *4 *5)) (-4 *3 (-232 *4 *5)))) ((*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-140)) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-396 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-174)))) ((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-572)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-848)) (-4 *4 (-368)) (-4 *5 (-794)) (-5 *2 (-572)) (-5 *1 (-518 *4 *5 *6 *7)) (-4 *7 (-956 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-988 *3)) (-4 *3 (-1054)) (-5 *2 (-923)))) ((*1 *2) (-12 (-4 *1 (-1266 *3)) (-4 *3 (-368)) (-5 *2 (-140))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-1259 (-694))) (-5 *1 (-301))))) 
-(((*1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *5 (-374)) (-5 *2 (-769))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1234 (-413 *2))) (-5 *2 (-572)) (-5 *1 (-915 *4 *3)) (-4 *3 (-1234 (-413 *4)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-258)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-476))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-959 (-413 (-572)))) (-5 *4 (-1170)) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-638 (-217))) (-5 *1 (-296))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 *4) (-769))))) (-5 *1 (-488 *4)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 *4) (-769)))) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 (-1170))) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) (-1170) *6)) (|:| C (-1 (-638 *5) (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 *3)) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) *3 *6)) (|:| C (-1 (-638 *5) (-769)))) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 HPSPEC) (-5 *1 (-492 *4)) (-14 *4 (-1170)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 HPSPEC (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3)))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-5 *2 (-638 (-2 (|:| C (-685 *5)) (|:| |g| (-1259 *5))))) (-5 *1 (-986 *5)) (-5 *3 (-685 *5)) (-5 *4 (-1259 *5))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-984 *4 *5 *6 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-1170)) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-638 (-217))) (-5 *1 (-186)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-1170)) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-638 (-217))) (-5 *1 (-296))))) 
-(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *2 (-769) (-769) *7)) (-5 *4 (-1259 *7)) (-5 *5 (-769)) (-5 *6 (-1259 (-1166 *2))) (-4 *7 (-52 *2 *5)) (-4 *2 (-13 (-562) (-457))) (-5 *1 (-349 *2 *7))))) 
-(((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-685 (-413 *4)))))) 
-(((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-638 (-611 *2))) (-5 *4 (-1170)) (-4 *2 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *5 *2))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -3069 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-5 *2 (-638 (-769))) (-5 *1 (-777 *3 *4 *5 *6 *7)) (-4 *3 (-1234 *6)) (-4 *7 (-956 *6 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-1098)) (-5 *1 (-972 *2 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-1150 (-2 (|:| |k| (-572)) (|:| |c| *6)))) (-5 *4 (-1033 (-841 (-572)))) (-5 *5 (-1170)) (-5 *7 (-413 (-572))) (-4 *6 (-1054)) (-5 *2 (-856)) (-5 *1 (-597 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-121) *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |goodPols| (-638 *8)) (|:| |badPols| (-638 *8)))) (-5 *1 (-985 *5 *6 *7 *8)) (-5 *4 (-638 *8))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-2 (|:| |totdeg| (-769)) (|:| -1805 *4))) (-5 *5 (-769)) (-4 *4 (-956 *6 *7 *8)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-5 *2 (-2 (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (-5 *1 (-454 *6 *7 *8 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *2 (-385)) (-5 *1 (-265)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *2 (-385)) (-5 *1 (-301))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-4 *2 (-1234 *4)) (-5 *1 (-924 *4 *2))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1218 *3))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *1 (-315)) (-5 *3 (-217))))) 
-(((*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-572)) (-4 *3 (-174)) (-4 *5 (-379 *3)) (-4 *6 (-379 *3)) (-5 *1 (-684 *3 *5 *6 *2)) (-4 *2 (-683 *3 *5 *6))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-1054)) (-4 *3 (-848)) (-5 *2 (-2 (|:| |val| *1) (|:| -3751 (-572)))) (-4 *1 (-436 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-893 *3)) (|:| -3751 (-893 *3)))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-2 (|:| |val| *3) (|:| -3751 (-572)))) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $)))))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-3 (-121) (-638 *1))) (-4 *1 (-1073 *4 *5 *6 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-638 *4)))) (-5 *2 (-638 (-638 *4))) (-5 *1 (-1176 *4)) (-4 *4 (-848))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) (-5 *1 (-258)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) ((*1 *2 *1 *3 *3 *4 *4 *4) (-12 (-5 *3 (-572)) (-5 *4 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) (-5 *2 (-1264)) (-5 *1 (-1261)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |theta| (-217)) (|:| |phi| (-217)) (|:| -1355 (-217)) (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |scaleZ| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)))) (-5 *1 (-1261)))) ((*1 *2 *1 *3 *3 *3 *3 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-133))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *1) (-5 *1 (-148))) ((*1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-846)) (-4 *4 (-368)) (-5 *2 (-769)) (-5 *1 (-952 *4 *5)) (-4 *5 (-1234 *4))))) 
-(((*1 *2 *3 *3 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-432 *4 *2)) (-4 *2 (-13 (-1190) (-29 *4))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-151)) (-4 *5 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *2 (-312 *5)) (-5 *1 (-592 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-385)) (-5 *2 (-217)) (-5 *1 (-1262)))) ((*1 *2) (-12 (-5 *2 (-217)) (-5 *1 (-1262))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *5))) (-5 *3 (-1166 *5)) (-4 *5 (-168 *4)) (-4 *4 (-554)) (-5 *1 (-153 *4 *5)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-353)) (-5 *1 (-362 *4 *5 *3)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 (-572)))) (-5 *3 (-1166 (-572))) (-5 *1 (-580)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-638 (-1166 *1))) (-5 *3 (-1166 *1)) (-4 *1 (-910))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-171 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1278 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-820 *3)))) ((*1 *2 *1) (-12 (-4 *2 (-844)) (-5 *1 (-1280 *3 *2)) (-4 *3 (-1054))))) 
-(((*1 *1) (-5 *1 (-443)))) 
-(((*1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-14 *6 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *2)) (-2 (|:| -1763 *5) (|:| -3751 *2)))) (-4 *2 (-232 (-4032 *3) (-769))) (-5 *1 (-467 *3 *4 *5 *2 *6 *7)) (-4 *5 (-848)) (-4 *7 (-956 *4 *2 (-858 *3)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *1 (-342 *4 *5 *6)) (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-2 (|:| |num| (-685 *5)) (|:| |den| *5)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-260 *12)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 *7)) (-4 *7 (-956 *5 *8 (-858 *6))) (-4 *8 (-232 (-4032 *6) (-769))) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *9 (-978 *5)) (-4 *10 (-645 *5)) (-4 *11 (-926 *5 *10)) (-4 *12 (-237 *11)) (-4 *13 (-540 *5 *6 *7 *8 *9 *10 *11 *12 *14)) (-4 *14 (-117)) (-5 *2 (-1264)) (-5 *1 (-262 *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (-4 *3 (-260 *13))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-385))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-1054)) (-5 *2 (-1259 *4)) (-5 *1 (-1171 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-5 *2 (-1259 *3)) (-5 *1 (-1171 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-123)) (-5 *4 (-1170)) (-4 *5 (-13 (-848) (-562) (-613 (-545)))) (-4 *2 (-436 *5)) (-5 *1 (-314 *5 *2 *6 *7)) (-4 *6 (-1249 *2)) (-4 *7 (-1249 (-1164 *2)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-866)) (-5 *1 (-861 *3)) (-14 *3 *2)))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-638 (-258))) (-5 *1 (-256))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *2 *3 *4 *5 *6 *7 *8 *9 *10)) (-4 *4 (-956 *2 *5 (-858 *3))) (-4 *5 (-232 (-4032 *3) (-769))) (-4 *6 (-978 *2)) (-4 *7 (-645 *2)) (-4 *8 (-926 *2 *7)) (-4 *9 (-237 *8)) (-4 *10 (-117)) (-4 *2 (-368))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-679 *4 *5 *6)) (-4 *4 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))))) ((*1 *2) (|partial| -12 (-4 *4 (-1214)) (-4 *5 (-1234 (-413 *2))) (-4 *2 (-1234 *4)) (-5 *1 (-341 *3 *4 *2 *5)) (-4 *3 (-342 *4 *2 *5)))) ((*1 *2) (|partial| -12 (-4 *1 (-342 *3 *2 *4)) (-4 *3 (-1214)) (-4 *4 (-1234 (-413 *2))) (-4 *2 (-1234 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-214 *3)))) ((*1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-4 *1 (-249 *3)))) ((*1 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-457)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-400)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 (-413 (-572)))) (-5 *2 (-638 *4)) (-5 *1 (-779 *4)) (-4 *4 (-13 (-368) (-846)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3 *3 *2 *4) (-12 (-5 *3 (-685 *2)) (-5 *4 (-572)) (-4 *2 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *5 (-1234 *2)) (-5 *1 (-512 *2 *5 *6)) (-4 *6 (-415 *2 *5))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-290 (-834 *3))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-834 *3)) (-5 *1 (-631 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-290 (-834 (-959 *5)))) (-4 *5 (-457)) (-5 *2 (-834 (-413 (-959 *5)))) (-5 *1 (-632 *5)) (-5 *3 (-413 (-959 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-290 (-413 (-959 *5)))) (-5 *3 (-413 (-959 *5))) (-4 *5 (-457)) (-5 *2 (-834 *3)) (-5 *1 (-632 *5))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-669 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-895 *2 *3)) (-4 *2 (-1234 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-217)) (-5 *1 (-30)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-424 *4) *4)) (-4 *4 (-562)) (-5 *2 (-424 *4)) (-5 *1 (-425 *4)))) ((*1 *1 *1) (-5 *1 (-932))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-932)))) ((*1 *1 *1) (-5 *1 (-933))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *4 (-413 (-572))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *4 (-413 (-572))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 (-413 (-572)))))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-1098)) (-5 *1 (-96 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-1098)) (-5 *1 (-214 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-848)) (-5 *1 (-498 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| *1 (-6 -4603)) (-4 *1 (-503 *3)) (-4 *3 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-1098)) (-5 *1 (-1007 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4603)) (-4 *3 (-1098)) (-5 *1 (-1140 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-846)) (-5 *2 (-572)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-906 *3)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1070 *4 *3)) (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-572)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-562) (-848) (-1044 *2) (-634 *2) (-457))) (-5 *2 (-572)) (-5 *1 (-1113 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-841 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 *2) (-634 *2) (-457))) (-5 *2 (-572)) (-5 *1 (-1113 *6 *3)))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-1152)) (-4 *6 (-13 (-562) (-848) (-1044 *2) (-634 *2) (-457))) (-5 *2 (-572)) (-5 *1 (-1113 *6 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-457)) (-5 *2 (-572)) (-5 *1 (-1114 *4)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-841 (-413 (-959 *6)))) (-5 *3 (-413 (-959 *6))) (-4 *6 (-457)) (-5 *2 (-572)) (-5 *1 (-1114 *6)))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-413 (-959 *6))) (-5 *4 (-1170)) (-5 *5 (-1152)) (-4 *6 (-457)) (-5 *2 (-572)) (-5 *1 (-1114 *6)))) ((*1 *2 *3) (|partial| -12 (-5 *2 (-572)) (-5 *1 (-1187 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-572))) (-5 *1 (-1052))))) 
-(((*1 *2 *1 *3 *3) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-605 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1204)) (-5 *2 (-1264))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1142 *3)) (-4 *3 (-1204)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-477)) (-5 *4 (-923)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-572)) (-5 *1 (-1187 *4)) (-4 *4 (-1054))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-175 *2)) (-4 *2 (-303)))) ((*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572)))) ((*1 *1 *1) (-12 (-4 *1 (-669 *2)) (-4 *2 (-1204)))) ((*1 *1 *1) (-4 *1 (-869 *2))) ((*1 *1 *1) (-12 (-4 *1 (-981 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *4 (-848))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-335 *3 *4 *5 *6)) (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 *3 *4 *5)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-540 *4 *5 *3 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *9)) (-5 *1 (-471 *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-638 *13)) (-5 *5 (-638 *9)) (-4 *9 (-978 *6)) (-4 *13 (-260 *12)) (-4 *6 (-368)) (-4 *12 (-540 *6 *7 *3 *8 *9 *10 *11 *2 *14)) (-4 *14 (-117)) (-14 *7 (-638 (-1170))) (-4 *3 (-956 *6 *8 (-858 *7))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *10 (-645 *6)) (-4 *11 (-926 *6 *10)) (-4 *2 (-237 *11)) (-5 *1 (-560 *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14)))) ((*1 *2 *3) (-12 (-5 *3 (-244 *5 *4)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-5 *2 (-238 (-928 *4))) (-5 *1 (-873 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-244 *5 *4)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *2 (-238 (-927 *4))) (-5 *1 (-874 *4 *5 *6)) (-4 *6 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-1264)) (-5 *1 (-468))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-856) (-856))) (-5 *1 (-123)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-856) (-638 (-856)))) (-5 *1 (-123)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-856) (-638 (-856)))) (-5 *1 (-123)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-207 *3)) (-4 *3 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 (*2 $)) (-15 -3735 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-400)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-400)))) ((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-504)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-515)))) ((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-706)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1185)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-1185))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-457)) (-5 *2 (-121)) (-5 *1 (-365 *4 *5)) (-14 *5 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-781 *4 (-858 *5)))) (-4 *4 (-457)) (-14 *5 (-638 (-1170))) (-5 *2 (-121)) (-5 *1 (-623 *4 *5))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-638 (-959 *4))) (-5 *3 (-638 (-1170))) (-4 *4 (-457)) (-5 *1 (-920 *4))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1166 *7)) (-5 *3 (-572)) (-4 *7 (-956 *6 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-5 *1 (-320 *4 *5 *6 *7))))) 
-(((*1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-442))))) 
-(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1091 *3)) (-4 *3 (-1204)) (-5 *2 (-572))))) 
-(((*1 *1 *1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *3 (-562))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-173)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)) (-4 *5 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *3)) (-5 *1 (-985 *4 *5 *6 *3)) (-4 *3 (-1068 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-645 *3)) (-4 *8 (-926 *3 *7)) (-4 *9 (-237 *8)) (-4 *10 (-117)) (-4 *2 (-978 *3))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1019)) (-5 *2 (-856))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-424 *4)) (-4 *4 (-562))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -2667 (-769)) (|:| |eqns| (-638 (-2 (|:| |det| *7) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (|:| |fgb| (-638 *7))))) (-4 *7 (-956 *4 *6 *5)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-769)) (-5 *1 (-930 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-1200 *2)) (-4 *2 (-982))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1091 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-130))) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-1051 *5 *6))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-1051 *4 *5))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-5 *1 (-1177 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *1 *1 *2) (-12 (-5 *1 (-1133 *3 *2)) (-4 *3 (-13 (-1098) (-39))) (-4 *2 (-13 (-1098) (-39)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *3 (-237 *10)) (-4 *11 (-540 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-5 *1 (-566 *4 *5 *6 *7 *8 *9 *10 *3)) (-4 *8 (-978 *4)) (-4 *3 (-237 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-238 (-928 *5))) (-5 *4 (-638 (-244 *6 *5))) (-4 *5 (-353)) (-14 *6 (-638 (-1170))) (-5 *2 (-638 (-244 *6 (-863 *5)))) (-5 *1 (-873 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-638 (-244 *5 *4))) (-5 *3 (-238 (-927 *4))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *1 (-874 *4 *5 *6)) (-4 *6 (-117))))) 
-(((*1 *2 *3 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-1173)) (-5 *3 (-1170))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *4 (-1170)) (-4 *6 (-1054)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *2 (-2 (|:| -4238 (-3 (-572) "failed")) (|:| -3306 (-3 (-572) "failed")) (|:| |ker| (-611 *5)))) (-5 *1 (-1031 *6 *5)) (-4 *5 (-13 (-436 *6) (-23) (-1044 (-572)) (-1044 *4) (-901 *4) (-162)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1065)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1065))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *4 (-572))) (-5 *5 (-1 (-1150 *4))) (-4 *4 (-368)) (-4 *4 (-1054)) (-5 *2 (-1150 *4)) (-5 *1 (-1154 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1166 *3)) (-4 *3 (-1054)) (-4 *1 (-1234 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3 *2 *4) (|partial| -12 (-5 *4 (-1 (-3 (-572) "failed") *5)) (-4 *5 (-1054)) (-5 *2 (-572)) (-5 *1 (-552 *5 *3)) (-4 *3 (-1234 *5)))) ((*1 *2 *3 *4 *2 *5) (|partial| -12 (-5 *5 (-1 (-3 (-572) "failed") *4)) (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-552 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-572) "failed") *4)) (-4 *4 (-1054)) (-5 *2 (-572)) (-5 *1 (-552 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *5 (-1214)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-5 *2 (-638 (-959 *5))) (-5 *1 (-341 *4 *5 *6 *7)) (-4 *4 (-342 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *1 (-342 *4 *5 *6)) (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-4 *4 (-368)) (-5 *2 (-638 (-959 *4)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054))))) 
-(((*1 *1) (-4 *1 (-23))) ((*1 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) ((*1 *1) (-5 *1 (-545))) ((*1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-368)) (-5 *1 (-657 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-839)) (-5 *4 (-1066)) (-5 *2 (-1042)) (-5 *1 (-838)))) ((*1 *2 *3) (-12 (-5 *3 (-839)) (-5 *2 (-1042)) (-5 *1 (-838)))) ((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-638 (-385))) (-5 *5 (-638 (-841 (-385)))) (-5 *6 (-638 (-312 (-385)))) (-5 *3 (-312 (-385))) (-5 *2 (-1042)) (-5 *1 (-838)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-385))) (-5 *5 (-638 (-841 (-385)))) (-5 *2 (-1042)) (-5 *1 (-838)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-312 (-385))) (-5 *4 (-638 (-385))) (-5 *2 (-1042)) (-5 *1 (-838)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-312 (-385)))) (-5 *4 (-638 (-385))) (-5 *2 (-1042)) (-5 *1 (-838))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-769)) (-4 *5 (-368)) (-5 *2 (-175 *6)) (-5 *1 (-867 *5 *4 *6)) (-4 *4 (-1249 *5)) (-4 *6 (-1234 *5))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-303)) (-4 *6 (-379 *5)) (-4 *4 (-379 *5)) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2237 (-638 *4)))) (-5 *1 (-1120 *5 *6 *4 *3)) (-4 *3 (-683 *5 *6 *4))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-173)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-4 *2 (-1234 *4)) (-5 *1 (-808 *4 *2 *3 *5)) (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-650 *2)) (-4 *5 (-650 (-413 *2))))) ((*1 *2 *3 *4) (-12 (-4 *2 (-1234 *4)) (-5 *1 (-808 *4 *2 *5 *3)) (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-650 *2)) (-4 *3 (-650 (-413 *2)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2307 *1))) (-4 *1 (-850 *3))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-609 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-638 *4)) (-4 *4 (-368)) (-5 *2 (-1259 *4)) (-5 *1 (-815 *4 *3)) (-4 *3 (-650 *4))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-1170))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1166 *3)) (-4 *3 (-374)) (-4 *1 (-329 *3)) (-4 *3 (-368))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-1054)) (-4 *2 (-1234 *5)) (-5 *1 (-1252 *5 *2 *6 *3)) (-4 *6 (-650 *2)) (-4 *3 (-1249 *5))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-232 *6 *2)) (-14 *6 *2) (-5 *2 (-769)) (-5 *1 (-914 *4 *3 *5 *6)) (-4 *3 (-326 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-956 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-769))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-353)) (-5 *2 (-638 *3)) (-5 *1 (-346 *5 *3)) (-4 *3 (-1234 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-353)) (-5 *2 (-638 *3)) (-5 *1 (-347 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-979)) (-5 *1 (-906 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-893 *4)) (-4 *4 (-1098)) (-5 *1 (-890 *4 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *2) (-12 (-5 *1 (-675 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1166 *9)) (-5 *4 (-638 *7)) (-5 *5 (-638 *8)) (-4 *7 (-848)) (-4 *8 (-1054)) (-4 *9 (-956 *8 *6 *7)) (-4 *6 (-794)) (-5 *2 (-1166 *8)) (-5 *1 (-320 *6 *7 *8 *9))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1170)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-996 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1105 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *2 *3) (-12 (-5 *1 (-675 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1074 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-372 *2)) (-4 *2 (-174))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-1166 (-959 *4))) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) ((*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-4 *3 (-368)) (-5 *2 (-1166 (-959 *3))))) ((*1 *2) (-12 (-5 *2 (-1166 (-413 (-959 *3)))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *1)))) (-4 *1 (-1073 *4 *5 *6 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-436 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-956 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-638 *3)) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $)))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-638 (-1170))) (-4 *6 (-368)) (-5 *2 (-638 (-290 (-959 *6)))) (-5 *1 (-547 *5 *6 *7)) (-4 *5 (-457)) (-4 *7 (-13 (-368) (-846)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *2 (-1042)) (-5 *1 (-301))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-638 *7)) (|:| -1337 *8))) (-4 *7 (-1068 *4 *5 *6)) (-4 *8 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-638 *7)) (|:| -1337 *8))) (-4 *7 (-1068 *4 *5 *6)) (-4 *8 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-477)) (-5 *3 (-638 (-258))) (-5 *1 (-1260)))) ((*1 *1 *1) (-5 *1 (-1260)))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-368)) (-5 *1 (-657 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1092 (-841 (-385)))) (-5 *2 (-1092 (-841 (-217)))) (-5 *1 (-301))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-21)) (-4 *2 (-1204))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-290 *3))) (-5 *1 (-290 *3)) (-4 *3 (-562)) (-4 *3 (-1204))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-151))) (-5 *1 (-546 *3 *2)) (-4 *2 (-1249 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-4 *4 (-1234 *3)) (-4 *5 (-720 *3 *4)) (-5 *1 (-550 *3 *4 *5 *2)) (-4 *2 (-1249 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-368) (-374) (-613 (-572)))) (-5 *1 (-551 *3 *2)) (-4 *2 (-1249 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-13 (-562) (-151))) (-5 *1 (-1145 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-3 (-1166 *4) (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116))))))) (-5 *1 (-350 *4)) (-4 *4 (-353))))) 
-(((*1 *2 *2 *1) (-12 (-5 *2 (-638 *6)) (-4 *1 (-984 *3 *4 *5 *6)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-424 *6)) (-4 *6 (-1234 *5)) (-4 *5 (-1054)) (-5 *2 (-638 *6)) (-5 *1 (-449 *5 *6))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-496 *3 *4))) (-14 *3 (-638 (-1170))) (-4 *4 (-457)) (-5 *1 (-626 *3 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769)))) (-638 *4) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *4 (-572)))) (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3)))) 
-(((*1 *2) (-12 (-5 *2 (-1259 (-638 (-2 (|:| -2148 (-911 *3)) (|:| -1763 (-1116)))))) (-5 *1 (-355 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) ((*1 *2) (-12 (-5 *2 (-1259 (-638 (-2 (|:| -2148 *3) (|:| -1763 (-1116)))))) (-5 *1 (-356 *3 *4)) (-4 *3 (-353)) (-14 *4 (-3 (-1166 *3) *2)))) ((*1 *2) (-12 (-5 *2 (-1259 (-638 (-2 (|:| -2148 *3) (|:| -1763 (-1116)))))) (-5 *1 (-357 *3 *4)) (-4 *3 (-353)) (-14 *4 (-923))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-638 *7)) (|:| |badPols| (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-611 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4))) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *4 *2))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-956 *4 *5 *6)) (-4 *4 (-368)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-455 *4 *5 *6 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-101 *6)) (-5 *5 (-1 *6 *6)) (-4 *6 (-368)) (-5 *2 (-2 (|:| R (-685 *6)) (|:| A (-685 *6)) (|:| |Ainv| (-685 *6)))) (-5 *1 (-986 *6)) (-5 *3 (-685 *6))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-562)) (-4 *7 (-956 *3 *5 *6)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *8) (|:| |radicand| *8))) (-5 *1 (-960 *5 *6 *3 *7 *8)) (-5 *4 (-769)) (-4 *8 (-13 (-368) (-10 -8 (-15 -4487 (*7 $)) (-15 -4492 (*7 $)) (-15 -3972 ($ *7)))))))) 
-(((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *6 (-1152)) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) ((*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) ((*1 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-374)) (-4 *2 (-368)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-335 *3 *4 *5 *2)) (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *2 (-342 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-396 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-174)))) ((*1 *1) (-12 (-4 *2 (-174)) (-4 *1 (-720 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-645 *3)) (-4 *3 (-368)) (-5 *2 (-572))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-848)) (-5 *2 (-638 (-660 *4 *5))) (-5 *1 (-622 *4 *5 *6)) (-4 *5 (-13 (-174) (-713 (-413 (-572))))) (-14 *6 (-923))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-611 *5))) (-4 *4 (-848)) (-5 *2 (-611 *5)) (-5 *1 (-581 *4 *5)) (-4 *5 (-436 *4))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-638 *1)) (-4 *1 (-1130 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 (-1150 *4) (-1150 *4))) (-5 *2 (-1150 *4)) (-5 *1 (-1282 *4)) (-4 *4 (-1204)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-638 (-1150 *5)) (-638 (-1150 *5)))) (-5 *4 (-572)) (-5 *2 (-638 (-1150 *5))) (-5 *1 (-1282 *5)) (-4 *5 (-1204))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-996 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-1105 *3 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2119 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-171 (-217))) (-5 *5 (-572)) (-5 *6 (-1152)) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-756))))) 
-(((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-611 *4)) (-4 *4 (-848)) (-4 *2 (-848)) (-5 *1 (-610 *2 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-984 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *5 (-1068 *3 *4 *2))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *8 (-978 *5)) (-4 *9 (-645 *5)) (-4 *10 (-926 *5 *9)) (-4 *11 (-540 *5 *6 *3 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-237 *10)) (-5 *1 (-262 *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (-4 *4 (-260 *11))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-381 *4 *2)) (-4 *2 (-13 (-379 *4) (-10 -7 (-6 -4603))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 "skip" "MonteCarlo" "deterministic")) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 "skip" "MonteCarlo" "deterministic")) (-5 *1 (-469)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 (-2 (|:| -4304 (-1166 *6)) (|:| -3751 (-572))))) (-4 *6 (-303)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-738 *4 *5 *6 *7)) (-4 *7 (-956 *6 *4 *5)))) ((*1 *1 *1) (-12 (-4 *1 (-1130 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 *1)) (-5 *4 (-1259 *1)) (-4 *1 (-634 *5)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -1369 (-685 *5)) (|:| |vec| (-1259 *5)))))) ((*1 *2 *3) (-12 (-5 *3 (-685 *1)) (-4 *1 (-634 *4)) (-4 *4 (-1054)) (-5 *2 (-685 *4))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385))))))) (-5 *1 (-804))))) 
-(((*1 *2) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-537 *3)) (-4 *3 (-13 (-722) (-25)))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-704 *3)) (-5 *1 (-828 *2 *3)) (-4 *3 (-1054))))) 
-(((*1 *1 *1) (|partial| -12 (-5 *1 (-290 *2)) (-4 *2 (-722)) (-4 *2 (-1204))))) 
-(((*1 *1) (-4 *1 (-353)))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-1259 *3)) (-5 *1 (-708 *3 *4)) (-4 *4 (-1234 *3))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-979))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |gen| *3) (|:| -4179 *4)))) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-1098)) (-4 *4 (-23)) (-14 *5 *4)))) 
-(((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1170))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-312 *3)) (-4 *3 (-562)) (-4 *3 (-848))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-368)) (-5 *1 (-533 *2 *4 *5 *3)) (-4 *3 (-683 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (|has| *2 (-6 (-4604 "*"))) (-4 *2 (-1054)))) ((*1 *2 *3) (-12 (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-174)) (-5 *1 (-684 *2 *4 *5 *3)) (-4 *3 (-683 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)) (|has| *2 (-6 (-4604 "*"))) (-4 *2 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-261 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-312 (-385))) (-5 *1 (-301))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) ((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-413 *1)) (-4 *1 (-1234 *3)) (-4 *3 (-1054)) (-4 *3 (-562)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-562))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-1092 (-217))) (-5 *2 (-933)) (-5 *1 (-931 *3)) (-4 *3 (-613 (-545))))) ((*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-1092 (-217))) (-5 *2 (-933)) (-5 *1 (-931 *3)) (-4 *3 (-613 (-545))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-932)))) ((*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-932)))) ((*1 *1 *2 *2 *2 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-932)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *1 *2 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *1 *2 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-638 (-1 (-217) (-217)))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-638 (-1 (-217) (-217)))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-217) (-217))) (-5 *3 (-1092 (-217))) (-5 *1 (-933))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-1150 (-959 *4)) (-1150 (-959 *4)))) (-5 *1 (-1267 *4)) (-4 *4 (-368))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-168 *2)) (-4 *2 (-174)) (-4 *2 (-1063)))) ((*1 *1 *1) (-12 (-5 *1 (-339 *2 *3 *4)) (-14 *2 (-638 (-1170))) (-14 *3 (-638 (-1170))) (-4 *4 (-393)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174)) (-4 *2 (-1063)))) ((*1 *1 *1) (-4 *1 (-846))) ((*1 *2 *1) (-12 (-4 *1 (-1004 *2)) (-4 *2 (-174)) (-4 *2 (-1063)))) ((*1 *1 *1) (-4 *1 (-1063))) ((*1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-638 *1)) (-4 *1 (-926 *3 *4))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-638 (-638 *3))))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-5 *2 (-638 (-638 *5))))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-638 *3))) (-5 *1 (-1177 *3)) (-4 *3 (-1098))))) 
-(((*1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-1150 (-959 *4)) (-1150 (-959 *4)))) (-5 *1 (-1267 *4)) (-4 *4 (-368))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-457)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-572)) (-5 *1 (-1112 *4 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-916 *2)) (-4 *2 (-303))))) 
-(((*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-638 (-2 (|:| |func| *2) (|:| |pole| (-121))))) (-4 *2 (-13 (-436 *4) (-1009))) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-274 *4 *2))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-275 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-923)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-258))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1102)) (-5 *1 (-330))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-173)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1200 *3)) (-4 *3 (-982))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))) (-5 *2 (-638 (-1152))) (-5 *1 (-265))))) 
-(((*1 *2 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4513 *3) (|:| |gap| (-769)) (|:| -3043 (-783 *3)) (|:| -2492 (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-1054)))) ((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-2 (|:| -4513 *1) (|:| |gap| (-769)) (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1068 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -4513 *1) (|:| |gap| (-769)) (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1068 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) ((*1 *2 *3 *1 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *1 (-1198 *5 *6 *7 *3)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-822))))) 
-(((*1 *2 *3 *3 *4 *5 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1259 *4)) (-4 *4 (-423 *3)) (-4 *3 (-303)) (-4 *3 (-562)) (-5 *1 (-48 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-368)) (-5 *2 (-1259 *1)) (-4 *1 (-329 *4)))) ((*1 *2) (-12 (-4 *3 (-368)) (-5 *2 (-1259 *1)) (-4 *1 (-329 *3)))) ((*1 *2) (-12 (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-1259 *1)) (-4 *1 (-415 *3 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-303)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-1259 *6)) (-5 *1 (-419 *3 *4 *5 *6)) (-4 *6 (-13 (-415 *4 *5) (-1044 *4))))) ((*1 *2 *1) (-12 (-4 *3 (-303)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-1259 *6)) (-5 *1 (-420 *3 *4 *5 *6 *7)) (-4 *6 (-415 *4 *5)) (-14 *7 *2))) ((*1 *2) (-12 (-4 *3 (-174)) (-5 *2 (-1259 *1)) (-4 *1 (-423 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 (-1259 *4))) (-5 *1 (-536 *4)) (-4 *4 (-353))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-303)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-2 (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (-5 *1 (-1120 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6))))) 
-(((*1 *1 *1 *1) (-4 *1 (-655))) ((*1 *1 *1 *1) (-5 *1 (-1116)))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2) (-12 (-5 *2 (-638 *3)) (-5 *1 (-1050 *3)) (-4 *3 (-368))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-252))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |mval| (-685 *3)) (|:| |invmval| (-685 *3)) (|:| |genIdeal| (-518 *3 *4 *5 *6)))) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-4 *3 (-1234 (-413 (-572)))) (-5 *2 (-2 (|:| |den| (-572)) (|:| |gcdnum| (-572)))) (-5 *1 (-915 *3 *4)) (-4 *4 (-1234 (-413 *3))))) ((*1 *2 *3) (-12 (-4 *4 (-1234 (-413 *2))) (-5 *2 (-572)) (-5 *1 (-915 *4 *3)) (-4 *3 (-1234 (-413 *4)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875))))) 
-(((*1 *2 *3 *3 *4 *5 *5 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *1 *1 *1) (-4 *1 (-655))) ((*1 *1 *1 *1) (-5 *1 (-1116)))) 
-(((*1 *1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-242 *3))))) 
-(((*1 *2 *3 *4 *4 *5 *3 *6) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-638 *3)) (-5 *6 (-1166 *3)) (-4 *3 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-568 *7 *3 *8)) (-4 *8 (-1098)))) ((*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| -12 (-5 *4 (-611 *3)) (-5 *5 (-638 *3)) (-5 *6 (-413 (-1166 *3))) (-4 *3 (-13 (-436 *7) (-27) (-1190))) (-4 *7 (-13 (-457) (-1044 (-572)) (-848) (-151) (-634 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-568 *7 *3 *8)) (-4 *8 (-1098))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-996 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-638 *7)) (-4 *7 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *1 (-1105 *3 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (-12 (-5 *4 (-572)) (-5 *6 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-572)) (-5 *1 (-236)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-572)) (-5 *1 (-236))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-923)) (-5 *2 (-121)) (-5 *1 (-235 *4)) (-4 *4 (-1054))))) 
-(((*1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-4 *5 (-232 (-4032 *3) (-769))) (-14 *6 (-1 (-121) (-2 (|:| -1763 *2) (|:| -3751 *5)) (-2 (|:| -1763 *2) (|:| -3751 *5)))) (-4 *2 (-848)) (-5 *1 (-467 *3 *4 *2 *5 *6 *7)) (-4 *7 (-956 *4 *5 (-858 *3)))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *3 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *3 (-848)) (-4 *6 (-1068 *4 *5 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *1) (-4 *1 (-23))) ((*1 *1) (-4 *1 (-39))) ((*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) ((*1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *1) (-4 *1 (-722))) ((*1 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) ((*1 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) ((*1 *1) (-5 *1 (-1170)))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *1) (-4 *1 (-303))) ((*1 *1 *1 *1) (-5 *1 (-769))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-567))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1102)) (-5 *1 (-1174))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1204)) (-5 *2 (-638 *1)) (-4 *1 (-1017 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-638 *10)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-923)) (-5 *5 (-638 *9)) (-4 *9 (-978 *6)) (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *4 (-956 *6 *8 (-858 *7))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *10 (-645 *6)) (-4 *11 (-926 *6 *10)) (-4 *12 (-237 *11)) (-4 *13 (-540 *6 *7 *4 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-5 *2 (-1264)) (-5 *1 (-560 *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (-4 *14 (-260 *13)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-638 (-928 *4))) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-638 (-927 *4))) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-685 *4)) (-5 *3 (-923)) (-4 *4 (-1054)) (-5 *1 (-1035 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-638 (-685 *4))) (-5 *3 (-923)) (-4 *4 (-1054)) (-5 *1 (-1035 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-5 *2 (-638 (-1170))) (-5 *1 (-204)) (-5 *3 (-1170)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-769)) (-5 *2 (-638 (-1170))) (-5 *1 (-265)))) ((*1 *2 *1) (-12 (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-820 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-638 *3)) (-5 *1 (-894 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-638 *3))))) 
-(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *1 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190)))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-850 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-562)) (-4 *5 (-1054)) (-5 *2 (-2 (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-851 *5 *3)) (-4 *3 (-850 *5))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-121) *6 *6)) (-4 *6 (-848)) (-5 *4 (-638 *6)) (-5 *2 (-2 (|:| |fs| (-121)) (|:| |sd| *4) (|:| |td| (-638 *4)))) (-5 *1 (-1176 *6)) (-5 *5 (-638 *4))))) 
-(((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *7)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-5 *2 (-638 (-974 *3))) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-638 (-973 *3))) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *2 (-638 *7)) (-5 *1 (-970 *4 *5 *3 *6 *7)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *7 (-978 *4))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-769)) (-4 *2 (-562)) (-5 *1 (-977 *2 *4)) (-4 *4 (-1234 *2))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-1128 *4 *2)) (-4 *2 (-13 (-605 (-572) *4) (-10 -7 (-6 -4602) (-6 -4603)))))) ((*1 *2 *2) (-12 (-4 *3 (-848)) (-4 *3 (-1204)) (-5 *1 (-1128 *3 *2)) (-4 *2 (-13 (-605 (-572) *3) (-10 -7 (-6 -4602) (-6 -4603))))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-893 *4)) (-4 *4 (-1098)) (-5 *1 (-891 *4 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-57)) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1 *1) (-4 *1 (-303))) ((*1 *1 *1 *1) (-5 *1 (-769))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-745))))) 
-(((*1 *2 *2 *3 *3) (|partial| -12 (-5 *3 (-1170)) (-4 *4 (-13 (-303) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-583 *4 *2)) (-4 *2 (-13 (-1190) (-966) (-1132) (-29 *4)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))) (-5 *4 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))) (-5 *4 (-413 (-572))))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-413 (-572))) (-5 *2 (-638 (-2 (|:| -1866 *5) (|:| -1862 *5)))) (-5 *1 (-1026 *3)) (-4 *3 (-1234 (-572))) (-5 *4 (-2 (|:| -1866 *5) (|:| -1862 *5))))) ((*1 *2 *3) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 (-413 (-572)))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 (-413 (-572)))) (-5 *4 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572))))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-413 (-572))) (-5 *2 (-638 (-2 (|:| -1866 *4) (|:| -1862 *4)))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-413 (-572))) (-5 *2 (-638 (-2 (|:| -1866 *5) (|:| -1862 *5)))) (-5 *1 (-1027 *3)) (-4 *3 (-1234 *5)) (-5 *4 (-2 (|:| -1866 *5) (|:| -1862 *5)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-2 (|:| -4273 (-1150 *4)) (|:| -4278 (-1150 *4)))) (-5 *1 (-1156 *4)) (-5 *3 (-1150 *4))))) 
-(((*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-769)) (-5 *4 (-923)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-769)) (-5 *4 (-923)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *5) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-69 -3313)))) (-5 *2 (-1042)) (-5 *1 (-744))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-217))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-769)) (-5 *1 (-454 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1259 *5)) (-4 *5 (-793)) (-5 *2 (-121)) (-5 *1 (-843 *4 *5)) (-14 *4 (-769))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *6))) (-5 *4 (-638 (-1170))) (-4 *6 (-13 (-562) (-1044 *5))) (-4 *5 (-562)) (-5 *2 (-638 (-638 (-290 (-413 (-959 *6)))))) (-5 *1 (-1045 *5 *6))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1137)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3))))) 
-(((*1 *2 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-86 FCN)))) (-5 *2 (-1042)) (-5 *1 (-744))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-697 *4 *5 *6 *7)) (-4 *4 (-613 (-545))) (-4 *5 (-1204)) (-4 *6 (-1204)) (-4 *7 (-1204))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-1259 *6)) (-5 *1 (-336 *3 *4 *5 *6)) (-4 *6 (-342 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-4 *2 (-368)) (-4 *2 (-846)) (-5 *1 (-952 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1046))))) 
-(((*1 *2) (-12 (-4 *3 (-174)) (-5 *2 (-1259 *1)) (-4 *1 (-372 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-215 *2 *3)) (-4 *2 (-13 (-1054) (-848))) (-14 *3 (-638 (-1170)))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-794)) (-4 *3 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $))))) (-4 *5 (-562)) (-5 *1 (-728 *4 *3 *5 *2)) (-4 *2 (-956 (-413 (-959 *5)) *4 *3)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-5 *1 (-992 *4 *5 *3 *2)) (-4 *2 (-956 (-959 *4) *5 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-13 (-848) (-10 -8 (-15 -4081 ((-1170) $)) (-15 -3342 ((-3 $ "failed") (-1170)))))) (-4 *4 (-1054)) (-4 *5 (-794)) (-5 *1 (-992 *4 *5 *6 *2)) (-4 *2 (-956 (-959 *4) *5 *6))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-923)) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-258))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-424 (-1166 (-572)))) (-5 *1 (-185)) (-5 *3 (-572))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-638 *3)) (-4 *3 (-303)) (-5 *1 (-179 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1150 *3)) (-4 *3 (-1098)) (-4 *3 (-1204))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-769)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-214 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-498 *4)) (-4 *4 (-848)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1007 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1140 *4)) (-4 *4 (-1098)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1211 *3)) (-4 *3 (-848)) (-4 *3 (-1098))))) 
-(((*1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-875)) (-5 *1 (-1262))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 *1)) (|has| *1 (-6 -4603)) (-4 *1 (-1017 *3)) (-4 *3 (-1204))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *9)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-769)) (-5 *1 (-1071 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-638 *9)) (-4 *8 (-1068 *5 *6 *7)) (-4 *9 (-1107 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-769)) (-5 *1 (-1138 *5 *6 *7 *8 *9))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-962)) (-5 *2 (-1092 (-217))))) ((*1 *2 *1) (-12 (-4 *1 (-982)) (-5 *2 (-1092 (-217)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-1150 *2)) (-4 *2 (-303)) (-5 *1 (-175 *2))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *7)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1186))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-855)))) ((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-997)))) ((*1 *2 *1) (-12 (-4 *1 (-1017 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-1098) (-39))) (-5 *1 (-1133 *2 *3)) (-4 *3 (-13 (-1098) (-39)))))) 
-(((*1 *2 *1 *3 *3 *4) (-12 (-5 *3 (-1 (-856) (-856) (-856))) (-5 *4 (-572)) (-5 *2 (-856)) (-5 *1 (-642 *5 *6 *7)) (-4 *5 (-1098)) (-4 *6 (-23)) (-14 *7 *6))) ((*1 *2 *1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-852 *3 *4 *5)) (-4 *3 (-1054)) (-14 *4 (-101 *3)) (-14 *5 (-1 *3 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-217)) (-5 *1 (-856)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-856)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-856)))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-856)) (-5 *1 (-1166 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-13 (-368) (-151))) (-5 *2 (-638 (-2 (|:| -3751 (-769)) (|:| -1694 *4) (|:| |num| *4)))) (-5 *1 (-405 *3 *4)) (-4 *4 (-1234 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1225 (-572))) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-279 *3)) (-4 *3 (-1204))))) 
-(((*1 *1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-685 (-312 (-217)))) (-5 *2 (-385)) (-5 *1 (-199))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-548 *4 *2 *5 *6)) (-4 *4 (-303)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-769)))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-769)) (-5 *1 (-167 *3 *4)) (-4 *3 (-168 *4)))) ((*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1204)) (-5 *2 (-769)) (-5 *1 (-231 *3 *4 *5)) (-4 *3 (-232 *4 *5)))) ((*1 *2) (-12 (-4 *4 (-848)) (-5 *2 (-769)) (-5 *1 (-435 *3 *4)) (-4 *3 (-436 *4)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-553 *3)) (-4 *3 (-554)))) ((*1 *2) (-12 (-4 *1 (-761)) (-5 *2 (-769)))) ((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-769)) (-5 *1 (-797 *3 *4)) (-4 *3 (-798 *4)))) ((*1 *2) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-999 *3 *4)) (-4 *3 (-1000 *4)))) ((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-769)) (-5 *1 (-1003 *3 *4)) (-4 *3 (-1004 *4)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1018 *3)) (-4 *3 (-1019)))) ((*1 *2) (-12 (-4 *1 (-1054)) (-5 *2 (-769)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1062 *3)) (-4 *3 (-1063))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4)))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-450 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |k| (-667 *3)) (|:| |c| *4)))) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| (-121)) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-4 *3 (-562)) (-5 *2 (-1166 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1150 *3)) (-5 *1 (-175 *3)) (-4 *3 (-303))))) 
-(((*1 *1 *1 *1) (-4 *1 (-147))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-160 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-159)))) ((*1 *2 *1) (-12 (-5 *2 (-159)) (-5 *1 (-875)))) ((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-148))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-148))) (-5 *1 (-143)))) ((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-143))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-708 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *3)))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *1 (-182 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 (-171 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *3 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-1194 *4 *2)) (-4 *2 (-13 (-27) (-1190) (-436 *4)))))) 
-(((*1 *1) (-5 *1 (-143)))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-139)) (-5 *3 (-769)) (-5 *2 (-1264))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2307 *1))) (-4 *1 (-850 *3))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-5 *2 (-638 *1)) (-4 *1 (-1130 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-4 *1 (-559 *3)) (-4 *3 (-13 (-410) (-1190))))) ((*1 *1 *2) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) ((*1 *1 *2 *2) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-4 *6 (-326 *5 *7)) (-4 *7 (-232 *8 (-769))) (-14 *8 (-769)) (-4 *5 (-368)) (-5 *2 (-121)) (-5 *1 (-935 *5 *6 *7 *8 *4)) (-4 *4 (-978 *5))))) 
-(((*1 *2) (-12 (-4 *2 (-174)) (-5 *1 (-167 *3 *2)) (-4 *3 (-168 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *2 *4)) (-4 *4 (-1234 *2)) (-4 *2 (-174)))) ((*1 *2) (-12 (-4 *4 (-1234 *2)) (-4 *2 (-174)) (-5 *1 (-414 *3 *2 *4)) (-4 *3 (-415 *2 *4)))) ((*1 *2) (-12 (-4 *1 (-415 *2 *3)) (-4 *3 (-1234 *2)) (-4 *2 (-174)))) ((*1 *2) (-12 (-4 *3 (-1234 *2)) (-5 *2 (-572)) (-5 *1 (-766 *3 *4)) (-4 *4 (-415 *2 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *3 (-174)))) ((*1 *2 *3) (-12 (-4 *2 (-562)) (-5 *1 (-977 *2 *3)) (-4 *3 (-1234 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1054)) (-4 *2 (-174))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1220 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1249 *3))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-133)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572))))) ((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-875)) (-5 *5 (-923)) (-5 *6 (-638 (-258))) (-5 *2 (-477)) (-5 *1 (-1263)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *2 (-477)) (-5 *1 (-1263)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-638 (-258))) (-5 *2 (-477)) (-5 *1 (-1263))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *4 (-368)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |cd| (-1152)) (|:| -3201 (-1152)))) (-5 *1 (-823))))) 
-(((*1 *2 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *2 (-572)) (-5 *4 (-1170)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *1 (-1031 *6 *5)) (-4 *5 (-13 (-436 *6) (-23) (-1044 *2) (-1044 *4) (-901 *4) (-162)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *2)) (-4 *2 (-174)))) ((*1 *2) (-12 (-4 *2 (-174)) (-5 *1 (-422 *3 *2)) (-4 *3 (-423 *2)))) ((*1 *2) (-12 (-4 *1 (-423 *2)) (-4 *2 (-174))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-214 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-848)) (-5 *2 (-121)) (-5 *1 (-498 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4602)) (-4 *1 (-503 *4)) (-4 *4 (-1204)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-1007 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-1140 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-330))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4603)) (-4 *1 (-128 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-248 *2 *3 *4 *5)) (-4 *2 (-1054)) (-4 *3 (-848)) (-4 *4 (-264 *3)) (-4 *5 (-794))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856))))) 
-(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1249 *3)) (-5 *1 (-276 *3 *4 *2)) (-4 *2 (-1220 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *4 (-1218 *3)) (-5 *1 (-277 *3 *4 *2 *5)) (-4 *2 (-1241 *3 *4)) (-4 *5 (-991 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1155 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-43 (-413 (-572)))) (-5 *1 (-1156 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-572)) (-5 *1 (-1112 *4 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1259 *4)) (-4 *4 (-634 *5)) (-4 *5 (-368)) (-4 *5 (-562)) (-5 *2 (-1259 *5)) (-5 *1 (-633 *5 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1259 *4)) (-4 *4 (-634 *5)) (-2959 (-4 *5 (-368))) (-4 *5 (-562)) (-5 *2 (-1259 (-413 *5))) (-5 *1 (-633 *5 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-330))) (-5 *1 (-330))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-50 (-1152) (-772))) (-5 *1 (-123))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123))))) 
-(((*1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-562)) (-4 *2 (-174))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 *4)) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-504)))) ((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-706))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-950 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-950 *3))) (-4 *1 (-1130 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-238 (-928 *4))) (-4 *4 (-353)) (-5 *2 (-685 *4)) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-238 (-928 *5))) (-5 *4 (-638 (-928 *5))) (-4 *5 (-353)) (-5 *2 (-685 *5)) (-5 *1 (-873 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-238 (-927 *4))) (-4 *4 (-368)) (-5 *2 (-685 *4)) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-238 (-927 *5))) (-5 *4 (-638 (-927 *5))) (-4 *5 (-368)) (-5 *2 (-685 *5)) (-5 *1 (-874 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-4 *7 (-117))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-1185))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-346 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 *3)) (-5 *1 (-347 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-545) (-638 (-545)))) (-5 *1 (-123)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-545) (-638 (-545)))) (-5 *1 (-123))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *3 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-638 *3)) (-5 *1 (-262 *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (-4 *12 (-260 *3))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-645 *2)) (-4 *2 (-368))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-133)))) 
-(((*1 *2 *3 *4 *2 *2 *5) (|partial| -12 (-5 *2 (-841 *4)) (-5 *3 (-611 *4)) (-5 *5 (-121)) (-4 *4 (-13 (-1190) (-29 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *1 (-216 *6 *4))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-388 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-1098)) (-5 *2 (-638 (-2 (|:| |k| *4) (|:| |c| *3)))))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |k| (-894 *3)) (|:| |c| *4)))) (-5 *1 (-622 *3 *4 *5)) (-4 *3 (-848)) (-4 *4 (-13 (-174) (-713 (-413 (-572))))) (-14 *5 (-923)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-667 *3))) (-5 *1 (-894 *3)) (-4 *3 (-848))))) 
-(((*1 *1 *1) (-5 *1 (-121)))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *1 (-119 *4 *5 *2 *6 *3)) (-4 *2 (-326 *4 *6)) (-4 *3 (-117))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-638 *8))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1054)) (-4 *7 (-1054)) (-4 *6 (-1234 *5)) (-5 *2 (-1166 (-1166 *7))) (-5 *1 (-514 *5 *6 *4 *7)) (-4 *4 (-1234 *6))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-385))) (-5 *1 (-1046)) (-5 *3 (-385))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-106 *3))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3 *3 *3 *3)) (-4 *3 (-1098)) (-5 *1 (-106 *3)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *1 (-106 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 *3)) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1234 (-413 *3))) (-5 *2 (-923)) (-5 *1 (-915 *4 *5)) (-4 *5 (-1234 (-413 *4)))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1137)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1259 (-2 (|:| |scaleX| (-217)) (|:| |scaleY| (-217)) (|:| |deltaX| (-217)) (|:| |deltaY| (-217)) (|:| -4161 (-572)) (|:| -4058 (-572)) (|:| |spline| (-572)) (|:| -1753 (-572)) (|:| |axesColor| (-875)) (|:| -1810 (-572)) (|:| |unitsColor| (-875)) (|:| |showing| (-572))))) (-5 *1 (-1260))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-1098)) (-4 *4 (-23)) (-14 *5 *4)))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1054)) (-5 *2 (-1 (-638 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-638 *4))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *1 (-64 *3)) (-4 *3 (-1204)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-64 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1218 *4)) (-4 *4 (-1054)) (-4 *4 (-562)) (-5 *2 (-413 (-959 *4))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-1218 *4)) (-4 *4 (-1054)) (-4 *4 (-562)) (-5 *2 (-413 (-959 *4)))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-57))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1 (-121) *7 (-638 *7))) (-4 *1 (-1198 *4 *5 *6 *7)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-199)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-385))) (-5 *2 (-385)) (-5 *1 (-199))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-457)) (-4 *3 (-848)) (-4 *3 (-1044 (-572))) (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-436 *3)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $)))))))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-669 *3)) (-4 *3 (-1204)) (-5 *2 (-769))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-748))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-896)) (-5 *3 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *2 (-1042))))) 
-(((*1 *1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-174)) (-4 *2 (-562)))) ((*1 *1 *1) (|partial| -4 *1 (-718)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1158 3 *3)) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) ((*1 *1) (-12 (-4 *1 (-1130 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-241 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *5)) (-4 *5 (-436 *4)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-856)) (-5 *1 (-36 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-379 *3)) (-4 *3 (-1204)) (-4 *3 (-848)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *1 (-379 *4)) (-4 *4 (-1204)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-4 *7 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-562)) (-4 *8 (-956 *7 *5 *6)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *3) (|:| |radicand| *3))) (-5 *1 (-960 *5 *6 *7 *8 *3)) (-5 *4 (-769)) (-4 *3 (-13 (-368) (-10 -8 (-15 -4487 (*8 $)) (-15 -4492 (*8 $)) (-15 -3972 ($ *8)))))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *5 (-1234 *4)) (-5 *2 (-638 (-2 (|:| |deg| (-769)) (|:| -2352 *5)))) (-5 *1 (-810 *4 *5 *3 *6)) (-4 *3 (-650 *5)) (-4 *6 (-650 (-413 *5)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-569)) (-5 *3 (-572)))) ((*1 *2 *3) (-12 (-5 *2 (-1166 (-413 (-572)))) (-5 *1 (-949)) (-5 *3 (-572))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (-12 (-5 *3 (-217)) (-5 *4 (-572)) (-5 *5 (-1152)) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-87 PDEF)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-88 BNDY)))) (-5 *2 (-1042)) (-5 *1 (-748))))) 
-(((*1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-562)) (-4 *2 (-174))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-769)) (-4 *2 (-13 (-562) (-457))) (-5 *1 (-349 *2 *4)) (-4 *4 (-52 *2 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-31 *4 *5 *6 *7 *8)) (-4 *8 (-978 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *8 (-978 *4))))) 
-(((*1 *1 *2 *3 *3 *4 *4) (-12 (-5 *2 (-959 (-572))) (-5 *3 (-1170)) (-5 *4 (-1092 (-413 (-572)))) (-5 *1 (-30))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-864)) (-5 *2 (-1264))))) 
-(((*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-670 (-217))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-748))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-950 (-217)))) (-5 *1 (-1260))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-1230 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) ((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-742 *3)) (-4 *3 (-174))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-605 *2 *3)) (-4 *3 (-1204)) (-4 *2 (-1098)) (-4 *2 (-848))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-769)) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-469))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457))) (-5 *2 (-841 *4)) (-5 *1 (-309 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1190) (-436 *3))) (-14 *5 (-1170)) (-14 *6 *4))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-848) (-1044 (-572)) (-634 (-572)) (-457))) (-5 *2 (-841 *4)) (-5 *1 (-1244 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1190) (-436 *3))) (-14 *5 (-1170)) (-14 *6 *4)))) 
-(((*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-638 (-1170))))) ((*1 *1 *1) (-12 (-5 *1 (-215 *2 *3)) (-4 *2 (-13 (-1054) (-848))) (-14 *3 (-638 (-1170)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-611 *4)) (-5 *1 (-610 *3 *4)) (-4 *3 (-848)) (-4 *4 (-848))))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-1272 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)) (-5 *1 (-660 *3 *4)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-660 *3 *4)) (-5 *1 (-1277 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-846)) (-5 *1 (-299 *3))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-959 *4)) (-4 *4 (-1054)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-959 *5)) (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-312 *4)) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-312 *5)) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-303)) (-5 *2 (-413 (-424 (-959 *4)))) (-5 *1 (-1048 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-148)))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-148))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190) (-1009))) (-5 *1 (-176 *3))))) 
-(((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1137)) (-5 *3 (-572)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-4 *4 (-562)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -2701 (-619 *4 *5)) (|:| -2146 (-413 *5)))) (-5 *1 (-619 *4 *5)) (-5 *3 (-413 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-1158 *3 *4))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-457)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| |primePart| *1) (|:| |commonPart| *1))) (-4 *1 (-1234 *3))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1002 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1204)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-498 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-503 *3)) (-4 *3 (-1204)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-638 *3)) (-5 *1 (-1140 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1169)) (-5 *1 (-330))))) 
-(((*1 *1) (-5 *1 (-159)))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-380 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1278 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-385))) (-5 *1 (-1046))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-848)) (-5 *2 (-638 (-638 (-638 *4)))) (-5 *1 (-1176 *4)) (-5 *3 (-638 (-638 *4)))))) 
-(((*1 *1 *1) (-4 *1 (-655))) ((*1 *1 *1) (-5 *1 (-1116)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-685 *5)) (-4 *5 (-1054)) (-5 *1 (-1058 *3 *4 *5)) (-14 *3 (-769)) (-14 *4 (-769))))) 
-(((*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-413 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *4))))) 
-(((*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3462 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *1 *1 *2) (|partial| -12 (-5 *2 (-769)) (-4 *1 (-1234 *3)) (-4 *3 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 *6 *5)) (-5 *1 (-702 *4 *5 *6)) (-4 *4 (-613 (-545))) (-4 *5 (-1204)) (-4 *6 (-1204))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-361 *3)) (-4 *3 (-353))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1068 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *6 *3)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *6 (-3 (|:| |fn| (-394)) (|:| |fp| (-94 G)))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-91 FCN)))) (-5 *3 (-217)) (-5 *2 (-1042)) (-5 *1 (-747))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-469))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-685 *5))) (-4 *5 (-303)) (-4 *5 (-1054)) (-5 *2 (-1259 (-1259 *5))) (-5 *1 (-1036 *5)) (-5 *4 (-1259 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-1166 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-312 (-171 (-385)))) (-5 *1 (-330)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-572))) (-5 *1 (-330)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-385))) (-5 *1 (-330)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-689))) (-5 *1 (-330)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-696))) (-5 *1 (-330)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-694))) (-5 *1 (-330)))) ((*1 *1) (-5 *1 (-330)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-769)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-794)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-454 *4 *5 *6 *7))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) ((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-476)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261)))) ((*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1261))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| -1824 (-123)) (|:| |w| (-217)))) (-5 *1 (-198))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-252))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-117)) (-5 *2 (-769))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-159)))) ((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-5 *1 (-906 *3))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-5 *2 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *5)) (-5 *1 (-119 *5 *6 *3 *7 *4)) (-4 *3 (-326 *5 *7)) (-4 *4 (-117))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-175 *3)) (-4 *3 (-303)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-669 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-736 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-848)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-869 *3)) (-5 *2 (-572)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *1 (-988 *3)) (-4 *3 (-1054)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-5 *3 (-638 *7)) (-4 *1 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1236 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1234 (-572))) (-5 *1 (-500 *3))))) 
-(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-638 (-244 *5 *6))) (-4 *6 (-457)) (-5 *2 (-244 *5 *6)) (-14 *5 (-638 (-1170))) (-5 *1 (-626 *5 *6))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-232 *5 (-769))) (-14 *5 (-769)) (-5 *1 (-914 *3 *2 *4 *5)) (-4 *2 (-326 *3 *4)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-368)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-935 *4 *2 *5 *6 *3)) (-4 *2 (-326 *4 *5)) (-4 *3 (-978 *4)))) ((*1 *2 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-368)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-5 *1 (-935 *5 *2 *6 *7 *3)) (-4 *2 (-326 *5 *6)) (-4 *3 (-978 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1216 *2)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-1250 *2 *3 *4)) (-4 *2 (-1054)) (-14 *3 (-1170)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1254 *2 *3)) (-4 *2 (-1054)) (-14 *3 (-1170))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-638 *7)) (|:| |badPols| (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)) (-5 *2 (-638 *6)) (-5 *1 (-995 *3 *4 *5 *6)) (-4 *6 (-956 *3 *5 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-385)) (-5 *3 (-1152)) (-5 *1 (-99)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-385)) (-5 *3 (-1152)) (-5 *1 (-99))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *2 (-638 (-413 (-572)))) (-5 *1 (-1026 *4)) (-4 *4 (-1234 (-572)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-825))))) 
-(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-638 (-685 *6))) (-5 *4 (-121)) (-5 *5 (-572)) (-5 *2 (-685 *6)) (-5 *1 (-1036 *6)) (-4 *6 (-368)) (-4 *6 (-1054)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 (-685 *4))) (-5 *2 (-685 *4)) (-5 *1 (-1036 *4)) (-4 *4 (-368)) (-4 *4 (-1054)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-638 (-685 *5))) (-5 *4 (-572)) (-5 *2 (-685 *5)) (-5 *1 (-1036 *5)) (-4 *5 (-368)) (-4 *5 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-431 *3)) (-4 *3 (-1098)) (-5 *2 (-769))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-667 *3)) (-4 *3 (-848)) (-4 *1 (-380 *3 *4)) (-4 *4 (-174))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-638 *3))) (-4 *3 (-1098)) (-5 *1 (-906 *3))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054)))) ((*1 *2 *1 *1) (-12 (-4 *2 (-1054)) (-5 *1 (-55 *2 *3)) (-14 *3 (-638 (-1170))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-638 (-923))) (-4 *2 (-368)) (-5 *1 (-156 *4 *2 *5)) (-14 *4 (-923)) (-14 *5 (-1001 *4 *2)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-312 *3)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) ((*1 *2 *3 *1) (-12 (-4 *1 (-322 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-138)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-388 *2 *3)) (-4 *3 (-1098)) (-4 *2 (-1054)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *2 (-562)) (-5 *1 (-619 *2 *4)) (-4 *4 (-1234 *2)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-704 *2)) (-4 *2 (-1054)))) ((*1 *2 *1 *3) (-12 (-4 *2 (-1054)) (-5 *1 (-731 *2 *3)) (-4 *3 (-722)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *5)) (-5 *3 (-638 (-769))) (-4 *1 (-736 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-848)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-736 *4 *2)) (-4 *4 (-1054)) (-4 *2 (-848)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-850 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *6)) (-5 *3 (-638 (-769))) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-956 *4 *5 *2)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *2 (-848)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-130)) (-5 *2 (-312 *4)) (-5 *1 (-1085 *4)) (-4 *4 (-13 (-848) (-562))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *2 (-956 *4 (-538 *5) *5)) (-5 *1 (-1122 *4 *5 *2)) (-4 *4 (-1054)) (-4 *5 (-848)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-959 *4)) (-5 *1 (-1199 *4)) (-4 *4 (-1054))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1092 (-841 (-217)))) (-5 *1 (-301))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *3 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *6 *7 *3 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-638 *9)) (-5 *1 (-471 *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-974 *4)) (-4 *4 (-353)) (-5 *2 (-638 (-928 *4))) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-973 *4)) (-4 *4 (-368)) (-5 *2 (-638 (-927 *4))) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-312 (-217))) (-5 *2 (-413 (-572))) (-5 *1 (-301))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-572)) (-5 *3 (-965 (-171 (-385)))) (-5 *1 (-115))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-298)) (-4 *2 (-1204)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-611 *1))) (-5 *3 (-638 *1)) (-4 *1 (-298)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-290 *1))) (-4 *1 (-298)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-290 *1)) (-4 *1 (-298))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-368)) (-4 *3 (-1054)) (-5 *1 (-1154 *3))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1170)) (-5 *3 (-440)) (-4 *5 (-848)) (-5 *1 (-1104 *5 *4)) (-4 *4 (-436 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-217))) (-5 *2 (-217)) (-5 *1 (-115))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-638 (-959 (-572)))) (-5 *4 (-638 (-1170))) (-5 *5 (-572)) (-4 *1 (-671 *6 *2)) (-4 *6 (-1204)) (-4 *2 (-1204))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-769)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-214 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-498 *4)) (-4 *4 (-848)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1007 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *2 (-121)) (-5 *1 (-1140 *4)) (-4 *4 (-1098))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *3 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-454 *4 *3 *5 *6)) (-4 *6 (-956 *4 *3 *5))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-368)) (-5 *1 (-1032 *3 *2)) (-4 *2 (-650 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-5 *2 (-2 (|:| -2352 *3) (|:| -1824 (-638 *5)))) (-5 *1 (-1032 *5 *3)) (-5 *4 (-638 *5)) (-4 *3 (-650 *5))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569)))) ((*1 *2 *3) (-12 (-5 *2 (-1166 (-413 (-572)))) (-5 *1 (-949)) (-5 *3 (-572))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-312 (-217))) (-5 *1 (-204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-638 *5))) (-4 *5 (-326 *4 *6)) (-4 *6 (-232 *7 *2)) (-14 *7 *2) (-4 *4 (-1054)) (-5 *2 (-769)) (-5 *1 (-778 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *6 (-232 *7 *2)) (-14 *7 *2) (-5 *2 (-769)) (-5 *1 (-935 *5 *3 *6 *7 *4)) (-4 *3 (-326 *5 *6)) (-4 *4 (-978 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-572)) (-4 *6 (-368)) (-4 *7 (-232 *8 *2)) (-14 *8 *2) (-5 *2 (-769)) (-5 *1 (-935 *6 *3 *7 *8 *4)) (-4 *3 (-326 *6 *7)) (-4 *4 (-978 *6))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1225 (-572))) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-644 *3)) (-4 *3 (-1204))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-290 (-312 *5)))) (-5 *1 (-1125 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-290 (-312 *4)))) (-5 *1 (-1125 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-290 (-413 (-959 *5)))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-290 (-312 *5)))) (-5 *1 (-1125 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-290 (-413 (-959 *4)))) (-4 *4 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-290 (-312 *4)))) (-5 *1 (-1125 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 *5)))) (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *5))))) (-5 *1 (-1125 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 *4)))) (-4 *4 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *4))))) (-5 *1 (-1125 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-290 (-413 (-959 *5))))) (-5 *4 (-638 (-1170))) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *5))))) (-5 *1 (-1125 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-290 (-413 (-959 *4))))) (-4 *4 (-13 (-303) (-848) (-151))) (-5 *2 (-638 (-638 (-290 (-312 *4))))) (-5 *1 (-1125 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-1152)) (-5 *1 (-186)))) ((*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-1152)) (-5 *1 (-296)))) ((*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-1152)) (-5 *1 (-301))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3) (-12 (|has| *2 (-6 (-4604 "*"))) (-4 *5 (-379 *2)) (-4 *6 (-379 *2)) (-4 *2 (-1054)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1234 *2)) (-4 *4 (-683 *2 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-368)) (-5 *2 (-638 *5)) (-5 *1 (-639 *5 *3)) (-4 *3 (-645 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-518 *3 *4 *5 *6))) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-638 *1)) (-5 *3 (-638 *7)) (-4 *1 (-1073 *4 *5 *6 *7)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-638 *1)) (-4 *1 (-1073 *4 *5 *6 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-545)) (-5 *1 (-544 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *2 (-57)) (-5 *1 (-545))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-1 *6 (-638 *6)))) (-4 *5 (-43 (-413 (-572)))) (-4 *6 (-1249 *5)) (-5 *2 (-638 *6)) (-5 *1 (-1251 *5 *6))))) 
-(((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-2 (|:| -4234 (-638 (-856))) (|:| -1614 (-638 (-856))) (|:| |presup| (-638 (-856))) (|:| -3398 (-638 (-856))) (|:| |args| (-638 (-856))))) (-5 *1 (-1170)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-638 (-856)))) (-5 *1 (-1170))))) 
-(((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1092 (-923))) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-1170))) (-5 *2 (-1264)) (-5 *1 (-1212)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 (-1170))) (-5 *2 (-1264)) (-5 *1 (-1212))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *3 (-562))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-822))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-1110)) (-4 *3 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-436 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-638 (-893 *3))) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-956 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-638 *3)) (-5 *1 (-957 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $)))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-171 (-217))) (-5 *2 (-217)) (-5 *1 (-115))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-697 *3 *5 *6 *7)) (-4 *3 (-613 (-545))) (-4 *5 (-1204)) (-4 *6 (-1204)) (-4 *7 (-1204)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-5 *2 (-1 *6 *5)) (-5 *1 (-702 *3 *5 *6)) (-4 *3 (-613 (-545))) (-4 *5 (-1204)) (-4 *6 (-1204))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-769)) (|:| |poli| *3) (|:| |polj| *3)))) (-4 *5 (-794)) (-4 *3 (-956 *4 *5 *6)) (-4 *4 (-457)) (-4 *6 (-848)) (-5 *1 (-454 *4 *5 *6 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-109))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *2 (-956 *3 *5 (-858 *4))) (-4 *5 (-232 (-4032 *4) (-769))) (-4 *6 (-978 *3)) (-4 *7 (-645 *3)) (-4 *8 (-926 *3 *7)) (-4 *9 (-237 *8)) (-4 *10 (-540 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-5 *1 (-471 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2 *2) (-12 (-5 *2 (-244 *4 *3)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-5 *1 (-873 *3 *4 *5)) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-244 *4 *3)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-5 *1 (-874 *3 *4 *5)) (-4 *5 (-117))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1182 *4 *5)) (-4 *4 (-1098)) (-4 *5 (-1098))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-923)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *2 (-683 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-572)) (-5 *1 (-450 *3)) (-4 *3 (-410)) (-4 *3 (-1054))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-64 *6)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-5 *2 (-64 *5)) (-5 *1 (-63 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *7 *5)) (-5 *4 (-234 *6 *7)) (-14 *6 (-769)) (-4 *7 (-1204)) (-4 *5 (-1204)) (-5 *2 (-234 *6 *5)) (-5 *1 (-233 *6 *7 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-4 *2 (-379 *5)) (-5 *1 (-377 *6 *4 *5 *2)) (-4 *4 (-379 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1098)) (-4 *5 (-1098)) (-4 *2 (-431 *5)) (-5 *1 (-429 *6 *4 *5 *2)) (-4 *4 (-431 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-638 *6)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-5 *2 (-638 *5)) (-5 *1 (-636 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-965 *6)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-5 *2 (-965 *5)) (-5 *1 (-964 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *3 *6 *3)) (-5 *5 (-1150 *6)) (-4 *6 (-1204)) (-4 *3 (-1204)) (-5 *2 (-1150 *3)) (-5 *1 (-1148 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-1259 *6)) (-4 *6 (-1204)) (-4 *5 (-1204)) (-5 *2 (-1259 *5)) (-5 *1 (-1258 *6 *5))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-440)) (-5 *2 (-638 (-3 (|:| -3201 (-1170)) (|:| |bounds| (-638 (-3 (|:| S (-1170)) (|:| P (-959 (-572))))))))) (-5 *1 (-1174))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *6 (-923)) (-4 *5 (-303)) (-4 *3 (-1234 *5)) (-5 *2 (-2 (|:| |plist| (-638 *3)) (|:| |modulo| *5))) (-5 *1 (-466 *5 *3)) (-5 *4 (-638 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-559 *3)) (-4 *3 (-13 (-410) (-1190))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-846)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1070 *4 *3)) (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1166 *4)) (-5 *1 (-361 *4)) (-4 *4 (-353))))) 
-(((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-41 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-2 (|:| -4111 *3) (|:| -4320 *4)))))) 
-(((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-1262))))) 
-(((*1 *2) (|partial| -12 (-4 *3 (-562)) (-4 *3 (-174)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2237 (-638 *1)))) (-4 *1 (-372 *3)))) ((*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-458 *3 *4 *5 *6)) (|:| -2237 (-638 (-458 *3 *4 *5 *6))))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-784 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-174))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-273))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-5 *1 (-906 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *1 (-879 *2)) (-4 *2 (-1204)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *1 (-881 *2)) (-4 *2 (-1204)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-5 *1 (-883 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-4 *1 (-736 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-848)) (-5 *2 (-959 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-736 *4 *5)) (-4 *4 (-1054)) (-4 *5 (-848)) (-5 *2 (-959 *4)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-769)) (-4 *1 (-1249 *4)) (-4 *4 (-1054)) (-5 *2 (-959 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-1249 *4)) (-4 *4 (-1054)) (-5 *2 (-959 *4))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-638 (-572)))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169))))) 
-(((*1 *2 *3 *3) (-12 (|has| *2 (-6 (-4604 "*"))) (-4 *5 (-379 *2)) (-4 *6 (-379 *2)) (-4 *2 (-1054)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1234 *2)) (-4 *4 (-683 *2 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 *3)) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-923))) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 *3)) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-677 *2)) (-4 *2 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-638 *5) (-638 *5))) (-5 *4 (-572)) (-5 *2 (-638 *5)) (-5 *1 (-677 *5)) (-4 *5 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1102)) (-5 *2 (-1264)) (-5 *1 (-102))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *5)) (-4 *5 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-413 (-572))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-290 *3)) (-5 *5 (-413 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-413 (-572)))) (-5 *4 (-290 *8)) (-5 *5 (-1225 (-413 (-572)))) (-5 *6 (-413 (-572))) (-4 *8 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-413 (-572)))) (-5 *7 (-413 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *8))) (-4 *8 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *8 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-413 (-572))) (-4 *4 (-1054)) (-4 *1 (-1241 *4 *3)) (-4 *3 (-1218 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-769)) (-5 *4 (-1259 *2)) (-4 *5 (-303)) (-4 *6 (-1000 *5)) (-4 *2 (-13 (-415 *6 *7) (-1044 *6))) (-5 *1 (-419 *5 *6 *7 *2)) (-4 *7 (-1234 *6))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-368))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-572)) (-5 *4 (-1 (-1264) (-1102))) (-5 *2 (-1264)) (-5 *1 (-102))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *5)) (-4 *5 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-13 (-457) (-848) (-1044 *4) (-634 *4))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 *5) (-634 *5))) (-5 *5 (-572)) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-572))) (-5 *4 (-290 *7)) (-5 *5 (-1225 (-572))) (-4 *7 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-572))) (-4 *3 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-572)) (-4 *4 (-1054)) (-4 *1 (-1220 *4 *3)) (-4 *3 (-1249 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1218 *3))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-769)) (-4 *4 (-353)) (-5 *1 (-209 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-1033 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *2 *1) (-12 (-4 *1 (-21)) (-5 *2 (-572)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-769)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-25)) (-5 *2 (-923)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-217)) (-5 *1 (-159)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-923)) (-5 *1 (-159)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-13 (-368) (-1190))) (-5 *1 (-221 *3)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-232 *3 *2)) (-4 *2 (-1204)) (-4 *2 (-722)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-232 *3 *2)) (-4 *2 (-1204)) (-4 *2 (-722)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1110)) (-4 *2 (-1204)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1110)) (-4 *2 (-1204)))) ((*1 *1 *2 *3) (-12 (-4 *1 (-322 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-138)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-366 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-366 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-387 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-848)))) ((*1 *1 *2 *3) (-12 (-4 *1 (-388 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-1098)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-392 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-14 *3 (-638 (-1170))) (-4 *4 (-174)) (-4 *6 (-232 (-4032 *3) (-769))) (-14 *7 (-1 (-121) (-2 (|:| -1763 *5) (|:| -3751 *6)) (-2 (|:| -1763 *5) (|:| -3751 *6)))) (-5 *1 (-467 *3 *4 *5 *6 *7 *2)) (-4 *5 (-848)) (-4 *2 (-956 *4 *6 (-858 *3))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-353)) (-5 *1 (-536 *3)))) ((*1 *1 *1 *1) (-5 *1 (-545))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-598 *2)) (-4 *2 (-1054)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-598 *2)) (-4 *2 (-1054)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-1061)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *7 (-1098)) (-5 *2 (-1 *7 *5)) (-5 *1 (-679 *5 *6 *7)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1098)) (-4 *4 (-1054)) (-5 *1 (-680 *3 *4)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-683 *3 *2 *4)) (-4 *3 (-1054)) (-4 *2 (-379 *3)) (-4 *4 (-379 *3)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-683 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *2 (-379 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) ((*1 *1 *1 *1) (-4 *1 (-716))) ((*1 *1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-572)) (-4 *4 (-368)) (-4 *5 (-645 *4)) (-5 *2 (-238 *1)) (-4 *1 (-926 *4 *5)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1259 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-562)) (-5 *1 (-977 *3 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1060 *2)) (-4 *2 (-1061)))) ((*1 *1 *1 *1) (-4 *1 (-1110))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1119 *3 *4 *2 *5)) (-4 *4 (-1054)) (-4 *2 (-232 *3 *4)) (-4 *5 (-232 *3 *4)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-1119 *3 *4 *5 *2)) (-4 *4 (-1054)) (-4 *5 (-232 *3 *4)) (-4 *2 (-232 *3 *4)))) ((*1 *1 *2 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-848)) (-5 *1 (-1122 *3 *4 *2)) (-4 *2 (-956 *3 (-538 *4) *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-950 (-217))) (-5 *3 (-217)) (-5 *1 (-1201)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-722)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-722)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-572)) (-4 *1 (-1257 *3)) (-4 *3 (-1204)) (-4 *3 (-21)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1274 *2 *3)) (-4 *2 (-848)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1274 *3 *2)) (-4 *3 (-848)) (-4 *2 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-1280 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-844))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *5)) (-4 *5 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-290 *3)) (-5 *5 (-769)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-572))) (-5 *4 (-290 *6)) (-4 *6 (-13 (-27) (-1190) (-436 *5))) (-4 *5 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-572))) (-5 *4 (-290 *7)) (-5 *5 (-1225 (-769))) (-4 *7 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1170)) (-5 *5 (-290 *3)) (-5 *6 (-1225 (-769))) (-4 *3 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-57)) (-5 *1 (-465 *7 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1220 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-1249 *3))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1152)) (-5 *3 (-824)) (-5 *1 (-823))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-368)) (-5 *1 (-282 *3 *2)) (-4 *2 (-1249 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-5 *1 (-217))) ((*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1) (-4 *1 (-1132))) ((*1 *1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-123)) (-5 *1 (-122 *3)) (-4 *3 (-848)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1152)) (-5 *1 (-787))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-545))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-381 *4 *2)) (-4 *2 (-13 (-379 *4) (-10 -7 (-6 -4603))))))) 
-(((*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-875)) (-5 *1 (-258)))) ((*1 *1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-258))))) 
-(((*1 *1 *1 *1) (-5 *1 (-217))) ((*1 *2 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-769)) (-5 *2 (-1 (-385))) (-5 *1 (-1046)))) ((*1 *1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848))) (-4 *2 (-13 (-436 (-171 *4)) (-1009) (-1190))) (-5 *1 (-601 *4 *3 *2)) (-4 *3 (-13 (-436 *4) (-1009) (-1190)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1204)))) ((*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *4 (-368)) (-4 *2 (-683 *4 *5 *6)) (-5 *1 (-673 *4 *5 *6 *2)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-413 (-572))) (-5 *2 (-217)) (-5 *1 (-301))))) 
-(((*1 *1 *1 *1) (-5 *1 (-163))) ((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-163))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1204)))) ((*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 *3)) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-923))) (-4 *5 (-368)) (-4 *6 (-379 *5)) (-4 *7 (-379 *5)) (-5 *2 (-638 *3)) (-5 *1 (-673 *5 *6 *7 *3)) (-4 *3 (-683 *5 *6 *7))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-572)) (-5 *1 (-1112 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *1 (-949)) (-5 *3 (-572)))) ((*1 *2 *2) (-12 (-4 *3 (-303)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-5 *1 (-1120 *3 *4 *5 *2)) (-4 *2 (-683 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-857)))) ((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-857)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-856)) (-5 *2 (-1264)) (-5 *1 (-857)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-1150 *4)) (-4 *4 (-1098)) (-4 *4 (-1204))))) 
-(((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-696)))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-696))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-562)) (-5 *2 (-2 (|:| -1369 (-685 *5)) (|:| |vec| (-1259 (-638 (-923)))))) (-5 *1 (-95 *5 *3)) (-5 *4 (-923)) (-4 *3 (-650 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-123))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-769)) (-4 *3 (-13 (-562) (-457))) (-5 *2 (-638 *3)) (-5 *1 (-349 *3 *5)) (-4 *5 (-52 *3 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-236)) (-5 *3 (-1152)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-1152))) (-5 *1 (-236)))) ((*1 *1 *2) (-12 (-5 *2 (-159)) (-5 *1 (-875))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-1264))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-545))) (-5 *2 (-1170)) (-5 *1 (-545))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-424 *3)) (-4 *3 (-562)) (-5 *1 (-425 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)))) ((*1 *2) (-12 (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)) (-5 *1 (-414 *3 *4 *5)) (-4 *3 (-415 *4 *5)))) ((*1 *2) (-12 (-4 *1 (-415 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-685 *3))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-232 *5 (-769))) (-14 *5 (-769)) (-5 *1 (-914 *3 *2 *4 *5)) (-4 *2 (-326 *3 *4))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1280 *3 *4)) (-4 *3 (-1054)) (-4 *4 (-844))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009)))))) 
-(((*1 *1 *1) (-5 *1 (-1169))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1098)) (-4 *3 (-848)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-667 *3)) (-5 *1 (-894 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) ((*1 *2 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1259 (-638 *3))) (-4 *4 (-303)) (-5 *2 (-638 *3)) (-5 *1 (-461 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-638 *3)) (-5 *1 (-968 *3)) (-4 *3 (-554))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3069 (-783 *3)) (|:| |coef1| (-783 *3)))) (-5 *1 (-783 *3)) (-4 *3 (-562)) (-4 *3 (-1054)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -3069 *1) (|:| |coef1| *1))) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1204)) (-5 *1 (-381 *4 *2)) (-4 *2 (-13 (-379 *4) (-10 -7 (-6 -4603))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1170)) (|:| |arrayIndex| (-638 (-959 (-572)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1170)) (|:| |rand| (-856)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1169)) (|:| |thenClause| (-330)) (|:| |elseClause| (-330)))) (|:| |returnBranch| (-2 (|:| -4037 (-121)) (|:| -2148 (-2 (|:| |ints2Floats?| (-121)) (|:| -1793 (-856)))))) (|:| |blockBranch| (-638 (-330))) (|:| |commentBranch| (-638 (-1152))) (|:| |callBranch| (-1152)) (|:| |forBranch| (-2 (|:| -1441 (-1090 (-959 (-572)))) (|:| |span| (-959 (-572))) (|:| |body| (-330)))) (|:| |labelBranch| (-1116)) (|:| |loopBranch| (-2 (|:| |switch| (-1169)) (|:| |body| (-330)))) (|:| |commonBranch| (-2 (|:| -3201 (-1170)) (|:| |contents| (-638 (-1170))))) (|:| |printBranch| (-638 (-856))))) (-5 *1 (-330))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-906 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-562) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-2 (|:| |func| *3) (|:| |kers| (-638 (-611 *3))) (|:| |vals| (-638 *3)))) (-5 *1 (-275 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-1152))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 (-638 *4))) (-5 *3 (-638 *4)) (-4 *4 (-368)) (-5 *1 (-657 *4))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-984 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *5 (-1068 *3 *4 *2))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-342 *4 *3 *5)) (-4 *4 (-1214)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *1 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-828 *2 *3)) (-4 *2 (-704 *3))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-572)) (-4 *1 (-62 *4 *3 *5)) (-4 *4 (-1204)) (-4 *3 (-379 *4)) (-4 *5 (-379 *4))))) 
-(((*1 *2 *3 *4 *4 *5 *6 *7) (-12 (-5 *5 (-1170)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-638 *4))) (-5 *7 (-1 (-3 (-2 (|:| -3444 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1190) (-27) (-436 *8))) (-4 *8 (-13 (-457) (-848) (-151) (-1044 *3) (-634 *3))) (-5 *3 (-572)) (-5 *2 (-2 (|:| |ans| *4) (|:| -1862 *4) (|:| |sol?| (-121)))) (-5 *1 (-1020 *8 *4))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-685 (-572))) (-5 *3 (-638 (-572))) (-5 *1 (-1108))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1051 *4 *5)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *4)) (|:| -3160 (-638 (-959 *4)))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1283 *5 *6 *7)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1283 *5 *6 *7)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *5)) (|:| -3160 (-638 (-959 *5)))))) (-5 *1 (-1283 *5 *6 *7)) (-5 *3 (-638 (-959 *5))) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-2 (|:| -3950 (-1166 *4)) (|:| -3160 (-638 (-959 *4)))))) (-5 *1 (-1283 *4 *5 *6)) (-5 *3 (-638 (-959 *4))) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170)))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-13 (-562) (-151))) (-5 *1 (-1228 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-856)))) ((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1264)) (-5 *1 (-969))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-121)) (-5 *2 (-1152)) (-5 *1 (-57))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-5 *3 (-121)) (-5 *1 (-114)))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (|has| *1 (-6 -4593)) (-4 *1 (-410)))) ((*1 *2) (-12 (-4 *1 (-410)) (-5 *2 (-923))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1074 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-1264)) (-5 *1 (-1106 *3 *4 *5 *6 *7)) (-4 *7 (-1073 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 (-385))) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-638 (-385))) (-5 *1 (-477)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-385))) (-5 *1 (-477)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-875)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-303)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-452 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-1152)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-303)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-452 *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-1152)) (-4 *7 (-956 *4 *5 *6)) (-4 *4 (-303)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-452 *4 *5 *6 *7))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1042))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *4)) (-4 *4 (-353)) (-5 *2 (-1166 *4)) (-5 *1 (-536 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1054)) (-14 *4 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *2 (-121)) (-5 *1 (-56 *4)) (-4 *4 (-1204)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-215 *3 *4)) (-4 *3 (-13 (-1054) (-848))) (-14 *4 (-638 (-1170))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-672 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-894 *3)) (-4 *3 (-848))))) 
-(((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-168 *2)) (-4 *2 (-174)) (-4 *2 (-562)))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-326 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *2 (-562)))) ((*1 *1 *1 *1) (|partial| -4 *1 (-562))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-562)))) ((*1 *1 *1 *1) (|partial| -5 *1 (-769))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-850 *2)) (-4 *2 (-1054)) (-4 *2 (-562)))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1259 *4)) (-4 *4 (-1234 *3)) (-4 *3 (-562)) (-5 *1 (-977 *3 *4)))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1057 *3 *4 *2 *5 *6)) (-4 *2 (-1054)) (-4 *5 (-232 *4 *2)) (-4 *6 (-232 *3 *2)) (-4 *2 (-562)))) ((*1 *2 *2 *2) (|partial| -12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-303)) (-5 *2 (-638 *5))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 (-685 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1152)) (-5 *2 (-772)) (-5 *1 (-123))))) 
-(((*1 *1 *1) (|partial| -12 (-5 *1 (-156 *2 *3 *4)) (-14 *2 (-923)) (-4 *3 (-368)) (-14 *4 (-1001 *2 *3)))) ((*1 *1 *1) (|partial| -12 (-4 *2 (-174)) (-5 *1 (-286 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1234 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-372 *2)) (-4 *2 (-174)) (-4 *2 (-562)))) ((*1 *1 *1) (|partial| -12 (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) ((*1 *1) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) ((*1 *1 *1) (|partial| -4 *1 (-718))) ((*1 *1 *1) (|partial| -4 *1 (-722))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *3))) (-5 *1 (-774 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) ((*1 *2 *2 *1) (|partial| -12 (-4 *1 (-1070 *3 *2)) (-4 *3 (-13 (-846) (-368))) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (|partial| -12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-769)) (-4 *2 (-13 (-562) (-457))) (-5 *1 (-349 *2 *4)) (-4 *4 (-52 *2 *3))))) 
-(((*1 *1 *2 *3 *3 *4 *5) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *3 (-638 (-875))) (-5 *4 (-638 (-923))) (-5 *5 (-638 (-258))) (-5 *1 (-477)))) ((*1 *1 *2 *3 *3 *4) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *3 (-638 (-875))) (-5 *4 (-638 (-923))) (-5 *1 (-477)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-638 (-950 (-217))))) (-5 *1 (-477)))) ((*1 *1 *1) (-5 *1 (-477)))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-143)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1137)) (-5 *2 (-148))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-312 (-572))) (|:| -3313 (-312 (-385))) (|:| CF (-312 (-171 (-385)))) (|:| |switch| (-1169)))) (-5 *1 (-1169))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1101 *3 *4 *5 *6 *2)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-4 *5 (-1098)) (-4 *6 (-1098)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-984 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-1068 *3 *4 *2)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1170)) (-5 *1 (-611 *3)) (-4 *3 (-848))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-572)) (-5 *2 (-121)) (-5 *1 (-558))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 (-858 *5))) (-14 *5 (-638 (-1170))) (-4 *6 (-457)) (-5 *2 (-2 (|:| |dpolys| (-638 (-244 *5 *6))) (|:| |coords| (-638 (-572))))) (-5 *1 (-480 *5 *6 *7)) (-5 *3 (-638 (-244 *5 *6))) (-4 *7 (-457))))) 
-(((*1 *1) (-5 *1 (-824)))) 
-(((*1 *2 *3 *4) (-12 (-4 *4 (-368)) (-5 *2 (-638 (-1150 *4))) (-5 *1 (-282 *4 *5)) (-5 *3 (-1150 *4)) (-4 *5 (-1249 *4))))) 
-(((*1 *1 *2 *3 *1 *3) (-12 (-5 *2 (-893 *4)) (-4 *4 (-1098)) (-5 *1 (-890 *4 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-326 *3 *2)) (-4 *3 (-1054)) (-4 *2 (-793)))) ((*1 *2 *1) (-12 (-4 *1 (-704 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-850 *3)) (-4 *3 (-1054)) (-5 *2 (-769)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *1 (-956 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-638 (-769))))) ((*1 *2 *1 *3) (-12 (-4 *1 (-956 *4 *5 *3)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-5 *2 (-769))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1216 *3)) (-4 *3 (-1054)) (-5 *1 (-1215 *3))))) 
-(((*1 *1 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190)))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1204)) (-5 *1 (-181 *3 *2)) (-4 *2 (-669 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-1129 (-217))) (-5 *1 (-1188))))) 
-(((*1 *2) (-12 (-4 *3 (-562)) (-5 *2 (-638 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-423 *3))))) 
-(((*1 *2) (-12 (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-1259 *1)) (-4 *1 (-342 *3 *4 *5)))) ((*1 *2) (-12 (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *2 (-2 (|:| -2237 (-685 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-685 *3)))) (-5 *1 (-354 *3 *4 *5)) (-4 *5 (-415 *3 *4)))) ((*1 *2) (-12 (-4 *3 (-1234 (-572))) (-5 *2 (-2 (|:| -2237 (-685 (-572))) (|:| |basisDen| (-572)) (|:| |basisInv| (-685 (-572))))) (-5 *1 (-766 *3 *4)) (-4 *4 (-415 (-572) *3)))) ((*1 *2) (-12 (-4 *3 (-353)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -2237 (-685 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-685 *4)))) (-5 *1 (-993 *3 *4 *5 *6)) (-4 *6 (-720 *4 *5)))) ((*1 *2) (-12 (-4 *3 (-353)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 *4)) (-5 *2 (-2 (|:| -2237 (-685 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-685 *4)))) (-5 *1 (-1268 *3 *4 *5 *6)) (-4 *6 (-415 *4 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-1140 (-1152))) (-5 *1 (-397))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-996 *5 *6 *7 *8 *3)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1073 *5 *6 *7 *8)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *8 (-1068 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1105 *5 *6 *7 *8 *3))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-2 (|:| |partsol| (-1259 (-413 (-959 *4)))) (|:| -2237 (-638 (-1259 (-413 (-959 *4))))))) (-5 *3 (-638 *7)) (-4 *4 (-13 (-303) (-151))) (-4 *7 (-956 *4 *6 *5)) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *1 (-930 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) *2)) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-769)) (-5 *1 (-262 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-769)) (-5 *1 (-341 *3 *4 *5 *6)) (-4 *3 (-342 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-769)))) ((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) *2)) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-769)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)))) ((*1 *1) (-4 *1 (-1144)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1166 *7)) (-4 *7 (-956 *6 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1054)) (-5 *2 (-1166 *6)) (-5 *1 (-320 *4 *5 *6 *7))))) 
-(((*1 *1) (-12 (-4 *1 (-410)) (-2959 (|has| *1 (-6 -4593))) (-2959 (|has| *1 (-6 -4585))))) ((*1 *2 *1) (-12 (-4 *1 (-431 *2)) (-4 *2 (-1098)) (-4 *2 (-848)))) ((*1 *2 *1) (-12 (-4 *1 (-831 *2)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-4 *1 (-848))) ((*1 *1) (-5 *1 (-1116)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1166 *1)) (-5 *4 (-1170)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 *1)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-959 *1)) (-4 *1 (-27)) (-5 *2 (-638 *1)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *2 (-638 *1)) (-4 *1 (-29 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *2 (-638 *1)) (-4 *1 (-29 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-312 (-217))) (-5 *4 (-638 (-1170))) (-5 *5 (-1092 (-841 (-217)))) (-5 *2 (-1150 (-217))) (-5 *1 (-296))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-823)) (-5 *1 (-822))))) 
-(((*1 *1 *1) (-5 *1 (-1066)))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-950 (-217))) (-5 *4 (-875)) (-5 *2 (-1264)) (-5 *1 (-477)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1054)) (-4 *1 (-988 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-950 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-950 *3)) (-4 *3 (-1054)) (-4 *1 (-1130 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-950 *3)) (-4 *1 (-1130 *3)) (-4 *3 (-1054)))) ((*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)) (-5 *3 (-217))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-569)) (-5 *3 (-572))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-469))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-923)) (-4 *1 (-374)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 *4)) (-5 *1 (-536 *4)) (-4 *4 (-353)))) ((*1 *2 *1) (-12 (-4 *2 (-848)) (-5 *1 (-709 *2 *3 *4)) (-4 *3 (-1098)) (-14 *4 (-1 (-121) (-2 (|:| -1763 *2) (|:| -3751 *3)) (-2 (|:| -1763 *2) (|:| -3751 *3))))))) 
-(((*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-572)) (-4 *3 (-174)) (-4 *5 (-379 *3)) (-4 *6 (-379 *3)) (-5 *1 (-684 *3 *5 *6 *2)) (-4 *2 (-683 *3 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-1166 (-1166 *4)))) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *8 (-978 *4))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *5 *5 *6 *7 *8 *8 *3) (-12 (-5 *6 (-638 (-121))) (-5 *7 (-685 (-217))) (-5 *8 (-685 (-572))) (-5 *3 (-572)) (-5 *4 (-217)) (-5 *5 (-121)) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *6)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-906 *3))) (-5 *1 (-905 *3)) (-4 *3 (-1098))))) 
-(((*1 *2) (-12 (-5 *2 (-834 (-572))) (-5 *1 (-543)))) ((*1 *1) (-12 (-5 *1 (-834 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1166 *1)) (-4 *1 (-1019))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *4 *4 *5 *6 *5 *4 *7 *3) (-12 (-5 *4 (-685 (-572))) (-5 *5 (-121)) (-5 *7 (-685 (-217))) (-5 *3 (-572)) (-5 *6 (-217)) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-385)) (-5 *1 (-99))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-875)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-923)) (-5 *4 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1260)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-217))) (-5 *2 (-217)) (-5 *1 (-115))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *5 *6 *6 *7 *7 *3) (-12 (-5 *4 (-638 (-121))) (-5 *5 (-685 (-217))) (-5 *6 (-685 (-572))) (-5 *7 (-217)) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-609 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-518 (-413 (-572)) (-234 *4 (-769)) (-858 *3) (-244 *3 (-413 (-572))))) (-14 *3 (-638 (-1170))) (-14 *4 (-769)) (-5 *1 (-519 *3 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-244 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-1054)) (-5 *2 (-959 *5)) (-5 *1 (-951 *4 *5))))) 
-(((*1 *2 *3 *4 *3 *5 *3) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-685 (-572))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $)))))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-385)) (-5 *1 (-786 *3)) (-4 *3 (-613 *2)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-5 *2 (-385)) (-5 *1 (-786 *3)) (-4 *3 (-613 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-959 *4)) (-4 *4 (-1054)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-959 *5)) (-5 *4 (-923)) (-4 *5 (-1054)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-312 *4)) (-4 *4 (-562)) (-4 *4 (-848)) (-4 *4 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-312 *5)) (-5 *4 (-923)) (-4 *5 (-562)) (-4 *5 (-848)) (-4 *5 (-613 *2)) (-5 *2 (-385)) (-5 *1 (-786 *5))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-685 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-415 *3 *4)) (-4 *3 (-174)) (-4 *4 (-1234 *3)) (-5 *2 (-685 *3))))) 
-(((*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *2) (-12 (-4 *2 (-174)) (-4 *2 (-1054)) (-5 *1 (-710 *2 *3)) (-4 *3 (-641 *2)))) ((*1 *2 *2) (-12 (-5 *1 (-835 *2)) (-4 *2 (-174)) (-4 *2 (-1054))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-1264)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098)) (-5 *2 (-1264))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2119 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-335 *3 *4 *5 *6)) (-4 *3 (-368)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 *3 *4 *5)) (-5 *2 (-419 *4 (-413 *4) *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 *6)) (-4 *6 (-13 (-415 *4 *5) (-1044 *4))) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-4 *3 (-303)) (-5 *1 (-419 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-956 *3 *4 *5)) (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-4 *2 (-1054)) (-5 *1 (-914 *2 *3 *5 *6)) (-4 *3 (-326 *2 *5))))) 
-(((*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *4)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *7 (-232 (-4032 *5) (-769))) (-5 *2 (-638 (-638 (-769)))) (-5 *1 (-119 *4 *5 *6 *7 *8)) (-4 *6 (-326 *4 *7)) (-4 *8 (-117))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *7)) (-5 *4 (-1166 *7)) (-4 *5 (-1054)) (-4 *7 (-1054)) (-4 *2 (-1234 *5)) (-5 *1 (-514 *5 *2 *6 *7)) (-4 *6 (-1234 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1054)) (-4 *7 (-1054)) (-4 *4 (-1234 *5)) (-5 *2 (-1166 *7)) (-5 *1 (-514 *5 *4 *6 *7)) (-4 *6 (-1234 *4))))) 
-(((*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2 *2 *2) (-12 (-4 *2 (-13 (-368) (-10 -8 (-15 ** ($ $ (-413 (-572))))))) (-5 *1 (-1124 *3 *2)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 (-171 (-413 (-572))))) (-5 *2 (-638 (-171 *4))) (-5 *1 (-762 *4)) (-4 *4 (-13 (-368) (-846)))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1116)) (-5 *4 (-965 (-171 (-217)))) (-5 *2 (-572)) (-5 *1 (-115))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-4 *5 (-368)) (-5 *2 (-638 (-1199 *5))) (-5 *1 (-1267 *5)) (-5 *4 (-1199 *5))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1152)) (-5 *4 (-572)) (-5 *5 (-685 (-171 (-217)))) (-5 *2 (-1042)) (-5 *1 (-752))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1013))))) 
-(((*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-638 *2)) (-4 *2 (-13 (-436 *6) (-23) (-1044 (-572)) (-1044 *4) (-901 *4) (-162))) (-5 *4 (-1170)) (-4 *6 (-13 (-848) (-562) (-613 (-545)))) (-5 *1 (-1031 *6 *2))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)) (-4 *2 (-554)))) ((*1 *1 *1) (-4 *1 (-1063)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-734))))) 
-(((*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (-12 (-5 *3 (-572)) (-5 *5 (-121)) (-5 *6 (-685 (-217))) (-5 *7 (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN)))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-1166 *3)) (-5 *1 (-46 *4 *3)) (-4 *3 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *4 (-611 $)) $)) (-15 -4492 ((-1121 *4 (-611 $)) $)) (-15 -3972 ($ (-1121 *4 (-611 $)))))))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-171 *4)) (-5 *1 (-180 *4 *3)) (-4 *4 (-13 (-368) (-846))) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-44 *3)) (-4 *3 (-1234 (-53)))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-562) (-151))) (-5 *2 (-2 (|:| -1866 *3) (|:| -1862 *3))) (-5 *1 (-1228 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-613 (-893 *3))) (-4 *3 (-887 *3)) (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-613 (-893 *3))) (-4 *2 (-887 *3)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-84 LSFUN1)))) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *2 (-436 *3)) (-5 *1 (-36 *3 *2)) (-4 *3 (-1044 *4)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-4 (-53) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-53))) (-1216 (-53)))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-53)))) (-1216 (-1166 (-53))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-53) (-769) (-769) (-1166 (-53)))) (|:| AF (-1 (-1166 (-53)) (-769) (-769) (-1216 (-1166 (-53))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-53)) (-769)))) (-638 (-469)))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 *4) (-769))))) (-5 *1 (-488 *4)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 *4 (-769) (-769) (-1166 *4))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 *4) (-769)))) (-638 (-469)))) (-5 *1 (-488 *4)) (-4 *4 (-1044 *3)) (-4 *4 (-13 (-353) (-613 (-572)))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-4 (-413 (-572)) (-1044 *3)) (-4 (-572) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-572)))) (-1216 (-413 (-572))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-572))))) (-1216 (-1166 (-413 (-572)))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-572) (-769) (-769) (-1166 (-572)))) (|:| AF (-1 (-1166 (-413 (-572))) (-769) (-769) (-1216 (-1166 (-413 (-572)))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-572)) (-769)))) (-638 (-469)))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 (-1170))) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) (-1170) *6)) (|:| C (-1 (-638 *5) (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 *4)) (-1216 *4))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 *4))) (-1216 (-1166 *4)))) (|:| |exprStream| (-1 (-1150 *6) *6 *3)) (|:| A (-1 *5 (-769) (-769) (-1166 *5))) (|:| AF (-1 (-1166 *4) (-769) (-769) (-1216 (-1166 *4)))) (|:| AX (-1 *6 (-769) *3 *6)) (|:| C (-1 (-638 *5) (-769)))) (-638 (-469)))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1044 *3)) (-4 *5 (-1044 *3)) (-4 *4 (-368)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 *3) (-1044 (-572)) (-162) (-901 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) (-1170))) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) (-1170) (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-4 (-413 (-959 (-572))) (-1044 *3)) (-4 (-959 (-572)) (-1044 *3)) (-5 *3 (-1170)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1150 (-1216 (-413 (-959 (-572))))) (-1216 (-413 (-959 (-572)))))) (|:| |degreeStream| (-1150 (-769))) (|:| |testStream| (-1 (-1150 (-1216 (-1166 (-413 (-959 (-572)))))) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| |exprStream| (-1 (-1150 (-312 (-572))) (-312 (-572)) *3)) (|:| A (-1 (-959 (-572)) (-769) (-769) (-1166 (-959 (-572))))) (|:| AF (-1 (-1166 (-413 (-959 (-572)))) (-769) (-769) (-1216 (-1166 (-413 (-959 (-572))))))) (|:| AX (-1 (-312 (-572)) (-769) *3 (-312 (-572)))) (|:| C (-1 (-638 (-959 (-572))) (-769)))) (-638 (-469)))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 HPSPEC) (-5 *1 (-492 *4)) (-14 *4 (-1170)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1 HPSPEC (-638 (-469)))) (-5 *1 (-492 *4)) (-14 *4 *3)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-572)) (-5 *2 (-1264)) (-5 *1 (-1013))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-68 LSFUN2)))) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-261 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-517 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-541 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *1) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-5 *2 (-856)) (-5 *1 (-542 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *10 (-237 *9)) (-4 *11 (-117))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)) (-4 *2 (-368)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-368)) (-5 *1 (-653 *4 *2)) (-4 *2 (-650 *4))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-1166 *2)) (-4 *2 (-436 *4)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-36 *4 *2))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-572)) (-4 *4 (-1054)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-914 *4 *2 *5 *6)) (-4 *2 (-326 *4 *5))))) 
-(((*1 *1 *1 *1) (|partial| -12 (-4 *2 (-174)) (-5 *1 (-286 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1234 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-707 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-711 *2 *3 *4 *5 *6)) (-4 *2 (-174)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *3 *5) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-3 (|:| |fn| (-394)) (|:| |fp| (-71 FUNCT1)))) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-685 *1)) (-4 *1 (-353)) (-5 *2 (-1259 *1)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-685 *1)) (-4 *1 (-149)) (-4 *1 (-910)) (-5 *2 (-1259 *1))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-572)) (-4 *1 (-62 *4 *5 *3)) (-4 *4 (-1204)) (-4 *5 (-379 *4)) (-4 *3 (-379 *4))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-1152)) (-5 *3 (-572)) (-5 *1 (-236)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-638 (-1152))) (-5 *3 (-572)) (-5 *4 (-1152)) (-5 *1 (-236)))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) ((*1 *2 *1) (-12 (-4 *1 (-1236 *2 *3)) (-4 *3 (-793)) (-4 *2 (-1054))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1172 (-413 (-572)))) (-5 *1 (-184)) (-5 *3 (-572))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-522 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-848))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-121)) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(((*1 *2) (-12 (-5 *2 (-638 (-769))) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-769))) (-5 *1 (-1262))))) 
-(((*1 *1 *2 *2 *1) (-12 (-5 *1 (-640 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-342 *4 *3 *5)) (-4 *4 (-1214)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-638 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-968 *2)) (-4 *2 (-554))))) 
-(((*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1204)) (-5 *2 (-769)) (-5 *1 (-231 *3 *4 *5)) (-4 *3 (-232 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-322 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-138)) (-5 *2 (-769)))) ((*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-769)) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-366 *3)) (-4 *3 (-1098)))) ((*1 *2) (-12 (-4 *1 (-374)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) ((*1 *2) (-12 (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-430 *3 *4)) (-4 *3 (-431 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-1098)) (-4 *4 (-23)) (-14 *5 *4))) ((*1 *2) (-12 (-4 *4 (-174)) (-4 *5 (-1234 *4)) (-5 *2 (-769)) (-5 *1 (-719 *3 *4 *5)) (-4 *3 (-720 *4 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-820 *3)) (-4 *3 (-848)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-1013)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *3 *3 *3 *4 *5 *5 *5 *5 *5 *5 *6 *6 *6 *3 *3 *5 *7 *3 *8) (-12 (-5 *5 (-685 (-217))) (-5 *6 (-121)) (-5 *7 (-685 (-572))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-70 QPHESS)))) (-5 *3 (-572)) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-572)) (-5 *1 (-198))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1054)) (-4 *4 (-1234 *3)) (-5 *1 (-165 *3 *4 *2)) (-4 *2 (-1234 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-572))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *3 *3 *5 *6 *3 *6 *6 *5 *6 *6 *6 *6 *5 *3 *3 *3 *3 *3 *6 *6 *6 *3 *3 *3 *3 *3 *7 *4 *4 *4 *4 *3 *8 *9) (-12 (-5 *4 (-685 (-217))) (-5 *5 (-121)) (-5 *6 (-217)) (-5 *7 (-685 (-572))) (-5 *8 (-3 (|:| |fn| (-394)) (|:| |fp| (-85 CONFUN)))) (-5 *9 (-3 (|:| |fn| (-394)) (|:| |fp| (-82 OBJFUN)))) (-5 *3 (-572)) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 (-2 (|:| |val| *3) (|:| -1337 *4)))) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1098)) (-4 *4 (-13 (-1054) (-887 *3) (-848) (-613 (-893 *3)))) (-5 *2 (-638 (-1076 *3 *4 *5))) (-5 *1 (-1077 *3 *4 *5)) (-4 *5 (-13 (-436 *4) (-887 *3) (-613 (-893 *3))))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1098)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-638 (-413 (-959 *6)))) (-5 *3 (-413 (-959 *6))) (-4 *6 (-13 (-562) (-1044 (-572)) (-151))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-578 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *2 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *2)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *2 (-1068 *3 *4 *5))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *3 *5 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-751))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-572))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-540 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-368)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-117)) (-4 *2 (-237 *9))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-638 (-638 (-638 (-769)))))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-419 *3 *4 *5 *6)) (-4 *6 (-1044 *4)) (-4 *3 (-303)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-4 *6 (-415 *4 *5)) (-14 *7 (-1259 *6)) (-5 *1 (-420 *3 *4 *5 *6 *7)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 *6)) (-4 *6 (-415 *4 *5)) (-4 *4 (-1000 *3)) (-4 *5 (-1234 *4)) (-4 *3 (-303)) (-5 *1 (-420 *3 *4 *5 *6 *7)) (-14 *7 *2)))) 
-(((*1 *2 *3 *4 *4 *5 *3 *3 *4 *3 *3 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1098)) (-4 *2 (-1204))))) 
-(((*1 *1) (-4 *1 (-39))) ((*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *1) (-5 *1 (-856))) ((*1 *1) (-12 (-4 *2 (-457)) (-4 *3 (-848)) (-4 *4 (-794)) (-5 *1 (-995 *2 *3 *4 *5)) (-4 *5 (-956 *2 *4 *3)))) ((*1 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) ((*1 *1) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) ((*1 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) ((*1 *1) (-5 *1 (-1173))) ((*1 *1) (-5 *1 (-1174)))) 
-(((*1 *1) (-12 (-4 *1 (-329 *2)) (-4 *2 (-374)) (-4 *2 (-368)))) ((*1 *2 *3) (-12 (-5 *3 (-923)) (-5 *2 (-1259 *4)) (-5 *1 (-536 *4)) (-4 *4 (-353))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-685 *4)))) ((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-685 *4)) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) ((*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-685 *3))))) 
-(((*1 *2 *3 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *5 (-685 (-217))) (-5 *4 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1098)) (-4 *2 (-1204))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-330))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-5 *2 (-638 *8)) (-5 *1 (-31 *5 *6 *3 *7 *8)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-923)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-5 *2 (-3 (-638 *8) "failed" "Infinite" (-572))) (-5 *1 (-32 *5 *6 *3 *7 *8)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1098)) (-5 *2 (-1152)))) ((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *3 *4 *4 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-379 *2)) (-4 *2 (-1204)))) ((*1 *2 *2) (-12 (-4 *3 (-1054)) (-5 *1 (-449 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-1098)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1173)))) ((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-13 (-303) (-10 -8 (-15 -1466 ((-424 $) $))))) (-4 *4 (-1234 *3)) (-5 *1 (-512 *3 *4 *5)) (-4 *5 (-415 *3 *4))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-638 (-312 (-217)))) (-5 *3 (-217)) (-5 *2 (-121)) (-5 *1 (-204))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-607 *2)) (-4 *2 (-1098)))) ((*1 *1 *1) (-5 *1 (-627)))) 
-(((*1 *1 *1) (-12 (-5 *1 (-672 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-5 *1 (-820 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-12 (-5 *1 (-894 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-1198 *2 *3 *4 *5)) (-4 *2 (-562)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *5 (-1068 *2 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-1246 *3)) (-4 *3 (-1204)))) ((*1 *1 *1) (-12 (-4 *1 (-1246 *2)) (-4 *2 (-1204))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-237 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-984 *3 *4 *2 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)) (-4 *5 (-1068 *3 *4 *2))))) 
-(((*1 *2 *3 *4 *4 *5 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-261 *3)) (-4 *3 (-1098)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-261 *3)) (-4 *3 (-1098)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-517 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-517 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-541 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-541 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-5 *2 (-121)) (-5 *1 (-542 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *10 (-237 *9)) (-4 *11 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-5 *1 (-542 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *7 (-978 *3)) (-4 *10 (-237 *9)) (-4 *11 (-117)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-861 *3)) (-14 *3 (-866)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-863 *3)) (-4 *3 (-353)))) ((*1 *2 *1) (-12 (-4 *1 (-864)) (-5 *2 (-856)))) ((*1 *2 *1) (-12 (-5 *2 (-856)) (-5 *1 (-866))))) 
-(((*1 *2 *3 *4 *4 *5 *3 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *5 (-217)) (-5 *2 (-1042)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-4 *2 (-1234 *4)) (-5 *1 (-810 *4 *2 *3 *5)) (-4 *4 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *3 (-650 *2)) (-4 *5 (-650 (-413 *2)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-905 (-572))) (-5 *1 (-919)))) ((*1 *2) (-12 (-5 *2 (-905 (-572))) (-5 *1 (-919))))) 
-(((*1 *1 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-155 *2)) (-4 *2 (-1204)) (-4 *2 (-1098))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)) (-4 *2 (-436 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1090 *2)) (-4 *2 (-436 *4)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1090 *1)) (-4 *1 (-162)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-162)) (-5 *2 (-1170)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-474 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1277 *3 *4)) (-4 *3 (-848)) (-4 *4 (-174))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-151))) (-5 *2 (-638 *3)) (-5 *1 (-1228 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1051 *4 *5)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-638 (-638 (-1030 (-413 *4))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170))))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-959 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *5))))) (-5 *1 (-1283 *5 *6 *7)) (-14 *6 (-638 (-1170))) (-14 *7 (-638 (-1170))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-959 *4))) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-5 *2 (-638 (-638 (-1030 (-413 *4))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-14 *6 (-638 (-1170)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *6 (-232 (-4032 *5) (-769))) (-4 *7 (-978 *4)) (-4 *8 (-645 *4)) (-4 *9 (-926 *4 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-572)) (-5 *1 (-262 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-956 *3 *6 (-858 *4))) (-4 *6 (-232 (-4032 *4) (-769))) (-4 *7 (-978 *3)) (-4 *8 (-645 *3)) (-4 *9 (-926 *3 *8)) (-4 *10 (-237 *9)) (-4 *11 (-540 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-260 *11)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-353)) (-14 *4 (-638 (-1170))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-874 *3 *4 *5)) (-4 *3 (-368)) (-14 *4 (-638 (-1170))) (-4 *5 (-117))))) 
-(((*1 *1) (-12 (-4 *3 (-1098)) (-5 *1 (-886 *2 *3 *4)) (-4 *2 (-1098)) (-4 *4 (-662 *3)))) ((*1 *1) (-12 (-5 *1 (-890 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1170)) (-5 *4 (-959 (-572))) (-5 *2 (-330)) (-5 *1 (-332))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-501))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| -1866 (-413 (-572))) (|:| -1862 (-413 (-572)))))) (-5 *2 (-638 (-217))) (-5 *1 (-301))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1068 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-53)) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *6) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 *6)) (-4 *6 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 *7) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 *7)) (-4 *7 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-572))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 *8) (|:| -3377 (-769)))) (-638 *6) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 *6)) (-4 *6 (-368)) (-14 *11 (-1 *8 *6)) (-4 *9 (-13 (-848) (-562))) (-14 *10 (-1 *6 *9)) (-5 *2 (-638 (-2 (|:| -3616 *8) (|:| -3377 (-769))))) (-5 *1 (-490 *6 *7 *8 *9 *10 *11)) (-4 *7 (-457)) (-4 *8 (-13 (-436 (-572)) (-562) (-1044 *9) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 *9) (|:| -3377 (-769)))) (-638 *7) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 *7)) (-4 *7 (-368)) (-14 *12 (-1 *9 *7)) (-4 *10 (-13 (-848) (-562))) (-14 *11 (-1 *7 *10)) (-5 *2 (-638 (-2 (|:| -3616 *9) (|:| -3377 (-769))))) (-5 *1 (-490 *7 *8 *9 *10 *11 *12)) (-4 *8 (-457)) (-4 *9 (-13 (-436 (-572)) (-562) (-1044 *10) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-959 (-572)))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-739 *6 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *6 (-572)))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *3 (-638 (-413 (-740 *6 (-572))))) (-14 *6 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *6 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-638 (-1 (-638 (-2 (|:| -3616 (-739 *7 (-572))) (|:| -3377 (-769)))) (-638 (-413 (-740 *7 (-572)))) (-638 (-469))))) (-5 *5 (-638 (-1170))) (-5 *6 (-638 (-469))) (-5 *3 (-638 (-413 (-740 *7 (-572))))) (-14 *7 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *7 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *7))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-2 (|:| |integrand| *3) (|:| |intvar| *3)))) (-5 *1 (-589 *3)) (-4 *3 (-368))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-457)))) ((*1 *1 *1 *1) (-4 *1 (-457))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-965 (-1208))) (-5 *4 (-572)) (-5 *2 (-1208)) (-5 *1 (-961))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1166 *1)) (-5 *3 (-1170)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-1166 *1)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-959 *1)) (-4 *1 (-27)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-848) (-562))))) ((*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-848) (-562)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1204)) (-5 *1 (-1150 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-641 *3)) (-4 *3 (-1054)) (-5 *1 (-710 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-835 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-662 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-638 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-1170))) (-5 *1 (-1170))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-638 (-959 *3))) (-4 *3 (-457)) (-5 *1 (-365 *3 *4)) (-14 *4 (-638 (-1170))))) ((*1 *2 *2) (|partial| -12 (-5 *2 (-638 (-781 *3 (-858 *4)))) (-4 *3 (-457)) (-14 *4 (-638 (-1170))) (-5 *1 (-623 *3 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219)))) ((*1 *1 *1) (-4 *1 (-624))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-572))) (-5 *4 (-906 (-572))) (-5 *2 (-685 (-572))) (-5 *1 (-593)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-572))) (-5 *2 (-638 (-685 (-572)))) (-5 *1 (-593)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-572))) (-5 *4 (-638 (-906 (-572)))) (-5 *2 (-638 (-685 (-572)))) (-5 *1 (-593))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-978 *3)) (-4 *3 (-368)) (-5 *2 (-572))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1166 *3)) (-4 *3 (-353)) (-5 *1 (-361 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-312 *3)) (-4 *3 (-562)) (-4 *3 (-848))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))) (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *2 (-121)) (-5 *1 (-519 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-217)) (-5 *2 (-413 (-572))) (-5 *1 (-301))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1117 *2)) (-4 *2 (-1204)))) ((*1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-559 *2)) (-4 *2 (-13 (-410) (-1190))))) ((*1 *1 *1 *1) (-4 *1 (-794)))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-956 *4 *7 (-858 *5))) (-4 *7 (-232 (-4032 *5) (-769))) (-4 *8 (-978 *4)) (-4 *9 (-645 *4)) (-4 *10 (-926 *4 *9)) (-4 *11 (-237 *10)) (-4 *12 (-540 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-572)) (-5 *1 (-471 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-260 *12)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-873 *4 *5 *6)) (-4 (-863 *4) (-374)) (-4 *4 (-353)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-923)) (-5 *2 (-572)) (-5 *1 (-874 *4 *5 *6)) (-4 *4 (-374)) (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-160 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *8)) (-4 *8 (-1073 *4 *5 *6 *7))))) 
-(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *4 (-1 *3)) (-4 *3 (-848)) (-4 *5 (-794)) (-4 *6 (-562)) (-4 *7 (-956 *6 *5 *3)) (-5 *1 (-470 *5 *3 *6 *7 *2)) (-4 *2 (-13 (-1044 (-413 (-572))) (-368) (-10 -8 (-15 -3972 ($ *7)) (-15 -4487 (*7 $)) (-15 -4492 (*7 $)))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-496 *4 *5))) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *2 (-638 (-244 *4 *5))) (-5 *1 (-626 *4 *5))))) 
-(((*1 *1 *1) (-5 *1 (-1066)))) 
-(((*1 *1 *1) (-4 *1 (-39))) ((*1 *1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *1 *1) (-5 *1 (-123))) ((*1 *1 *1) (-5 *1 (-173))) ((*1 *1 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *1 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *1 *1) (-4 *1 (-554))) ((*1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) ((*1 *1 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) ((*1 *1 *1) (-12 (-4 *1 (-1130 *2)) (-4 *2 (-1054)))) ((*1 *1 *1) (-12 (-5 *1 (-1133 *2 *3)) (-4 *2 (-13 (-1098) (-39))) (-4 *3 (-13 (-1098) (-39))))) ((*1 *1 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-366 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-769)) (-5 *1 (-392 *4)) (-4 *4 (-1098)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *2 (-23)) (-5 *1 (-642 *4 *2 *5)) (-4 *4 (-1098)) (-14 *5 *2))) ((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *2 (-769)) (-5 *1 (-820 *4)) (-4 *4 (-848))))) 
-(((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1034 *5 *6 *7 *8))) (-5 *1 (-1034 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-638 *8)) (-5 *4 (-121)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-638 (-1139 *5 *6 *7 *8))) (-5 *1 (-1139 *5 *6 *7 *8))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-798 *2)) (-4 *2 (-174))))) 
-(((*1 *1 *2 *1) (-12 (-5 *1 (-638 *2)) (-4 *2 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1150 *2)) (-4 *2 (-1204))))) 
-(((*1 *2) (-12 (-4 *4 (-1214)) (-4 *5 (-1234 *4)) (-4 *6 (-1234 (-413 *5))) (-5 *2 (-769)) (-5 *1 (-341 *3 *4 *5 *6)) (-4 *3 (-342 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-769))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1204)) (-5 *2 (-121))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-303) (-1044 (-572)) (-634 (-572)) (-151))) (-5 *1 (-805 *4 *2)) (-4 *2 (-13 (-29 *4) (-1190) (-966)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856)))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-1095 *3)))) ((*1 *1) (-12 (-4 *1 (-1095 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-933))))) 
-(((*1 *1) (-5 *1 (-1173)))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1102)) (-5 *3 (-772)) (-5 *1 (-57))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-848)) (-5 *2 (-2 (|:| -4513 (-572)) (|:| |var| (-611 *1)))) (-4 *1 (-436 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1152)) (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 (-2 (|:| |eqzro| (-638 *7)) (|:| |neqzro| (-638 *7)) (|:| |wcond| (-638 (-959 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *4)))) (|:| -2237 (-638 (-1259 (-413 (-959 *4)))))))))) (-5 *1 (-930 *4 *5 *6 *7)) (-4 *7 (-956 *4 *6 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-1166 *3))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *4 (-1 *2 *2)) (-4 *2 (-641 *5)) (-4 *5 (-1054)) (-5 *1 (-59 *5 *2 *3)) (-4 *3 (-850 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-685 *3)) (-4 *1 (-423 *3)) (-4 *3 (-174)))) ((*1 *2 *1 *2 *2) (-12 (-4 *1 (-850 *2)) (-4 *2 (-1054)))) ((*1 *2 *3 *2 *2 *4 *5) (-12 (-5 *4 (-101 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-1054)) (-5 *1 (-851 *2 *3)) (-4 *3 (-850 *2))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-933))))) 
-(((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| -2352 (-638 *9)) (|:| -1337 *4) (|:| |ineq| (-638 *9)))) (-5 *1 (-996 *6 *7 *8 *9 *4)) (-5 *3 (-638 *9)) (-4 *4 (-1073 *6 *7 *8 *9)))) ((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *9 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| -2352 (-638 *9)) (|:| -1337 *4) (|:| |ineq| (-638 *9)))) (-5 *1 (-1105 *6 *7 *8 *9 *4)) (-5 *3 (-638 *9)) (-4 *4 (-1073 *6 *7 *8 *9))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *3 (-638 (-258))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-258)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-477)))) ((*1 *2 *1) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-477))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-638 (-217)))) (-5 *1 (-932))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 (-121) *9)) (-5 *5 (-1 (-121) *9 *9)) (-4 *9 (-1068 *6 *7 *8)) (-4 *6 (-562)) (-4 *7 (-794)) (-4 *8 (-848)) (-5 *2 (-2 (|:| |bas| *1) (|:| -1615 (-638 *9)))) (-5 *3 (-638 *9)) (-4 *1 (-1198 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1 (-121) *8 *8)) (-4 *8 (-1068 *5 *6 *7)) (-4 *5 (-562)) (-4 *6 (-794)) (-4 *7 (-848)) (-5 *2 (-2 (|:| |bas| *1) (|:| -1615 (-638 *8)))) (-5 *3 (-638 *8)) (-4 *1 (-1198 *5 *6 *7 *8))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1234 (-53))))) ((*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |less| (-131 *3)) (|:| |greater| (-131 *3)))) (-5 *1 (-131 *3)) (-4 *3 (-848)))) ((*1 *2 *1) (-12 (-4 *3 (-1098)) (-5 *2 (-638 *1)) (-4 *1 (-237 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-589 *4)) (-4 *4 (-13 (-29 *3) (-1190))) (-4 *3 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *1 (-587 *3 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-589 (-413 (-959 *3)))) (-4 *3 (-13 (-457) (-1044 (-572)) (-848) (-634 (-572)))) (-5 *1 (-592 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-368)) (-5 *2 (-2 (|:| -2071 *3) (|:| |special| *3))) (-5 *1 (-723 *5 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1259 *5)) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-638 (-638 (-685 *5)))) (-5 *1 (-1036 *5)) (-5 *3 (-638 (-685 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1259 (-1259 *5))) (-4 *5 (-368)) (-4 *5 (-1054)) (-5 *2 (-638 (-638 (-685 *5)))) (-5 *1 (-1036 *5)) (-5 *3 (-638 (-685 *5))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-143)) (-5 *2 (-638 *1)) (-4 *1 (-1137)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-148)) (-5 *2 (-638 *1)) (-4 *1 (-1137))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-848)) (-4 *4 (-368)) (-4 *5 (-794)) (-5 *1 (-518 *4 *5 *6 *2)) (-4 *2 (-956 *4 *5 *6)))) ((*1 *1 *1 *2) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-518 *3 *4 *5 *2)) (-4 *2 (-956 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1130 *3)) (-4 *3 (-1054)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-923)) (-5 *2 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-5 *1 (-350 *4)) (-4 *4 (-353))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1152)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-1152))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-825)) (-5 *1 (-826))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-508))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 (-1259 *4))) (-4 *4 (-1054)) (-5 *2 (-685 *4)) (-5 *1 (-1036 *4))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1170)) (-5 *6 (-638 (-611 *3))) (-5 *5 (-611 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *7))) (-4 *7 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-2 (|:| -3444 *3) (|:| |coeff| *3))) (-5 *1 (-563 *7 *3))))) 
-(((*1 *1 *1 *1) (|partial| -4 *1 (-138)))) 
-(((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-214 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-848)) (-5 *2 (-769)) (-5 *1 (-498 *4)))) ((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-503 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-769)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4602)) (-4 *1 (-503 *4)) (-4 *4 (-1204)) (-5 *2 (-769)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-1007 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4602)) (-5 *2 (-769)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4602)) (-4 *4 (-1098)) (-5 *2 (-769)) (-5 *1 (-1140 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-327 *3)) (-4 *3 (-1204)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-529 *3 *4)) (-4 *3 (-1204)) (-14 *4 (-572))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-336 *5 *6 *7 *8)) (-4 *5 (-436 *4)) (-4 *6 (-1234 *5)) (-4 *7 (-1234 (-413 *6))) (-4 *8 (-342 *5 *6 *7)) (-4 *4 (-13 (-848) (-562) (-1044 (-572)))) (-5 *2 (-121)) (-5 *1 (-912 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-336 (-413 (-572)) *4 *5 *6)) (-4 *4 (-1234 (-413 (-572)))) (-4 *5 (-1234 (-413 *4))) (-4 *6 (-342 (-413 (-572)) *4 *5)) (-5 *2 (-121)) (-5 *1 (-913 *4 *5 *6))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-685 *3)) (-4 *3 (-303)) (-5 *1 (-695 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-638 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-4 *2 (-13 (-408) (-10 -7 (-15 -3972 (*2 *4)) (-15 -3633 ((-923) *2)) (-15 -2237 ((-1259 *2) (-923))) (-15 -2611 (*2 *2))))) (-5 *1 (-360 *2 *4))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-735 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-96 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-893 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-1117 *3)) (-4 *3 (-1204)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1140 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3190 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *9 (-232 (-4032 *7) (-769))) (-5 *2 (-2 (|:| |mult| (-769)) (|:| |subMult| (-769)) (|:| |blUpRec| (-638 (-2 (|:| |recTransStr| (-244 (-3921 (QUOTE X) (QUOTE -2301)) *6)) (|:| |recPoint| (-33 *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (-5 *1 (-119 *6 *7 *8 *9 *5)) (-5 *3 (-244 (-3921 (QUOTE X) (QUOTE -2301)) *6)) (-5 *4 (-33 *6)) (-4 *8 (-326 *6 *9)) (-4 *5 (-117))))) 
-(((*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-950 *5)) (-5 *3 (-769)) (-4 *5 (-1054)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1170)) (-5 *5 (-638 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *6))) (-4 *6 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-563 *6 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-769)) (-5 *1 (-784 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-174))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-769)) (-4 *1 (-225 *4)) (-4 *4 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-225 *3)) (-4 *3 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-227)) (-5 *2 (-769)))) ((*1 *1 *1) (-4 *1 (-227))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *4)) (-4 *4 (-1234 *3)))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-368) (-151))) (-5 *1 (-405 *2 *3)) (-4 *3 (-1234 *2)))) ((*1 *1) (-12 (-4 *1 (-650 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 *4)) (-5 *3 (-638 (-769))) (-4 *1 (-901 *4)) (-4 *4 (-1098)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-769)) (-4 *1 (-901 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *1 (-901 *3)) (-4 *3 (-1098)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-901 *2)) (-4 *2 (-1098))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2) (-12 (-5 *2 (-385)) (-5 *1 (-1046))))) 
-(((*1 *1) (-12 (-4 *1 (-431 *2)) (-4 *2 (-374)) (-4 *2 (-1098))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-244 *4 *5))) (-5 *2 (-244 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *1 (-626 *4 *5))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1231 *5 *4)) (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-638 *4)) (-5 *1 (-1112 *4 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-4 *1 (-650 *3)) (-4 *3 (-1054)) (-4 *3 (-368)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-769)) (-5 *4 (-1 *5 *5)) (-4 *5 (-368)) (-5 *1 (-653 *5 *2)) (-4 *2 (-650 *5))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4602)) (-4 *1 (-229 *3)) (-4 *3 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-279 *3)) (-4 *3 (-1204))))) 
-(((*1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-368))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-252))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-53))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-53))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-486)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-13 (-353) (-613 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-572)))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-489)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *5)) (-5 *4 (-638 (-469))) (-4 *5 (-368)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-848) (-562))) (-14 *9 (-1 *5 *8)) (-5 *2 (-638 (-2 (|:| -3616 *7) (|:| -3377 (-769))))) (-5 *1 (-490 *5 *6 *7 *8 *9 *10)) (-4 *6 (-457)) (-4 *7 (-13 (-436 (-572)) (-562) (-1044 *8) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-848) (-562))) (-14 *8 (-1 *4 *7)) (-5 *2 (-638 (-2 (|:| -3616 *6) (|:| -3377 (-769))))) (-5 *1 (-490 *4 *5 *6 *7 *8 *9)) (-4 *5 (-457)) (-4 *6 (-13 (-436 (-572)) (-562) (-1044 *7) (-1044 (-1170)) (-1044 (-572)) (-162) (-901 (-1170)) (-10 -8 (-15 * ($ $ $)) (-15 -1379 ($ $ $)) (-15 ** ($ $ $)) (-15 -4347 ($ $)) (-15 -3425 ($ $)) (-15 -4357 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *4 (-638 (-469))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-959 (-572))))) (-5 *2 (-638 (-2 (|:| -3616 (-312 (-572))) (|:| -3377 (-769))))) (-5 *1 (-491)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-413 (-740 *5 (-572))))) (-5 *4 (-638 (-469))) (-14 *5 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *5 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-413 (-740 *4 (-572))))) (-14 *4 (-1170)) (-5 *2 (-638 (-2 (|:| -3616 (-739 *4 (-572))) (|:| -3377 (-769))))) (-5 *1 (-492 *4))))) 
-(((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1169)) (-5 *1 (-330)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1169)) (-5 *1 (-330))))) 
-(((*1 *2 *3 *4 *5 *6 *7 *7 *8) (-12 (-5 *3 (-2 (|:| |det| *12) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572))))) (-5 *4 (-685 *12)) (-5 *5 (-638 (-413 (-959 *9)))) (-5 *6 (-638 (-638 *12))) (-5 *7 (-769)) (-5 *8 (-572)) (-4 *9 (-13 (-303) (-151))) (-4 *12 (-956 *9 *11 *10)) (-4 *10 (-13 (-848) (-613 (-1170)))) (-4 *11 (-794)) (-5 *2 (-2 (|:| |eqzro| (-638 *12)) (|:| |neqzro| (-638 *12)) (|:| |wcond| (-638 (-959 *9))) (|:| |bsoln| (-2 (|:| |partsol| (-1259 (-413 (-959 *9)))) (|:| -2237 (-638 (-1259 (-413 (-959 *9))))))))) (-5 *1 (-930 *9 *10 *11 *12))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4602)) (-4 *1 (-229 *3)) (-4 *3 (-1098)))) ((*1 *1 *2 *1) (-12 (|has| *1 (-6 -4602)) (-4 *1 (-229 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-279 *2)) (-4 *2 (-1204)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) ((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-609 *3 *2)) (-4 *3 (-1098)) (-4 *2 (-1098)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-572)) (-4 *4 (-1098)) (-5 *1 (-733 *4)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-572)) (-5 *1 (-733 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1134 *3 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-848)) (-5 *1 (-498 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *3 (-1234 *4)) (-4 *2 (-1249 *4)) (-5 *1 (-1252 *4 *3 *5 *2)) (-4 *5 (-650 *3))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)) (-5 *2 (-121)) (-5 *1 (-995 *3 *4 *5 *6)) (-4 *6 (-956 *3 *5 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1133 *3 *4)) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-767)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042)))) (-5 *1 (-573)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-767)) (-5 *4 (-1066)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))) (|:| |extra| (-1042)))) (-5 *1 (-573)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-788)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-788)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)) (|:| |extra| (-1042)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-801)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)))))) ((*1 *2 *3) (-12 (-5 *3 (-809)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-806)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-809)) (-5 *4 (-1066)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-806)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-837)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-837)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)))))) ((*1 *2 *3) (-12 (-5 *3 (-839)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-838)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-839)) (-5 *4 (-1066)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-838)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-896)) (-5 *3 (-1066)) (-5 *4 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *2 (-2 (|:| -1540 (-385)) (|:| |explanations| (-1152)))))) ((*1 *2 *3) (-12 (-5 *3 (-899)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-898)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-899)) (-5 *4 (-1066)) (-5 *2 (-2 (|:| -1540 (-385)) (|:| -3201 (-1152)) (|:| |explanations| (-638 (-1152))))) (-5 *1 (-898))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-923)) (|has| *1 (-6 -4593)) (-4 *1 (-410)))) ((*1 *2) (-12 (-4 *1 (-410)) (-5 *2 (-923)))) ((*1 *2 *2) (-12 (-5 *2 (-923)) (-5 *1 (-694)))) ((*1 *2) (-12 (-5 *2 (-923)) (-5 *1 (-694))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-572) (-572))) (-5 *1 (-366 *3)) (-4 *3 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-769) (-769))) (-5 *1 (-392 *3)) (-4 *3 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-312 (-572))) (-5 *1 (-487 *3)) (-4 *3 (-13 (-353) (-613 (-572))))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-638 *3)) (-4 *3 (-1234 *5)) (-4 *5 (-303)) (-5 *2 (-769)) (-5 *1 (-461 *5 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-1098)) (-4 *1 (-229 *3)))) ((*1 *1) (-12 (-4 *1 (-229 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *8 (-978 *5)) (-4 *4 (-926 *5 *2)) (-4 *9 (-237 *4)) (-4 *10 (-540 *5 *6 *3 *7 *8 *2 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-645 *5)) (-5 *1 (-471 *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (-4 *11 (-260 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-244 *6 *5)) (-5 *4 (-928 *5)) (-4 *5 (-353)) (-14 *6 (-638 (-1170))) (-5 *2 (-780 (-863 *5))) (-5 *1 (-873 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-244 *6 *5)) (-5 *4 (-927 *5)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-5 *2 (-780 *5)) (-5 *1 (-874 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-638 *2)) (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *2 (-645 *5)) (-5 *1 (-877 *5 *6 *3 *7 *8 *2 *9)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)) (-4 *9 (-926 *5 *2)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *2 (-645 *5)) (-5 *1 (-877 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)) (-4 *4 (-926 *5 *2)))) ((*1 *2 *3 *3 *4) (-12 (-4 *5 (-368)) (-14 *6 (-638 (-1170))) (-4 *7 (-232 (-4032 *6) (-769))) (-4 *2 (-645 *5)) (-5 *1 (-877 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-956 *5 *7 (-858 *6))) (-4 *8 (-978 *5)) (-4 *4 (-926 *5 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-572)) (-4 *6 (-368)) (-14 *7 (-638 (-1170))) (-4 *8 (-232 (-4032 *7) (-769))) (-4 *2 (-645 *6)) (-5 *1 (-877 *6 *7 *3 *8 *9 *2 *4)) (-4 *3 (-956 *6 *8 (-858 *7))) (-4 *9 (-978 *6)) (-4 *4 (-926 *6 *2))))) 
-(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-883 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-638 *5) *6)) (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-638 (-2 (|:| -3211 *5) (|:| -2352 *3)))) (-5 *1 (-810 *5 *6 *3 *7)) (-4 *3 (-650 *6)) (-4 *7 (-650 (-413 *6)))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1108)) (-5 *3 (-572))))) 
-(((*1 *2 *3) (-12 (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *2 (-638 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572)))))) (-5 *1 (-519 *4 *5)) (-5 *3 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572)))))))) 
-(((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-685 (-217))) (-5 *4 (-572)) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 (-638 (-2 (|:| -2148 *4) (|:| -1763 (-1116)))))) (-4 *4 (-353)) (-5 *2 (-685 *4)) (-5 *1 (-350 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-171 (-572))) (-5 *2 (-121)) (-5 *1 (-451)))) ((*1 *2 *3) (-12 (-5 *3 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))) (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *2 (-121)) (-5 *1 (-519 *4 *5)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-968 *3)) (-4 *3 (-554)))) ((*1 *2 *1) (-12 (-4 *1 (-1214)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1170)) (-5 *2 (-1264)) (-5 *1 (-1173)))) ((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-1174))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-769)) (-5 *1 (-590 *2)) (-4 *2 (-554))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (|has| *2 (-6 (-4604 "*"))) (-4 *2 (-1054)))) ((*1 *2 *3) (-12 (-4 *4 (-379 *2)) (-4 *5 (-379 *2)) (-4 *2 (-174)) (-5 *1 (-684 *2 *4 *5 *3)) (-4 *3 (-683 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2)) (|has| *2 (-6 (-4604 "*"))) (-4 *2 (-1054))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-1191 *3))) (-5 *1 (-1191 *3)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-597 *2)) (-4 *2 (-43 (-413 (-572)))) (-4 *2 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5 *4)) (-4 *5 (-1098)) (-4 *4 (-1098)) (-4 *6 (-1098)) (-5 *2 (-1 *6 *5)) (-5 *1 (-679 *5 *4 *6))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-1000 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-144 *4 *5 *3)) (-4 *3 (-379 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-1000 *4)) (-5 *2 (-2 (|:| |num| *6) (|:| |den| *4))) (-5 *1 (-516 *4 *5 *6 *3)) (-4 *6 (-379 *4)) (-4 *3 (-379 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-685 *5)) (-4 *5 (-1000 *4)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |num| (-685 *4)) (|:| |den| *4))) (-5 *1 (-688 *4 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-368) (-151) (-1044 (-413 (-572))))) (-4 *6 (-1234 *5)) (-5 *2 (-2 (|:| -2352 *7) (|:| |rh| (-638 (-413 *6))))) (-5 *1 (-808 *5 *6 *7 *3)) (-5 *4 (-638 (-413 *6))) (-4 *7 (-650 *6)) (-4 *3 (-650 (-413 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-1000 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-1227 *4 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-385)) (-5 *1 (-199))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1116)) (-5 *1 (-113)))) ((*1 *2 *1) (|partial| -12 (-5 *1 (-370 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-1152)) (-5 *1 (-1186))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-906 *3))) (-4 *3 (-1098)) (-5 *1 (-905 *3))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *4 (-562)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3462 *4))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-801)) (-5 *3 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *2 (-1042))))) 
-(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-950 *3) (-950 *3))) (-5 *1 (-176 *3)) (-4 *3 (-13 (-368) (-1190) (-1009)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-769) "arbitrary")) (-5 *1 (-469))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-1152))) (-5 *2 (-1152)) (-5 *1 (-186)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-856))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-572)) (|has| *1 (-6 -4593)) (-4 *1 (-410)) (-5 *2 (-923))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-950 *4))) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-368)) (-4 *5 (-562)) (-5 *2 (-2 (|:| |minor| (-638 (-923))) (|:| -2352 *3) (|:| |minors| (-638 (-638 (-923)))) (|:| |ops| (-638 *3)))) (-5 *1 (-95 *5 *3)) (-5 *4 (-923)) (-4 *3 (-650 *5))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-2 (|:| |bas| (-485 *4 *5 *6 *7)) (|:| -1615 (-638 *7)))) (-5 *1 (-985 *4 *5 *6 *7)) (-5 *3 (-638 *7))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-638 *5))))) 
-(((*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-965 (-217))) (-5 *3 (-1116)) (-5 *4 (-217)) (-5 *1 (-115))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-1183))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-962)) (-5 *2 (-1092 (-217))))) ((*1 *2 *1) (-12 (-4 *1 (-982)) (-5 *2 (-1092 (-217)))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-638 (-572))))) ((*1 *2 *3) (-12 (-5 *2 (-1150 (-638 (-572)))) (-5 *1 (-884)) (-5 *3 (-638 (-572)))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-669 *3)) (-4 *3 (-1204)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-638 *3)) (-5 *1 (-1083 *3)) (-4 *3 (-139))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1042))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-572)) (-5 *4 (-685 (-217))) (-5 *2 (-1042)) (-5 *1 (-753))))) 
-(((*1 *2) (-12 (-4 *4 (-368)) (-5 *2 (-769)) (-5 *1 (-328 *3 *4)) (-4 *3 (-329 *4)))) ((*1 *2) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-769))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-5 *2 (-171 (-312 *4))) (-5 *1 (-182 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 (-171 *4)))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-457) (-848) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-171 *3)) (-5 *1 (-1194 *4 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *4)))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-638 *1)) (-4 *1 (-1068 *4 *5 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1198 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1198 *4 *5 *6 *3)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-638 (-923))) (-5 *1 (-1262)))) ((*1 *2 *2) (-12 (-5 *2 (-638 (-923))) (-5 *1 (-1262))))) 
-(((*1 *1 *1 *1) (-4 *1 (-554)))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-572)) (-5 *3 (-965 (-385))) (-5 *1 (-115))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-685 (-312 (-217)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-385)) (|:| |stabilityFactor| (-385)))) (-5 *1 (-199))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-834 (-217))) (-5 *1 (-219))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-395)) (-5 *2 (-1152))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1108)) (-5 *3 (-572))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-385)) (-5 *2 (-1152)) (-5 *1 (-301))))) 
-(((*1 *2) (-12 (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-910)) (-5 *1 (-463 *3 *4 *2 *5)) (-4 *5 (-956 *2 *3 *4)))) ((*1 *2) (-12 (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-910)) (-5 *1 (-907 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) ((*1 *2) (-12 (-4 *2 (-910)) (-5 *1 (-908 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-638 (-1231 *5 *4))) (-5 *1 (-1112 *4 *5)) (-5 *3 (-1231 *5 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1246 *3)) (-4 *3 (-1204)) (-5 *2 (-769))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-956 *3 *4 *2)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *2 (-848)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-794)) (-4 *5 (-1054)) (-4 *6 (-956 *5 *4 *2)) (-4 *2 (-848)) (-5 *1 (-957 *4 *2 *5 *6 *3)) (-4 *3 (-13 (-368) (-10 -8 (-15 -3972 ($ *6)) (-15 -4487 (*6 $)) (-15 -4492 (*6 $))))))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-413 (-959 *4))) (-4 *4 (-562)) (-5 *2 (-1170)) (-5 *1 (-1049 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (-5 *1 (-330))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-4 *3 (-1054)) (-4 *1 (-683 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1 *2) (-12 (-4 *2 (-1054)) (-4 *1 (-1119 *3 *2 *4 *5)) (-4 *4 (-232 *3 *2)) (-4 *5 (-232 *3 *2))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1068 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-794)) (-4 *4 (-848)) (-4 *2 (-562))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-424 *3)) (-5 *1 (-565 *3)) (-4 *3 (-554)))) ((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-5 *2 (-424 *3)) (-5 *1 (-738 *4 *5 *6 *3)) (-4 *3 (-956 *6 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-303)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-738 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) ((*1 *2 *1) (-12 (-4 *3 (-457)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-424 *1)) (-4 *1 (-956 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-848)) (-4 *5 (-794)) (-4 *6 (-457)) (-5 *2 (-424 *3)) (-5 *1 (-987 *4 *5 *6 *3)) (-4 *3 (-956 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-457)) (-4 *7 (-956 *6 *4 *5)) (-5 *2 (-424 (-1166 (-413 *7)))) (-5 *1 (-1165 *4 *5 *6 *7)) (-5 *3 (-1166 (-413 *7))))) ((*1 *2 *1) (-12 (-5 *2 (-424 *1)) (-4 *1 (-1214)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-424 *3)) (-5 *1 (-1237 *4 *3)) (-4 *3 (-13 (-1234 *4) (-562) (-10 -8 (-15 -3069 ($ $ $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1051 *4 *5)) (-4 *4 (-13 (-846) (-303) (-151) (-1028))) (-14 *5 (-638 (-1170))) (-5 *2 (-638 (-1139 *4 (-538 (-858 *6)) (-858 *6) (-781 *4 (-858 *6))))) (-5 *1 (-1283 *4 *5 *6)) (-14 *6 (-638 (-1170)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-171 (-217))) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-5 *2 (-217)) (-5 *1 (-219)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-4 *4 (-1054)) (-5 *1 (-710 *4 *2)) (-4 *2 (-641 *4)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-5 *1 (-835 *2)) (-4 *2 (-1054))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-950 *5)) (-4 *5 (-1054)) (-5 *2 (-769)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-769)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923)) (-4 *5 (-1054)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-769))) (-5 *3 (-950 *5)) (-4 *5 (-1054)) (-5 *1 (-1158 *4 *5)) (-14 *4 (-923))))) 
-(((*1 *2 *3 *2 *2) (-12 (-5 *2 (-638 (-496 *4 *5))) (-5 *3 (-858 *4)) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *1 (-626 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-590 *3)) (-4 *3 (-554))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-217)) (-5 *3 (-769)) (-5 *1 (-219)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-171 (-217))) (-5 *3 (-769)) (-5 *1 (-219)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-437 *3 *2)) (-4 *2 (-436 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1132)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *2 (-2 (|:| |additions| (-572)) (|:| |multiplications| (-572)) (|:| |exponentiations| (-572)) (|:| |functionCalls| (-572)))) (-5 *1 (-301))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |var| (-638 (-1170))) (|:| |pred| (-57)))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-562)) (-5 *2 (-769)) (-5 *1 (-48 *4 *3)) (-4 *3 (-423 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-214 *3)) (-4 *3 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-249 *3)) (-4 *3 (-1204)) (-5 *2 (-769)))) ((*1 *2 *1) (-12 (-4 *1 (-298)) (-5 *2 (-769)))) ((*1 *2 *3) (-12 (-4 *4 (-1054)) (-4 *2 (-13 (-410) (-1044 *4) (-368) (-1190) (-281))) (-5 *1 (-448 *4 *3 *2)) (-4 *3 (-1234 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-611 *3)) (-4 *3 (-848)))) ((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-856)))) ((*1 *2 *1) (-12 (-5 *2 (-572)) (-5 *1 (-856))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-303) (-151))) (-4 *4 (-13 (-848) (-613 (-1170)))) (-4 *5 (-794)) (-5 *1 (-930 *3 *4 *5 *2)) (-4 *2 (-956 *3 *5 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $))))))))) ((*1 *2 *2 *2) (-12 (-4 *3 (-562)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *3 (-611 $)) $)) (-15 -4492 ((-1121 *3 (-611 $)) $)) (-15 -3972 ($ (-1121 *3 (-611 $))))))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *4 (-611 $)) $)) (-15 -4492 ((-1121 *4 (-611 $)) $)) (-15 -3972 ($ (-1121 *4 (-611 $))))))) (-4 *4 (-562)) (-5 *1 (-46 *4 *2)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-638 (-611 *2))) (-4 *2 (-13 (-368) (-298) (-10 -8 (-15 -4487 ((-1121 *4 (-611 $)) $)) (-15 -4492 ((-1121 *4 (-611 $)) $)) (-15 -3972 ($ (-1121 *4 (-611 $))))))) (-4 *4 (-562)) (-5 *1 (-46 *4 *2))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-37 *3)) (-4 *3 (-368)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-638 *1)) (-5 *3 (-769)) (-4 *1 (-37 *4)) (-4 *4 (-368)))) ((*1 *2 *2) (-12 (-5 *2 (-638 *1)) (-4 *1 (-978 *3)) (-4 *3 (-368)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-638 *1)) (-5 *3 (-769)) (-4 *1 (-978 *4)) (-4 *4 (-368))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-424 *5)) (-4 *5 (-562)) (-5 *2 (-2 (|:| -3751 (-769)) (|:| -4513 *5) (|:| |radicand| (-638 *5)))) (-5 *1 (-318 *5)) (-5 *4 (-769)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1009)) (-5 *2 (-572))))) 
-(((*1 *2 *2 *2) (-12 (-5 *1 (-161 *2)) (-4 *2 (-554))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-562)) (-5 *2 (-2 (|:| -4513 *4) (|:| -3043 *3) (|:| -2492 *3))) (-5 *1 (-977 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-2 (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1068 *3 *4 *5)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-5 *2 (-2 (|:| -4513 *3) (|:| -3043 *1) (|:| -2492 *1))) (-4 *1 (-1234 *3))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *2 (-572)) (-5 *1 (-577 *3)) (-4 *3 (-1044 *2))))) 
-(((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-121)) (-5 *1 (-371 *3 *4)) (-4 *3 (-372 *4)))) ((*1 *2) (-12 (-4 *1 (-372 *3)) (-4 *3 (-174)) (-5 *2 (-121))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1 *3 *3 (-572))) (-4 *3 (-1054)) (-5 *1 (-101 *3)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-101 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1054)) (-5 *1 (-101 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1116)) (-5 *1 (-330))))) 
-(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-769)) (-4 *5 (-174)))) ((*1 *1 *1) (-12 (-5 *1 (-142 *2 *3 *4)) (-14 *2 (-572)) (-14 *3 (-769)) (-4 *4 (-174)))) ((*1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) ((*1 *1 *2) (-12 (-4 *3 (-1054)) (-4 *1 (-683 *3 *2 *4)) (-4 *2 (-379 *3)) (-4 *4 (-379 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1135 *2 *3)) (-14 *2 (-769)) (-4 *3 (-1054))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-562)) (-4 *4 (-1000 *3)) (-5 *1 (-144 *3 *4 *2)) (-4 *2 (-379 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *5 (-1000 *4)) (-4 *2 (-379 *4)) (-5 *1 (-516 *4 *5 *2 *3)) (-4 *3 (-379 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-685 *5)) (-4 *5 (-1000 *4)) (-4 *4 (-562)) (-5 *2 (-685 *4)) (-5 *1 (-688 *4 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-562)) (-4 *4 (-1000 *3)) (-5 *1 (-1227 *3 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *1) (-5 *1 (-121)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-1092 (-413 (-572))))) (-5 *1 (-258)))) ((*1 *1 *2) (-12 (-5 *2 (-638 (-1092 (-385)))) (-5 *1 (-258))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-217)) (-5 *5 (-572)) (-5 *2 (-1200 *3)) (-5 *1 (-791 *3)) (-4 *3 (-982)))) ((*1 *1 *2 *3 *4) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *4 (-121)) (-5 *1 (-1200 *2)) (-4 *2 (-982))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-504)))) ((*1 *2 *3) (-12 (-5 *3 (-856)) (-5 *2 (-1152)) (-5 *1 (-706))))) 
-(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-769)) (-4 *5 (-174)))) ((*1 *1 *1 *2 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-142 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-769)) (-4 *5 (-174)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-518 (-413 (-572)) (-234 *5 (-769)) (-858 *4) (-244 *4 (-413 (-572))))) (-5 *3 (-638 (-858 *4))) (-14 *4 (-638 (-1170))) (-14 *5 (-769)) (-5 *1 (-519 *4 *5))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-232 *3 *2)) (-4 *2 (-1204)) (-4 *2 (-1054)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-856)))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *2 *3 *3) (-12 (-5 *3 (-950 (-217))) (-5 *2 (-217)) (-5 *1 (-1201)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-1054))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1274 *3 *4)) (-4 *3 (-848)) (-4 *4 (-1054)) (-5 *2 (-2 (|:| |k| (-820 *3)) (|:| |c| *4)))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-4 *5 (-436 *4)) (-5 *2 (-424 (-1166 (-413 (-572))))) (-5 *1 (-441 *4 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-638 *7)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-985 *4 *5 *6 *7))))) 
-(((*1 *2) (-12 (-5 *2 (-413 (-959 *3))) (-5 *1 (-458 *3 *4 *5 *6)) (-4 *3 (-562)) (-4 *3 (-174)) (-14 *4 (-923)) (-14 *5 (-638 (-1170))) (-14 *6 (-1259 (-685 *3)))))) 
-(((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1166 (-572))) (-5 *3 (-572)) (-4 *1 (-869 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-572)) (-5 *1 (-569))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-956 *4 *5 *6)) (-5 *2 (-424 (-1166 *7))) (-5 *1 (-907 *4 *5 *6 *7)) (-5 *3 (-1166 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-910)) (-4 *5 (-1234 *4)) (-5 *2 (-424 (-1166 *5))) (-5 *1 (-908 *4 *5)) (-5 *3 (-1166 *5))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-1152)) (-4 *1 (-369 *2 *4)) (-4 *2 (-1098)) (-4 *4 (-1098)))) ((*1 *1 *2) (-12 (-4 *1 (-369 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-638 *4)) (-5 *1 (-1106 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 *7 *7)) (-5 *5 (-638 (-413 *7))) (-4 *7 (-1234 *6)) (-5 *3 (-413 *7)) (-4 *6 (-368)) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-638 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-582 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-769)) (|:| |poli| *2) (|:| |polj| *2))) (-4 *5 (-794)) (-4 *2 (-956 *4 *5 *6)) (-5 *1 (-454 *4 *5 *6 *2)) (-4 *4 (-457)) (-4 *6 (-848))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-99))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *2)) (-4 *2 (-1249 *4)) (-5 *1 (-1251 *4 *2)) (-4 *4 (-43 (-413 (-572))))))) 
-(((*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-638 (-1133 *4 *5))) (-5 *3 (-1 (-121) *5 *5)) (-4 *4 (-13 (-1098) (-39))) (-4 *5 (-13 (-1098) (-39))) (-5 *1 (-1134 *4 *5)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-638 (-1133 *3 *4))) (-4 *3 (-13 (-1098) (-39))) (-4 *4 (-13 (-1098) (-39))) (-5 *1 (-1134 *3 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-312 (-217)))) (-5 *1 (-265))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |fst| (-440)) (|:| -3166 "void"))) (-5 *1 (-443))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-303) (-151))) (-4 *5 (-13 (-848) (-613 (-1170)))) (-4 *6 (-794)) (-5 *2 (-638 *3)) (-5 *1 (-930 *4 *5 *6 *3)) (-4 *3 (-956 *4 *6 *5))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-342 *4 *3 *5)) (-4 *4 (-1214)) (-4 *3 (-1234 *4)) (-4 *5 (-1234 (-413 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-342 *3 *4 *5)) (-4 *3 (-1214)) (-4 *4 (-1234 *3)) (-4 *5 (-1234 (-413 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-186)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-296)))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-217))) (-5 *2 (-638 (-1152))) (-5 *1 (-301))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-457))) (-5 *1 (-1196 *3 *2)) (-4 *2 (-13 (-436 *3) (-1190)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1170)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)) (-4 *2 (-436 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1090 *2)) (-4 *2 (-436 *4)) (-4 *4 (-13 (-848) (-562))) (-5 *1 (-160 *4 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1090 *1)) (-4 *1 (-162)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-162)) (-5 *2 (-1170))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-175 *2)) (-4 *2 (-303))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-863 *4))) (-4 *4 (-353)) (-5 *2 (-974 *4)) (-5 *1 (-873 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-638 *4)) (-4 *4 (-368)) (-5 *2 (-973 *4)) (-5 *1 (-874 *4 *5 *6)) (-14 *5 (-638 (-1170))) (-4 *6 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *3)) (-4 *3 (-368)) (-4 *1 (-978 *3))))) 
-(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-893 *4)) (-4 *4 (-1098)) (-5 *2 (-121)) (-5 *1 (-890 *4 *5)) (-4 *5 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-5 *2 (-121)) (-5 *1 (-891 *5 *3)) (-4 *3 (-1204)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-893 *5)) (-4 *5 (-1098)) (-4 *6 (-1204)) (-5 *2 (-121)) (-5 *1 (-891 *5 *6))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-562) (-848) (-1044 (-572)))) (-4 *5 (-436 *4)) (-5 *2 (-424 *3)) (-5 *1 (-441 *4 *5 *3)) (-4 *3 (-1234 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-932))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1264)) (-5 *1 (-823))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-769)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-685 (-413 (-959 (-572))))) (-5 *2 (-638 (-685 (-312 (-572))))) (-5 *1 (-1038)) (-5 *3 (-312 (-572)))))) 
-(((*1 *1 *2 *3) (-12 (-5 *1 (-433 *3 *2)) (-4 *3 (-13 (-174) (-43 (-413 (-572))))) (-4 *2 (-13 (-848) (-21)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-303)) (-5 *1 (-695 *3))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -3444 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-368)) (-4 *7 (-1234 *6)) (-5 *2 (-2 (|:| |answer| (-589 (-413 *7))) (|:| |a0| *6))) (-5 *1 (-582 *6 *7)) (-5 *3 (-413 *7))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-685 (-312 (-572)))) (-5 *1 (-1038))))) 
-(((*1 *1 *2 *1) (|partial| -12 (-5 *2 (-130)) (-5 *1 (-1085 *3)) (-4 *3 (-13 (-848) (-562)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-5 *2 (-424 (-1166 (-1166 *4)))) (-5 *1 (-1203 *4)) (-5 *3 (-1166 (-1166 *4)))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-353)) (-4 *5 (-329 *4)) (-4 *6 (-1234 *5)) (-5 *2 (-638 *3)) (-5 *1 (-775 *4 *5 *6 *3 *7)) (-4 *3 (-1234 *6)) (-14 *7 (-923))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *1 *1 *1) (-4 *1 (-759)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-638 (-950 (-217))))) (-5 *2 (-638 (-217))) (-5 *1 (-477))))) 
-(((*1 *2) (-12 (-5 *2 (-965 (-1116))) (-5 *1 (-343 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923)))) ((*1 *2) (-12 (-5 *2 (-965 (-1116))) (-5 *1 (-344 *3 *4)) (-4 *3 (-353)) (-14 *4 (-1166 *3)))) ((*1 *2) (-12 (-5 *2 (-965 (-1116))) (-5 *1 (-345 *3 *4)) (-4 *3 (-353)) (-14 *4 (-923))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-685 *8)) (-5 *4 (-769)) (-4 *8 (-956 *5 *7 *6)) (-4 *5 (-13 (-303) (-151))) (-4 *6 (-13 (-848) (-613 (-1170)))) (-4 *7 (-794)) (-5 *2 (-638 (-2 (|:| |det| *8) (|:| -3682 (-638 (-572))) (|:| |cols| (-638 (-572)))))) (-5 *1 (-930 *5 *6 *7 *8))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-670 *3)) (-4 *3 (-1054)) (-4 *3 (-1098))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-369 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) ((*1 *1 *1) (-5 *1 (-627)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-923) "arbitrary")) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-923) "arbitrary")) (-5 *1 (-469))))) 
-(((*1 *1) (-5 *1 (-443)))) 
-(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-685 *3)) (-4 *3 (-1054)) (-5 *1 (-686 *3))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-4 *6 (-887 *5)) (-5 *2 (-886 *5 *6 (-638 *6))) (-5 *1 (-888 *5 *6 *4)) (-5 *3 (-638 *6)) (-4 *4 (-613 (-893 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-5 *2 (-638 (-290 *3))) (-5 *1 (-888 *5 *3 *4)) (-4 *3 (-1044 (-1170))) (-4 *3 (-887 *5)) (-4 *4 (-613 (-893 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-5 *2 (-638 (-290 (-959 *3)))) (-5 *1 (-888 *5 *3 *4)) (-4 *3 (-1054)) (-2959 (-4 *3 (-1044 (-1170)))) (-4 *3 (-887 *5)) (-4 *4 (-613 (-893 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1098)) (-5 *2 (-890 *5 *3)) (-5 *1 (-888 *5 *3 *4)) (-2959 (-4 *3 (-1044 (-1170)))) (-2959 (-4 *3 (-1054))) (-4 *3 (-887 *5)) (-4 *4 (-613 (-893 *5)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-274 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009)))))) 
-(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-769)) (-4 *4 (-13 (-562) (-151))) (-5 *1 (-1228 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-638 (-638 (-572)))) (-5 *1 (-979)) (-5 *3 (-638 (-572)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-996 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *7 (-1068 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1105 *4 *5 *6 *7 *3)) (-4 *3 (-1073 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-368)) (-14 *5 (-638 (-1170))) (-4 *6 (-232 (-4032 *5) (-769))) (-5 *2 (-1166 (-1166 *4))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-956 *4 *6 (-858 *5))) (-4 *7 (-978 *4))))) 
-(((*1 *2) (|partial| -12 (-4 *4 (-1214)) (-4 *5 (-1234 (-413 *2))) (-4 *2 (-1234 *4)) (-5 *1 (-341 *3 *4 *2 *5)) (-4 *3 (-342 *4 *2 *5)))) ((*1 *2) (|partial| -12 (-4 *1 (-342 *3 *2 *4)) (-4 *3 (-1214)) (-4 *4 (-1234 (-413 *2))) (-4 *2 (-1234 *3))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1054)) (-4 *3 (-793)) (-4 *2 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-217)))) ((*1 *1 *1 *1) (-1841 (-12 (-5 *1 (-290 *2)) (-4 *2 (-368)) (-4 *2 (-1204))) (-12 (-5 *1 (-290 *2)) (-4 *2 (-482)) (-4 *2 (-1204))))) ((*1 *1 *1 *1) (-4 *1 (-368))) ((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-5 *1 (-385)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1121 *3 (-611 *1))) (-4 *3 (-562)) (-4 *3 (-848)) (-4 *1 (-436 *3)))) ((*1 *1 *1 *1) (-4 *1 (-482))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1259 *3)) (-4 *3 (-353)) (-5 *1 (-536 *3)))) ((*1 *1 *1 *1) (-5 *1 (-545))) ((*1 *1 *2 *3) (-12 (-4 *4 (-174)) (-5 *1 (-617 *2 *4 *3)) (-4 *2 (-43 *4)) (-4 *3 (|SubsetCategory| (-722) *4)))) ((*1 *1 *1 *2) (-12 (-4 *4 (-174)) (-5 *1 (-617 *3 *4 *2)) (-4 *3 (-43 *4)) (-4 *2 (|SubsetCategory| (-722) *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-629 *2)) (-4 *2 (-174)) (-4 *2 (-368)))) ((*1 *1 *2 *3) (-12 (-4 *4 (-174)) (-5 *1 (-656 *2 *4 *3)) (-4 *2 (-713 *4)) (-4 *3 (|SubsetCategory| (-722) *4)))) ((*1 *1 *1 *2) (-12 (-4 *4 (-174)) (-5 *1 (-656 *3 *4 *2)) (-4 *3 (-713 *4)) (-4 *2 (|SubsetCategory| (-722) *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 (-312 (-572)) *3)) (-4 *3 (-1098)) (-5 *1 (-680 *3 *4)) (-4 *4 (-1054)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)) (-4 *2 (-368)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-739 *2 *3)) (-14 *2 (-1170)) (-4 *3 (-13 (-1054) (-848) (-562))))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-859 *2 *3 *4 *5)) (-4 *2 (-368)) (-4 *2 (-1054)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-769))) (-14 *5 (-769)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1000 *2)) (-4 *2 (-562)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1057 *3 *4 *2 *5 *6)) (-4 *2 (-1054)) (-4 *5 (-232 *4 *2)) (-4 *6 (-232 *3 *2)) (-4 *2 (-368)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-312 *3)) (-4 *3 (-13 (-848) (-562))) (-5 *1 (-1085 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1266 *2)) (-4 *2 (-368)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *2 (-368)) (-4 *2 (-1054)) (-4 *3 (-848)) (-4 *4 (-794)) (-14 *6 (-638 *3)) (-5 *1 (-1269 *2 *3 *4 *5 *6 *7 *8)) (-4 *5 (-956 *2 *4 *3)) (-14 *7 (-638 (-769))) (-14 *8 (-769)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-1280 *2 *3)) (-4 *2 (-368)) (-4 *2 (-1054)) (-4 *3 (-844))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-769)) (-5 *2 (-385)) (-5 *1 (-1046))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-2 (|:| |den| (-572)) (|:| |gcdnum| (-572))))) (-4 *4 (-1234 (-413 *2))) (-5 *2 (-572)) (-5 *1 (-915 *4 *5)) (-4 *5 (-1234 (-413 *4)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-769)) (-5 *5 (-638 *3)) (-4 *3 (-303)) (-4 *6 (-848)) (-4 *7 (-794)) (-5 *2 (-121)) (-5 *1 (-621 *6 *7 *3 *8)) (-4 *8 (-956 *3 *7 *6))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-3 (-121) "failed")) (-4 *3 (-457)) (-4 *4 (-848)) (-4 *5 (-794)) (-5 *1 (-995 *3 *4 *5 *6)) (-4 *6 (-956 *3 *5 *4))))) 
-(((*1 *1 *1 *1) (-4 *1 (-21))) ((*1 *1 *1) (-4 *1 (-21))) ((*1 *1 *1 *1) (|partial| -5 *1 (-140))) ((*1 *1 *1 *1) (-12 (-5 *1 (-207 *2)) (-4 *2 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-21)) (-4 *2 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-21)) (-4 *2 (-1204)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) ((*1 *1 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1098)) (-4 *4 (-1054)) (-5 *1 (-680 *3 *4)))) ((*1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) ((*1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)))) ((*1 *2 *2 *1) (-12 (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-21)))) ((*1 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-21))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-821)) (-14 *5 (-1170)) (-5 *2 (-638 (-1231 *5 *4))) (-5 *1 (-1112 *4 *5)) (-5 *3 (-1231 *5 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 *2)) (-4 *2 (-436 *4)) (-5 *1 (-437 *4 *2)) (-4 *4 (-13 (-848) (-562)))))) 
-(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-1152)) (-5 *3 (-824)) (-5 *1 (-823))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-217))) (-5 *4 (-769)) (-5 *2 (-685 (-217))) (-5 *1 (-301))))) 
-(((*1 *2 *3 *4 *5 *6 *5 *3 *7) (-12 (-5 *4 (-572)) (-5 *6 (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385)))) (-5 *7 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789)))) ((*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (-12 (-5 *4 (-572)) (-5 *6 (-2 (|:| |try| (-385)) (|:| |did| (-385)) (|:| -2043 (-385)))) (-5 *7 (-1 (-1264) (-1259 *5) (-1259 *5) (-385))) (-5 *3 (-1259 (-385))) (-5 *5 (-385)) (-5 *2 (-1264)) (-5 *1 (-789))))) 
-(((*1 *1 *1 *1) (-4 *1 (-25))) ((*1 *1 *1 *1) (-5 *1 (-159))) ((*1 *1 *1 *1) (-12 (-5 *1 (-207 *2)) (-4 *2 (-13 (-848) (-10 -8 (-15 -3277 ((-1152) $ (-1170))) (-15 -2415 ((-1264) $)) (-15 -3735 ((-1264) $))))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-25)) (-4 *2 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-290 *2)) (-4 *2 (-25)) (-4 *2 (-1204)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-322 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-138)))) ((*1 *1 *2 *1) (-12 (-4 *3 (-13 (-368) (-151))) (-5 *1 (-405 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-479 *2 *3)) (-4 *2 (-174)) (-4 *3 (-23)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-368)) (-4 *3 (-794)) (-4 *4 (-848)) (-5 *1 (-518 *2 *3 *4 *5)) (-4 *5 (-956 *2 *3 *4)))) ((*1 *1 *1 *1) (-5 *1 (-545))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1098)) (-4 *4 (-1054)) (-5 *1 (-680 *3 *4)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-683 *2 *3 *4)) (-4 *2 (-1054)) (-4 *3 (-379 *2)) (-4 *4 (-379 *2)))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)))) ((*1 *2 *2 *1) (-12 (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)) (-4 *3 (-368)) (-4 *4 (-645 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-368)) (-4 *4 (-645 *3)) (-5 *2 (-238 *1)) (-4 *1 (-926 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-950 (-217))) (-5 *1 (-1201)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1257 *2)) (-4 *2 (-1204)) (-4 *2 (-25))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1073 *3 *4 *5 *6)) (-4 *3 (-457)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *6 (-1068 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1073 *4 *5 *6 *3)) (-4 *4 (-457)) (-4 *5 (-794)) (-4 *6 (-848)) (-4 *3 (-1068 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-13 (-846) (-368))) (-5 *1 (-1064 *2 *3)) (-4 *3 (-1234 *2))))) 
-(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-769)) (-4 *3 (-1204)) (-4 *1 (-62 *3 *4 *5)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)))) ((*1 *1) (-5 *1 (-173))) ((*1 *1 *2 *2 *2) (-12 (-5 *2 (-1152)) (-4 *1 (-395)))) ((*1 *1) (-5 *1 (-400))) ((*1 *1 *2 *3) (-12 (-5 *2 (-769)) (-4 *1 (-644 *3)) (-4 *3 (-1204)))) ((*1 *1) (-12 (-4 *3 (-1098)) (-5 *1 (-886 *2 *3 *4)) (-4 *2 (-1098)) (-4 *4 (-662 *3)))) ((*1 *1) (-12 (-5 *1 (-890 *2 *3)) (-4 *2 (-1098)) (-4 *3 (-1098)))) ((*1 *1) (-12 (-5 *1 (-1158 *2 *3)) (-14 *2 (-923)) (-4 *3 (-1054)))) ((*1 *1 *1) (-5 *1 (-1170))) ((*1 *1) (-5 *1 (-1170))) ((*1 *1) (-5 *1 (-1185)))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-368)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *4 *5 *6 *3)) (-4 *3 (-956 *4 *5 *6))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *6 *7 *8 *3 *4)) (-4 *4 (-1073 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1071 *5 *6 *7 *3 *4)) (-4 *4 (-1073 *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-769)) (-4 *6 (-457)) (-4 *7 (-794)) (-4 *8 (-848)) (-4 *3 (-1068 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *6 *7 *8 *3 *4)) (-4 *4 (-1107 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-457)) (-4 *6 (-794)) (-4 *7 (-848)) (-4 *3 (-1068 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-638 *4)) (|:| |todo| (-638 (-2 (|:| |val| (-638 *3)) (|:| -1337 *4)))))) (-5 *1 (-1138 *5 *6 *7 *3 *4)) (-4 *4 (-1107 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1133 *4 *5)) (-4 *4 (-13 (-1098) (-39))) (-4 *5 (-13 (-1098) (-39))) (-5 *2 (-121)) (-5 *1 (-1134 *4 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-638 *6)) (-5 *4 (-1170)) (-4 *6 (-436 *5)) (-4 *5 (-848)) (-5 *2 (-638 (-611 *6))) (-5 *1 (-581 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 (-312 (-217)))) (-5 *2 (-1259 (-312 (-385)))) (-5 *1 (-301))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-638 *6)) (-4 *6 (-848)) (-4 *4 (-368)) (-4 *5 (-794)) (-5 *2 (-2 (|:| |mval| (-685 *4)) (|:| |invmval| (-685 *4)) (|:| |genIdeal| (-518 *4 *5 *6 *7)))) (-5 *1 (-518 *4 *5 *6 *7)) (-4 *7 (-956 *4 *5 *6))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-121)) (-5 *5 (-1100 (-769))) (-5 *6 (-769)) (-5 *2 (-2 (|:| |contp| (-572)) (|:| -4547 (-638 (-2 (|:| |irr| *3) (|:| -3341 (-572))))))) (-5 *1 (-447 *3)) (-4 *3 (-1234 (-572)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1259 (-1259 (-572)))) (-5 *3 (-923)) (-5 *1 (-475))))) 
-(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) ((*1 *1 *2) (-12 (-5 *1 (-714 *2)) (-4 *2 (-368)))) ((*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-923)) (-5 *4 (-385)) (-5 *2 (-1264)) (-5 *1 (-1260))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 *1)) (-4 *1 (-372 *4)) (-4 *4 (-174)) (-5 *2 (-1259 (-685 *4))))) ((*1 *2) (-12 (-4 *4 (-174)) (-5 *2 (-1259 (-685 *4))) (-5 *1 (-422 *3 *4)) (-4 *3 (-423 *4)))) ((*1 *2) (-12 (-4 *1 (-423 *3)) (-4 *3 (-174)) (-5 *2 (-1259 (-685 *3))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1170))) (-4 *5 (-368)) (-5 *2 (-1259 (-685 (-413 (-959 *5))))) (-5 *1 (-1084 *5)) (-5 *4 (-685 (-413 (-959 *5)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-638 (-1170))) (-4 *5 (-368)) (-5 *2 (-1259 (-685 (-959 *5)))) (-5 *1 (-1084 *5)) (-5 *4 (-685 (-959 *5))))) ((*1 *2 *3) (-12 (-5 *3 (-638 (-685 *4))) (-4 *4 (-368)) (-5 *2 (-1259 (-685 *4))) (-5 *1 (-1084 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-43 (-413 (-572)))) (-5 *2 (-2 (|:| -4217 (-1150 *4)) (|:| -4220 (-1150 *4)))) (-5 *1 (-1156 *4)) (-5 *3 (-1150 *4))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-769)) (-5 *1 (-1158 *3 *4)) (-14 *3 (-923)) (-4 *4 (-1054))))) 
-(((*1 *1 *2) (-12 (-5 *1 (-221 *2)) (-4 *2 (-13 (-368) (-1190)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1100 *4)) (-4 *4 (-1098)) (-5 *2 (-1 *4)) (-5 *1 (-1024 *4)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-385))) (-5 *1 (-1046)) (-5 *3 (-385)))) ((*1 *2 *3) (-12 (-5 *3 (-1092 (-572))) (-5 *2 (-1 (-572))) (-5 *1 (-1052))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-848)) (-5 *2 (-121)))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-554)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-598 *3)) (-4 *3 (-1054)))) ((*1 *2 *1) (-12 (-4 *1 (-981 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-793)) (-4 *5 (-848)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-984 *4 *5 *3 *6)) (-4 *4 (-1054)) (-4 *5 (-794)) (-4 *3 (-848)) (-4 *6 (-1068 *4 *5 *3)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-638 (-1166 (-572)))) (-5 *1 (-185)) (-5 *3 (-572))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1152)) (-5 *2 (-1264)) (-5 *1 (-1261))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-237 *3)) (-4 *3 (-1098)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-848)) (-5 *2 (-121)))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-905 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *3 (-368)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-121)) (-5 *1 (-518 *3 *4 *5 *6)) (-4 *6 (-956 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *1 (-671 *3 *4)) (-4 *3 (-1204)) (-4 *4 (-1204)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1070 *4 *3)) (-4 *4 (-13 (-846) (-368))) (-4 *3 (-1234 *4)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-244 *4 *5)) (-14 *4 (-638 (-1170))) (-4 *5 (-457)) (-5 *2 (-496 *4 *5)) (-5 *1 (-626 *4 *5))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1150 *3)) (-4 *3 (-1054)) (-5 *1 (-1154 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-856))) (-5 *1 (-1170))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-848)) (-5 *2 (-121)))) ((*1 *1 *1 *1) (-5 *1 (-856)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-638 (-611 *1))) (-4 *1 (-298))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1276 *3)) (-4 *3 (-368)) (-5 *2 (-121))))) 
-(((*1 *1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-131 *2)) (-4 *2 (-848)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-136 *2)) (-4 *2 (-848)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-279 *3)) (-4 *3 (-1204)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-279 *2)) (-4 *2 (-1204)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-498 *2)) (-4 *2 (-848)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -4111 (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1150 (-217))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1441 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (-5 *1 (-567)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-769)) (-4 *1 (-690 *2)) (-4 *2 (-1098)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -4111 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| -4320 (-2 (|:| |stiffness| (-385)) (|:| |stability| (-385)) (|:| |expense| (-385)) (|:| |accuracy| (-385)) (|:| |intermediateResults| (-385)))))) (-5 *1 (-804)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1007 *2)) (-4 *2 (-1098)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1140 *2)) (-4 *2 (-1098)))) ((*1 *2 *3 *4) (-12 (-5 *2 (-1264)) (-5 *1 (-1182 *3 *4)) (-4 *3 (-1098)) (-4 *4 (-1098))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-848)) (-5 *2 (-121)))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *2 *1 *1) (-12 (-4 *1 (-904 *3)) (-4 *3 (-1098)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-905 *3)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1095 *3)) (-4 *3 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-572)) (-4 *1 (-322 *4 *2)) (-4 *4 (-1098)) (-4 *2 (-138))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-923)) (-5 *1 (-1037 *2)) (-4 *2 (-13 (-1098) (-10 -8 (-15 -1367 ($ $ $)))))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-638 *7)) (-5 *5 (-638 (-638 *8))) (-4 *7 (-848)) (-4 *8 (-303)) (-4 *6 (-794)) (-4 *9 (-956 *8 *6 *7)) (-5 *2 (-2 (|:| |unitPart| *9) (|:| |suPart| (-638 (-2 (|:| -4304 (-1166 *9)) (|:| -3751 (-572))))))) (-5 *1 (-738 *6 *7 *8 *9)) (-5 *3 (-1166 *9))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-290 (-413 (-959 *5)))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-1159 (-638 (-312 *5)) (-638 (-290 (-312 *5))))) (-5 *1 (-1125 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-413 (-959 *5))) (-5 *4 (-1170)) (-4 *5 (-13 (-303) (-848) (-151))) (-5 *2 (-1159 (-638 (-312 *5)) (-638 (-290 (-312 *5))))) (-5 *1 (-1125 *5))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-893 *2)) (-4 *2 (-1098))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 (-312 (-217)))) (-5 *1 (-265))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-385)) (-5 *1 (-219)))) ((*1 *1 *1) (-4 *1 (-624))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-848) (-562))) (-5 *1 (-625 *3 *2)) (-4 *2 (-13 (-436 *3) (-1009) (-1190)))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1169)) (-5 *1 (-330))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-214 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *1 *2 *2) (-12 (-5 *1 (-290 *2)) (-4 *2 (-1204)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-440)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-498 *3)) (-4 *3 (-1098)) (-4 *3 (-848)))) ((*1 *1 *1 *1) (-5 *1 (-856))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1007 *3)) (-4 *3 (-1098)) (-4 *3 (-1098)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1033 *3)) (-4 *3 (-1204)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1140 *3)) (-4 *3 (-1098)) (-4 *3 (-1098))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-562)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *2 (-638 *1)) (-4 *1 (-1068 *3 *4 *5))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-769)) (-4 *4 (-353)) (-5 *1 (-209 *4 *2)) (-4 *2 (-1234 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-923) "arbitrary")) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-923) "arbitrary")) (-5 *1 (-469))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-457)) (-4 *3 (-562)) (-4 *4 (-794)) (-4 *5 (-848)) (-5 *1 (-985 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-638 *7)) (-5 *3 (-121)) (-4 *7 (-1068 *4 *5 *6)) (-4 *4 (-457)) (-4 *4 (-562)) (-4 *5 (-794)) (-4 *6 (-848)) (-5 *1 (-985 *4 *5 *6 *7))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-769)) (-4 *4 (-353)) (-5 *1 (-209 *4 *2)) (-4 *2 (-1234 *4)))) ((*1 *2 *2 *3 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-691 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (-12 (-5 *2 (-959 (-385))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-385)))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-385))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-385))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (-12 (-5 *2 (-959 (-572))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-572)))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-572))) (-5 *1 (-339 *3 *4 *5)) (-4 *5 (-1044 (-572))) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))) (-4 *5 (-393)))) ((*1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 *2)) (-14 *4 (-638 *2)) (-4 *5 (-393)))) ((*1 *1 *2) (-12 (-5 *2 (-312 *5)) (-4 *5 (-393)) (-5 *1 (-339 *3 *4 *5)) (-14 *3 (-638 (-1170))) (-14 *4 (-638 (-1170))))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-413 (-959 (-572))))) (-4 *1 (-390)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-413 (-959 (-385))))) (-4 *1 (-390)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-959 (-572)))) (-4 *1 (-390)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-959 (-385)))) (-4 *1 (-390)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-312 (-572)))) (-4 *1 (-390)))) ((*1 *1 *2) (-12 (-5 *2 (-685 (-312 (-385)))) (-4 *1 (-390)))) ((*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-572)))) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-413 (-959 (-385)))) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-959 (-572))) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-959 (-385))) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-572))) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-312 (-385))) (-4 *1 (-402)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-413 (-959 (-572))))) (-4 *1 (-446)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-413 (-959 (-385))))) (-4 *1 (-446)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-959 (-572)))) (-4 *1 (-446)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-959 (-385)))) (-4 *1 (-446)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-312 (-572)))) (-4 *1 (-446)))) ((*1 *1 *2) (-12 (-5 *2 (-1259 (-312 (-385)))) (-4 *1 (-446)))) ((*1 *2 *1) (-12 (-5 *2 (-413 (-740 *3 *4))) (-5 *1 (-739 *3 *4)) (-14 *3 (-1170)) (-4 *4 (-13 (-1054) (-848) (-562))))) ((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1170)) (|:| |fn| (-312 (-217))) (|:| -1441 (-1092 (-841 (-217)))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (|:| |mdnia| (-2 (|:| |fn| (-312 (-217))) (|:| -1441 (-638 (-1092 (-841 (-217))))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))))) (-5 *1 (-767)))) ((*1 *1 *2) (-12 (-5 *2 (-1216 *3)) (-4 *3 (-353)) (-5 *1 (-776 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |xinit| (-217)) (|:| |xend| (-217)) (|:| |fn| (-1259 (-312 (-217)))) (|:| |yinit| (-638 (-217))) (|:| |intvals| (-638 (-217))) (|:| |g| (-312 (-217))) (|:| |abserr| (-217)) (|:| |relerr| (-217)))) (-5 *1 (-809)))) ((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-312 (-217))) (|:| -1773 (-638 (-217))) (|:| |lb| (-638 (-841 (-217)))) (|:| |cf| (-638 (-312 (-217)))) (|:| |ub| (-638 (-841 (-217)))))) (|:| |lsa| (-2 (|:| |lfn| (-638 (-312 (-217)))) (|:| -1773 (-638 (-217))))))) (-5 *1 (-839)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |pde| (-638 (-312 (-217)))) (|:| |constraints| (-638 (-2 (|:| |start| (-217)) (|:| |finish| (-217)) (|:| |grid| (-769)) (|:| |boundaryType| (-572)) (|:| |dStart| (-685 (-217))) (|:| |dFinish| (-685 (-217)))))) (|:| |f| (-638 (-638 (-312 (-217))))) (|:| |st| (-1152)) (|:| |tol| (-217)))) (-5 *1 (-899)))) ((*1 *1 *2) (-12 (-5 *2 (-638 *6)) (-4 *6 (-1068 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848)) (-4 *1 (-984 *3 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1044 *2)) (-4 *2 (-1204)))) ((*1 *1 *2) (-1841 (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-2959 (-4 *3 (-43 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-554))) (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 *3)) (-12 (-2959 (-4 *3 (-1000 (-572)))) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *1 (-1068 *3 *4 *5)) (-4 *4 (-794)) (-4 *5 (-848))))) ((*1 *1 *2) (-1841 (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-2959 (-4 *3 (-43 (-413 (-572))))) (-4 *3 (-43 (-572))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))) (-12 (-5 *2 (-959 (-572))) (-4 *1 (-1068 *3 *4 *5)) (-12 (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170)))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))))) ((*1 *1 *2) (-12 (-5 *2 (-959 (-413 (-572)))) (-4 *1 (-1068 *3 *4 *5)) (-4 *3 (-43 (-413 (-572)))) (-4 *5 (-613 (-1170))) (-4 *3 (-1054)) (-4 *4 (-794)) (-4 *5 (-848))))) 
-(((*1 *2) (-12 (-4 *1 (-353)) (-5 *2 (-3 "prime" "polynomial" "normal" "cyclic"))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-589 *3)) (-4 *3 (-368))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-638 (-57))) (-5 *1 (-893 *3)) (-4 *3 (-1098))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-638 (-469))) (-5 *2 (-3 (-923) (-121))) (-5 *1 (-468)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-923) (-121))) (-5 *1 (-469))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-330))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-214 *2)) (-4 *2 (-1098)))) ((*1 *2 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1204))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1170)) (-4 *5 (-13 (-457) (-848) (-151) (-1044 (-572)) (-634 (-572)))) (-5 *2 (-589 *3)) (-5 *1 (-563 *5 *3)) (-4 *3 (-13 (-27) (-1190) (-436 *5)))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-638 (-572))) (-5 *1 (-1011 *3)) (-14 *3 (-572))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-244 *6 *5)) (-5 *4 (-974 *5)) (-4 *5 (-353)) (-14 *6 (-638 (-1170))) (-5 *2 (-244 *6 (-863 *5))) (-5 *1 (-873 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *2 *3 *4) (-12 (-5 *4 (-572)) (-4 *5 (-368)) (-4 *6 (-232 *7 (-769))) (-14 *7 (-769)) (-5 *1 (-935 *5 *2 *6 *7 *3)) (-4 *2 (-326 *5 *6)) (-4 *3 (-978 *5)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-368)) (-4 *5 (-232 *6 (-769))) (-14 *6 (-769)) (-5 *1 (-935 *4 *2 *5 *6 *3)) (-4 *2 (-326 *4 *5)) (-4 *3 (-978 *4))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1170)) (-5 *1 (-1066))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-950 *2)) (-5 *1 (-990 *2)) (-4 *2 (-1054))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-572)) (-5 *1 (-424 *2)) (-4 *2 (-562))))) 
-(((*1 *2) (-12 (-5 *2 (-1152)) (-5 *1 (-757))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-685 *4)) (-4 *4 (-1054)) (-5 *1 (-1135 *3 *4)) (-14 *3 (-769))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1017 *3)) (-4 *3 (-1204)) (-4 *3 (-1098)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-173))))) 
-(((*1 *2 *3) (-12 (|has| *6 (-6 -4603)) (-4 *4 (-368)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-638 *6)) (-5 *1 (-533 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) ((*1 *2 *3) (-12 (|has| *9 (-6 -4603)) (-4 *4 (-562)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-4 *7 (-1000 *4)) (-4 *8 (-379 *7)) (-4 *9 (-379 *7)) (-5 *2 (-638 *6)) (-5 *1 (-534 *4 *5 *6 *3 *7 *8 *9 *10)) (-4 *3 (-683 *4 *5 *6)) (-4 *10 (-683 *7 *8 *9)))) ((*1 *2 *1) (-12 (-4 *1 (-683 *3 *4 *5)) (-4 *3 (-1054)) (-4 *4 (-379 *3)) (-4 *5 (-379 *3)) (-4 *3 (-562)) (-5 *2 (-638 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-562)) (-4 *4 (-174)) (-4 *5 (-379 *4)) (-4 *6 (-379 *4)) (-5 *2 (-638 *6)) (-5 *1 (-684 *4 *5 *6 *3)) (-4 *3 (-683 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1057 *3 *4 *5 *6 *7)) (-4 *5 (-1054)) (-4 *6 (-232 *4 *5)) (-4 *7 (-232 *3 *5)) (-4 *5 (-562)) (-5 *2 (-638 *7))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-638 (-923))) (-5 *1 (-1099 *3 *4)) (-14 *3 (-923)) (-14 *4 (-923))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-413 (-572))) (-5 *1 (-597 *3)) (-4 *3 (-43 *2)) (-4 *3 (-1054))))) 
-(((*1 *2 *2) (-12 (-4 *2 (-13 (-368) (-846))) (-5 *1 (-180 *2 *3)) (-4 *3 (-1234 (-171 *2)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-353)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-1166 *4)) (-4 *4 (-353)) (-5 *2 (-121)) (-5 *1 (-361 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-1264)) (-5 *1 (-1212))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-572)) (-4 *1 (-645 *3)) (-4 *3 (-368))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1259 (-685 *4))) (-4 *4 (-174)) (-5 *2 (-1259 (-685 (-959 *4)))) (-5 *1 (-183 *4))))) 
-(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *2 (-638 (-1166 *7))) (-5 *3 (-1166 *7)) (-4 *7 (-956 *5 *6 *4)) (-4 *5 (-910)) (-4 *6 (-794)) (-4 *4 (-848)) (-5 *1 (-907 *5 *6 *4 *7))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-991 *2)) (-4 *2 (-1190))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-875)) (-5 *3 (-638 (-258))) (-5 *1 (-256))))) 
-((-1291 . 842840) (-1292 . 842774) (-1293 . 842595) (-1294 . 842481) (-1295 . 842408) (-1296 . 842357) (-1297 . 842219) (-1298 . 842122) (-1299 . 842024) (-1300 . 841926) (-1301 . 841085) (-1302 . 841030) (-1303 . 840939) (-1304 . 840845) (-1305 . 840795) (-1306 . 840722) (-1307 . 840648) (-1308 . 840591) (-1309 . 840109) (-1310 . 840027) (-1311 . 839845) (-1312 . 839736) (-1313 . 839683) (-1314 . 839536) (-1315 . 839456) (-1316 . 839386) (-1317 . 839300) (-1318 . 834237) (-1319 . 834059) (-1320 . 833740) (-1321 . 833583) (-1322 . 833485) (-1323 . 833356) (-1324 . 832655) (-1325 . 832599) (-1326 . 832533) (-1327 . 832345) (-1328 . 832279) (-1329 . 832223) (-1330 . 831865) (-1331 . 831577) (-1332 . 831467) (-1333 . 831375) (-1334 . 831075) (-1335 . 828948) (-1336 . 828877) (-1337 . 828815) (-1338 . 828729) (-1339 . 828666) (-1340 . 828587) (-1341 . 828463) (-1342 . 828089) (-1343 . 827861) (-1344 . 827788) (-1345 . 827706) (-1346 . 827568) (-1347 . 827393) (-1348 . 827338) (-1349 . 827252) (-1350 . 827009) (-1351 . 826940) (-1352 . 826846) (-1353 . 826699) (-1354 . 826036) (-1355 . 825764) (-1356 . 825678) (-1357 . 825461) (-1358 . 825224) (-1359 . 825127) (-1360 . 824989) (-1361 . 824849) (-1362 . 823814) (-1363 . 823678) (-1364 . 823073) (-1365 . 822982) (-1366 . 822712) (-1367 . 821205) (-1368 . 820699) (-1369 . 820600) (-1370 . 820526) (-1371 . 820419) (-1372 . 820289) (-1373 . 818690) (-1374 . 818540) (-1375 . 818368) (-1376 . 818197) (-1377 . 818060) (-1378 . 817992) (-1379 . 815608) (-1380 . 815356) (-1381 . 815157) (-1382 . 814823) (-1383 . 814735) (-1384 . 814613) (-1385 . 814510) (-1386 . 813832) (-1387 . 813752) (-1388 . 813724) (-1389 . 813567) (-1390 . 813464) (-1391 . 813361) (-1392 . 813274) (-1393 . 813167) (-1394 . 812891) (-1395 . 812610) (-1396 . 812515) (-1397 . 812481) (-1398 . 812407) (-1399 . 812250) (-1400 . 812184) (-1401 . 812067) (-1402 . 811970) (-1403 . 811903) (-1404 . 811657) (-1405 . 811584) (-1406 . 811470) (-1407 . 811335) (-1408 . 811244) (-1409 . 811191) (-1410 . 811142) (-1411 . 810998) (-1412 . 810643) (-1413 . 810297) (-1414 . 810242) (-1415 . 809917) (-1416 . 809813) (-1417 . 809573) (-1418 . 809332) (-1419 . 809162) (-1420 . 809074) (-1421 . 809008) (-1422 . 808712) (-1423 . 808599) (-1424 . 808548) (-1425 . 808345) (-1426 . 808090) (-1427 . 807918) (-1428 . 807752) (-1429 . 807470) (-1430 . 807418) (-1431 . 807278) (-1432 . 807110) (-1433 . 806955) (-1434 . 806782) (-1435 . 806661) (-1436 . 806355) (-1437 . 805947) (-1438 . 805814) (-1439 . 805706) (-1440 . 805486) (-1441 . 805348) (-1442 . 805320) (-1443 . 804899) (-1444 . 804436) (-1445 . 804383) (-1446 . 804154) (-1447 . 804002) (-1448 . 803918) (-1449 . 803514) (-1450 . 803456) (-1451 . 803238) (-1452 . 802921) (-1453 . 802070) (-1454 . 801918) (-1455 . 801436) (-1456 . 801346) (-1457 . 801231) (-1458 . 801035) (-1459 . 800770) (-1460 . 800736) (-1461 . 800666) (-1462 . 800532) (-1463 . 800185) (-1464 . 800019) (-1465 . 799796) (-1466 . 798582) (-1467 . 798363) (-1468 . 798142) (-1469 . 797674) (-1470 . 797252) (-1471 . 797180) (-1472 . 797050) (-1473 . 796752) (-1474 . 796684) (-1475 . 796603) (-1476 . 796550) (-1477 . 796491) (-1478 . 796350) (-1479 . 796270) (-1480 . 796197) (-1481 . 796163) (-1482 . 796049) (-1483 . 795545) (-1484 . 795496) (-1485 . 795186) (-1486 . 795033) (-1487 . 794922) (-1488 . 794807) (-1489 . 794773) (-1490 . 794721) (-1491 . 794668) (-1492 . 794597) (-1493 . 794526) (-1494 . 794421) (-1495 . 794243) (-1496 . 794069) (-1497 . 793952) (-1498 . 793915) (-1499 . 793861) (-1500 . 793756) (-1501 . 793651) (-1502 . 793513) (-1503 . 793300) (-1504 . 793078) (-1505 . 792977) (-1506 . 792888) (-1507 . 792756) (-1508 . 792652) (-1509 . 792495) (-1510 . 792385) (-1511 . 792286) (-1512 . 792020) (-1513 . 791880) (-1514 . 791799) (-1515 . 791612) (-1516 . 791347) (-1517 . 791239) (-1518 . 790415) (-1519 . 790277) (-1520 . 790193) (-1521 . 790110) (-1522 . 789730) (-1523 . 789625) (-1524 . 789552) (-1525 . 789431) (-1526 . 789065) (-1527 . 788929) (-1528 . 788827) (-1529 . 788577) (-1530 . 788496) (-1531 . 788256) (-1532 . 788194) (-1533 . 788095) (-1534 . 786529) (-1535 . 786405) (-1536 . 786292) (-1537 . 786195) (-1538 . 785919) (-1539 . 785704) (-1540 . 782749) (-1541 . 782494) (-1542 . 782372) (-1543 . 782299) (-1544 . 781588) (-1545 . 781022) (-1546 . 780910) (-1547 . 778473) (-1548 . 778421) (-1549 . 778370) (-1550 . 778187) (-1551 . 777985) (-1552 . 777866) (-1553 . 777732) (-1554 . 777664) (-1555 . 777614) (-1556 . 777530) (-1557 . 776734) (-1558 . 776633) (-1559 . 776338) (-1560 . 776203) (-1561 . 776085) (-1562 . 775628) (-1563 . 775486) (-1564 . 775142) (-1565 . 775066) (-1566 . 774863) (-1567 . 774789) (-1568 . 774710) (-1569 . 774299) (-1570 . 774141) (-1571 . 772798) (-1572 . 772754) (-1573 . 772486) (-1574 . 772384) (-1575 . 772329) (-1576 . 772277) (-1577 . 772224) (-1578 . 772171) (-1579 . 772028) (-1580 . 771962) (-1581 . 771837) (-1582 . 771806) (-1583 . 771734) (-1584 . 771474) (-1585 . 770346) (-1586 . 769869) (-1587 . 769803) (-1588 . 769516) (-1589 . 768944) (-1590 . 768892) (-1591 . 768515) (-1592 . 768481) (-1593 . 768407) (-1594 . 768035) (-1595 . 767902) (-1596 . 767832) (-1597 . 767803) (-1598 . 767751) (-1599 . 767541) (-1600 . 767377) (-1601 . 767284) (-1602 . 766953) (-1603 . 766837) (-1604 . 766782) (-1605 . 766391) (-1606 . 766043) (-1607 . 765460) (-1608 . 765428) (-1609 . 765290) (-1610 . 765028) (-1611 . 764658) (-1612 . 764551) (-1613 . 763868) (-1614 . 763768) (-1615 . 763552) (-1616 . 763478) (-1617 . 763300) (-1618 . 763215) (-1619 . 763141) (-1620 . 763071) (-1621 . 762763) (-1622 . 762568) (-1623 . 762327) (-1624 . 762074) (-1625 . 761900) (-1626 . 761825) (-1627 . 761501) (-1628 . 761464) (-1629 . 761281) (-1630 . 761167) (-1631 . 761114) (-1632 . 754583) (-1633 . 754391) (-1634 . 754260) (-1635 . 754201) (-1636 . 754142) (-1637 . 754049) (-1638 . 753887) (-1639 . 752977) (-1640 . 752138) (-1641 . 752029) (-1642 . 751447) (-1643 . 751353) (-1644 . 751219) (-1645 . 751058) (-1646 . 750938) (-1647 . 749584) (-1648 . 749432) (-1649 . 749315) (-1650 . 749139) (-1651 . 748727) (-1652 . 748643) (-1653 . 748541) (-1654 . 748379) (-1655 . 748191) (-1656 . 747975) (-1657 . 747867) (-1658 . 747388) (-1659 . 746943) (-1660 . 746884) (-1661 . 746809) (-1662 . 746683) (-1663 . 746436) (-1664 . 746283) (-1665 . 745723) (-1666 . 745648) (-1667 . 745516) (-1668 . 745170) (-1669 . 745077) (-1670 . 744842) (-1671 . 744760) (-1672 . 744634) (-1673 . 744511) (-1674 . 744359) (-1675 . 744087) (-1676 . 744012) (-1677 . 743810) (-1678 . 743603) (-1679 . 743225) (-1680 . 743173) (-1681 . 743020) (-1682 . 742832) (-1683 . 742566) (-1684 . 742493) (-1685 . 741535) (-1686 . 741480) (-1687 . 741387) (-1688 . 741146) (-1689 . 741084) (-1690 . 740970) (-1691 . 740823) (-1692 . 740749) (-1693 . 740667) (-1694 . 740347) (-1695 . 740229) (-1696 . 740049) (-1697 . 739880) (-1698 . 739282) (-1699 . 739137) (-1700 . 739027) (-1701 . 738855) (-1702 . 738287) (-1703 . 738124) (-1704 . 738055) (-1705 . 731666) (-1706 . 731528) (-1707 . 731403) (-1708 . 731240) (-1709 . 731050) (-1710 . 730906) (-1711 . 730830) (-1712 . 730722) (-1713 . 730501) (-1714 . 730284) (-1715 . 730215) (-1716 . 730115) (-1717 . 729892) (-1718 . 729842) (-1719 . 729708) (-1720 . 729588) (-1721 . 729485) (-1722 . 729353) (-1723 . 729228) (-1724 . 729085) (-1725 . 728768) (-1726 . 728664) (-1727 . 728425) (-1728 . 728316) (-1729 . 728171) (-1730 . 727715) (-1731 . 727593) (-1732 . 727466) (-1733 . 727363) (-1734 . 727272) (-1735 . 726898) (-1736 . 726762) (-1737 . 726728) (-1738 . 726655) (-1739 . 726495) (-1740 . 726393) (-1741 . 726184) (-1742 . 725305) (-1743 . 725252) (-1744 . 725050) (-1745 . 724926) (-1746 . 724804) (-1747 . 724711) (-1748 . 724548) (-1749 . 724477) (-1750 . 724389) (-1751 . 724210) (-1752 . 724108) (-1753 . 723860) (-1754 . 723726) (-1755 . 723548) (-1756 . 723481) (-1757 . 723375) (-1758 . 723161) (-1759 . 723086) (-1760 . 722889) (-1761 . 722633) (-1762 . 722485) (-1763 . 722179) (-1764 . 722105) (-1765 . 721948) (-1766 . 721874) (-1767 . 721260) (-1768 . 721228) (-1769 . 721176) (-1770 . 720624) (-1771 . 720353) (-1772 . 720196) (-1773 . 720077) (-1774 . 718916) (-1775 . 718645) (-1776 . 717944) (-1777 . 717886) (-1778 . 716968) (-1779 . 716878) (-1780 . 716820) (-1781 . 716740) (-1782 . 716671) (-1783 . 716592) (-1784 . 716143) (-1785 . 716041) (-1786 . 715916) (-1787 . 715888) (-1788 . 715655) (-1789 . 715585) (-1790 . 715504) (-1791 . 715363) (-1792 . 715153) (-1793 . 715020) (-1794 . 714865) (-1795 . 714798) (-1796 . 714689) (-1797 . 714317) (-1798 . 714205) (-1799 . 713066) (-1800 . 712985) (-1801 . 712888) (-1802 . 712757) (-1803 . 711940) (-1804 . 711453) (-1805 . 711360) (-1806 . 711307) (-1807 . 711273) (-1808 . 711221) (-1809 . 710778) (-1810 . 710404) (-1811 . 710079) (-1812 . 709989) (-1813 . 709802) (-1814 . 709650) (-1815 . 709583) (-1816 . 709499) (-1817 . 709381) (-1818 . 709277) (-1819 . 709243) (-1820 . 708020) (-1821 . 707932) (-1822 . 707483) (-1823 . 707365) (-1824 . 707288) (-1825 . 707047) (-1826 . 706924) (-1827 . 706823) (-1828 . 706732) (-1829 . 706493) (-1830 . 706422) (-1831 . 705464) (-1832 . 705332) (-1833 . 705046) (-1834 . 704928) (-1835 . 704852) (-1836 . 704715) (-1837 . 704198) (-1838 . 704146) (-1839 . 703965) (-1840 . 703855) (-1841 . 703700) (-1842 . 703523) (-1843 . 702910) (-1844 . 702780) (-1845 . 702464) (-1846 . 702388) (-1847 . 702313) (-12 . 702158) (-1849 . 702066) (-1850 . 701884) (-1851 . 701692) (-1852 . 701640) (-1853 . 701513) (-1854 . 701457) (-1855 . 701295) (-1856 . 701197) (-1857 . 700875) (-1858 . 700678) (-1859 . 700544) (-1860 . 700428) (-1861 . 700104) (-1862 . 699776) (-1863 . 699693) (-1864 . 699619) (-1865 . 699379) (-1866 . 699051) (-1867 . 698975) (-1868 . 698814) (-1869 . 698475) (-1870 . 698374) (-1871 . 698301) (-1872 . 698178) (-1873 . 698046) (-1874 . 697983) (-1875 . 697915) (-1876 . 697829) (-1877 . 697457) (-1878 . 697386) (-1879 . 697306) (-1880 . 697235) (-1881 . 695501) (* . 690848) (-1883 . 690791) (-1884 . 690693) (-1885 . 689263) (-1886 . 689163) (-1887 . 689089) (-1888 . 688912) (-1889 . 687450) (-1890 . 687381) (-1891 . 687184) (-1892 . 686860) (-1893 . 686682) (-1894 . 686527) (-1895 . 686435) (-1896 . 686032) (-1897 . 685816) (-1898 . 685742) (-1899 . 685690) (-1900 . 685610) (-1901 . 685418) (-1902 . 685317) (-1903 . 684959) (-1904 . 684859) (-1905 . 684729) (-1906 . 684610) (-1907 . 684521) (-1908 . 684282) (-1909 . 684108) (-1910 . 683947) (-1911 . 682816) (-1912 . 682730) (-1913 . 682585) (-1914 . 682474) (-1915 . 681907) (-1916 . 681835) (-1917 . 681778) (-1918 . 681565) (-1919 . 681267) (-1920 . 681193) (-1921 . 680655) (-1922 . 680602) (-1923 . 680473) (-1924 . 680319) (-1925 . 680023) (-1926 . 679902) (-1927 . 679647) (-1928 . 679514) (-1929 . 679351) (-1930 . 679232) (-1931 . 678317) (-1932 . 678264) (-1933 . 678152) (-1934 . 677977) (-1935 . 677911) (-1936 . 677800) (-1937 . 677602) (-1938 . 676385) (-1939 . 676233) (-1940 . 676080) (-1941 . 675595) (-1942 . 675536) (-1943 . 675402) (-1944 . 675177) (-1945 . 675041) (-1946 . 674542) (-1947 . 674384) (-1948 . 674288) (-1949 . 674236) (-1950 . 674122) (-1951 . 674028) (-1952 . 673754) (-1953 . 673667) (-1954 . 673586) (-1955 . 673533) (-1956 . 672901) (-1957 . 672834) (-1958 . 671213) (-1959 . 671132) (-1960 . 671041) (-1961 . 670970) (-1962 . 670867) (-1963 . 670814) (-1964 . 670412) (-1965 . 670360) (-1966 . 670269) (-1967 . 670104) (-1968 . 670067) (-1969 . 669927) (-1970 . 669823) (-1971 . 669687) (-1972 . 669484) (-1973 . 669191) (-1974 . 668752) (-1975 . 668597) (-1976 . 668516) (-1977 . 667371) (-1978 . 667158) (-1979 . 667077) (-1980 . 666954) (-1981 . 666703) (-1982 . 666651) (-1983 . 666419) (-1984 . 666319) (-1985 . 666175) (-1986 . 665957) (-1987 . 665586) (-1988 . 665444) (-1989 . 665370) (-1990 . 665266) (-1991 . 665120) (-1992 . 664963) (-1993 . 664729) (-1994 . 664225) (-1995 . 664155) (-1996 . 664020) (-1997 . 663935) (-1998 . 663801) (-1999 . 663644) (-2000 . 663405) (-2001 . 663297) (-2002 . 663168) (-2003 . 663055) (-2004 . 662995) (-2005 . 662882) (-2006 . 662809) (-2007 . 662628) (-2008 . 662600) (-2009 . 662544) (-2010 . 661876) (-2011 . 661712) (-2012 . 661312) (-2013 . 661238) (-2014 . 661143) (-2015 . 661041) (-2016 . 660928) (-2017 . 660147) (-2018 . 660074) (-2019 . 659867) (-2020 . 659776) (-2021 . 659601) (-2022 . 659201) (-2023 . 659078) (-2024 . 658941) (-2025 . 658789) (-2026 . 658699) (-2027 . 658626) (-2028 . 658482) (-2029 . 658400) (-2030 . 658333) (-2031 . 658137) (-2032 . 658084) (-2033 . 657968) (-2034 . 657491) (-2035 . 657379) (-2036 . 657302) (-2037 . 657067) (-2038 . 656914) (-2039 . 656699) (-2040 . 656391) (-2041 . 656208) (-2042 . 656087) (-2043 . 656031) (-2044 . 655947) (-2045 . 655818) (-2046 . 655700) (-2047 . 655343) (-2048 . 655191) (-2049 . 655059) (-2050 . 654988) (-2051 . 654715) (-2052 . 654625) (-2053 . 654535) (-2054 . 654406) (-2055 . 654269) (-2056 . 654194) (-2057 . 654023) (-2058 . 653943) (-2059 . 653713) (-2060 . 653623) (-2061 . 653480) (-2062 . 653377) (-2063 . 653293) (-2064 . 653187) (-2065 . 652868) (-2066 . 652812) (-2067 . 652687) (-2068 . 652589) (-2069 . 652421) (-2070 . 652344) (-2071 . 652268) (-2072 . 652100) (-2073 . 651948) (-2074 . 651889) (-2075 . 651634) (-2076 . 651582) (-2077 . 651456) (-2078 . 651404) (-2079 . 651241) (-2080 . 651210) (-2081 . 650843) (-2082 . 650718) (-2083 . 650514) (-2084 . 650449) (-2085 . 650391) (-2086 . 650038) (-2087 . 649886) (-2088 . 649699) (-2089 . 649638) (-2090 . 649579) (-2091 . 648954) (-2092 . 648629) (-2093 . 648496) (-2094 . 648324) (-2095 . 648247) (-2096 . 648173) (-2097 . 648121) (-2098 . 648055) (-2099 . 647996) (-2100 . 647937) (-2101 . 647641) (-2102 . 647563) (-2103 . 647450) (-2104 . 646905) (-2105 . 646846) (-2106 . 646733) (-2107 . 646652) (-2108 . 646599) (-2109 . 645905) (-2110 . 645712) (-2111 . 645502) (-2112 . 645413) (-2113 . 645173) (-2114 . 644823) (-2115 . 644667) (-2116 . 644589) (-2117 . 644524) (-2118 . 644445) (-2119 . 643771) (-2120 . 643588) (-2121 . 643362) (-2122 . 643287) (-2123 . 643151) (-2124 . 643080) (-2125 . 643052) (-2126 . 642483) (-2127 . 642405) (-2128 . 642296) (-2129 . 642244) (-2130 . 642169) (-2131 . 642069) (-2132 . 641897) (-2133 . 641719) (-2134 . 641645) (-2135 . 641556) (-2136 . 641348) (-2137 . 641176) (-2138 . 641107) (-2139 . 640981) (-2140 . 640157) (-2141 . 640017) (-2142 . 639943) (-2143 . 639862) (-2144 . 639828) (-2145 . 639675) (-2146 . 639516) (-2147 . 638969) (-2148 . 638716) (-2149 . 638662) (-2150 . 638446) (-2151 . 638369) (-2152 . 638274) (-2153 . 638157) (-2154 . 637750) (-2155 . 637650) (-2156 . 637550) (-2157 . 636964) (-2158 . 636879) (-2159 . 636804) (-2160 . 636728) (-2161 . 636658) (-2162 . 636576) (-2163 . 636450) (-2164 . 635852) (-2165 . 635756) (-2166 . 635620) (-2167 . 635549) (-2168 . 635499) (-2169 . 635407) (-2170 . 635255) (-2171 . 635098) (-2172 . 634926) (-2173 . 634785) (-2174 . 634729) (-2175 . 634541) (-2176 . 634430) (-2177 . 634297) (-2178 . 634218) (-2179 . 634159) (-2180 . 634100) (-2181 . 634044) (-2182 . 633892) (-2183 . 633703) (-2184 . 633556) (-2185 . 633472) (-2186 . 632137) (-2187 . 632029) (-2188 . 631844) (-2189 . 631745) (-2190 . 631649) (-2191 . 631483) (-2192 . 631198) (-2193 . 631100) (-2194 . 630325) (-2195 . 630135) (-2196 . 629862) (-2197 . 629793) (-2198 . 629694) (-2199 . 628911) (-2200 . 628721) (-2201 . 627629) (-2202 . 627554) (-2203 . 627407) (-2204 . 627073) (-2205 . 627019) (-2206 . 626963) (-2207 . 626002) (-2208 . 625906) (-2209 . 625754) (-2210 . 625658) (-2211 . 625219) (-2212 . 625166) (-2213 . 624960) (-2214 . 624696) (-2215 . 624607) (-2216 . 624467) (-2217 . 624316) (-2218 . 624139) (-2219 . 623805) (-2220 . 623709) (-2221 . 623014) (-2222 . 622941) (-2223 . 620504) (-2224 . 620449) (-2225 . 620353) (-2226 . 620287) (-2227 . 620160) (-2228 . 620108) (-2229 . 619848) (-2230 . 619632) (-2231 . 619580) (-2232 . 619259) (-2233 . 619188) (-2234 . 619122) (-2235 . 619056) (-2236 . 618858) (-2237 . 618033) (-2238 . 617909) (-2239 . 617856) (-2240 . 617455) (-2241 . 616962) (-2242 . 616839) (-2243 . 616724) (-2244 . 616411) (-2245 . 616291) (-2246 . 616238) (-2247 . 616117) (-2248 . 616045) (-2249 . 615919) (-2250 . 615627) (-2251 . 615455) (-2252 . 615334) (-2253 . 615279) (-2254 . 615227) (-2255 . 615099) (-2256 . 615046) (-2257 . 614926) (-2258 . 614845) (-2259 . 614510) (-2260 . 614408) (-2261 . 614274) (-2262 . 613784) (-2263 . 613693) (-2264 . 613207) (-2265 . 613154) (-2266 . 613034) (-2267 . 611915) (-2268 . 611658) (-2269 . 611577) (-2270 . 611505) (-2271 . 611004) (-2272 . 610916) (-2273 . 610865) (-2274 . 610766) (-2275 . 610628) (-2276 . 610517) (-2277 . 610420) (-2278 . 610392) (-2279 . 610311) (-2280 . 610234) (-2281 . 610151) (-2282 . 609728) (-2283 . 609632) (-2284 . 609389) (-2285 . 608949) (-2286 . 608860) (-2287 . 608728) (-2288 . 608392) (-2289 . 608289) (-2290 . 608223) (-2291 . 608100) (-2292 . 608004) (-2293 . 607879) (-2294 . 607776) (-2295 . 607642) (-2296 . 607541) (-2297 . 607391) (-2298 . 607258) (-2299 . 607119) (-2300 . 606785) (-2301 . 606527) (-2302 . 606423) (-2303 . 606348) (-2304 . 606229) (-2305 . 606064) (-2306 . 605984) (-2307 . 605407) (-2308 . 605274) (-2309 . 604981) (-2310 . 604642) (-2311 . 604483) (-2312 . 604248) (-2313 . 604045) (-2314 . 603970) (-2315 . 603554) (-2316 . 599630) (-2317 . 599520) (-2318 . 599388) (-2319 . 599302) (-2320 . 599146) (-2321 . 598997) (-2322 . 598574) (-2323 . 598508) (-2324 . 598412) (-2325 . 598342) (-2326 . 598293) (-2327 . 598196) (-2328 . 598110) (-2329 . 598027) (-2330 . 597920) (-2331 . 597486) (-2332 . 597338) (-2333 . 596525) (-2334 . 596345) (-2335 . 596292) (-2336 . 595756) (-2337 . 595670) (-2338 . 595358) (-2339 . 594996) (-2340 . 594941) (-2341 . 594734) (-2342 . 594656) (-2343 . 594570) (-2344 . 594246) (-2345 . 594172) (-2346 . 594119) (-2347 . 593920) (-2348 . 593847) (-2349 . 593773) (-2350 . 593550) (-2351 . 593472) (-2352 . 593321) (-2353 . 593222) (-2354 . 593151) (-2355 . 593065) (-2356 . 592842) (-2357 . 592479) (-2358 . 592339) (-2359 . 592247) (-2360 . 591994) (-2361 . 591914) (-2362 . 591828) (-2363 . 591673) (-2364 . 591544) (-2365 . 591451) (-2366 . 591315) (-2367 . 591244) (-2368 . 591158) (-2369 . 590833) (-2370 . 590745) (-2371 . 590588) (-2372 . 590389) (-2373 . 590238) (-2374 . 590086) (-2375 . 589437) (-2376 . 589366) (-2377 . 589293) (-2378 . 589125) (-2379 . 589049) (-2380 . 588714) (-2381 . 588279) (-2382 . 588193) (-2383 . 588117) (-2384 . 587973) (-2385 . 587869) (-2386 . 587556) (-2387 . 587449) (-2388 . 587363) (-2389 . 587283) (-2390 . 586326) (-2391 . 586223) (-2392 . 586080) (-2393 . 585998) (-2394 . 585389) (-2395 . 585237) (-2396 . 585151) (-2397 . 585060) (-2398 . 584856) (-2399 . 584799) (-2400 . 584743) (-2401 . 584422) (-2402 . 584307) (-2403 . 584251) (-2404 . 584016) (-2405 . 583864) (-2406 . 583745) (-2407 . 583613) (-2408 . 583488) (-2409 . 583396) (-2410 . 583327) (-2411 . 583227) (-2412 . 583071) (-2413 . 582965) (-2414 . 582714) (-2415 . 581925) (-2416 . 581754) (-2417 . 581697) (-2418 . 581611) (-2419 . 581536) (-2420 . 580537) (-2421 . 580453) (-2422 . 580305) (-2423 . 580219) (-2424 . 579912) (-2425 . 579824) (-2426 . 579734) (-2427 . 579654) (-2428 . 579598) (-2429 . 579526) (-2430 . 579407) (-2431 . 579324) (-2432 . 579238) (-2433 . 577968) (-2434 . 577895) (-2435 . 577199) (-2436 . 576187) (-2437 . 576030) (-2438 . 575974) (-2439 . 575506) (-2440 . 575323) (-2441 . 575220) (-2442 . 575102) (-2443 . 574984) (-2444 . 574898) (-2445 . 574743) (-2446 . 574498) (-2447 . 574139) (-2448 . 574004) (-2449 . 573769) (-2450 . 573692) (-2451 . 573625) (-2452 . 573433) (-2453 . 573248) (-2454 . 573162) (-2455 . 573094) (-2456 . 572368) (-2457 . 572192) (-2458 . 571928) (-2459 . 571900) (-2460 . 571735) (-2461 . 571642) (-2462 . 571189) (-2463 . 571074) (-2464 . 570746) (-2465 . 570651) (-2466 . 570526) (-2467 . 570470) (-2468 . 570374) (-2469 . 569137) (-2470 . 569024) (-2471 . 568871) (-2472 . 568360) (-2473 . 568212) (-2474 . 568133) (-2475 . 568044) (-2476 . 567946) (-2477 . 567743) (-2478 . 567473) (-2479 . 567244) (-2480 . 567042) (-2481 . 566950) (-2482 . 566875) (-2483 . 566713) (-2484 . 566629) (-2485 . 566504) (-2486 . 566401) (-2487 . 566206) (-2488 . 566077) (-2489 . 565883) (-2490 . 565791) (-2491 . 565528) (-2492 . 565328) (-2493 . 565174) (-2494 . 558785) (-2495 . 558645) (-2496 . 558424) (-2497 . 558314) (-2498 . 558164) (-2499 . 558075) (-2500 . 557975) (-2501 . 557893) (-2502 . 557189) (-2503 . 557097) (-2504 . 557013) (-2505 . 556961) (-2506 . 555777) (-2507 . 555608) (-2508 . 555522) (-2509 . 555436) (-2510 . 555363) (-2511 . 555259) (-2512 . 555184) (-2513 . 555134) (-2514 . 555050) (-2515 . 554796) (-2516 . 554490) (-2517 . 554318) (-2518 . 554249) (-2519 . 554116) (-2520 . 554032) (-2521 . 553951) (-2522 . 553860) (-2523 . 553805) (-2524 . 553731) (-2525 . 553546) (-2526 . 553460) (-2527 . 552899) (-2528 . 551780) (-2529 . 551709) (-2530 . 551518) (-2531 . 551461) (-2532 . 551333) (-2533 . 551234) (-2534 . 550275) (-2535 . 550118) (-2536 . 550057) (-2537 . 549957) (-2538 . 549773) (-2539 . 549690) (-2540 . 549625) (-2541 . 549065) (-2542 . 549013) (-2543 . 548851) (-2544 . 548765) (-2545 . 548593) (-2546 . 548426) (-2547 . 548279) (-2548 . 548174) (-2549 . 548011) (-2550 . 547859) (-2551 . 547634) (-2552 . 547472) (-2553 . 547104) (-2554 . 546853) (-2555 . 546567) (-2556 . 546511) (-2557 . 546458) (-2558 . 546301) (-2559 . 546267) (-2560 . 546207) (-2561 . 545743) (-2562 . 545657) (-2563 . 545579) (-2564 . 545030) (-2565 . 544920) (-2566 . 544739) (-2567 . 544499) (-2568 . 544290) (-2569 . 544168) (-2570 . 544083) (-2571 . 543923) (-2572 . 543779) (-2573 . 543525) (-2574 . 543334) (-2575 . 543060) (-2576 . 542971) (-2577 . 542813) (-2578 . 542710) (-2579 . 542653) (-2580 . 542408) (-2581 . 542311) (-2582 . 542217) (-2583 . 542035) (-2584 . 541944) (-2585 . 541827) (-2586 . 541612) (-2587 . 541584) (-2588 . 541398) (-2589 . 540807) (-2590 . 540384) (-2591 . 540232) (-2592 . 539954) (-2593 . 539845) (-2594 . 539705) (-2595 . 539609) (-2596 . 539523) (-2597 . 539376) (-2598 . 539161) (-2599 . 538959) (-2600 . 538768) (-2601 . 538661) (-2602 . 537720) (-2603 . 537569) (-2604 . 537444) (-2605 . 537286) (-2606 . 536993) (-2607 . 536373) (-2608 . 536341) (-2609 . 535967) (-2610 . 535896) (-2611 . 535603) (-2612 . 535534) (-2613 . 535007) (-2614 . 534873) (-2615 . 534823) (-2616 . 534737) (-2617 . 534622) (-2618 . 534541) (-2619 . 534484) (-2620 . 534384) (-2621 . 534094) (-2622 . 533936) (-2623 . 533863) (-2624 . 533708) (-2625 . 533473) (-2626 . 533397) (-2627 . 533344) (-2628 . 533192) (-2629 . 533017) (-2630 . 532747) (-2631 . 532614) (-2632 . 532542) (-2633 . 532425) (-2634 . 532325) (-2635 . 531756) (-2636 . 531517) (-2637 . 531436) (-2638 . 531201) (-2639 . 531127) (-2640 . 530763) (-2641 . 529563) (-2642 . 529430) (-2643 . 529283) (-2644 . 529117) (-2645 . 529040) (-2646 . 528835) (-2647 . 528763) (-2648 . 528703) (-2649 . 526972) (-2650 . 526784) (-2651 . 526698) (-2652 . 525892) (-2653 . 525290) (-2654 . 525073) (-2655 . 523109) (-2656 . 523027) (-2657 . 522671) (-2658 . 522300) (-2659 . 522214) (-2660 . 521979) (-2661 . 521831) (-2662 . 521759) (-2663 . 521336) (-2664 . 521171) (-2665 . 521075) (-2666 . 520972) (-2667 . 519785) (-2668 . 519572) (-2669 . 519486) (-2670 . 519274) (-2671 . 519219) (-2672 . 518894) (-2673 . 518784) (-2674 . 518582) (-2675 . 518201) (-2676 . 518116) (-2677 . 518031) (-2678 . 517874) (-2679 . 517788) (-2680 . 517664) (-2681 . 517513) (-2682 . 517009) (-2683 . 516915) (-2684 . 516834) (-2685 . 516765) (-2686 . 516665) (-2687 . 516470) (-2688 . 516332) (-2689 . 516047) (-2690 . 515973) (-2691 . 515899) (-2692 . 515800) (-2693 . 515661) (-2694 . 515563) (-2695 . 515482) (-2696 . 515403) (-2697 . 515261) (-2698 . 514995) (-2699 . 514920) (-2700 . 514831) (-2701 . 514741) (-2702 . 514553) (-2703 . 514500) (-2704 . 514444) (-2705 . 514182) (-2706 . 514040) (-2707 . 513011) (-2708 . 512686) (-2709 . 512371) (-2710 . 512240) (-2711 . 512166) (-2712 . 512113) (-2713 . 511962) (-2714 . 511464) (-2715 . 510532) (-2716 . 510418) (-2717 . 510337) (-2718 . 510227) (-2719 . 510102) (-2720 . 509774) (-2721 . 509714) (-2722 . 509588) (-2723 . 509536) (-2724 . 509388) (-2725 . 509271) (-2726 . 509147) (-2727 . 509095) (-2728 . 508779) (-2729 . 508474) (-2730 . 508369) (-2731 . 508265) (-2732 . 508162) (-2733 . 507802) (-2734 . 507483) (-2735 . 507284) (-2736 . 507231) (-2737 . 507135) (-2738 . 507002) (-2739 . 506909) (-2740 . 506799) (-2741 . 506681) (-2742 . 506517) (-2743 . 506211) (-2744 . 505973) (-2745 . 505921) (-2746 . 505793) (-2747 . 505688) (-2748 . 505622) (-2749 . 505594) (-2750 . 505380) (-2751 . 505310) (-2752 . 505208) (-2753 . 505003) (-2754 . 503937) (-2755 . 503885) (-2756 . 503733) (-2757 . 503539) (-2758 . 503399) (-2759 . 503337) (-2760 . 502813) (-2761 . 502660) (-2762 . 502603) (-2763 . 502449) (-2764 . 502248) (-2765 . 502144) (-2766 . 502008) (-2767 . 501713) (-2768 . 501526) (-2769 . 501409) (-2770 . 501236) (-2771 . 501134) (-2772 . 500644) (-2773 . 500492) (-2774 . 493652) (-2775 . 493560) (-2776 . 493453) (-2777 . 493388) (-2778 . 493285) (-2779 . 493157) (-2780 . 493024) (-2781 . 492886) (-2782 . 492807) (-2783 . 492561) (-2784 . 492443) (-2785 . 492229) (-2786 . 492154) (-2787 . 491749) (-2788 . 491533) (-2789 . 491425) (-2790 . 491073) (-2791 . 490875) (-2792 . 490778) (-2793 . 490729) (-2794 . 490647) (-2795 . 490302) (-2796 . 489727) (-2797 . 489649) (-2798 . 489559) (-2799 . 489497) (-2800 . 480604) (-2801 . 480280) (-2802 . 480119) (-2803 . 480037) (-2804 . 479958) (-2805 . 479722) (-2806 . 478956) (-2807 . 478718) (-2808 . 478491) (-2809 . 478439) (-2810 . 478373) (-2811 . 478307) (-2812 . 478189) (-2813 . 477842) (-2814 . 477570) (-2815 . 477493) (-2816 . 477348) (-2817 . 477222) (-2818 . 477169) (-2819 . 477094) (-2820 . 476942) (-2821 . 476768) (-2822 . 476618) (-2823 . 476470) (-2824 . 476210) (-2825 . 475840) (-2826 . 475594) (-2827 . 475301) (-2828 . 475132) (-2829 . 475081) (-2830 . 474501) (-2831 . 474351) (-2832 . 474161) (-2833 . 473212) (-2834 . 469288) (-2835 . 469049) (-2836 . 468908) (-2837 . 468830) (-2838 . 468467) (-2839 . 468396) (-2840 . 468272) (-2841 . 468131) (-2842 . 468036) (-2843 . 467927) (-2844 . 467504) (-2845 . 467386) (-2846 . 467331) (-2847 . 467074) (-2848 . 466956) (-2849 . 466775) (-2850 . 466577) (-2851 . 466462) (-2852 . 466359) (-2853 . 466222) (-2854 . 465985) (-2855 . 465867) (-2856 . 465728) (-2857 . 465662) (-2858 . 465513) (-2859 . 465123) (-2860 . 464889) (-2861 . 464832) (-2862 . 464735) (-2863 . 464636) (-2864 . 464576) (-2865 . 464369) (-2866 . 464238) (-2867 . 460314) (-2868 . 460030) (-2869 . 459959) (-2870 . 459810) (-2871 . 459722) (-2872 . 459644) (-2873 . 459570) (-2874 . 459498) (-2875 . 459290) (-2876 . 459020) (-2877 . 458884) (-2878 . 458701) (-2879 . 458157) (-2880 . 456667) (-2881 . 456563) (-2882 . 456316) (-2883 . 456201) (-2884 . 456133) (-2885 . 452395) (-2886 . 452277) (-2887 . 452211) (-2888 . 452183) (-2889 . 452105) (-2890 . 451800) (-2891 . 451713) (-2892 . 451598) (-2893 . 451520) (-2894 . 451439) (-2895 . 451407) (-2896 . 451098) (-2897 . 451022) (-2898 . 450877) (-2899 . 450826) (-2900 . 450657) (-2901 . 450463) (-2902 . 450391) (-2903 . 450105) (-2904 . 449967) (-2905 . 449890) (-2906 . 449817) (-2907 . 449718) (-2908 . 449665) (-2909 . 449594) (-2910 . 449361) (-2911 . 448846) (-2912 . 448609) (-2913 . 448536) (-2914 . 448445) (-2915 . 448282) (-2916 . 448207) (-2917 . 448014) (-2918 . 447870) (-2919 . 447785) (-2920 . 447695) (-2921 . 447429) (-2922 . 447311) (-2923 . 447041) (-2924 . 446905) (-2925 . 446779) (-2926 . 446655) (-2927 . 446321) (-2928 . 446169) (-2929 . 446091) (-2930 . 445980) (-2931 . 445306) (-2932 . 445217) (-2933 . 445044) (-2934 . 445007) (-2935 . 444919) (-2936 . 443477) (-2937 . 443372) (-2938 . 443268) (-2939 . 443196) (-2940 . 443105) (-2941 . 442711) (-2942 . 442658) (-2943 . 442606) (-2944 . 442498) (-2945 . 442350) (-2946 . 442084) (-2947 . 442032) (-2948 . 441581) (-2949 . 441522) (-2950 . 441374) (-2951 . 441340) (-2952 . 441142) (-2953 . 440597) (-2954 . 440442) (-2955 . 440272) (-2956 . 439517) (-2957 . 438466) (-2958 . 438413) (-2959 . 438297) (-2960 . 438166) (-2961 . 438024) (-2962 . 437973) (-2963 . 437802) (-2964 . 437073) (-2965 . 436973) (-2966 . 436877) (-2967 . 436715) (-2968 . 436534) (-2969 . 436280) (-2970 . 435802) (-2971 . 435744) (-2972 . 435673) (-2973 . 435279) (-2974 . 435120) (-2975 . 435009) (-2976 . 434811) (-2977 . 434460) (-2978 . 434178) (-2979 . 434083) (-2980 . 433991) (-2981 . 433877) (-2982 . 433681) (-2983 . 433572) (-2984 . 433443) (-2985 . 433174) (-2986 . 433108) (-2987 . 433052) (-2988 . 432901) (-2989 . 432763) (-2990 . 432691) (-2991 . 432554) (-2992 . 432457) (-2993 . 432319) (-2994 . 432235) (-2995 . 432164) (-2996 . 432072) (-2997 . 431984) (-2998 . 431912) (-2999 . 431790) (-3000 . 431738) (-3001 . 431659) (-3002 . 430820) (-3003 . 430791) (-3004 . 430688) (-3005 . 430475) (-3006 . 430350) (-3007 . 430193) (-3008 . 429780) (-3009 . 429683) (-3010 . 429624) (-3011 . 429479) (-3012 . 429395) (-3013 . 429342) (-3014 . 429235) (-3015 . 429080) (-3016 . 428765) (-3017 . 428675) (-3018 . 428130) (-3019 . 427168) (-3020 . 426994) (-3021 . 426920) (-3022 . 426756) (-3023 . 426648) (-3024 . 426500) (-3025 . 426448) (-3026 . 426330) (-3027 . 426279) (-3028 . 426129) (-3029 . 425944) (-3030 . 425855) (-3031 . 425747) (-3032 . 425599) (-3033 . 425498) (-3034 . 425278) (-3035 . 424609) (-3036 . 424541) (-3037 . 424320) (-3038 . 424073) (-3039 . 423998) (-3040 . 423917) (-3041 . 423604) (-3042 . 423552) (-3043 . 423313) (-3044 . 423189) (-3045 . 422954) (-3046 . 422802) (-3047 . 422466) (-3048 . 422327) (-3049 . 422192) (-3050 . 422139) (-3051 . 422064) (-3052 . 421926) (-3053 . 421842) (-3054 . 421577) (-3055 . 421474) (-3056 . 421201) (-3057 . 420962) (-3058 . 420533) (-3059 . 420429) (-3060 . 420401) (-3061 . 420320) (-3062 . 420193) (-3063 . 419991) (-3064 . 419377) (-3065 . 419284) (-3066 . 419045) (-3067 . 418961) (-3068 . 418857) (-3069 . 417638) (-3070 . 417545) (-3071 . 417477) (-3072 . 417398) (-3073 . 416974) (-3074 . 416673) (-3075 . 416539) (-3076 . 416454) (-3077 . 416341) (-3078 . 415710) (-3079 . 415569) (-3080 . 415495) (-3081 . 415427) (-3082 . 415324) (-3083 . 415088) (-3084 . 414637) (-3085 . 414585) (-3086 . 414407) (-3087 . 414208) (-3088 . 414177) (-3089 . 413887) (-3090 . 413814) (-3091 . 413723) (-3092 . 413488) (-3093 . 413384) (-3094 . 412977) (-3095 . 412424) (-3096 . 412358) (-3097 . 412208) (-3098 . 412117) (-3099 . 412001) (-3100 . 411631) (-3101 . 411277) (-3102 . 410974) (-3103 . 408826) (-3104 . 408680) (-3105 . 408574) (-3106 . 408458) (-3107 . 407989) (-3108 . 407615) (-3109 . 407529) (-3110 . 407414) (-3111 . 406506) (-3112 . 406451) (-3113 . 406203) (-3114 . 405965) (-3115 . 405893) (-3116 . 402283) (-3117 . 402224) (-3118 . 402120) (-3119 . 402012) (-3120 . 401753) (-3121 . 401519) (-3122 . 401411) (-3123 . 401358) (-3124 . 401288) (-3125 . 401108) (-3126 . 401004) (-3127 . 400891) (-3128 . 400807) (-3129 . 400697) (-3130 . 400320) (-3131 . 400247) (-3132 . 399563) (-3133 . 399194) (-3134 . 399074) (-3135 . 399016) (-3136 . 398925) (-3137 . 398834) (-3138 . 398760) (-3139 . 396361) (-3140 . 396009) (-3141 . 395954) (-3142 . 393517) (-3143 . 393358) (-3144 . 393268) (-3145 . 392788) (-3146 . 392739) (-3147 . 392537) (-3148 . 392415) (-3149 . 392313) (-3150 . 392244) (-3151 . 392153) (-3152 . 392100) (-3153 . 392010) (-3154 . 391934) (-3155 . 391861) (-3156 . 391723) (-3157 . 391653) (-3158 . 391539) (-3159 . 391392) (-3160 . 390258) (-3161 . 390166) (-3162 . 389981) (-3163 . 389893) (-3164 . 389821) (-3165 . 389642) (-3166 . 389613) (-3167 . 389482) (-3168 . 389411) (-3169 . 389322) (-3170 . 389172) (-3171 . 389075) (-3172 . 388942) (-3173 . 388871) (-3174 . 388772) (-3175 . 387840) (-3176 . 387788) (-3177 . 387736) (-3178 . 387641) (-3179 . 387585) (-3180 . 387496) (-3181 . 387388) (-3182 . 387269) (-3183 . 387192) (-3184 . 387111) (-3185 . 387056) (-3186 . 386905) (-3187 . 386685) (-3188 . 386049) (-3189 . 385866) (-3190 . 385425) (-3191 . 385306) (-3192 . 385163) (-3193 . 384676) (-3194 . 384380) (-3195 . 383700) (-3196 . 383625) (-3197 . 383475) (-3198 . 383325) (-3199 . 383235) (-3200 . 382443) (-3201 . 382040) (-3202 . 381666) (-3203 . 381416) (-3204 . 381326) (-3205 . 381217) (-3206 . 380973) (-3207 . 380924) (-3208 . 380738) (-3209 . 380229) (-3210 . 380170) (-3211 . 379647) (-3212 . 379556) (-3213 . 379399) (-3214 . 379262) (-3215 . 379193) (-3216 . 379165) (-3217 . 379072) (-3218 . 378976) (-3219 . 378862) (-3220 . 378721) (-3221 . 378537) (-3222 . 378398) (-3223 . 378330) (-3224 . 378239) (-3225 . 378126) (-3226 . 378049) (-3227 . 377814) (-3228 . 376947) (-3229 . 376833) (-3230 . 376441) (-3231 . 376386) (-3232 . 376287) (-3233 . 376078) (-3234 . 375964) (-3235 . 375868) (-3236 . 375769) (-3237 . 375633) (-3238 . 375525) (-3239 . 375316) (-3240 . 375264) (-3241 . 375170) (-3242 . 374995) (-3243 . 374892) (-3244 . 374822) (-3245 . 374645) (-3246 . 374537) (-3247 . 373594) (-3248 . 373440) (-3249 . 373290) (-3250 . 373214) (-3251 . 372857) (-3252 . 372808) (-3253 . 372499) (-3254 . 372421) (-3255 . 372178) (-3256 . 372106) (-3257 . 372047) (-3258 . 371897) (-3259 . 371772) (-3260 . 371682) (-3261 . 371608) (-3262 . 371496) (-3263 . 371367) (-3264 . 371221) (-3265 . 371138) (-3266 . 371085) (-3267 . 370986) (-3268 . 370884) (-3269 . 370826) (-3270 . 370752) (-3271 . 370669) (-3272 . 370617) (-3273 . 370512) (-3274 . 370417) (-3275 . 370267) (-3276 . 370160) (-3277 . 365061) (-3278 . 364938) (-3279 . 364669) (-3280 . 364338) (-3281 . 364245) (-3282 . 362910) (-3283 . 361525) (-3284 . 361441) (-3285 . 361333) (-3286 . 360710) (-3287 . 360578) (-3288 . 360303) (-3289 . 360153) (-3290 . 360045) (-3291 . 359410) (-3292 . 358632) (-3293 . 358302) (-3294 . 358157) (-3295 . 358058) (-3296 . 357984) (-3297 . 357839) (-3298 . 357726) (-3299 . 357529) (-3300 . 357424) (-3301 . 357306) (-3302 . 357240) (-3303 . 357150) (-3304 . 357062) (-3305 . 356945) (-3306 . 356893) (-3307 . 356816) (-3308 . 356656) (-3309 . 356533) (-3310 . 356182) (-3311 . 355611) (-3312 . 355511) (-3313 . 355435) (-3314 . 355312) (-3315 . 355228) (-3316 . 355149) (-3317 . 354969) (-3318 . 354855) (-3319 . 354406) (-3320 . 354374) (-3321 . 354126) (-3322 . 354010) (-3323 . 353841) (-3324 . 353456) (-3325 . 353366) (-3326 . 353261) (-3327 . 353187) (-3328 . 352993) (-3329 . 352965) (-3330 . 352817) (-3331 . 352733) (-3332 . 352662) (-3333 . 352493) (-3334 . 352366) (-3335 . 352256) (-3336 . 352131) (-3337 . 351905) (-3338 . 351726) (-3339 . 351636) (-3340 . 351533) (-3341 . 351326) (-3342 . 350918) (-3343 . 350753) (-3344 . 350654) (-3345 . 350185) (-3346 . 349841) (-3347 . 349674) (-3348 . 349625) (-3349 . 349531) (-3350 . 349425) (-3351 . 349110) (-3352 . 348943) (-3353 . 348839) (-3354 . 348603) (-3355 . 348497) (-3356 . 347395) (-3357 . 347361) (-3358 . 347068) (-3359 . 346626) (-3360 . 346524) (-3361 . 346432) (-3362 . 346339) (-3363 . 346281) (-3364 . 346226) (-3365 . 346122) (-3366 . 345852) (-3367 . 345755) (-3368 . 341831) (-3369 . 341776) (-3370 . 341492) (-3371 . 341423) (-3372 . 340955) (-3373 . 340805) (-3374 . 340723) (-3375 . 340670) (-3376 . 336494) (-3377 . 334210) (-3378 . 334081) (-3379 . 333394) (-3380 . 333342) (-3381 . 333268) (-3382 . 333091) (-3383 . 332926) (-3384 . 332850) (-3385 . 332777) (-3386 . 332681) (-3387 . 332604) (-3388 . 332458) (-3389 . 332405) (-3390 . 332218) (-3391 . 331660) (-3392 . 331500) (-3393 . 331412) (-3394 . 331339) (-3395 . 331214) (-3396 . 331130) (-3397 . 331031) (-3398 . 330997) (-3399 . 330900) (-3400 . 330627) (-3401 . 330493) (-3402 . 330427) (-3403 . 330243) (-3404 . 330170) (-3405 . 329069) (-3406 . 328922) (-3407 . 328835) (-3408 . 328746) (-3409 . 328697) (-3410 . 328055) (-3411 . 327957) (-3412 . 327868) (-3413 . 327748) (-3414 . 327689) (-3415 . 327596) (-3416 . 327388) (-3417 . 327231) (-3418 . 327165) (-3419 . 326932) (-3420 . 326846) (-3421 . 326438) (-3422 . 326219) (-3423 . 326032) (-3424 . 325907) (-3425 . 325691) (-3426 . 325075) (-3427 . 324995) (-3428 . 324915) (-3429 . 324806) (-3430 . 324627) (-3431 . 324344) (-3432 . 324253) (-3433 . 324119) (-3434 . 323906) (-3435 . 323837) (-3436 . 323748) (-3437 . 323228) (-3438 . 322920) (-3439 . 322077) (-3440 . 322005) (-3441 . 321720) (-3442 . 321670) (-3443 . 321417) (-3444 . 321362) (-3445 . 320792) (-3446 . 320587) (-3447 . 320494) (-3448 . 320248) (-3449 . 319526) (-3450 . 319333) (-3451 . 319246) (-3452 . 319051) (-3453 . 318952) (-3454 . 318851) (-3455 . 318787) (-3456 . 317570) (-3457 . 317199) (-3458 . 317080) (-3459 . 317029) (-3460 . 316948) (-3461 . 316773) (-3462 . 316678) (-3463 . 316555) (-3464 . 316247) (-3465 . 316195) (-3466 . 315993) (-3467 . 315919) (-3468 . 315619) (-3469 . 315457) (-3470 . 315370) (-3471 . 315179) (-3472 . 315043) (-3473 . 314504) (-3474 . 313918) (-3475 . 313656) (-3476 . 313289) (-3477 . 313181) (-3478 . 313091) (-3479 . 313015) (-3480 . 312963) (-3481 . 312824) (-3482 . 312673) (-3483 . 312606) (-3484 . 312553) (-3485 . 312387) (-3486 . 312325) (-3487 . 312270) (-3488 . 312190) (-3489 . 312079) (-3490 . 308398) (-3491 . 308333) (-3492 . 308149) (-3493 . 307881) (-3494 . 307771) (-3495 . 307653) (-3496 . 307572) (-3497 . 307461) (-3498 . 307200) (-3499 . 306857) (-3500 . 306775) (-3501 . 306081) (-3502 . 306022) (-3503 . 305948) (-3504 . 305851) (-3505 . 305462) (-3506 . 305364) (-3507 . 305312) (-3508 . 305124) (-3509 . 304975) (-3510 . 304840) (-3511 . 304698) (-3512 . 304625) (-3513 . 304506) (-3514 . 304409) (-3515 . 304317) (-3516 . 304111) (-3517 . 304011) (-3518 . 303661) (-3519 . 303470) (-3520 . 303062) (-3521 . 302982) (-3522 . 302866) (-3523 . 302747) (-3524 . 302065) (-3525 . 301646) (-3526 . 300805) (-3527 . 300699) (-3528 . 300560) (-3529 . 300189) (-3530 . 300122) (-3531 . 300030) (-3532 . 299894) (-3533 . 299564) (-3534 . 299385) (-3535 . 299291) (-3536 . 299195) (-3537 . 299120) (-3538 . 299092) (-3539 . 297916) (-3540 . 297844) (-3541 . 297714) (-3542 . 295603) (-3543 . 295503) (-3544 . 295207) (-3545 . 295133) (-3546 . 295102) (-3547 . 294860) (-3548 . 293896) (-3549 . 293756) (-3550 . 293701) (-3551 . 293625) (-3552 . 293525) (-3553 . 293150) (-3554 . 293008) (-3555 . 292926) (-3556 . 292776) (-3557 . 292673) (-3558 . 292513) (-3559 . 292110) (-3560 . 291766) (-3561 . 291229) (-3562 . 291135) (-3563 . 291064) (-3564 . 291011) (-3565 . 290901) (-3566 . 290784) (-3567 . 290617) (-3568 . 290476) (-3569 . 290283) (-3570 . 290215) (-3571 . 290006) (-3572 . 289864) (-3573 . 289589) (-3574 . 289473) (-3575 . 289339) (-3576 . 289247) (-3577 . 288748) (-3578 . 288546) (-3579 . 288472) (-3580 . 288267) (-3581 . 288133) (-3582 . 288077) (-3583 . 287993) (-3584 . 287579) (-3585 . 287508) (-3586 . 287223) (-3587 . 287071) (-3588 . 287016) (-3589 . 286942) (-3590 . 286856) (-3591 . 286801) (-3592 . 286720) (-3593 . 286578) (-3594 . 285803) (-3595 . 285684) (-3596 . 285320) (-3597 . 284761) (-3598 . 284352) (-3599 . 284320) (-3600 . 283878) (-3601 . 283814) (-3602 . 283662) (-3603 . 283510) (-3604 . 282574) (-3605 . 282422) (-3606 . 282318) (-3607 . 282259) (-3608 . 282183) (-3609 . 282074) (-3610 . 281767) (-3611 . 281554) (-3612 . 281457) (-3613 . 281302) (-3614 . 281237) (-3615 . 281108) (-3616 . 280679) (-3617 . 280597) (-3618 . 280480) (-3619 . 280377) (-3620 . 280076) (-3621 . 279980) (-3622 . 279923) (-3623 . 279806) (-3624 . 279355) (-3625 . 279129) (-3626 . 279097) (-3627 . 279030) (-3628 . 278653) (-3629 . 278300) (-3630 . 278186) (-3631 . 278092) (-3632 . 277928) (-3633 . 277790) (-3634 . 277608) (-3635 . 277519) (-3636 . 277428) (-3637 . 277257) (-3638 . 277119) (-3639 . 276990) (-3640 . 276871) (-3641 . 276764) (-3642 . 276484) (-3643 . 276329) (-3644 . 276155) (-3645 . 276071) (-3646 . 276000) (-3647 . 274629) (-3648 . 274557) (-3649 . 274150) (-3650 . 270226) (-3651 . 270076) (-3652 . 269743) (-3653 . 269652) (-3654 . 269541) (-3655 . 269443) (-3656 . 268921) (-3657 . 268823) (-3658 . 268382) (-3659 . 268329) (-3660 . 268236) (-3661 . 268111) (-3662 . 268028) (-3663 . 267710) (-3664 . 267562) (-3665 . 267473) (-3666 . 267146) (-3667 . 266952) (-3668 . 266660) (-3669 . 266377) (-3670 . 266303) (-3671 . 266096) (-3672 . 265980) (-3673 . 265882) (-3674 . 265812) (-3675 . 265759) (-3676 . 265706) (-3677 . 265596) (-3678 . 265533) (-3679 . 265206) (-3680 . 265154) (-3681 . 265072) (-3682 . 264776) (-3683 . 264620) (-3684 . 264417) (-3685 . 264328) (-3686 . 264276) (-3687 . 264224) (-3688 . 264128) (-3689 . 264076) (-3690 . 263741) (-3691 . 263615) (-3692 . 263393) (-3693 . 263264) (-3694 . 262900) (-3695 . 262872) (-3696 . 262780) (-3697 . 262622) (-3698 . 262323) (-3699 . 262223) (-3700 . 262058) (-3701 . 261747) (-3702 . 261307) (-3703 . 261109) (-3704 . 260874) (-3705 . 260846) (-3706 . 260758) (-3707 . 260660) (-3708 . 260480) (-3709 . 260428) (-3710 . 260368) (-3711 . 259381) (-3712 . 259146) (-3713 . 258961) (-3714 . 258654) (-3715 . 258583) (-3716 . 258428) (-3717 . 258338) (-3718 . 258156) (-3719 . 258067) (-3720 . 257875) (-3721 . 257771) (-3722 . 257718) (-3723 . 257684) (-3724 . 256847) (-3725 . 256670) (-3726 . 256532) (-3727 . 256394) (-3728 . 256232) (-3729 . 255535) (-3730 . 255404) (-3731 . 255033) (-3732 . 255005) (-3733 . 254260) (-3734 . 253517) (-3735 . 253137) (-3736 . 253019) (-3737 . 252908) (-3738 . 252880) (-3739 . 252814) (-3740 . 252739) (-3741 . 252543) (-3742 . 252483) (-3743 . 252164) (-3744 . 251996) (-3745 . 251930) (-3746 . 251802) (-3747 . 251653) (-3748 . 251262) (-3749 . 251105) (-3750 . 250204) (-3751 . 249746) (-3752 . 249662) (-3753 . 249446) (-3754 . 248909) (-3755 . 248803) (-3756 . 248676) (-3757 . 248598) (-3758 . 248519) (-3759 . 248194) (-3760 . 248041) (-3761 . 247982) (-3762 . 247887) (-3763 . 247674) (-3764 . 247600) (-3765 . 247308) (-3766 . 247104) (-3767 . 246734) (-3768 . 246651) (-3769 . 246504) (-3770 . 246393) (-3771 . 246318) (-3772 . 246102) (-3773 . 246045) (-3774 . 245990) (-3775 . 245449) (-3776 . 245134) (-3777 . 245059) (-3778 . 245030) (-3779 . 244938) (-3780 . 244746) (-3781 . 244523) (-3782 . 244359) (-3783 . 244068) (-3784 . 243820) (-3785 . 243584) (-3786 . 243281) (-3787 . 243229) (-3788 . 243140) (-3789 . 242845) (-3790 . 242746) (-3791 . 242510) (-3792 . 242305) (-3793 . 242228) (-3794 . 242139) (-3795 . 242086) (-3796 . 241973) (-3797 . 241883) (-3798 . 241647) (-3799 . 241594) (-3800 . 241495) (-3801 . 241442) (-3802 . 241351) (-3803 . 241270) (-3804 . 241047) (-3805 . 240978) (-3806 . 240812) (-3807 . 240548) (-3808 . 240481) (-3809 . 240353) (-3810 . 240253) (-3811 . 240140) (-3812 . 239857) (-3813 . 239498) (-3814 . 239144) (-3815 . 239016) (-3816 . 238771) (-3817 . 238588) (-3818 . 238536) (-3819 . 238383) (-3820 . 238248) (-3821 . 237818) (-3822 . 237715) (-3823 . 237615) (-3824 . 237111) (-3825 . 237040) (-3826 . 236791) (-3827 . 236475) (-3828 . 222636) (-3829 . 222270) (-3830 . 222099) (-3831 . 221964) (-3832 . 221936) (-3833 . 221869) (-3834 . 221803) (-3835 . 221562) (-3836 . 221411) (-3837 . 221059) (-3838 . 220792) (-3839 . 220552) (-3840 . 220357) (-3841 . 220070) (-3842 . 219968) (-3843 . 219898) (-3844 . 219795) (-3845 . 219574) (-3846 . 219405) (-3847 . 219275) (-3848 . 219149) (-3849 . 219016) (-3850 . 218912) (-3851 . 218619) (-3852 . 218505) (-3853 . 218353) (-3854 . 218301) (-3855 . 218248) (-3856 . 218115) (-3857 . 218052) (-3858 . 217548) (-3859 . 217477) (-3860 . 217249) (-3861 . 217130) (-3862 . 217080) (-3863 . 214414) (-3864 . 214273) (-3865 . 214181) (-3866 . 214109) (-3867 . 214000) (-3868 . 213727) (-3869 . 213587) (-3870 . 213490) (-3871 . 213438) (-3872 . 213304) (-3873 . 212581) (-3874 . 212431) (-3875 . 212180) (-3876 . 212130) (-3877 . 212046) (-3878 . 211907) (-3879 . 211576) (-3880 . 211319) (-3881 . 211177) (-3882 . 211122) (-3883 . 211070) (-3884 . 210910) (-3885 . 210826) (-3886 . 210623) (-3887 . 210548) (-3888 . 210495) (-3889 . 210323) (-3890 . 210263) (-3891 . 210184) (-3892 . 209876) (-3893 . 209645) (-3894 . 209527) (-3895 . 209374) (-3896 . 209313) (-3897 . 209115) (-3898 . 208794) (-3899 . 208608) (-3900 . 208309) (-3901 . 208228) (-3902 . 208094) (-3903 . 207914) (-3904 . 207567) (-3905 . 207315) (-3906 . 207202) (-3907 . 207054) (-3908 . 206966) (-3909 . 206914) (-3910 . 206493) (-3911 . 206321) (-3912 . 206193) (-3913 . 206098) (-3914 . 205975) (-3915 . 205484) (-3916 . 205265) (-3917 . 205164) (-3918 . 204922) (-3919 . 204791) (-3920 . 204529) (-3921 . 201991) (-3922 . 201959) (-3923 . 201815) (-3924 . 201707) (-3925 . 201387) (-3926 . 201287) (-3927 . 201052) (-3928 . 200953) (-3929 . 200850) (-3930 . 200692) (-3931 . 200572) (-3932 . 200483) (-3933 . 200402) (-3934 . 199760) (-3935 . 199509) (-3936 . 199384) (-3937 . 199185) (-3938 . 199129) (-3939 . 199062) (-3940 . 198972) (-3941 . 198643) (-3942 . 198559) (-3943 . 198486) (-3944 . 198411) (-3945 . 198305) (-3946 . 198274) (-3947 . 198219) (-3948 . 198144) (-3949 . 197580) (-3950 . 197279) (-3951 . 197142) (-3952 . 196960) (-3953 . 196886) (-3954 . 196489) (-3955 . 196385) (-3956 . 196252) (-3957 . 196189) (-3958 . 196137) (-3959 . 195760) (-3960 . 195456) (-3961 . 195414) (-3962 . 195319) (-3963 . 195247) (-3964 . 195042) (-3965 . 194798) (-3966 . 194555) (-3967 . 194405) (-3968 . 194260) (-3969 . 193559) (-3970 . 193401) (-3971 . 193346) (-3972 . 169838) (-3973 . 169635) (-3974 . 169451) (-3975 . 167756) (-3976 . 167661) (-3977 . 167578) (-3978 . 167389) (-3979 . 167337) (-3980 . 166974) (-3981 . 166815) (-3982 . 166698) (-3983 . 166632) (-3984 . 166409) (-3985 . 165889) (-3986 . 165785) (-3987 . 165757) (-3988 . 165192) (-3989 . 165031) (-3990 . 164921) (-3991 . 164033) (-3992 . 163824) (-3993 . 163796) (-3994 . 163222) (-3995 . 163121) (-3996 . 162892) (-3997 . 162637) (-3998 . 162542) (-3999 . 162172) (-4000 . 161949) (-4001 . 161868) (-4002 . 161795) (-4003 . 161694) (-4004 . 161638) (-4005 . 161549) (-4006 . 161497) (-4007 . 161218) (-4008 . 161068) (-4009 . 160945) (-4010 . 160377) (-4011 . 160237) (-4012 . 160033) (-4013 . 159948) (-4014 . 159448) (-4015 . 159364) (-4016 . 159194) (-4017 . 158995) (-4018 . 158779) (-4019 . 158471) (-4020 . 158409) (-4021 . 158296) (-4022 . 158090) (-4023 . 158010) (-4024 . 157656) (-4025 . 157571) (-4026 . 157364) (-4027 . 157284) (-4028 . 157188) (-4029 . 157136) (-4030 . 157108) (-4031 . 157016) (-4032 . 156266) (-4033 . 154661) (-4034 . 154539) (-4035 . 154277) (-4036 . 154029) (-4037 . 153396) (-4038 . 153347) (-4039 . 153273) (-4040 . 153149) (-4041 . 153046) (-4042 . 152781) (-4043 . 152683) (-4044 . 152447) (-4045 . 152394) (-4046 . 152121) (-4047 . 152054) (-4048 . 151941) (-4049 . 151875) (-4050 . 151632) (-4051 . 151577) (-4052 . 150769) (-4053 . 150352) (-4054 . 150233) (-4055 . 150151) (-4056 . 150086) (-4057 . 149821) (-4058 . 149730) (-4059 . 149146) (-4060 . 149091) (-4061 . 149013) (-4062 . 148875) (-4063 . 148826) (-4064 . 148737) (-4065 . 148471) (-4066 . 148414) (-4067 . 148291) (-4068 . 148182) (-4069 . 147760) (-4070 . 147726) (-4071 . 147698) (-4072 . 147613) (-4073 . 147404) (-4074 . 147314) (-4075 . 147286) (-4076 . 146921) (-4077 . 146632) (-4078 . 146456) (-4079 . 146317) (-4080 . 146153) (-4081 . 141695) (-4082 . 141505) (-4083 . 141408) (-4084 . 141198) (-4085 . 141139) (-4086 . 141108) (-4087 . 141030) (-4088 . 140962) (-4089 . 140930) (-4090 . 140627) (-4091 . 140568) (-4092 . 140536) (-4093 . 140447) (-4094 . 140097) (-4095 . 140069) (-4096 . 139950) (-4097 . 139850) (-4098 . 139670) (-4099 . 139520) (-4100 . 139381) (-4101 . 139286) (-4102 . 139179) (-4103 . 139098) (-4104 . 138946) (-4105 . 138894) (-4106 . 138792) (-4107 . 138564) (-4108 . 138154) (-4109 . 138053) (-4110 . 137703) (-4111 . 137551) (-4112 . 137462) (-4113 . 137336) (-4114 . 137236) (-4115 . 137121) (-4116 . 137034) (-4117 . 136962) (-4118 . 136785) (-4119 . 136709) (-4120 . 136559) (-4121 . 136510) (-4122 . 135705) (-4123 . 135210) (-4124 . 135041) (-4125 . 134846) (-4126 . 134818) (-4127 . 134583) (-4128 . 134431) (-4129 . 134324) (-4130 . 134272) (-4131 . 134075) (-4132 . 133938) (-4133 . 133889) (-4134 . 133818) (-4135 . 133720) (-4136 . 133606) (-4137 . 133515) (-4138 . 133487) (-4139 . 133337) (-4140 . 133222) (-4141 . 133170) (-4142 . 133011) (-4143 . 132888) (-4144 . 132710) (-4145 . 132427) (-4146 . 132234) (-4147 . 132181) (-4148 . 132051) (-4149 . 131998) (-4150 . 131705) (-4151 . 131622) (-4152 . 131198) (-4153 . 131088) (-4154 . 130955) (-4155 . 130879) (-4156 . 130724) (-4157 . 130576) (-4158 . 130473) (-4159 . 130421) (-4160 . 130354) (-4161 . 130263) (-4162 . 130012) (-4163 . 129946) (-4164 . 129823) (-4165 . 127954) (-4166 . 127787) (-4167 . 127721) (-4168 . 127623) (-4169 . 127424) (-4170 . 127345) (-4171 . 127276) (-4172 . 127031) (-4173 . 126979) (-4174 . 126627) (-4175 . 126575) (-4176 . 126464) (-4177 . 126360) (-4178 . 126170) (-4179 . 125020) (-4180 . 124865) (-4181 . 124812) (-4182 . 124709) (-4183 . 124035) (-4184 . 123781) (-4185 . 123592) (-4186 . 123529) (-4187 . 123497) (-4188 . 123389) (-4189 . 123286) (-4190 . 122904) (-4191 . 122766) (-4192 . 122543) (** . 119394) (-4194 . 119301) (-4195 . 119185) (-4196 . 119078) (-4197 . 118954) (-4198 . 118815) (-4199 . 118628) (-4200 . 118545) (-4201 . 118517) (-4202 . 118443) (-4203 . 118304) (-4204 . 118234) (-4205 . 118046) (-4206 . 117851) (-4207 . 117648) (-4208 . 117596) (-4209 . 117451) (-4210 . 117351) (-4211 . 117295) (-4212 . 116973) (-4213 . 116834) (-4214 . 116759) (-4215 . 116662) (-4216 . 116513) (-4217 . 115808) (-4218 . 115674) (-4219 . 115522) (-4220 . 114817) (-4221 . 114496) (-4222 . 114307) (-4223 . 114152) (-4224 . 113499) (-4225 . 113352) (-4226 . 113250) (-4227 . 112955) (-4228 . 112408) (-4229 . 112300) (-4230 . 112243) (-4231 . 112118) (-4232 . 111918) (-4233 . 111371) (-4234 . 111337) (-4235 . 111253) (-4236 . 111149) (-4237 . 110602) (-4238 . 110279) (-4239 . 110156) (-4240 . 109964) (-4241 . 109313) (-4242 . 108753) (-4243 . 108582) (-4244 . 108436) (-4245 . 108313) (-4246 . 107662) (-4247 . 107470) (-4248 . 107267) (-4249 . 107196) (-4250 . 107159) (-4251 . 106446) (-4252 . 106324) (-4253 . 106208) (-4254 . 106128) (-4255 . 106013) (-4256 . 105882) (-4257 . 105337) (-4258 . 105135) (-4259 . 105036) (-4260 . 104910) (-4261 . 104857) (-4262 . 104618) (-4263 . 104073) (-4264 . 103969) (-4265 . 103373) (-4266 . 103265) (-4267 . 103024) (-4268 . 102479) (-4269 . 102371) (-4270 . 102223) (-4271 . 102150) (-4272 . 102061) (-4273 . 101409) (-4274 . 101325) (-4275 . 101218) (-4276 . 101189) (-4277 . 101079) (-4278 . 100427) (-4279 . 100169) (-4280 . 99946) (-4281 . 99876) (-4282 . 99362) (-4283 . 99294) (-4284 . 98642) (-4285 . 96605) (-4286 . 96550) (-4287 . 96477) (-4288 . 96290) (-4289 . 95744) (-4290 . 95641) (-4291 . 95579) (-4292 . 95476) (-4293 . 95261) (-4294 . 95187) (-4295 . 94641) (-4296 . 94243) (-4297 . 92778) (-4298 . 92726) (-4299 . 92051) (-4300 . 91940) (-4301 . 91751) (-4302 . 91205) (-4303 . 91094) (-4304 . 85512) (-4305 . 85423) (-4306 . 85166) (-4307 . 85017) (-4308 . 84472) (-4309 . 84410) (-4310 . 84073) (-4311 . 83865) (-4312 . 83772) (-4313 . 83649) (-4314 . 83104) (-4315 . 83026) (-4316 . 80584) (-4317 . 80501) (-4318 . 80408) (-4319 . 80186) (-4320 . 79253) (-4321 . 78708) (-4322 . 78579) (-4323 . 78301) (-4324 . 78059) (-4325 . 77959) (-4326 . 77907) (-4327 . 77362) (-4328 . 75814) (-4329 . 75713) (-4330 . 75209) (-4331 . 75059) (-4332 . 74962) (-4333 . 74417) (-4334 . 74362) (-4335 . 73546) (-4336 . 73496) (-4337 . 72924) (-4338 . 72858) (-4339 . 72724) (-4340 . 72693) (-4341 . 72619) (-4342 . 72504) (-4343 . 72217) (-4344 . 72158) (-4345 . 72074) (-4346 . 71876) (-4347 . 71659) (-4348 . 71586) (-4349 . 71536) (-4350 . 70830) (-4351 . 70353) (-4352 . 70283) (-4353 . 70096) (-4354 . 70028) (-4355 . 69488) (-4356 . 69324) (-4357 . 69011) (-4358 . 68771) (-4359 . 68705) (-4360 . 67308) (-4361 . 67205) (-4362 . 67079) (-4363 . 66975) (-4364 . 66893) (-4365 . 66795) (-4366 . 62871) (-4367 . 62667) (-4368 . 62062) (-4369 . 61964) (-4370 . 61411) (-4371 . 61355) (-4372 . 61278) (-4373 . 60163) (-4374 . 60074) (-4375 . 59353) (-4376 . 59250) (-4377 . 59128) (-4378 . 59018) (-4379 . 58839) (-4380 . 58708) (-4381 . 58635) (-4382 . 58583) (-4383 . 57450) (-4384 . 56477) (-4385 . 55879) (-4386 . 55679) (-4387 . 55546) (-4388 . 55459) (-4389 . 55407) (-4390 . 55310) (-4391 . 55141) (-4392 . 55054) (-4393 . 54814) (-4394 . 54738) (-4395 . 54704) (-4396 . 54646) (-4397 . 54283) (-4398 . 54201) (-4399 . 53663) (-4400 . 53582) (-4401 . 53496) (-4402 . 53445) (-4403 . 53361) (-4404 . 53275) (-4405 . 53171) (-4406 . 52782) (-4407 . 52672) (-4408 . 52577) (-4409 . 52506) (-4410 . 52239) (-4411 . 52097) (-4412 . 51955) (-4413 . 51659) (-4414 . 51470) (-4415 . 51376) (-4416 . 50944) (-4417 . 50892) (-4418 . 50695) (-4419 . 50503) (-4420 . 50286) (-4421 . 50008) (-4422 . 49907) (-4423 . 49571) (-4424 . 49196) (-4425 . 49088) (-4426 . 48995) (-4427 . 48933) (-4428 . 48628) (-4429 . 46913) (-4430 . 46882) (-4431 . 46776) (-4432 . 46612) (-4433 . 46512) (-4434 . 46340) (-4435 . 45654) (-4436 . 45572) (-4437 . 45461) (-4438 . 45287) (-4439 . 45174) (-4440 . 44718) (-4441 . 44445) (-4442 . 44319) (-4443 . 44259) (-4444 . 43740) (-4445 . 43672) (-4446 . 43638) (-4447 . 43550) (-4448 . 43478) (-4449 . 43371) (-4450 . 43208) (-4451 . 43097) (-4452 . 42827) (-4453 . 42724) (-4454 . 42606) (-4455 . 41887) (-4456 . 41270) (-4457 . 40374) (-4458 . 40214) (-4459 . 40151) (-4460 . 40085) (-4461 . 40028) (-4462 . 39902) (-4463 . 39786) (-4464 . 39565) (-4465 . 39254) (-4466 . 39183) (-4467 . 38556) (-4468 . 38363) (-4469 . 38289) (-4470 . 38154) (-4471 . 38125) (-4472 . 37886) (-4473 . 37439) (-4474 . 37364) (-4475 . 36788) (-4476 . 36714) (-4477 . 36580) (-4478 . 36530) (-4479 . 36422) (-4480 . 36209) (-4481 . 36157) (-4482 . 36087) (-4483 . 35801) (-4484 . 35613) (-4485 . 29781) (-4486 . 29698) (-4487 . 29024) (-4488 . 28916) (-4489 . 28882) (-4490 . 28798) (-4491 . 28733) (-4492 . 28079) (-4493 . 27744) (-4494 . 27580) (-4495 . 27190) (-4496 . 26891) (-4497 . 26820) (-4498 . 26604) (-4499 . 26500) (-4500 . 25830) (-4501 . 25539) (-4502 . 21673) (-4503 . 21551) (-4504 . 21401) (-4505 . 21346) (-4506 . 21294) (-4507 . 19059) (-4508 . 18963) (-4509 . 18477) (-4510 . 18269) (-4511 . 17911) (-4512 . 17704) (-4513 . 17363) (-4514 . 17252) (-4515 . 17171) (-4516 . 17057) (-4517 . 16440) (-4518 . 16178) (-4519 . 16061) (-4520 . 15995) (-4521 . 13156) (-4522 . 12823) (-4523 . 12477) (-4524 . 12396) (-4525 . 12290) (-4526 . 11948) (-4527 . 11820) (-4528 . 11767) (-4529 . 11615) (-4530 . 11378) (-4531 . 11142) (-4532 . 10831) (-4533 . 10527) (-4534 . 10396) (-4535 . 10034) (-4536 . 9984) (-4537 . 9808) (-4538 . 9650) (-4539 . 9560) (-4540 . 9435) (-4541 . 9283) (-4542 . 9111) (-4543 . 8299) (-4544 . 8196) (-4545 . 8089) (-4546 . 8026) (-4547 . 7597) (-4548 . 7533) (-4549 . 7449) (-4550 . 7327) (-4551 . 7261) (-4552 . 6849) (-4553 . 6746) (-4554 . 6539) (-4555 . 6421) (-4556 . 6172) (-4557 . 5225) (-4558 . 4967) (-4559 . 4838) (-4560 . 4603) (-4561 . 4478) (-4562 . 4222) (-4563 . 4140) (-4564 . 3143) (-4565 . 2733) (-4566 . 2432) (-4567 . 2358) (-4568 . 2278) (-4569 . 2194) (-4570 . 2142) (-4571 . 2015) (-4572 . 1908) (-4573 . 1644) (-4574 . 1589) (-4575 . 1515) (-4576 . 1412) (-4577 . 1217) (-4578 . 1047) (-4579 . 938) (-4580 . 697) (-4581 . 192) (-4582 . 30)) 
\ No newline at end of file
+(843383 . 3613822958)        
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-327)) (-5 *1 (-851))))) 
+(((*1 *2 *3 *3) (-12 (|has| *2 (-6 (-4627 "*"))) (-4 *5 (-399 *2)) (-4 *6 (-399 *2)) (-4 *2 (-1075)) (-5 *1 (-128 *2 *3 *4 *5 *6)) (-4 *3 (-1255 *2)) (-4 *4 (-704 *2 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-658 (-658 *3))))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-658 (-658 *5))))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-658 *3))) (-5 *1 (-1198 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *1 *1) (-4 *1 (-39))) ((*1 *1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *1 *1) (-5 *1 (-143))) ((*1 *1 *1) (-5 *1 (-193))) ((*1 *1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-4 *1 (-574))) ((*1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) ((*1 *1 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) ((*1 *1 *1) (-12 (-4 *1 (-1151 *2)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) ((*1 *1 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-617 *3)) (-4 *3 (-43 *2)) (-4 *3 (-1075))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-433 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *4 (-388)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141))))) 
+(((*1 *1 *1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *3 (-582))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)))) ((*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-658 (-1191))))) ((*1 *1 *1) (-12 (-5 *1 (-235 *2 *3)) (-4 *2 (-13 (-1075) (-869))) (-14 *3 (-658 (-1191))))) ((*1 *1 *1) (-12 (-5 *1 (-258 *2)) (-4 *2 (-1117)))) ((*1 *1 *1) (-12 (-4 *1 (-408 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-1119)))) ((*1 *1 *1) (-12 (-14 *2 (-658 (-1191))) (-4 *3 (-194)) (-4 *5 (-252 (-1699 *2) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *4) (|:| -3215 *5)) (-2 (|:| -1825 *4) (|:| -3215 *5)))) (-5 *1 (-487 *2 *3 *4 *5 *6 *7)) (-4 *4 (-869)) (-4 *7 (-977 *3 *5 (-879 *2))))) ((*1 *1 *1) (-12 (-4 *1 (-542 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-869)))) ((*1 *1 *1) (-12 (-4 *2 (-582)) (-5 *1 (-639 *2 *3)) (-4 *3 (-1255 *2)))) ((*1 *1 *1) (-12 (-4 *1 (-725 *2)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-752 *2 *3)) (-4 *3 (-869)) (-4 *2 (-1075)) (-4 *3 (-743)))) ((*1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-5 *1 (-1301 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-865))))) 
+(((*1 *1 *2 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1171 *2)) (-4 *2 (-1225))))) 
+(((*1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-778))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1063))))) 
+(((*1 *1) (-5 *1 (-1282)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-264 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-1075)) (-5 *2 (-980 *5)) (-5 *1 (-972 *4 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-1116 *3)))) ((*1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-977 *3 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1034)))) ((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1034))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-980 (-592))) (-5 *2 (-350)) (-5 *1 (-352))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-2 (|:| -4249 *5) (|:| -2042 *3)))) (-5 *1 (-831 *5 *6 *3 *7)) (-4 *3 (-670 *6)) (-4 *7 (-670 (-433 *6)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) ((*1 *2 *1) (-12 (-4 *2 (-1075)) (-5 *1 (-55 *2 *3)) (-14 *3 (-658 (-1191))))) ((*1 *2 *1) (-12 (-5 *2 (-332 *3)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) ((*1 *2 *1) (-12 (-4 *1 (-408 *2 *3)) (-4 *3 (-1119)) (-4 *2 (-1075)))) ((*1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *5 (-252 (-1699 *3) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *4) (|:| -3215 *5)) (-2 (|:| -1825 *4) (|:| -3215 *5)))) (-4 *2 (-194)) (-5 *1 (-487 *3 *2 *4 *5 *6 *7)) (-4 *4 (-869)) (-4 *7 (-977 *2 *5 (-879 *3))))) ((*1 *2 *1) (-12 (-4 *1 (-542 *2 *3)) (-4 *3 (-869)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *2 (-582)) (-5 *1 (-639 *2 *3)) (-4 *3 (-1255 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-725 *2)) (-4 *2 (-1075)))) ((*1 *2 *1) (-12 (-4 *2 (-1075)) (-5 *1 (-752 *2 *3)) (-4 *3 (-869)) (-4 *3 (-743)))) ((*1 *2 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)))) ((*1 *2 *1) (-12 (-4 *1 (-1002 *2 *3 *4)) (-4 *3 (-814)) (-4 *4 (-869)) (-4 *2 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869))))) 
+(((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)) (-4 *2 (-1211)))) ((*1 *2 *1) (-12 (-5 *1 (-351 *2)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-631 *3)) (-4 *3 (-869))))) 
+(((*1 *1 *1) (-5 *1 (-877))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *2 *3 *4 *5 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1172)))) ((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1191))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)))) ((*1 *2 *1) (-12 (-4 *1 (-408 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-4 *6 (-252 (-1699 *3) (-790))) (-14 *7 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *6)) (-2 (|:| -1825 *5) (|:| -3215 *6)))) (-5 *2 (-730 *5 *6 *7)) (-5 *1 (-487 *3 *4 *5 *6 *7 *8)) (-4 *5 (-869)) (-4 *8 (-977 *4 *6 (-879 *3))))) ((*1 *2 *1) (-12 (-4 *2 (-743)) (-4 *2 (-869)) (-5 *1 (-752 *3 *2)) (-4 *3 (-1075)))) ((*1 *1 *1) (-12 (-4 *1 (-1002 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *4 (-869))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *4 (-1 *2 *2)) (-4 *2 (-661 *5)) (-4 *5 (-1075)) (-5 *1 (-59 *5 *2 *3)) (-4 *3 (-871 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-706 *3)) (-4 *1 (-443 *3)) (-4 *3 (-194)))) ((*1 *2 *1 *2 *2) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)))) ((*1 *2 *3 *2 *2 *4 *5) (-12 (-5 *4 (-121 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-1075)) (-5 *1 (-872 *2 *3)) (-4 *3 (-871 *2))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-643 *5 *6))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-323)))) ((*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-412 *3)) (|:| |rm| (-412 *3)))) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2230 (-790)) (|:| -3027 (-790)))) (-5 *1 (-790)))) ((*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-3 (-841 *3) "failed")) (|:| |rm| (-3 (-841 *3) "failed")))) (-5 *1 (-841 *3)) (-4 *3 (-869)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1801 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477))))) 
+(((*1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -3191 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-433 *7)) (|:| |a0| *6)) (-2 (|:| -3191 (-433 *7)) (|:| |coeff| (-433 *7))) "failed")) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-346 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) ((*1 *2 *1) (-12 (-4 *1 (-456 *2)) (-4 *2 (-869))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 *3)) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-944))) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 *3)) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-639 *4 *5)) (-5 *3 (-1 (-2 (|:| |ans| *4) (|:| -1954 *4) (|:| |sol?| (-141))) (-592) *4)) (-4 *4 (-388)) (-4 *5 (-1255 *4)) (-5 *1 (-602 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1121 (-1121 *3))) (-5 *1 (-926 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-96 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-4 *1 (-131 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-234 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-518 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1028 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1161 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-456 *3)) (-4 *3 (-869)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-760 *3 *4)) (-14 *3 (-1191)) (-4 *4 (-13 (-1075) (-869) (-582))))) ((*1 *2 *1) (-12 (-4 *1 (-885)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1075)) (-5 *1 (-340 *4 *5 *2 *6)) (-4 *6 (-977 *2 *4 *5))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-658 *7)) (|:| |badPols| (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-193)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)) (-4 *5 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-592)) (-5 *1 (-597 *3)) (-4 *3 (-1065 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *2 *5 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119))))) 
+(((*1 *1 *1) (-4 *1 (-260))) ((*1 *1 *1) (-12 (-4 *2 (-194)) (-5 *1 (-306 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1255 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (-3836 (-12 (-5 *1 (-310 *2)) (-4 *2 (-388)) (-4 *2 (-1225))) (-12 (-5 *1 (-310 *2)) (-4 *2 (-502)) (-4 *2 (-1225))))) ((*1 *1 *1) (-4 *1 (-502))) ((*1 *2 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-373)) (-5 *1 (-556 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)) (-4 *2 (-388))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-362 *4 *3 *5)) (-4 *4 (-1235)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-790)) (-5 *1 (-761 *4 *3)) (-14 *4 (-1191)) (-4 *3 (-1075)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-790)) (-5 *1 (-804 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *1 (-992 *3 *2)) (-4 *2 (-158)) (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *2 (-814)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1187 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-1000)) (-4 *2 (-158)) (-5 *1 (-1193 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1252 *4 *3)) (-14 *4 (-1191)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *7))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1040)) (-5 *2 (-877))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-698 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-4 *1 (-301))) ((*1 *2 *3) (-12 (-5 *3 (-444 *4)) (-4 *4 (-582)) (-5 *2 (-658 (-2 (|:| -1487 (-790)) (|:| |logand| *4)))) (-5 *1 (-338 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *2 *1) (-12 (-5 *2 (-681 *3 *4)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-1075) (-734 (-433 (-592))))) (-4 *5 (-869)) (-5 *1 (-1294 *4 *5 *2)) (-4 *2 (-1299 *5 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1298 *3 *4)) (-4 *4 (-734 (-433 (-592)))) (-4 *3 (-869)) (-4 *4 (-194))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $)))))))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1187 *4)) (-5 *1 (-556 *4)) (-4 *4 (-373))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-405)) (-5 *1 (-1087))))) 
+(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-592)) (-5 *3 (-944)) (-4 *1 (-430)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-4 *1 (-430)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *2 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119))))) 
+(((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-658 *1)) (-4 *1 (-943))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *1 (-610 *2)) (-4 *2 (-574))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 *13)) (-4 *13 (-280 *12)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) *2)) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-5 *2 (-790)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-143))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-1171 (-980 *4)) (-1171 (-980 *4)))) (-5 *1 (-1288 *4)) (-4 *4 (-388))))) 
+(((*1 *2 *3 *4) (-12 (-4 *6 (-582)) (-4 *2 (-977 *3 *5 *4)) (-5 *1 (-749 *5 *4 *6 *2)) (-5 *3 (-433 (-980 *6))) (-4 *5 (-815)) (-4 *4 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)))))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1187 (-433 (-1187 *2)))) (-5 *4 (-631 *2)) (-4 *2 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *1 (-588 *5 *2 *6)) (-4 *6 (-1119)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-977 *4 *5 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1187 *4)) (-4 *4 (-1075)) (-4 *1 (-977 *4 *5 *3)) (-4 *5 (-815)) (-4 *3 (-869)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-1187 *2))) (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-1075)) (-4 *2 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))) (-5 *1 (-978 *5 *4 *6 *7 *2)) (-4 *7 (-977 *6 *5 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-1187 (-433 (-980 *5))))) (-5 *4 (-1191)) (-5 *2 (-433 (-980 *5))) (-5 *1 (-1070 *5)) (-4 *5 (-582))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-350)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-350))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-698 *2)) (-4 *2 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-658 *5) (-658 *5))) (-5 *4 (-592)) (-5 *2 (-658 *5)) (-5 *1 (-698 *5)) (-4 *5 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)))) ((*1 *2 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-388)))) ((*1 *2 *1) (-12 (-4 *1 (-396 *2 *3)) (-4 *3 (-1255 *2)) (-4 *2 (-194)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-944)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 (-631 *4))) (-4 *4 (-456 *3)) (-4 *3 (-869)) (-5 *1 (-601 *3 *4)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-911 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *2 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-658 (-944))) (-5 *1 (-176 *4 *2 *5)) (-14 *4 (-944)) (-4 *2 (-388)) (-14 *5 (-1022 *4 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-730 *5 *6 *7)) (-4 *5 (-869)) (-4 *6 (-252 (-1699 *4) (-790))) (-14 *7 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *6)) (-2 (|:| -1825 *5) (|:| -3215 *6)))) (-14 *4 (-658 (-1191))) (-4 *2 (-194)) (-5 *1 (-487 *4 *2 *5 *6 *7 *8)) (-4 *8 (-977 *2 *6 (-879 *4))))) ((*1 *1 *2 *3) (-12 (-4 *1 (-542 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-869)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-4 *2 (-582)) (-5 *1 (-639 *2 *4)) (-4 *4 (-1255 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-725 *2)) (-4 *2 (-1075)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-752 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-743)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *5)) (-5 *3 (-658 (-790))) (-4 *1 (-757 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-869)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-757 *4 *2)) (-4 *4 (-1075)) (-4 *2 (-869)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-871 *2)) (-4 *2 (-1075)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *6)) (-5 *3 (-658 (-790))) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-977 *4 *5 *2)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *2 (-869)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *6)) (-5 *3 (-658 *5)) (-4 *1 (-1002 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-814)) (-4 *6 (-869)))) ((*1 *1 *1 *2 *3) (-12 (-4 *1 (-1002 *4 *3 *2)) (-4 *4 (-1075)) (-4 *3 (-814)) (-4 *2 (-869))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-52 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) ((*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-592)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-268 *4 *3 *5 *6)) (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-293)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1187 *8)) (-5 *4 (-658 *6)) (-4 *6 (-869)) (-4 *8 (-977 *7 *5 *6)) (-4 *5 (-815)) (-4 *7 (-1075)) (-5 *2 (-658 (-790))) (-5 *1 (-340 *5 *6 *7 *8)))) ((*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-944)))) ((*1 *2 *1) (-12 (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-499 *3 *2)) (-4 *3 (-194)) (-4 *2 (-23)))) ((*1 *2 *1) (-12 (-4 *3 (-582)) (-5 *2 (-592)) (-5 *1 (-639 *3 *4)) (-4 *4 (-1255 *3)))) ((*1 *2 *3) (-12 (-4 *1 (-692 *3 *4)) (-4 *3 (-1225)) (-4 *4 (-1225)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-4 *1 (-725 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-871 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-1075)) (-4 *6 (-252 *7 *2)) (-14 *7 *2) (-5 *2 (-790)) (-5 *1 (-935 *5 *3 *6 *7)) (-4 *3 (-346 *5 *6)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 (-790))))) ((*1 *2 *1 *3) (-12 (-4 *1 (-977 *4 *5 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-790)))) ((*1 *2 *3) (-12 (-5 *3 (-1229)) (-5 *2 (-592)) (-5 *1 (-982)))) ((*1 *2 *1) (-12 (-4 *1 (-1002 *3 *2 *4)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *2 (-814)))) ((*1 *2 *1) (-12 (-4 *1 (-1117)) (-5 *2 (-944)))) ((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-1241 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1270 *3)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-4 *1 (-1262 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1239 *3)) (-5 *2 (-433 (-592))))) ((*1 *2 *1) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-855 (-944))))) ((*1 *2 *1) (-12 (-4 *1 (-1299 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-790))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-5 *2 (-706 *4)) (-5 *1 (-836 *4 *5)) (-4 *5 (-670 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-790)) (-4 *5 (-388)) (-5 *2 (-706 *5)) (-5 *1 (-836 *5 *6)) (-4 *6 (-670 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-925 *3))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-1 (-609 *3) *3 (-1191))) (-5 *6 (-1 (-3 (-2 (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (-1191))) (-4 *3 (-301)) (-4 *3 (-644)) (-4 *3 (-1065 *4)) (-4 *3 (-456 *7)) (-5 *4 (-1191)) (-4 *7 (-633 (-914 (-592)))) (-4 *7 (-477)) (-4 *7 (-908 (-592))) (-4 *7 (-869)) (-5 *2 (-609 *3)) (-5 *1 (-601 *7 *3))))) 
+(((*1 *2 *2 *1) (-12 (-5 *2 (-658 *6)) (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-5 *1 (-1200 *2)) (-4 *2 (-388))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *3)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 *4)))) (-5 *1 (-911 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) ((*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-658 *1)) (-4 *1 (-1122 *3 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-2 (|:| -1487 *1) (|:| |gap| (-790)) (|:| -3027 *1))) (-4 *1 (-1089 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -1487 *1) (|:| |gap| (-790)) (|:| -3027 *1))) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *2 (-141)) (-5 *1 (-224))))) 
+(((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-790)) (-4 *5 (-388)) (-5 *2 (-195 *6)) (-5 *1 (-888 *5 *4 *6)) (-4 *4 (-1270 *5)) (-4 *6 (-1255 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1280 *4)) (-4 *4 (-1225)) (-4 *1 (-252 *3 *4))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3))))) 
+(((*1 *1 *1 *2) (|partial| -12 (-5 *2 (-790)) (-4 *1 (-1255 *3)) (-4 *3 (-1075))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-405))) (-5 *1 (-278)))) ((*1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-582)) (-4 *2 (-194)))) ((*1 *2 *1) (-12 (-5 *1 (-444 *2)) (-4 *2 (-582))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1016 (-433 (-592)) (-879 *3) (-254 *4 (-790)) (-264 *3 (-433 (-592))))) (-14 *3 (-658 (-1191))) (-14 *4 (-790)) (-5 *1 (-1015 *3 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) *4)) (-4 *9 (-999 *5)) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-4 *3 (-257 *11)) (-4 *12 (-560 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-137)) (-5 *2 (-658 *7)) (-5 *1 (-491 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-4 *13 (-280 *12)))) ((*1 *2 *3 *4 *5 *2) (-12 (-5 *2 (-658 *5)) (-4 *5 (-977 *6 *8 (-879 *7))) (-4 *8 (-252 (-1699 *7) *4)) (-5 *4 (-790)) (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *10 (-665 *6)) (-4 *11 (-947 *6 *10)) (-5 *1 (-586 *6 *7 *5 *8 *9 *10 *11 *3)) (-4 *9 (-999 *6)) (-4 *3 (-257 *11)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-258 (-949 *5))) (-5 *4 (-790)) (-4 *5 (-373)) (-5 *2 (-658 (-264 *6 *5))) (-5 *1 (-894 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-258 (-948 *5))) (-5 *4 (-790)) (-4 *5 (-388)) (-5 *2 (-658 (-264 *6 *5))) (-5 *1 (-895 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-332 *4)) (-5 *1 (-202 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 (-191 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3)))))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-841 *3)) (-4 *3 (-869)) (-5 *1 (-688 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-191 (-237)) (-191 (-237)))) (-5 *4 (-1113 (-237))) (-5 *2 (-1282)) (-5 *1 (-272))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-665 *3)) (-4 *8 (-947 *3 *7)) (-4 *9 (-257 *8)) (-4 *10 (-137)) (-4 *2 (-999 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-53))) (-5 *2 (-444 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1255 (-53))))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1255 (-53))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-53))) (-4 *5 (-869)) (-4 *6 (-815)) (-5 *2 (-444 *3)) (-5 *1 (-47 *5 *6 *3)) (-4 *3 (-977 (-53) *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-53))) (-4 *5 (-869)) (-4 *6 (-815)) (-4 *7 (-977 (-53) *6 *5)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-47 *5 *6 *7)) (-5 *3 (-1187 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-189 *4 *3)) (-4 *3 (-1255 (-191 *4))))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-141)) (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-229 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-881)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-337 *4)) (-5 *3 (-1187 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-886)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-339 *4)) (-5 *3 (-1187 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-790))) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-790))) (-5 *5 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3) (-12 (-5 *2 (-444 (-191 (-592)))) (-5 *1 (-471)) (-5 *3 (-191 (-592))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-4 *5 (-815)) (-4 *7 (-582)) (-5 *2 (-444 *3)) (-5 *1 (-482 *4 *5 *6 *7 *3)) (-4 *6 (-582)) (-4 *3 (-977 *7 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-323)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-484 *4)) (-5 *3 (-1187 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-4 *7 (-13 (-388) (-171) (-741 *5 *6))) (-5 *2 (-444 *3)) (-5 *1 (-527 *5 *6 *7 *3)) (-4 *3 (-1255 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-444 (-1187 *7)) (-1187 *7))) (-4 *7 (-13 (-323) (-171))) (-4 *5 (-869)) (-4 *6 (-815)) (-5 *2 (-444 *3)) (-5 *1 (-569 *5 *6 *7 *3)) (-4 *3 (-977 *7 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-444 (-1187 *7)) (-1187 *7))) (-4 *7 (-13 (-323) (-171))) (-4 *5 (-869)) (-4 *6 (-815)) (-4 *8 (-977 *7 *6 *5)) (-5 *2 (-444 (-1187 *8))) (-5 *1 (-569 *5 *6 *7 *8)) (-5 *3 (-1187 *8)))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-585 *3)) (-4 *3 (-574)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-667 (-433 *6)))) (-5 *1 (-671 *5 *6)) (-5 *3 (-667 (-433 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-667 (-433 *5)))) (-5 *1 (-671 *4 *5)) (-5 *3 (-667 (-433 *5))))) ((*1 *2 *3) (-12 (-5 *3 (-841 *4)) (-4 *4 (-869)) (-5 *2 (-658 (-688 *4))) (-5 *1 (-688 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-5 *2 (-658 *3)) (-5 *1 (-712 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-714 *4 *5 *6 *3)) (-4 *3 (-977 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-373)) (-4 *7 (-977 *6 *5 *4)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-714 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-4 *6 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-747 *4 *5 *6 *3)) (-4 *3 (-977 (-980 *6) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *6 (-582)) (-5 *2 (-444 *3)) (-5 *1 (-749 *4 *5 *6 *3)) (-4 *3 (-977 (-433 (-980 *6)) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-13 (-323) (-171))) (-5 *2 (-444 *3)) (-5 *1 (-750 *4 *5 *6 *3)) (-4 *3 (-977 (-433 *6) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-13 (-323) (-171))) (-5 *2 (-444 *3)) (-5 *1 (-758 *4 *5 *6 *3)) (-4 *3 (-977 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-977 *6 *5 *4)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-758 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1035 *3)) (-4 *3 (-1255 (-433 (-592)))))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1068 *3)) (-4 *3 (-1255 (-433 (-980 (-592))))))) ((*1 *2 *3) (-12 (-4 *4 (-1255 (-433 (-592)))) (-4 *5 (-13 (-388) (-171) (-741 (-433 (-592)) *4))) (-5 *2 (-444 *3)) (-5 *1 (-1100 *4 *5 *3)) (-4 *3 (-1255 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-1255 (-433 (-980 (-592))))) (-4 *5 (-13 (-388) (-171) (-741 (-433 (-980 (-592))) *4))) (-5 *2 (-444 *3)) (-5 *1 (-1102 *4 *5 *3)) (-4 *3 (-1255 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-477)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-444 (-1187 (-433 *7)))) (-5 *1 (-1186 *4 *5 *6 *7)) (-5 *3 (-1187 (-433 *7))))) ((*1 *2 *1) (-12 (-5 *2 (-444 *1)) (-4 *1 (-1235)))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1244 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)) (-5 *2 (-141)) (-5 *1 (-1016 *3 *4 *5 *6)) (-4 *6 (-977 *3 *5 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1123)) (-5 *2 (-1285)) (-5 *1 (-122))))) 
+(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-435 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-706 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-631 *1)) (-4 *1 (-456 *4)) (-4 *4 (-869)) (-4 *4 (-582)) (-5 *2 (-433 (-1187 *1))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-631 *3)) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-1187 (-433 (-1187 *3)))) (-5 *1 (-588 *6 *3 *7)) (-5 *5 (-1187 *3)) (-4 *7 (-1119)))) ((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *2 (-1187 *4)) (-5 *1 (-935 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1276 *5)) (-14 *5 (-1191)) (-4 *6 (-1075)) (-5 *2 (-1252 *5 (-980 *6))) (-5 *1 (-975 *5 *6)) (-5 *3 (-980 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-1187 *3)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-1187 *1)) (-4 *1 (-977 *4 *5 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *5 *4)) (-5 *2 (-433 (-1187 *3))) (-5 *1 (-978 *5 *4 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-1187 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))) (-4 *7 (-977 *6 *5 *4)) (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-1075)) (-5 *1 (-978 *5 *4 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-582)) (-5 *2 (-433 (-1187 (-433 (-980 *5))))) (-5 *1 (-1070 *5)) (-5 *3 (-433 (-980 *5)))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-399 *2)) (-4 *2 (-1225)) (-4 *2 (-869)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-141) *3 *3)) (-4 *1 (-399 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1151 *2)) (-4 *2 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-1179 *3 *4))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 *6 *5)) (-5 *1 (-723 *4 *5 *6)) (-4 *4 (-633 (-565))) (-4 *5 (-1225)) (-4 *6 (-1225))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-323)) (-4 *6 (-399 *5)) (-4 *4 (-399 *5)) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-1141 *5 *6 *4 *3)) (-4 *3 (-704 *5 *6 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1187 *2)) (-4 *2 (-977 (-433 (-980 *6)) *5 *4)) (-5 *1 (-749 *5 *4 *6 *2)) (-4 *5 (-815)) (-4 *4 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *6 (-582))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-631 *1))) (-4 *1 (-318))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-4 *7 (-977 *4 *6 *5)) (-5 *2 (-2 (|:| |sysok| (-141)) (|:| |z0| (-658 *7)) (|:| |n0| (-658 *7)))) (-5 *1 (-951 *4 *5 *6 *7)) (-5 *3 (-658 *7))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -1544 *3) (|:| |coef1| (-804 *3)) (|:| |coef2| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-444 *3)) (-5 *1 (-937 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *3 (-869)) (-4 *3 (-1065 (-592))) (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-456 *3)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $)))))))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-191 (-405))) (-5 *1 (-807 *3)) (-4 *3 (-633 (-405))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-5 *2 (-191 (-405))) (-5 *1 (-807 *3)) (-4 *3 (-633 (-405))))) ((*1 *2 *3) (-12 (-5 *3 (-191 *4)) (-4 *4 (-194)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-191 *5)) (-5 *4 (-944)) (-4 *5 (-194)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-980 (-191 *4))) (-4 *4 (-194)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-980 (-191 *5))) (-5 *4 (-944)) (-4 *5 (-194)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-980 *4)) (-4 *4 (-1075)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-980 *5)) (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-433 (-980 (-191 *4)))) (-4 *4 (-582)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-191 *5)))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-332 *4)) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-332 *5)) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-332 (-191 *4))) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-332 (-191 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-477)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-592)) (-5 *1 (-1133 *4 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-592))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-14 *5 (-658 (-1191))) (-4 *3 (-977 *2 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *2)) (-4 *8 (-665 *2)) (-4 *4 (-947 *2 *8)) (-4 *9 (-257 *4)) (-4 *10 (-560 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-14 *5 (-658 (-1191))) (-4 *3 (-977 *2 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *2)) (-4 *8 (-665 *2)) (-4 *4 (-947 *2 *8)) (-4 *9 (-257 *4)) (-4 *10 (-560 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 *6)) (-4 *6 (-977 *2 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-14 *5 (-658 (-1191))) (-4 *8 (-999 *2)) (-4 *9 (-665 *2)) (-4 *4 (-947 *2 *9)) (-4 *10 (-257 *4)) (-4 *11 (-560 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-264 *5 *2)) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-264 *5 *2)) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-264 *5 *2))) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-264 *5 *2)) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-264 *5 *2)) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-264 *5 *2))) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-944)) (-5 *2 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-5 *1 (-370 *4)) (-4 *4 (-373))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *4 *4 *5 *4 *3 *6 *3 *4 *7 *8 *9 *10) (-12 (-5 *4 (-592)) (-5 *5 (-1173)) (-5 *6 (-706 (-237))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-414)) (|:| |fp| (-76 PEDERV)))) (-5 *10 (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-381 *3)) (-4 *3 (-373))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168))))) 
+(((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-523 *3)) (-4 *3 (-1225)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-754 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-1161 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-4 *1 (-175 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -3215 (-790)) (|:| -2838 *4) (|:| |num| *4)))) (-4 *4 (-1255 *3)) (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *4)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-141)) (-5 *1 (-463)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *3 (-658 (-1191))) (-5 *4 (-141)) (-5 *1 (-463)))) ((*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-622 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-649 *2)) (-4 *2 (-194)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-688 *3)) (-4 *3 (-869)) (-5 *1 (-681 *3 *4)) (-4 *4 (-194)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-688 *3)) (-4 *3 (-869)) (-5 *1 (-681 *3 *4)) (-4 *4 (-194)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-688 *3)) (-4 *3 (-869)) (-5 *1 (-681 *3 *4)) (-4 *4 (-194)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-658 *3)))) (-4 *3 (-1119)) (-5 *1 (-691 *3)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-730 *2 *3 *4)) (-4 *2 (-869)) (-4 *3 (-1119)) (-14 *4 (-1 (-141) (-2 (|:| -1825 *2) (|:| -3215 *3)) (-2 (|:| -1825 *2) (|:| -3215 *3)))))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 *4)))) (-4 *4 (-1119)) (-5 *1 (-911 *3 *4)) (-4 *3 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 *5)) (-4 *5 (-13 (-1119) (-39))) (-5 *2 (-658 (-1154 *3 *5))) (-5 *1 (-1154 *3 *5)) (-4 *3 (-13 (-1119) (-39))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| |val| *4) (|:| -2165 *5)))) (-4 *4 (-13 (-1119) (-39))) (-4 *5 (-13 (-1119) (-39))) (-5 *2 (-658 (-1154 *4 *5))) (-5 *1 (-1154 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |val| *3) (|:| -2165 *4))) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1154 *3 *4)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-141)) (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) ((*1 *1 *2 *3 *2 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-13 (-1119) (-39))) (-5 *1 (-1155 *2 *3)) (-4 *2 (-13 (-1119) (-39))))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-658 (-1154 *2 *3))) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))) (-5 *1 (-1155 *2 *3)))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-658 (-1155 *2 *3))) (-5 *1 (-1155 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) ((*1 *1 *2) (-12 (-5 *2 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1155 *3 *4)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-1180 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3 *3 *4 *5 *5 *5 *4 *4 *4 *3 *4 *4 *6) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-896)) (-5 *3 (-658 (-278))) (-5 *1 (-276))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-658 (-1171 *7))) (-4 *6 (-869)) (-4 *7 (-977 *5 (-558 *6) *6)) (-4 *5 (-1075)) (-5 *2 (-1 (-1171 *7) *7)) (-5 *1 (-1143 *5 *6 *7))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1040)) (-5 *2 (-877))))) 
+(((*1 *1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *3)) (-4 *3 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *1 (-690 *3)) (-4 *3 (-1225)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-141) *4)) (-5 *3 (-592)) (-4 *4 (-1119)) (-5 *1 (-754 *4)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-754 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1155 *3 *4))))) 
+(((*1 *2 *3 *3 *4 *3 *4 *4 *4 *5 *5 *5 *5 *4 *4 *6 *7) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-89 FCNF)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-90 FCNG)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-433 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-582)) (-4 *4 (-1075)) (-4 *2 (-1270 *4)) (-5 *1 (-1273 *4 *5 *6 *2)) (-4 *6 (-670 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-793)) (-5 *1 (-57))))) 
+(((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-592)) (-5 *5 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *6 (-1075)) (-4 *7 (-252 *8 (-790))) (-14 *8 (-790)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-799 *6 *3 *7 *8)) (-4 *3 (-346 *6 *7))))) 
+(((*1 *2 *2) (-12 (-4 *2 (-194)) (-4 *2 (-1075)) (-5 *1 (-731 *2 *3)) (-4 *3 (-661 *2)))) ((*1 *2 *2) (-12 (-5 *1 (-856 *2)) (-4 *2 (-194)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL)))) (-5 *2 (-1063)) (-5 *1 (-768)))) ((*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7 *8 *8) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-92 BDYVAL)))) (-5 *8 (-414)) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1173)) (-5 *3 (-793)) (-5 *1 (-143))))) 
+(((*1 *2 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-342 *2 *4)) (-4 *4 (-158)) (-4 *2 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-386 *2)) (-4 *2 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-412 *2)) (-4 *2 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *2 (-1119)) (-5 *1 (-662 *2 *4 *5)) (-4 *4 (-23)) (-14 *5 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-841 *2)) (-4 *2 (-869))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-80 FCN JACOBF JACEPS)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-81 G JACOBG JACGEP)))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-163)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-168))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-205)) (-5 *3 (-592)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-805 *2)) (-4 *2 (-194)))) ((*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1187 *1)) (-4 *1 (-885)) (-5 *2 (-658 *1)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-388)) (-5 *2 (-2 (|:| |zeros| (-658 *4)) (|:| -2378 (-592)))) (-5 *1 (-1071 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-844))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1000))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1089 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *6 *3)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1171 *4)) (-4 *4 (-43 *3)) (-4 *4 (-1075)) (-5 *3 (-433 (-592))) (-5 *1 (-1175 *4))))) 
+(((*1 *2) (-12 (-4 *1 (-373)) (-5 *2 (-3 "prime" "polynomial" "normal" "cyclic"))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-489)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-954))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-219))))) 
+(((*1 *2 *3 *3 *4 *3 *4 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *3 *4) (-12 (-4 *2 (-1255 *4)) (-5 *1 (-829 *4 *2 *3 *5)) (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-670 *2)) (-4 *5 (-670 (-433 *2))))) ((*1 *2 *3 *4) (-12 (-4 *2 (-1255 *4)) (-5 *1 (-829 *4 *2 *5 *3)) (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-670 *2)) (-4 *3 (-670 (-433 *2)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1221 *3)) (-4 *3 (-1003))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-444 *4)) (-4 *4 (-582))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-256)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-1285)) (-5 *1 (-256))))) 
+(((*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1233))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-141)) (-5 *1 (-315 *4 *5)) (-14 *4 *3) (-14 *5 *3))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1113 (-862 (-237)))) (-5 *3 (-237)) (-5 *2 (-141)) (-5 *1 (-321)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |k| (-1191)) (|:| |c| (-1300 *3))))) (-5 *1 (-1300 *3)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |k| *3) (|:| |c| (-1302 *3 *4))))) (-5 *1 (-1302 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-879 *5))) (-14 *5 (-658 (-1191))) (-4 *6 (-477)) (-5 *2 (-658 (-658 (-264 *5 *6)))) (-5 *1 (-500 *5 *6 *7)) (-5 *3 (-658 (-264 *5 *6))) (-4 *7 (-477))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582))))) 
+(((*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-790)) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) ((*1 *2) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-790))))) 
+(((*1 *2 *3 *4 *4 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-790)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-815)) (-4 *4 (-977 *5 *6 *7)) (-4 *5 (-477)) (-4 *7 (-869)) (-5 *1 (-474 *5 *6 *7 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-444 *5)) (-4 *5 (-582)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *5) (|:| |radicand| (-658 *5)))) (-5 *1 (-338 *5)) (-5 *4 (-790)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1030)) (-5 *2 (-592))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-1131)) (-4 *3 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-456 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-977 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-658 *3)) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $)))))))) 
+(((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-937 *2)) (-4 *2 (-323))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-386 (-143))) (-4 *2 (-1075)) (-5 *1 (-731 *2 *4)) (-4 *4 (-661 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-386 (-143))) (-5 *1 (-856 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-846))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-150))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-846)) (-5 *1 (-847))))) 
+(((*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1095 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-2 (|:| |val| (-658 *8)) (|:| -2165 *9)))) (-5 *5 (-141)) (-4 *8 (-1089 *6 *7 *4)) (-4 *9 (-1094 *6 *7 *4 *8)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *4 (-869)) (-5 *2 (-658 (-2 (|:| |val| *8) (|:| -2165 *9)))) (-5 *1 (-1095 *6 *7 *4 *8 *9))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1 (-141) *7 (-658 *7))) (-4 *1 (-1219 *4 *5 *6 *7)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-877))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-429 *3)) (-4 *3 (-430)))) ((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-429 *3)) (-4 *3 (-430)))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (|has| *1 (-6 -4616)) (-4 *1 (-430)))) ((*1 *2) (-12 (-4 *1 (-430)) (-5 *2 (-944)))) ((*1 *2 *1) (-12 (-4 *1 (-890 *3)) (-5 *2 (-1171 (-592)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592)))) ((*1 *2 *1) (-12 (-5 *2 (-1280 (-3 (-497) "undefined"))) (-5 *1 (-1281))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| *7) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 *7))))) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-790)) (-5 *1 (-951 *4 *5 *6 *7))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-141))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-33 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))))) ((*1 *1 *1) (-5 *1 (-405))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-795 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1137)) (-5 *2 (-141)) (-5 *1 (-843))))) 
+(((*1 *2 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-191 (-237))) (-5 *2 (-237)) (-5 *1 (-135))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *2 (-3 (-658 *7) "failed" "Infinite" (-592))) (-5 *1 (-31 *4 *5 *3 *6 *7)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *7 (-999 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *2 (-3 (-658 *7) "failed" "Infinite" (-592))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *7 (-999 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 (-1187 *4))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *8 (-999 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-389 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-658 (-2 (|:| |func| *2) (|:| |pole| (-141))))) (-4 *2 (-13 (-456 *4) (-1030))) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-294 *4 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1171 *3)) (-4 *3 (-1119)) (-4 *3 (-1225))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-446 *3 *2 *4 *5)) (-4 *2 (-13 (-27) (-1211) (-456 *3))) (-14 *4 (-1191)) (-14 *5 *2))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-4 *2 (-13 (-27) (-1211) (-456 *3) (-10 -8 (-15 -1683 ($ *4))))) (-4 *4 (-867)) (-4 *5 (-13 (-1257 *2 *4) (-388) (-1211) (-10 -8 (-15 -3644 ($ $)) (-15 -3162 ($ $))))) (-5 *1 (-448 *3 *2 *4 *5 *6 *7)) (-4 *6 (-1012 *5)) (-14 *7 (-1191))))) 
+(((*1 *2 *3 *4 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) (-790))) (-4 *9 (-999 *5)) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-4 *3 (-257 *11)) (-4 *12 (-560 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-137)) (-5 *2 (-2 (|:| -2016 (-592)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (-592)))) (-5 *1 (-491 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-5 *4 (-592)) (-4 *13 (-280 *12)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-258 (-949 *5))) (-4 *5 (-373)) (-5 *2 (-2 (|:| -2016 (-592)) (|:| |num| (-264 *6 *5)) (|:| |den| (-264 *6 *5)) (|:| |upTo| (-592)))) (-5 *1 (-894 *5 *6 *7)) (-5 *4 (-592)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-258 (-948 *5))) (-4 *5 (-388)) (-5 *2 (-2 (|:| -2016 (-592)) (|:| |num| (-264 *6 *5)) (|:| |den| (-264 *6 *5)) (|:| |upTo| (-592)))) (-5 *1 (-895 *5 *6 *7)) (-5 *4 (-592)) (-14 *6 (-658 (-1191))) (-4 *7 (-137))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-318)) (-5 *2 (-658 (-143)))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-528))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-179)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-1040)) (-5 *2 (-877))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *1 *2 *2 *2 *2) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *2 (-947 *5 *8)) (-5 *1 (-679 *5 *6 *4 *7 *3 *8 *2)) (-4 *4 (-977 *5 *7 (-879 *6))) (-4 *3 (-999 *5)) (-4 *8 (-665 *5))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-1221 *2)) (-4 *2 (-1003))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-804 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-143)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-456 *6) (-23) (-1065 (-592)) (-1065 *4) (-922 *4) (-182))) (-5 *4 (-1191)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *1 (-1052 *6 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1187 (-592))) (-5 *2 (-592)) (-5 *1 (-970))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-264 *3 *4)) (-14 *3 (-658 (-1191))) (-4 *4 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-14 *3 (-658 (-1191))) (-5 *1 (-479 *3 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-252 (-1699 *3) (-790))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-516 *3 *4)) (-14 *3 (-658 (-1191))) (-4 *4 (-1075))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1187 *5)) (-4 *5 (-388)) (-5 *2 (-658 *6)) (-5 *1 (-559 *5 *6 *4)) (-4 *6 (-388)) (-4 *4 (-13 (-388) (-867)))))) 
+(((*1 *2) (-12 (-5 *2 (-862 (-592))) (-5 *1 (-563)))) ((*1 *1) (-12 (-5 *1 (-862 *2)) (-4 *2 (-1119))))) 
+(((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-706 (-433 *4)))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1171 *3)) (-4 *3 (-1119)) (-4 *3 (-1225))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-804 *2)) (-4 *2 (-1075)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| -1487 *4) (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1089 *3 *4 *5)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -1487 *3) (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1255 *3))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-405))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-433 (-980 (-405)))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-332 (-405))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-592))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-433 (-980 (-592)))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-332 (-592))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 *2)) (-14 *4 (-658 *2)) (-4 *5 (-413)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-332 *5)) (-4 *5 (-413)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-433 (-980 (-592))))) (-4 *1 (-410)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-433 (-980 (-405))))) (-4 *1 (-410)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-980 (-592)))) (-4 *1 (-410)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-980 (-405)))) (-4 *1 (-410)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-332 (-592)))) (-4 *1 (-410)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-706 (-332 (-405)))) (-4 *1 (-410)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-433 (-980 (-592)))) (-4 *1 (-422)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-433 (-980 (-405)))) (-4 *1 (-422)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-592))) (-4 *1 (-422)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-405))) (-4 *1 (-422)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-332 (-592))) (-4 *1 (-422)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-332 (-405))) (-4 *1 (-422)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-433 (-980 (-592))))) (-4 *1 (-466)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-433 (-980 (-405))))) (-4 *1 (-466)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-980 (-592)))) (-4 *1 (-466)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-980 (-405)))) (-4 *1 (-466)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-332 (-592)))) (-4 *1 (-466)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1280 (-332 (-405)))) (-4 *1 (-466)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-373)) (-4 *5 (-349 *4)) (-4 *6 (-1255 *5)) (-5 *2 (-1187 (-1187 *4))) (-5 *1 (-796 *4 *5 *6 *3 *7)) (-4 *3 (-1255 *6)) (-14 *7 (-944)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *1 (-1005 *3 *4 *5 *6)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1065 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (|partial| -3836 (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-3252 (-4 *3 (-43 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-574))) (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-1021 (-592)))) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))))) ((*1 *1 *2) (|partial| -3836 (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-980 (-433 (-592)))) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-718 *3 *5 *6 *7)) (-4 *3 (-633 (-565))) (-4 *5 (-1225)) (-4 *6 (-1225)) (-4 *7 (-1225)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-1 *6 *5)) (-5 *1 (-723 *3 *5 *6)) (-4 *3 (-633 (-565))) (-4 *5 (-1225)) (-4 *6 (-1225))))) 
+(((*1 *2) (-12 (-5 *2 (-862 (-592))) (-5 *1 (-563)))) ((*1 *1) (-12 (-5 *1 (-862 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-790)) (-4 *5 (-388)) (-5 *2 (-433 *6)) (-5 *1 (-888 *5 *4 *6)) (-4 *4 (-1270 *5)) (-4 *6 (-1255 *5)))) ((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-790)) (-5 *4 (-1271 *5 *6 *7)) (-4 *5 (-388)) (-14 *6 (-1191)) (-14 *7 *5) (-5 *2 (-433 (-1252 *6 *5))) (-5 *1 (-889 *5 *6 *7)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-790)) (-5 *4 (-1271 *5 *6 *7)) (-4 *5 (-388)) (-14 *6 (-1191)) (-14 *7 *5) (-5 *2 (-433 (-1252 *6 *5))) (-5 *1 (-889 *5 *6 *7))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-944))) (-5 *1 (-1120 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1278 *3)) (-4 *3 (-1225)) (-4 *3 (-1075)) (-5 *2 (-706 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4)))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-1137)) (-4 *4 (-373)) (-5 *1 (-556 *4))))) 
+(((*1 *1) (-5 *1 (-163)))) 
+(((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-1 *3 *3)) (-4 *3 (-1255 *6)) (-4 *6 (-13 (-388) (-171) (-1065 *4))) (-5 *4 (-592)) (-5 *2 (-3 (|:| |ans| (-2 (|:| |ans| *3) (|:| |nosol| (-141)))) (|:| -2042 (-2 (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (-5 *1 (-1043 *6 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-914 *4)) (-5 *3 (-1 (-141) *5)) (-4 *4 (-1119)) (-4 *5 (-1225)) (-5 *1 (-912 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-914 *4)) (-5 *3 (-658 (-1 (-141) *5))) (-4 *4 (-1119)) (-4 *5 (-1225)) (-5 *1 (-912 *4 *5)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-914 *5)) (-5 *3 (-658 (-1191))) (-5 *4 (-1 (-141) (-658 *6))) (-4 *5 (-1119)) (-4 *6 (-1225)) (-5 *1 (-912 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-141) *5)) (-4 *5 (-1225)) (-4 *4 (-869)) (-5 *1 (-965 *4 *2 *5)) (-4 *2 (-456 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-1 (-141) *5))) (-4 *5 (-1225)) (-4 *4 (-869)) (-5 *1 (-965 *4 *2 *5)) (-4 *2 (-456 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-1 (-141) *5)) (-4 *5 (-1225)) (-5 *2 (-332 (-592))) (-5 *1 (-966 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-658 (-1 (-141) *5))) (-4 *5 (-1225)) (-5 *2 (-332 (-592))) (-5 *1 (-966 *5)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-1 (-141) (-658 *6))) (-4 *6 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-1097 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-565))))) 
+(((*1 *2 *3 *4 *5 *5 *5 *6 *4 *4 *4 *5 *4 *5 *7) (-12 (-5 *3 (-1173)) (-5 *5 (-706 (-237))) (-5 *6 (-237)) (-5 *7 (-706 (-592))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 *4) (-790)))) (-658 (-489)))) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 (-1191))) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) (-1191) *6)) (|:| C (-1 (-658 *5) (-790)))) (-658 (-489)))) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-14 *9 (-1 *6 *4)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-1 HPSPEC (-658 (-489)))) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 (-1191))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-57))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-706 *11)) (-5 *4 (-658 (-433 (-980 *8)))) (-5 *5 (-790)) (-5 *6 (-1173)) (-4 *8 (-13 (-323) (-171))) (-4 *11 (-977 *8 *10 *9)) (-4 *9 (-13 (-869) (-633 (-1191)))) (-4 *10 (-815)) (-5 *2 (-2 (|:| |rgl| (-658 (-2 (|:| |eqzro| (-658 *11)) (|:| |neqzro| (-658 *11)) (|:| |wcond| (-658 (-980 *8))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *8)))) (|:| -2195 (-658 (-1280 (-433 (-980 *8)))))))))) (|:| |rgsz| (-592)))) (-5 *1 (-951 *8 *9 *10 *11)) (-5 *7 (-592))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *5 *3 *3 *3 *6 *4 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *6 (-237)) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-790)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-268 *4 *3 *5 *6)) (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-284 *3)) (-4 *3 (-869)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-373)) (-5 *2 (-944)))) ((*1 *2 *3) (-12 (-5 *3 (-356 *4 *5 *6 *7)) (-4 *4 (-13 (-394) (-388))) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-4 *7 (-362 *4 *5 *6)) (-5 *2 (-790)) (-5 *1 (-418 *4 *5 *6 *7)))) ((*1 *2 *1) (-12 (-4 *1 (-428)) (-5 *2 (-855 (-944))))) ((*1 *2 *1) (-12 (-4 *1 (-430)) (-5 *2 (-592)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-4 *3 (-582)) (-5 *2 (-592)) (-5 *1 (-639 *3 *4)) (-4 *4 (-1255 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-592)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-790)) (-4 *1 (-757 *4 *3)) (-4 *4 (-1075)) (-4 *3 (-869)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-757 *4 *3)) (-4 *4 (-1075)) (-4 *3 (-869)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-890 *3)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-356 *5 *6 *7 *8)) (-4 *5 (-456 *4)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *8 (-362 *5 *6 *7)) (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-790)) (-5 *1 (-933 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-356 (-433 (-592)) *4 *5 *6)) (-4 *4 (-1255 (-433 (-592)))) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 (-433 (-592)) *4 *5)) (-5 *2 (-790)) (-5 *1 (-934 *4 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-356 *6 *7 *4 *8)) (-5 *5 (-1 *9 *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-4 *4 (-1255 (-433 *7))) (-4 *8 (-362 *6 *7 *4)) (-4 *9 (-13 (-394) (-388))) (-5 *2 (-790)) (-5 *1 (-1046 *6 *7 *4 *8 *9)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1255 *3)) (-4 *3 (-1075)) (-4 *3 (-582)) (-5 *2 (-790)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) ((*1 *2 *1) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-790)) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-96 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-234 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-518 *4)) (-4 *4 (-869)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1028 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1161 *4)) (-4 *4 (-1119)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-141)) (-5 *1 (-1232 *3)) (-4 *3 (-869)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1482 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-790)))) (-5 *1 (-926 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-389 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-1285))))) 
+(((*1 *2 *3 *4 *5 *4 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *7 *4) (-12 (-5 *3 (-1173)) (-5 *5 (-706 (-237))) (-5 *6 (-237)) (-5 *7 (-706 (-592))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-844))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-944)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-278))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-658 (-980 *3))) (-4 *3 (-477)) (-5 *1 (-385 *3 *4)) (-14 *4 (-658 (-1191))))) ((*1 *2 *2) (|partial| -12 (-5 *2 (-658 (-802 *3 (-879 *4)))) (-4 *3 (-477)) (-14 *4 (-658 (-1191))) (-5 *1 (-643 *3 *4))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *2 (-592)) (-5 *1 (-597 *3)) (-4 *3 (-1065 *2))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-790)) (|:| |poli| *3) (|:| |polj| *3)))) (-4 *5 (-815)) (-4 *3 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *6 (-869)) (-5 *1 (-474 *4 *5 *6 *3))))) 
+(((*1 *2 *3 *4 *5 *5 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-219)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-405))) (-5 *2 (-405)) (-5 *1 (-219))))) 
+(((*1 *1 *1) (-5 *1 (-1087)))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-388)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1264 *3 *4 *5)) (-4 *3 (-13 (-388) (-869))) (-14 *4 (-1191)) (-14 *5 *3) (-5 *1 (-336 *3 *4 *5)))) ((*1 *2 *3) (-12 (-5 *2 (-1 (-405))) (-5 *1 (-1067)) (-5 *3 (-405))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-160))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119))))) 
+(((*1 *2) (-12 (-5 *2 (-2 (|:| -2781 (-658 *3)) (|:| -2369 (-658 *3)))) (-5 *1 (-1232 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) ((*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-264 *6 *5)) (-5 *4 (-995 *5)) (-4 *5 (-373)) (-14 *6 (-658 (-1191))) (-5 *2 (-264 *6 (-884 *5))) (-5 *1 (-894 *5 *6 *7)) (-4 *7 (-137)))) ((*1 *2 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-388)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-5 *1 (-956 *5 *2 *6 *7 *3)) (-4 *2 (-346 *5 *6)) (-4 *3 (-999 *5)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-388)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-956 *4 *2 *5 *6 *3)) (-4 *2 (-346 *4 *5)) (-4 *3 (-999 *4))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-980 (-592))) (-5 *5 (-658 (-1191))) (-4 *1 (-692 *2 *6)) (-4 *6 (-1225)) (-5 *4 (-1191)) (-4 *2 (-1225))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1143 *4 *3 *5))) (-4 *4 (-43 (-433 (-592)))) (-4 *4 (-1075)) (-4 *3 (-869)) (-5 *1 (-1143 *4 *3 *5)) (-4 *5 (-977 *4 (-558 *3) *3)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1220 *4))) (-5 *3 (-1191)) (-5 *1 (-1220 *4)) (-4 *4 (-43 (-433 (-592)))) (-4 *4 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-150))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *2 *3) (-12 (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *2 (-2 (|:| |glbase| (-658 (-264 *4 *5))) (|:| |glval| (-658 (-592))))) (-5 *1 (-646 *4 *5)) (-5 *3 (-658 (-264 *4 *5)))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283))))) 
+(((*1 *2) (-12 (-4 *3 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *2 (-658 *4)) (-5 *1 (-935 *3 *4 *5 *6)) (-4 *4 (-346 *3 *5))))) 
+(((*1 *2 *3 *3 *4 *4 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-141)) (-5 *1 (-851))))) 
+(((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-234 *3)))) ((*1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-4 *1 (-269 *3)))) ((*1 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-388)) (-5 *1 (-302 *3 *2)) (-4 *2 (-1270 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *6 *7 *8 *3 *4)) (-4 *4 (-1128 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *5 *6 *7 *3 *4)) (-4 *4 (-1128 *5 *6 *7 *3))))) 
+(((*1 *1) (-5 *1 (-845)))) 
+(((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-665 *3)) (-4 *3 (-388))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-896)) (-5 *3 (-658 (-278))) (-5 *1 (-276))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)))) ((*1 *1 *1) (-4 *1 (-644))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-790))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-143)) (-4 *4 (-1075)) (-5 *1 (-731 *4 *2)) (-4 *2 (-661 *4)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-143)) (-5 *1 (-856 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5 *5)) (-4 *5 (-1270 *4)) (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-1 (-1171 *4) (-1171 *4) (-1171 *4))) (-5 *1 (-1272 *4 *5))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 *1)) (|has| *1 (-6 -4626)) (-4 *1 (-1038 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| |deg| (-790)) (|:| -1975 *5)))) (-4 *5 (-1255 *4)) (-4 *4 (-373)) (-5 *2 (-658 *5)) (-5 *1 (-229 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| -4500 *5) (|:| -4525 (-592))))) (-5 *4 (-592)) (-4 *5 (-1255 *4)) (-5 *2 (-658 *5)) (-5 *1 (-712 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-790))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373)))) ((*1 *1) (-4 *1 (-394))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 *4)) (-5 *1 (-556 *4)) (-4 *4 (-373)))) ((*1 *1 *1) (-4 *1 (-574))) ((*1 *1) (-4 *1 (-574))) ((*1 *1 *1) (-5 *1 (-592))) ((*1 *1 *1) (-5 *1 (-790))) ((*1 *2 *1) (-12 (-5 *2 (-927 *3)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-927 *4)) (-5 *1 (-926 *4)) (-4 *4 (-1119)))) ((*1 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-574)) (-4 *2 (-582))))) 
+(((*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1087))))) 
+(((*1 *1 *2 *3) (-12 (-5 *1 (-993 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-1171 *3))) (-5 *2 (-1171 *3)) (-5 *1 (-1175 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1285)) (-5 *1 (-474 *4 *5 *6 *7)) (-4 *7 (-977 *4 *5 *6))))) 
+(((*1 *2 *3 *4 *4 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-658 (-2 (|:| |deg| (-790)) (|:| -1975 *3)))) (-5 *1 (-229 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-392 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-631 *4)) (-4 *4 (-869)) (-4 *2 (-869)) (-5 *1 (-630 *2 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-592))))) 
+(((*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-877))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) ((*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-597 *3)) (-4 *3 (-1065 (-592))))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1154 *4 *5)) (-4 *4 (-13 (-1119) (-39))) (-4 *5 (-13 (-1119) (-39))) (-5 *2 (-141)) (-5 *1 (-1155 *4 *5))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-477)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1113 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *9)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-790)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *9)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-790)) (-5 *1 (-1159 *5 *6 *7 *8 *9))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-592))) (-5 *4 (-927 (-592))) (-5 *2 (-706 (-592))) (-5 *1 (-613)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-658 (-706 (-592)))) (-5 *1 (-613)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-592))) (-5 *4 (-658 (-927 (-592)))) (-5 *2 (-658 (-706 (-592)))) (-5 *1 (-613))))) 
+(((*1 *2 *3 *4) (-12 (-4 *4 (-388)) (-5 *2 (-658 (-1171 *4))) (-5 *1 (-302 *4 *5)) (-5 *3 (-1171 *4)) (-4 *5 (-1270 *4))))) 
+(((*1 *2 *3 *4 *4 *4 *3 *3 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 (-706 *4))) (-4 *4 (-194)) (-5 *2 (-1280 (-706 (-980 *4)))) (-5 *1 (-203 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-971 *5)) (-4 *5 (-1075)) (-5 *2 (-790)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-790)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)) (-4 *5 (-1075)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-971 *5)) (-4 *5 (-1075)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1291 *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-658 *8)) (-5 *3 (-1 (-141) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1291 *5 *6 *7 *8))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 (-790))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1121 (-1191))) (-5 *1 (-58)) (-5 *3 (-1191))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-565))) (-5 *1 (-565))))) 
+(((*1 *1) (-12 (-4 *1 (-494 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) ((*1 *1) (-5 *1 (-565))) ((*1 *1) (-4 *1 (-739))) ((*1 *1) (-4 *1 (-743))) ((*1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) ((*1 *1) (-12 (-5 *1 (-915 *2)) (-4 *2 (-869))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-58))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) ((*1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-983)) (-5 *2 (-1113 (-237))))) ((*1 *2 *1) (-12 (-4 *1 (-1003)) (-5 *2 (-1113 (-237)))))) 
+(((*1 *2 *3 *4 *3 *5) (-12 (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *9 (-665 *6)) (-5 *2 (-2 (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (-658 (-592))))) (-5 *1 (-679 *6 *7 *3 *8 *4 *9 *10)) (-5 *5 (-592)) (-4 *3 (-977 *6 *8 (-879 *7))) (-4 *4 (-999 *6)) (-4 *10 (-947 *6 *9))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-582)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-1216 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-2 (|:| -1644 (-592)) (|:| -2033 (-658 *3)))) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-954)) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-954)) (-5 *4 (-433 (-592))) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5)) (-4 *5 (-1119)) (-5 *2 (-1 *5 *4)) (-5 *1 (-699 *4 *5)) (-4 *4 (-1119)))) ((*1 *2 *3) (-12 (-4 *4 (-252 *5 (-790))) (-14 *5 (-790)) (-4 *2 (-1075)) (-5 *1 (-935 *2 *3 *4 *5)) (-4 *3 (-346 *2 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-869)) (-5 *1 (-957 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-332 (-592))) (-5 *1 (-958)))) ((*1 *2 *1) (-12 (-4 *1 (-1295 *3 *2)) (-4 *3 (-869)) (-4 *2 (-1075)))) ((*1 *2 *1) (-12 (-4 *2 (-1075)) (-5 *1 (-1301 *2 *3)) (-4 *3 (-865))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-388)) (-5 *1 (-677 *3))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-587))))) 
+(((*1 *1 *1 *2 *1) (-12 (-4 *1 (-155 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-79 FCN)))) (-5 *2 (-1063)) (-5 *1 (-765))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *3 (-869)) (-4 *3 (-1065 (-592))) (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-456 *3)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $)))))))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-790)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-815)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-477)) (-4 *5 (-869)) (-5 *1 (-474 *3 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877))))) (-5 *1 (-1191))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-141)) (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-444 *3)) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4)))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-954))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-592))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) ((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4)))) ((*1 *1 *1) (-4 *1 (-574))) ((*1 *2 *1) (-12 (-5 *2 (-944)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-944)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-841 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-915 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-4 *1 (-1023 *3)) (-4 *3 (-1225)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1223 *3)) (-4 *3 (-1225)))) ((*1 *2 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-1030)) (-4 *2 (-1075))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *3) (-12 (-4 *3 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *3)) (-5 *1 (-1145 *4 *3)) (-4 *4 (-1255 *3))))) 
+(((*1 *1 *2 *3 *1 *3) (-12 (-5 *2 (-914 *4)) (-4 *4 (-1119)) (-5 *1 (-911 *4 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-141)) (-5 *2 (-1063)) (-5 *1 (-764))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1106 *2)) (-4 *2 (-13 (-869) (-582)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-430)) (-4 *3 (-1075)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-430)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-1191)) (-4 *6 (-456 *5)) (-4 *5 (-869)) (-5 *2 (-658 (-631 *6))) (-5 *1 (-601 *5 *6))))) 
+(((*1 *2) (-12 (-4 *1 (-430)) (-5 *2 (-944)))) ((*1 *1) (-4 *1 (-574))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-715)))) ((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-715)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-926 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *5 (-141)) (-5 *2 (-1063)) (-5 *1 (-764))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405)))) (-5 *1 (-219))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-944) (-141))) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-944) (-141))) (-5 *1 (-489))))) 
+(((*1 *1) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1225)) (-5 *2 (-790))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1179 3 (-237))) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-328))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-373)) (-5 *3 (-592)) (-5 *2 (-1199 (-944) (-790)))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-1051 *3)) (-4 *3 (-13 (-867) (-388) (-1049))))) ((*1 *2 *3 *1 *2) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2)))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1091 *2 *3)) (-4 *2 (-13 (-867) (-388))) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *2 (-658 (-1187 *7))) (-5 *3 (-1187 *7)) (-4 *7 (-977 *5 *6 *4)) (-4 *5 (-931)) (-4 *6 (-815)) (-4 *4 (-869)) (-5 *1 (-928 *5 *6 *4 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *2 (-658 *8)) (-5 *1 (-991 *4 *5 *6 *7 *8)) (-4 *8 (-999 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 (-433 (-592)))) (-5 *2 (-658 *4)) (-5 *1 (-800 *4)) (-4 *4 (-13 (-388) (-867)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-587)))) ((*1 *2 *1) (-12 (-4 *1 (-625 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1225)) (-5 *2 (-658 *4))))) 
+(((*1 *1 *1 *2 *3 *1) (-12 (-4 *1 (-346 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-346 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) ((*1 *2 *1) (-12 (-4 *1 (-725 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-871 *3)) (-4 *3 (-1075)) (-5 *2 (-790)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 (-790))))) ((*1 *2 *1 *3) (-12 (-4 *1 (-977 *4 *5 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-790))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1187 *5)) (-4 *5 (-477)) (-5 *2 (-658 *6)) (-5 *1 (-567 *5 *6 *4)) (-4 *6 (-388)) (-4 *4 (-13 (-388) (-867))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-980 *5)) (-4 *5 (-477)) (-5 *2 (-658 *6)) (-5 *1 (-567 *5 *6 *4)) (-4 *6 (-388)) (-4 *4 (-13 (-388) (-867)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 *4)) (-5 *1 (-1155 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-1171 *2)) (-4 *2 (-323)) (-5 *1 (-195 *2))))) 
+(((*1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-388))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-58))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-706 *2)) (-4 *2 (-194)) (-5 *1 (-170 *2)))) ((*1 *2 *3) (-12 (-4 *4 (-194)) (-4 *2 (-1255 *4)) (-5 *1 (-197 *4 *2 *3)) (-4 *3 (-741 *4 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 (-433 (-980 *5)))) (-5 *4 (-1191)) (-5 *2 (-980 *5)) (-5 *1 (-308 *5)) (-4 *5 (-477)))) ((*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 *4)))) (-5 *2 (-980 *4)) (-5 *1 (-308 *4)) (-4 *4 (-477)))) ((*1 *2 *1) (-12 (-4 *1 (-396 *3 *2)) (-4 *3 (-194)) (-4 *2 (-1255 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-706 (-191 (-433 (-592))))) (-5 *2 (-980 (-191 (-433 (-592))))) (-5 *1 (-783 *4)) (-4 *4 (-13 (-388) (-867))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 (-191 (-433 (-592))))) (-5 *4 (-1191)) (-5 *2 (-980 (-191 (-433 (-592))))) (-5 *1 (-783 *5)) (-4 *5 (-13 (-388) (-867))))) ((*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-592)))) (-5 *2 (-980 (-433 (-592)))) (-5 *1 (-800 *4)) (-4 *4 (-13 (-388) (-867))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 (-433 (-592)))) (-5 *4 (-1191)) (-5 *2 (-980 (-433 (-592)))) (-5 *1 (-800 *5)) (-4 *5 (-13 (-388) (-867)))))) 
+(((*1 *1 *1) (-5 *1 (-237))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *1 *1) (-5 *1 (-405))) ((*1 *1) (-5 *1 (-405)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *2 (-1280 (-332 (-405)))) (-5 *1 (-321))))) 
+(((*1 *1 *1 *2) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-405)) (-5 *2 (-237)) (-5 *1 (-321))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 *3)) (|:| |logand| (-1187 *3))))) (-5 *1 (-609 *3)) (-4 *3 (-388))))) 
+(((*1 *1) (-5 *1 (-1285)))) 
+(((*1 *2) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-1 *4 (-592) (-592))) (-4 *4 (-1075)) (-4 *1 (-704 *4 *5 *6)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-877)))) (-5 *1 (-877)))) ((*1 *2 *1) (-12 (-5 *2 (-1156 *3 *4)) (-5 *1 (-1022 *3 *4)) (-14 *3 (-944)) (-4 *4 (-388)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-658 *5))) (-4 *5 (-1075)) (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5))))) 
+(((*1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *1 *1) (-12 (-5 *1 (-937 *2)) (-4 *2 (-323))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-843)) (-5 *2 (-57)) (-5 *1 (-853))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-188 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-433 (-592))) (-5 *1 (-444 *3)) (-4 *3 (-574)) (-4 *3 (-582)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-574)) (-5 *2 (-433 (-592))))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-819 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-433 (-592))) (-5 *1 (-855 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-433 (-592))) (-5 *1 (-862 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1025 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) ((*1 *2 *3) (|partial| -12 (-5 *2 (-433 (-592))) (-5 *1 (-1036 *3)) (-4 *3 (-1065 *2))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-917)) (-5 *3 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *2 (-1063))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *1 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) ((*1 *1 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1237 *3)) (-4 *3 (-1075)) (-5 *1 (-1236 *3))))) 
+(((*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-477)) (-4 *3 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-474 *4 *3 *5 *6)) (-4 *6 (-977 *4 *3 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 *2) (-4 *5 (-194)))) ((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-944)) (-5 *1 (-187 *3 *4)) (-4 *3 (-188 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-944)))) ((*1 *2) (-12 (-4 *1 (-396 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-944)))) ((*1 *2 *3) (-12 (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-790)) (-5 *1 (-553 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 *5)) (-5 *4 (-1280 *5)) (-4 *5 (-388)) (-5 *2 (-790)) (-5 *1 (-684 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-5 *2 (-790)) (-5 *1 (-685 *5 *6 *4 *3)) (-4 *3 (-704 *5 *6 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-582)) (-5 *2 (-790)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-790)) (-5 *1 (-705 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-4 *5 (-582)) (-5 *2 (-790))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1280 *1)) (-5 *4 (-1 *5 *5)) (-4 *5 (-388)) (-4 *1 (-741 *5 *6)) (-4 *5 (-194)) (-4 *6 (-1255 *5)) (-5 *2 (-706 *5))))) 
+(((*1 *2 *3 *2 *2) (-12 (-5 *2 (-658 (-516 *4 *5))) (-5 *3 (-879 *4)) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *1 (-646 *4 *5))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-869)) (-4 *4 (-388)) (-4 *5 (-815)) (-5 *2 (-2 (|:| |mval| (-706 *4)) (|:| |invmval| (-706 *4)) (|:| |genIdeal| (-538 *4 *5 *6 *7)))) (-5 *1 (-538 *4 *5 *6 *7)) (-4 *7 (-977 *4 *5 *6))))) 
+(((*1 *1 *1 *1) (-5 *1 (-141)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-667 (-433 *6))) (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-433 *6))) (-5 *1 (-834 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-667 (-433 *7))) (-5 *4 (-1 (-658 *6) *7)) (-5 *5 (-1 (-444 *7) *7)) (-4 *6 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *7 (-1255 *6)) (-5 *2 (-658 (-433 *7))) (-5 *1 (-834 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-668 *6 (-433 *6))) (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-433 *6))) (-5 *1 (-834 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-668 *7 (-433 *7))) (-5 *4 (-1 (-658 *6) *7)) (-5 *5 (-1 (-444 *7) *7)) (-4 *6 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *7 (-1255 *6)) (-5 *2 (-658 (-433 *7))) (-5 *1 (-834 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-667 (-433 *5))) (-4 *5 (-1255 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-433 *5))) (-5 *1 (-834 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-667 (-433 *6))) (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-433 *6))) (-5 *1 (-834 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-668 *5 (-433 *5))) (-4 *5 (-1255 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-433 *5))) (-5 *1 (-834 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-668 *6 (-433 *6))) (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-433 *6))) (-5 *1 (-834 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1207))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-332 *3)) (-4 *3 (-582)) (-4 *3 (-869))))) 
+(((*1 *2 *3 *1 *4) (-12 (-5 *3 (-1154 *5 *6)) (-5 *4 (-1 (-141) *6 *6)) (-4 *5 (-13 (-1119) (-39))) (-4 *6 (-13 (-1119) (-39))) (-5 *2 (-141)) (-5 *1 (-1155 *5 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3)))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *5)) (-4 *5 (-388)) (-5 *3 (-790)) (-14 *6 (-658 (-1191))) (-4 *8 (-252 (-1699 *6) *3)) (-5 *1 (-139 *5 *6 *7 *8 *4)) (-4 *7 (-346 *5 *8)) (-4 *4 (-137))))) 
+(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-592)) (-5 *3 (-944)) (-5 *1 (-715)))) ((*1 *2 *2 *2 *3 *4) (-12 (-5 *2 (-706 *5)) (-5 *3 (-121 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-388)) (-5 *1 (-1007 *5))))) 
+(((*1 *2 *3 *4 *4 *5) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-658 *3)) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-594 *6 *3 *7)) (-4 *7 (-1119))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-759 *5 *4 *6 *3)) (-4 *3 (-977 *6 *5 *4))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-631 *1)) (-4 *1 (-318))))) 
+(((*1 *2 *1 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-323)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2934 *1))) (-4 *1 (-323))))) 
+(((*1 *1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-194)) (-4 *2 (-582)))) ((*1 *1 *1) (|partial| -4 *1 (-739)))) 
+(((*1 *1 *1) (-4 *1 (-644))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *3 *3 *2 *4) (-12 (-5 *3 (-706 *2)) (-5 *4 (-592)) (-4 *2 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *5 (-1255 *2)) (-5 *1 (-532 *2 *5 *6)) (-4 *6 (-435 *2 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-977 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |poly| *3) (|:| |mult| *5))) (-5 *1 (-474 *5 *6 *7 *3))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *2 (-137))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1005 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *5 (-1089 *3 *4 *2))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-272))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-592)) (-5 *2 (-658 (-1229))) (-5 *1 (-982)) (-5 *3 (-1229))))) 
+(((*1 *2 *1 *3 *3 *4) (-12 (-5 *3 (-1 (-877) (-877) (-877))) (-5 *4 (-592)) (-5 *2 (-877)) (-5 *1 (-662 *5 *6 *7)) (-4 *5 (-1119)) (-4 *6 (-23)) (-14 *7 *6))) ((*1 *2 *1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-873 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-121 *3)) (-14 *5 (-1 *3 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-237)) (-5 *1 (-877)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-877)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-877)))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-1187 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))) (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *2 (-141)) (-5 *1 (-539 *4 *5))))) 
+(((*1 *1 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1179 3 *3)) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) ((*1 *1) (-12 (-4 *1 (-1151 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *1 *1 *3 *4) (-12 (-5 *3 (-1 (-141) *5 *5)) (-5 *4 (-1 (-141) *6 *6)) (-4 *5 (-13 (-1119) (-39))) (-4 *6 (-13 (-1119) (-39))) (-5 *2 (-141)) (-5 *1 (-1154 *5 *6))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-141)) (-5 *5 (-1121 (-790))) (-5 *6 (-790)) (-5 *2 (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| *3) (|:| -1777 (-592))))))) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (|has| *1 (-6 -4626)) (-4 *1 (-1267 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-310 (-332 *5)))) (-5 *1 (-1146 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-310 (-332 *4)))) (-5 *1 (-1146 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-433 (-980 *5)))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-310 (-332 *5)))) (-5 *1 (-1146 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-310 (-433 (-980 *4)))) (-4 *4 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-310 (-332 *4)))) (-5 *1 (-1146 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 *5)))) (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *5))))) (-5 *1 (-1146 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 *4)))) (-4 *4 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *4))))) (-5 *1 (-1146 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-310 (-433 (-980 *5))))) (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *5))))) (-5 *1 (-1146 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-310 (-433 (-980 *4))))) (-4 *4 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *4))))) (-5 *1 (-1146 *4))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1104 *3)) (-4 *3 (-159))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-778))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-489))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-658 (-971 *3)))))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-658 (-658 (-971 *4)))) (-5 *3 (-141)) (-4 *4 (-1075)) (-4 *1 (-1151 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-971 *3)))) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) ((*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-658 (-658 (-658 *4)))) (-5 *3 (-141)) (-4 *1 (-1151 *4)) (-4 *4 (-1075)))) ((*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-658 (-658 (-971 *4)))) (-5 *3 (-141)) (-4 *1 (-1151 *4)) (-4 *4 (-1075)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-658 (-658 *5)))) (-5 *3 (-658 (-193))) (-5 *4 (-193)) (-4 *1 (-1151 *5)) (-4 *5 (-1075)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-658 (-971 *5)))) (-5 *3 (-658 (-193))) (-5 *4 (-193)) (-4 *1 (-1151 *5)) (-4 *5 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-131 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1293 (-1191) *3)) (-4 *3 (-1075)) (-5 *1 (-1300 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1293 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *1 (-1302 *3 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *6 *3)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-13 (-388) (-171))) (-5 *2 (-658 (-2 (|:| -3215 (-790)) (|:| -2838 *4) (|:| |num| *4)))) (-5 *1 (-425 *3 *4)) (-4 *4 (-1255 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *2 *2)) (-4 *5 (-388)) (-4 *6 (-1255 (-433 *2))) (-4 *2 (-1255 *5)) (-5 *1 (-228 *5 *2 *6 *3)) (-4 *3 (-362 *5 *2 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-405))) (-5 *1 (-1067))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-310 (-855 *3))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-855 *3)) (-5 *1 (-651 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-310 (-855 (-980 *5)))) (-4 *5 (-477)) (-5 *2 (-855 (-433 (-980 *5)))) (-5 *1 (-652 *5)) (-5 *3 (-433 (-980 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-310 (-433 (-980 *5)))) (-5 *3 (-433 (-980 *5))) (-4 *5 (-477)) (-5 *2 (-855 *3)) (-5 *1 (-652 *5))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-141)) (-5 *1 (-316))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-160))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1187 *6)) (-5 *3 (-592)) (-4 *6 (-323)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-759 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (|has| *1 (-6 -4625)) (-4 *1 (-249 *3)) (-4 *3 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *1 (-299 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *3)) (-5 *1 (-1145 *4 *3)) (-4 *4 (-1255 *3))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-658 (-2 (|:| |totdeg| (-790)) (|:| -3489 *3)))) (-5 *4 (-790)) (-4 *3 (-977 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-474 *5 *6 *7 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-188 *3)) (-4 *3 (-194)) (-4 *3 (-1084)) (-4 *3 (-1211)) (-5 *2 (-2 (|:| |r| *3) (|:| |phi| *3)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-433 *6)) (-4 *5 (-1235)) (-4 *6 (-1255 *5)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *3) (|:| |radicand| *6))) (-5 *1 (-172 *5 *6 *7)) (-5 *4 (-790)) (-4 *7 (-1255 *3))))) 
+(((*1 *2 *3 *4 *4 *2 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-790)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-815)) (-4 *4 (-977 *5 *6 *7)) (-4 *5 (-477)) (-4 *7 (-869)) (-5 *1 (-474 *5 *6 *7 *4))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1280 (-1280 (-592)))) (-5 *3 (-944)) (-5 *1 (-495))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1173)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-278)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1225)) (-5 *1 (-201 *3 *2)) (-4 *2 (-690 *3))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1246 (-592))) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-299 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-433 (-592))) (-5 *1 (-321))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1123)) (-5 *3 (-793)) (-5 *1 (-57))))) 
+(((*1 *2) (-12 (-5 *2 (-855 (-592))) (-5 *1 (-563)))) ((*1 *1) (-12 (-5 *1 (-855 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-323)) (-5 *1 (-199 *3))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1028 *3))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-1255 *3)) (-5 *1 (-425 *3 *2)) (-4 *3 (-13 (-388) (-171)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-400 *2 *3)) (-4 *2 (-869)) (-4 *3 (-194)))) ((*1 *1 *1) (-12 (-5 *1 (-642 *2 *3 *4)) (-4 *2 (-869)) (-4 *3 (-13 (-194) (-734 (-433 (-592))))) (-14 *4 (-944)))) ((*1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-5 *2 (-986 (-1137))) (-5 *1 (-370 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-953))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *5)) (-4 *5 (-456 *4)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-877)) (-5 *1 (-36 *4 *5))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *1) (-12 (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-907 *3 *4 *5)) (-4 *3 (-1119)) (-4 *5 (-683 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-911 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *7 *8) (-12 (-5 *3 (-2 (|:| |det| *12) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592))))) (-5 *4 (-706 *12)) (-5 *5 (-658 (-433 (-980 *9)))) (-5 *6 (-658 (-658 *12))) (-5 *7 (-790)) (-5 *8 (-592)) (-4 *9 (-13 (-323) (-171))) (-4 *12 (-977 *9 *11 *10)) (-4 *10 (-13 (-869) (-633 (-1191)))) (-4 *11 (-815)) (-5 *2 (-2 (|:| |eqzro| (-658 *12)) (|:| |neqzro| (-658 *12)) (|:| |wcond| (-658 (-980 *9))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *9)))) (|:| -2195 (-658 (-1280 (-433 (-980 *9))))))))) (-5 *1 (-951 *9 *10 *11 *12))))) 
+(((*1 *1 *2 *3 *3 *3 *4) (-12 (-4 *4 (-388)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-4 *1 (-355 *4 *3 *5 *2)) (-4 *2 (-362 *4 *3 *5)))) ((*1 *1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *2 (-388)) (-4 *4 (-1255 *2)) (-4 *5 (-1255 (-433 *4))) (-4 *1 (-355 *2 *4 *5 *6)) (-4 *6 (-362 *2 *4 *5)))) ((*1 *1 *2 *2) (-12 (-4 *2 (-388)) (-4 *3 (-1255 *2)) (-4 *4 (-1255 (-433 *3))) (-4 *1 (-355 *2 *3 *4 *5)) (-4 *5 (-362 *2 *3 *4)))) ((*1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *1 (-355 *3 *4 *5 *2)) (-4 *2 (-362 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-439 *4 (-433 *4) *5 *6)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 *3 *4 *5)) (-4 *3 (-388)) (-4 *1 (-355 *3 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-143)))) ((*1 *2 *1) (-12 (-4 *1 (-389 *2 *3)) (-4 *3 (-1119)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-1173)))) ((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-464 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1096 *3)) (-14 *3 *2))) ((*1 *1 *1) (-5 *1 (-1191)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-2 (|:| |num| (-1280 *4)) (|:| |den| *4)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141))))) 
+(((*1 *1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *2) (-12 (-5 *2 (-1150 (-237))) (-5 *1 (-1209))))) 
+(((*1 *2 *2 *2 *3 *4) (-12 (-5 *3 (-121 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-1075)) (-5 *1 (-872 *5 *2)) (-4 *2 (-871 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-610 *2)) (-4 *2 (-574))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-5 *2 (-1191)) (-5 *1 (-350))))) 
+(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) ((*1 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) ((*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-944)) (-5 *4 (-405)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *2 (-658 (-1191))) (-5 *1 (-285)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 *7)) (-4 *7 (-977 *6 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-5 *2 (-658 *5)) (-5 *1 (-340 *4 *5 *6 *7)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-359 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-413)))) ((*1 *2 *1) (-12 (-4 *1 (-456 *3)) (-4 *3 (-869)) (-5 *2 (-658 (-1191))))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-658 *5)) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $))))))) ((*1 *2 *1) (-12 (-4 *1 (-1002 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-814)) (-4 *5 (-869)) (-5 *2 (-658 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-658 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-5 *2 (-658 (-1191))) (-5 *1 (-1070 *4))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-388)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-785 *3 *4)) (-4 *3 (-725 *4)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-871 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121 *5)) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-872 *5 *3)) (-4 *3 (-871 *5))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-1173))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373))))) 
+(((*1 *1) (-5 *1 (-179)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) ((*1 *1 *1 *1) (-4 *1 (-815)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-610 *3)) (-4 *3 (-574))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-944)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-399 *3)) (-4 *3 (-1225)) (-4 *3 (-869)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *1 (-399 *4)) (-4 *4 (-1225)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-416 *3 *4 *5)) (-14 *3 (-790)) (-14 *4 (-790)) (-4 *5 (-194))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *3 (-1225)) (-5 *1 (-201 *3 *2)) (-4 *2 (-690 *3))))) 
+(((*1 *2 *3 *2) (|partial| -12 (-5 *3 (-944)) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) ((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-944)) (-5 *4 (-790)) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) ((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-944)) (-5 *4 (-658 (-790))) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) ((*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *3 (-944)) (-5 *4 (-658 (-790))) (-5 *5 (-790)) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) ((*1 *2 *3 *2 *4 *5 *6) (|partial| -12 (-5 *3 (-944)) (-5 *4 (-658 (-790))) (-5 *5 (-790)) (-5 *6 (-141)) (-5 *1 (-467 *2)) (-4 *2 (-1255 (-592))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-444 *2)) (-4 *2 (-1255 *5)) (-5 *1 (-469 *5 *2)) (-4 *5 (-1075))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *2 (-592)) (-5 *1 (-1208 *3)) (-4 *3 (-1075))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-373)) (-4 *2 (-1075)) (-5 *1 (-729 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-706 (-332 (-237)))) (-5 *2 (-405)) (-5 *1 (-219))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-790)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-815)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-477)) (-4 *5 (-869)) (-5 *1 (-474 *3 *4 *5 *6))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (|has| *1 (-6 -4625)) (-4 *1 (-249 *3)) (-4 *3 (-1119)))) ((*1 *1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-249 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) ((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-629 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-141) *4)) (-5 *3 (-592)) (-4 *4 (-1119)) (-5 *1 (-754 *4)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *1 (-754 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1155 *3 *4))))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-4 *3 (-194))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-5 *2 (-658 *3))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-1137)) (-5 *2 (-141)) (-5 *1 (-843))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-1280 (-706 *4))))) ((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-1280 (-706 *4))) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) ((*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-1280 (-706 *3))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1191))) (-4 *5 (-388)) (-5 *2 (-1280 (-706 (-433 (-980 *5))))) (-5 *1 (-1105 *5)) (-5 *4 (-706 (-433 (-980 *5)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1191))) (-4 *5 (-388)) (-5 *2 (-1280 (-706 (-980 *5)))) (-5 *1 (-1105 *5)) (-5 *4 (-706 (-980 *5))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-706 *4))) (-4 *4 (-388)) (-5 *2 (-1280 (-706 *4))) (-5 *1 (-1105 *4))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-916 *2 *3)) (-4 *2 (-1255 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |answer| *3) (|:| |polypart| *3))) (-5 *1 (-602 *5 *3))))) 
+(((*1 *2 *3 *4) (-12 (-4 *7 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-582)) (-4 *8 (-977 *7 *5 *6)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *3) (|:| |radicand| *3))) (-5 *1 (-981 *5 *6 *7 *8 *3)) (-5 *4 (-790)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1448 (*8 $)) (-15 -1456 (*8 $)) (-15 -1683 ($ *8)))))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477))) (-5 *2 (-2 (|:| |%term| (-2 (|:| |%coef| (-1264 *4 *5 *6)) (|:| |%expon| (-336 *4 *5 *6)) (|:| |%expTerms| (-658 (-2 (|:| |k| (-433 (-592))) (|:| |c| *4)))))) (|:| |%type| (-1173)))) (-5 *1 (-1265 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1211) (-456 *3))) (-14 *5 (-1191)) (-14 *6 *4)))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-141)) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-4 *3 (-13 (-27) (-1211) (-456 *6) (-10 -8 (-15 -1683 ($ *7))))) (-4 *7 (-867)) (-4 *8 (-13 (-1257 *3 *7) (-388) (-1211) (-10 -8 (-15 -3644 ($ $)) (-15 -3162 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173)))))) (-5 *1 (-448 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1173)) (-4 *9 (-1012 *8)) (-14 *10 (-1191))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1270 *4)) (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-1 (-1171 *4) (-1171 *4))) (-5 *1 (-1272 *4 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869))) (-4 *2 (-13 (-456 *4) (-1030) (-1211))) (-5 *1 (-621 *4 *2 *3)) (-4 *3 (-13 (-456 (-191 *4)) (-1030) (-1211)))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *8 (-999 *5)) (-4 *9 (-665 *5)) (-4 *10 (-947 *5 *9)) (-4 *11 (-560 *5 *6 *3 *7 *8 *9 *10 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *10)) (-5 *1 (-282 *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (-4 *4 (-280 *11))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *2 *3 *1) (|partial| -12 (-5 *3 (-1 (-141) *2)) (-4 *1 (-175 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-1191)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-489))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1 *1)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-1171 *3))) (-5 *1 (-1171 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944)) (|has| *1 (-6 -4616)) (-4 *1 (-430)))) ((*1 *2) (-12 (-4 *1 (-430)) (-5 *2 (-944)))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-715)))) ((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-715))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-592)) (-5 *1 (-474 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-896)) (-5 *5 (-944)) (-5 *6 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-1284)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-1284))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-444 (-1187 *1))) (-5 *1 (-332 *4)) (-5 *3 (-1187 *1)) (-4 *4 (-477)) (-4 *4 (-582)) (-4 *4 (-869)))) ((*1 *2 *3) (-12 (-4 *1 (-931)) (-5 *2 (-444 (-1187 *1))) (-5 *3 (-1187 *1))))) 
+(((*1 *1 *1 *1) (-4 *1 (-167))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574)))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *2 *3 *4) (-12 (-5 *4 |RationalNumber|) (-5 *2 (-1 (-592))) (-5 *1 (-1073)) (-5 *3 (-592))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869))))) 
+(((*1 *1) (-5 *1 (-163)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-3 "left" "center" "right" "vertical" "horizontal"))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-2 (|:| |deg| (-790)) (|:| -2042 *5)))) (-5 *1 (-831 *4 *5 *3 *6)) (-4 *3 (-670 *5)) (-4 *6 (-670 (-433 *5)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-230))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -1544 *3) (|:| |coef2| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592)))))))))) (-5 *1 (-1195))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)) (-5 *1 (-697 *5 *6 *2))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-237)) (-5 *1 (-30)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-444 *4) *4)) (-4 *4 (-582)) (-5 *2 (-444 *4)) (-5 *1 (-445 *4)))) ((*1 *1 *1) (-5 *1 (-953))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-953)))) ((*1 *1 *1) (-5 *1 (-954))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *4 (-433 (-592))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *4 (-433 (-592))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 (-433 (-592)))))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-401 *4 *2)) (-4 *2 (-13 (-399 *4) (-10 -7 (-6 -4626))))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-1 *4 (-592))) (-4 *4 (-1075)) (-5 *1 (-1175 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-1255 *4)) (-5 *1 (-568 *4 *2 *5 *6)) (-4 *4 (-323)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-790)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-2 (|:| -1495 (-1171 *4)) (|:| -1501 (-1171 *4)))) (-5 *1 (-1177 *4)) (-5 *3 (-1171 *4))))) 
+(((*1 *2) (-12 (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)))) ((*1 *2) (-12 (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-374 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) ((*1 *2) (-12 (-4 *3 (-1255 (-592))) (-5 *2 (-2 (|:| -2195 (-706 (-592))) (|:| |basisDen| (-592)) (|:| |basisInv| (-706 (-592))))) (-5 *1 (-787 *3 *4)) (-4 *4 (-435 (-592) *3)))) ((*1 *2) (-12 (-4 *3 (-373)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -2195 (-706 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-706 *4)))) (-5 *1 (-1014 *3 *4 *5 *6)) (-4 *6 (-741 *4 *5)))) ((*1 *2) (-12 (-4 *3 (-373)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -2195 (-706 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-706 *4)))) (-5 *1 (-1289 *3 *4 *5 *6)) (-4 *6 (-435 *4 *5))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-193)))))) 
+(((*1 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-237)) (-5 *3 (-790)) (-5 *1 (-239)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-191 (-237))) (-5 *3 (-790)) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-589)) (-5 *3 (-592)))) ((*1 *2 *3) (-12 (-5 *2 (-1187 (-433 (-592)))) (-5 *1 (-970)) (-5 *3 (-592))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 *3) (|:| -3552 *4)))) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *1 (-1202 *3 *4)))) ((*1 *1) (-12 (-4 *1 (-1202 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-658 *10)) (-5 *5 (-141)) (-4 *10 (-1094 *6 *7 *8 *9)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-1089 *6 *7 *8)) (-5 *2 (-658 (-2 (|:| -2042 (-658 *9)) (|:| -2165 *10) (|:| |ineq| (-658 *9))))) (-5 *1 (-1017 *6 *7 *8 *9 *10)) (-5 *3 (-658 *9)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-658 *10)) (-5 *5 (-141)) (-4 *10 (-1094 *6 *7 *8 *9)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-1089 *6 *7 *8)) (-5 *2 (-658 (-2 (|:| -2042 (-658 *9)) (|:| -2165 *10) (|:| |ineq| (-658 *9))))) (-5 *1 (-1126 *6 *7 *8 *9 *10)) (-5 *3 (-658 *9))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-706 (-980 *4))) (-5 *1 (-1056 *4)) (-4 *4 (-1075))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-518 *3))))) 
+(((*1 *1 *1) (-5 *1 (-141)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-1075)) (-4 *2 (-1255 *4)) (-5 *1 (-469 *4 *2)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-433 (-1187 (-332 *5)))) (-5 *3 (-1280 (-332 *5))) (-5 *4 (-592)) (-4 *5 (-13 (-582) (-869))) (-5 *1 (-1147 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1075)) (-4 *1 (-1255 *3))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-790)) (-5 *1 (-187 *3 *4)) (-4 *3 (-188 *4)))) ((*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1225)) (-5 *2 (-790)) (-5 *1 (-251 *3 *4 *5)) (-4 *3 (-252 *4 *5)))) ((*1 *2) (-12 (-4 *4 (-869)) (-5 *2 (-790)) (-5 *1 (-455 *3 *4)) (-4 *3 (-456 *4)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-573 *3)) (-4 *3 (-574)))) ((*1 *2) (-12 (-4 *1 (-782)) (-5 *2 (-790)))) ((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-790)) (-5 *1 (-818 *3 *4)) (-4 *3 (-819 *4)))) ((*1 *2) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-1020 *3 *4)) (-4 *3 (-1021 *4)))) ((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-790)) (-5 *1 (-1024 *3 *4)) (-4 *3 (-1025 *4)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1039 *3)) (-4 *3 (-1040)))) ((*1 *2) (-12 (-4 *1 (-1075)) (-5 *2 (-790)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1083 *3)) (-4 *3 (-1084))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1119)) (-4 *4 (-1225)) (-5 *2 (-141)) (-5 *1 (-1171 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1187 (-980 *6))) (-4 *6 (-582)) (-4 *2 (-977 (-433 (-980 *6)) *5 *4)) (-5 *1 (-749 *5 *4 *6 *2)) (-4 *5 (-815)) (-4 *4 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)))))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-565) (-658 (-565)))) (-5 *1 (-143)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-565) (-658 (-565)))) (-5 *1 (-143))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-658 (-310 (-980 *4))))) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-310 (-433 (-980 (-592)))))) (-5 *2 (-658 (-658 (-310 (-980 *4))))) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-592)))) (-5 *2 (-658 (-310 (-980 *4)))) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-433 (-980 (-592))))) (-5 *2 (-658 (-310 (-980 *4)))) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1191)) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-4 *4 (-13 (-29 *6) (-1211) (-987))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2195 (-658 *4)))) (-5 *1 (-666 *6 *4 *3)) (-4 *3 (-670 *4)))) ((*1 *2 *3 *2 *4 *2 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-666 *6 *2 *3)) (-4 *3 (-670 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |particular| (-3 (-1280 *5) "failed")) (|:| -2195 (-658 (-1280 *5))))) (-5 *1 (-684 *5)) (-5 *4 (-1280 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 *5))) (-4 *5 (-388)) (-5 *2 (-2 (|:| |particular| (-3 (-1280 *5) "failed")) (|:| -2195 (-658 (-1280 *5))))) (-5 *1 (-684 *5)) (-5 *4 (-1280 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 *5)) (-4 *5 (-388)) (-5 *2 (-658 (-2 (|:| |particular| (-3 (-1280 *5) "failed")) (|:| -2195 (-658 (-1280 *5)))))) (-5 *1 (-684 *5)) (-5 *4 (-658 (-1280 *5))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 *5))) (-4 *5 (-388)) (-5 *2 (-658 (-2 (|:| |particular| (-3 (-1280 *5) "failed")) (|:| -2195 (-658 (-1280 *5)))))) (-5 *1 (-684 *5)) (-5 *4 (-658 (-1280 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-685 *5 *6 *4 *3)) (-4 *3 (-704 *5 *6 *4)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-4 *7 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-5 *2 (-658 (-2 (|:| |particular| (-3 *7 "failed")) (|:| -2195 (-658 *7))))) (-5 *1 (-685 *5 *6 *7 *3)) (-5 *4 (-658 *7)) (-4 *3 (-704 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *5)))))) (-5 *1 (-789 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *4)))))) (-5 *1 (-789 *4)))) ((*1 *2 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-143)) (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-791 *5 *2)) (-4 *2 (-13 (-29 *5) (-1211) (-987))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-706 *7)) (-5 *5 (-1191)) (-4 *7 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-2 (|:| |particular| (-1280 *7)) (|:| -2195 (-658 (-1280 *7))))) (-5 *1 (-824 *6 *7)) (-5 *4 (-1280 *7)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-706 *6)) (-5 *4 (-1191)) (-4 *6 (-13 (-29 *5) (-1211) (-987))) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-1280 *6))) (-5 *1 (-824 *5 *6)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-658 (-310 *7))) (-5 *4 (-658 (-143))) (-5 *5 (-1191)) (-4 *7 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-2 (|:| |particular| (-1280 *7)) (|:| -2195 (-658 (-1280 *7))))) (-5 *1 (-824 *6 *7)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-658 *7)) (-5 *4 (-658 (-143))) (-5 *5 (-1191)) (-4 *7 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-2 (|:| |particular| (-1280 *7)) (|:| -2195 (-658 (-1280 *7))))) (-5 *1 (-824 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 *7)) (-5 *4 (-143)) (-5 *5 (-1191)) (-4 *7 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-3 (-2 (|:| |particular| *7) (|:| -2195 (-658 *7))) *7 "failed")) (-5 *1 (-824 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-143)) (-5 *5 (-1191)) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-3 (-2 (|:| |particular| *3) (|:| -2195 (-658 *3))) *3 "failed")) (-5 *1 (-824 *6 *3)) (-4 *3 (-13 (-29 *6) (-1211) (-987))))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-310 *2)) (-5 *4 (-143)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-29 *6) (-1211) (-987))) (-5 *1 (-824 *6 *2)) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))))) ((*1 *2 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-143)) (-5 *4 (-310 *2)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-29 *6) (-1211) (-987))) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-824 *6 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-830)) (-5 *2 (-1063)) (-5 *1 (-827)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-830)) (-5 *4 (-1087)) (-5 *2 (-1063)) (-5 *1 (-827)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1280 (-332 (-405)))) (-5 *4 (-405)) (-5 *5 (-658 *4)) (-5 *2 (-1063)) (-5 *1 (-827)))) ((*1 *2 *3 *4 *4 *5 *4) (-12 (-5 *3 (-1280 (-332 (-405)))) (-5 *4 (-405)) (-5 *5 (-658 *4)) (-5 *2 (-1063)) (-5 *1 (-827)))) ((*1 *2 *3 *4 *4 *5 *6 *4) (-12 (-5 *3 (-1280 (-332 *4))) (-5 *5 (-658 (-405))) (-5 *6 (-332 (-405))) (-5 *4 (-405)) (-5 *2 (-1063)) (-5 *1 (-827)))) ((*1 *2 *3 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1280 (-332 (-405)))) (-5 *4 (-405)) (-5 *5 (-658 *4)) (-5 *2 (-1063)) (-5 *1 (-827)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4) (-12 (-5 *3 (-1280 (-332 *4))) (-5 *5 (-658 (-405))) (-5 *6 (-332 (-405))) (-5 *4 (-405)) (-5 *2 (-1063)) (-5 *1 (-827)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (-12 (-5 *3 (-1280 (-332 *4))) (-5 *5 (-658 (-405))) (-5 *6 (-332 (-405))) (-5 *4 (-405)) (-5 *2 (-1063)) (-5 *1 (-827)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-2 (|:| |particular| *6) (|:| -2195 (-658 *6))) "failed") *7 *6)) (-4 *6 (-388)) (-4 *7 (-670 *6)) (-5 *2 (-2 (|:| |particular| (-1280 *6)) (|:| -2195 (-706 *6)))) (-5 *1 (-835 *6 *7)) (-5 *3 (-706 *6)) (-5 *4 (-1280 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-920)) (-5 *2 (-1063)) (-5 *1 (-919)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-920)) (-5 *4 (-1087)) (-5 *2 (-1063)) (-5 *1 (-919)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (-12 (-5 *4 (-790)) (-5 *6 (-658 (-658 (-332 *3)))) (-5 *7 (-1173)) (-5 *8 (-237)) (-5 *5 (-658 (-332 (-405)))) (-5 *3 (-405)) (-5 *2 (-1063)) (-5 *1 (-919)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (-12 (-5 *4 (-790)) (-5 *6 (-658 (-658 (-332 *3)))) (-5 *7 (-1173)) (-5 *5 (-658 (-332 (-405)))) (-5 *3 (-405)) (-5 *2 (-1063)) (-5 *1 (-919)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-980 (-433 (-592)))) (-5 *2 (-658 (-405))) (-5 *1 (-1050)) (-5 *4 (-405)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-980 (-592))) (-5 *2 (-658 (-405))) (-5 *1 (-1050)) (-5 *4 (-405)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-310 (-332 *4)))) (-5 *1 (-1148 *4)) (-5 *3 (-332 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-310 (-332 *4)))) (-5 *1 (-1148 *4)) (-5 *3 (-310 (-332 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-310 (-332 *5)))) (-5 *1 (-1148 *5)) (-5 *3 (-310 (-332 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-310 (-332 *5)))) (-5 *1 (-1148 *5)) (-5 *3 (-332 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-658 (-658 (-310 (-332 *5))))) (-5 *1 (-1148 *5)) (-5 *3 (-658 (-310 (-332 *5)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 *5)))) (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *5)))))) (-5 *1 (-1196 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *5)))))) (-5 *1 (-1196 *5)) (-5 *3 (-658 (-310 (-433 (-980 *5))))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 *4)))) (-4 *4 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *4)))))) (-5 *1 (-1196 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *4)))))) (-5 *1 (-1196 *4)) (-5 *3 (-658 (-310 (-433 (-980 *4))))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-582)) (-5 *2 (-658 (-310 (-433 (-980 *5))))) (-5 *1 (-1196 *5)) (-5 *3 (-433 (-980 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-582)) (-5 *2 (-658 (-310 (-433 (-980 *5))))) (-5 *1 (-1196 *5)) (-5 *3 (-310 (-433 (-980 *5)))))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 (-310 (-433 (-980 *4))))) (-5 *1 (-1196 *4)) (-5 *3 (-433 (-980 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 (-310 (-433 (-980 *4))))) (-5 *1 (-1196 *4)) (-5 *3 (-310 (-433 (-980 *4))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-523 *3)) (-4 *3 (-1225)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-658 *3)) (-5 *1 (-1161 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-141)) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-4 *3 (-13 (-27) (-1211) (-456 *6) (-10 -8 (-15 -1683 ($ *7))))) (-4 *7 (-867)) (-4 *8 (-13 (-1257 *3 *7) (-388) (-1211) (-10 -8 (-15 -3644 ($ $)) (-15 -3162 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173)))))) (-5 *1 (-448 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1173)) (-4 *9 (-1012 *8)) (-14 *10 (-1191))))) 
+(((*1 *1 *2 *2) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-790))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-4 *1 (-925 *3))))) 
+(((*1 *1) (-5 *1 (-845)))) 
+(((*1 *2 *2 *2 *3 *3) (-12 (-5 *3 (-790)) (-4 *4 (-1075)) (-5 *1 (-1251 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-332 *4)) (-5 *1 (-202 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 (-191 *4)))))) ((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) ((*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373))))) 
+(((*1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-582)) (-4 *2 (-194))))) 
+(((*1 *2 *3 *2) (|partial| -12 (-5 *2 (-1280 *4)) (-5 *3 (-706 *4)) (-4 *4 (-388)) (-5 *1 (-684 *4)))) ((*1 *2 *3 *2) (|partial| -12 (-4 *4 (-388)) (-4 *5 (-13 (-399 *4) (-10 -7 (-6 -4626)))) (-4 *2 (-13 (-399 *4) (-10 -7 (-6 -4626)))) (-5 *1 (-685 *4 *5 *2 *3)) (-4 *3 (-704 *4 *5 *2)))) ((*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *4 (-658 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-388)) (-5 *1 (-836 *2 *3)) (-4 *3 (-670 *2)))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *3 (-1255 *4)) (-4 *2 (-1270 *4)) (-5 *1 (-1273 *4 *3 *5 *2)) (-4 *5 (-670 *3))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-1257 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-4 *1 (-1260 *3)) (-4 *3 (-1075))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-1119)) (-5 *1 (-96 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-1119)) (-5 *1 (-234 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-869)) (-5 *1 (-518 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| *1 (-6 -4626)) (-4 *1 (-523 *3)) (-4 *3 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-1119)) (-5 *1 (-1028 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4626)) (-4 *3 (-1119)) (-5 *1 (-1161 *3))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4)))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1063)) (-5 *3 (-1191)) (-5 *1 (-206))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-284 *2)) (-4 *2 (-869)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-879 *3)) (-14 *3 (-658 *2)))) ((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1018)))) ((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1111 *3)) (-4 *3 (-1225)))) ((*1 *2 *1) (-12 (-4 *1 (-1257 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-1191)))) ((*1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1276 *3)) (-14 *3 *2)))) 
+(((*1 *2) (-12 (-5 *2 (-1161 (-1173))) (-5 *1 (-417))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-582)) (-5 *1 (-998 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *1 *1) (-4 *1 (-890 *2)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-851)) (-5 *3 (-1173))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-815)) (-4 *3 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *5 (-582)) (-5 *1 (-749 *4 *3 *5 *2)) (-4 *2 (-977 (-433 (-980 *5)) *4 *3)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-5 *1 (-1013 *4 *5 *3 *2)) (-4 *2 (-977 (-980 *4) *5 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-4 *4 (-1075)) (-4 *5 (-815)) (-5 *1 (-1013 *4 *5 *6 *2)) (-4 *2 (-977 (-980 *4) *5 *6))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-790)) (-4 *2 (-13 (-582) (-477))) (-5 *1 (-369 *2 *4)) (-4 *4 (-52 *2 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1280 *6)) (-5 *4 (-1280 (-592))) (-5 *5 (-592)) (-4 *6 (-1119)) (-5 *2 (-1 *6)) (-5 *1 (-1045 *6))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-474 *3 *4 *5 *2)) (-4 *2 (-977 *3 *4 *5))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 "skip" "MonteCarlo" "deterministic")) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 "skip" "MonteCarlo" "deterministic")) (-5 *1 (-489)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 (-2 (|:| -4500 (-1187 *6)) (|:| -3215 (-592))))) (-4 *6 (-323)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-759 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5)))) ((*1 *1 *1) (-12 (-4 *1 (-1151 *2)) (-4 *2 (-1075))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-592) (-592))) (-5 *1 (-386 *3)) (-4 *3 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-790) (-790))) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-662 *3 *4 *5)) (-4 *3 (-1119))))) 
+(((*1 *2) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-658 (-658 *4))) (-5 *1 (-361 *3 *4 *5 *6)) (-4 *3 (-362 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *3 (-394)) (-5 *2 (-658 (-658 *3))))) ((*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *7)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-5 *2 (-658 (-995 *3))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-658 (-994 *3))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-5 *2 (-658 *8)) (-5 *1 (-991 *5 *6 *3 *7 *8)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-470 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *4 (-1 *3)) (-4 *3 (-869)) (-4 *5 (-815)) (-4 *6 (-582)) (-4 *7 (-977 *6 *5 *3)) (-5 *1 (-490 *5 *3 *6 *7 *2)) (-4 *2 (-13 (-1065 (-433 (-592))) (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $)))))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-474 *4 *5 *6 *2))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-658 *8)) (-5 *3 (-1 (-141) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1006 *5 *6 *7 *8))))) 
+(((*1 *1 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-1017 *5 *6 *7 *8 *3)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-1126 *5 *6 *7 *8 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-31 *4 *5 *6 *7 *8)) (-4 *8 (-999 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *8 (-999 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-399 *2)) (-4 *2 (-1225)) (-4 *2 (-869)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3 *3)) (-4 *1 (-399 *3)) (-4 *3 (-1225)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-927 *3))) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-4 *6 (-1089 *4 *5 *3)) (-5 *2 (-2 (|:| |under| *1) (|:| -2039 *1) (|:| |upper| *1))) (-4 *1 (-1005 *4 *5 *3 *6))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-1225)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-305 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *2 *6 *7)) (-4 *6 (-252 *5 *2)) (-4 *7 (-252 *4 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-405))) (-5 *1 (-1067))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-4 *7 (-1255 (-433 *6))) (-5 *2 (-2 (|:| |answer| *3) (|:| -4192 *3))) (-5 *1 (-590 *5 *6 *7 *3)) (-4 *3 (-362 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |answer| (-433 *6)) (|:| -4192 (-433 *6)) (|:| |specpart| (-433 *6)) (|:| |polypart| *6))) (-5 *1 (-591 *5 *6)) (-5 *3 (-433 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-1075))))) 
+(((*1 *1 *2 *2) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |k| (-688 *3)) (|:| |c| *4)))) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-667 (-433 *6))) (-5 *4 (-433 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-832 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-667 (-433 *6))) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-2 (|:| -2195 (-658 (-433 *6))) (|:| -3253 (-706 *5)))) (-5 *1 (-832 *5 *6)) (-5 *4 (-658 (-433 *6))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-668 *6 (-433 *6))) (-5 *4 (-433 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-832 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-668 *6 (-433 *6))) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-2 (|:| -2195 (-658 (-433 *6))) (|:| -3253 (-706 *5)))) (-5 *1 (-832 *5 *6)) (-5 *4 (-658 (-433 *6)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-141))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-971 (-237))) (-5 *2 (-1285)) (-5 *1 (-497))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-412 *3)) (|:| |mm| (-412 *3)) (|:| |rm| (-412 *3)))) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-841 *3)) (|:| |mm| (-841 *3)) (|:| |rm| (-841 *3)))) (-5 *1 (-841 *3)) (-4 *3 (-869))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1285)) (-5 *1 (-227 *4)) (-4 *4 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 (*2 $)) (-15 -3948 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-227 *3)) (-4 *3 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 (*2 $)) (-15 -3948 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-535))))) 
+(((*1 *2 *3 *4 *2 *3) (-12 (-5 *2 (-986 (-237))) (-5 *3 (-1137)) (-5 *4 (-237)) (-5 *1 (-135))))) 
+(((*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-1 (-658 *4) *4)) (-5 *1 (-127 *4)) (-5 *3 (-658 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 *1)) (-5 *4 (-1280 *1)) (-4 *1 (-654 *5)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -3253 (-706 *5)) (|:| |vec| (-1280 *5)))))) ((*1 *2 *3) (-12 (-5 *3 (-706 *1)) (-4 *1 (-654 *4)) (-4 *4 (-1075)) (-5 *2 (-706 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323))))) 
+(((*1 *1 *2 *3 *3 *4 *4) (-12 (-5 *2 (-980 (-592))) (-5 *3 (-1191)) (-5 *4 (-1113 (-433 (-592)))) (-5 *1 (-30))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-579 *3)) (-4 *3 (-13 (-430) (-1211))) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1121 *4)) (-4 *4 (-1119)) (-5 *2 (-1 *4)) (-5 *1 (-1045 *4)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-405))) (-5 *1 (-1067)) (-5 *3 (-405)))) ((*1 *2 *3) (-12 (-5 *3 (-1113 (-592))) (-5 *2 (-1 (-592))) (-5 *1 (-1073))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-867)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-927 *3)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1091 *4 *3)) (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-592)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-582) (-869) (-1065 *2) (-654 *2) (-477))) (-5 *2 (-592)) (-5 *1 (-1134 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-862 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 *2) (-654 *2) (-477))) (-5 *2 (-592)) (-5 *1 (-1134 *6 *3)))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-1173)) (-4 *6 (-13 (-582) (-869) (-1065 *2) (-654 *2) (-477))) (-5 *2 (-592)) (-5 *1 (-1134 *6 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-477)) (-5 *2 (-592)) (-5 *1 (-1135 *4)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-862 (-433 (-980 *6)))) (-5 *3 (-433 (-980 *6))) (-4 *6 (-477)) (-5 *2 (-592)) (-5 *1 (-1135 *6)))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-433 (-980 *6))) (-5 *4 (-1191)) (-5 *5 (-1173)) (-4 *6 (-477)) (-5 *2 (-592)) (-5 *1 (-1135 *6)))) ((*1 *2 *3) (|partial| -12 (-5 *2 (-592)) (-5 *1 (-1208 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-433 (-980 *4))) (-5 *1 (-951 *4 *5 *6 *3)) (-4 *3 (-977 *4 *6 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-706 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-706 (-433 (-980 *4)))) (-5 *1 (-951 *4 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-433 (-980 *4)))) (-5 *1 (-951 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-516 *4 *5))) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *2 (-658 (-264 *4 *5))) (-5 *1 (-646 *4 *5))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-2 (|:| |partsol| (-1280 (-433 (-980 *4)))) (|:| -2195 (-658 (-1280 (-433 (-980 *4))))))) (-5 *3 (-658 *7)) (-4 *4 (-13 (-323) (-171))) (-4 *7 (-977 *4 *6 *5)) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *1 (-951 *4 *5 *6 *7))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *1 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-37 *2)) (-4 *2 (-388)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1225)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "right") (|has| *1 (-6 -4626)) (-4 *1 (-148 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "left") (|has| *1 (-6 -4626)) (-4 *1 (-148 *3)) (-4 *3 (-1225)))) ((*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-305 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-57)) (-5 *3 (-1191)) (-5 *1 (-647)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 (-1246 (-592))) (|has| *1 (-6 -4626)) (-4 *1 (-664 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-658 (-592))) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-999 *2)) (-4 *2 (-388)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "value") (|has| *1 (-6 -4626)) (-4 *1 (-1038 *2)) (-4 *2 (-1225)))) ((*1 *2 *1 *2) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225)))) ((*1 *2 *1 *3 *2) (-12 (-4 *1 (-1202 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "last") (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "rest") (|has| *1 (-6 -4626)) (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "first") (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-658 *11)) (|:| |todo| (-658 (-2 (|:| |val| *3) (|:| -2165 *11)))))) (-5 *6 (-790)) (-5 *2 (-658 (-2 (|:| |val| (-658 *10)) (|:| -2165 *11)))) (-5 *3 (-658 *10)) (-5 *4 (-658 *11)) (-4 *10 (-1089 *7 *8 *9)) (-4 *11 (-1094 *7 *8 *9 *10)) (-4 *7 (-477)) (-4 *8 (-815)) (-4 *9 (-869)) (-5 *1 (-1092 *7 *8 *9 *10 *11)))) ((*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-658 *11)) (|:| |todo| (-658 (-2 (|:| |val| *3) (|:| -2165 *11)))))) (-5 *6 (-790)) (-5 *2 (-658 (-2 (|:| |val| (-658 *10)) (|:| -2165 *11)))) (-5 *3 (-658 *10)) (-5 *4 (-658 *11)) (-4 *10 (-1089 *7 *8 *9)) (-4 *11 (-1128 *7 *8 *9 *10)) (-4 *7 (-477)) (-4 *8 (-815)) (-4 *9 (-869)) (-5 *1 (-1159 *7 *8 *9 *10 *11))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-57))) (-5 *2 (-1285)) (-5 *1 (-878))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-790)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-489))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2 *3) (-12 (-5 *3 (-1000)) (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-37 *2)) (-4 *2 (-388)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1225)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *2 "right") (-4 *1 (-148 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *2 "left") (-4 *1 (-148 *3)) (-4 *3 (-1225)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-658 (-592))) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 (-592)) (-14 *5 (-790)))) ((*1 *2 *1 *3 *3 *3 *3) (-12 (-5 *3 (-592)) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-790)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-592)) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-790)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-790)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *2 (-194)) (-5 *1 (-162 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-790)))) ((*1 *2 *1) (-12 (-4 *2 (-194)) (-5 *1 (-162 *3 *4 *2)) (-14 *3 (-592)) (-14 *4 (-790)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-262 (-1173))) (-5 *1 (-227 *4)) (-4 *4 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ *3)) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1018)) (-5 *1 (-227 *3)) (-4 *3 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))))) ((*1 *2 *1 *3) (-12 (-5 *3 "count") (-5 *2 (-790)) (-5 *1 (-262 *4)) (-4 *4 (-869)))) ((*1 *1 *1 *2) (-12 (-5 *2 "sort") (-5 *1 (-262 *3)) (-4 *3 (-869)))) ((*1 *1 *1 *2) (-12 (-5 *2 "unique") (-5 *1 (-262 *3)) (-4 *3 (-869)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-303 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225)))) ((*1 *2 *1 *3 *2) (-12 (-4 *1 (-305 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225)))) ((*1 *2 *1 *2) (-12 (-4 *3 (-194)) (-5 *1 (-306 *3 *2 *4 *5 *6 *7)) (-4 *2 (-1255 *3)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-658 *1)) (-4 *1 (-318)))) ((*1 *1 *2 *1 *1 *1 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) ((*1 *1 *2 *1 *1 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) ((*1 *1 *2 *1 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) ((*1 *2 *1 *2 *2) (-12 (-4 *1 (-362 *2 *3 *4)) (-4 *2 (-1235)) (-4 *3 (-1255 *2)) (-4 *4 (-1255 (-433 *3))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-443 *2)) (-4 *2 (-194)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1173)) (-5 *1 (-535)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-57)) (-5 *1 (-647)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1246 (-592))) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-790)) (-5 *1 (-691 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-658 (-592))) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-658 (-914 *4))) (-5 *1 (-914 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-925 *2)) (-4 *2 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-927 *4)) (-5 *1 (-926 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-947 *2 *4)) (-4 *4 (-665 *2)) (-4 *2 (-388)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-999 *2)) (-4 *2 (-388)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-254 *4 *2)) (-14 *4 (-944)) (-4 *2 (-388)) (-5 *1 (-1022 *4 *2)))) ((*1 *2 *1 *3) (-12 (-5 *3 "value") (-4 *1 (-1038 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *2 *6 *7)) (-4 *2 (-1075)) (-4 *6 (-252 *5 *2)) (-4 *7 (-252 *4 *2)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *2 *6 *7)) (-4 *6 (-252 *5 *2)) (-4 *7 (-252 *4 *2)) (-4 *2 (-1075)))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-1097 *4 *5 *2)) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-1098 *4 *5 *2)) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)))) ((*1 *1 *1 *1) (-4 *1 (-1158))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-1191)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-433 *1)) (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-433 *1)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)) (-4 *3 (-582)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1257 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) ((*1 *2 *1 *3) (-12 (-5 *3 "last") (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *2 "rest") (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) ((*1 *2 *1 *3) (-12 (-5 *3 "first") (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-658 (-631 *6))) (-5 *4 (-1191)) (-5 *2 (-631 *6)) (-4 *6 (-456 *5)) (-4 *5 (-869)) (-5 *1 (-601 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-885)) (-5 *2 (-1285))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-926 *4)) (-4 *4 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-926 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477))))) 
+(((*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-592))) (-5 *1 (-1073))))) 
+(((*1 *1 *1) (|partial| -4 *1 (-1165)))) 
+(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-592)) (-5 *6 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810)))) ((*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (-12 (-5 *4 (-592)) (-5 *6 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405))))))) (-5 *1 (-825))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) *2)) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-790)) (-5 *1 (-282 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-790)) (-5 *1 (-361 *3 *4 *5 *6)) (-4 *3 (-362 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-790)))) ((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-790)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-171)) (-4 *3 (-323)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-4 *3 (-582)) (-5 *2 (-1187 *3))))) 
+(((*1 *1 *1) (-5 *1 (-1087)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-193))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-489))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-574)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1191)) (-5 *2 (-1195)) (-5 *1 (-1194))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-971 (-237)))) (-5 *1 (-1281))))) 
+(((*1 *2 *3 *4 *2 *5) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 (-914 *6))) (-5 *5 (-1 (-911 *6 *8) *8 (-914 *6) (-911 *6 *8))) (-4 *6 (-1119)) (-4 *8 (-13 (-1075) (-633 (-914 *6)) (-1065 *7))) (-5 *2 (-911 *6 *8)) (-4 *7 (-13 (-1075) (-869))) (-5 *1 (-969 *6 *7 *8))))) 
+(((*1 *1 *2 *2 *1) (|partial| -12 (-5 *2 (-150)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1187 *1)) (-5 *3 (-1191)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-980 *1)) (-4 *1 (-27)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-869) (-582))))) ((*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-869) (-582))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1187 *2)) (-5 *4 (-1191)) (-4 *2 (-456 *5)) (-5 *1 (-36 *5 *2)) (-4 *5 (-13 (-869) (-582))))) ((*1 *1 *2 *3) (|partial| -12 (-5 *2 (-1187 *1)) (-5 *3 (-944)) (-4 *1 (-1040)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-1187 *1)) (-5 *3 (-944)) (-5 *4 (-877)) (-4 *1 (-1040)))) ((*1 *1 *2 *3) (|partial| -12 (-5 *3 (-944)) (-4 *4 (-13 (-867) (-388))) (-4 *1 (-1091 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 (-516 *5 *6))) (-5 *4 (-879 *5)) (-14 *5 (-658 (-1191))) (-5 *2 (-516 *5 *6)) (-5 *1 (-646 *5 *6)) (-4 *6 (-477)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-516 *5 *6))) (-5 *4 (-879 *5)) (-14 *5 (-658 (-1191))) (-5 *2 (-516 *5 *6)) (-5 *1 (-646 *5 *6)) (-4 *6 (-477))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-582)) (-4 *3 (-977 *7 *5 *6)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *3) (|:| |radicand| (-658 *3)))) (-5 *1 (-981 *5 *6 *7 *3 *8)) (-5 *4 (-790)) (-4 *8 (-13 (-388) (-10 -8 (-15 -1448 (*3 $)) (-15 -1456 (*3 $)) (-15 -1683 ($ *3)))))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-980 *3))) (-4 *3 (-477)) (-5 *1 (-385 *3 *4)) (-14 *4 (-658 (-1191))))) ((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-475 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-1173)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-475 *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-1173)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-475 *4 *5 *6 *7)))) ((*1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-977 *3 *5 *6)) (-4 *3 (-388)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-584 *3 *4 *5 *6 *7)) (-14 *4 (-658 (-1191))))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-802 *3 (-879 *4)))) (-4 *3 (-477)) (-14 *4 (-658 (-1191))) (-5 *1 (-643 *3 *4))))) 
+(((*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1055 *5 *6 *7 *3))) (-5 *1 (-1055 *5 *6 *7 *3)) (-4 *3 (-1089 *5 *6 *7)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-658 *6)) (-4 *1 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1094 *3 *4 *5 *2)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) ((*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1160 *5 *6 *7 *3))) (-5 *1 (-1160 *5 *6 *7 *3)) (-4 *3 (-1089 *5 *6 *7))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-592)) (-5 *2 (-658 (-658 (-237)))) (-5 *1 (-1222))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-141))))) 
+(((*1 *2 *1 *3 *3) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-625 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1225)) (-5 *2 (-1285))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *2 (-13 (-430) (-1065 *5) (-388) (-1211) (-301))) (-5 *1 (-468 *5 *3 *2)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-206)))) ((*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-316)))) ((*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-321))))) 
+(((*1 *2) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-557 *3)) (-4 *3 (-13 (-743) (-25)))))) 
+(((*1 *1 *2 *1) (-12 (-4 *1 (-21)) (-5 *2 (-592)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-790)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-25)) (-5 *2 (-944)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-237)) (-5 *1 (-179)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-944)) (-5 *1 (-179)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211))) (-5 *1 (-241 *3)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-252 *3 *2)) (-4 *2 (-1225)) (-4 *2 (-743)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-252 *3 *2)) (-4 *2 (-1225)) (-4 *2 (-743)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1131)) (-4 *2 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1131)) (-4 *2 (-1225)))) ((*1 *1 *2 *3) (-12 (-4 *1 (-342 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-158)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-386 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-386 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-407 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-869)))) ((*1 *1 *2 *3) (-12 (-4 *1 (-408 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-1119)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-4 *6 (-252 (-1699 *3) (-790))) (-14 *7 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *6)) (-2 (|:| -1825 *5) (|:| -3215 *6)))) (-5 *1 (-487 *3 *4 *5 *6 *7 *2)) (-4 *5 (-869)) (-4 *2 (-977 *4 *6 (-879 *3))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-373)) (-5 *1 (-556 *3)))) ((*1 *1 *1 *1) (-5 *1 (-565))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-618 *2)) (-4 *2 (-1075)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-618 *2)) (-4 *2 (-1075)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-661 *2)) (-4 *2 (-1082)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-1 *7 *5)) (-5 *1 (-700 *5 *6 *7)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1119)) (-4 *4 (-1075)) (-5 *1 (-701 *3 *4)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-704 *3 *2 *4)) (-4 *3 (-1075)) (-4 *2 (-399 *3)) (-4 *4 (-399 *3)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-704 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *2 (-399 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) ((*1 *1 *1 *1) (-4 *1 (-737))) ((*1 *1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-592)) (-4 *4 (-388)) (-4 *5 (-665 *4)) (-5 *2 (-258 *1)) (-4 *1 (-947 *4 *5)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1280 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-582)) (-5 *1 (-998 *3 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1081 *2)) (-4 *2 (-1082)))) ((*1 *1 *1 *1) (-4 *1 (-1131))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1140 *3 *4 *2 *5)) (-4 *4 (-1075)) (-4 *2 (-252 *3 *4)) (-4 *5 (-252 *3 *4)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-1140 *3 *4 *5 *2)) (-4 *4 (-1075)) (-4 *5 (-252 *3 *4)) (-4 *2 (-252 *3 *4)))) ((*1 *1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-869)) (-5 *1 (-1143 *3 *4 *2)) (-4 *2 (-977 *3 (-558 *4) *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-971 (-237))) (-5 *3 (-237)) (-5 *1 (-1222)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-743)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-743)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-1278 *3)) (-4 *3 (-1225)) (-4 *3 (-21)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1295 *3 *2)) (-4 *3 (-869)) (-4 *2 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-1301 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-865))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1187 *7)) (-4 *7 (-977 *6 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-5 *2 (-1187 *6)) (-5 *1 (-340 *4 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-141))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-1285)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) ((*1 *2) (-12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-141)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-5 *1 (-679 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *9 (-947 *3 *8)))) ((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-5 *2 (-141)) (-5 *1 (-679 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *9 (-947 *3 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| |val| (-658 *8)) (|:| -2165 *9)))) (-5 *4 (-790)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-1285)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| |val| (-658 *8)) (|:| -2165 *9)))) (-5 *4 (-790)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-1285)) (-5 *1 (-1159 *5 *6 *7 *8 *9))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-1251 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-386 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-790)) (-5 *1 (-412 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *2 (-23)) (-5 *1 (-662 *4 *2 *5)) (-4 *4 (-1119)) (-14 *5 *2))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-790)) (-5 *1 (-841 *4)) (-4 *4 (-869))))) 
+(((*1 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-944)) (-5 *1 (-1058 *2)) (-4 *2 (-13 (-1119) (-10 -8 (-15 -3300 ($ $ $)))))))) 
+(((*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-592)) (-4 *4 (-1075)) (-5 *1 (-1175 *4)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-1191))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-176 *3 *4 *5)) (-14 *3 *2) (-4 *4 (-388)) (-14 *5 (-1022 *3 *4))))) 
+(((*1 *1) (-5 *1 (-163)))) 
+(((*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-638 *4 *2)) (-4 *2 (-13 (-1211) (-987) (-29 *4)))))) 
+(((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-179))))) 
+(((*1 *2 *3 *4 *4 *3 *3 *5) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-1187 *3)) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-588 *6 *3 *7)) (-4 *7 (-1119)))) ((*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-433 (-1187 *3))) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-588 *6 *3 *7)) (-4 *7 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 *5)) (-4 *5 (-1255 *3)) (-4 *3 (-323)) (-5 *2 (-141)) (-5 *1 (-481 *3 *5))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-1280 *6)) (-5 *1 (-356 *3 *4 *5 *6)) (-4 *6 (-362 *3 *4 *5))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-497)) (-5 *4 (-944)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (-12 (-5 *3 (-592)) (-5 *5 (-141)) (-5 *6 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-658 (-658 (-658 *5)))) (-5 *3 (-1 (-141) *5 *5)) (-5 *4 (-658 *5)) (-4 *5 (-869)) (-5 *1 (-1197 *5))))) 
+(((*1 *1 *1 *1) (-4 *1 (-167))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1191))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1163 *3)) (-4 *3 (-1225)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE)))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-774)))) ((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-73 IMAGE)))) (-5 *8 (-414)) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) ((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-585 *3)) (-4 *3 (-574))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-725 *3)) (-5 *1 (-849 *2 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1187 *1)) (-5 *4 (-1191)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 *1)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-980 *1)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-658 *1)) (-4 *1 (-29 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *2 (-658 *1)) (-4 *1 (-29 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-658 (-1191))) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-1171 (-237))) (-5 *1 (-316))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-141)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1055 *5 *6 *7 *8))) (-5 *1 (-1055 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1160 *5 *6 *7 *8))) (-5 *1 (-1160 *5 *6 *7 *8))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869))) (-5 *2 (-191 *5)) (-5 *1 (-621 *4 *5 *3)) (-4 *5 (-13 (-456 *4) (-1030) (-1211))) (-4 *3 (-13 (-456 (-191 *4)) (-1030) (-1211)))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-141)) (-5 *5 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-132)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-230)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-521)))) ((*1 *1 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)) (-4 *2 (-323)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) ((*1 *1 *1) (-4 *1 (-1084)))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-971 *4)) (-4 *4 (-1075)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944))))) 
+(((*1 *2 *3 *2) (-12 (-5 *1 (-696 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-433 *2)) (-4 *2 (-1255 *5)) (-5 *1 (-829 *5 *2 *3 *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-670 *2)) (-4 *6 (-670 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-433 *2))) (-4 *2 (-1255 *5)) (-5 *1 (-829 *5 *2 *3 *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-670 *2)) (-4 *6 (-670 (-433 *2)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592))))) 
+(((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1173)) (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-179)))) ((*1 *2 *1) (-12 (-5 *2 (-179)) (-5 *1 (-896)))) ((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *2 *3) (-12 (-5 *1 (-696 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1173)) (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-1173)) (-5 *1 (-206)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877))))) 
+(((*1 *1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-953)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-953)))) ((*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *4 *5 *3 *6 *3) (-12 (-5 *3 (-592)) (-5 *5 (-191 (-237))) (-5 *6 (-1173)) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-444 *3)) (-4 *3 (-582)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4500 *4) (|:| -4525 (-592))))) (-4 *4 (-1255 (-592))) (-5 *2 (-790)) (-5 *1 (-467 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-456 *2)) (-4 *2 (-869)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) ((*1 *1 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582))))) 
+(((*1 *1 *1) (|partial| -12 (-5 *1 (-310 *2)) (-4 *2 (-743)) (-4 *2 (-1225))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-844)) (-5 *1 (-843))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-3 (-150) (-592))) (-5 *1 (-150))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |preimage| (-658 *3)) (|:| |image| (-658 *3)))) (-5 *1 (-927 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194))))) 
+(((*1 *1 *1) (-5 *1 (-1190))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-516 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-1075)) (-5 *2 (-980 *5)) (-5 *1 (-972 *4 *5))))) 
+(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-776))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-667 (-433 *5)))) (-5 *1 (-671 *4 *5)) (-5 *3 (-667 (-433 *5)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-1065 (-592)) (-477) (-654 (-592)))) (-5 *2 (-2 (|:| -3479 *3) (|:| |nconst| *3))) (-5 *1 (-595 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) ((*1 *2 *3) (-12 (-5 *2 (-1187 (-433 (-592)))) (-5 *1 (-970)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (-12 (-5 *3 (-1173)) (-5 *5 (-706 (-237))) (-5 *6 (-706 (-592))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-776))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *2 (-977 *3 *5 (-879 *4))) (-4 *5 (-252 (-1699 *4) (-790))) (-4 *6 (-999 *3)) (-4 *7 (-665 *3)) (-4 *8 (-947 *3 *7)) (-4 *9 (-257 *8)) (-4 *10 (-560 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-137)) (-5 *1 (-491 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2 *2) (-12 (-5 *2 (-264 *4 *3)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-5 *1 (-894 *3 *4 *5)) (-4 *5 (-137)))) ((*1 *2 *2) (-12 (-5 *2 (-264 *4 *3)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-5 *1 (-895 *3 *4 *5)) (-4 *5 (-137))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *3 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-658 *3)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (-4 *12 (-280 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 (-1171 *4) (-1171 *4))) (-5 *2 (-1171 *4)) (-5 *1 (-1303 *4)) (-4 *4 (-1225)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-658 (-1171 *5)) (-658 (-1171 *5)))) (-5 *4 (-592)) (-5 *2 (-658 (-1171 *5))) (-5 *1 (-1303 *5)) (-4 *5 (-1225))))) 
+(((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283))))) 
+(((*1 *1 *2 *2 *2 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 *5)) (-5 *4 (-1280 *5)) (-4 *5 (-388)) (-5 *2 (-141)) (-5 *1 (-684 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4626)))) (-5 *2 (-141)) (-5 *1 (-685 *5 *6 *4 *3)) (-4 *3 (-704 *5 *6 *4))))) 
+(((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-776))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-171)) (-4 *3 (-323)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1187 *9)) (-5 *4 (-658 *7)) (-4 *7 (-869)) (-4 *9 (-977 *8 *6 *7)) (-4 *6 (-815)) (-4 *8 (-323)) (-5 *2 (-658 (-790))) (-5 *1 (-759 *6 *7 *8 *9)) (-5 *5 (-790))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592))))) 
+(((*1 *2 *3 *4 *4 *5 *4 *4 *5) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-776))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *1) (-4 *1 (-373)))) 
+(((*1 *1 *1) (-5 *1 (-1087)))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *2 (-999 *3)) (-4 *7 (-665 *3)) (-4 *8 (-947 *3 *7)) (-4 *9 (-257 *8)) (-4 *10 (-137))))) 
+(((*1 *1) (-5 *1 (-350)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239))))) 
+(((*1 *2) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-790)) (-5 *1 (-361 *3 *4 *5 *6)) (-4 *3 (-362 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-790))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-332 (-592))) (-5 *1 (-507 *3)) (-4 *3 (-13 (-373) (-633 (-592))))))) 
+(((*1 *2 *1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-1173)) (-5 *1 (-1281)))) ((*1 *2 *1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1281)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1281)))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-1173)) (-5 *1 (-1282)))) ((*1 *2 *1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1282)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1282))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-862 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388))))) 
+(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-13 (-388) (-171) (-1065 (-592)))) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -3191 (-433 *5)) (|:| |coeff| (-433 *5)))) (-5 *1 (-596 *4 *5)) (-5 *3 (-433 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-350))))) 
+(((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *2)) (-5 *4 (-1 (-141) *2 *2)) (-5 *1 (-1232 *2)) (-4 *2 (-1119)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-1119)) (-4 *2 (-869)) (-5 *1 (-1232 *2))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (-5 *1 (-206))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-146 *3)) (-14 *3 *2))) ((*1 *1 *1) (-12 (-5 *1 (-146 *2)) (-14 *2 (-592)))) ((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-892 *3)) (-14 *3 *2))) ((*1 *1 *1) (-12 (-5 *1 (-892 *2)) (-14 *2 (-592)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-14 *3 *2) (-5 *1 (-893 *3 *4)) (-4 *4 (-890 *3)))) ((*1 *1 *1) (-12 (-14 *2 (-592)) (-5 *1 (-893 *2 *3)) (-4 *3 (-890 *2)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-1241 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1270 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-1241 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-1270 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-118))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-323)) (-5 *2 (-790)) (-5 *1 (-481 *5 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |%expansion| (-329 *5 *3 *6 *7)) (|:| |%problem| (-2 (|:| |func| (-1173)) (|:| |prob| (-1173)))))) (-5 *1 (-446 *5 *3 *6 *7)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-14 *6 (-1191)) (-14 *7 *3)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))) (-5 *4 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))) (-5 *4 (-433 (-592))))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-433 (-592))) (-5 *2 (-658 (-2 (|:| -1961 *5) (|:| -1954 *5)))) (-5 *1 (-1047 *3)) (-4 *3 (-1255 (-592))) (-5 *4 (-2 (|:| -1961 *5) (|:| -1954 *5))))) ((*1 *2 *3) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 (-433 (-592)))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 (-433 (-592)))) (-5 *4 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-433 (-592))) (-5 *2 (-658 (-2 (|:| -1961 *4) (|:| -1954 *4)))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-433 (-592))) (-5 *2 (-658 (-2 (|:| -1961 *5) (|:| -1954 *5)))) (-5 *1 (-1048 *3)) (-4 *3 (-1255 *5)) (-5 *4 (-2 (|:| -1961 *5) (|:| -1954 *5)))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-1280 *3)) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-497)) (-5 *4 (-944)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *1 *1 *1) (-5 *1 (-141))) ((*1 *1 *1 *1) (-4 *1 (-153)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (|has| *2 (-6 (-4627 "*"))) (-4 *2 (-1075)))) ((*1 *2 *3) (-12 (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-194)) (-5 *1 (-705 *2 *4 *5 *3)) (-4 *3 (-704 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)) (|has| *2 (-6 (-4627 "*"))) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-625 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1225)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-589)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *1) (-5 *1 (-163))) ((*1 *1 *1) (-5 *1 (-168))) ((*1 *1 *1) (-4 *1 (-1158)))) 
+(((*1 *1 *1 *1 *2) (|partial| -12 (-5 *2 (-141)) (-5 *1 (-617 *3)) (-4 *3 (-1075))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-143)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-143)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-268 *4 *3 *5 *6)) (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-284 *3)) (-4 *3 (-869)) (-5 *2 (-790))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-611 *4)) (-4 *4 (-373))))) 
+(((*1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *6 (-908 *5)) (-5 *2 (-907 *5 *6 (-658 *6))) (-5 *1 (-909 *5 *6 *4)) (-5 *3 (-658 *6)) (-4 *4 (-633 (-914 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-5 *2 (-658 (-310 *3))) (-5 *1 (-909 *5 *3 *4)) (-4 *3 (-1065 (-1191))) (-4 *3 (-908 *5)) (-4 *4 (-633 (-914 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-5 *2 (-658 (-310 (-980 *3)))) (-5 *1 (-909 *5 *3 *4)) (-4 *3 (-1075)) (-3252 (-4 *3 (-1065 (-1191)))) (-4 *3 (-908 *5)) (-4 *4 (-633 (-914 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-5 *2 (-911 *5 *3)) (-5 *1 (-909 *5 *3 *4)) (-3252 (-4 *3 (-1065 (-1191)))) (-3252 (-4 *3 (-1075))) (-4 *3 (-908 *5)) (-4 *4 (-633 (-914 *5)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *3)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 (-658 *7) (-658 *7))) (-5 *2 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-347 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-549 *3 *4)) (-14 *4 (-592))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *4 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1255 *4))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-281 *3)) (-4 *3 (-1119)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-281 *3)) (-4 *3 (-1119)))) ((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-561 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-561 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-5 *2 (-141)) (-5 *1 (-562 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *10 (-257 *9)) (-4 *11 (-137)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-5 *1 (-562 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *10 (-257 *9)) (-4 *11 (-137)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-882 *3)) (-14 *3 (-887)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-884 *3)) (-4 *3 (-373)))) ((*1 *2 *1) (-12 (-4 *1 (-885)) (-5 *2 (-877)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-887))))) 
+(((*1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (-12 (-5 *1 (-1246 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1 (-237) (-237) (-237) (-237))) (-5 *2 (-1 (-971 (-237)) (-237) (-237))) (-5 *1 (-713))))) 
+(((*1 *2 *3 *4 *2 *2 *5) (|partial| -12 (-5 *2 (-862 *4)) (-5 *3 (-631 *4)) (-5 *5 (-141)) (-4 *4 (-13 (-1211) (-29 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-236 *6 *4))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-1280 *4)) (-4 *4 (-654 (-592))) (-5 *2 (-1280 (-592))) (-5 *1 (-1305 *4))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-5 *1 (-677 *3))))) 
+(((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1054 (-862 (-592)))) (-5 *3 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *4)))) (-4 *4 (-1075)) (-5 *1 (-617 *4))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-193))))) 
+(((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-706 (-433 *4)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-592)) (-5 *1 (-1208 *4)) (-4 *4 (-1075))))) 
+(((*1 *2 *3 *4 *3 *4 *4 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) ((*1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-405)))) ((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-405))))) 
+(((*1 *1 *2 *3) (-12 (-5 *1 (-453 *3 *2)) (-4 *3 (-13 (-194) (-43 (-433 (-592))))) (-4 *2 (-13 (-869) (-21)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-489))))) 
+(((*1 *2 *3 *4 *3 *5 *5 *3 *5 *4) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-1235)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-2 (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (-4 *1 (-362 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-3 (-1187 *4) (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137))))))) (-5 *1 (-370 *4)) (-4 *4 (-373))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *2 (-2 (|:| |additions| (-592)) (|:| |multiplications| (-592)) (|:| |exponentiations| (-592)) (|:| |functionCalls| (-592)))) (-5 *1 (-321))))) 
+(((*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-977 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *1)))) (-4 *1 (-1094 *4 *5 *6 *3)))) ((*1 *1 *1) (-4 *1 (-1235))) ((*1 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-1258 *3 *2)) (-4 *2 (-13 (-1255 *3) (-582) (-10 -8 (-15 -3548 ($ $ $)))))))) 
+(((*1 *2 *3) (-12 (-4 *2 (-1255 *4)) (-5 *1 (-831 *4 *2 *3 *5)) (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-670 *2)) (-4 *5 (-670 (-433 *2)))))) 
+(((*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-980 (-592))) (-5 *2 (-658 *1)) (-4 *1 (-1040)))) ((*1 *2 *3) (-12 (-5 *3 (-980 (-433 (-592)))) (-5 *2 (-658 *1)) (-4 *1 (-1040)))) ((*1 *2 *3) (-12 (-5 *3 (-980 *1)) (-4 *1 (-1040)) (-5 *2 (-658 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 (-592))) (-5 *2 (-658 *1)) (-4 *1 (-1040)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 (-433 (-592)))) (-5 *2 (-658 *1)) (-4 *1 (-1040)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 *1)) (-4 *1 (-1040)) (-5 *2 (-658 *1)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-658 *1)) (-4 *1 (-1091 *4 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-2 (|:| -1575 (-1171 *4)) (|:| -1581 (-1171 *4)))) (-5 *1 (-1177 *4)) (-5 *3 (-1171 *4))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1137)) (-5 *2 (-1285)) (-5 *1 (-853))))) 
+(((*1 *2 *3 *3 *4 *3 *5 *3 *5 *4 *5 *5 *4 *4 *5 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-1282)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-944)) (-4 *5 (-869)) (-5 *2 (-658 (-688 *5))) (-5 *1 (-688 *5))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-3 (-141) (-658 *1))) (-4 *1 (-1094 *4 *5 *6 *3))))) 
+(((*1 *2 *3 *4 *5 *6 *3 *3 *3 *3 *6 *3 *7 *8) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-141)) (-5 *6 (-237)) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-73 APROD)))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-78 MSOLVE)))) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-592)) (-5 *2 (-855 (-237))) (-5 *1 (-239)) (-5 *4 (-237))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *5 *4)) (-5 *1 (-700 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-141)) (-5 *2 (-1173)) (-5 *1 (-57))))) 
+(((*1 *2 *3 *4 *3 *4 *5 *3 *4 *3 *3 *3 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-658 (-2 (|:| |k| *4) (|:| |c| *3)))))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |k| (-915 *3)) (|:| |c| *4)))) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-688 *3))) (-5 *1 (-915 *3)) (-4 *3 (-869))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-13 (-867) (-388))) (-5 *2 (-141)) (-5 *1 (-1085 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *3 (-658 (-592))) (-5 *1 (-905))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-804 *2)) (-4 *2 (-582)) (-4 *2 (-1075)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) ((*1 *2 *3 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *1)))) (-4 *1 (-1094 *4 *5 *6 *3))))) 
+(((*1 *2 *3 *3 *4 *4 *4 *4 *3 *3 *3 *3 *5 *3 *6) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-75 APROD)))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-775))))) 
+(((*1 *2) (-12 (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5))))) 
+(((*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-790)) (-5 *4 (-944)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-790)) (-5 *4 (-944)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *2 *1) (-12 (-5 *2 (-658 *6)) (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-986 (-237))) (-5 *1 (-135)) (-5 *3 (-237))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1212 *3))) (-5 *1 (-1212 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-790)) (-4 *4 (-13 (-582) (-171))) (-5 *1 (-1249 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-162 *5 *6 *7)) (-14 *5 (-592)) (-14 *6 (-790)) (-4 *7 (-194)) (-4 *8 (-194)) (-5 *2 (-162 *5 *6 *8)) (-5 *1 (-161 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *9)) (-4 *9 (-1075)) (-4 *5 (-869)) (-4 *6 (-815)) (-4 *8 (-1075)) (-4 *2 (-977 *9 *7 *5)) (-5 *1 (-745 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-815)) (-4 *4 (-977 *8 *6 *5))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *2 (-257 *9)) (-4 *10 (-137))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-625 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1225)) (-5 *2 (-658 *3))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -1544 *3) (|:| |coef1| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-658 *4)))) (-5 *2 (-658 (-658 *4))) (-5 *1 (-1197 *4)) (-4 *4 (-869))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) ((*1 *1) (-4 *1 (-1165)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1191)) (|:| |arrayIndex| (-658 (-980 (-592)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1191)) (|:| |rand| (-877)) (|:| |ints2Floats?| (-141)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1190)) (|:| |thenClause| (-350)) (|:| |elseClause| (-350)))) (|:| |returnBranch| (-2 (|:| -2943 (-141)) (|:| -2324 (-2 (|:| |ints2Floats?| (-141)) (|:| -1564 (-877)))))) (|:| |blockBranch| (-658 (-350))) (|:| |commentBranch| (-658 (-1173))) (|:| |callBranch| (-1173)) (|:| |forBranch| (-2 (|:| -2166 (-1111 (-980 (-592)))) (|:| |span| (-980 (-592))) (|:| |body| (-350)))) (|:| |labelBranch| (-1137)) (|:| |loopBranch| (-2 (|:| |switch| (-1190)) (|:| |body| (-350)))) (|:| |commonBranch| (-2 (|:| -4095 (-1191)) (|:| |contents| (-658 (-1191))))) (|:| |printBranch| (-658 (-877))))) (-5 *1 (-350))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-944)) (-4 *5 (-869)) (-5 *2 (-64 (-658 (-688 *5)))) (-5 *1 (-688 *5))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *1 (-139 *4 *5 *2 *6 *3)) (-4 *2 (-346 *4 *6)) (-4 *3 (-137))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 (-706 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-388)) (-5 *1 (-918 *2 *4)) (-4 *2 (-1255 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-658 *4))))) 
+(((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *6 (-1173)) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-5 *2 (-658 *3)) (-5 *1 (-973 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *2 (-658 (-191 *4))) (-5 *1 (-178 *3 *4)) (-4 *3 (-1255 (-191 (-592)))) (-4 *4 (-13 (-388) (-867))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-658 (-191 *4))) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-658 (-191 *4))) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4)))))) 
+(((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *6 (-1173)) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-444 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-1075)) (-5 *2 (-658 *6)) (-5 *1 (-469 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 (-405))) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-658 (-405))) (-5 *1 (-497)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-405))) (-5 *1 (-497)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-896)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)) (-4 *2 (-456 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1111 *2)) (-4 *2 (-456 *4)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1111 *1)) (-4 *1 (-182)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-182)) (-5 *2 (-1191)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-494 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1298 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) (-5 *1 (-278)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) ((*1 *2 *1 *3 *3 *4 *4 *4) (-12 (-5 *3 (-592)) (-5 *4 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) (-5 *2 (-1285)) (-5 *1 (-1282)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |theta| (-237)) (|:| |phi| (-237)) (|:| -4086 (-237)) (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |scaleZ| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)))) (-5 *1 (-1282)))) ((*1 *2 *1 *3 *3 *3 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-323)) (-5 *1 (-481 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-323)) (-5 *1 (-486 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-323)) (-14 *4 *3) (-14 *5 (-1 *3 *3 (-790))) (-5 *1 (-568 *3 *2 *4 *5)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *3 *2 *4 *5) (-12 (-5 *2 (-658 *3)) (-5 *5 (-944)) (-4 *3 (-1255 *4)) (-4 *4 (-323)) (-5 *1 (-486 *4 *3))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-658 (-658 (-592)))) (-5 *1 (-1000)) (-5 *3 (-658 (-592)))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-141)) (-5 *1 (-134)))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (|has| *1 (-6 -4616)) (-4 *1 (-430)))) ((*1 *2) (-12 (-4 *1 (-430)) (-5 *2 (-944))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-582)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-1250 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1187 *4))) (-4 *4 (-388)) (-5 *2 (-2 (|:| |zeros| (-658 *4)) (|:| -2378 (-592)))) (-5 *1 (-1071 *4))))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-780)))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-664 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-191 (-237)))) (-5 *1 (-166)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-1280 *3))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-658 (-1280 *4))) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-4 *3 (-582)) (-5 *2 (-658 (-1280 *3)))))) 
+(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1173)) (-5 *2 (-793)) (-5 *1 (-143))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239))))) 
+(((*1 *1 *1 *2) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *1 *1) (-5 *1 (-53))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-64 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-63 *5 *2)))) ((*1 *2 *3 *1 *2 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1119)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)))) ((*1 *2 *3 *1 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)))) ((*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-2 (|:| -3489 (-1187 *4)) (|:| |deg| (-944)))) (-5 *1 (-233 *4 *5)) (-5 *3 (-1187 *4)) (-4 *5 (-13 (-582) (-869))))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *6 *2)) (-5 *4 (-254 *5 *6)) (-14 *5 (-790)) (-4 *6 (-1225)) (-4 *2 (-1225)) (-5 *1 (-253 *5 *6 *2)))) ((*1 *1 *2 *3) (-12 (-4 *4 (-194)) (-5 *1 (-306 *4 *2 *3 *5 *6 *7)) (-4 *2 (-1255 *4)) (-4 *3 (-23)) (-14 *5 (-1 *2 *2 *3)) (-14 *6 (-1 (-3 *3 "failed") *3 *3)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-332 *2)) (-4 *2 (-582)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-4 *1 (-355 *2 *3 *4 *5)) (-4 *2 (-388)) (-4 *3 (-1255 *2)) (-4 *4 (-1255 (-433 *3))) (-4 *5 (-362 *2 *3 *4)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-397 *5 *4 *2 *6)) (-4 *4 (-399 *5)) (-4 *6 (-399 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1119)) (-4 *2 (-1119)) (-5 *1 (-449 *5 *4 *2 *6)) (-4 *4 (-451 *5)) (-4 *6 (-451 *2)))) ((*1 *1 *1) (-5 *1 (-528))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-658 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-656 *5 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1075)) (-4 *2 (-1075)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-4 *8 (-399 *2)) (-4 *9 (-399 *2)) (-5 *1 (-702 *5 *6 *7 *4 *2 *8 *9 *10)) (-4 *4 (-704 *5 *6 *7)) (-4 *10 (-704 *2 *8 *9)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-728 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-729 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-433 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-388)) (-4 *3 (-194)) (-4 *1 (-741 *3 *4)))) ((*1 *1 *2) (-12 (-4 *3 (-194)) (-4 *1 (-741 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-947 *4 *5)) (-4 *4 (-388)) (-4 *5 (-665 *4)) (-5 *2 (-258 *1)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-986 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-985 *5 *2)))) ((*1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1062 *3 *4 *5 *2 *6)) (-4 *2 (-977 *3 *4 *5)) (-14 *6 (-658 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *7 *2)) (-4 *7 (-1075)) (-4 *2 (-1075)) (-14 *5 (-790)) (-14 *6 (-790)) (-4 *8 (-252 *6 *7)) (-4 *9 (-252 *5 *7)) (-4 *10 (-252 *6 *2)) (-4 *11 (-252 *5 *2)) (-5 *1 (-1080 *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (-4 *4 (-1078 *5 *6 *7 *8 *9)) (-4 *12 (-1078 *5 *6 *2 *10 *11)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1171 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-1169 *5 *2)))) ((*1 *2 *2 *1 *3 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *4 (-1 (-141) *2 *2)) (-4 *1 (-1219 *5 *6 *7 *2)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *2 (-1089 *5 *6 *7)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1280 *5)) (-4 *5 (-1225)) (-4 *2 (-1225)) (-5 *1 (-1279 *5 *2))))) 
+(((*1 *2 *3 *3 *4 *5 *3 *3 *4 *4 *4 *6) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5 *4)) (-4 *5 (-1119)) (-4 *4 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *5)) (-5 *1 (-700 *5 *4 *6))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-928 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-1255 *4)) (-5 *2 (-444 (-1187 *5))) (-5 *1 (-929 *4 *5)) (-5 *3 (-1187 *5))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-323)) (-5 *2 (-141))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-405)))) ((*1 *1 *1 *1) (-4 *1 (-574))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) ((*1 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-790))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-631 *6)) (-4 *6 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-1187 (-433 (-1187 *6)))) (-5 *1 (-588 *5 *6 *7)) (-5 *3 (-1187 *6)) (-4 *7 (-1119)))) ((*1 *2 *1) (-12 (-4 *2 (-1255 *3)) (-5 *1 (-729 *3 *2)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-4 *1 (-741 *3 *2)) (-4 *3 (-194)) (-4 *2 (-1255 *3)))) ((*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| -12 (-5 *4 (-1187 *11)) (-5 *6 (-658 *10)) (-5 *7 (-658 (-790))) (-5 *8 (-658 *11)) (-4 *10 (-869)) (-4 *11 (-323)) (-4 *9 (-815)) (-4 *5 (-977 *11 *9 *10)) (-5 *2 (-658 (-1187 *5))) (-5 *1 (-759 *9 *10 *11 *5)) (-5 *3 (-1187 *5)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) ((*1 *2 *1) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) ((*1 *2 *1) (-12 (-4 *2 (-977 *3 *4 *5)) (-5 *1 (-1062 *3 *4 *5 *2 *6)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-14 *6 (-658 *2))))) 
+(((*1 *2 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-971 *5)) (-4 *5 (-1075)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-790)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)) (-4 *5 (-1075)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-971 *5)) (-4 *5 (-1075)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-516 *3 *4))) (-14 *3 (-658 (-1191))) (-4 *4 (-477)) (-5 *1 (-646 *3 *4))))) 
+(((*1 *1) (-5 *1 (-168))) ((*1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-790)) (-4 *1 (-245 *4)) (-4 *4 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-245 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-247)) (-5 *2 (-790)))) ((*1 *1 *1) (-4 *1 (-247))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-284 *3)) (-4 *3 (-869)))) ((*1 *1 *1) (-12 (-4 *1 (-284 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *4)) (-4 *4 (-1255 *3)))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-388) (-171))) (-5 *1 (-425 *2 *3)) (-4 *3 (-1255 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-503 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *2 *1 *3) (-12 (-4 *2 (-388)) (-4 *2 (-922 *3)) (-5 *1 (-609 *2)) (-5 *3 (-1191)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-609 *2)) (-4 *2 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-877)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *4)) (-5 *3 (-658 (-790))) (-4 *1 (-922 *4)) (-4 *4 (-1119)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-922 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *1 (-922 *3)) (-4 *3 (-1119)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-922 *2)) (-4 *2 (-1119)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1229)) (-5 *3 (-592)) (-5 *1 (-982)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-1229)) (-5 *3 (-790)) (-5 *4 (-592)) (-5 *1 (-982)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1181 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1188 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1189 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 (QUOTE |x|))) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1264 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-1191))) (-5 *2 (-658 (-658 *5))) (-5 *1 (-406 *5)) (-4 *5 (-13 (-867) (-388))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-592)))) (-5 *2 (-658 *4)) (-5 *1 (-406 *4)) (-4 *4 (-13 (-867) (-388)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-171))) (-5 *2 (-658 *3)) (-5 *1 (-1249 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1128 *5 *6 *7 *8)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-614 *5 *6 *7 *8 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-5 *2 (-497)) (-5 *1 (-1281))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *2 (-13 (-456 *4) (-908 *3) (-633 (-914 *3)))) (-5 *1 (-1097 *3 *4 *2)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))))) ((*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-1180 *2 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-237))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1225)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 *7)) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) (-790))) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-5 *2 (-658 (-1280 *5))) (-5 *1 (-586 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-999 *5)) (-4 *3 (-257 *11))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-1021 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-164 *4 *5 *3)) (-4 *3 (-399 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-1021 *4)) (-5 *2 (-2 (|:| |num| *6) (|:| |den| *4))) (-5 *1 (-536 *4 *5 *6 *3)) (-4 *6 (-399 *4)) (-4 *3 (-399 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-706 *5)) (-4 *5 (-1021 *4)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |num| (-706 *4)) (|:| |den| *4))) (-5 *1 (-709 *4 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-2 (|:| -2042 *7) (|:| |rh| (-658 (-433 *6))))) (-5 *1 (-829 *5 *6 *7 *3)) (-5 *4 (-658 (-433 *6))) (-4 *7 (-670 *6)) (-4 *3 (-670 (-433 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-1021 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-1248 *4 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-658 (-706 (-592)))) (-5 *1 (-1129))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-405)))) ((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-405))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 G)))) (-5 *2 (-1063)) (-5 *1 (-767))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -4509 *1) (|:| -4612 *1) (|:| |associate| *1))) (-4 *1 (-582))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-261 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-867)) (-4 *4 (-388)) (-5 *2 (-790)) (-5 *1 (-973 *4 *5)) (-4 *5 (-1255 *4))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 (-706 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-188 *2)) (-4 *2 (-194)) (-4 *2 (-582)))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-346 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *2 (-582)))) ((*1 *1 *1 *1) (|partial| -4 *1 (-582))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-582)))) ((*1 *1 *1 *1) (|partial| -5 *1 (-790))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-582)))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-582)) (-5 *1 (-998 *3 *4)))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1078 *3 *4 *2 *5 *6)) (-4 *2 (-1075)) (-4 *5 (-252 *4 *2)) (-4 *6 (-252 *3 *2)) (-4 *2 (-582)))) ((*1 *2 *2 *2) (|partial| -12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1158)) (-5 *3 (-168)) (-5 *2 (-141))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1187 *1)) (-5 *3 (-1191)) (-4 *1 (-885)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1187 *1)) (-5 *3 (-1191)) (-4 *1 (-885)))) ((*1 *1 *2 *2 *3 *1 *4) (-12 (-5 *2 (-1187 (-887))) (-5 *3 (-944)) (-5 *4 (-1191)) (-5 *1 (-887))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *4)) (-4 *4 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-700 *4 *5 *6)) (-4 *5 (-1119))))) 
+(((*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1095 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1127 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3)))) 
+(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-1191)) (-5 *6 (-141)) (-4 *7 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-4 *3 (-13 (-1211) (-987) (-29 *7))) (-5 *2 (-3 (|:| |f1| (-862 *3)) (|:| |f2| (-658 (-862 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-231 *7 *3)) (-5 *5 (-862 *3))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *5 *5 *5 *3 *5 *5 *3 *6 *3 *3 *3) (-12 (-5 *5 (-706 (-237))) (-5 *6 (-706 (-592))) (-5 *3 (-592)) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-658 *8))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-1113 (-237))) (-5 *2 (-954)) (-5 *1 (-952 *3)) (-4 *3 (-633 (-565))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-954)) (-5 *1 (-952 *3)) (-4 *3 (-633 (-565))))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *1 (-954)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1072 *4 *5)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-658 (-658 (-1051 (-433 *4))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *4))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3548 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 *7 *7)) (-5 *5 (-658 (-433 *7))) (-4 *7 (-1255 *6)) (-5 *3 (-433 *7)) (-4 *6 (-388)) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-602 *6 *7))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *2 (-1187 (-1187 *4))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *7 (-999 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-790)) (-5 *1 (-613))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-278)))) ((*1 *1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-278))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-5 *2 (-2 (|:| A (-706 *5)) (|:| |eqs| (-658 (-2 (|:| C (-706 *5)) (|:| |g| (-1280 *5)) (|:| -2042 *6) (|:| |rh| *5)))))) (-5 *1 (-835 *5 *6)) (-5 *3 (-706 *5)) (-5 *4 (-1280 *5)) (-4 *6 (-670 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-670 *5)) (-5 *2 (-2 (|:| -3253 (-706 *6)) (|:| |vec| (-1280 *5)))) (-5 *1 (-835 *5 *6)) (-5 *3 (-706 *6)) (-5 *4 (-1280 *5))))) 
+(((*1 *2 *3 *4) (-12 (-4 *4 (-881)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-337 *4)) (-5 *3 (-1187 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-886)) (-5 *2 (-444 (-1187 *4))) (-5 *1 (-339 *4)) (-5 *3 (-1187 *4))))) 
+(((*1 *2 *2 *2 *2 *3) (-12 (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-67 *3)) (-14 *3 (-1191)))) ((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-74 *3)) (-14 *3 (-1191)))) ((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-77 *3)) (-14 *3 (-1191)))) ((*1 *2 *1) (-12 (-4 *1 (-421)) (-5 *2 (-1285)))) ((*1 *2 *3) (-12 (-5 *3 (-414)) (-5 *2 (-1285)) (-5 *1 (-423)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-877)) (-5 *2 (-1285)) (-5 *1 (-1152)))) ((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-1152)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-877))) (-5 *2 (-1285)) (-5 *1 (-1152))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-405))) (-5 *5 (-1173)) (-5 *6 (-658 (-278))) (-5 *2 (-1285)) (-5 *1 (-480)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-405))) (-5 *5 (-1173)) (-5 *2 (-1285)) (-5 *1 (-480)))) ((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-405))) (-5 *5 (-1173)) (-5 *6 (-658 (-278))) (-5 *2 (-1285)) (-5 *1 (-480)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-405))) (-5 *5 (-1173)) (-5 *2 (-1285)) (-5 *1 (-480))))) 
+(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-808))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-373)) (-5 *2 (-2 (|:| |cont| *5) (|:| -2033 (-658 (-2 (|:| |irr| *3) (|:| -1777 (-592))))))) (-5 *1 (-229 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-452 *4 *2)) (-4 *2 (-13 (-1211) (-29 *4))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-171)) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-332 *5)) (-5 *1 (-612 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-417))))) 
+(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-880 *4 *5 *6 *7)) (-4 *4 (-1075)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 *3)) (-14 *7 *3))) ((*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-1075)) (-4 *5 (-869)) (-4 *6 (-815)) (-14 *8 (-658 *5)) (-5 *2 (-1285)) (-5 *1 (-1290 *4 *5 *6 *7 *8 *9 *10)) (-4 *7 (-977 *4 *6 *5)) (-14 *9 (-658 *3)) (-14 *10 *3)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-658 *2))) (-4 *4 (-388)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))) (-5 *2 (-1063)) (-5 *1 (-321))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-323)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-472 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-1173)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-323)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-472 *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-1173)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-323)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-472 *4 *5 *6 *7))))) 
+(((*1 *1 *2 *2 *2) (-12 (-5 *2 (-1173)) (-4 *1 (-415))))) 
+(((*1 *2 *3 *3 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-790)) (-5 *1 (-474 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-1280 (-658 (-2 (|:| -2324 (-932 *3)) (|:| -1825 (-1137)))))) (-5 *1 (-375 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) ((*1 *2) (-12 (-5 *2 (-1280 (-658 (-2 (|:| -2324 *3) (|:| -1825 (-1137)))))) (-5 *1 (-376 *3 *4)) (-4 *3 (-373)) (-14 *4 (-3 (-1187 *3) *2)))) ((*1 *2) (-12 (-5 *2 (-1280 (-658 (-2 (|:| -2324 *3) (|:| -1825 (-1137)))))) (-5 *1 (-377 *3 *4)) (-4 *3 (-373)) (-14 *4 (-944))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-1152)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-877))) (-5 *2 (-1285)) (-5 *1 (-1152))))) 
+(((*1 *1 *1 *1) (-5 *1 (-141))) ((*1 *1 *1 *1) (-4 *1 (-153))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-414)) (-5 *2 (-1285)) (-5 *1 (-417)))) ((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-417))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1113 (-862 (-237)))) (-5 *1 (-321))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-191 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1138 *2)) (-4 *2 (-1225)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-592)) (-5 *1 (-282 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-141)) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-1191)) (|:| -3552 (-463))))) (-5 *1 (-1195))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1198 (-658 *4))) (-4 *4 (-869)) (-5 *2 (-658 (-658 *4))) (-5 *1 (-1197 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-160)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-855 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-862 *3)) (-4 *3 (-1119))))) 
+(((*1 *2) (|partial| -12 (-4 *4 (-1235)) (-4 *5 (-1255 (-433 *2))) (-4 *2 (-1255 *4)) (-5 *1 (-361 *3 *4 *2 *5)) (-4 *3 (-362 *4 *2 *5)))) ((*1 *2) (|partial| -12 (-4 *1 (-362 *3 *2 *4)) (-4 *3 (-1235)) (-4 *4 (-1255 (-433 *2))) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-405)) (-5 *2 (-237)) (-5 *1 (-1283)))) ((*1 *2) (-12 (-5 *2 (-237)) (-5 *1 (-1283))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-739)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-743)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3) (-12 (|has| *6 (-6 -4626)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-658 *6)) (-5 *1 (-553 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) ((*1 *2 *3) (-12 (|has| *9 (-6 -4626)) (-4 *4 (-582)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-4 *7 (-1021 *4)) (-4 *8 (-399 *7)) (-4 *9 (-399 *7)) (-5 *2 (-658 *6)) (-5 *1 (-554 *4 *5 *6 *3 *7 *8 *9 *10)) (-4 *3 (-704 *4 *5 *6)) (-4 *10 (-704 *7 *8 *9)))) ((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-582)) (-5 *2 (-658 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-658 *6)) (-5 *1 (-705 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-4 *5 (-582)) (-5 *2 (-658 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1065 (-592))) (-4 *1 (-318)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-574)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-927 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-587))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1) (-12 (-4 *3 (-1119)) (-5 *1 (-907 *2 *3 *4)) (-4 *2 (-1119)) (-4 *4 (-683 *3)))) ((*1 *1) (-12 (-5 *1 (-911 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1280 *5)) (-4 *5 (-814)) (-5 *2 (-141)) (-5 *1 (-864 *4 *5)) (-14 *4 (-790))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-477)))) ((*1 *1 *1 *1) (-4 *1 (-477))) ((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-5 *1 (-520 *2)) (-4 *2 (-1255 (-592))))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-712 *2)) (-4 *2 (-1255 *3)))) ((*1 *1 *1 *1) (-5 *1 (-790))) ((*1 *2 *2 *2) (-12 (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-323)) (-5 *1 (-939 *3 *4 *5 *2)) (-4 *2 (-977 *5 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *6 *4 *5)) (-5 *1 (-939 *4 *5 *6 *2)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1187 *6)) (-4 *6 (-977 *5 *3 *4)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-323)) (-5 *1 (-939 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-1187 *7))) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-5 *2 (-1187 *7)) (-5 *1 (-939 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5)))) ((*1 *1 *1 *1) (-5 *1 (-944))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-1229)) (-5 *3 (-592)) (-5 *1 (-982)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-986 (-1229))) (-5 *4 (-592)) (-5 *2 (-1229)) (-5 *1 (-982)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-477)) (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-841 *3)) (-4 *3 (-869))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-394)) (-5 *2 (-944)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-373)) (-5 *2 (-944)) (-5 *1 (-556 *4))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2) (-12 (-4 *2 (-13 (-388) (-867))) (-5 *1 (-200 *2 *3)) (-4 *3 (-1255 (-191 *2)))))) 
+(((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-191 (-237)) (-191 (-237)))) (-5 *4 (-1113 (-237))) (-5 *5 (-141)) (-5 *2 (-1282)) (-5 *1 (-272))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1280 *5)) (-4 *5 (-814)) (-5 *2 (-141)) (-5 *1 (-864 *4 *5)) (-14 *4 (-790))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-1179 3 *3)))) ((*1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1150 (-237))) (-5 *1 (-1282)))) ((*1 *2 *1) (-12 (-5 *2 (-1150 (-237))) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2 *2 *3) (-12 (-4 *1 (-692 *2 *3)) (-4 *2 (-1225)) (-4 *3 (-1225))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-862 (-237)))) (-5 *4 (-237)) (-5 *2 (-658 *4)) (-5 *1 (-285))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-877) (-877))) (-5 *1 (-143)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-877) (-658 (-877)))) (-5 *1 (-143)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-877) (-658 (-877)))) (-5 *1 (-143)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-227 *3)) (-4 *3 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 (*2 $)) (-15 -3948 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-420)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-420)))) ((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-524)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-535)))) ((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-727)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1206)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-1206))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3))))) 
+(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3548 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-405)) (-5 *1 (-1067))))) 
+(((*1 *2 *3 *4 *4 *3 *5) (-12 (-5 *4 (-631 *3)) (-5 *5 (-1187 *3)) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-588 *6 *3 *7)) (-4 *7 (-1119)))) ((*1 *2 *3 *4 *4 *4 *3 *5) (-12 (-5 *4 (-631 *3)) (-5 *5 (-433 (-1187 *3))) (-4 *3 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-588 *6 *3 *7)) (-4 *7 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-706 *5))) (-5 *4 (-592)) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-141)) (-5 *1 (-1057 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-706 *4))) (-4 *4 (-388)) (-4 *4 (-1075)) (-5 *2 (-141)) (-5 *1 (-1057 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-980 (-592))) (-5 *2 (-350)) (-5 *1 (-352))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *5))) (-5 *3 (-1187 *5)) (-4 *5 (-188 *4)) (-4 *4 (-574)) (-5 *1 (-173 *4 *5)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-373)) (-5 *1 (-382 *4 *5 *3)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 (-592)))) (-5 *3 (-1187 (-592))) (-5 *1 (-600)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *1))) (-5 *3 (-1187 *1)) (-4 *1 (-931))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1075)) (-4 *7 (-1075)) (-4 *6 (-1255 *5)) (-5 *2 (-1187 (-1187 *7))) (-5 *1 (-534 *5 *6 *4 *7)) (-4 *4 (-1255 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *6))) (-5 *4 (-658 (-1191))) (-4 *6 (-13 (-582) (-1065 *5))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *6)))))) (-5 *1 (-1066 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-489))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1063))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) ((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-715))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-877))))) 
+(((*1 *1) (-4 *1 (-23))) ((*1 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) ((*1 *1) (-5 *1 (-565))) ((*1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-141)) (-5 *1 (-851))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-860)) (-5 *4 (-1087)) (-5 *2 (-1063)) (-5 *1 (-859)))) ((*1 *2 *3) (-12 (-5 *3 (-860)) (-5 *2 (-1063)) (-5 *1 (-859)))) ((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-658 (-405))) (-5 *5 (-658 (-862 (-405)))) (-5 *6 (-658 (-332 (-405)))) (-5 *3 (-332 (-405))) (-5 *2 (-1063)) (-5 *1 (-859)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-405))) (-5 *5 (-658 (-862 (-405)))) (-5 *2 (-1063)) (-5 *1 (-859)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-405))) (-5 *2 (-1063)) (-5 *1 (-859)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-332 (-405)))) (-5 *4 (-658 (-405))) (-5 *2 (-1063)) (-5 *1 (-859))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-193)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-790)) (|:| |poli| *2) (|:| |polj| *2))) (-4 *5 (-815)) (-4 *2 (-977 *4 *5 *6)) (-5 *1 (-474 *4 *5 *6 *2)) (-4 *4 (-477)) (-4 *6 (-869))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-1 (-237) (-237))) (-5 *1 (-720 *3)) (-4 *3 (-633 (-565))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1191)) (-5 *2 (-1 (-237) (-237) (-237))) (-5 *1 (-720 *3)) (-4 *3 (-633 (-565)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3)))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-790)) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-332 (-237))) (-5 *1 (-285))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-5 *2 (-1187 *1)) (-4 *1 (-349 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-1187 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-396 *3 *2)) (-4 *3 (-194)) (-4 *3 (-388)) (-4 *2 (-1255 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-373)) (-5 *2 (-1187 *4)) (-5 *1 (-556 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-151 *3))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-658 *7)) (|:| |badPols| (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-914 *4)) (-4 *4 (-1119)) (-5 *2 (-1 (-141) *5)) (-5 *1 (-912 *4 *5)) (-4 *5 (-1225))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| -12 (-5 *4 (-658 *11)) (-5 *5 (-658 (-1187 *9))) (-5 *6 (-658 *9)) (-5 *7 (-658 *12)) (-5 *8 (-658 (-790))) (-4 *11 (-869)) (-4 *9 (-323)) (-4 *12 (-977 *9 *10 *11)) (-4 *10 (-815)) (-5 *2 (-658 (-1187 *12))) (-5 *1 (-724 *10 *11 *9 *12)) (-5 *3 (-1187 *12))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-143))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1299 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-841 *3)))) ((*1 *2 *1) (-12 (-4 *2 (-865)) (-5 *1 (-1301 *3 *2)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-126 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-219))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-373)) (-5 *2 (-1187 *4)) (-5 *1 (-556 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-118))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-1075)) (-4 *6 (-252 *7 *3)) (-14 *7 *3) (-5 *2 (-658 *5)) (-5 *1 (-935 *4 *5 *6 *7)) (-4 *5 (-346 *4 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 *5)))) (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-980 *5)))) (-5 *1 (-1196 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-383 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-462))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1005 *4 *5 *6 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 *3 *4)) (-5 *1 (-699 *4 *3)) (-4 *4 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *6) (|partial| -12 (-5 *5 (-2 (|:| |contp| *3) (|:| -2033 (-658 (-2 (|:| |irr| *10) (|:| -1777 (-592))))))) (-5 *6 (-658 *3)) (-5 *7 (-658 *8)) (-4 *8 (-869)) (-4 *3 (-323)) (-4 *10 (-977 *3 *9 *8)) (-4 *9 (-815)) (-5 *2 (-2 (|:| |polfac| (-658 *10)) (|:| |correct| *3) (|:| |corrfact| (-658 (-1187 *3))))) (-5 *1 (-641 *8 *9 *3 *10)) (-5 *4 (-658 (-1187 *3)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-706 (-592))) (-5 *1 (-1129))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1280 (-1191))) (-5 *3 (-1280 (-478 *4 *5 *6 *7))) (-5 *1 (-478 *4 *5 *6 *7)) (-4 *4 (-194)) (-14 *5 (-944)) (-14 *6 (-658 (-1191))) (-14 *7 (-1280 (-706 *4))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-478 *4 *5 *6 *7))) (-5 *1 (-478 *4 *5 *6 *7)) (-4 *4 (-194)) (-14 *5 (-944)) (-14 *6 (-658 *2)) (-14 *7 (-1280 (-706 *4))))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-478 *3 *4 *5 *6))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-1191))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 *2)) (-14 *6 (-1280 (-706 *3))))) ((*1 *1) (-12 (-5 *1 (-478 *2 *3 *4 *5)) (-4 *2 (-194)) (-14 *3 (-944)) (-14 *4 (-658 (-1191))) (-14 *5 (-1280 (-706 *2)))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-790)) (-4 *4 (-373)) (-5 *1 (-229 *4 *2)) (-4 *2 (-1255 *4)))) ((*1 *2 *2 *3 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-712 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-388)))) ((*1 *2 *1) (-12 (-4 *1 (-999 *2)) (-4 *2 (-388))))) 
+(((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *6 (-1173)) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-944)) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) ((*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-855 (-944))) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) ((*1 *2) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-944)))) ((*1 *2) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-855 (-944)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-718 *4 *5 *6 *7)) (-4 *4 (-633 (-565))) (-4 *5 (-1225)) (-4 *6 (-1225)) (-4 *7 (-1225))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *1) (-5 *1 (-463)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *3 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *6 *7 *3 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *9)) (-5 *1 (-491 *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-995 *4)) (-4 *4 (-373)) (-5 *2 (-658 (-949 *4))) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-994 *4)) (-4 *4 (-388)) (-5 *2 (-658 (-948 *4))) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-191 (-237))) (-5 *5 (-592)) (-5 *6 (-1173)) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-777))))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3 *3 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-126 *3)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *1 (-126 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1137)) (-5 *1 (-133)))) ((*1 *2 *1) (|partial| -12 (-5 *1 (-390 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-1173)) (-5 *1 (-1207))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| |den| (-592)) (|:| |gcdnum| (-592))))) (-4 *4 (-1255 (-433 *2))) (-5 *2 (-592)) (-5 *1 (-936 *4 *5)) (-4 *5 (-1255 (-433 *4)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *2 (-141)) (-5 *1 (-56 *4)) (-4 *4 (-1225)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-915 *3)) (-4 *3 (-869))))) 
+(((*1 *2) (-12 (-4 *3 (-1075)) (-5 *2 (-986 (-729 *3 *4))) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-869)) (-5 *1 (-1197 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-521))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030)))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *7))) (-5 *3 (-1187 *7)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-931)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-928 *4 *5 *6 *7)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *5))) (-5 *3 (-1187 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-931)) (-5 *1 (-929 *4 *5))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-234 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-869)) (-5 *2 (-790)) (-5 *1 (-518 *4)))) ((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-523 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-790)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| *1 (-6 -4625)) (-4 *1 (-523 *4)) (-4 *4 (-1225)) (-5 *2 (-790)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-1028 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-1161 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1156 *3 *4)) (-14 *3 (-944)) (-4 *4 (-388)) (-5 *1 (-1022 *3 *4))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1173)) (-5 *3 (-592)) (-5 *1 (-256))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-971 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-2 (|:| |zeros| (-1171 (-237))) (|:| |ones| (-1171 (-237))) (|:| |singularities| (-1171 (-237))))) (-5 *1 (-129))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1123)) (-5 *1 (-57))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-971 *4)) (-4 *1 (-1151 *4)) (-4 *4 (-1075)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-790)) (-5 *4 (-971 (-237))) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *1 *2 *2 *2 *2 *2 *3 *4) (-12 (-5 *2 (-592)) (-5 *3 (-141)) (-5 *4 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *1 (-137))))) 
+(((*1 *2 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1138 *3)) (-4 *3 (-1225)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1161 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 *3)) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-1280 *6)) (-5 *1 (-356 *3 *4 *5 *6)) (-4 *6 (-362 *3 *4 *5))))) 
+(((*1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-14 *6 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *2)) (-2 (|:| -1825 *5) (|:| -3215 *2)))) (-4 *2 (-252 (-1699 *3) (-790))) (-5 *1 (-487 *3 *4 *5 *2 *6 *7)) (-4 *5 (-869)) (-4 *7 (-977 *4 *2 (-879 *3)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-332 *3)) (-4 *3 (-13 (-1075) (-869))) (-5 *1 (-235 *3 *4)) (-14 *4 (-658 (-1191)))))) 
+(((*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1203 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1119))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-927 *3))) (-4 *3 (-1119)) (-5 *1 (-926 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-658 *6) "failed") (-592) *6 *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-2 (|:| |answer| (-609 (-433 *7))) (|:| |a0| *6))) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-323)) (-5 *2 (-658 *5))))) 
+(((*1 *1 *2 *1) (-12 (-5 *1 (-151 *2)) (-4 *2 (-869))))) 
+(((*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-252 (-1699 *4) (-790))) (-4 *6 (-999 *3)) (-4 *7 (-665 *3)) (-4 *8 (-947 *3 *7)) (-4 *9 (-257 *8)) (-4 *10 (-560 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-137)) (-4 *2 (-977 *3 *5 (-879 *4))) (-5 *1 (-491 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2) (-12 (-5 *2 (-264 *4 *3)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-264 *4 *3)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-631 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4))) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *4 *2))))) 
+(((*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| -12 (-5 *2 (-658 (-1187 *13))) (-5 *3 (-1187 *13)) (-5 *4 (-658 *12)) (-5 *5 (-658 *10)) (-5 *6 (-658 *13)) (-5 *7 (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| *13))))) (-5 *8 (-658 (-790))) (-5 *9 (-1280 (-658 (-1187 *10)))) (-4 *12 (-869)) (-4 *10 (-323)) (-4 *13 (-977 *10 *11 *12)) (-4 *11 (-815)) (-5 *1 (-724 *11 *12 *10 *13))))) 
+(((*1 *2 *3 *3 *4 *5 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-1280 *5)) (-4 *5 (-654 *4)) (-4 *4 (-582)) (-5 *2 (-1280 *4)) (-5 *1 (-653 *4 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-5 *1 (-1071 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-790)) (-5 *5 (-658 *3)) (-4 *3 (-323)) (-4 *6 (-869)) (-4 *7 (-815)) (-5 *2 (-141)) (-5 *1 (-641 *6 *7 *3 *8)) (-4 *8 (-977 *3 *7 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592))))) 
+(((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1190)) (-5 *1 (-350)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1190)) (-5 *1 (-350))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-373)) (-4 *4 (-349 *3)) (-4 *5 (-1255 *4)) (-5 *1 (-796 *3 *4 *5 *2 *6)) (-4 *2 (-1255 *5)) (-14 *6 (-944)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-4 *3 (-394)))) ((*1 *1 *1) (-12 (-4 *1 (-1297 *2)) (-4 *2 (-388)) (-4 *2 (-394))))) 
+(((*1 *2 *3 *3 *4 *5 *5 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1255 (-433 *3))) (-5 *2 (-944)) (-5 *1 (-936 *4 *5)) (-4 *5 (-1255 (-433 *4)))))) 
+(((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *2 (-658 (-237))) (-5 *1 (-321))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *3)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *3 (-188 *6)) (-4 (-980 *6) (-908 *5)) (-4 *6 (-13 (-908 *5) (-194))) (-5 *1 (-198 *5 *6 *3)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-911 *4 *1)) (-5 *3 (-914 *4)) (-4 *1 (-908 *4)) (-4 *4 (-1119)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *6)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *6 (-13 (-1119) (-1065 *3))) (-4 *3 (-908 *5)) (-5 *1 (-959 *5 *3 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *3)) (-4 *5 (-1119)) (-4 *3 (-13 (-456 *6) (-633 *4) (-908 *5) (-1065 (-631 $)))) (-5 *4 (-914 *5)) (-4 *6 (-13 (-582) (-869) (-908 *5))) (-5 *1 (-960 *5 *6 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 (-592) *3)) (-5 *4 (-914 (-592))) (-4 *3 (-574)) (-5 *1 (-961 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *6)) (-5 *3 (-631 *6)) (-4 *5 (-1119)) (-4 *6 (-13 (-869) (-1065 (-631 $)) (-633 *4) (-908 *5))) (-5 *4 (-914 *5)) (-5 *1 (-962 *5 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-907 *5 *6 *3)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *6 (-908 *5)) (-4 *3 (-683 *6)) (-5 *1 (-963 *5 *6 *3)))) ((*1 *2 *3 *4 *2 *5) (-12 (-5 *5 (-1 (-911 *6 *3) *8 (-914 *6) (-911 *6 *3))) (-4 *8 (-869)) (-5 *2 (-911 *6 *3)) (-5 *4 (-914 *6)) (-4 *6 (-1119)) (-4 *3 (-13 (-977 *9 *7 *8) (-633 *4))) (-4 *7 (-815)) (-4 *9 (-13 (-1075) (-869) (-908 *6))) (-5 *1 (-964 *6 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *3)) (-4 *5 (-1119)) (-4 *3 (-13 (-977 *8 *6 *7) (-633 *4))) (-5 *4 (-914 *5)) (-4 *7 (-908 *5)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-13 (-1075) (-869) (-908 *5))) (-5 *1 (-964 *5 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 *3)) (-4 *5 (-1119)) (-4 *3 (-1021 *6)) (-4 *6 (-13 (-582) (-908 *5) (-633 *4))) (-5 *4 (-914 *5)) (-5 *1 (-967 *5 *6 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-911 *5 (-1191))) (-5 *3 (-1191)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-5 *1 (-968 *5)))) ((*1 *2 *3 *4 *5 *2 *6) (-12 (-5 *4 (-658 (-914 *7))) (-5 *5 (-1 *9 (-658 *9))) (-5 *6 (-1 (-911 *7 *9) *9 (-914 *7) (-911 *7 *9))) (-4 *7 (-1119)) (-4 *9 (-13 (-1075) (-633 (-914 *7)) (-1065 *8))) (-5 *2 (-911 *7 *9)) (-5 *3 (-658 *9)) (-4 *8 (-13 (-1075) (-869))) (-5 *1 (-969 *7 *8 *9))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-194))))) 
+(((*1 *2 *3) (-12 (-4 *2 (-388)) (-4 *2 (-867)) (-5 *1 (-973 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-658 (-1191))) (-4 *5 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *5)))))) (-5 *1 (-789 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-582)) (-5 *2 (-658 (-658 (-310 (-433 (-980 *4)))))) (-5 *1 (-789 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *7)) (-5 *5 (-1 (-2 (|:| |particular| (-3 *6 "failed")) (|:| -2195 (-658 *6))) *7 *6)) (-4 *6 (-388)) (-4 *7 (-670 *6)) (-5 *2 (-2 (|:| |particular| (-3 (-1280 *6) "failed")) (|:| -2195 (-658 (-1280 *6))))) (-5 *1 (-835 *6 *7)) (-5 *4 (-1280 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *1 (-362 *4 *5 *6)) (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-2 (|:| |num| (-706 *5)) (|:| |den| *5)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-665 *4)) (-4 *3 (-947 *4 *8)) (-4 *9 (-257 *3)) (-4 *10 (-560 *4 *5 *6 *7 *2 *8 *3 *9 *12)) (-4 *12 (-137)) (-4 *2 (-999 *4)) (-5 *1 (-491 *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-665 *4)) (-4 *2 (-999 *4)) (-5 *1 (-679 *4 *5 *6 *7 *2 *8 *3)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *3 (-947 *4 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-949 *4)) (-4 *4 (-373)) (-5 *2 (-995 *4)) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-948 *4)) (-4 *4 (-388)) (-5 *2 (-994 *4)) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194)))) ((*1 *2 *3 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1171 (-592))) (-5 *1 (-1175 *4)) (-4 *4 (-1075)) (-5 *3 (-592))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-342 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-158)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-386 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-412 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-662 *3 *4 *5)) (-4 *4 (-23)) (-14 *5 *4)))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 (-706 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211))))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-592)) (-4 *5 (-1075)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-5 *1 (-935 *5 *2 *6 *7)) (-4 *2 (-346 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5)))) ((*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-944)) (-5 *4 (-405)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-953)))) ((*1 *2 *1) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-237))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1252 *5 *4)) (-5 *1 (-1189 *4 *5 *6)) (-4 *4 (-1075)) (-14 *5 (-1191)) (-14 *6 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1252 (QUOTE |x|) *4)) (-5 *1 (-1237 *4)) (-4 *4 (-1075)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1252 *5 *4)) (-5 *1 (-1271 *4 *5 *6)) (-4 *4 (-1075)) (-14 *5 (-1191)) (-14 *6 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1252 *5 *4)) (-5 *1 (-1275 *4 *5)) (-4 *4 (-1075)) (-14 *5 (-1191))))) 
+(((*1 *2) (-12 (-5 *2 (-1199 (-1106 *3) (-1106 *3))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592))))) 
+(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-766))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1280 (-2 (|:| |scaleX| (-237)) (|:| |scaleY| (-237)) (|:| |deltaX| (-237)) (|:| |deltaY| (-237)) (|:| -2190 (-592)) (|:| -2180 (-592)) (|:| |spline| (-592)) (|:| -1436 (-592)) (|:| |axesColor| (-896)) (|:| -3682 (-592)) (|:| |unitsColor| (-896)) (|:| |showing| (-592))))) (-5 *1 (-1281))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1065 (-592))) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-36 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-1187 *4)) (-5 *1 (-187 *3 *4)) (-4 *3 (-188 *4)))) ((*1 *1 *1) (-12 (-4 *1 (-1075)) (-4 *1 (-318)))) ((*1 *2) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-1187 *3)))) ((*1 *2) (-12 (-4 *1 (-741 *3 *2)) (-4 *3 (-194)) (-4 *2 (-1255 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) ((*1 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-885)))) ((*1 *2 *1) (-12 (-4 *1 (-1091 *3 *2)) (-4 *3 (-13 (-867) (-388))) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *4 *5 *6)) (-4 *4 (-388)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-475 *4 *5 *6 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-121 *6)) (-5 *5 (-1 *6 *6)) (-4 *6 (-388)) (-5 *2 (-2 (|:| R (-706 *6)) (|:| A (-706 *6)) (|:| |Ainv| (-706 *6)))) (-5 *1 (-1007 *6)) (-5 *3 (-706 *6))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-389 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-468 *4 *3 *5)) (-4 *3 (-1255 *4)) (-4 *5 (-13 (-430) (-1065 *4) (-388) (-1211) (-301)))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *5) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-69 -3958)))) (-5 *2 (-1063)) (-5 *1 (-765))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-658 (-658 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-658 (-3 (|:| |array| (-658 *3)) (|:| |scalar| (-1191))))) (-5 *6 (-658 (-1191))) (-5 *3 (-1191)) (-5 *2 (-1123)) (-5 *1 (-423)))) ((*1 *2 *3 *4 *5 *6 *3) (-12 (-5 *5 (-658 (-658 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-658 (-3 (|:| |array| (-658 *3)) (|:| |scalar| (-1191))))) (-5 *6 (-658 (-1191))) (-5 *3 (-1191)) (-5 *2 (-1123)) (-5 *1 (-423)))) ((*1 *2 *3 *4 *5 *4) (-12 (-5 *4 (-658 (-1191))) (-5 *5 (-1194)) (-5 *3 (-1191)) (-5 *2 (-1123)) (-5 *1 (-423))))) 
+(((*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1067))))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (-592))))) (-5 *1 (-444 *3)) (-4 *3 (-582)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-790)) (-4 *3 (-373)) (-4 *5 (-1255 *3)) (-5 *2 (-658 (-1187 *3))) (-5 *1 (-531 *3 *5 *6)) (-4 *6 (-1255 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-86 FCN)))) (-5 *2 (-1063)) (-5 *1 (-765))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1158)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1801 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-3 (-141) "failed")) (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)) (-5 *1 (-1016 *3 *4 *5 *6)) (-4 *6 (-977 *3 *5 *4))))) 
+(((*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *3 (-1229)) (-5 *1 (-982))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-280 *12)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 *7)) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) (-790))) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *9 (-999 *5)) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-4 *12 (-257 *11)) (-4 *13 (-560 *5 *6 *7 *8 *9 *10 *11 *12 *14)) (-4 *14 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (-4 *3 (-280 *13))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-658 *3)) (-4 *3 (-977 *4 *6 *5)) (-4 *4 (-477)) (-4 *5 (-869)) (-4 *6 (-815)) (-5 *1 (-1016 *4 *5 *6 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1065 (-592))) (-4 *1 (-318)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-574)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-927 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1) (|partial| -12 (-5 *1 (-176 *2 *3 *4)) (-14 *2 (-944)) (-4 *3 (-388)) (-14 *4 (-1022 *2 *3)))) ((*1 *1 *1) (|partial| -12 (-4 *2 (-194)) (-5 *1 (-306 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1255 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-194)) (-4 *2 (-582)))) ((*1 *1 *1) (|partial| -12 (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) ((*1 *1) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) ((*1 *1 *1) (|partial| -4 *1 (-739))) ((*1 *1 *1) (|partial| -4 *1 (-743))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *3))) (-5 *1 (-795 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) ((*1 *2 *2 *1) (|partial| -12 (-4 *1 (-1091 *3 *2)) (-4 *3 (-13 (-867) (-388))) (-4 *2 (-1255 *3)))) ((*1 *2 *2) (|partial| -12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-662 *3 *4 *5)) (-4 *3 (-1119)) (-4 *4 (-23)) (-14 *5 *4)))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-234 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-869)) (-5 *2 (-141)) (-5 *1 (-518 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| *1 (-6 -4625)) (-4 *1 (-523 *4)) (-4 *4 (-1225)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-1028 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-1161 *4))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-592)) (-4 *4 (-1075)) (-5 *1 (-1175 *4)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-1191))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *2 (-1119)) (-5 *1 (-1203 *3 *2)) (-4 *3 (-1119))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-143)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-869)) (-5 *1 (-957 *4 *2)) (-4 *2 (-456 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-1173)) (-5 *2 (-332 (-592))) (-5 *1 (-958))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *2)) (-4 *2 (-1270 *4)) (-5 *1 (-1272 *4 *2)) (-4 *4 (-43 (-433 (-592))))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-57))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4500 *4) (|:| -4525 (-592))))) (-4 *4 (-1255 (-592))) (-5 *2 (-754 (-790))) (-5 *1 (-467 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-444 *5)) (-4 *5 (-1255 *4)) (-4 *4 (-1075)) (-5 *2 (-754 (-790))) (-5 *1 (-469 *4 *5))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-592)) (-4 *1 (-692 *5 *4)) (-4 *5 (-1225)) (-4 *4 (-1225)) (-5 *2 |SortedExponentVector|)))) 
+(((*1 *1) (-5 *1 (-463)))) 
+(((*1 *2) (-12 (-4 *3 (-194)) (-5 *2 (-1280 *1)) (-4 *1 (-392 *3))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-582)) (-4 *7 (-977 *3 *5 *6)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *8) (|:| |radicand| *8))) (-5 *1 (-981 *5 *6 *3 *7 *8)) (-5 *4 (-790)) (-4 *8 (-13 (-388) (-10 -8 (-15 -1448 (*7 $)) (-15 -1456 (*7 $)) (-15 -1683 ($ *7)))))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-247)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-1 *1 (-790))) (-4 *1 (-268 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-1 *1 (-790))) (-4 *1 (-268 *4 *3 *5 *6)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-284 *2)) (-4 *2 (-869))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-583 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5)))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-822)) (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-1063))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-658 (-1252 *5 *4))) (-5 *1 (-1133 *4 *5)) (-5 *3 (-1252 *5 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-405))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-844)) (-5 *1 (-843))))) 
+(((*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1027 *3)) (-4 *3 (-194)) (-5 *1 (-821 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *6) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 *6)) (-4 *6 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *7) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 *7)) (-4 *7 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 *8) (|:| -4346 (-790)))) (-658 *6) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 *6)) (-4 *6 (-388)) (-14 *11 (-1 *8 *6)) (-4 *9 (-13 (-869) (-582))) (-14 *10 (-1 *6 *9)) (-5 *2 (-658 (-2 (|:| -1325 *8) (|:| -4346 (-790))))) (-5 *1 (-510 *6 *7 *8 *9 *10 *11)) (-4 *7 (-477)) (-4 *8 (-13 (-456 (-592)) (-582) (-1065 *9) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 *9) (|:| -4346 (-790)))) (-658 *7) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 *7)) (-4 *7 (-388)) (-14 *12 (-1 *9 *7)) (-4 *10 (-13 (-869) (-582))) (-14 *11 (-1 *7 *10)) (-5 *2 (-658 (-2 (|:| -1325 *9) (|:| -4346 (-790))))) (-5 *1 (-510 *7 *8 *9 *10 *11 *12)) (-4 *8 (-477)) (-4 *9 (-13 (-456 (-592)) (-582) (-1065 *10) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-760 *6 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *6 (-592)))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *3 (-658 (-433 (-761 *6 (-592))))) (-14 *6 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *6 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-658 (-1 (-658 (-2 (|:| -1325 (-760 *7 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *7 (-592)))) (-658 (-489))))) (-5 *5 (-658 (-1191))) (-5 *6 (-658 (-489))) (-5 *3 (-658 (-433 (-761 *7 (-592))))) (-14 *7 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *7 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *7))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-790)) (-4 *2 (-13 (-582) (-477))) (-5 *1 (-369 *2 *4)) (-4 *4 (-52 *2 *3))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1138 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-489))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-658 (-1252 *5 *4))) (-5 *1 (-1133 *4 *5)) (-5 *3 (-1252 *5 *4))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-790)) (-4 *5 (-373)) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-2 (|:| -2195 (-706 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-706 *6))))) (-5 *1 (-531 *5 *6 *7)) (-5 *3 (-2 (|:| -2195 (-706 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-706 *6)))) (-4 *7 (-1255 *6))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582) (-633 (-565)))) (-5 *1 (-1052 *3 *2)) (-4 *2 (-13 (-456 *3) (-23) (-1065 (-592)) (-1065 (-1191)) (-922 (-1191)) (-182)))))) 
+(((*1 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-394)) (-4 *2 (-388))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-237))) (-5 *2 (-237)) (-5 *1 (-135))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-444 (-1187 *1))) (-5 *1 (-332 *4)) (-5 *3 (-1187 *1)) (-4 *4 (-477)) (-4 *4 (-582)) (-4 *4 (-869)))) ((*1 *2 *3) (-12 (-4 *1 (-931)) (-5 *2 (-444 (-1187 *1))) (-5 *3 (-1187 *1))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-640 *3 *4 *5 *6 *7 *2)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *2 (-1128 *3 *4 *5 *6))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-944)) (-5 *1 (-1060 *2)) (-4 *2 (-13 (-1119) (-10 -8 (-15 * ($ $ $)))))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-96 *3))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030)))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-592))))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-2 (|:| |ans| *7) (|:| -1954 *7) (|:| |sol?| (-141))) (-592) *7)) (-5 *6 (-658 (-433 *8))) (-4 *7 (-388)) (-4 *8 (-1255 *7)) (-5 *3 (-433 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-602 *7 *8))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1003)) (-5 *2 (-1113 (-237)))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-444 *2)) (-4 *2 (-323)) (-5 *1 (-937 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-171))) (-5 *2 (-57)) (-5 *1 (-938 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-444 (-980 *6))) (-5 *5 (-1191)) (-5 *3 (-980 *6)) (-4 *6 (-13 (-323) (-171))) (-5 *2 (-57)) (-5 *1 (-938 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1075)) (-5 *2 (-1280 *4)) (-5 *1 (-1192 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-5 *2 (-1280 *3)) (-5 *1 (-1192 *3)) (-4 *3 (-1075))))) 
+(((*1 *1) (-5 *1 (-141)))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1158)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191))))) 
+(((*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1154 *4 *5))) (-5 *3 (-1 (-141) *5 *5)) (-4 *4 (-13 (-1119) (-39))) (-4 *5 (-13 (-1119) (-39))) (-5 *1 (-1155 *4 *5)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-658 (-1154 *3 *4))) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))) (-5 *1 (-1155 *3 *4))))) 
+(((*1 *1 *2 *3 *3 *4 *5) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *3 (-658 (-896))) (-5 *4 (-658 (-944))) (-5 *5 (-658 (-278))) (-5 *1 (-497)))) ((*1 *1 *2 *3 *3 *4) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *3 (-658 (-896))) (-5 *4 (-658 (-944))) (-5 *1 (-497)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *1 (-497)))) ((*1 *1 *1) (-5 *1 (-497)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *3 *2 *3) (-12 (-5 *2 (-463)) (-5 *3 (-1191)) (-5 *1 (-1194)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-463)) (-5 *3 (-1191)) (-5 *1 (-1194)))) ((*1 *2 *3 *2 *4 *1) (-12 (-5 *2 (-463)) (-5 *3 (-658 (-1191))) (-5 *4 (-1191)) (-5 *1 (-1194)))) ((*1 *2 *3 *2 *3 *1) (-12 (-5 *2 (-463)) (-5 *3 (-1191)) (-5 *1 (-1194)))) ((*1 *2 *3 *2 *1) (-12 (-5 *2 (-463)) (-5 *3 (-1191)) (-5 *1 (-1195)))) ((*1 *2 *3 *2 *1) (-12 (-5 *2 (-463)) (-5 *3 (-658 (-1191))) (-5 *1 (-1195))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-658 *8))) (-5 *3 (-658 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *5 *6 *7 *8))))) 
+(((*1 *1) (-12 (-4 *1 (-430)) (-3252 (|has| *1 (-6 -4616))) (-3252 (|has| *1 (-6 -4608))))) ((*1 *2 *1) (-12 (-4 *1 (-451 *2)) (-4 *2 (-1119)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-4 *1 (-869))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-869)))) ((*1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1267 *3)) (-4 *3 (-1225)) (-5 *2 (-790))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-1 (-658 *4) *4)) (-5 *1 (-127 *4)) (-5 *3 (-658 *4))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-769))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *2 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *2 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *1 (-491 *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-264 *5 *4)) (-5 *3 (-592)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-5 *1 (-894 *4 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-264 *5 *4)) (-5 *3 (-592)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *1 (-895 *4 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5)))) ((*1 *1 *1) (-12 (-4 *1 (-999 *2)) (-4 *2 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-999 *3)) (-4 *3 (-388))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *2 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-237)))) ((*1 *1 *1 *1) (-3836 (-12 (-5 *1 (-310 *2)) (-4 *2 (-388)) (-4 *2 (-1225))) (-12 (-5 *1 (-310 *2)) (-4 *2 (-502)) (-4 *2 (-1225))))) ((*1 *1 *1 *1) (-4 *1 (-388))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-405)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1142 *3 (-631 *1))) (-4 *3 (-582)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) ((*1 *1 *1 *1) (-4 *1 (-502))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-373)) (-5 *1 (-556 *3)))) ((*1 *1 *1 *1) (-5 *1 (-565))) ((*1 *1 *2 *3) (-12 (-4 *4 (-194)) (-5 *1 (-637 *2 *4 *3)) (-4 *2 (-43 *4)) (-4 *3 (|SubsetCategory| (-743) *4)))) ((*1 *1 *1 *2) (-12 (-4 *4 (-194)) (-5 *1 (-637 *3 *4 *2)) (-4 *3 (-43 *4)) (-4 *2 (|SubsetCategory| (-743) *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-649 *2)) (-4 *2 (-194)) (-4 *2 (-388)))) ((*1 *1 *2 *3) (-12 (-4 *4 (-194)) (-5 *1 (-676 *2 *4 *3)) (-4 *2 (-734 *4)) (-4 *3 (|SubsetCategory| (-743) *4)))) ((*1 *1 *1 *2) (-12 (-4 *4 (-194)) (-5 *1 (-676 *3 *4 *2)) (-4 *3 (-734 *4)) (-4 *2 (|SubsetCategory| (-743) *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 (-332 (-592)) *3)) (-4 *3 (-1119)) (-5 *1 (-701 *3 *4)) (-4 *4 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-388)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-880 *2 *3 *4 *5)) (-4 *2 (-388)) (-4 *2 (-1075)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-790))) (-14 *5 (-790)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1078 *3 *4 *2 *5 *6)) (-4 *2 (-1075)) (-4 *5 (-252 *4 *2)) (-4 *6 (-252 *3 *2)) (-4 *2 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-332 *3)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-1106 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1287 *2)) (-4 *2 (-388)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *2 (-388)) (-4 *2 (-1075)) (-4 *3 (-869)) (-4 *4 (-815)) (-14 *6 (-658 *3)) (-5 *1 (-1290 *2 *3 *4 *5 *6 *7 *8)) (-4 *5 (-977 *2 *4 *3)) (-14 *7 (-658 (-790))) (-14 *8 (-790)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-1301 *2 *3)) (-4 *2 (-388)) (-4 *2 (-1075)) (-4 *3 (-865))))) 
+(((*1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1194))))) 
+(((*1 *1 *1) (-5 *1 (-1087)))) 
+(((*1 *1 *1) (-12 (-5 *1 (-235 *2 *3)) (-4 *2 (-13 (-1075) (-869))) (-14 *3 (-658 (-1191)))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (-12 (-5 *3 (-237)) (-5 *4 (-592)) (-5 *5 (-1173)) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-87 PDEF)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-88 BNDY)))) (-5 *2 (-1063)) (-5 *1 (-769))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075))))) 
+(((*1 *2) (-12 (-4 *2 (-13 (-456 *3) (-1030))) (-5 *1 (-294 *3 *2)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *1 *1 *1) (-4 *1 (-21))) ((*1 *1 *1) (-4 *1 (-21))) ((*1 *1 *1 *1) (|partial| -5 *1 (-160))) ((*1 *1 *1 *1) (-12 (-5 *1 (-227 *2)) (-4 *2 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-21)) (-4 *2 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-21)) (-4 *2 (-1225)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) ((*1 *1 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1119)) (-4 *4 (-1075)) (-5 *1 (-701 *3 *4)))) ((*1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)))) ((*1 *2 *2 *1) (-12 (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-21)))) ((*1 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-21))))) 
+(((*1 *2 *2 *1) (-12 (-5 *2 (-1302 *3 *4)) (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2) (|partial| -12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-841 *3)) (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-141)) (-5 *1 (-236 *4 *5)) (-4 *5 (-13 (-1211) (-29 *4)))))) 
+(((*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-691 (-237))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-769))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1 (-971 (-237)) (-971 (-237)))) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-971 (-237)) (-971 (-237)))) (-5 *1 (-278)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-516 *5 *6))) (-5 *3 (-516 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-477)) (-5 *2 (-1280 *6)) (-5 *1 (-646 *5 *6))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-658 (-433 *6))) (-5 *3 (-433 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-596 *5 *6))))) 
+(((*1 *1 *1 *1) (-4 *1 (-25))) ((*1 *1 *1 *1) (-5 *1 (-179))) ((*1 *1 *1 *1) (-12 (-5 *1 (-227 *2)) (-4 *2 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-25)) (-4 *2 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-25)) (-4 *2 (-1225)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-342 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-158)))) ((*1 *1 *2 *1) (-12 (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-499 *2 *3)) (-4 *2 (-194)) (-4 *3 (-23)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) ((*1 *1 *1 *1) (-5 *1 (-565))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1119)) (-4 *4 (-1075)) (-5 *1 (-701 *3 *4)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)))) ((*1 *2 *2 *1) (-12 (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-258 *1)) (-4 *1 (-947 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-25))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-658 (-658 *4)))) (-5 *2 (-658 (-658 *4))) (-4 *4 (-869)) (-5 *1 (-1197 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-869)) (-5 *2 (-658 (-681 *4 *5))) (-5 *1 (-642 *4 *5 *6)) (-4 *5 (-13 (-194) (-734 (-433 (-592))))) (-14 *6 (-944))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *1 (-64 *3)) (-4 *3 (-1225)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-64 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |gen| *3) (|:| -1430 (-592)))) (-5 *1 (-258 *3)) (-4 *3 (-1117)))) ((*1 *1 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225)))) ((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-1173)) (-5 *3 (-845)) (-5 *1 (-844))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-143)) (-5 *4 (-1191)) (-4 *5 (-13 (-869) (-582) (-633 (-565)))) (-4 *2 (-456 *5)) (-5 *1 (-334 *5 *2 *6 *7)) (-4 *6 (-1270 *2)) (-4 *7 (-1270 (-1185 *2)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-373)) (-5 *2 (-141)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-381 *4))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-815)) (-4 *3 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *5 (-582)) (-5 *1 (-749 *4 *3 *5 *2)) (-4 *2 (-977 (-433 (-980 *5)) *4 *3)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-5 *1 (-1013 *4 *5 *3 *2)) (-4 *2 (-977 (-980 *4) *5 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-4 *4 (-1075)) (-4 *5 (-815)) (-5 *1 (-1013 *4 *5 *6 *2)) (-4 *2 (-977 (-980 *4) *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |integrand| *3) (|:| |intvar| *3)))) (-5 *1 (-609 *3)) (-4 *3 (-388))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-168)))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-168))))) 
+(((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1158)) (-5 *3 (-592)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1270 *4)) (-5 *1 (-1272 *4 *2)) (-4 *4 (-43 (-433 (-592))))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-869)) (-5 *2 (-141)))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2190 (-790)) (|:| |curves| (-790)) (|:| |polygons| (-790)) (|:| |constructs| (-790))))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1054 (-862 (-592)))) (-5 *1 (-617 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-841 *3)))) ((*1 *2 *1) (-12 (-4 *2 (-865)) (-5 *1 (-1301 *3 *2)) (-4 *3 (-1075))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-318)))) ((*1 *1 *1) (-4 *1 (-318))) ((*1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-869)) (-5 *2 (-141)))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-926 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *5 *6)) (-4 *6 (-633 (-1191))) (-4 *4 (-388)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1180 (-658 (-980 *4)) (-658 (-310 (-980 *4))))) (-5 *1 (-538 *4 *5 *6 *7))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4))))) 
+(((*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-1191)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-489))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-869)) (-5 *2 (-141)))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-342 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-158))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-658 *1)) (-4 *1 (-456 *4)) (-4 *4 (-869)))) ((*1 *1 *2 *1 *1 *1 *1) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)))) ((*1 *1 *2 *1 *1 *1) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869))))) 
+(((*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *6 (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G)))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-944)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-278))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-869)) (-5 *2 (-141)))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *2 *1 *1) (-12 (-4 *1 (-925 *3)) (-4 *3 (-1119)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1116 *3)) (-4 *3 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-887)) (-5 *1 (-882 *3)) (-14 *3 *2)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-631 *5))) (-4 *4 (-869)) (-5 *2 (-631 *5)) (-5 *1 (-601 *4 *5)) (-4 *5 (-456 *4))))) 
+(((*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (-12 (-5 *4 (-592)) (-5 *5 (-1173)) (-5 *6 (-706 (-237))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-414)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-237)) (-5 *2 (-1063)) (-5 *1 (-768))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-346 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *2 (-477)))) ((*1 *1 *1) (-12 (-4 *1 (-362 *2 *3 *4)) (-4 *2 (-1235)) (-4 *3 (-1255 *2)) (-4 *4 (-1255 (-433 *3))))) ((*1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-477)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *3 (-477)))) ((*1 *1 *1) (-12 (-4 *1 (-977 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-323)) (-4 *3 (-582)) (-5 *1 (-1178 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *1) (-5 *1 (-463)))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-1089 *3 *4 *2)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-658 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-658 *6))) (-4 *6 (-977 *3 *5 *4)) (-4 *3 (-13 (-323) (-171))) (-4 *4 (-13 (-869) (-633 (-1191)))) (-4 *5 (-815)) (-5 *1 (-951 *3 *4 *5 *6))))) 
+(((*1 *1 *1) (|partial| -12 (-5 *1 (-310 *2)) (-4 *2 (-743)) (-4 *2 (-1225))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-125)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *1 *2 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1054 *3)) (-4 *3 (-1225)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-1075)) (-4 *6 (-977 *5 *4 *2)) (-4 *2 (-869)) (-5 *1 (-978 *4 *2 *5 *6 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *6)) (-15 -1448 (*6 $)) (-15 -1456 (*6 $))))))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-5 *2 (-1191)) (-5 *1 (-1070 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-237))) (-5 *4 (-790)) (-5 *2 (-706 (-237))) (-5 *1 (-321))))) 
+(((*1 *1 *1) (-5 *1 (-141))) ((*1 *1 *1) (-4 *1 (-153))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-4 *1 (-947 *4 *5)) (-4 *4 (-388)) (-4 *5 (-665 *4)) (-5 *2 (-1285))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-582))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1255 (-592))) (-5 *1 (-520 *3))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1239 *4)) (-4 *4 (-1075)) (-4 *4 (-582)) (-5 *2 (-433 (-980 *4))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1239 *4)) (-4 *4 (-1075)) (-4 *4 (-582)) (-5 *2 (-433 (-980 *4)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-444 (-1187 (-592)))) (-5 *1 (-205)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-927 (-592))) (-5 *4 (-592)) (-5 *2 (-706 *4)) (-5 *1 (-1056 *5)) (-4 *5 (-1075)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-706 (-592))) (-5 *1 (-1056 *4)) (-4 *4 (-1075)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-927 (-592)))) (-5 *4 (-592)) (-5 *2 (-658 (-706 *4))) (-5 *1 (-1056 *5)) (-4 *5 (-1075)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-592)))) (-5 *2 (-658 (-706 (-592)))) (-5 *1 (-1056 *4)) (-4 *4 (-1075))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-869)) (-5 *1 (-957 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-332 (-592))) (-5 *1 (-958))))) 
+(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-790)) (-4 *3 (-1225)) (-4 *1 (-62 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1) (-5 *1 (-193))) ((*1 *1 *2 *2 *2) (-12 (-5 *2 (-1173)) (-4 *1 (-415)))) ((*1 *1) (-5 *1 (-420))) ((*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) ((*1 *1) (-12 (-4 *3 (-1119)) (-5 *1 (-907 *2 *3 *4)) (-4 *2 (-1119)) (-4 *4 (-683 *3)))) ((*1 *1) (-12 (-5 *1 (-911 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) ((*1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075)))) ((*1 *1 *1) (-5 *1 (-1191))) ((*1 *1) (-5 *1 (-1191))) ((*1 *1) (-5 *1 (-1206)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *2 (-1285)) (-5 *1 (-1194)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *2 (-1285)) (-5 *1 (-1194)))) ((*1 *2 *3 *4 *1) (-12 (-5 *3 (-1191)) (-5 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *2 (-1285)) (-5 *1 (-1194))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) ((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-869)) (-5 *1 (-957 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-332 (-592))) (-5 *1 (-958))))) 
+(((*1 *1) (-5 *1 (-845)))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-141) (-143) (-143))) (-5 *1 (-143))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) ((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1194))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-658 *1)) (-4 *1 (-1151 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-141)) (-5 *3 (-658 (-278))) (-5 *1 (-276))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-332 (-237)))) (-5 *2 (-141)) (-5 *1 (-285))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-1075) (-734 (-433 (-592))))) (-4 *5 (-869)) (-5 *1 (-1294 *4 *5 *2)) (-4 *2 (-1299 *5 *4))))) 
+(((*1 *2 *3 *4 *5 *6 *5 *3 *7) (-12 (-5 *4 (-592)) (-5 *6 (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405)))) (-5 *7 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810)))) ((*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (-12 (-5 *4 (-592)) (-5 *6 (-2 (|:| |try| (-405)) (|:| |did| (-405)) (|:| -3314 (-405)))) (-5 *7 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1212 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-433 (-592))) (-5 *1 (-321))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-57))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1187 *1)) (-5 *3 (-1191)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-980 *1)) (-4 *1 (-27)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-869) (-582))))) ((*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-869) (-582)))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *2) (-12 (-4 *2 (-1075)) (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-860)) (-5 *2 (-1063)) (-5 *1 (-859)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-332 (-405)))) (-5 *4 (-658 (-405))) (-5 *2 (-1063)) (-5 *1 (-859))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 *2)) (-5 *1 (-199 *2)) (-4 *2 (-323)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-658 (-658 *4))) (-5 *2 (-658 *4)) (-4 *4 (-323)) (-5 *1 (-199 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 (-2 (|:| -2195 (-706 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-706 *7))))) (-5 *5 (-790)) (-4 *8 (-1255 *7)) (-4 *7 (-1255 *6)) (-4 *6 (-373)) (-5 *2 (-2 (|:| -2195 (-706 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-706 *7)))) (-5 *1 (-531 *6 *7 *8)))) ((*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |ir| (-609 (-433 *6))) (|:| |specpart| (-433 *6)) (|:| |polypart| *6))) (-5 *1 (-602 *5 *6)) (-5 *3 (-433 *6))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-582)) (-4 *4 (-869)) (-5 *1 (-601 *4 *2)) (-4 *2 (-456 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 (-1187 (-1187 *4)))) (-5 *1 (-1224 *4)) (-5 *3 (-1187 (-1187 *4)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1264 *3 *4 *5)) (-5 *1 (-336 *3 *4 *5)) (-4 *3 (-13 (-388) (-869))) (-14 *4 (-1191)) (-14 *5 *3))) ((*1 *2 *1) (-12 (-4 *1 (-430)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-444 *3)) (-4 *3 (-582)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) ((*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-730 *3 *2 *4)) (-4 *3 (-869)) (-14 *4 (-1 (-141) (-2 (|:| -1825 *3) (|:| -3215 *2)) (-2 (|:| -1825 *3) (|:| -3215 *2))))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-533 *2)) (-14 *2 (-592)))) ((*1 *1 *1 *1) (-5 *1 (-1137)))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-128 *4 *3 *2 *5 *6)) (-4 *3 (-1255 *4)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-658 (-658 *7))) (-5 *1 (-473 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-977 *5 *6 *7)) (-5 *2 (-658 (-658 *8))) (-5 *1 (-473 *5 *6 *7 *8)) (-5 *3 (-658 *8)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-658 (-658 *7))) (-5 *1 (-473 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-977 *5 *6 *7)) (-5 *2 (-658 (-658 *8))) (-5 *1 (-473 *5 *6 *7 *8)) (-5 *3 (-658 *8))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1246 (-592))) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-664 *3)) (-4 *3 (-1225))))) 
+(((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-717)))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-717))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-658 *3)) (-4 *3 (-323)) (-5 *1 (-199 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *2 *3 *4 *5 *6 *7 *8 *9 *10)) (-4 *4 (-977 *2 *5 (-879 *3))) (-4 *5 (-252 (-1699 *3) (-790))) (-4 *6 (-999 *2)) (-4 *7 (-665 *2)) (-4 *8 (-947 *2 *7)) (-4 *9 (-257 *8)) (-4 *10 (-137)) (-4 *2 (-388))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1190)) (-5 *1 (-350))))) 
+(((*1 *1 *1) (-4 *1 (-1158)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-631 *3)) (-4 *3 (-869))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-658 (-278))) (-5 *4 (-1191)) (-5 *1 (-277 *2)) (-4 *2 (-1225)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-658 (-278))) (-5 *4 (-1191)) (-5 *2 (-57)) (-5 *1 (-278)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-658 (-489))) (-5 *4 (-1191)) (-5 *2 (-57)) (-5 *1 (-489))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-268 *2 *3 *4 *5)) (-4 *2 (-1075)) (-4 *3 (-869)) (-4 *4 (-284 *3)) (-4 *5 (-815))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-57)) (-5 *1 (-851))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-143)) (-5 *1 (-1052 *4 *3)) (-4 *3 (-13 (-456 *4) (-23) (-1065 (-592)) (-1065 (-1191)) (-922 (-1191)) (-182)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-565)) (-5 *1 (-564 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *2 (-57)) (-5 *1 (-565))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3)))) ((*1 *2 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-609 *2)) (-4 *2 (-388))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-261 *2)) (-4 *2 (-1225)))) ((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) ((*1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-141)) (-5 *1 (-951 *4 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-141)) (-5 *1 (-951 *4 *5 *6 *7)) (-4 *7 (-977 *4 *6 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-592))) (-5 *4 (-592)) (-5 *2 (-57)) (-5 *1 (-1033))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *3 (-388)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-553 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-582)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-4 *7 (-1021 *4)) (-4 *2 (-704 *7 *8 *9)) (-5 *1 (-554 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-704 *4 *5 *6)) (-4 *8 (-399 *7)) (-4 *9 (-399 *7)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-388)))) ((*1 *2 *2) (|partial| -12 (-4 *3 (-388)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-705 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) ((*1 *1 *1) (|partial| -12 (-5 *1 (-706 *2)) (-4 *2 (-388)) (-4 *2 (-1075)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-1140 *2 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-252 *2 *3)) (-4 *5 (-252 *2 *3)) (-4 *3 (-388)))) ((*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-1197 *3))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-592)) (-5 *3 (-986 (-191 (-405)))) (-5 *1 (-135))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *1 *2 *3 *4) (-12 (-14 *5 (-658 (-1191))) (-4 *2 (-194)) (-4 *4 (-252 (-1699 *5) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *3) (|:| -3215 *4)) (-2 (|:| -1825 *3) (|:| -3215 *4)))) (-5 *1 (-487 *5 *2 *3 *4 *6 *7)) (-4 *3 (-869)) (-4 *7 (-977 *2 *4 (-879 *5)))))) 
+(((*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *4 (-592)) (-5 *6 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-790)) (-5 *1 (-553 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-582)) (-5 *2 (-790)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-790)) (-5 *1 (-705 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-4 *5 (-582)) (-5 *2 (-790))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-582)) (-5 *2 (-2 (|:| -3253 (-706 *5)) (|:| |vec| (-1280 (-658 (-944)))))) (-5 *1 (-95 *5 *3)) (-5 *4 (-944)) (-4 *3 (-670 *5))))) 
+(((*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (-12 (-5 *4 (-592)) (-5 *6 (-1 (-1285) (-1280 *5) (-1280 *5) (-405))) (-5 *3 (-1280 (-405))) (-5 *5 (-405)) (-5 *2 (-1285)) (-5 *1 (-810))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-1017 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-1126 *3 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-700 *4 *5 *6)) (-4 *4 (-1119))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-871 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121 *5)) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-872 *5 *3)) (-4 *3 (-871 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))) (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *2 (-141)) (-5 *1 (-539 *4 *5))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-592)) (-5 *2 (-141)) (-5 *1 (-578))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-565))))) 
+(((*1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-256))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *12)) (-5 *1 (-282 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *12)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-5 *2 (-658 (-281 (-561 *3 *4 *5)))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-658 (-281 (-537 *3 *4 *5)))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-661 *3)) (-4 *3 (-1075)) (-5 *1 (-731 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-856 *3))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-585 *3)) (-4 *3 (-574)))) ((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-759 *4 *5 *6 *3)) (-4 *3 (-977 *6 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-759 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) ((*1 *2 *1) (-12 (-4 *3 (-477)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-444 *1)) (-4 *1 (-977 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-869)) (-4 *5 (-815)) (-4 *6 (-477)) (-5 *2 (-444 *3)) (-5 *1 (-1008 *4 *5 *6 *3)) (-4 *3 (-977 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-477)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-444 (-1187 (-433 *7)))) (-5 *1 (-1186 *4 *5 *6 *7)) (-5 *3 (-1187 (-433 *7))))) ((*1 *2 *1) (-12 (-5 *2 (-444 *1)) (-4 *1 (-1235)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-444 *3)) (-5 *1 (-1258 *4 *3)) (-4 *3 (-13 (-1255 *4) (-582) (-10 -8 (-15 -3548 ($ $ $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1072 *4 *5)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-658 (-1160 *4 (-558 (-879 *6)) (-879 *6) (-802 *4 (-879 *6))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191)))))) 
+(((*1 *1 *1) (-4 *1 (-675))) ((*1 *1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-862 *3))) (-4 *3 (-13 (-1211) (-987) (-29 *5))) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 *3)) (|:| |f2| (-658 (-862 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-231 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1111 (-862 *3))) (-5 *5 (-1173)) (-4 *3 (-13 (-1211) (-987) (-29 *6))) (-4 *6 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 *3)) (|:| |f2| (-658 (-862 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-231 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1111 (-862 (-332 *5)))) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 (-332 *5))) (|:| |f2| (-658 (-862 (-332 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-232 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-433 (-980 *6))) (-5 *4 (-1111 (-862 (-332 *6)))) (-5 *5 (-1173)) (-4 *6 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 (-332 *6))) (|:| |f2| (-658 (-862 (-332 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-232 *6)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-862 (-433 (-980 *5))))) (-5 *3 (-433 (-980 *5))) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 (-332 *5))) (|:| |f2| (-658 (-862 (-332 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-232 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1111 (-862 (-433 (-980 *6))))) (-5 *5 (-1173)) (-5 *3 (-433 (-980 *6))) (-4 *6 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (|:| |f1| (-862 (-332 *6))) (|:| |f2| (-658 (-862 (-332 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-232 *6)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 *3 (-658 *3))) (-5 *1 (-454 *5 *3)) (-4 *3 (-13 (-1211) (-987) (-29 *5))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-503 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1113 (-862 (-405)))) (-5 *5 (-405)) (-5 *6 (-1087)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3) (-12 (-5 *3 (-788)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1113 (-862 (-405)))) (-5 *5 (-405)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1113 (-862 (-405)))) (-5 *5 (-405)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-1113 (-862 (-405)))) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-1113 (-862 (-405))))) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-1113 (-862 (-405))))) (-5 *5 (-405)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-1113 (-862 (-405))))) (-5 *5 (-405)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-332 (-405))) (-5 *4 (-658 (-1113 (-862 (-405))))) (-5 *5 (-405)) (-5 *6 (-1087)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-862 (-405)))) (-5 *5 (-1173)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-332 (-405))) (-5 *4 (-1111 (-862 (-405)))) (-5 *5 (-1191)) (-5 *2 (-1063)) (-5 *1 (-593)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-592)))) (-4 *5 (-1255 *4)) (-5 *2 (-609 (-433 *5))) (-5 *1 (-596 *4 *5)) (-5 *3 (-433 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-171)) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-3 (-332 *5) (-658 (-332 *5)))) (-5 *1 (-612 *5)))) ((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-757 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-869)) (-4 *3 (-43 (-433 (-592)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-980 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)))) ((*1 *1 *1 *2 *3) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-4 *2 (-869)) (-5 *1 (-1143 *3 *2 *4)) (-4 *4 (-977 *3 (-558 *2) *2)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1181 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1188 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1189 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *1 (-1220 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 (QUOTE |x|))) (-5 *1 (-1237 *3)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-3836 (-12 (-5 *2 (-1191)) (-4 *1 (-1239 *3)) (-4 *3 (-1075)) (-12 (-4 *3 (-29 (-592))) (-4 *3 (-987)) (-4 *3 (-1211)) (-4 *3 (-43 (-433 (-592)))))) (-12 (-5 *2 (-1191)) (-4 *1 (-1239 *3)) (-4 *3 (-1075)) (-12 (|has| *3 (-15 -4085 ((-658 *2) *3))) (|has| *3 (-15 -3162 (*3 *3 *2))) (-4 *3 (-43 (-433 (-592)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1239 *2)) (-4 *2 (-1075)) (-4 *2 (-43 (-433 (-592)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-43 (-433 (-592)))))) ((*1 *1 *1 *2) (-3836 (-12 (-5 *2 (-1191)) (-4 *1 (-1260 *3)) (-4 *3 (-1075)) (-12 (-4 *3 (-29 (-592))) (-4 *3 (-987)) (-4 *3 (-1211)) (-4 *3 (-43 (-433 (-592)))))) (-12 (-5 *2 (-1191)) (-4 *1 (-1260 *3)) (-4 *3 (-1075)) (-12 (|has| *3 (-15 -4085 ((-658 *2) *3))) (|has| *3 (-15 -3162 (*3 *3 *2))) (-4 *3 (-43 (-433 (-592)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1260 *2)) (-4 *2 (-1075)) (-4 *2 (-43 (-433 (-592)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1264 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-3836 (-12 (-5 *2 (-1191)) (-4 *1 (-1270 *3)) (-4 *3 (-1075)) (-12 (-4 *3 (-29 (-592))) (-4 *3 (-987)) (-4 *3 (-1211)) (-4 *3 (-43 (-433 (-592)))))) (-12 (-5 *2 (-1191)) (-4 *1 (-1270 *3)) (-4 *3 (-1075)) (-12 (|has| *3 (-15 -4085 ((-658 *2) *3))) (|has| *3 (-15 -3162 (*3 *3 *2))) (-4 *3 (-43 (-433 (-592)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1270 *2)) (-4 *2 (-1075)) (-4 *2 (-43 (-433 (-592)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-43 (-433 (-592)))) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *4 *5 *4 *4 *4) (-12 (-4 *6 (-869)) (-5 *3 (-658 *6)) (-5 *5 (-658 *3)) (-5 *2 (-2 (|:| |f1| *3) (|:| |f2| (-658 *5)) (|:| |f3| *5) (|:| |f4| (-658 *5)))) (-5 *1 (-1197 *6)) (-5 *4 (-658 *5))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-477)) (-4 *4 (-869)) (-5 *1 (-601 *4 *2)) (-4 *2 (-301)) (-4 *2 (-456 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-658 (-658 *7))) (-5 *1 (-473 *4 *5 *6 *7)) (-5 *3 (-658 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-977 *5 *6 *7)) (-5 *2 (-658 (-658 *8))) (-5 *1 (-473 *5 *6 *7 *8)) (-5 *3 (-658 *8))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-477))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-790)) (-4 *4 (-373)) (-5 *1 (-229 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-944) (-141))) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-944) (-141))) (-5 *1 (-489))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *2)) (-5 *4 (-790)) (-4 *2 (-1119)) (-5 *1 (-695 *2))))) 
+(((*1 *1 *1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1171 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *1) (-5 *1 (-1087)))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-143))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-896)))) ((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-41 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-2 (|:| -1350 *3) (|:| -3552 *4)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *9)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-790)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *9)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-790)) (-5 *1 (-1159 *5 *6 *7 *8 *9))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-318)) (-4 *2 (-1225)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-631 *1))) (-5 *3 (-658 *1)) (-4 *1 (-318)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-310 *1))) (-4 *1 (-318)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-310 *1)) (-4 *1 (-318))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))))) ((*1 *2) (|partial| -12 (-4 *4 (-1235)) (-4 *5 (-1255 (-433 *2))) (-4 *2 (-1255 *4)) (-5 *1 (-361 *3 *4 *2 *5)) (-4 *3 (-362 *4 *2 *5)))) ((*1 *2) (|partial| -12 (-4 *1 (-362 *3 *2 *4)) (-4 *3 (-1235)) (-4 *4 (-1255 (-433 *2))) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *4 (-658 (-1191))) (-5 *2 (-706 (-332 (-237)))) (-5 *1 (-219)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *6 (-922 *5)) (-5 *2 (-706 *6)) (-5 *1 (-708 *5 *6 *3 *4)) (-4 *3 (-399 *6)) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4625))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3 *4) (-12 (-5 *2 (-2 (|:| |part1| *3) (|:| |part2| *4))) (-5 *1 (-722 *3 *4)) (-4 *3 (-1225)) (-4 *4 (-1225))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-879 *5))) (-14 *5 (-658 (-1191))) (-4 *6 (-477)) (-5 *2 (-2 (|:| |dpolys| (-658 (-264 *5 *6))) (|:| |coords| (-658 (-592))))) (-5 *1 (-500 *5 *6 *7)) (-5 *3 (-658 (-264 *5 *6))) (-4 *7 (-477))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-323)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-1141 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-592)) (-5 *1 (-256)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-592)) (-5 *1 (-256))))) 
+(((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) ((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-523 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-927 *4)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-926 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-944)) (-5 *2 (-141)) (-5 *1 (-1120 *4 *5)) (-14 *4 *3) (-14 *5 *3))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-658 *7)) (|:| |badPols| (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-944) "arbitrary")) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-944) "arbitrary")) (-5 *1 (-489))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 (-141) *6)) (-4 *6 (-13 (-1119) (-1065 *5))) (-4 *5 (-908 *4)) (-4 *4 (-1119)) (-5 *2 (-1 (-141) *5)) (-5 *1 (-959 *4 *5 *6))))) 
+(((*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1017 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1126 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-1161 (-1173))) (-5 *1 (-417))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-754 *3)))) ((*1 *1 *2) (-12 (-5 *1 (-754 *2)) (-4 *2 (-1119)))) ((*1 *1) (-12 (-5 *1 (-754 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *3 (-13 (-582) (-477))) (-5 *2 (-658 *3)) (-5 *1 (-369 *3 *5)) (-4 *5 (-52 *3 *4))))) 
+(((*1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-323)) (-5 *1 (-939 *3 *4 *5 *2)) (-4 *2 (-977 *5 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1187 *6)) (-4 *6 (-977 *5 *3 *4)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-323)) (-5 *1 (-939 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *6 *4 *5)) (-5 *1 (-939 *4 *5 *6 *2)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-589)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -3191 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-2 (|:| |answer| (-609 (-433 *7))) (|:| |a0| *6))) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *1 (-1175 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-5 *2 (-141)) (-5 *1 (-255 *4)) (-4 *4 (-1075))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (|has| *1 (-6 -4625)) (-4 *1 (-175 *3)) (-4 *3 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *1 (-690 *3)) (-4 *3 (-1225)))) ((*1 *2 *1 *3) (|partial| -12 (-4 *1 (-1219 *4 *5 *3 *2)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *3 (-869)) (-4 *2 (-1089 *4 *5 *3)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *1 (-1223 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 *7)) (-4 *7 (-869)) (-4 *8 (-977 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-5 *2 (-2 (|:| |particular| (-3 (-1280 (-433 *8)) "failed")) (|:| -2195 (-658 (-1280 (-433 *8)))))) (-5 *1 (-686 *5 *6 *7 *8))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-2 (|:| |poly| *6) (|:| -2042 *3)))) (-5 *1 (-831 *5 *6 *3 *7)) (-4 *3 (-670 *6)) (-4 *7 (-670 (-433 *6))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-658 *5) *6)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-5 *2 (-658 (-2 (|:| |poly| *6) (|:| -2042 (-668 *6 (-433 *6)))))) (-5 *1 (-834 *5 *6)) (-5 *3 (-668 *6 (-433 *6)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-405)))) ((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-405))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-658 *1)) (-4 *1 (-408 *3 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-752 *3 *4))) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) ((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *2 (-658 *3)) (-5 *1 (-935 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) ((*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-977 *3 *4 *5))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-944))) (-5 *1 (-1120 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-141)) (-5 *1 (-285))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3))))) 
+(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-914 *4)) (-4 *4 (-1119)) (-5 *1 (-911 *4 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1280 (-790))) (-5 *1 (-691 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-954)) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-954)) (-5 *4 (-433 (-592))) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)) (-5 *3 (-658 (-971 (-237)))))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 (-237))))) (|:| |xValues| (-1113 (-237))) (|:| |yValues| (-1113 (-237))))) (-5 *1 (-177)) (-5 *3 (-658 (-658 (-971 (-237))))))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-278)))) ((*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-278))))) 
+(((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *6 (-13 (-582) (-869))) (-5 *2 (-658 (-332 *6))) (-5 *1 (-233 *5 *6)) (-5 *3 (-332 *6)) (-4 *5 (-1075)))) ((*1 *2 *1) (-12 (-5 *1 (-444 *2)) (-4 *2 (-582)))) ((*1 *2 *3) (-12 (-5 *3 (-609 *5)) (-4 *5 (-13 (-29 *4) (-1211))) (-4 *4 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-658 *5)) (-5 *1 (-607 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-609 (-433 (-980 *4)))) (-4 *4 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-658 (-332 *4))) (-5 *1 (-612 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1114 *3 *2)) (-4 *3 (-867)) (-4 *2 (-1163 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1114 *4 *2)) (-4 *4 (-867)) (-4 *2 (-1163 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211))))) ((*1 *2 *1) (-12 (-5 *2 (-1293 (-1191) *3)) (-5 *1 (-1300 *3)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-5 *2 (-1293 *3 *4)) (-5 *1 (-1302 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-706 (-332 (-592))))) (-5 *1 (-1059))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (-12 (-4 *4 (-1119)) (-5 *2 (-911 *3 *4)) (-5 *1 (-907 *3 *4 *5)) (-4 *3 (-1119)) (-4 *5 (-683 *4))))) 
+(((*1 *2 *1) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-4 *5 (-252 (-1699 *3) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *2) (|:| -3215 *5)) (-2 (|:| -1825 *2) (|:| -3215 *5)))) (-4 *2 (-869)) (-5 *1 (-487 *3 *4 *2 *5 *6 *7)) (-4 *7 (-977 *4 *5 (-879 *3)))))) 
+(((*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-557 *3)) (-4 *3 (-13 (-743) (-25)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 *4) (-790))))) (-5 *1 (-508 *4)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 *4) (-790)))) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 (-1191))) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) (-1191) *6)) (|:| C (-1 (-658 *5) (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 *3)) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) *3 *6)) (|:| C (-1 (-658 *5) (-790)))) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 HPSPEC) (-5 *1 (-512 *4)) (-14 *4 (-1191)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 HPSPEC (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-381 *3)) (-4 *3 (-373))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |cd| (-1173)) (|:| -4095 (-1173)))) (-5 *1 (-844))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-878)))) ((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-878)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-877)) (-5 *2 (-1285)) (-5 *1 (-878)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-1171 *4)) (-4 *4 (-1119)) (-4 *4 (-1225))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1280 (-658 (-592)))) (-5 *1 (-515)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-706 (-332 (-592)))) (-5 *1 (-1059))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-706 *4)) (-4 *4 (-1075)) (-5 *1 (-1156 *3 *4)) (-14 *3 (-790))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-229 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-658 *3)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-658 *3)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-790))) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-790))) (-5 *5 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-790)) (-5 *2 (-444 *3)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1035 *3)) (-4 *3 (-1255 (-433 (-592)))))) ((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-1244 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-977 *4 *5 *6)) (-5 *2 (-444 (-1187 *7))) (-5 *1 (-928 *4 *5 *6 *7)) (-5 *3 (-1187 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-1255 *4)) (-5 *2 (-444 (-1187 *5))) (-5 *1 (-929 *4 *5)) (-5 *3 (-1187 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1155 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39)))))) 
+(((*1 *1 *1) (|partial| -12 (-5 *1 (-1155 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39)))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-219))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-592))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1113 (-592))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-256)) (-5 *3 (-1173)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-141)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *7))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *3 (-658 (-896))) (-5 *1 (-497))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-347 *3)) (-4 *3 (-1225)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-549 *3 *4)) (-4 *3 (-1225)) (-14 *4 (-592))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-332 *5))) (-5 *1 (-1146 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 *5)))) (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-658 (-658 (-332 *5)))) (-5 *1 (-1146 *5))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *3 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *3 (-869)) (-4 *6 (-1089 *4 *5 *3)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-953))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-171))) (-5 *1 (-566 *3 *2)) (-4 *2 (-1270 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-4 *4 (-1255 *3)) (-4 *5 (-741 *3 *4)) (-5 *1 (-570 *3 *4 *5 *2)) (-4 *2 (-1270 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-5 *1 (-571 *3 *2)) (-4 *2 (-1270 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-13 (-582) (-171))) (-5 *1 (-1166 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -2324 *4) (|:| -3775 (-592))))) (-4 *4 (-1119)) (-5 *2 (-1 *4)) (-5 *1 (-1045 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-565))) (-5 *2 (-1191)) (-5 *1 (-565))))) 
+(((*1 *2 *3 *4 *5 *5) (-12 (-5 *5 (-790)) (-4 *6 (-1119)) (-4 *7 (-922 *6)) (-5 *2 (-706 *7)) (-5 *1 (-708 *6 *7 *3 *4)) (-4 *3 (-399 *7)) (-4 *4 (-13 (-399 *6) (-10 -7 (-6 -4625))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-841 *4)) (-4 *4 (-869)) (-5 *2 (-141)) (-5 *1 (-688 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-392 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-5 *2 (-658 (-2 (|:| C (-706 *5)) (|:| |g| (-1280 *5))))) (-5 *1 (-1007 *5)) (-5 *3 (-706 *5)) (-5 *4 (-1280 *5))))) 
+(((*1 *2) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-141)) (-5 *1 (-361 *3 *4 *5 *6)) (-4 *3 (-362 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-1173)) (-5 *1 (-206)))) ((*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-1173)) (-5 *1 (-316)))) ((*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-1173)) (-5 *1 (-321))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-5 *2 (-658 *6)) (-5 *1 (-935 *4 *5 *6 *7)) (-4 *5 (-346 *4 *6))))) 
+(((*1 *2 *2 *3 *4 *5) (-12 (-5 *3 (-143)) (-5 *2 (-592)) (-5 *4 (-1191)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *1 (-1052 *6 *5)) (-4 *5 (-13 (-456 *6) (-23) (-1065 *2) (-1065 *4) (-922 *4) (-182)))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-141))))) 
+(((*1 *1 *2 *1) (|partial| -12 (-5 *2 (-150)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1301 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-865))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-388)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-553 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-4 *7 (-1021 *4)) (-4 *2 (-704 *7 *8 *9)) (-5 *1 (-554 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-704 *4 *5 *6)) (-4 *8 (-399 *7)) (-4 *9 (-399 *7)))) ((*1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-323)))) ((*1 *2 *2) (-12 (-4 *3 (-323)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-705 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-323)) (-5 *1 (-716 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-1078 *2 *3 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-252 *3 *4)) (-4 *6 (-252 *2 *4)) (-4 *4 (-323))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| *8) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 *8))))) (-5 *1 (-951 *5 *6 *7 *8)) (-5 *4 (-790))))) 
+(((*1 *1 *1 *2) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39)))))) 
+(((*1 *1) (-5 *1 (-463)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-592))))) 
+(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1038 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2) (-12 (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-658 (-706 *4))) (-5 *2 (-706 *4)) (-4 *4 (-1075)) (-5 *1 (-1057 *4))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *1) (-5 *1 (-1087)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-388)) (-5 *1 (-673 *4 *2)) (-4 *2 (-670 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-36 *4 *5)) (-4 *5 (-456 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-180 *4 *5)) (-4 *5 (-456 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-294 *4 *5)) (-4 *5 (-13 (-456 *4) (-1030))))) ((*1 *2 *3) (-12 (-5 *3 (-143)) (-5 *2 (-141)) (-5 *1 (-317 *4)) (-4 *4 (-318)))) ((*1 *2 *3) (-12 (-4 *1 (-318)) (-5 *3 (-143)) (-5 *2 (-141)))) ((*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-455 *4 *5)) (-4 *4 (-456 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-457 *4 *5)) (-4 *5 (-456 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-143)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-645 *4 *5)) (-4 *5 (-13 (-456 *4) (-1030) (-1211)))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |polnum| (-804 *3)) (|:| |polden| *3) (|:| -3116 (-790)))) (-5 *1 (-804 *3)) (-4 *3 (-1075)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| |polnum| *1) (|:| |polden| *1) (|:| -3116 (-790)))) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *2) (-12 (-4 *2 (-13 (-456 *3) (-1030))) (-5 *1 (-294 *3 *2)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-3 (-1 (-237) (-237) (-237) (-237)) "undefined")) (-5 *5 (-1113 (-237))) (-5 *6 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-713)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-237))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-713)))) ((*1 *2 *2 *3 *4 *4 *5) (-12 (-5 *2 (-1150 (-237))) (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-237))) (-5 *5 (-658 (-278))) (-5 *1 (-713))))) 
+(((*1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-658 *1)) (-4 *1 (-947 *3 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-2 (|:| |k| (-841 *3)) (|:| |c| *4)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-5 *3 (-658 *7)) (-4 *1 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *2)) (-4 *2 (-194)))) ((*1 *2) (-12 (-4 *2 (-194)) (-5 *1 (-442 *3 *2)) (-4 *3 (-443 *2)))) ((*1 *2) (-12 (-4 *1 (-443 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-877)))) ((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-990))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-944)) (-4 *5 (-582)) (-5 *2 (-706 *5)) (-5 *1 (-984 *5 *3)) (-4 *3 (-670 *5))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1005 *4 *5 *6 *3)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-5 *2 (-2 (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4)))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-877))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-2 (|:| |start| *3) (|:| -2033 (-444 *3)))) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-388)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-553 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 (-1187 (-1187 *4)))) (-5 *1 (-1224 *4)) (-5 *3 (-1187 (-1187 *4)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1171 (-1171 *4))) (-5 *2 (-1171 *4)) (-5 *1 (-1175 *4)) (-4 *4 (-43 (-433 (-592)))) (-4 *4 (-1075))))) 
+(((*1 *2 *3 *3 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-1 (-658 *4) *4)) (-5 *1 (-127 *4)) (-5 *3 (-658 *4))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-332 (-237))) (-5 *1 (-285))))) 
+(((*1 *2 *3 *4 *3 *3) (-12 (-5 *3 (-310 *6)) (-5 *4 (-143)) (-4 *6 (-456 *5)) (-4 *5 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *5 *6)))) ((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-310 *7)) (-5 *4 (-143)) (-5 *5 (-658 *7)) (-4 *7 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *7)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-658 (-310 *7))) (-5 *4 (-658 (-143))) (-5 *5 (-310 *7)) (-4 *7 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 (-310 *8))) (-5 *4 (-658 (-143))) (-5 *5 (-310 *8)) (-5 *6 (-658 *8)) (-4 *8 (-456 *7)) (-4 *7 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *7 *8)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-658 *7)) (-5 *4 (-658 (-143))) (-5 *5 (-310 *7)) (-4 *7 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 *8)) (-5 *4 (-658 (-143))) (-5 *6 (-658 (-310 *8))) (-4 *8 (-456 *7)) (-5 *5 (-310 *8)) (-4 *7 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *7 *8)))) ((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-310 *5)) (-5 *4 (-143)) (-4 *5 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *5)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-143)) (-5 *5 (-310 *3)) (-4 *3 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *3)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-143)) (-5 *5 (-310 *3)) (-4 *3 (-456 *6)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *6 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-143)) (-5 *5 (-310 *3)) (-5 *6 (-658 *3)) (-4 *3 (-456 *7)) (-4 *7 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-57)) (-5 *1 (-333 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-143)) (-5 *5 (-1191)) (-5 *6 (-658 *3)) (-4 *3 (-456 *7)) (-4 *7 (-13 (-869) (-582) (-633 (-565)))) (-4 *2 (-1270 *3)) (-5 *1 (-334 *7 *3 *2 *8)) (-4 *8 (-1270 (-1185 *3))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *6)) (-5 *4 (-658 *5)) (-4 *5 (-388)) (-4 *6 (-1270 (-1185 *5))) (-4 *2 (-1270 *5)) (-5 *1 (-1274 *5 *2 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 *5)) (-4 *5 (-13 (-582) (-477))) (-5 *4 (-790)) (-5 *2 (-433 (-1187 *5))) (-5 *1 (-369 *5 *6)) (-4 *6 (-52 *5 *4)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 (-433 *5))) (-4 *5 (-13 (-582) (-477))) (-5 *4 (-790)) (-5 *2 (-433 (-1187 *5))) (-5 *1 (-369 *5 *6)) (-4 *6 (-52 *5 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1252 *4 *5)) (-5 *3 (-658 *5)) (-14 *4 (-1191)) (-4 *5 (-388)) (-5 *1 (-946 *4 *5)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 *5)) (-4 *5 (-388)) (-5 *2 (-1187 *5)) (-5 *1 (-946 *4 *5)) (-14 *4 (-1191)))) ((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-790)) (-4 *6 (-388)) (-5 *2 (-433 (-980 *6))) (-5 *1 (-1076 *5 *6)) (-14 *5 (-1191))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-141)) (-5 *1 (-143)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-318)) (-5 *3 (-1191)) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-318)) (-5 *3 (-143)) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-141)) (-5 *1 (-631 *4)) (-4 *4 (-869)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-143)) (-5 *2 (-141)) (-5 *1 (-631 *4)) (-4 *4 (-869)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-5 *2 (-141)) (-5 *1 (-909 *5 *3 *4)) (-4 *3 (-908 *5)) (-4 *4 (-633 (-914 *5))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-4 *6 (-908 *5)) (-4 *5 (-1119)) (-5 *2 (-141)) (-5 *1 (-909 *5 *6 *4)) (-4 *4 (-633 (-914 *5)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-137)) (-4 *2 (-257 *9))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-388)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1112 *3)) (-4 *3 (-1225)) (-5 *2 (-592))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-658 (-1191))) (-5 *2 (-658 (-658 (-405)))) (-5 *1 (-1050)) (-5 *5 (-405)))) ((*1 *2 *3) (-12 (-5 *3 (-1072 *4 *5)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-658 (-658 (-1051 (-433 *4))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *5))))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-658 (-1051 (-433 *4))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-592))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-1187 (-980 *4))) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) ((*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-4 *3 (-388)) (-5 *2 (-1187 (-980 *3))))) ((*1 *2) (-12 (-5 *2 (-1187 (-433 (-980 *3)))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-237))) (-5 *2 (-237)) (-5 *1 (-135))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-234 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-869)) (-5 *2 (-141)) (-5 *1 (-518 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| *1 (-6 -4625)) (-4 *1 (-523 *4)) (-4 *4 (-1225)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-1028 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (|has| $ (-6 -4625)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-1161 *4))))) 
+(((*1 *1) (-4 *1 (-23))) ((*1 *1) (-4 *1 (-39))) ((*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) ((*1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *1) (-4 *1 (-743))) ((*1 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) ((*1 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) ((*1 *1) (-5 *1 (-1191)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-163)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-168))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *1) (-5 *1 (-497)))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190))))) 
+(((*1 *2 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-2 (|:| |k| *4) (|:| |c| *3)))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-582)) (-5 *1 (-998 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-1191)) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-658 (-237))) (-5 *1 (-206)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-1191)) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-658 (-237))) (-5 *1 (-316))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| |radicand| (-433 *5)) (|:| |deg| (-790)))) (-5 *1 (-172 *4 *5 *3)) (-4 *3 (-1255 (-433 *5)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-658 *8))) (-5 *3 (-658 *8)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-141)) (-5 *1 (-951 *5 *6 *7 *8))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-592)) (-4 *6 (-665 *5)) (-4 *5 (-388)) (-5 *2 (-706 *5)) (-5 *1 (-659 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-698 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-844))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-342 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-158)) (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 *4)))))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| -1487 *3) (|:| -1493 *4)))) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) ((*1 *2 *1) (-12 (-4 *1 (-1257 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-1171 (-2 (|:| |k| *4) (|:| |c| *3))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-5 *1 (-520 *2)) (-4 *2 (-1255 (-592)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-869)) (-4 *4 (-388)) (-4 *5 (-815)) (-5 *2 (-141)) (-5 *1 (-538 *4 *5 *6 *7)) (-4 *7 (-977 *4 *5 *6))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *1)))) (-4 *1 (-1094 *4 *5 *6 *3))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 *4)) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-4 *4 (-1075)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-867))) (-5 *1 (-200 *3 *2)) (-4 *2 (-1255 (-191 *3)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-350))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-658 (-658 (-790)))))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *7)) (-4 *7 (-869)) (-4 *5 (-931)) (-4 *6 (-815)) (-4 *8 (-977 *5 *6 *7)) (-5 *2 (-444 (-1187 *8))) (-5 *1 (-928 *5 *6 *7 *8)) (-5 *4 (-1187 *8)))) ((*1 *2 *3) (-12 (-4 *4 (-931)) (-4 *5 (-1255 *4)) (-5 *2 (-444 (-1187 *5))) (-5 *1 (-929 *4 *5)) (-5 *3 (-1187 *5))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-582)) (-5 *1 (-639 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-790))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1129)) (-5 *3 (-592))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1219 *2 *3 *4 *5)) (-4 *2 (-582)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-1089 *2 *3 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (-592)))) (-4 *4 (-13 (-1255 *3) (-582) (-10 -8 (-15 -3548 ($ $ $))))) (-4 *3 (-582)) (-5 *1 (-1258 *3 *4))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-4 *5 (-456 *4)) (-5 *2 (-444 (-1187 (-433 (-592))))) (-5 *1 (-461 *4 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1285)) (-5 *1 (-474 *4 *5 *6 *3)) (-4 *3 (-977 *4 *5 *6))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-388)) (-5 *2 (-658 *3)) (-5 *1 (-973 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *2 (-790) (-790) *7)) (-5 *4 (-1280 *7)) (-5 *5 (-790)) (-5 *6 (-1280 (-1187 *2))) (-4 *7 (-52 *2 *5)) (-4 *2 (-13 (-582) (-477))) (-5 *1 (-369 *2 *7))))) 
+(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3))))) 
+(((*1 *2 *3) (-12 (|has| *2 (-6 (-4627 "*"))) (-4 *5 (-399 *2)) (-4 *6 (-399 *2)) (-4 *2 (-1075)) (-5 *1 (-128 *2 *3 *4 *5 *6)) (-4 *3 (-1255 *2)) (-4 *4 (-704 *2 *5 *6))))) 
+(((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *4 (-237)) (-5 *2 (-2 (|:| |brans| (-658 (-658 (-971 *4)))) (|:| |xValues| (-1113 *4)) (|:| |yValues| (-1113 *4)))) (-5 *1 (-177)) (-5 *3 (-658 (-658 (-971 *4))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1163 *3)) (-4 *3 (-1225)) (-5 *2 (-141))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-658 (-592))) (-5 *3 (-706 (-592))) (-5 *1 (-1129))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1280 (-658 *3))) (-4 *4 (-323)) (-5 *2 (-658 *3)) (-5 *1 (-481 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-141)) (-5 *1 (-202 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 (-191 *4)))))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-141)) (-5 *1 (-1215 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-237)))) ((*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) ((*1 *1 *1) (-4 *1 (-574))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-615 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1119)) (-5 *2 (-1137)))) ((*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-430)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-715))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-148 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3)))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-456 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-977 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-658 *3)) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $)))))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-658 (-971 *4))) (-4 *1 (-1151 *4)) (-4 *4 (-1075)) (-5 *2 (-790))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *3)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)) (-4 *2 (-456 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-182)) (-5 *2 (-1191)))) ((*1 *1 *1) (-4 *1 (-182)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-39)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)) (-5 *2 (-141)) (-5 *1 (-1016 *3 *4 *5 *6)) (-4 *6 (-977 *3 *5 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1154 *3 *4)) (-4 *3 (-13 (-1119) (-39))) (-4 *4 (-13 (-1119) (-39))))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-587))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *5 (-349 *4)) (-4 *6 (-1255 *5)) (-5 *2 (-658 *3)) (-5 *1 (-796 *4 *5 *6 *3 *7)) (-4 *3 (-1255 *6)) (-14 *7 (-944))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-1187 (-980 *4)) (-980 *4))) (-5 *1 (-1288 *4)) (-4 *4 (-388))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-980 (-237))) (-5 *2 (-237)) (-5 *1 (-321))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *5 *5 *6 *7 *8 *8 *3) (-12 (-5 *6 (-658 (-141))) (-5 *7 (-706 (-237))) (-5 *8 (-706 (-592))) (-5 *3 (-592)) (-5 *4 (-237)) (-5 *5 (-141)) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *2 (-658 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592)))))) (-5 *1 (-539 *4 *5)) (-5 *3 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592)))))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) ((*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) ((*1 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-394)) (-4 *2 (-388)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-355 *3 *4 *5 *2)) (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *2 (-362 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-416 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-194)))) ((*1 *1) (-12 (-4 *2 (-194)) (-4 *1 (-741 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) ((*1 *2 *2) (-12 (-4 *3 (-388)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-694 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1075)) (-5 *1 (-706 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *4)) (-4 *4 (-1075)) (-4 *1 (-1140 *3 *4 *5 *6)) (-4 *5 (-252 *3 *4)) (-4 *6 (-252 *3 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-179)))) ((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *2) (-12 (-4 *3 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-1285)) (-5 *1 (-459 *3 *4)) (-4 *4 (-456 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-439 *3 *4 *5 *6)) (-4 *6 (-1065 *4)) (-4 *3 (-323)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-4 *6 (-435 *4 *5)) (-14 *7 (-1280 *6)) (-5 *1 (-440 *3 *4 *5 *6 *7)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *6)) (-4 *6 (-435 *4 *5)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-4 *3 (-323)) (-5 *1 (-440 *3 *4 *5 *6 *7)) (-14 *7 *2)))) 
+(((*1 *2 *3 *3 *3 *4 *4 *4 *4 *5 *6 *5 *4 *7 *3) (-12 (-5 *4 (-706 (-592))) (-5 *5 (-141)) (-5 *7 (-706 (-237))) (-5 *3 (-592)) (-5 *6 (-237)) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-141))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *5)) (-4 *5 (-194)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790))))) 
+(((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-706 (-433 *4)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-388)) (-5 *2 (-658 *5)) (-5 *1 (-659 *5 *3)) (-4 *3 (-665 *5))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *5 *6 *6 *7 *7 *3) (-12 (-5 *4 (-658 (-141))) (-5 *5 (-706 (-237))) (-5 *6 (-706 (-592))) (-5 *7 (-237)) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-592)) (-5 *4 (-444 *2)) (-4 *2 (-977 *7 *5 *6)) (-5 *1 (-759 *5 *6 *7 *2)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-323))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1038 *3)) (-4 *3 (-1225)) (-5 *2 (-592))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1270 *3))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-658 *3)) (-5 *1 (-989 *3)) (-4 *3 (-574))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-1200 *2)) (-4 *2 (-388))))) 
+(((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-629 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1119))))) 
+(((*1 *2) (-12 (-5 *2 (-706 (-932 *3))) (-5 *1 (-375 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) ((*1 *2) (-12 (-5 *2 (-706 *3)) (-5 *1 (-376 *3 *4)) (-4 *3 (-373)) (-14 *4 (-3 (-1187 *3) (-1280 (-658 (-2 (|:| -2324 *3) (|:| -1825 (-1137))))))))) ((*1 *2) (-12 (-5 *2 (-706 *3)) (-5 *1 (-377 *3 *4)) (-4 *3 (-373)) (-14 *4 (-944))))) 
+(((*1 *2 *3 *4 *3 *5 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-790))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-658 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-141) *2)) (-4 *2 (-159)) (-5 *1 (-1104 *2)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-592) *2 *2)) (-4 *2 (-159)) (-5 *1 (-1104 *2))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-477)) (-4 *3 (-869)) (-4 *3 (-1065 (-592))) (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-456 *3)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $)))))))))) 
+(((*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1187 (-433 (-980 *3)))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-582)) (-5 *2 (-1187 *4)) (-5 *1 (-786 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-790))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *3 *3 *2) (|partial| -12 (-5 *2 (-790)) (-4 *3 (-13 (-743) (-394) (-10 -7 (-15 ** (*3 *3 (-592)))))) (-5 *1 (-263 *3))))) 
+(((*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-851))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-160))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *1 (-497))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-193)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-143)) (-4 *2 (-1119)) (-4 *2 (-869)) (-5 *1 (-142 *2))))) 
+(((*1 *1) (-4 *1 (-39))) ((*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *1) (-5 *1 (-877))) ((*1 *1) (-12 (-4 *2 (-477)) (-4 *3 (-869)) (-4 *4 (-815)) (-5 *1 (-1016 *2 *3 *4 *5)) (-4 *5 (-977 *2 *4 *3)))) ((*1 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) ((*1 *1) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39))))) ((*1 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) ((*1 *1) (-5 *1 (-1194))) ((*1 *1) (-5 *1 (-1195)))) 
+(((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-658 (-631 *2))) (-5 *4 (-1191)) (-4 *2 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *5 *2))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-5 *1 (-927 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1 (-971 (-237)) (-237) (-237))) (-5 *3 (-1 (-237) (-237) (-237) (-237))) (-5 *1 (-270))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *5)) (-4 *5 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-433 (-592))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-310 *3)) (-5 *5 (-433 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-592))) (-5 *4 (-310 *6)) (-4 *6 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-592))) (-5 *4 (-310 *7)) (-5 *5 (-1246 (-592))) (-4 *7 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-433 (-592)))) (-5 *4 (-310 *8)) (-5 *5 (-1246 (-433 (-592)))) (-5 *6 (-433 (-592))) (-4 *8 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-433 (-592)))) (-5 *7 (-433 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *8))) (-4 *8 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *8 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))) (-4 *3 (-1075)) (-5 *1 (-617 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-618 *3)))) ((*1 *1 *2 *3 *1) (-12 (-5 *2 (-592)) (-4 *1 (-665 *3)) (-4 *3 (-388)))) ((*1 *1 *2) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))) (-4 *3 (-1075)) (-4 *1 (-1239 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *3 (-1171 (-2 (|:| |k| (-433 (-592))) (|:| |c| *4)))) (-4 *4 (-1075)) (-4 *1 (-1260 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-4 *1 (-1270 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-790)) (|:| |c| *3)))) (-4 *3 (-1075)) (-4 *1 (-1270 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-388)) (-5 *1 (-302 *3 *2)) (-4 *2 (-1270 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1123)) (-5 *1 (-1195))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-841 *3)) (-4 *3 (-869)) (-5 *1 (-688 *3))))) 
+(((*1 *2 *3 *1) (|partial| -12 (-5 *3 (-914 *4)) (-4 *4 (-1119)) (-4 *2 (-1119)) (-5 *1 (-911 *4 *2))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-163)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-168))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *2 (-1063)) (-5 *1 (-321)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063)))) (-5 *2 (-1063)) (-5 *1 (-321))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1173)) (-5 *4 (-592)) (-5 *5 (-706 (-191 (-237)))) (-5 *2 (-1063)) (-5 *1 (-773))))) 
+(((*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (-12 (-5 *3 (-944)) (-5 *4 (-237)) (-5 *5 (-592)) (-5 *6 (-896)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-706 *5))) (-5 *4 (-1280 *5)) (-4 *5 (-323)) (-4 *5 (-1075)) (-5 *2 (-706 *5)) (-5 *1 (-1057 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-560 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *10)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-280 *11))))) 
+(((*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| -12 (-5 *2 (-658 (-1187 *11))) (-5 *3 (-1187 *11)) (-5 *4 (-658 *10)) (-5 *5 (-658 *8)) (-5 *6 (-658 (-790))) (-5 *7 (-1280 (-658 (-1187 *8)))) (-4 *10 (-869)) (-4 *8 (-323)) (-4 *11 (-977 *8 *9 *10)) (-4 *9 (-815)) (-5 *1 (-724 *9 *10 *8 *11))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-195 (-433 (-592)))) (-5 *1 (-146 *3)) (-14 *3 (-592)))) ((*1 *1 *2 *3 *3) (-12 (-5 *3 (-1171 *2)) (-4 *2 (-323)) (-5 *1 (-195 *2)))) ((*1 *1 *2) (-12 (-5 *2 (-433 *3)) (-4 *3 (-323)) (-5 *1 (-195 *3)))) ((*1 *2 *3) (-12 (-5 *2 (-195 (-592))) (-5 *1 (-784 *3)) (-4 *3 (-430)))) ((*1 *2 *1) (-12 (-5 *2 (-195 (-433 (-592)))) (-5 *1 (-892 *3)) (-14 *3 (-592)))) ((*1 *2 *1) (-12 (-14 *3 (-592)) (-5 *2 (-195 (-433 (-592)))) (-5 *1 (-893 *3 *4)) (-4 *4 (-890 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1173)) (-5 *1 (-321))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-755))))) 
+(((*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (-12 (-5 *3 (-592)) (-5 *5 (-141)) (-5 *6 (-706 (-237))) (-5 *7 (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN)))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-592)) (-5 *1 (-1133 *4 *5))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1272 *3 *2)) (-4 *2 (-1270 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-592)) (-4 *4 (-1075)) (-5 *1 (-1175 *4)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-1191))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1119)) (-5 *2 (-1285)) (-5 *1 (-1232 *4)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1119)) (-5 *2 (-1285)) (-5 *1 (-1232 *4))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-84 LSFUN1)))) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-790)) (-5 *6 (-141)) (-4 *7 (-477)) (-4 *8 (-815)) (-4 *9 (-869)) (-4 *3 (-1089 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *7 *8 *9 *3 *4)) (-4 *4 (-1094 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-790)) (-5 *6 (-141)) (-4 *7 (-477)) (-4 *8 (-815)) (-4 *9 (-869)) (-4 *3 (-1089 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *7 *8 *9 *3 *4)) (-4 *4 (-1128 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *6 *7 *8 *3 *4)) (-4 *4 (-1128 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *5 *6 *7 *3 *4)) (-4 *4 (-1128 *5 *6 *7 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-847))))) 
+(((*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-658 (-1191))) (-4 *6 (-388)) (-5 *2 (-658 (-310 (-980 *6)))) (-5 *1 (-567 *5 *6 *7)) (-4 *5 (-477)) (-4 *7 (-13 (-388) (-867)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-538 *3 *4 *5 *6))) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-5 *3 (-658 *7)) (-4 *1 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 (-433 *3))) (-5 *1 (-195 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-68 LSFUN2)))) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(((*1 *2 *3 *3) (-12 (-4 *2 (-582)) (-5 *1 (-998 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-13 (-1119) (-39))) (-5 *1 (-1154 *3 *2)) (-4 *3 (-13 (-1119) (-39)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3548 (-804 *3)) (|:| |coef1| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -3548 *1) (|:| |coef1| *1))) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *1 *1 *1) (-4 *1 (-780)))) 
+(((*1 *1 *2 *2) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-150))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-5 *2 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *5)) (-5 *1 (-139 *5 *6 *3 *7 *4)) (-4 *3 (-346 *5 *7)) (-4 *4 (-137))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *3 *5) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-3 (|:| |fn| (-414)) (|:| |fp| (-71 FUNCT1)))) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-5 *1 (-587)))) ((*1 *2 *1) (-12 (-4 *1 (-629 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))) (-5 *1 (-825))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-4 *4 (-373)) (-5 *2 (-706 *4)) (-5 *1 (-370 *4))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-1173)) (-5 *3 (-592)) (-5 *1 (-256)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-658 (-1173))) (-5 *3 (-592)) (-5 *4 (-1173)) (-5 *1 (-256)))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) ((*1 *2 *1) (-12 (-4 *1 (-1257 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075))))) 
+(((*1 *1 *1) (-4 *1 (-885)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-280 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-280 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-280 *2)) (-4 *2 (-1119)))) ((*1 *1 *2) (-12 (-5 *1 (-1212 *2)) (-4 *2 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1212 *3)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-658 (-1212 *2))) (-5 *1 (-1212 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-405)) (-5 *1 (-1087))))) 
+(((*1 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-394)) (-4 *2 (-388)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 *4)) (-5 *1 (-556 *4)) (-4 *4 (-373))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-141)) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-399 *2)) (-4 *2 (-1225)) (-4 *2 (-869)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-141) *3 *3)) (|has| *1 (-6 -4626)) (-4 *1 (-399 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 *4)) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-474 *4 *5 *6 *2))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *3 *3 *3 *4 *5 *5 *5 *5 *5 *5 *6 *6 *6 *3 *3 *5 *7 *3 *8) (-12 (-5 *5 (-706 (-237))) (-5 *6 (-141)) (-5 *7 (-706 (-592))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-70 QPHESS)))) (-5 *3 (-592)) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(((*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-894 *3 *4 *5)) (-4 (-884 *3) (-394)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1187 (-433 (-980 *3)))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *2) (-12 (-5 *2 (-790)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030)))))) 
+(((*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-1187 (-592))) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-1187 (-592))) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) ((*1 *2) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-894 *3 *4 *5)) (-4 (-884 *3) (-394)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 (-592))) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 (-592))) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1173)) (-4 *1 (-389 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *3 *3 *5 *6 *3 *6 *6 *5 *6 *6 *6 *6 *5 *3 *3 *3 *3 *3 *6 *6 *6 *3 *3 *3 *3 *3 *7 *4 *4 *4 *4 *3 *8 *9) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-141)) (-5 *6 (-237)) (-5 *7 (-706 (-592))) (-5 *8 (-3 (|:| |fn| (-414)) (|:| |fp| (-85 CONFUN)))) (-5 *9 (-3 (|:| |fn| (-414)) (|:| |fp| (-82 OBJFUN)))) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(((*1 *1 *1 *1) (-4 *1 (-318))) ((*1 *1 *1) (-4 *1 (-318)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-867))) (-5 *1 (-200 *3 *2)) (-4 *2 (-1255 (-191 *3)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-658 *2))) (-5 *4 (-658 *5)) (-4 *5 (-43 (-433 (-592)))) (-4 *2 (-1270 *5)) (-5 *1 (-1272 *5 *2))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -3548 *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-1 *6 (-658 *6)))) (-4 *5 (-43 (-433 (-592)))) (-4 *6 (-1270 *5)) (-5 *2 (-658 *6)) (-5 *1 (-1272 *5 *6))))) 
+(((*1 *2 *3) (-12 (-4 *3 (-1255 *2)) (-4 *2 (-1255 *4)) (-5 *1 (-1014 *4 *2 *3 *5)) (-4 *4 (-373)) (-4 *5 (-741 *2 *3))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *3 *5 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-772))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1280 *4)) (-4 *4 (-654 *5)) (-4 *5 (-388)) (-4 *5 (-582)) (-5 *2 (-1280 *5)) (-5 *1 (-653 *5 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1280 *4)) (-4 *4 (-654 *5)) (-3252 (-4 *5 (-388))) (-4 *5 (-582)) (-5 *2 (-1280 (-433 *5))) (-5 *1 (-653 *5 *4))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *2 (-1063)) (-5 *1 (-321))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-401 *4 *2)) (-4 *2 (-13 (-399 *4) (-10 -7 (-6 -4626))))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-195 *3)) (-4 *3 (-323)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-690 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-757 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-869)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *1 (-1009 *3)) (-4 *3 (-1075)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-5 *3 (-658 *7)) (-4 *1 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *4 *5 *6 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-433 *5)) (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-5 *1 (-172 *4 *5 *2)) (-4 *2 (-1255 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1193 (-433 (-592)))) (-5 *2 (-433 (-592))) (-5 *1 (-204)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-706 (-332 (-237)))) (-5 *3 (-658 (-1191))) (-5 *4 (-1280 (-332 (-237)))) (-5 *1 (-219)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-310 *3))) (-4 *3 (-325 *3)) (-4 *3 (-1119)) (-4 *3 (-1225)) (-5 *1 (-310 *3)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-325 *2)) (-4 *2 (-1119)) (-4 *2 (-1225)) (-5 *1 (-310 *2)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *1 *1)) (-4 *1 (-318)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *1 (-658 *1))) (-4 *1 (-318)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-143))) (-5 *3 (-658 (-1 *1 (-658 *1)))) (-4 *1 (-318)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-143))) (-5 *3 (-658 (-1 *1 *1))) (-4 *1 (-318)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1 *1 *1)) (-4 *1 (-318)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1 *1 (-658 *1))) (-4 *1 (-318)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-658 (-1 *1 (-658 *1)))) (-4 *1 (-318)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-658 (-1 *1 *1))) (-4 *1 (-318)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-310 *3))) (-4 *1 (-325 *3)) (-4 *3 (-1119)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-310 *3)) (-4 *1 (-325 *3)) (-4 *3 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-592))) (-5 *4 (-1193 (-433 (-592)))) (-5 *1 (-326 *2)) (-4 *2 (-43 (-433 (-592)))))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *4)) (-5 *3 (-658 *1)) (-4 *1 (-400 *4 *5)) (-4 *4 (-869)) (-4 *5 (-194)))) ((*1 *1 *1 *2 *1) (-12 (-4 *1 (-400 *2 *3)) (-4 *2 (-869)) (-4 *3 (-194)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-790)) (-5 *4 (-1 *1 *1)) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-1075)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-790)) (-5 *4 (-1 *1 (-658 *1))) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-1075)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-658 (-790))) (-5 *4 (-658 (-1 *1 (-658 *1)))) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-1075)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-658 (-790))) (-5 *4 (-658 (-1 *1 *1))) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-1075)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-658 (-143))) (-5 *3 (-658 *1)) (-5 *4 (-1191)) (-4 *1 (-456 *5)) (-4 *5 (-869)) (-4 *5 (-633 (-565))))) ((*1 *1 *1 *2 *1 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1191)) (-4 *1 (-456 *4)) (-4 *4 (-869)) (-4 *4 (-633 (-565))))) ((*1 *1 *1) (-12 (-4 *1 (-456 *2)) (-4 *2 (-869)) (-4 *2 (-633 (-565))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-1191))) (-4 *1 (-456 *3)) (-4 *3 (-869)) (-4 *3 (-633 (-565))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1191)) (-4 *1 (-456 *3)) (-4 *3 (-869)) (-4 *3 (-633 (-565))))) ((*1 *2 *3 *4) (-12 (-14 *5 (-658 (-1191))) (-4 *3 (-977 *2 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *2)) (-4 *8 (-665 *2)) (-4 *4 (-947 *2 *8)) (-4 *9 (-257 *4)) (-4 *10 (-560 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2 *3 *3 *4) (-12 (-14 *5 (-658 (-1191))) (-4 *3 (-977 *2 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *2)) (-4 *8 (-665 *2)) (-4 *4 (-947 *2 *8)) (-4 *9 (-257 *4)) (-4 *10 (-560 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 *6)) (-4 *6 (-977 *2 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-14 *5 (-658 (-1191))) (-4 *8 (-999 *2)) (-4 *9 (-665 *2)) (-4 *4 (-947 *2 *9)) (-4 *10 (-257 *4)) (-4 *11 (-560 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-137)) (-4 *2 (-388)) (-5 *1 (-491 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *1 *1 *2 *3) (-12 (-4 *1 (-547 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1225)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *4)) (-5 *3 (-658 *5)) (-4 *1 (-547 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1225)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-855 *3)) (-4 *3 (-388)) (-5 *1 (-735 *3)))) ((*1 *2 *1 *2) (-12 (-5 *1 (-735 *2)) (-4 *2 (-388)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-264 *5 *2)) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-264 *5 *2)) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-264 *5 *2))) (-5 *4 (-949 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-373)) (-5 *1 (-894 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-264 *5 *2)) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-264 *5 *2)) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-264 *5 *2))) (-5 *4 (-948 *2)) (-14 *5 (-658 (-1191))) (-4 *2 (-388)) (-5 *1 (-895 *2 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-925 *2)) (-4 *2 (-1119)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-4 *2 (-388)) (-5 *1 (-956 *2 *3 *5 *6 *4)) (-4 *3 (-346 *2 *5)) (-4 *4 (-999 *2)))) ((*1 *2 *2 *3 *2) (-12 (-5 *2 (-433 (-980 *4))) (-5 *3 (-1191)) (-4 *4 (-582)) (-5 *1 (-1070 *4)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-658 (-1191))) (-5 *4 (-658 (-433 (-980 *5)))) (-5 *2 (-433 (-980 *5))) (-4 *5 (-582)) (-5 *1 (-1070 *5)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-310 (-433 (-980 *4)))) (-5 *2 (-433 (-980 *4))) (-4 *4 (-582)) (-5 *1 (-1070 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-310 (-433 (-980 *4))))) (-5 *2 (-433 (-980 *4))) (-4 *4 (-582)) (-5 *1 (-1070 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1257 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (|has| *3 (-15 ** (*3 *3 *4))) (-5 *2 (-1171 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-433 *2)) (-5 *4 (-1 *2 *2)) (-4 *2 (-1255 *5)) (-5 *1 (-744 *5 *2)) (-4 *5 (-388))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *3 *4 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-191 (-592))) (-5 *2 (-141)) (-5 *1 (-471)))) ((*1 *2 *3) (-12 (-5 *3 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))) (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *2 (-141)) (-5 *1 (-539 *4 *5)))) ((*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-989 *3)) (-4 *3 (-574)))) ((*1 *2 *1) (-12 (-4 *1 (-1235)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *2 (-658 (-237))) (-5 *1 (-497))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-706 (-332 (-237)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-405)) (|:| |stabilityFactor| (-405)))) (-5 *1 (-219))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-790)) (-4 *4 (-373)) (-5 *1 (-556 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-477)) (-5 *2 (-658 (-2 (|:| |eigval| (-3 (-433 (-980 *4)) (-1180 (-1191) (-980 *4)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 (-706 (-433 (-980 *4)))))))) (-5 *1 (-308 *4)) (-5 *3 (-706 (-433 (-980 *4))))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *5 (-706 (-237))) (-5 *4 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *1) (-5 *1 (-179)))) 
+(((*1 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) ((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-706 *4)) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) ((*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-706 *3))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-631 (-53)))) (-5 *1 (-53)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-631 (-53))) (-5 *1 (-53)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1187 (-53))) (-5 *3 (-658 (-631 (-53)))) (-5 *1 (-53)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1187 (-53))) (-5 *3 (-631 (-53))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-388) (-867))) (-5 *1 (-200 *2 *3)) (-4 *3 (-1255 (-191 *2))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)))) ((*1 *2 *1) (-12 (-4 *1 (-349 *2)) (-4 *2 (-388)))) ((*1 *2 *1) (-12 (-4 *1 (-396 *2 *3)) (-4 *3 (-1255 *2)) (-4 *2 (-194)))) ((*1 *2 *1) (-12 (-4 *4 (-1255 *2)) (-4 *2 (-1021 *3)) (-5 *1 (-439 *3 *2 *4 *5)) (-4 *3 (-323)) (-4 *5 (-13 (-435 *2 *4) (-1065 *2))))) ((*1 *2 *1) (-12 (-4 *4 (-1255 *2)) (-4 *2 (-1021 *3)) (-5 *1 (-440 *3 *2 *4 *5 *6)) (-4 *3 (-323)) (-4 *5 (-435 *2 *4)) (-14 *6 (-1280 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *2 (-13 (-430) (-1065 *5) (-388) (-1211) (-301))) (-5 *1 (-468 *5 *3 *2)) (-4 *3 (-1255 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-631 (-528)))) (-5 *1 (-528)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-631 (-528))) (-5 *1 (-528)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1187 (-528))) (-5 *3 (-658 (-631 (-528)))) (-5 *1 (-528)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1187 (-528))) (-5 *3 (-631 (-528))) (-5 *1 (-528)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-944)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-741 *4 *2)) (-4 *2 (-1255 *4)) (-5 *1 (-794 *4 *2 *5 *3)) (-4 *3 (-1255 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) ((*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)))) ((*1 *1 *1) (-4 *1 (-1084)))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-790)) (-4 *6 (-1119)) (-4 *3 (-922 *6)) (-5 *2 (-706 *3)) (-5 *1 (-708 *6 *3 *7 *4)) (-4 *7 (-399 *3)) (-4 *4 (-13 (-399 *6) (-10 -7 (-6 -4625))))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-36 *3 *4)) (-4 *4 (-456 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-790)) (-5 *1 (-143)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-143)))) ((*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *4)) (-4 *4 (-456 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-143)) (-5 *1 (-184)))) ((*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *4)) (-4 *4 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-5 *2 (-143)) (-5 *1 (-317 *3)) (-4 *3 (-318)))) ((*1 *2 *2) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) ((*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *4 (-869)) (-5 *1 (-455 *3 *4)) (-4 *3 (-456 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *4)) (-4 *4 (-456 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-143)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) ((*1 *2 *2) (-12 (-5 *2 (-143)) (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *4)) (-4 *4 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *2 *3 *3 *4 *4 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *2))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (-592))))) (-4 *2 (-582)) (-5 *1 (-444 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| *4) (|:| -1777 (-592))))))) (-4 *4 (-1255 (-592))) (-5 *2 (-444 *4)) (-5 *1 (-467 *4))))) 
+(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-433 (-1187 (-332 *3)))) (-4 *3 (-13 (-582) (-869))) (-5 *1 (-1147 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-4 *5 (-456 *4)) (-5 *2 (-3 (|:| |overq| (-1187 (-433 (-592)))) (|:| |overan| (-1187 (-53))) (|:| -3550 (-141)))) (-5 *1 (-461 *4 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1075)) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-444 *3)) (-5 *1 (-383 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3 *4 *4 *5 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-456 *2)) (-4 *2 (-869)) (-4 *2 (-582)))) ((*1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) ((*1 *1 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3)))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5))))) 
+(((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *5 (-237)) (-5 *2 (-1063)) (-5 *1 (-771))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-5 *1 (-350))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1225)) (-5 *2 (-658 *1)) (-4 *1 (-1038 *3))))) 
+(((*1 *1 *1 *1) (-5 *1 (-141))) ((*1 *1 *1 *1) (-4 *1 (-153))) ((*1 *1 *1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *3)))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4)))))) 
+(((*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *5 (-631 *4)) (-5 *6 (-1187 *4)) (-4 *4 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-588 *7 *4 *3)) (-4 *3 (-670 *4)) (-4 *3 (-1119)))) ((*1 *2 *3 *4 *5 *5 *5 *4 *6) (-12 (-5 *5 (-631 *4)) (-5 *6 (-433 (-1187 *4))) (-4 *4 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-588 *7 *4 *3)) (-4 *3 (-670 *4)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-323)) (-5 *2 (-790))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) ((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-927 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1085 (-1051 *4) (-1187 (-1051 *4)))) (-5 *3 (-877)) (-5 *1 (-1051 *4)) (-4 *4 (-13 (-867) (-388) (-1049)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1255 (-592))) (-5 *1 (-520 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-516 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-1075)) (-5 *2 (-264 *4 *5)) (-5 *1 (-972 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2) (-12 (-5 *2 (-986 (-1137))) (-5 *1 (-363 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) ((*1 *2) (-12 (-5 *2 (-986 (-1137))) (-5 *1 (-364 *3 *4)) (-4 *3 (-373)) (-14 *4 (-1187 *3)))) ((*1 *2) (-12 (-5 *2 (-986 (-1137))) (-5 *1 (-365 *3 *4)) (-4 *3 (-373)) (-14 *4 (-944))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-1251 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-911 *4 *5)) (-5 *3 (-911 *4 *6)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-683 *5)) (-5 *1 (-907 *4 *5 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-129))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-60 *4 *5 *2)) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4))))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-1075)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-470 *3)) (-4 *3 (-1075))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-350))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-433 (-592))) (-5 *1 (-237)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-433 (-592))) (-5 *1 (-237)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-433 (-592))) (-5 *1 (-405)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-433 (-592))) (-5 *1 (-405))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1301 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-865))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-452 *5 *3)) (-4 *3 (-13 (-1211) (-29 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-1065 (-592)) (-171))) (-5 *2 (-609 (-433 (-980 *5)))) (-5 *1 (-598 *5)) (-5 *3 (-433 (-980 *5)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-477)))) ((*1 *1 *1 *1) (-4 *1 (-477))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-986 (-1229))) (-5 *4 (-592)) (-5 *2 (-1229)) (-5 *1 (-982))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *3 (-592)) (-4 *1 (-890 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1255 *6)) (-4 *6 (-13 (-27) (-456 *5))) (-4 *5 (-13 (-869) (-582) (-1065 (-592)))) (-4 *8 (-1255 (-433 *7))) (-5 *2 (-609 *3)) (-5 *1 (-577 *5 *6 *7 *8 *3)) (-4 *3 (-362 *6 *7 *8))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-62 *4 *2 *5)) (-4 *4 (-1225)) (-4 *5 (-399 *4)) (-4 *2 (-399 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *6 *2 *7)) (-4 *6 (-1075)) (-4 *7 (-252 *4 *6)) (-4 *2 (-252 *5 *6))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1009 *2)) (-4 *2 (-1075)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-1075))))) 
+(((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)) (-4 *2 (-574)))) ((*1 *1 *1) (-4 *1 (-1084)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-658 *10)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-944)) (-5 *5 (-658 *9)) (-4 *9 (-999 *6)) (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *4 (-977 *6 *8 (-879 *7))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *10 (-665 *6)) (-4 *11 (-947 *6 *10)) (-4 *12 (-257 *11)) (-4 *13 (-560 *6 *7 *4 *8 *9 *10 *11 *12 *15)) (-4 *15 (-137)) (-5 *2 (-1285)) (-5 *1 (-580 *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (-4 *14 (-280 *13)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-658 (-949 *4))) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-658 (-948 *4))) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3253 (-706 (-433 (-980 *4)))) (|:| |vec| (-658 (-433 (-980 *4)))) (|:| -4175 (-790)) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592))))) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-2 (|:| |partsol| (-1280 (-433 (-980 *4)))) (|:| -2195 (-658 (-1280 (-433 (-980 *4))))))) (-5 *1 (-951 *4 *5 *6 *7)) (-4 *7 (-977 *4 *6 *5))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-1187 *4))) (-5 *3 (-1187 *4)) (-4 *4 (-931)) (-5 *1 (-680 *4))))) 
+(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-658 (-264 *5 *6))) (-4 *6 (-477)) (-5 *2 (-264 *5 *6)) (-14 *5 (-658 (-1191))) (-5 *1 (-646 *5 *6))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-388)) (-5 *1 (-677 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *1 (-1221 *3)) (-4 *3 (-1003))))) 
+(((*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-658 (-658 (-237)))) (-5 *4 (-237)) (-5 *2 (-658 (-971 *4))) (-5 *1 (-1222)) (-5 *3 (-971 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-5 *2 (-658 (-790))) (-5 *1 (-798 *3 *4 *5 *6 *7)) (-4 *3 (-1255 *6)) (-4 *7 (-977 *6 *4 *5))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-191 (-405)))) (-5 *1 (-350)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-405))) (-5 *1 (-350)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-592))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-191 (-405))))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-405)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-592)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-191 (-405))))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-405)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-592)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-191 (-405)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-405))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-592))) (-5 *1 (-350)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-710))) (-5 *1 (-350)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-715))) (-5 *1 (-350)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-332 (-717))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-710)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-715)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-332 (-717)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-710)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-715)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-332 (-717)))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-710))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-715))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1280 (-717))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-710))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-715))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-706 (-717))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-710))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-715))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-332 (-717))) (-5 *1 (-350)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1173)) (-5 *1 (-350)))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1173)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-278))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-52 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-55 *3 *4)) (-14 *4 (-658 (-1191))))) ((*1 *1 *2 *1 *1 *3) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-64 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-64 *6)) (-5 *1 (-63 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-96 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *7)) (-5 *4 (-162 *5 *6 *7)) (-14 *5 (-592)) (-14 *6 (-790)) (-4 *7 (-194)) (-4 *8 (-194)) (-5 *2 (-162 *5 *6 *8)) (-5 *1 (-161 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-191 *5)) (-4 *5 (-194)) (-4 *6 (-194)) (-5 *2 (-191 *6)) (-5 *1 (-190 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-234 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-332 *3) (-332 *3))) (-4 *3 (-13 (-1075) (-869))) (-5 *1 (-235 *3 *4)) (-14 *4 (-658 (-1191))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-254 *5 *6)) (-14 *5 (-790)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-5 *2 (-254 *5 *7)) (-5 *1 (-253 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-310 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-310 *6)) (-5 *1 (-309 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1225)) (-5 *1 (-310 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1173)) (-5 *5 (-631 *6)) (-4 *6 (-318)) (-4 *2 (-1225)) (-5 *1 (-313 *6 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5)) (-5 *4 (-631 *5)) (-4 *5 (-318)) (-4 *2 (-318)) (-5 *1 (-314 *5 *2)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *1 *1)) (-5 *3 (-631 *1)) (-4 *1 (-318)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-706 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-706 *6)) (-5 *1 (-320 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-332 *5)) (-4 *5 (-869)) (-4 *6 (-869)) (-5 *2 (-332 *6)) (-5 *1 (-330 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-4 *6 (-1075)) (-4 *7 (-1075)) (-4 *5 (-814)) (-4 *2 (-346 *7 *5)) (-5 *1 (-344 *5 *6 *4 *7 *2)) (-4 *4 (-346 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-356 *5 *6 *7 *8)) (-4 *5 (-388)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *8 (-362 *5 *6 *7)) (-4 *9 (-388)) (-4 *10 (-1255 *9)) (-4 *11 (-1255 (-433 *10))) (-5 *2 (-356 *9 *10 *11 *12)) (-5 *1 (-353 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-362 *9 *10 *11)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-358 *3)) (-4 *3 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1235)) (-4 *8 (-1235)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *9 (-1255 *8)) (-4 *2 (-362 *8 *9 *10)) (-5 *1 (-360 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-362 *5 *6 *7)) (-4 *10 (-1255 (-433 *9))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-4 *2 (-399 *6)) (-5 *1 (-397 *5 *4 *6 *2)) (-4 *4 (-399 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-444 *5)) (-4 *5 (-582)) (-4 *6 (-582)) (-5 *2 (-444 *6)) (-5 *1 (-431 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-433 *5)) (-4 *5 (-582)) (-4 *6 (-582)) (-5 *2 (-433 *6)) (-5 *1 (-432 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-439 *5 *6 *7 *8)) (-4 *5 (-323)) (-4 *6 (-1021 *5)) (-4 *7 (-1255 *6)) (-4 *8 (-13 (-435 *6 *7) (-1065 *6))) (-4 *9 (-323)) (-4 *10 (-1021 *9)) (-4 *11 (-1255 *10)) (-5 *2 (-439 *9 *10 *11 *12)) (-5 *1 (-438 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-13 (-435 *10 *11) (-1065 *10))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-194)) (-4 *6 (-194)) (-4 *2 (-443 *6)) (-5 *1 (-441 *4 *5 *2 *6)) (-4 *4 (-443 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-582)) (-5 *1 (-444 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-13 (-1075) (-869))) (-4 *6 (-13 (-1075) (-869))) (-4 *2 (-456 *6)) (-5 *1 (-447 *5 *4 *6 *2)) (-4 *4 (-456 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-451 *6)) (-5 *1 (-449 *5 *4 *6 *2)) (-4 *4 (-451 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-869)) (-5 *1 (-518 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-523 *3)) (-4 *3 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-542 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-869)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-609 *5)) (-4 *5 (-388)) (-4 *6 (-388)) (-5 *2 (-609 *6)) (-5 *1 (-608 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| -3191 *5) (|:| |coeff| *5)) "failed")) (-4 *5 (-388)) (-4 *6 (-388)) (-5 *2 (-2 (|:| -3191 *6) (|:| |coeff| *6))) (-5 *1 (-608 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *2 *5)) (-5 *4 (-3 *5 "failed")) (-4 *5 (-388)) (-4 *2 (-388)) (-5 *1 (-608 *5 *2)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| |mainpart| *5) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (-4 *5 (-388)) (-4 *6 (-388)) (-5 *2 (-2 (|:| |mainpart| *6) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *6) (|:| |logand| *6)))))) (-5 *1 (-608 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-622 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-622 *6)) (-5 *1 (-619 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-622 *6)) (-5 *5 (-622 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-622 *8)) (-5 *1 (-620 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1171 *6)) (-5 *5 (-622 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-1171 *8)) (-5 *1 (-620 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-622 *6)) (-5 *5 (-1171 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-1171 *8)) (-5 *1 (-620 *6 *7 *8)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1225)) (-5 *1 (-622 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-658 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-658 *6)) (-5 *1 (-656 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-658 *6)) (-5 *5 (-658 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-658 *8)) (-5 *1 (-657 *6 *7 *8)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1075)) (-4 *8 (-1075)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-4 *2 (-704 *8 *9 *10)) (-5 *1 (-702 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-704 *5 *6 *7)) (-4 *9 (-399 *8)) (-4 *10 (-399 *8)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *8 "failed") *5)) (-4 *5 (-1075)) (-4 *8 (-1075)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-4 *2 (-704 *8 *9 *10)) (-5 *1 (-702 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-704 *5 *6 *7)) (-4 *9 (-399 *8)) (-4 *10 (-399 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-582)) (-4 *7 (-582)) (-4 *6 (-1255 *5)) (-4 *2 (-1255 (-433 *8))) (-5 *1 (-726 *5 *6 *4 *7 *8 *2)) (-4 *4 (-1255 (-433 *6))) (-4 *8 (-1255 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *8)) (-4 *8 (-1075)) (-4 *9 (-1075)) (-4 *5 (-869)) (-4 *6 (-815)) (-4 *2 (-977 *9 *7 *5)) (-5 *1 (-745 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-815)) (-4 *4 (-977 *8 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-869)) (-4 *6 (-869)) (-4 *7 (-815)) (-4 *9 (-1075)) (-4 *2 (-977 *9 *8 *6)) (-5 *1 (-746 *5 *6 *7 *8 *9 *4 *2)) (-4 *8 (-815)) (-4 *4 (-977 *9 *7 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-752 *5 *7)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-4 *7 (-743)) (-5 *2 (-752 *6 *7)) (-5 *1 (-751 *5 *6 *7)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-752 *3 *4)) (-4 *4 (-743)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-804 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-804 *6)) (-5 *1 (-803 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-194)) (-4 *6 (-194)) (-4 *2 (-819 *6)) (-5 *1 (-820 *4 *5 *2 *6)) (-4 *4 (-819 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-855 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-855 *6)) (-5 *1 (-854 *5 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-855 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-855 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *1 (-854 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-862 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-862 *6)) (-5 *1 (-861 *5 *6)))) ((*1 *2 *3 *4 *2 *2) (-12 (-5 *2 (-862 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-862 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *1 (-861 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-900 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-900 *6)) (-5 *1 (-899 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-902 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-902 *6)) (-5 *1 (-901 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-904 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-904 *6)) (-5 *1 (-903 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-911 *5 *6)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-911 *5 *7)) (-5 *1 (-910 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-914 *6)) (-5 *1 (-913 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-980 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-980 *6)) (-5 *1 (-974 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *7)) (-5 *4 (-1 *2 *8)) (-4 *7 (-869)) (-4 *8 (-1075)) (-4 *6 (-815)) (-4 *2 (-13 (-1119) (-10 -8 (-15 -3300 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-790)))))) (-5 *1 (-979 *6 *7 *8 *5 *2)) (-4 *5 (-977 *8 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-986 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-986 *6)) (-5 *1 (-985 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-971 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-971 *6)) (-5 *1 (-1010 *5 *6)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-1 *2 (-980 *4))) (-4 *4 (-1075)) (-4 *2 (-977 (-980 *4) *5 *6)) (-4 *5 (-815)) (-4 *6 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $)) (-15 -3983 ((-3 $ "failed") (-1191)))))) (-5 *1 (-1013 *4 *5 *6 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-582)) (-4 *6 (-582)) (-4 *2 (-1021 *6)) (-5 *1 (-1019 *5 *6 *4 *2)) (-4 *4 (-1021 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-194)) (-4 *6 (-194)) (-4 *2 (-1025 *6)) (-5 *1 (-1026 *4 *5 *2 *6)) (-4 *4 (-1025 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-1028 *3)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *5 *5 *5)) (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *5 *5)) (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *10 *7)) (-4 *7 (-1075)) (-4 *10 (-1075)) (-14 *5 (-790)) (-14 *6 (-790)) (-4 *8 (-252 *6 *7)) (-4 *9 (-252 *5 *7)) (-4 *2 (-1078 *5 *6 *10 *11 *12)) (-5 *1 (-1080 *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (-4 *4 (-1078 *5 *6 *7 *8 *9)) (-4 *11 (-252 *6 *10)) (-4 *12 (-252 *5 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1113 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1113 *6)) (-5 *1 (-1109 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1113 *5)) (-4 *5 (-867)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-658 *6)) (-5 *1 (-1109 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1111 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1111 *6)) (-5 *1 (-1110 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 *4 *4)) (-4 *1 (-1114 *4 *2)) (-4 *4 (-867)) (-4 *2 (-1163 *4)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1119)) (-5 *1 (-1161 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1171 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1171 *6)) (-5 *1 (-1169 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1171 *6)) (-5 *5 (-1171 *7)) (-4 *6 (-1225)) (-4 *7 (-1225)) (-4 *8 (-1225)) (-5 *2 (-1171 *8)) (-5 *1 (-1170 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1187 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-5 *2 (-1187 *6)) (-5 *1 (-1184 *5 *6)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *4 *4 *4)) (-4 *1 (-1202 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1243 *5 *7 *9)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-14 *7 (-1191)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1243 *6 *8 *10)) (-5 *1 (-1238 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1191)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1246 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1246 *6)) (-5 *1 (-1245 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1246 *5)) (-4 *5 (-867)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1171 *6)) (-5 *1 (-1245 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *6)) (-5 *4 (-1252 *5 *6)) (-14 *5 (-1191)) (-4 *6 (-1075)) (-4 *8 (-1075)) (-5 *2 (-1252 *7 *8)) (-5 *1 (-1247 *5 *6 *7 *8)) (-14 *7 (-1191)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-4 *2 (-1255 *6)) (-5 *1 (-1253 *5 *4 *6 *2)) (-4 *4 (-1255 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1264 *5 *7 *9)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-14 *7 (-1191)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1264 *6 *8 *10)) (-5 *1 (-1259 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1191)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1075)) (-4 *6 (-1075)) (-4 *2 (-1270 *6)) (-5 *1 (-1268 *5 *6 *4 *2)) (-4 *4 (-1270 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1280 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1280 *6)) (-5 *1 (-1279 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *6 "failed") *5)) (-5 *4 (-1280 *5)) (-4 *5 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1280 *6)) (-5 *1 (-1279 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-1301 *3 *4)) (-4 *4 (-865))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *5 (-1065 (-53))) (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-4 *5 (-456 *4)) (-5 *2 (-444 (-1187 (-53)))) (-5 *1 (-461 *4 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| |eqzro| (-658 *8)) (|:| |neqzro| (-658 *8)) (|:| |wcond| (-658 (-980 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *5)))) (|:| -2195 (-658 (-1280 (-433 (-980 *5)))))))))) (-5 *4 (-1173)) (-4 *5 (-13 (-323) (-171))) (-4 *8 (-977 *5 *7 *6)) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *5 *6 *7 *8))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-658 *7)) (|:| -2165 *8))) (-4 *7 (-1089 *4 *5 *6)) (-4 *8 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *8)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-658 *7)) (|:| -2165 *8))) (-4 *7 (-1089 *4 *5 *6)) (-4 *8 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *8))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-2 (|:| |func| *3) (|:| |kers| (-658 (-631 *3))) (|:| |vals| (-658 *3)))) (-5 *1 (-295 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5)))))) 
+(((*1 *2 *3 *3 *3 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-1191)) (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137))))) 
+(((*1 *1 *2 *2) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1173)) (-5 *1 (-1018)))) ((*1 *2 *3 *1) (|partial| -12 (-5 *2 (-310 (-1106 *3))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) ((*1 *2 *1 *3) (|partial| -12 (-5 *2 (-310 (-1106 *3))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-1113 *4)) (-4 *4 (-1225)) (-5 *1 (-1111 *4))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-706 *4)) (-5 *3 (-944)) (-4 *4 (-1075)) (-5 *1 (-1056 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-658 (-706 *4))) (-5 *3 (-944)) (-4 *4 (-1075)) (-5 *1 (-1056 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-5 *4 (-790)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| |det| *8) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (-5 *1 (-951 *5 *6 *7 *8))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-1173))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 *4)) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *1 *2) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-143))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-5 *2 (-658 *8)) (-5 *1 (-31 *5 *6 *3 *7 *8)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-32 *5 *6 *3 *7 *8)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5))))) 
+(((*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1073))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)) (-4 *2 (-869)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-141) *3 *3)) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-869))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1113 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-433 (-980 *4)))) (-5 *1 (-951 *4 *5 *6 *7)) (-4 *7 (-977 *4 *6 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-631 *5)) (-4 *5 (-456 *4)) (-4 *4 (-1065 (-592))) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-1187 *5)) (-5 *1 (-36 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-631 *1)) (-4 *1 (-1075)) (-4 *1 (-318)) (-5 *2 (-1187 *1))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1207)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1207))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1193 (-433 (-592)))) (-5 *2 (-433 (-592))) (-5 *1 (-204))))) 
+(((*1 *1 *1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 (-433 *3))) (-5 *1 (-195 *3)) (-4 *3 (-323))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-57))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-715)) (-5 *1 (-321))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-37 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-252 *5 (-790))) (-14 *5 (-790)) (-5 *1 (-935 *3 *2 *4 *5)) (-4 *2 (-346 *3 *4)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-388)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-956 *4 *2 *5 *6 *3)) (-4 *2 (-346 *4 *5)) (-4 *3 (-999 *4)))) ((*1 *2 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-388)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-5 *1 (-956 *5 *2 *6 *7 *3)) (-4 *2 (-346 *5 *6)) (-4 *3 (-999 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-417))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1191)) (-5 *2 (-463)) (-5 *1 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-993 *2 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-5 *2 (-1187 *3)) (-5 *1 (-1200 *3)) (-4 *3 (-388))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-264 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-1075)) (-5 *2 (-516 *4 *5)) (-5 *1 (-972 *4 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-477)) (-5 *2 (-658 (-2 (|:| |eigval| (-3 (-433 (-980 *4)) (-1180 (-1191) (-980 *4)))) (|:| |geneigvec| (-658 (-706 (-433 (-980 *4)))))))) (-5 *1 (-308 *4)) (-5 *3 (-706 (-433 (-980 *4))))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-5 *2 (-658 (-1191))) (-5 *1 (-224)) (-5 *3 (-1191)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-790)) (-5 *2 (-658 (-1191))) (-5 *1 (-285)))) ((*1 *2 *1) (-12 (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-841 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-915 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-658 *3))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-497)) (-5 *3 (-658 (-278))) (-5 *1 (-1281)))) ((*1 *1 *1) (-5 *1 (-1281)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-389 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-1173))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 (-592))))) (-5 *2 (-658 (-332 (-592)))) (-5 *1 (-1059))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-658 (-1097 *4 *5 *2))) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))) (-5 *1 (-60 *4 *5 *2)))) ((*1 *2 *3 *2 *4) (-12 (-5 *3 (-658 (-1097 *5 *6 *2))) (-5 *4 (-944)) (-4 *5 (-1119)) (-4 *6 (-13 (-1075) (-908 *5) (-869) (-633 (-914 *5)))) (-4 *2 (-13 (-456 *6) (-908 *5) (-633 (-914 *5)))) (-5 *1 (-60 *5 *6 *2))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-433 (-592))) (-4 *4 (-1065 (-592))) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-36 *4 *2)) (-4 *2 (-456 *4)))) ((*1 *1 *1 *1) (-5 *1 (-160))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1 *1) (-5 *1 (-237))) ((*1 *1 *1 *2) (-12 (-4 *1 (-260)) (-5 *2 (-592)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-433 (-592))) (-4 *4 (-388)) (-4 *4 (-43 *3)) (-4 *5 (-1270 *4)) (-5 *1 (-296 *4 *5 *2)) (-4 *2 (-1241 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-433 (-592))) (-4 *4 (-388)) (-4 *4 (-43 *3)) (-4 *5 (-1239 *4)) (-5 *1 (-297 *4 *5 *2 *6)) (-4 *2 (-1262 *4 *5)) (-4 *6 (-1012 *5)))) ((*1 *1 *1 *1) (-4 *1 (-301))) ((*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-386 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *1) (-5 *1 (-405))) ((*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-5 *1 (-412 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-456 *3)) (-4 *3 (-869)) (-4 *3 (-1131)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-502)) (-5 *2 (-592)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-592)) (-4 *4 (-373)) (-5 *1 (-556 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-565)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-565)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-790)) (-4 *4 (-1119)) (-5 *1 (-698 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-4 *3 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-706 *4)) (-5 *3 (-790)) (-4 *4 (-1075)) (-5 *1 (-707 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *3 (-1075)) (-5 *1 (-731 *3 *4)) (-4 *4 (-661 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-592)) (-4 *4 (-1075)) (-5 *1 (-731 *4 *5)) (-4 *5 (-661 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-737)) (-5 *2 (-944)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-739)) (-5 *2 (-790)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-743)) (-5 *2 (-790)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-760 *2 *3)) (-14 *2 (-1191)) (-4 *3 (-13 (-1075) (-869) (-582))))) ((*1 *1 *2 *3) (-12 (-5 *3 (-790)) (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-856 *3)) (-4 *3 (-1075)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-592)) (-5 *1 (-856 *4)) (-4 *4 (-1075)))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1030)) (-5 *2 (-433 (-592))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1131)) (-5 *2 (-944)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1140 *3 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-252 *3 *4)) (-4 *6 (-252 *3 *4)) (-4 *4 (-388)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1270 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *1) (-5 *1 (-350)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1119)) (-5 *2 (-1173)))) ((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1129)) (-5 *3 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-5 *2 (-1285)) (-5 *1 (-1233)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 (-1191))) (-5 *2 (-1285)) (-5 *1 (-1233))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-737)) (-5 *2 (-944)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-739)) (-5 *2 (-790))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-141) (-143) (-143))) (-5 *1 (-143))))) 
+(((*1 *1) (-5 *1 (-141)))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-706 (-592))) (-5 *1 (-1129))))) 
+(((*1 *2 *3 *4 *5) (-12 (-4 *6 (-1255 *9)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-323)) (-4 *10 (-977 *9 *7 *8)) (-5 *2 (-2 (|:| |deter| (-658 (-1187 *10))) (|:| |dterm| (-658 (-658 (-2 (|:| -3336 (-790)) (|:| |pcoef| *10))))) (|:| |nfacts| (-658 *6)) (|:| |nlead| (-658 *10)))) (-5 *1 (-798 *6 *7 *8 *9 *10)) (-5 *3 (-1187 *10)) (-5 *4 (-658 *6)) (-5 *5 (-658 *10))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-790))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-1280 *5)) (-5 *3 (-790)) (-5 *4 (-1137)) (-4 *5 (-373)) (-5 *1 (-556 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-252 *3 *4)) (-4 *4 (-1075)) (-4 *4 (-1225)))) ((*1 *1 *2) (-12 (-14 *3 (-658 (-1191))) (-4 *4 (-194)) (-4 *5 (-252 (-1699 *3) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *2) (|:| -3215 *5)) (-2 (|:| -1825 *2) (|:| -3215 *5)))) (-5 *1 (-487 *3 *4 *2 *5 *6 *7)) (-4 *2 (-869)) (-4 *7 (-977 *4 *5 (-879 *3))))) ((*1 *2 *2) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222))))) 
+(((*1 *1 *1) (-4 *1 (-644))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-999 *3)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-995 *3))) (-4 *3 (-373)) (-5 *1 (-894 *3 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-994 *3))) (-4 *3 (-388)) (-5 *1 (-895 *3 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *1) (-5 *1 (-1087)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1237 *2)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-1271 *2 *3 *4)) (-4 *2 (-1075)) (-14 *3 (-1191)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1275 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-1191))))) 
+(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3))))) 
+(((*1 *1) (-4 *1 (-373))) ((*1 *2 *3) (-12 (-5 *3 (-658 *5)) (-4 *5 (-456 *4)) (-4 *4 (-13 (-582) (-869) (-171))) (-5 *2 (-2 (|:| |primelt| *5) (|:| |poly| (-658 (-1187 *5))) (|:| |prim| (-1187 *5)))) (-5 *1 (-458 *4 *5)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-582) (-869) (-171))) (-5 *2 (-2 (|:| |primelt| *3) (|:| |pol1| (-1187 *3)) (|:| |pol2| (-1187 *3)) (|:| |prim| (-1187 *3)))) (-5 *1 (-458 *4 *3)) (-4 *3 (-27)) (-4 *3 (-456 *4)))) ((*1 *2 *3 *4 *3 *4) (-12 (-5 *3 (-980 *5)) (-5 *4 (-1191)) (-4 *5 (-13 (-388) (-171))) (-5 *2 (-2 (|:| |coef1| (-592)) (|:| |coef2| (-592)) (|:| |prim| (-1187 *5)))) (-5 *1 (-988 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-658 (-1191))) (-4 *5 (-13 (-388) (-171))) (-5 *2 (-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 *5))) (|:| |prim| (-1187 *5)))) (-5 *1 (-988 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-980 *6))) (-5 *4 (-658 (-1191))) (-5 *5 (-1191)) (-4 *6 (-13 (-388) (-171))) (-5 *2 (-2 (|:| -1487 (-658 (-592))) (|:| |poly| (-658 (-1187 *6))) (|:| |prim| (-1187 *6)))) (-5 *1 (-988 *6))))) 
+(((*1 *1 *2) (-12 (-5 *1 (-241 *2)) (-4 *2 (-13 (-388) (-1211)))))) 
+(((*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) ((*1 *2) (-12 (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-894 *3 *4 *5)) (-4 (-884 *3) (-394)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2) (-12 (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1275 (-592) -4132)) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-706 *2)) (-5 *4 (-790)) (-4 *2 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *5 (-1255 *2)) (-5 *1 (-532 *2 *5 *6)) (-4 *6 (-435 *2 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *2 (-137))))) 
+(((*1 *1) (-5 *1 (-463)))) 
+(((*1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-582)) (-4 *2 (-194))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-658 (-2 (|:| -3511 *1) (|:| -1774 (-658 *7))))) (-5 *3 (-658 *7)) (-4 *1 (-1219 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *6)))) (-5 *4 (-1054 (-862 (-592)))) (-5 *5 (-1191)) (-5 *7 (-433 (-592))) (-4 *6 (-1075)) (-5 *2 (-877)) (-5 *1 (-617 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-160))))) 
+(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-582)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-705 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-388)) (-5 *1 (-677 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 (-658 *4))) (-5 *3 (-658 *4)) (-4 *4 (-388)) (-5 *1 (-677 *4))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-1280 *1)) (-4 *1 (-885)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-1255 *4)) (-4 *4 (-1075)) (-5 *2 (-1280 *4))))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *3 (-582))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-592)) (-5 *1 (-470 *3)) (-4 *3 (-430)) (-4 *3 (-1075))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *3 (-592)) (-5 *4 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-444 *2)) (-4 *2 (-582))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1194)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1173)) (-5 *1 (-321))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1005 *4 *5 *3 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-4 *6 (-1089 *4 *5 *3)) (-5 *2 (-141))))) 
+(((*1 *1 *2 *3 *1) (-12 (-14 *4 (-658 (-1191))) (-4 *2 (-194)) (-4 *3 (-252 (-1699 *4) (-790))) (-14 *6 (-1 (-141) (-2 (|:| -1825 *5) (|:| -3215 *3)) (-2 (|:| -1825 *5) (|:| -3215 *3)))) (-5 *1 (-487 *4 *2 *5 *3 *6 *7)) (-4 *5 (-869)) (-4 *7 (-977 *2 *3 (-879 *4)))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *2 *1 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-146 *4)) (-14 *4 *3) (-5 *3 (-592)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592)))) ((*1 *2 *1 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-892 *4)) (-14 *4 *3) (-5 *3 (-592)))) ((*1 *2 *1 *3) (-12 (-14 *4 *3) (-5 *2 (-433 (-592))) (-5 *1 (-893 *4 *5)) (-5 *3 (-592)) (-4 *5 (-890 *4)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1040)) (-5 *2 (-433 (-592))))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1091 *2 *3)) (-4 *2 (-13 (-867) (-388))) (-4 *3 (-1255 *2)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1257 *2 *3)) (-4 *3 (-814)) (|has| *2 (-15 ** (*2 *2 *3))) (|has| *2 (-15 -1683 (*2 (-1191)))) (-4 *2 (-1075))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-871 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121 *5)) (-4 *5 (-582)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-872 *5 *3)) (-4 *3 (-871 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) ((*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-658 *7)) (|:| |badPols| (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-691 *3)) (-4 *3 (-1075)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 *4)) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-1161 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1156 *4 *2)) (-14 *4 (-944)) (-4 *2 (-13 (-1075) (-10 -7 (-6 (-4627 "*"))))) (-5 *1 (-924 *4 *2))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-13 (-869) (-10 -8 (-15 -1778 ((-1191) $))))) (-4 *6 (-582)) (-5 *2 (-2 (|:| -4079 (-980 *6)) (|:| -1817 (-980 *6)))) (-5 *1 (-749 *4 *5 *6 *3)) (-4 *3 (-977 (-433 (-980 *6)) *4 *5))))) 
+(((*1 *2 *1 *3) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1087)) (-5 *3 (-1173))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-658 (-980 *4))) (-5 *3 (-658 (-1191))) (-4 *4 (-477)) (-5 *1 (-941 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-351 *3)) (-4 *3 (-869))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-606))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| -1608 (-143)) (|:| |arg| (-658 (-914 *3))))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-143)) (-5 *2 (-658 (-914 *4))) (-5 *1 (-914 *4)) (-4 *4 (-1119))))) 
+(((*1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-477) (-171))) (-5 *2 (-444 *3)) (-5 *1 (-123 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-13 (-477) (-171))) (-5 *2 (-444 *3)) (-5 *1 (-123 *5 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-141) *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |goodPols| (-658 *8)) (|:| |badPols| (-658 *8)))) (-5 *1 (-1006 *5 *6 *7 *8)) (-5 *4 (-658 *8))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1171 (-592))) (-5 *1 (-1175 *4)) (-4 *4 (-1075)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *3) (-12 (-4 *3 (-1235)) (-4 *5 (-1255 *3)) (-4 *6 (-1255 (-433 *5))) (-5 *2 (-141)) (-5 *1 (-361 *4 *3 *5 *6)) (-4 *4 (-362 *3 *5 *6)))) ((*1 *2 *3 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-388)) (-4 *5 (-1255 *4)) (-5 *2 (-1285)) (-5 *1 (-45 *4 *5 *6 *7)) (-4 *6 (-1255 (-433 *5))) (-14 *7 *6)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-788)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063)))) (-5 *1 (-593)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-788)) (-5 *4 (-1087)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))) (|:| |extra| (-1063)))) (-5 *1 (-593)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-809)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-809)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)) (|:| |extra| (-1063)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-822)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)))))) ((*1 *2 *3) (-12 (-5 *3 (-830)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-827)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-830)) (-5 *4 (-1087)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-827)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-858)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-858)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)))))) ((*1 *2 *3) (-12 (-5 *3 (-860)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-859)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-860)) (-5 *4 (-1087)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-859)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-917)) (-5 *3 (-1087)) (-5 *4 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *2 (-2 (|:| -2617 (-405)) (|:| |explanations| (-1173)))))) ((*1 *2 *3) (-12 (-5 *3 (-920)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-919)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-920)) (-5 *4 (-1087)) (-5 *2 (-2 (|:| -2617 (-405)) (|:| -4095 (-1173)) (|:| |explanations| (-658 (-1173))))) (-5 *1 (-919))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-141) *6 *6)) (-4 *6 (-869)) (-5 *4 (-658 *6)) (-5 *2 (-2 (|:| |fs| (-141)) (|:| |sd| *4) (|:| |td| (-658 *4)))) (-5 *1 (-1197 *6)) (-5 *5 (-658 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-405)))) (-5 *2 (-1113 (-862 (-237)))) (-5 *1 (-321))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1005 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *5 (-1089 *3 *4 *2))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-843))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 (-658 *2) *2 *2 *2)) (-4 *2 (-1119)) (-5 *1 (-126 *2)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1119)) (-5 *1 (-126 *2))))) 
+(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-524)))) ((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-727))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-356 *5 *6 *7 *8)) (-4 *5 (-456 *4)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *8 (-362 *5 *6 *7)) (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-2 (|:| -4346 (-790)) (|:| -1325 *8))) (-5 *1 (-933 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-356 (-433 (-592)) *4 *5 *6)) (-4 *4 (-1255 (-433 (-592)))) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 (-433 (-592)) *4 *5)) (-5 *2 (-2 (|:| -4346 (-790)) (|:| -1325 *6))) (-5 *1 (-934 *4 *5 *6))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-389 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119)))) ((*1 *1 *1) (-5 *1 (-647)))) 
+(((*1 *2) (-12 (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-931)) (-5 *1 (-483 *3 *4 *2 *5)) (-4 *5 (-977 *2 *3 *4)))) ((*1 *2) (-12 (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-931)) (-5 *1 (-928 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4)))) ((*1 *2) (-12 (-4 *2 (-931)) (-5 *1 (-929 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815)) (-5 *2 (-658 *6)) (-5 *1 (-1016 *3 *4 *5 *6)) (-4 *6 (-977 *3 *5 *4))))) 
+(((*1 *2) (|partial| -12 (-4 *3 (-582)) (-4 *3 (-194)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2195 (-658 *1)))) (-4 *1 (-392 *3)))) ((*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-478 *3 *4 *5 *6)) (|:| -2195 (-658 (-478 *3 *4 *5 *6))))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-706 (-237))) (-5 *4 (-592)) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-2 (|:| -2838 *5) (|:| -2724 *5)))) (-5 *1 (-829 *4 *5 *3 *6)) (-4 *3 (-670 *5)) (-4 *6 (-670 (-433 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *4 (-1255 *5)) (-5 *2 (-658 (-2 (|:| -2838 *4) (|:| -2724 *4)))) (-5 *1 (-829 *5 *4 *3 *6)) (-4 *3 (-670 *4)) (-4 *6 (-670 (-433 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-2 (|:| -2838 *5) (|:| -2724 *5)))) (-5 *1 (-829 *4 *5 *6 *3)) (-4 *6 (-670 *5)) (-4 *3 (-670 (-433 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *4 (-1255 *5)) (-5 *2 (-658 (-2 (|:| -2838 *4) (|:| -2724 *4)))) (-5 *1 (-829 *5 *4 *6 *3)) (-4 *6 (-670 *4)) (-4 *3 (-670 (-433 *4)))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *1 (-532 *3 *4 *5)) (-4 *5 (-435 *3 *4))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1095 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1127 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-658 *8)) (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-631 *3)) (-4 *3 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-594 *5 *3 *6)) (-4 *6 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-4 *4 (-373)) (-5 *2 (-1285)) (-5 *1 (-556 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-592))) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-582)) (-4 *8 (-977 *7 *5 *6)) (-5 *2 (-2 (|:| -3215 (-790)) (|:| -1487 *9) (|:| |radicand| *9))) (-5 *1 (-981 *5 *6 *7 *8 *9)) (-5 *4 (-790)) (-4 *9 (-13 (-388) (-10 -8 (-15 -1448 (*8 $)) (-15 -1456 (*8 $)) (-15 -1683 ($ *8)))))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-1119)) (-4 *2 (-922 *4)) (-5 *1 (-708 *4 *2 *5 *3)) (-4 *5 (-399 *2)) (-4 *3 (-13 (-399 *4) (-10 -7 (-6 -4625))))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *7)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-5 *2 (-658 (-995 *3))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-658 (-994 *3))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-252 (-1699 *5) (-790))) (-5 *2 (-658 *7)) (-5 *1 (-991 *4 *5 *3 *6 *7)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *7 (-999 *4))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *1 *3 *3 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-691 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))) (-5 *1 (-1095 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-4 *3 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-4 *4 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-374 *3 *4 *5)) (-4 *5 (-435 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-787 *4 *5)) (-4 *5 (-435 *3 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-1014 *4 *3 *5 *6)) (-4 *6 (-741 *3 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 *3)) (-5 *2 (-2 (|:| -2195 (-706 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-706 *3)))) (-5 *1 (-1289 *4 *3 *5 *6)) (-4 *6 (-435 *3 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-477)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-141)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-477)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-1006 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-2 (|:| |totdeg| (-790)) (|:| -3489 *4))) (-5 *5 (-790)) (-4 *4 (-977 *6 *7 *8)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-5 *2 (-2 (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (-5 *1 (-474 *6 *7 *8 *4))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-971 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *4 *5 *5 *2) (|partial| -12 (-5 *2 (-141)) (-5 *3 (-980 *6)) (-5 *4 (-1191)) (-5 *5 (-862 *7)) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-4 *7 (-13 (-1211) (-29 *6))) (-5 *1 (-236 *6 *7)))) ((*1 *2 *3 *4 *4 *2) (|partial| -12 (-5 *2 (-141)) (-5 *3 (-1187 *6)) (-5 *4 (-862 *6)) (-4 *6 (-13 (-1211) (-29 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-236 *5 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-362 *4 *3 *5)) (-4 *4 (-1235)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-5 *2 (-141)))) ((*1 *2 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-790)) (-5 *1 (-143))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *2 (-582)) (-5 *1 (-998 *2 *4)) (-4 *4 (-1255 *2))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *1 *1 *2 *2 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-953)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 *7)) (-5 *4 (-1 *7 (-790) (-790) *8)) (-5 *5 (-1280 *9)) (-5 *6 (-658 (-790))) (-4 *7 (-13 (-582) (-477))) (-4 *8 (-346 *7 (-790))) (-4 *9 (-346 (-433 *7) (-790))) (-5 *2 (-706 (-1187 *7))) (-5 *1 (-368 *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-658 *7)) (-5 *4 (-1 *7 (-790) (-790) *8)) (-5 *5 (-1280 *9)) (-5 *6 (-790)) (-4 *7 (-13 (-582) (-477))) (-4 *8 (-346 *7 *6)) (-4 *9 (-346 (-433 *7) *6)) (-5 *2 (-1171 (-706 (-1187 *7)))) (-5 *1 (-368 *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 *7)) (-5 *4 (-1 *7 (-790) (-790) *8)) (-5 *5 (-1280 *8)) (-5 *6 (-658 (-790))) (-4 *7 (-13 (-582) (-477))) (-4 *8 (-52 *7 (-790))) (-5 *2 (-706 (-1187 *7))) (-5 *1 (-369 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-658 *7)) (-5 *4 (-1 *7 (-790) (-790) *8)) (-5 *5 (-1280 *8)) (-5 *6 (-790)) (-4 *7 (-13 (-582) (-477))) (-4 *8 (-52 *7 *6)) (-5 *2 (-1171 (-706 (-1187 *7)))) (-5 *1 (-369 *7 *8))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1160 *5 (-558 (-879 *6)) (-879 *6) (-802 *5 (-879 *6))))) (-5 *1 (-643 *5 *6))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-191 (-237)))) (-5 *2 (-237)) (-5 *1 (-135))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-658 (-332 (-237)))) (-5 *3 (-237)) (-5 *2 (-141)) (-5 *1 (-224))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1191)) (-4 *5 (-633 (-914 (-592)))) (-4 *5 (-908 (-592))) (-4 *5 (-13 (-869) (-1065 (-592)) (-477) (-654 (-592)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-595 *5 *3)) (-4 *3 (-644)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) ((*1 *2 *2 *3 *4 *4) (|partial| -12 (-5 *3 (-1191)) (-5 *4 (-862 *2)) (-4 *2 (-1153)) (-4 *2 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-633 (-914 (-592)))) (-4 *5 (-908 (-592))) (-4 *5 (-13 (-869) (-1065 (-592)) (-477) (-654 (-592)))) (-5 *1 (-595 *5 *2))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030)))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-258 (-949 *4))) (-4 *4 (-373)) (-5 *2 (-706 *4)) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-258 (-949 *5))) (-5 *4 (-658 (-949 *5))) (-4 *5 (-373)) (-5 *2 (-706 *5)) (-5 *1 (-894 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-258 (-948 *4))) (-4 *4 (-388)) (-5 *2 (-706 *4)) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-258 (-948 *5))) (-5 *4 (-658 (-948 *5))) (-4 *5 (-388)) (-5 *2 (-706 *5)) (-5 *1 (-895 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-954))))) 
+(((*1 *2) (-12 (-5 *2 (-658 (-150))) (-5 *1 (-150))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1191)) (-5 *2 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *1 (-1194))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-658 *3))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-592)) (-5 *4 (-706 (-237))) (-5 *2 (-1063)) (-5 *1 (-774))))) 
+(((*1 *1) (-5 *1 (-463)))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-790)) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-96 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-234 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-518 *4)) (-4 *4 (-869)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1028 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1161 *4)) (-4 *4 (-1119)))) ((*1 *2 *3 *3) (|partial| -12 (-5 *2 (-141)) (-5 *1 (-1232 *3)) (-4 *3 (-1119)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-1 (-141) *3 *3)) (-4 *3 (-1119)) (-5 *2 (-141)) (-5 *1 (-1232 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-141)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-278))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *2 (-405)) (-5 *1 (-285)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *2 (-405)) (-5 *1 (-321))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-350))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-658 (-1 *4 (-658 *4)))) (-4 *4 (-1119)) (-5 *1 (-142 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1119)) (-5 *1 (-142 *4)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-143)) (-5 *2 (-658 (-1 *4 (-658 *4)))) (-5 *1 (-142 *4)) (-4 *4 (-1119))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-4 *4 (-194)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)) (-4 *3 (-194))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-592)) (-4 *1 (-62 *4 *3 *5)) (-4 *4 (-1225)) (-4 *3 (-399 *4)) (-4 *5 (-399 *4))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-405)) (-5 *3 (-1173)) (-5 *1 (-118)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-405)) (-5 *3 (-1173)) (-5 *1 (-118))))) 
+(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-1149 *4 *2)) (-4 *2 (-13 (-625 (-592) *4) (-10 -7 (-6 -4625) (-6 -4626)))))) ((*1 *2 *2) (-12 (-4 *3 (-869)) (-4 *3 (-1225)) (-5 *1 (-1149 *3 *2)) (-4 *2 (-13 (-625 (-592) *3) (-10 -7 (-6 -4625) (-6 -4626))))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-583 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4)))))) 
+(((*1 *2 *2 *2 *2 *2 *3) (-12 (-5 *2 (-706 *4)) (-5 *3 (-790)) (-4 *4 (-1075)) (-5 *1 (-707 *4))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-592)))) ((*1 *2 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-592)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-592))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-790)) (-5 *1 (-610 *2)) (-4 *2 (-574))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-627 *2)) (-4 *2 (-1119)))) ((*1 *1 *1) (-5 *1 (-647)))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-582)) (-5 *2 (-141))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-477)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1187 *6)) (-4 *6 (-977 *5 *3 *4)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-931)) (-5 *1 (-483 *3 *4 *5 *6)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1187 *1)) (-4 *1 (-931))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-269 *3)) (-4 *3 (-1225)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-318)) (-5 *2 (-790)))) ((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-877))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-790)) (-4 *6 (-388)) (-5 *4 (-1220 *6)) (-5 *2 (-1 (-1171 *4) (-1171 *4))) (-5 *1 (-1288 *6)) (-5 *5 (-1171 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1255 *6)) (-4 *6 (-13 (-27) (-456 *5))) (-4 *5 (-13 (-869) (-582) (-1065 (-592)))) (-4 *8 (-1255 (-433 *7))) (-5 *2 (-609 *3)) (-5 *1 (-577 *5 *6 *7 *8 *3)) (-4 *3 (-362 *6 *7 *8))))) 
+(((*1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1283))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-944) "arbitrary")) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-944) "arbitrary")) (-5 *1 (-489))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (-433 *5)) (|:| |c2| (-433 *5)) (|:| |deg| (-790)))) (-5 *1 (-172 *4 *5 *3)) (-4 *3 (-1255 (-433 *5)))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-790)) (-4 *4 (-13 (-582) (-171))) (-5 *1 (-1249 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-21)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-4 *2 (-1255 *4)) (-5 *1 (-945 *4 *2))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-574)) (-5 *1 (-181 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-293))))) 
+(((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-631 *3)) (-5 *5 (-1 (-1187 *3) (-1187 *3))) (-4 *3 (-13 (-27) (-456 *6))) (-4 *6 (-13 (-869) (-582))) (-5 *2 (-609 *3)) (-5 *1 (-576 *6 *3))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-658 (-804 *3))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *4 *4 *5 *6 *7) (-12 (-5 *5 (-1191)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-658 *4))) (-5 *7 (-1 (-3 (-2 (|:| -3191 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1211) (-27) (-456 *8))) (-4 *8 (-13 (-477) (-869) (-171) (-1065 *3) (-654 *3))) (-5 *3 (-592)) (-5 *2 (-2 (|:| |ans| *4) (|:| -1954 *4) (|:| |sol?| (-141)))) (-5 *1 (-1041 *8 *4))))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-914 *4)) (-4 *4 (-1119)) (-5 *1 (-912 *4 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-57)) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-477)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-433 (-592))) (-5 *1 (-459 *4 *3)) (-4 *3 (-456 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-631 *3)) (-4 *3 (-456 *5)) (-4 *5 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-1187 (-433 (-592)))) (-5 *1 (-459 *5 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-132)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-565))) (-5 *1 (-565))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *1 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225)))) ((*1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-399 *2)) (-4 *2 (-1225)))) ((*1 *1 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1212 *2)) (-4 *2 (-1119))))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1291 *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-658 *8)) (-5 *3 (-1 (-141) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1291 *5 *6 *7 *8))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *7)) (-5 *4 (-1187 *7)) (-4 *5 (-1075)) (-4 *7 (-1075)) (-4 *2 (-1255 *5)) (-5 *1 (-534 *5 *2 *6 *7)) (-4 *6 (-1255 *2))))) 
+(((*1 *2 *1 *3) (-12 (-5 *2 (-2 (|:| |k| (-592)) (|:| |c| *4))) (-5 *1 (-801 *4)) (-4 *4 (-388)) (-5 *3 (-592))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1005 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *5 (-1089 *3 *4 *2))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-592)) (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *9 (-665 *6)) (-5 *2 (-658 *9)) (-5 *1 (-679 *6 *7 *4 *8 *3 *9 *10)) (-4 *4 (-977 *6 *8 (-879 *7))) (-4 *3 (-999 *6)) (-4 *10 (-947 *6 *9))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-927 *4)) (-4 *4 (-1119)) (-5 *2 (-658 (-790))) (-5 *1 (-926 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-790)) (-5 *4 (-1280 *2)) (-4 *5 (-323)) (-4 *6 (-1021 *5)) (-4 *2 (-13 (-435 *6 *7) (-1065 *6))) (-5 *1 (-439 *5 *6 *7 *2)) (-4 *7 (-1255 *6))))) 
+(((*1 *1 *1) (|partial| -12 (-4 *1 (-392 *2)) (-4 *2 (-194)) (-4 *2 (-582)))) ((*1 *1 *1) (|partial| -4 *1 (-739)))) 
+(((*1 *1) (-5 *1 (-463)))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-1262 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1239 *3))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-237)) (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *2 *3 *3) (|partial| -12 (-5 *3 (-1191)) (-4 *4 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-603 *4 *2)) (-4 *2 (-13 (-1211) (-987) (-1153) (-29 *4)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-310 *3))) (-5 *1 (-310 *3)) (-4 *3 (-582)) (-4 *3 (-1225))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-706 (-592))) (-5 *3 (-658 (-592))) (-5 *1 (-1129))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592)))))) (-5 *2 (-658 (-433 (-592)))) (-5 *1 (-1047 *4)) (-4 *4 (-1255 (-592)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1225)) (-5 *2 (-658 *1)) (-4 *1 (-1038 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-1179 *3 *4))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-658 *9)) (-5 *3 (-1 (-141) *9)) (-5 *4 (-1 (-141) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1089 *6 *7 *8)) (-4 *6 (-582)) (-4 *7 (-815)) (-4 *8 (-869)) (-5 *1 (-1006 *6 *7 *8 *9))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-141)) (|:| -2165 *4)))) (-5 *1 (-795 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) ((*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-592)) (-5 *3 (-986 (-237))) (-5 *1 (-135))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1138 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *2 (-1 *5 *5)) (-5 *1 (-826 *4 *5)) (-4 *5 (-13 (-29 *4) (-1211) (-987)))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-33 *3)) (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1255 *4)) (-4 *4 (-1235)) (-4 *1 (-362 *4 *3 *5)) (-4 *5 (-1255 (-433 *3)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1089 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *6 *3)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *1 (-335)) (-5 *3 (-237))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| |radval| (-332 (-592))) (|:| |radmult| (-592)) (|:| |radvect| (-658 (-706 (-332 (-592)))))))) (-5 *1 (-1059))))) 
+(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1072 *4 *5)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *4)) (|:| -2231 (-658 (-980 *4)))))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1304 *5 *6 *7)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1304 *5 *6 *7)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1304 *5 *6 *7)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *4)) (|:| -2231 (-658 (-980 *4)))))) (-5 *1 (-1304 *4 *5 *6)) (-5 *3 (-658 (-980 *4))) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-846))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-515))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-1195))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1150 (-237))) (-5 *3 (-658 (-278))) (-5 *1 (-1282)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1150 (-237))) (-5 *3 (-1173)) (-5 *1 (-1282)))) ((*1 *1 *1) (-5 *1 (-1282)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-592)) (-5 *4 (-1 (-1285) (-1123))) (-5 *2 (-1285)) (-5 *1 (-122))))) 
+(((*1 *2) (-12 (-4 *3 (-394)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *9)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-5 *2 (-658 (-949 *3))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-658 (-948 *3))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-477)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-592)) (-5 *1 (-1133 *4 *5))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1116 *3)) (-4 *3 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) ((*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-489))))) 
+(((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-592))) (-5 *1 (-1073))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-592)) (-4 *3 (-194)) (-4 *5 (-399 *3)) (-4 *6 (-399 *3)) (-5 *1 (-705 *3 *5 *6 *2)) (-4 *2 (-704 *3 *5 *6))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *3)) (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-869)) (-5 *2 (-658 (-658 *4))) (-5 *1 (-1197 *4)) (-5 *3 (-658 *4))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-592)) (-4 *4 (-13 (-582) (-171))) (-5 *1 (-566 *4 *2)) (-4 *2 (-1270 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-592)) (-4 *4 (-13 (-388) (-394) (-633 *3))) (-4 *5 (-1255 *4)) (-4 *6 (-741 *4 *5)) (-5 *1 (-570 *4 *5 *6 *2)) (-4 *2 (-1270 *6)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-592)) (-4 *4 (-13 (-388) (-394) (-633 *3))) (-5 *1 (-571 *4 *2)) (-4 *2 (-1270 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-592)) (-4 *4 (-13 (-582) (-171))) (-5 *1 (-1166 *4))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-171))) (-5 *1 (-566 *3 *2)) (-4 *2 (-1270 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-4 *4 (-1255 *3)) (-4 *5 (-741 *3 *4)) (-5 *1 (-570 *3 *4 *5 *2)) (-4 *2 (-1270 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-5 *1 (-571 *3 *2)) (-4 *2 (-1270 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-13 (-582) (-171))) (-5 *1 (-1166 *3))))) 
+(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-13 (-582) (-171))) (-5 *1 (-1249 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-658 (-706 *6))) (-5 *4 (-141)) (-5 *5 (-592)) (-5 *2 (-706 *6)) (-5 *1 (-1057 *6)) (-4 *6 (-388)) (-4 *6 (-1075)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 (-706 *4))) (-5 *2 (-706 *4)) (-5 *1 (-1057 *4)) (-4 *4 (-388)) (-4 *4 (-1075)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 (-706 *5))) (-5 *4 (-592)) (-5 *2 (-706 *5)) (-5 *1 (-1057 *5)) (-4 *5 (-388)) (-4 *5 (-1075))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-790)) (-4 *4 (-373)) (-5 *1 (-229 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *1 *2 *3) (-12 (-4 *4 (-388)) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-665 *4)) (-4 *8 (-947 *4 *7)) (-4 *1 (-560 *4 *5 *3 *6 *2 *7 *8 *9 *10)) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *2 (-999 *4)) (-4 *9 (-257 *8)) (-4 *10 (-137)))) ((*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (-12 (-5 *3 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *8)) (-5 *4 (-33 *8)) (-5 *9 (-1191)) (-4 *8 (-388)) (-5 *5 (-790)) (-4 *12 (-252 (-1699 *10) *5)) (-4 *13 (-665 *8)) (-4 *14 (-947 *8 *13)) (-4 *1 (-560 *8 *10 *11 *12 *2 *13 *14 *7 *6)) (-4 *11 (-977 *8 *12 (-879 *10))) (-4 *2 (-999 *8)) (-4 *7 (-257 *14)) (-4 *6 (-137)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-4 *3 (-388)) (-4 *1 (-947 *3 *4)) (-4 *4 (-665 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-947 *3 *4)) (-4 *4 (-665 *3)))) ((*1 *1) (-5 *1 (-1103)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (-5 *1 (-285))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-2 (|:| |val| (-658 *6)) (|:| -2165 *7)))) (-4 *6 (-1089 *3 *4 *5)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1017 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-2 (|:| |val| (-658 *6)) (|:| -2165 *7)))) (-4 *6 (-1089 *3 *4 *5)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1126 *3 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-191 (-237)))) (-5 *2 (-237)) (-5 *1 (-135))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-706 *5))) (-4 *5 (-323)) (-4 *5 (-1075)) (-5 *2 (-1280 (-1280 *5))) (-5 *1 (-1057 *5)) (-5 *4 (-1280 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-191 (-332 *4))) (-5 *1 (-202 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 (-191 *4)))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-191 *3)) (-5 *1 (-1215 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1280 *5)) (-4 *5 (-814)) (-5 *2 (-141)) (-5 *1 (-864 *4 *5)) (-14 *4 (-790))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-1075)) (-5 *1 (-469 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-388)) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-37 *4)) (-4 *4 (-388)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-188 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-444 *3)) (-4 *3 (-574)) (-4 *3 (-582)))) ((*1 *2 *1) (-12 (-4 *1 (-574)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-819 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-855 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-862 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-999 *4)) (-4 *4 (-388)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1025 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-141)))) ((*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-1036 *3)) (-4 *3 (-1065 (-433 (-592))))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *3 (-582)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-705 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-592)) (-4 *5 (-867)) (-4 *5 (-388)) (-5 *2 (-790)) (-5 *1 (-973 *5 *6)) (-4 *6 (-1255 *5))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-582)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-1216 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1225)) (-5 *2 (-790)) (-5 *1 (-201 *4 *3)) (-4 *3 (-690 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *5)) (-4 *5 (-654 *4)) (-4 *4 (-582)) (-5 *2 (-141)) (-5 *1 (-653 *4 *5))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-1075)) (-4 *3 (-869)) (-5 *2 (-2 (|:| |val| *1) (|:| -3215 (-592)))) (-4 *1 (-456 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-914 *3)) (|:| -3215 (-914 *3)))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-2 (|:| |val| *3) (|:| -3215 (-592)))) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $)))))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) ((*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-239)))) ((*1 *1 *1) (-4 *1 (-644))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2934 *1))) (-4 *1 (-871 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-373)) (-5 *2 (-444 (-1187 (-1187 *5)))) (-5 *1 (-1224 *5)) (-5 *3 (-1187 (-1187 *5)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *2 (-922 *5)) (-5 *1 (-708 *5 *2 *3 *4)) (-4 *3 (-399 *2)) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4625))))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-237)) (-5 *1 (-844))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953))))) 
+(((*1 *2 *1 *1 *3) (-12 (-5 *3 (-1 (-141) *5 *5)) (-4 *5 (-13 (-1119) (-39))) (-5 *2 (-141)) (-5 *1 (-1154 *4 *5)) (-4 *4 (-13 (-1119) (-39)))))) 
+(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-658 (-980 *6))) (-5 *4 (-658 (-1191))) (-4 *6 (-477)) (-5 *2 (-658 (-658 *7))) (-5 *1 (-567 *6 *7 *5)) (-4 *7 (-388)) (-4 *5 (-13 (-388) (-867)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1270 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 *2)) (-14 *6 *2) (-5 *2 (-790)) (-5 *1 (-935 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1112 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -1954 *6) (|:| |sol?| (-141))) (-592) *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-2 (|:| |answer| (-609 (-433 *7))) (|:| |a0| *6))) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1191)) (-5 *3 (-460)) (-4 *5 (-869)) (-5 *1 (-1125 *5 *4)) (-4 *4 (-456 *5))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1221 *3)) (-4 *3 (-1003))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1173)) (-5 *3 (-845)) (-5 *1 (-844))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-980 (-191 *4))) (-4 *4 (-194)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-980 (-191 *5))) (-5 *4 (-944)) (-4 *5 (-194)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-980 *4)) (-4 *4 (-1075)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-980 *5)) (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 (-191 *4)))) (-4 *4 (-582)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-980 (-191 *5)))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-332 *4)) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-332 *5)) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-332 (-191 *4))) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-332 (-191 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 (-405))) (-5 *2 (-191 (-405))) (-5 *1 (-807 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 (-1280 *4))) (-4 *4 (-1075)) (-5 *2 (-706 *4)) (-5 *1 (-1057 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (-12 (-5 *2 (-980 (-405))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-405)))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-405))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-405))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (-12 (-5 *2 (-980 (-592))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-592)))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-592))) (-5 *1 (-359 *3 *4 *5)) (-4 *5 (-1065 (-592))) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 *2)) (-14 *4 (-658 *2)) (-4 *5 (-413)))) ((*1 *1 *2) (-12 (-5 *2 (-332 *5)) (-4 *5 (-413)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-433 (-980 (-592))))) (-4 *1 (-410)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-433 (-980 (-405))))) (-4 *1 (-410)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-980 (-592)))) (-4 *1 (-410)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-980 (-405)))) (-4 *1 (-410)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-332 (-592)))) (-4 *1 (-410)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-332 (-405)))) (-4 *1 (-410)))) ((*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-592)))) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-405)))) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-980 (-592))) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-980 (-405))) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-592))) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-405))) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-433 (-980 (-592))))) (-4 *1 (-466)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-433 (-980 (-405))))) (-4 *1 (-466)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-980 (-592)))) (-4 *1 (-466)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-980 (-405)))) (-4 *1 (-466)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-332 (-592)))) (-4 *1 (-466)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-332 (-405)))) (-4 *1 (-466)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-761 *3 *4))) (-5 *1 (-760 *3 *4)) (-14 *3 (-1191)) (-4 *4 (-13 (-1075) (-869) (-582))))) ((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) (-5 *1 (-788)))) ((*1 *1 *2) (-12 (-5 *2 (-1237 *3)) (-4 *3 (-373)) (-5 *1 (-797 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *1 (-830)))) ((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))) (-5 *1 (-860)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *1 (-920)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *1 (-1005 *3 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1065 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (-3836 (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-3252 (-4 *3 (-43 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-574))) (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 *3)) (-12 (-3252 (-4 *3 (-1021 (-592)))) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869))))) ((*1 *1 *2) (-3836 (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))))) ((*1 *1 *2) (-12 (-5 *2 (-980 (-433 (-592)))) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-1187 *3))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-629 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1283))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1225)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-416 *3 *4 *5)) (-14 *3 (-790)) (-14 *4 (-790)) (-4 *5 (-194))))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-3 (-2 (|:| -3191 *7) (|:| |coeff| *7)) "failed") *7)) (-5 *6 (-658 (-433 *8))) (-4 *7 (-388)) (-4 *8 (-1255 *7)) (-5 *3 (-433 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-602 *7 *8))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-706 *7)) (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *1 (-951 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *4 *4)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-5 *2 (-1 *5 *4)) (-5 *1 (-699 *4 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-332 (-237)))) (-5 *1 (-285))))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-592)) (|has| *1 (-6 -4626)) (-4 *1 (-399 *3)) (-4 *3 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-980 *5)) (-4 *5 (-1075)) (-5 *2 (-516 *4 *5)) (-5 *1 (-972 *4 *5)) (-14 *4 (-658 (-1191)))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-388)) (-5 *1 (-302 *3 *2)) (-4 *2 (-1270 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-1187 *2)) (-4 *2 (-456 *4)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-36 *4 *2))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-944)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-278))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4175 (-790)) (|:| |eqns| (-658 (-2 (|:| |det| *7) (|:| -4274 (-658 (-592))) (|:| |cols| (-658 (-592)))))) (|:| |fgb| (-658 *7))))) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-790)) (-5 *1 (-951 *4 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-885)) (-5 *2 (-944))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-1191)) (-4 *6 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-4 *4 (-13 (-29 *6) (-1211) (-987))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2195 (-658 *4)))) (-5 *1 (-823 *6 *4 *3)) (-4 *3 (-670 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373))))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1191)) (-5 *6 (-658 (-631 *3))) (-5 *5 (-631 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-583 *7 *3))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-2 (|:| -3220 (-658 (-877))) (|:| -4079 (-658 (-877))) (|:| |presup| (-658 (-877))) (|:| -3589 (-658 (-877))) (|:| |args| (-658 (-877))))) (-5 *1 (-1191)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-658 (-877)))) (-5 *1 (-1191))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1085 (-1051 *3) (-1187 (-1051 *3)))) (-5 *1 (-1051 *3)) (-4 *3 (-13 (-867) (-388) (-1049)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-667 *4)) (-4 *4 (-362 *5 *6 *7)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-828 *5 *6 *7 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-778))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-57))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *1) (-5 *1 (-168))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-1150 (-237))) (-5 *1 (-278))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-332 (-237)))) (-5 *2 (-141)) (-5 *1 (-285)))) ((*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-141)) (-5 *1 (-285)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-332 (-191 (-405)))) (-5 *1 (-350)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-592))) (-5 *1 (-350)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-405))) (-5 *1 (-350)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-710))) (-5 *1 (-350)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-717))) (-5 *1 (-350)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-715))) (-5 *1 (-350)))) ((*1 *1) (-5 *1 (-350)))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-658 *4)) (-4 *4 (-388)) (-5 *2 (-1280 *4)) (-5 *1 (-836 *4 *3)) (-4 *3 (-670 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-665 *2)) (-4 *2 (-388))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-654 (-592))) (-5 *2 (-141)) (-5 *1 (-1305 *4))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1232 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *1 (-935 *4 *2 *5 *6)) (-4 *2 (-346 *4 *5))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *1 *2 *2) (-12 (-5 *1 (-900 *2)) (-4 *2 (-1225)))) ((*1 *1 *2 *2 *2) (-12 (-5 *1 (-902 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-971 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-971 *3))) (-4 *1 (-1151 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *3 (-257 *10)) (-4 *11 (-560 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-137)) (-5 *2 (-2 (|:| |num| (-658 *6)) (|:| |den| *6))) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-258 (-949 *5))) (-5 *4 (-790)) (-4 *5 (-373)) (-5 *2 (-658 (-433 (-264 *6 *5)))) (-5 *1 (-894 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-258 (-949 *4))) (-4 *4 (-373)) (-5 *2 (-2 (|:| |num| (-658 (-264 *5 *4))) (|:| |den| (-264 *5 *4)))) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-258 (-948 *5))) (-5 *4 (-790)) (-4 *5 (-388)) (-5 *2 (-658 (-433 (-264 *6 *5)))) (-5 *1 (-895 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-4 *7 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-258 (-948 *4))) (-4 *4 (-388)) (-5 *2 (-2 (|:| |num| (-658 (-264 *5 *4))) (|:| |den| (-264 *5 *4)))) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *3)) (-5 *1 (-1145 *4 *3)) (-4 *4 (-1255 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-5 *1 (-463))))) 
+(((*1 *1 *1 *1) (|partial| -4 *1 (-158)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-855 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-862 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1) (-5 *1 (-237))) ((*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1) (-4 *1 (-1153))) ((*1 *1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1089 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1219 *4 *5 *6 *3)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1482 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)) (-5 *2 (-1187 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-790)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-815)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-474 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-914 *4)) (-4 *4 (-1119)) (-5 *2 (-658 *5)) (-5 *1 (-912 *4 *5)) (-4 *5 (-1225))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-658 *5)) (-4 *1 (-947 *4 *5)) (-4 *4 (-388)) (-4 *5 (-665 *4)) (-5 *2 (-1285))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-468 *4 *3 *5)) (-4 *3 (-1255 *4)) (-4 *5 (-13 (-430) (-1065 *4) (-388) (-1211) (-301)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1262 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1239 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-937 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1123)) (-5 *1 (-350))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-50 (-1173) (-793))) (-5 *1 (-143))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1 *3 *3 (-592))) (-4 *3 (-1075)) (-5 *1 (-121 *3)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-121 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-121 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-2 (|:| |adjMat| *3) (|:| |detMat| *4))) (-5 *1 (-705 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-194)) (-4 *2 (-1075)) (-5 *1 (-731 *2 *3)) (-4 *3 (-661 *2)))) ((*1 *1 *1) (-12 (-4 *2 (-194)) (-4 *2 (-1075)) (-5 *1 (-731 *2 *3)) (-4 *3 (-661 *2)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-856 *2)) (-4 *2 (-194)) (-4 *2 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-856 *2)) (-4 *2 (-194)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-3 (-1 (-237) (-237) (-237) (-237)) "undefined")) (-5 *5 (-1113 (-237))) (-5 *6 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-713))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-237)) (-5 *1 (-321))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-347 *3)) (-4 *3 (-1225)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-549 *3 *4)) (-4 *3 (-1225)) (-14 *4 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-1106 *4)))) (-5 *2 (-141)) (-5 *1 (-1106 *4)) (-4 *4 (-13 (-869) (-582))))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 (-1106 *4))) (-5 *2 (-141)) (-5 *1 (-1106 *4)) (-4 *4 (-13 (-869) (-582))))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-658 (-1187 (-592)))) (-5 *1 (-205)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1063)) (-5 *3 (-1191)) (-5 *1 (-285))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-876)))) ((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-1018)))) ((*1 *2 *1) (-12 (-4 *1 (-1038 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-1119) (-39))) (-5 *1 (-1154 *2 *3)) (-4 *3 (-13 (-1119) (-39)))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *3 (-1255 *4)) (-5 *1 (-831 *4 *3 *2 *5)) (-4 *2 (-670 *3)) (-4 *5 (-670 (-433 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-433 *5)) (-4 *4 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *1 (-831 *4 *5 *2 *6)) (-4 *2 (-670 *5)) (-4 *6 (-670 *3))))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-1191)) (-5 *1 (-150))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-143)) (-5 *1 (-142 *3)) (-4 *3 (-869)) (-4 *3 (-1119))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) ((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 *3)) (-5 *1 (-951 *4 *5 *6 *3)) (-4 *3 (-977 *4 *6 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) ((*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-980 *5))) (-5 *4 (-141)) (-4 *5 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-1304 *5 *6 *7)) (-14 *6 (-658 (-1191))) (-14 *7 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-658 (-1072 *4 *5))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191)))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-953))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496))))) 
+(((*1 *1 *1 *1) (|partial| -12 (-4 *2 (-194)) (-5 *1 (-306 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1255 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-728 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *2 (-194)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-5 *2 (-141)) (-5 *1 (-610 *3)) (-4 *3 (-574))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-355 *3 *4 *5 *6)) (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 *3 *4 *5)) (-5 *2 (-439 *4 (-433 *4) *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *6)) (-4 *6 (-13 (-435 *4 *5) (-1065 *4))) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-4 *3 (-323)) (-5 *1 (-439 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-1030)) (-4 *2 (-1075))))) 
+(((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-658 *1)) (-4 *1 (-323))))) 
+(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| -3191 (-433 *6)) (|:| |coeff| (-433 *6)))) (-5 *1 (-602 *5 *6)) (-5 *3 (-433 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-193)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1221 *3)) (-4 *3 (-1003))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-350))))) 
+(((*1 *1 *1) (-4 *1 (-1084))) ((*1 *1 *1 *2 *2) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1257 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-814))))) 
+(((*1 *2 *3 *2) (-12 (-4 *2 (-13 (-388) (-867))) (-5 *1 (-200 *2 *3)) (-4 *3 (-1255 (-191 *2))))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-388) (-867))) (-5 *1 (-200 *2 *3)) (-4 *3 (-1255 (-191 *2)))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-356 *5 *6 *7 *8)) (-4 *5 (-456 *4)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-4 *8 (-362 *5 *6 *7)) (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-5 *2 (-141)) (-5 *1 (-933 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-356 (-433 (-592)) *4 *5 *6)) (-4 *4 (-1255 (-433 (-592)))) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 (-433 (-592)) *4 *5)) (-5 *2 (-141)) (-5 *1 (-934 *4 *5 *6))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-706 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282)))) ((*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1282))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-323)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-2 (|:| |Hermite| *3) (|:| |eqMat| *3))) (-5 *1 (-1141 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6))))) 
+(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 (-2 (|:| -3191 *4) (|:| |coeff| *4)) "failed") *4)) (-4 *4 (-388)) (-5 *1 (-602 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1173)) (-5 *1 (-808))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-1191))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-122)))) ((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-227 (-535))) (-5 *1 (-857))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-5 *1 (-1198 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-463))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-658 *5))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))) (-5 *2 (-658 (-1191))) (-5 *1 (-1097 *3 *4 *5)) (-4 *5 (-13 (-456 *4) (-908 *3) (-633 (-914 *3))))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-706 *1)) (-4 *1 (-373)) (-5 *2 (-1280 *1)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-706 *1)) (-4 *1 (-169)) (-4 *1 (-931)) (-5 *2 (-1280 *1))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-3 (-433 (-980 *5)) (-1180 (-1191) (-980 *5)))) (-4 *5 (-477)) (-5 *2 (-658 (-706 (-433 (-980 *5))))) (-5 *1 (-308 *5)) (-5 *4 (-706 (-433 (-980 *5))))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-4 *2 (-1075)) (-5 *1 (-935 *2 *3 *5 *6)) (-4 *3 (-346 *2 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1187 (-592))) (-5 *4 (-592)) (-5 *2 (-1229)) (-5 *1 (-982))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-660 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1) (-4 *1 (-167))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-180 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-362 *4 *3 *5)) (-4 *4 (-1235)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-5 *2 (-141)))) ((*1 *2 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))) (-5 *2 (-658 (-1173))) (-5 *1 (-285))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-1173)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *4 (-1089 *6 *7 *8)) (-5 *2 (-1285)) (-5 *1 (-795 *6 *7 *8 *4 *5)) (-4 *5 (-1094 *6 *7 *8 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| -1608 (-143)) (|:| |w| (-237)))) (-5 *1 (-218))))) 
+(((*1 *2) (-12 (-5 *2 (-658 (-944))) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-944))) (-5 *1 (-1283))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-323)) (-5 *1 (-716 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-4 *1 (-1002 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-814)) (-4 *5 (-869)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *1 (-692 *3 *4)) (-4 *3 (-1225)) (-4 *4 (-1225)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1091 *4 *3)) (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-171)) (-4 *3 (-323)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-188 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-444 *3)) (-4 *3 (-574)) (-4 *3 (-582)))) ((*1 *2 *1) (-12 (-4 *1 (-574)) (-5 *2 (-433 (-592))))) ((*1 *2 *1) (-12 (-4 *1 (-819 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-855 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-862 *3)) (-4 *3 (-574)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1025 *3)) (-4 *3 (-194)) (-4 *3 (-574)) (-5 *2 (-433 (-592))))) ((*1 *2 *3) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-1036 *3)) (-4 *3 (-1065 *2))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-560 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *10)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-280 *11)))) ((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-560 *3 *4 *5 *6 *7 *8 *9 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *9)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2) (-12 (-5 *2 (-258 (-949 *3))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-258 (-948 *3))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *4)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-5 *2 (-658 (-658 (-790)))) (-5 *1 (-139 *4 *5 *6 *7 *8)) (-4 *6 (-346 *4 *7)) (-4 *8 (-137))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-658 (-980 (-592)))) (-5 *4 (-658 (-1191))) (-5 *5 (-592)) (-4 *1 (-692 *6 *2)) (-4 *6 (-1225)) (-4 *2 (-1225))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-257 *2)) (-4 *2 (-1119)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1063)) (-5 *1 (-321)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-1063))) (-5 *2 (-1063)) (-5 *1 (-321)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-664 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-664 *2)) (-4 *2 (-1225)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-664 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-664 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *1) (-5 *1 (-1087))) ((*1 *2 *3) (-12 (-5 *3 (-1171 (-1171 *4))) (-5 *2 (-1171 *4)) (-5 *1 (-1168 *4)) (-4 *4 (-1225)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-401 *4 *2)) (-4 *2 (-13 (-399 *4) (-10 -7 (-6 -4626))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-706 *4)) (-4 *4 (-388)) (-5 *2 (-1187 *4)) (-5 *1 (-559 *4 *5 *6)) (-4 *5 (-388)) (-4 *6 (-13 (-388) (-867)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-1065 (-433 *2)))) (-5 *2 (-592)) (-5 *1 (-144 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *1 *2 *1) (-12 (-4 *1 (-1158)) (-5 *2 (-1246 (-592)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-625 *2 *3)) (-4 *3 (-1225)) (-4 *2 (-1119)) (-4 *2 (-869))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-825))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1283))))) 
+(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1191)) (-4 *4 (-1075)) (-4 *4 (-869)) (-5 *2 (-2 (|:| |var| (-631 *1)) (|:| -3215 (-592)))) (-4 *1 (-456 *4)))) ((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-143)) (-4 *4 (-1075)) (-4 *4 (-869)) (-5 *2 (-2 (|:| |var| (-631 *1)) (|:| -3215 (-592)))) (-4 *1 (-456 *4)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1131)) (-4 *3 (-869)) (-5 *2 (-2 (|:| |var| (-631 *1)) (|:| -3215 (-592)))) (-4 *1 (-456 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-914 *3)) (|:| -3215 (-790)))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-977 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| |var| *5) (|:| -3215 (-790)))))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-4 *7 (-977 *6 *4 *5)) (-5 *2 (-2 (|:| |var| *5) (|:| -3215 (-592)))) (-5 *1 (-978 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-388) (-10 -8 (-15 -1683 ($ *7)) (-15 -1448 (*7 $)) (-15 -1456 (*7 $)))))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-592)) (-4 *4 (-373)) (-5 *1 (-556 *4))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206))))) 
+(((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-625 *4 *3)) (-4 *4 (-1119)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-272))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1187 *3)) (-4 *3 (-394)) (-4 *1 (-349 *3)) (-4 *3 (-388))))) 
+(((*1 *2 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *1 *2) (-12 (-5 *1 (-1154 *3 *2)) (-4 *3 (-13 (-1119) (-39))) (-4 *2 (-13 (-1119) (-39)))))) 
+(((*1 *1 *2 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 *10)) (-5 *1 (-640 *5 *6 *7 *8 *9 *10)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *10 (-1128 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-643 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1160 *5 (-558 (-879 *6)) (-879 *6) (-802 *5 (-879 *6))))) (-5 *1 (-643 *5 *6)))) ((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1055 *5 *6 *7 *8))) (-5 *1 (-1055 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1055 *5 *6 *7 *8))) (-5 *1 (-1055 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 (-802 *5 (-879 *6)))) (-5 *4 (-141)) (-4 *5 (-477)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-1072 *5 *6))) (-5 *1 (-1072 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1094 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1160 *5 *6 *7 *8))) (-5 *1 (-1160 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-658 (-1160 *5 *6 *7 *8))) (-5 *1 (-1160 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 *1)) (-4 *1 (-1219 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-206)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-316)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-321))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-658 *3))))) 
+(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-790)) (-4 *5 (-194)))) ((*1 *1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194)))) ((*1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *1 (-704 *3 *2 *4)) (-4 *2 (-399 *3)) (-4 *4 (-399 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1156 *2 *3)) (-14 *2 (-790)) (-4 *3 (-1075))))) 
+(((*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-318)))) ((*1 *1 *1) (-4 *1 (-318))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) ((*1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-592)) (-4 *1 (-62 *4 *5 *3)) (-4 *4 (-1225)) (-4 *5 (-399 *4)) (-4 *3 (-399 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-191 (-592)))))) (-5 *2 (-658 (-658 (-310 (-980 (-191 *4)))))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-310 (-433 (-980 (-191 (-592))))))) (-5 *2 (-658 (-658 (-310 (-980 (-191 *4)))))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-191 (-592))))) (-5 *2 (-658 (-310 (-980 (-191 *4))))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-433 (-980 (-191 (-592)))))) (-5 *2 (-658 (-310 (-980 (-191 *4))))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-264 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *2 (-516 *4 *5)) (-5 *1 (-646 *4 *5))))) 
+(((*1 *2 *3 *3 *3 *3) (-12 (-5 *3 (-592)) (-5 *2 (-141)) (-5 *1 (-515))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-706 *2)) (-4 *4 (-1255 *2)) (-4 *2 (-13 (-323) (-10 -8 (-15 -3164 ((-444 $) $))))) (-5 *1 (-532 *2 *4 *5)) (-4 *5 (-435 *2 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1187 *1)) (-4 *1 (-1040))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-937 *2)) (-4 *2 (-323))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1 (-237) (-237) (-237) (-237))) (-5 *1 (-278)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-237) (-237) (-237))) (-5 *1 (-278)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *1 (-278))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1 (-971 (-237)) (-971 (-237)))) (-5 *1 (-278)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-349 *4)) (-4 *4 (-388)) (-5 *2 (-706 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-5 *2 (-1280 *3)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-1280 *4)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-1280 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-435 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-435 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-1280 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-443 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-1280 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-706 *5))) (-5 *3 (-706 *5)) (-4 *5 (-388)) (-5 *2 (-1280 *5)) (-5 *1 (-1105 *5))))) 
+(((*1 *1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *2)) (-4 *2 (-977 *3 *4 *5)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-388)) (-4 *3 (-815)) (-4 *4 (-869)) (-5 *1 (-538 *2 *3 *4 *5)) (-4 *5 (-977 *2 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-191 *5)) (-4 *5 (-13 (-456 *4) (-1030) (-1211))) (-4 *4 (-13 (-582) (-869))) (-4 *2 (-13 (-456 (-191 *4)) (-1030) (-1211))) (-5 *1 (-621 *4 *5 *2))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-971 *3) (-971 *3))) (-5 *1 (-196 *3)) (-4 *3 (-13 (-388) (-1211) (-1030)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-37 *3)) (-4 *3 (-388)))) ((*1 *1 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)))) ((*1 *1 *1 *1) (-4 *1 (-502))) ((*1 *1 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) ((*1 *1 *1) (-4 *1 (-885))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-905)))) ((*1 *1 *1) (-12 (-4 *1 (-999 *2)) (-4 *2 (-388)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-999 *3)) (-4 *3 (-388)))) ((*1 *1 *1) (-5 *1 (-1000))) ((*1 *1 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *3 (-257 *10)) (-4 *11 (-560 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-137)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-5 *1 (-586 *4 *5 *6 *7 *8 *9 *10 *3)) (-4 *8 (-999 *4)) (-4 *3 (-257 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-258 (-949 *5))) (-5 *4 (-658 (-264 *6 *5))) (-4 *5 (-373)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-264 *6 (-884 *5)))) (-5 *1 (-894 *5 *6 *7)) (-4 *7 (-137)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-658 (-264 *5 *4))) (-5 *3 (-258 (-948 *4))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *1 (-895 *4 *5 *6)) (-4 *6 (-137))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-1116 *3)))) ((*1 *1) (-12 (-4 *1 (-1116 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-927 *3))) (-5 *1 (-926 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-143)) (-5 *4 (-790)) (-4 *5 (-477)) (-4 *5 (-869)) (-4 *5 (-1065 (-592))) (-4 *5 (-582)) (-5 *1 (-46 *5 *2)) (-4 *2 (-456 *5)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *5 (-631 $)) $)) (-15 -1456 ((-1142 *5 (-631 $)) $)) (-15 -1683 ($ (-1142 *5 (-631 $)))))))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-1075)) (-4 *2 (-1255 *5)) (-5 *1 (-1273 *5 *2 *6 *3)) (-4 *6 (-670 *2)) (-4 *3 (-1270 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-4 *2 (-13 (-428) (-10 -7 (-15 -1683 (*2 *4)) (-15 -3546 ((-944) *2)) (-15 -2195 ((-1280 *2) (-944))) (-15 -3417 (*2 *2))))) (-5 *1 (-380 *2 *4))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-582)) (-4 *4 (-1021 *3)) (-5 *1 (-164 *3 *4 *2)) (-4 *2 (-399 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-1021 *4)) (-4 *2 (-399 *4)) (-5 *1 (-536 *4 *5 *2 *3)) (-4 *3 (-399 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-706 *5)) (-4 *5 (-1021 *4)) (-4 *4 (-582)) (-5 *2 (-706 *4)) (-5 *1 (-709 *4 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-582)) (-4 *4 (-1021 *3)) (-5 *1 (-1248 *3 *4 *2)) (-4 *2 (-1255 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-843))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *4 *6) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-592)) (-5 *2 (-1221 (-953))) (-5 *1 (-335)))) ((*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-592)) (-5 *7 (-1173)) (-5 *2 (-1221 (-953))) (-5 *1 (-335)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-237)) (-5 *7 (-592)) (-5 *2 (-1221 (-953))) (-5 *1 (-335)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-237)) (-5 *7 (-592)) (-5 *8 (-1173)) (-5 *2 (-1221 (-953))) (-5 *1 (-335))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *7)) (-5 *4 (-1187 *7)) (-4 *5 (-1075)) (-4 *7 (-1075)) (-4 *2 (-1255 *5)) (-5 *1 (-534 *5 *2 *6 *7)) (-4 *6 (-1255 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1075)) (-4 *7 (-1075)) (-4 *4 (-1255 *5)) (-5 *2 (-1187 *7)) (-5 *1 (-534 *5 *4 *6 *7)) (-4 *6 (-1255 *4))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-1175 *3))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-143)) (-5 *4 (-631 *7)) (-4 *7 (-13 (-456 *6) (-23) (-1065 *2) (-1065 *5) (-922 *5) (-182))) (-5 *5 (-1191)) (-4 *6 (-1075)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-592)) (-5 *1 (-1052 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *3 (-922 *5)) (-5 *2 (-706 *3)) (-5 *1 (-708 *5 *3 *6 *4)) (-4 *6 (-399 *3)) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4625))))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 *5)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)) (-4 *5 (-194))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-1137)) (-5 *1 (-133))))) 
+(((*1 *2 *3 *4 *4 *4 *5 *4 *6 *6 *3) (-12 (-5 *4 (-706 (-237))) (-5 *5 (-706 (-592))) (-5 *6 (-237)) (-5 *3 (-592)) (-5 *2 (-1063)) (-5 *1 (-770))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-5 *2 (-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-799 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *5)) (-4 *5 (-346 *4 *6)) (-4 *6 (-252 *7 (-790))) (-14 *7 (-790)) (-4 *4 (-1075)) (-5 *2 (-2 (|:| -2535 (-592)) (|:| -4226 (-592)) (|:| -2230 (-592)) (|:| |reste| (-592)) (|:| -4039 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-799 *4 *5 *6 *7))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-237))))) 
+(((*1 *1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-658 (-310 *4))) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-578))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *1 *1) (-4 *1 (-1158)))) 
+(((*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-171) (-27) (-1065 (-592)) (-1065 (-433 (-592))))) (-4 *5 (-1255 *4)) (-5 *2 (-1187 (-433 *5))) (-5 *1 (-634 *4 *5)) (-5 *3 (-433 *5)))) ((*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-171) (-27) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-1187 (-433 *6))) (-5 *1 (-634 *5 *6)) (-5 *3 (-433 *6))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -1487 *3) (|:| |gap| (-790)) (|:| -2230 (-804 *3)) (|:| -3027 (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-1075)))) ((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-2 (|:| -1487 *1) (|:| |gap| (-790)) (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1089 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -1487 *1) (|:| |gap| (-790)) (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *2 *3 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-1194)) (-5 *3 (-1191))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1280 *4)) (-4 *4 (-443 *3)) (-4 *3 (-323)) (-4 *3 (-582)) (-5 *1 (-48 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-388)) (-5 *2 (-1280 *1)) (-4 *1 (-349 *4)))) ((*1 *2) (-12 (-4 *3 (-388)) (-5 *2 (-1280 *1)) (-4 *1 (-349 *3)))) ((*1 *2) (-12 (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-1280 *1)) (-4 *1 (-435 *3 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-323)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-1280 *6)) (-5 *1 (-439 *3 *4 *5 *6)) (-4 *6 (-13 (-435 *4 *5) (-1065 *4))))) ((*1 *2 *1) (-12 (-4 *3 (-323)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-1280 *6)) (-5 *1 (-440 *3 *4 *5 *6 *7)) (-4 *6 (-435 *4 *5)) (-14 *7 *2))) ((*1 *2) (-12 (-4 *3 (-194)) (-5 *2 (-1280 *1)) (-4 *1 (-443 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 (-1280 *4))) (-5 *1 (-556 *4)) (-4 *4 (-373))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239)) (-5 *3 (-237))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-756 *3))))) 
+(((*1 *2 *2 *2) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-1191))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-252 *6 *2)) (-14 *6 *2) (-5 *2 (-790)) (-5 *1 (-935 *4 *3 *5 *6)) (-4 *3 (-346 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-790))))) 
+(((*1 *2) (-12 (-5 *2 (-658 *3)) (-5 *1 (-1104 *3)) (-4 *3 (-159))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-658 (-592)))) (-5 *1 (-951 *4 *5 *6 *7)) (-5 *3 (-592)) (-4 *7 (-977 *4 *6 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-869) (-582))) (-5 *2 (-141)) (-5 *1 (-294 *4 *3)) (-4 *3 (-13 (-456 *4) (-1030)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-278)))) ((*1 *1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-278))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-451 *2)) (-4 *2 (-1119)) (-4 *2 (-394))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-542 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-869))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-50 (-1173) (-793))) (-5 *1 (-143))))) 
+(((*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-971 (-237))) (-5 *4 (-896)) (-5 *5 (-944)) (-5 *2 (-1285)) (-5 *1 (-497)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-971 (-237))) (-5 *2 (-1285)) (-5 *1 (-497)))) ((*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-658 (-971 (-237)))) (-5 *4 (-896)) (-5 *5 (-944)) (-5 *2 (-1285)) (-5 *1 (-497))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1129)) (-5 *3 (-592))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)) (-4 *2 (-456 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1111 *2)) (-4 *2 (-456 *4)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-180 *4 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1111 *1)) (-4 *1 (-182)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-182)) (-5 *2 (-1191))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-373)) (-5 *2 (-790)))) ((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-428)) (-5 *2 (-790))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-433 *4)) (-4 *4 (-1255 *3)) (-4 *3 (-13 (-388) (-171) (-1065 (-592)))) (-5 *1 (-596 *3 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-323)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *2 (-2 (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (-5 *1 (-1141 *4 *5 *6 *3)) (-4 *3 (-704 *4 *5 *6))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-658 *1)) (-4 *1 (-1089 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)))) ((*1 *2 *3 *1 *4) (-12 (-5 *4 (-1 (-141) *3 *3)) (-4 *1 (-1219 *5 *6 *7 *3)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-141))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 (-191 (-433 (-592))))) (-5 *2 (-658 (-191 *4))) (-5 *1 (-783 *4)) (-4 *4 (-13 (-388) (-867)))))) 
+(((*1 *1 *1 *1) (-5 *1 (-237))) ((*1 *2 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-405))) (-5 *1 (-1067)))) ((*1 *1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-195 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1544 *4))) (-5 *1 (-998 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-1113 (-433 (-592))))) (-5 *1 (-278)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-278))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-631 *1))) (-4 *1 (-318))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *1 (-1175 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *4)) (-5 *1 (-1145 *3 *4)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *3 *3) (-12 (-4 *3 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-658 *3)) (-5 *1 (-1145 *4 *3)) (-4 *4 (-1255 *3))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 *2))) (-5 *2 (-914 *3)) (-5 *1 (-1097 *3 *4 *5)) (-4 *5 (-13 (-456 *4) (-908 *3) (-633 *2)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *2 (-658 (-1113 (-237)))) (-5 *1 (-955))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-336 *3 *4 *5)) (-4 *3 (-13 (-388) (-869))) (-14 *4 (-1191)) (-14 *5 *3)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-219))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-846)) (-5 *3 (-658 (-1191))) (-5 *1 (-847))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-1075)) (-5 *2 (-592)) (-5 *1 (-468 *5 *3 *6)) (-4 *3 (-1255 *5)) (-4 *6 (-13 (-430) (-1065 *5) (-388) (-1211) (-301))))) ((*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-468 *4 *3 *5)) (-4 *3 (-1255 *4)) (-4 *5 (-13 (-430) (-1065 *4) (-388) (-1211) (-301)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-1075)) (-5 *1 (-469 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-986 (-191 (-237)))) (-5 *3 (-1137)) (-5 *4 (-191 (-237))) (-5 *1 (-135))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-373)) (-5 *2 (-658 *3)) (-5 *1 (-366 *5 *3)) (-4 *3 (-1255 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-373)) (-5 *2 (-658 *3)) (-5 *1 (-367 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-21)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-143)) (-5 *4 (-1191)) (-4 *6 (-1075)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *2 (-2 (|:| -3319 (-3 (-592) "failed")) (|:| -2016 (-3 (-592) "failed")) (|:| |ker| (-631 *5)))) (-5 *1 (-1052 *6 *5)) (-4 *5 (-13 (-456 *6) (-23) (-1065 (-592)) (-1065 *4) (-922 *4) (-182)))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-989 *2)) (-4 *2 (-574))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-877))))) 
+(((*1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-778))))) 
+(((*1 *2) (-12 (-5 *2 (-658 (-790))) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-790))) (-5 *1 (-1283))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *9 (-252 (-1699 *7) (-790))) (-5 *2 (-2 (|:| |mult| (-790)) (|:| |subMult| (-790)) (|:| |blUpRec| (-658 (-2 (|:| |recTransStr| (-264 (-4466 (QUOTE X) (QUOTE -3820)) *6)) (|:| |recPoint| (-33 *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (-5 *1 (-139 *6 *7 *8 *9 *5)) (-5 *3 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *6)) (-5 *4 (-33 *6)) (-4 *8 (-346 *6 *9)) (-4 *5 (-137))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-191 (-237)))) (-5 *2 (-592)) (-5 *1 (-135))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-141))))) 
+(((*1 *2 *2 *1) (-12 (-5 *2 (-1302 *3 *4)) (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-412 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2) (|partial| -12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-841 *3)) (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-195 *2)) (-4 *2 (-323))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-229 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-366 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-367 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) *2)) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-790))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869))) (-4 *2 (-13 (-456 (-191 *4)) (-1030) (-1211))) (-5 *1 (-621 *4 *3 *2)) (-4 *3 (-13 (-456 *4) (-1030) (-1211)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-565)) (-5 *1 (-564 *4)) (-4 *4 (-1225))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-658 (-631 *2))) (-5 *4 (-658 (-1191))) (-4 *2 (-13 (-456 (-191 *5)) (-1030) (-1211))) (-4 *5 (-13 (-582) (-869))) (-5 *1 (-621 *5 *6 *2)) (-4 *6 (-13 (-456 *5) (-1030) (-1211)))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-261 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-582))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *1 *1 *1) (-4 *1 (-502))) ((*1 *1 *1 *1) (-4 *1 (-780)))) 
+(((*1 *2) (-12 (-5 *2 (-658 *3)) (-5 *1 (-1071 *3)) (-4 *3 (-388))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 *7)) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) (-790))) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-5 *2 (-658 (-1280 *5))) (-5 *1 (-586 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-999 *5)) (-4 *3 (-257 *11))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-156 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1086)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1086))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-790)) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-96 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-234 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-518 *4)) (-4 *4 (-869)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1028 *4)) (-4 *4 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-141)) (-5 *1 (-1161 *4)) (-4 *4 (-1119))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1173)) (-5 *1 (-1207))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1000)) (-5 *1 (-927 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-4 *5 (-388)) (-5 *2 (-658 (-1220 *5))) (-5 *1 (-1288 *5)) (-5 *4 (-1220 *5))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-1187 (-980 *4))) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) ((*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-4 *3 (-388)) (-5 *2 (-1187 (-980 *3))))) ((*1 *2) (-12 (-5 *2 (-1187 (-433 (-980 *3)))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) ((*1 *1 *2 *3 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3))) ((*1 *1 *1 *1) (-12 (-5 *1 (-691 *2)) (-4 *2 (-1075)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-1255 *4)) (-5 *2 (-1 *6 (-658 *6))) (-5 *1 (-1273 *4 *5 *3 *6)) (-4 *3 (-670 *5)) (-4 *6 (-1270 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-884 *4))) (-4 *4 (-373)) (-5 *2 (-995 *4)) (-5 *1 (-894 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-5 *2 (-994 *4)) (-5 *1 (-895 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-999 *3))))) 
+(((*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-971 *5)) (-5 *3 (-790)) (-4 *5 (-1075)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944))))) 
+(((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-141)) (-5 *5 (-592)) (-4 *6 (-388)) (-4 *6 (-394)) (-4 *6 (-1075)) (-5 *2 (-658 (-658 (-706 *6)))) (-5 *1 (-1057 *6)) (-5 *3 (-658 (-706 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-388)) (-4 *4 (-394)) (-4 *4 (-1075)) (-5 *2 (-658 (-658 (-706 *4)))) (-5 *1 (-1057 *4)) (-5 *3 (-658 (-706 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-388)) (-4 *5 (-394)) (-4 *5 (-1075)) (-5 *2 (-658 (-658 (-706 *5)))) (-5 *1 (-1057 *5)) (-5 *3 (-658 (-706 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-4 *5 (-394)) (-4 *5 (-1075)) (-5 *2 (-658 (-658 (-706 *5)))) (-5 *1 (-1057 *5)) (-5 *3 (-658 (-706 *5)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)) (-5 *2 (-141)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-381 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 *4)) (-4 *4 (-373)) (-5 *2 (-141)) (-5 *1 (-556 *4))))) 
+(((*1 *1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-131 *2)) (-4 *2 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-151 *2)) (-4 *2 (-869)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-156 *2)) (-4 *2 (-869)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-299 *3)) (-4 *3 (-1225)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-299 *2)) (-4 *2 (-1225)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -1350 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1171 (-237))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -2166 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (-5 *1 (-587)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-711 *2)) (-4 *2 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -1350 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| -3552 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))))) (-5 *1 (-825)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *2 (-1285)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-5 *2 (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| *3) (|:| -1777 (-592))))))) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-5 *2 (-2 (|:| |contp| (-592)) (|:| -2033 (-658 (-2 (|:| |irr| *3) (|:| -1777 (-592))))))) (-5 *1 (-1244 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-737)) (-5 *2 (-944)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-739)) (-5 *2 (-790))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-433 (-592))) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-295 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *4 (-592))) (-5 *5 (-1 (-1171 *4))) (-4 *4 (-388)) (-4 *4 (-1075)) (-5 *2 (-1171 *4)) (-5 *1 (-1175 *4))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *8)) (-5 *4 (-706 (-1187 *8))) (-4 *5 (-1075)) (-4 *8 (-1075)) (-4 *6 (-1255 *5)) (-5 *2 (-706 *6)) (-5 *1 (-534 *5 *6 *7 *8)) (-4 *7 (-1255 *6))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-131 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-5 *1 (-518 *2)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-5 *1 (-1161 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-362 *4 *3 *5)) (-4 *4 (-1235)) (-4 *3 (-1255 *4)) (-4 *5 (-1255 (-433 *3))) (-5 *2 (-141)))) ((*1 *2 *3) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *1 *2 *3) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1034))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 (-191 (-433 (-592))))) (-5 *2 (-658 (-2 (|:| |outval| (-191 *4)) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 (-191 *4))))))) (-5 *1 (-783 *4)) (-4 *4 (-13 (-388) (-867)))))) 
+(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-691 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1121 (-1191))) (-5 *1 (-58)) (-5 *3 (-1191))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-944))) (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *3 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-474 *4 *3 *5 *6)) (-4 *6 (-977 *4 *3 *5))))) 
+(((*1 *2 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *3 (-582)) (-5 *1 (-998 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-346 *4 *5)) (-4 *5 (-252 *6 (-790))) (-14 *6 (-790)) (-4 *4 (-1075)) (-5 *1 (-799 *4 *3 *5 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| |outval| *4) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 *4)))))) (-5 *1 (-800 *4)) (-4 *4 (-13 (-388) (-867)))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *6) (-12 (-5 *3 (-332 (-592))) (-5 *4 (-1 (-237) (-237))) (-5 *5 (-1113 (-237))) (-5 *6 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-713))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| -1947 (-444 *3)) (|:| |special| (-444 *3)))) (-5 *1 (-744 *5 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-1113 *3)) (-4 *3 (-977 *7 *6 *4)) (-4 *6 (-815)) (-4 *4 (-869)) (-4 *7 (-582)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-592)))) (-5 *1 (-616 *6 *4 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-815)) (-4 *4 (-869)) (-4 *6 (-582)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-592)))) (-5 *1 (-616 *5 *4 *6 *3)) (-4 *3 (-977 *6 *5 *4)))) ((*1 *1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1182 *4 *2)) (-4 *2 (-13 (-456 *4) (-182) (-27) (-1211))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1111 *2)) (-4 *2 (-13 (-456 *4) (-182) (-27) (-1211))) (-4 *4 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1182 *4 *2)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-433 (-980 *5))) (-5 *1 (-1183 *5)) (-5 *3 (-980 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-3 (-433 (-980 *5)) (-332 *5))) (-5 *1 (-1183 *5)) (-5 *3 (-433 (-980 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-980 *5))) (-5 *3 (-980 *5)) (-4 *5 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-433 *3)) (-5 *1 (-1183 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-433 (-980 *5)))) (-5 *3 (-433 (-980 *5))) (-4 *5 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-3 *3 (-332 *5))) (-5 *1 (-1183 *5))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1021 *2)) (-4 *2 (-582)) (-5 *1 (-164 *2 *4 *3)) (-4 *3 (-399 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-1021 *2)) (-4 *2 (-582)) (-5 *1 (-536 *2 *4 *5 *3)) (-4 *5 (-399 *2)) (-4 *3 (-399 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-706 *4)) (-4 *4 (-1021 *2)) (-4 *2 (-582)) (-5 *1 (-709 *2 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-1021 *2)) (-4 *2 (-582)) (-5 *1 (-1248 *2 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-914 *4)) (-4 *4 (-1119)) (-5 *1 (-911 *4 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-13 (-430) (-1065 *4) (-388) (-1211) (-301))) (-5 *1 (-468 *4 *3 *2)) (-4 *3 (-1255 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1187 *3)) (-4 *3 (-1075)) (-4 *1 (-1255 *3))))) 
+(((*1 *2 *2 *3 *3 *4) (-12 (-5 *3 (-790)) (-4 *2 (-13 (-582) (-477))) (-5 *1 (-369 *2 *4)) (-4 *4 (-52 *2 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *4 (-388)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2))))) 
+(((*1 *1) (-5 *1 (-179)))) 
+(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-914 *4)) (-4 *4 (-1119)) (-5 *2 (-141)) (-5 *1 (-911 *4 *5)) (-4 *5 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-5 *2 (-141)) (-5 *1 (-912 *5 *3)) (-4 *3 (-1225)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-914 *5)) (-4 *5 (-1119)) (-4 *6 (-1225)) (-5 *2 (-141)) (-5 *1 (-912 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-180 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-143)) (-5 *5 (-658 *2)) (-4 *2 (-13 (-456 *6) (-23) (-1065 (-592)) (-1065 *4) (-922 *4) (-182))) (-5 *4 (-1191)) (-4 *6 (-13 (-869) (-582) (-633 (-565)))) (-5 *1 (-1052 *6 *2))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1229)) (-5 *5 (-592)) (-4 *1 (-692 *3 *6)) (-4 *3 (-1225)) (-4 *6 (-1225)) (-5 *2 (-1285))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-342 *4 *2)) (-4 *4 (-1119)) (-4 *2 (-158))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-272))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-877))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-237)) (-5 *5 (-592)) (-5 *2 (-1221 *3)) (-5 *1 (-812 *3)) (-4 *3 (-1003)))) ((*1 *1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-141)) (-5 *1 (-1221 *2)) (-4 *2 (-1003))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-688 *3)) (-4 *3 (-869)) (-4 *1 (-400 *3 *4)) (-4 *4 (-194))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-565))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1255 *3)) (-4 *3 (-1075)) (-5 *2 (-1187 *3))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1121 *3)) (-5 *1 (-927 *3)) (-4 *3 (-394)) (-4 *3 (-1119))))) 
+(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-1111 (-980 (-592)))) (-5 *3 (-980 (-592))) (-5 *1 (-350)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1111 (-980 (-592)))) (-5 *1 (-350))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-1280 (-706 *4))) (-5 *1 (-95 *4 *5)) (-5 *3 (-706 *4)) (-4 *5 (-670 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-927 *4)) (-4 *4 (-1119)) (-5 *2 (-658 (-790))) (-5 *1 (-926 *4))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-1195))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-310 (-862 *3))) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-3 (-862 *3) (-2 (|:| |leftHandLimit| (-3 (-862 *3) "failed")) (|:| |rightHandLimit| (-3 (-862 *3) "failed"))) "failed")) (-5 *1 (-651 *5 *3)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-310 *3)) (-5 *5 (-1173)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-862 *3)) (-5 *1 (-651 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-310 (-862 (-980 *5)))) (-4 *5 (-477)) (-5 *2 (-3 (-862 (-433 (-980 *5))) (-2 (|:| |leftHandLimit| (-3 (-862 (-433 (-980 *5))) "failed")) (|:| |rightHandLimit| (-3 (-862 (-433 (-980 *5))) "failed"))) "failed")) (-5 *1 (-652 *5)) (-5 *3 (-433 (-980 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-310 (-433 (-980 *5)))) (-5 *3 (-433 (-980 *5))) (-4 *5 (-477)) (-5 *2 (-3 (-862 *3) (-2 (|:| |leftHandLimit| (-3 (-862 *3) "failed")) (|:| |rightHandLimit| (-3 (-862 *3) "failed"))) "failed")) (-5 *1 (-652 *5)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-310 (-433 (-980 *6)))) (-5 *5 (-1173)) (-5 *3 (-433 (-980 *6))) (-4 *6 (-477)) (-5 *2 (-862 *3)) (-5 *1 (-652 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-790)) (-5 *4 (-592)) (-5 *1 (-470 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1187 *9)) (-5 *4 (-658 *7)) (-5 *5 (-658 (-658 *8))) (-4 *7 (-869)) (-4 *8 (-323)) (-4 *9 (-977 *8 *6 *7)) (-4 *6 (-815)) (-5 *2 (-2 (|:| |upol| (-1187 *8)) (|:| |Lval| (-658 *8)) (|:| |Lfact| (-658 (-2 (|:| -4500 (-1187 *8)) (|:| -3215 (-592))))) (|:| |ctpol| *8))) (-5 *1 (-759 *6 *7 *8 *9))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-587))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-347 *3)) (-4 *3 (-1225)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-549 *3 *4)) (-4 *3 (-1225)) (-14 *4 *2)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1280 *5))) (-5 *4 (-592)) (-5 *2 (-1280 *5)) (-5 *1 (-1057 *5)) (-4 *5 (-388)) (-4 *5 (-394)) (-4 *5 (-1075))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-658 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-583 *6 *3))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 *7)) (-5 *5 (-658 (-658 *8))) (-4 *7 (-869)) (-4 *8 (-323)) (-4 *6 (-815)) (-4 *9 (-977 *8 *6 *7)) (-5 *2 (-2 (|:| |unitPart| *9) (|:| |suPart| (-658 (-2 (|:| -4500 (-1187 *9)) (|:| -3215 (-592))))))) (-5 *1 (-759 *6 *7 *8 *9)) (-5 *3 (-1187 *9))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |mval| (-706 *3)) (|:| |invmval| (-706 *3)) (|:| |genIdeal| (-538 *3 *4 *5 *6)))) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3548 (-804 *3)) (|:| |coef1| (-804 *3)) (|:| |coef2| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -3548 *1) (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-141))))) 
+(((*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1067))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-323)) (-5 *2 (-444 *3)) (-5 *1 (-759 *4 *5 *6 *3)) (-4 *3 (-977 *6 *4 *5))))) 
+(((*1 *2 *3 *2 *4) (|partial| -12 (-5 *4 (-1 (-3 (-592) "failed") *5)) (-4 *5 (-1075)) (-5 *2 (-592)) (-5 *1 (-572 *5 *3)) (-4 *3 (-1255 *5)))) ((*1 *2 *3 *4 *2 *5) (|partial| -12 (-5 *5 (-1 (-3 (-592) "failed") *4)) (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-572 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-592) "failed") *4)) (-4 *4 (-1075)) (-5 *2 (-592)) (-5 *1 (-572 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-433 (-592))) (-5 *2 (-237)) (-5 *1 (-321))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-711 *3)) (-4 *3 (-1119)) (-5 *2 (-658 (-2 (|:| -3552 *3) (|:| -3452 (-790)))))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-5 *1 (-927 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1255 (-433 (-592)))) (-5 *1 (-936 *3 *2)) (-4 *2 (-1255 (-433 *3)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)) (-4 *2 (-574)))) ((*1 *1 *1) (-4 *1 (-1084)))) 
+(((*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| -12 (-5 *5 (-1191)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-658 *4))) (-5 *7 (-1 (-3 (-2 (|:| -3191 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1211) (-27) (-456 *8))) (-4 *8 (-13 (-477) (-869) (-171) (-1065 *3) (-654 *3))) (-5 *3 (-592)) (-5 *2 (-658 *4)) (-5 *1 (-1042 *8 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1171 (-1171 *4))) (-5 *2 (-1171 *4)) (-5 *1 (-1175 *4)) (-4 *4 (-1075))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-989 *2)) (-4 *2 (-574))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 (-592))))) (-5 *1 (-386 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 (-790))))) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| -4500 *3) (|:| -3215 (-592))))) (-5 *1 (-444 *3)) (-4 *3 (-582)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 (-790))))) (-5 *1 (-841 *3)) (-4 *3 (-869))))) 
+(((*1 *1) (-12 (-5 *1 (-255 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-609 *3)) (-4 *3 (-388))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)) (-4 *5 (-194))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-592)) (-4 *4 (-194)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-705 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-846))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-52 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-617 *3)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-4 *3 (-582)) (-5 *2 (-141)) (-5 *1 (-639 *3 *4)) (-4 *4 (-1255 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) ((*1 *2 *1) (-12 (-4 *1 (-1295 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075)) (-5 *2 (-141))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-790)) (-5 *1 (-1120 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
+(((*1 *2 *3) (-12 (-4 *3 (-1255 (-433 (-592)))) (-5 *2 (-2 (|:| |den| (-592)) (|:| |gcdnum| (-592)))) (-5 *1 (-936 *3 *4)) (-4 *4 (-1255 (-433 *3))))) ((*1 *2 *3) (-12 (-4 *4 (-1255 (-433 *2))) (-5 *2 (-592)) (-5 *1 (-936 *4 *3)) (-4 *3 (-1255 (-433 *4)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-4 *5 (-456 *4)) (-5 *2 (-444 *3)) (-5 *1 (-461 *4 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-805 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-194))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-658 (-631 *5))) (-5 *3 (-1191)) (-4 *5 (-456 *4)) (-4 *4 (-869)) (-5 *1 (-601 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-310 (-980 (-592)))) (-5 *2 (-2 (|:| |varOrder| (-658 (-1191))) (|:| |inhom| (-3 (-658 (-1280 (-790))) "failed")) (|:| |hom| (-658 (-1280 (-790)))))) (-5 *1 (-250))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-405)) (-5 *1 (-1087))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-658 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-1113 (-944))) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6)))) ((*1 *1 *1 *2 *2 *2 *2) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-516 *4 *5))) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *2 (-2 (|:| |gblist| (-658 (-264 *4 *5))) (|:| |gvlist| (-658 (-592))))) (-5 *1 (-646 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-332 (-433 (-592)))) (-5 *1 (-321))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-168))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-433 (-980 *5)))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-1180 (-658 (-332 *5)) (-658 (-310 (-332 *5))))) (-5 *1 (-1146 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171))) (-5 *2 (-1180 (-658 (-332 *5)) (-658 (-310 (-332 *5))))) (-5 *1 (-1146 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 *4)))) (-4 *4 (-477)) (-5 *2 (-658 (-3 (-433 (-980 *4)) (-1180 (-1191) (-980 *4))))) (-5 *1 (-308 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-4 *3 (-582)) (-5 *2 (-1187 *3))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-4 *1 (-757 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-869)) (-5 *2 (-980 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-757 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-869)) (-5 *2 (-980 *4)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-790)) (-4 *1 (-1270 *4)) (-4 *4 (-1075)) (-5 *2 (-980 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-1270 *4)) (-4 *4 (-1075)) (-5 *2 (-980 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *5 (-1235)) (-4 *6 (-1255 *5)) (-4 *7 (-1255 (-433 *6))) (-5 *2 (-658 (-980 *5))) (-5 *1 (-361 *4 *5 *6 *7)) (-4 *4 (-362 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *1 (-362 *4 *5 *6)) (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-4 *6 (-1255 (-433 *5))) (-4 *4 (-388)) (-5 *2 (-658 (-980 *4)))))) 
+(((*1 *1 *1 *1) (-5 *1 (-183))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-183))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *8)) (|:| |neqzro| (-658 *8)) (|:| |wcond| (-658 (-980 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *5)))) (|:| -2195 (-658 (-1280 (-433 (-980 *5)))))))))) (-5 *1 (-951 *5 *6 *7 *8)) (-5 *4 (-658 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-5 *4 (-658 (-1191))) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *8)) (|:| |neqzro| (-658 *8)) (|:| |wcond| (-658 (-980 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *5)))) (|:| -2195 (-658 (-1280 (-433 (-980 *5)))))))))) (-5 *1 (-951 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-706 *7)) (-4 *7 (-977 *4 *6 *5)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *7)) (|:| |neqzro| (-658 *7)) (|:| |wcond| (-658 (-980 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *4)))) (|:| -2195 (-658 (-1280 (-433 (-980 *4)))))))))) (-5 *1 (-951 *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *5 (-944)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *9)) (|:| |neqzro| (-658 *9)) (|:| |wcond| (-658 (-980 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *6)))) (|:| -2195 (-658 (-1280 (-433 (-980 *6)))))))))) (-5 *1 (-951 *6 *7 *8 *9)) (-5 *4 (-658 *9)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *4 (-658 (-1191))) (-5 *5 (-944)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *9)) (|:| |neqzro| (-658 *9)) (|:| |wcond| (-658 (-980 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *6)))) (|:| -2195 (-658 (-1280 (-433 (-980 *6)))))))))) (-5 *1 (-951 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-5 *4 (-944)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *8)) (|:| |neqzro| (-658 *8)) (|:| |wcond| (-658 (-980 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *5)))) (|:| -2195 (-658 (-1280 (-433 (-980 *5)))))))))) (-5 *1 (-951 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *4 (-658 *9)) (-5 *5 (-1173)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *6 *7 *8 *9)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *4 (-658 (-1191))) (-5 *5 (-1173)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-706 *8)) (-5 *4 (-1173)) (-4 *8 (-977 *5 *7 *6)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-13 (-869) (-633 (-1191)))) (-4 *7 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-706 *10)) (-5 *4 (-658 *10)) (-5 *5 (-944)) (-5 *6 (-1173)) (-4 *10 (-977 *7 *9 *8)) (-4 *7 (-13 (-323) (-171))) (-4 *8 (-13 (-869) (-633 (-1191)))) (-4 *9 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-706 *10)) (-5 *4 (-658 (-1191))) (-5 *5 (-944)) (-5 *6 (-1173)) (-4 *10 (-977 *7 *9 *8)) (-4 *7 (-13 (-323) (-171))) (-4 *8 (-13 (-869) (-633 (-1191)))) (-4 *9 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *9)) (-5 *4 (-944)) (-5 *5 (-1173)) (-4 *9 (-977 *6 *8 *7)) (-4 *6 (-13 (-323) (-171))) (-4 *7 (-13 (-869) (-633 (-1191)))) (-4 *8 (-815)) (-5 *2 (-592)) (-5 *1 (-951 *6 *7 *8 *9))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-855 (-237))) (-5 *1 (-239))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-1187 *3)) (-5 *1 (-46 *4 *3)) (-4 *3 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *4 (-631 $)) $)) (-15 -1456 ((-1142 *4 (-631 $)) $)) (-15 -1683 ($ (-1142 *4 (-631 $)))))))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-658 *3)) (-5 *1 (-614 *5 *6 *7 *8 *3)) (-4 *3 (-1128 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1099 *5 *6)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-323) (-171))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *4)) (|:| -2231 (-658 (-980 *4)))))) (-5 *1 (-1099 *4 *5)) (-5 *3 (-658 (-980 *4))) (-14 *5 (-658 (-1191))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-323) (-171))) (-5 *2 (-658 (-2 (|:| -1666 (-1187 *5)) (|:| -2231 (-658 (-980 *5)))))) (-5 *1 (-1099 *5 *6)) (-5 *3 (-658 (-980 *5))) (-14 *6 (-658 (-1191)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-237)) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-5 *2 (-191 (-237))) (-5 *1 (-239)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *5)) (-4 *5 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-433 (-592))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-310 *3)) (-5 *5 (-433 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *6 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-433 (-592)))) (-5 *4 (-310 *8)) (-5 *5 (-1246 (-433 (-592)))) (-5 *6 (-433 (-592))) (-4 *8 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-433 (-592)))) (-5 *7 (-433 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *8))) (-4 *8 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *8 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-433 (-592))) (-4 *4 (-1075)) (-4 *1 (-1262 *4 *3)) (-4 *3 (-1239 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-62 *4 *5 *2)) (-4 *4 (-1225)) (-4 *5 (-399 *4)) (-4 *2 (-399 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *1 (-1078 *4 *5 *6 *7 *2)) (-4 *6 (-1075)) (-4 *7 (-252 *5 *6)) (-4 *2 (-252 *4 *6))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *2 (-1089 *4 *5 *6)) (-5 *1 (-795 *4 *5 *6 *2 *3)) (-4 *3 (-1094 *4 *5 *6 *2))))) 
+(((*1 *1 *1) (-5 *1 (-237))) ((*1 *1 *1) (-5 *1 (-405))) ((*1 *1) (-5 *1 (-405)))) 
+(((*1 *2 *3 *2 *3 *2 *3) (-12 (-5 *2 (-986 (-237))) (-5 *3 (-1137)) (-5 *1 (-135))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1212 *3))) (-5 *1 (-1212 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *5)) (-4 *5 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *5 (-13 (-477) (-869) (-1065 *4) (-654 *4))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 *5) (-654 *5))) (-5 *5 (-592)) (-5 *2 (-57)) (-5 *1 (-331 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-592))) (-5 *4 (-310 *7)) (-5 *5 (-1246 (-592))) (-4 *7 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-592))) (-4 *3 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-592)) (-4 *4 (-1075)) (-4 *1 (-1241 *4 *3)) (-4 *3 (-1270 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1262 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1239 *3))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-804 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-4 *1 (-692 *2 *3)) (-4 *2 (-1225)) (-4 *3 (-1225))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (-5 *1 (-350))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-971 *3)))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-953))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *5)) (-4 *5 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *4 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-310 *3)) (-5 *5 (-790)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-331 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-592))) (-5 *4 (-310 *6)) (-4 *6 (-13 (-27) (-1211) (-456 *5))) (-4 *5 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-592))) (-5 *4 (-310 *7)) (-5 *5 (-1246 (-790))) (-4 *7 (-13 (-27) (-1211) (-456 *6))) (-4 *6 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1191)) (-5 *5 (-310 *3)) (-5 *6 (-1246 (-790))) (-4 *3 (-13 (-27) (-1211) (-456 *7))) (-4 *7 (-13 (-582) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-57)) (-5 *1 (-485 *7 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1270 *3))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) ((*1 *1 *1) (-12 (-5 *1 (-1301 *2 *3)) (-4 *2 (-1075)) (-4 *3 (-865))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1235)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -1487 (-433 *5)) (|:| |poly| *3))) (-5 *1 (-172 *4 *5 *3)) (-4 *3 (-1255 (-433 *5)))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-914 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-808))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-592)) (-5 *3 (-986 (-405))) (-5 *1 (-135))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1 (-141) *8))) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |goodPols| (-658 *8)) (|:| |badPols| (-658 *8)))) (-5 *1 (-1006 *5 *6 *7 *8)) (-5 *4 (-658 *8))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1179 *2 *3)) (-14 *2 (-944)) (-4 *3 (-1075))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-388)) (-5 *1 (-1053 *3 *2)) (-4 *2 (-670 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-5 *2 (-2 (|:| -2042 *3) (|:| -1608 (-658 *5)))) (-5 *1 (-1053 *5 *3)) (-5 *4 (-658 *5)) (-4 *3 (-670 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 *3)) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-944))) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 *3)) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7))))) 
+(((*1 *1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-1006 *4 *5 *6 *3)) (-4 *3 (-1089 *4 *5 *6))))) 
+(((*1 *2 *3 *4 *3 *4 *4 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-444 *3)) (-4 *3 (-582))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-191 *4)) (-5 *1 (-200 *4 *3)) (-4 *4 (-13 (-388) (-867))) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-592)) (-5 *1 (-405))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1285)) (-5 *1 (-1152)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-877))) (-5 *2 (-1285)) (-5 *1 (-1152))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2) (-12 (-4 *1 (-373)) (-5 *2 (-658 (-2 (|:| -4500 (-592)) (|:| -3215 (-592)))))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-269 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-667 (-433 *2))) (-4 *2 (-1255 *4)) (-5 *1 (-832 *4 *2)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))))) ((*1 *2 *3) (-12 (-5 *3 (-668 *2 (-433 *2))) (-4 *2 (-1255 *4)) (-5 *1 (-832 *4 *2)) (-4 *4 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592)))))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-944)) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-658 (-944))) (-5 *5 (-944)) (-4 *6 (-388)) (-4 *7 (-399 *6)) (-4 *8 (-399 *6)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-694 *6 *7 *8 *3)) (-4 *3 (-704 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-658 (-944))) (-5 *4 (-944)) (-4 *6 (-388)) (-4 *7 (-399 *6)) (-4 *8 (-399 *6)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-694 *6 *7 *8 *3)) (-4 *3 (-704 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-658 (-944))) (-4 *5 (-388)) (-4 *6 (-399 *5)) (-4 *7 (-399 *5)) (-5 *2 (-658 (-658 *3))) (-5 *1 (-694 *5 *6 *7 *3)) (-4 *3 (-704 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-1280 *3)) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-148 *2)) (-4 *2 (-1225)))) ((*1 *1 *1) (-12 (-5 *1 (-688 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-1067))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-592)) (-5 *1 (-1133 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-609 *2)) (-4 *2 (-13 (-29 *4) (-1211))) (-5 *1 (-607 *4 *2)) (-4 *4 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-609 (-433 (-980 *4)))) (-4 *4 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *2 (-332 *4)) (-5 *1 (-612 *4))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-57)) (-5 *1 (-1204))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-148 *2)) (-4 *2 (-1225)))) ((*1 *1 *1) (-12 (-5 *1 (-688 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-877)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-332 (-237)))) (-5 *1 (-285))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) ((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-706 *4)) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) ((*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-706 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-388)) (-5 *1 (-677 *3))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-405))) (-5 *1 (-1067)) (-5 *3 (-405))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-977 *4 *5 *6)) (-4 *4 (-323)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-472 *4 *5 *6 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1171 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-206)))) ((*1 *2 *3) (-12 (-5 *3 (-1171 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-316)))) ((*1 *2 *3) (-12 (-5 *3 (-1171 (-237))) (-5 *2 (-658 (-1173))) (-5 *1 (-321))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-592)) (-5 *1 (-218))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-980 *5)) (-4 *5 (-1075)) (-5 *2 (-264 *4 *5)) (-5 *1 (-972 *4 *5)) (-14 *4 (-658 (-1191)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-44 *3)) (-4 *3 (-1255 (-53)))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-790)) (-4 *1 (-245 *4)) (-4 *4 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-245 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-247)) (-5 *2 (-790)))) ((*1 *1 *1) (-4 *1 (-247))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *3 (-13 (-388) (-171))) (-5 *1 (-425 *3 *4)) (-4 *4 (-1255 *3)))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-388) (-171))) (-5 *1 (-425 *2 *3)) (-4 *3 (-1255 *2)))) ((*1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *4)) (-5 *3 (-658 (-790))) (-4 *1 (-922 *4)) (-4 *4 (-1119)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-922 *2)) (-4 *2 (-1119)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *1 (-922 *3)) (-4 *3 (-1119)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-922 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-706 *4)) (-5 *3 (-944)) (|has| *4 (-6 (-4627 "*"))) (-4 *4 (-1075)) (-5 *1 (-1056 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-658 (-706 *4))) (-5 *3 (-944)) (|has| *4 (-6 (-4627 "*"))) (-4 *4 (-1075)) (-5 *1 (-1056 *4))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1095 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-1285)) (-5 *1 (-1127 *4 *5 *6 *7 *8)) (-4 *8 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)))) ((*1 *2 *1 *1) (-12 (-4 *2 (-1075)) (-5 *1 (-55 *2 *3)) (-14 *3 (-658 (-1191))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-658 (-944))) (-4 *2 (-388)) (-5 *1 (-176 *4 *2 *5)) (-14 *4 (-944)) (-14 *5 (-1022 *4 *2)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-332 *3)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191))))) ((*1 *2 *3 *1) (-12 (-4 *1 (-342 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-158)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-408 *2 *3)) (-4 *3 (-1119)) (-4 *2 (-1075)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-592)) (-4 *2 (-582)) (-5 *1 (-639 *2 *4)) (-4 *4 (-1255 *2)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-725 *2)) (-4 *2 (-1075)))) ((*1 *2 *1 *3) (-12 (-4 *2 (-1075)) (-5 *1 (-752 *2 *3)) (-4 *3 (-743)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *5)) (-5 *3 (-658 (-790))) (-4 *1 (-757 *4 *5)) (-4 *4 (-1075)) (-4 *5 (-869)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-757 *4 *2)) (-4 *4 (-1075)) (-4 *2 (-869)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *1 (-871 *2)) (-4 *2 (-1075)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 *6)) (-5 *3 (-658 (-790))) (-4 *1 (-977 *4 *5 *6)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *6 (-869)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-790)) (-4 *1 (-977 *4 *5 *2)) (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *2 (-869)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-150)) (-5 *2 (-332 *4)) (-5 *1 (-1106 *4)) (-4 *4 (-13 (-869) (-582))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *2 (-977 *4 (-558 *5) *5)) (-5 *1 (-1143 *4 *5 *2)) (-4 *4 (-1075)) (-4 *5 (-869)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *2 (-980 *4)) (-5 *1 (-1220 *4)) (-4 *4 (-1075))))) 
+(((*1 *2) (-12 (-14 *4 (-790)) (-4 *5 (-1225)) (-5 *2 (-160)) (-5 *1 (-251 *3 *4 *5)) (-4 *3 (-252 *4 *5)))) ((*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-160)) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-416 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-194)))) ((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-592)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-869)) (-4 *4 (-388)) (-4 *5 (-815)) (-5 *2 (-592)) (-5 *1 (-538 *4 *5 *6 *7)) (-4 *7 (-977 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1009 *3)) (-4 *3 (-1075)) (-5 *2 (-944)))) ((*1 *2) (-12 (-4 *1 (-1287 *3)) (-4 *3 (-388)) (-5 *2 (-160))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-980 *4)) (-4 *4 (-13 (-323) (-171))) (-4 *2 (-977 *4 *6 *5)) (-5 *1 (-951 *4 *5 *6 *2)) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815))))) 
+(((*1 *1 *1 *2 *2) (|partial| -12 (-5 *2 (-944)) (-5 *1 (-1120 *3 *4)) (-14 *3 *2) (-14 *4 *2)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -1954 *6) (|:| |sol?| (-141))) (-592) *6)) (-4 *6 (-388)) (-4 *7 (-1255 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-433 *7)) (|:| |a0| *6)) (-2 (|:| -3191 (-433 *7)) (|:| |coeff| (-433 *7))) "failed")) (-5 *1 (-602 *6 *7)) (-5 *3 (-433 *7))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1092 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-658 *4)) (|:| |todo| (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))))) (-5 *1 (-1159 *5 *6 *7 *3 *4)) (-4 *4 (-1128 *5 *6 *7 *3))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-582)) (-5 *2 (-986 *3)) (-5 *1 (-1178 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-405)) (-5 *1 (-239)))) ((*1 *1 *1) (-4 *1 (-644))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-1191))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-706 (-433 (-980 (-592))))) (-5 *2 (-706 (-332 (-592)))) (-5 *1 (-1059))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1187 *6)) (-4 *6 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-1187 *7)) (-5 *1 (-340 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-252 *5 (-790))) (-14 *5 (-790)) (-5 *1 (-935 *3 *2 *4 *5)) (-4 *2 (-346 *3 *4))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-444 *2)) (-4 *2 (-582))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-625 *3 *2)) (-4 *3 (-1119)) (-4 *3 (-869)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-688 *3)) (-5 *1 (-915 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) ((*1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1297 *3)) (-4 *3 (-388)) (-5 *2 (-141))))) 
+(((*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1191)) (-5 *3 (-141)) (-5 *1 (-914 *4)) (-4 *4 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-1171 (-237))) (-5 *1 (-206)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-332 (-237))) (-5 *4 (-658 (-1191))) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-1171 (-237))) (-5 *1 (-316)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1280 (-332 (-237)))) (-5 *4 (-658 (-1191))) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-1171 (-237))) (-5 *1 (-316))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-844)) (-5 *2 (-57)) (-5 *1 (-851))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1154 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-977 *3 *5 *4)) (-5 *1 (-1016 *3 *4 *5 *2)) (-4 *3 (-477)) (-4 *4 (-869)) (-4 *5 (-815))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-582) (-171))) (-5 *2 (-2 (|:| -1961 *3) (|:| -1954 *3))) (-5 *1 (-1249 *4 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-1280 (-715))) (-5 *1 (-321))))) 
+(((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-355 *3 *4 *5 *6)) (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 *3 *4 *5)) (-5 *2 (-2 (|:| -4547 (-439 *4 (-433 *4) *5 *6)) (|:| |principalPart| *6))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| |poly| *6) (|:| -1947 (-433 *6)) (|:| |special| (-433 *6)))) (-5 *1 (-744 *5 *6)) (-5 *3 (-433 *6)))) ((*1 *2 *3) (-12 (-4 *4 (-388)) (-5 *2 (-658 *3)) (-5 *1 (-918 *3 *4)) (-4 *3 (-1255 *4)))) ((*1 *2 *3 *4 *4) (|partial| -12 (-5 *4 (-790)) (-4 *5 (-388)) (-5 *2 (-2 (|:| -1961 *3) (|:| -1954 *3))) (-5 *1 (-918 *3 *5)) (-4 *3 (-1255 *5)))) ((*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-658 *9)) (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-658 *9)) (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1094 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1092 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-658 *9)) (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1159 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-658 *9)) (-5 *3 (-658 *8)) (-5 *4 (-141)) (-4 *8 (-1089 *5 *6 *7)) (-4 *9 (-1128 *5 *6 *7 *8)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *1 (-1159 *5 *6 *7 *8 *9))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-1255 *3)) (-5 *1 (-185 *3 *4 *2)) (-4 *2 (-1255 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-141))))) 
+(((*1 *2 *2 *1 *3 *4) (-12 (-5 *2 (-658 *8)) (-5 *3 (-1 *8 *8 *8)) (-5 *4 (-1 (-141) *8 *8)) (-4 *1 (-1219 *5 *6 *7 *8)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7))))) 
+(((*1 *2) (-12 (-5 *2 (-1199 (-1191) (-150))) (-5 *1 (-150))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-262 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-944)) (-5 *1 (-808))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-423))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1225)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (-4 *1 (-1078 *3 *4 *5 *6 *7)) (-4 *5 (-1075)) (-4 *6 (-252 *4 *5)) (-4 *7 (-252 *3 *5)) (-5 *2 (-592))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-278))) (-5 *1 (-1281)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-278))) (-5 *1 (-1281)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-278))) (-5 *1 (-1282)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-278))) (-5 *1 (-1282))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1113 *3)) (-5 *1 (-1111 *3)) (-4 *3 (-1225)))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (-12 (-5 *1 (-1246 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592)))) ((*1 *2 *2) (-12 (-4 *3 (-323)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *1 (-1141 *3 *4 *5 *2)) (-4 *2 (-704 *3 *4 *5))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-62 *2 *3 *4)) (-4 *2 (-1225)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)))) ((*1 *1 *1 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-625 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 (-1280 (-592)))) (-5 *1 (-495))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-706 *3)) (-4 *3 (-323)) (-5 *1 (-716 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *5)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *2 (-346 *5 *7)) (-5 *1 (-139 *5 *6 *2 *7 *4)) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *4 (-137))))) 
+(((*1 *1) (-12 (-5 *1 (-162 *2 *3 *4)) (-14 *2 (-592)) (-14 *3 (-790)) (-4 *4 (-194))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-633 (-914 *3))) (-4 *3 (-908 *3)) (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-633 (-914 *3))) (-4 *2 (-908 *3)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-268 *2 *3 *4 *5)) (-4 *2 (-1075)) (-4 *3 (-869)) (-4 *4 (-284 *3)) (-4 *5 (-815))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 (-658 *7) *7 (-1187 *7))) (-5 *5 (-1 (-444 *7) *7)) (-4 *7 (-1255 *6)) (-4 *6 (-13 (-388) (-171) (-1065 (-433 (-592))))) (-5 *2 (-658 (-2 (|:| |frac| (-433 *7)) (|:| -2042 *3)))) (-5 *1 (-831 *6 *7 *3 *8)) (-4 *3 (-670 *7)) (-4 *8 (-670 (-433 *7))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-444 *6) *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)) (-1065 (-433 (-592))))) (-5 *2 (-658 (-2 (|:| |frac| (-433 *6)) (|:| -2042 (-668 *6 (-433 *6)))))) (-5 *1 (-834 *5 *6)) (-5 *3 (-668 *6 (-433 *6)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1187 *9)) (-5 *4 (-658 *7)) (-5 *5 (-658 *8)) (-4 *7 (-869)) (-4 *8 (-1075)) (-4 *9 (-977 *8 *6 *7)) (-4 *6 (-815)) (-5 *2 (-1187 *8)) (-5 *1 (-340 *6 *7 *8 *9))))) 
+(((*1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589)))) ((*1 *2 *3) (-12 (-5 *2 (-1187 (-433 (-592)))) (-5 *1 (-970)) (-5 *3 (-592))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *6) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-658 *3)) (-5 *6 (-1187 *3)) (-4 *3 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-588 *7 *3 *8)) (-4 *8 (-1119)))) ((*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| -12 (-5 *4 (-631 *3)) (-5 *5 (-658 *3)) (-5 *6 (-433 (-1187 *3))) (-4 *3 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-588 *7 *3 *8)) (-4 *8 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-706 (-433 (-980 (-592))))) (-5 *2 (-658 (-706 (-332 (-592))))) (-5 *1 (-1059)) (-5 *3 (-332 (-592)))))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-373)) (-5 *2 (-986 (-1187 *4))) (-5 *1 (-381 *4)) (-5 *3 (-1187 *4))))) 
+(((*1 *1) (-12 (-4 *1 (-451 *2)) (-4 *2 (-394)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *2)) (-4 *2 (-194)))) ((*1 *2) (-12 (-4 *2 (-194)) (-5 *1 (-442 *3 *2)) (-4 *3 (-443 *2)))) ((*1 *2) (-12 (-4 *1 (-443 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-137)) (-5 *2 (-592))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1280 *1)) (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *4)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-5 *2 (-1 *5)) (-5 *1 (-699 *4 *5))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-1056 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-658 (-706 *3))) (-4 *3 (-1075)) (-5 *1 (-1056 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-1056 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-658 (-706 *3))) (-4 *3 (-1075)) (-5 *1 (-1056 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-392 *2)) (-4 *2 (-194))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *1 (-609 *2)) (-4 *2 (-1065 *3)) (-4 *2 (-388)))) ((*1 *1 *2 *2) (-12 (-5 *1 (-609 *2)) (-4 *2 (-388)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-645 *4 *2)) (-4 *2 (-13 (-456 *4) (-1030) (-1211))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1111 *2)) (-4 *2 (-13 (-456 *4) (-1030) (-1211))) (-4 *4 (-13 (-869) (-582))) (-5 *1 (-645 *4 *2)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-987)) (-5 *2 (-1191)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1111 *1)) (-4 *1 (-987))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-592)) (|has| *1 (-6 -4616)) (-4 *1 (-430)) (-5 *2 (-944))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-489))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-264 *4 *5))) (-5 *2 (-264 *4 *5)) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *1 (-646 *4 *5))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-388) (-171) (-1065 (-592)))) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| |ans| (-433 *5)) (|:| |nosol| (-141)))) (-5 *1 (-1043 *4 *5)) (-5 *3 (-433 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-1191)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-489))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 (-658 *5))) (-4 *5 (-1270 *4)) (-4 *4 (-43 (-433 (-592)))) (-5 *2 (-1 (-1171 *4) (-658 (-1171 *4)))) (-5 *1 (-1272 *4 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-4 *2 (-456 *3)) (-5 *1 (-36 *3 *2)) (-4 *3 (-1065 *4)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-1017 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-658 *7)) (-4 *7 (-1094 *3 *4 *5 *6)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *1 (-1126 *3 *4 *5 *6 *7))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *5 (-394)) (-5 *2 (-790))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-592)) (-5 *1 (-520 *4)) (-4 *4 (-1255 *2))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-257 *3)) (-4 *3 (-1119)) (-5 *2 (-658 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-350))))) 
+(((*1 *2 *3 *3) (-12 (-4 *3 (-323)) (-4 *3 (-194)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-705 *3 *4 *5 *6)) (-4 *6 (-704 *3 *4 *5)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-716 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-844))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-947 *3 *4)) (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-1285))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-171)) (-4 *2 (-323)) (-4 *2 (-477)) (-4 *3 (-869)) (-4 *4 (-815)) (-5 *1 (-1016 *2 *3 *4 *5)) (-4 *5 (-977 *2 *4 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-53)) (-5 *2 (-332 (-592))) (-5 *1 (-1136)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-414)) (-5 *1 (-647))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-323)) (-4 *3 (-1021 *2)) (-4 *4 (-1255 *3)) (-5 *1 (-439 *2 *3 *4 *5)) (-4 *5 (-13 (-435 *3 *4) (-1065 *3)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-1255 *4)) (-5 *1 (-568 *4 *2 *5 *6)) (-4 *4 (-323)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-790)))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-871 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121 *5)) (-4 *5 (-582)) (-4 *5 (-1075)) (-5 *2 (-2 (|:| -2230 *3) (|:| -3027 *3))) (-5 *1 (-872 *5 *3)) (-4 *3 (-871 *5))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194)))) ((*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592))))) 
+(((*1 *1 *2 *3) (-12 (-5 *1 (-453 *3 *2)) (-4 *3 (-13 (-194) (-43 (-433 (-592))))) (-4 *2 (-13 (-869) (-21)))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-592)) (-5 *1 (-712 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1246 *3)) (-4 *3 (-1225))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1155 *2 *3)) (-4 *2 (-13 (-1119) (-39))) (-4 *3 (-13 (-1119) (-39)))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204))))) 
+(((*1 *1) (-12 (-4 *1 (-430)) (-3252 (|has| *1 (-6 -4616))) (-3252 (|has| *1 (-6 -4608))))) ((*1 *2 *1) (-12 (-4 *1 (-451 *2)) (-4 *2 (-1119)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-4 *1 (-852 *2)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-4 *1 (-869))) ((*1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-332 (-237))) (-5 *1 (-224))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-763 *3)) (-4 *3 (-194))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-980 (-592))) (-5 *2 (-350)) (-5 *1 (-352))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-971 (-237))) (-5 *4 (-896)) (-5 *2 (-1285)) (-5 *1 (-497)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1075)) (-4 *1 (-1009 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-971 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-1075)) (-4 *1 (-1151 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-971 *3)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) ((*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-971 (-237))) (-5 *1 (-1222)) (-5 *3 (-237))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1255 (-433 *2))) (-5 *2 (-592)) (-5 *1 (-936 *4 *3)) (-4 *3 (-1255 (-433 *4)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *5 *5)) (-4 *5 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *2 (-2 (|:| |solns| (-658 *5)) (|:| |maps| (-658 (-2 (|:| |arg| *5) (|:| |res| *5)))))) (-5 *1 (-1145 *3 *5)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-186)) (-5 *2 (-141))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-1191))))) 
+(((*1 *1) (-5 *1 (-1281)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-944)) (-4 *1 (-394)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1280 *4)) (-5 *1 (-556 *4)) (-4 *4 (-373)))) ((*1 *2 *1) (-12 (-4 *2 (-869)) (-5 *1 (-730 *2 *3 *4)) (-4 *3 (-1119)) (-14 *4 (-1 (-141) (-2 (|:| -1825 *2) (|:| -3215 *3)) (-2 (|:| -1825 *2) (|:| -3215 *3))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-790))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-444 *3)) (-4 *3 (-582)) (-5 *1 (-445 *3))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-658 *8)) (|:| |towers| (-658 (-1055 *5 *6 *7 *8))))) (-5 *1 (-1055 *5 *6 *7 *8)) (-5 *3 (-658 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-141)) (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-1089 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-658 *8)) (|:| |towers| (-658 (-1160 *5 *6 *7 *8))))) (-5 *1 (-1160 *5 *6 *7 *8)) (-5 *3 (-658 *8))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-3 (-433 (-980 *6)) (-1180 (-1191) (-980 *6)))) (-5 *5 (-790)) (-4 *6 (-477)) (-5 *2 (-658 (-706 (-433 (-980 *6))))) (-5 *1 (-308 *6)) (-5 *4 (-706 (-433 (-980 *6)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-2 (|:| |eigval| (-3 (-433 (-980 *5)) (-1180 (-1191) (-980 *5)))) (|:| |eigmult| (-790)) (|:| |eigvec| (-658 *4)))) (-4 *5 (-477)) (-5 *2 (-658 (-706 (-433 (-980 *5))))) (-5 *1 (-308 *5)) (-5 *4 (-706 (-433 (-980 *5))))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1252 *5 *4)) (-4 *4 (-842)) (-14 *5 (-1191)) (-5 *2 (-658 *4)) (-5 *1 (-1133 *4 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-323)) (-5 *1 (-716 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) ((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-235 *3 *4)) (-4 *3 (-13 (-1075) (-869))) (-14 *4 (-658 (-1191)))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-658 (-237))) (-5 *1 (-218))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-625 *2 *3)) (-4 *3 (-1225)) (-4 *2 (-1119)) (-4 *2 (-869))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1191)) (-5 *5 (-658 (-433 (-980 *6)))) (-5 *3 (-433 (-980 *6))) (-4 *6 (-13 (-582) (-1065 (-592)) (-171))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-658 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-598 *6))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-578))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-538 (-433 (-592)) (-254 *4 (-790)) (-879 *3) (-264 *3 (-433 (-592))))) (-14 *3 (-658 (-1191))) (-14 *4 (-790)) (-5 *1 (-539 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-53))) (-1237 (-53)))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-53)))) (-1237 (-1187 (-53))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-53) (-790) (-790) (-1187 (-53)))) (|:| AF (-1 (-1187 (-53)) (-790) (-790) (-1237 (-1187 (-53))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-53)) (-790)))) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 *4) (-790))))) (-5 *1 (-508 *4)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 *4 (-790) (-790) (-1187 *4))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 *4) (-790)))) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-592)))) (-1237 (-433 (-592))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-592))))) (-1237 (-1187 (-433 (-592)))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-592) (-790) (-790) (-1187 (-592)))) (|:| AF (-1 (-1187 (-433 (-592))) (-790) (-790) (-1237 (-1187 (-433 (-592)))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-592)) (-790)))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 (-1191))) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) (-1191) *6)) (|:| C (-1 (-658 *5) (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 *4)) (-1237 *4))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 *4))) (-1237 (-1187 *4)))) (|:| |exprStream| (-1 (-1171 *6) *6 *3)) (|:| A (-1 *5 (-790) (-790) (-1187 *5))) (|:| AF (-1 (-1187 *4) (-790) (-790) (-1237 (-1187 *4)))) (|:| AX (-1 *6 (-790) *3 *6)) (|:| C (-1 (-658 *5) (-790)))) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) (-1191))) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) (-1191) (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1171 (-1237 (-433 (-980 (-592))))) (-1237 (-433 (-980 (-592)))))) (|:| |degreeStream| (-1171 (-790))) (|:| |testStream| (-1 (-1171 (-1237 (-1187 (-433 (-980 (-592)))))) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| |exprStream| (-1 (-1171 (-332 (-592))) (-332 (-592)) *3)) (|:| A (-1 (-980 (-592)) (-790) (-790) (-1187 (-980 (-592))))) (|:| AF (-1 (-1187 (-433 (-980 (-592)))) (-790) (-790) (-1237 (-1187 (-433 (-980 (-592))))))) (|:| AX (-1 (-332 (-592)) (-790) *3 (-332 (-592)))) (|:| C (-1 (-658 (-980 (-592))) (-790)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 HPSPEC) (-5 *1 (-512 *4)) (-14 *4 (-1191)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 HPSPEC (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-592)) (-5 *1 (-470 *3)) (-4 *3 (-430)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-524)))) ((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-727))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-405)) (-5 *1 (-807 *3)) (-4 *3 (-633 *2)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-944)) (-5 *2 (-405)) (-5 *1 (-807 *3)) (-4 *3 (-633 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-980 *4)) (-4 *4 (-1075)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-980 *5)) (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-332 *4)) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-332 *5)) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-524)))) ((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-727))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-141)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-278)))) ((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496)))) ((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-496))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-706 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-706 *3))))) 
+(((*1 *2 *3 *3) (-12 (-4 *2 (-582)) (-4 *2 (-477)) (-5 *1 (-998 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *4 *5)) (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)))) ((*1 *2) (-12 (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-706 *4)) (-5 *1 (-434 *3 *4 *5)) (-4 *3 (-435 *4 *5)))) ((*1 *2) (-12 (-4 *1 (-435 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-706 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-706 *6)) (-5 *5 (-1 (-444 (-1187 *6)) (-1187 *6))) (-4 *6 (-388)) (-5 *2 (-658 (-2 (|:| |outval| *7) (|:| |outmult| (-592)) (|:| |outvect| (-658 (-706 *7)))))) (-5 *1 (-559 *6 *7 *4)) (-4 *7 (-388)) (-4 *4 (-13 (-388) (-867)))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-462))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-5 *4 (-592)) (-4 *6 (-665 *5)) (-4 *5 (-388)) (-5 *2 (-706 *5)) (-5 *1 (-659 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-980 (-237))) (-5 *2 (-332 (-405))) (-5 *1 (-321))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-280 *12))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (-4 *2 (-1075)) (-4 *2 (-194))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) ((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-496)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 (-658 (-658 *4)))) (-5 *3 (-658 *4)) (-4 *4 (-869)) (-5 *1 (-1197 *4))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-704 *4 *5 *6)) (-5 *1 (-128 *4 *3 *2 *5 *6)) (-4 *3 (-1255 *4)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-1 (-141) *8))) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |goodPols| (-658 *8)) (|:| |badPols| (-658 *8)))) (-5 *1 (-1006 *5 *6 *7 *8)) (-5 *4 (-658 *8))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-875 *2)) (-4 *2 (-194)))) ((*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-790)) (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *1 *1) (-5 *1 (-565)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1187 *3)) (-5 *1 (-937 *3)) (-4 *3 (-323))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-280 *12))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-64 *6)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-5 *2 (-64 *5)) (-5 *1 (-63 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *7 *5)) (-5 *4 (-254 *6 *7)) (-14 *6 (-790)) (-4 *7 (-1225)) (-4 *5 (-1225)) (-5 *2 (-254 *6 *5)) (-5 *1 (-253 *6 *7 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-4 *2 (-399 *5)) (-5 *1 (-397 *6 *4 *5 *2)) (-4 *4 (-399 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1119)) (-4 *5 (-1119)) (-4 *2 (-451 *5)) (-5 *1 (-449 *6 *4 *5 *2)) (-4 *4 (-451 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-658 *6)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-5 *2 (-658 *5)) (-5 *1 (-656 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-986 *6)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-5 *2 (-986 *5)) (-5 *1 (-985 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *3 *6 *3)) (-5 *5 (-1171 *6)) (-4 *6 (-1225)) (-4 *3 (-1225)) (-5 *2 (-1171 *3)) (-5 *1 (-1169 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-1280 *6)) (-4 *6 (-1225)) (-4 *5 (-1225)) (-5 *2 (-1280 *5)) (-5 *1 (-1279 *6 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-150)))) ((*1 *2 *3) (-12 (-4 *5 (-13 (-633 *2) (-194))) (-5 *2 (-914 *4)) (-5 *1 (-192 *4 *5 *3)) (-4 *4 (-1119)) (-4 *3 (-188 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-1113 (-862 (-405))))) (-5 *2 (-658 (-1113 (-862 (-237))))) (-5 *1 (-321)))) ((*1 *1 *2) (-12 (-5 *2 (-237)) (-5 *1 (-405)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-877)) (-5 *3 (-592)) (-5 *1 (-420)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-194)) (-4 *1 (-435 *3 *4)) (-4 *4 (-1255 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-435 *3 *4)) (-4 *3 (-194)) (-4 *4 (-1255 *3)) (-5 *2 (-1280 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-194)) (-4 *1 (-443 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-1280 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-444 *1)) (-4 *1 (-456 *3)) (-4 *3 (-582)) (-4 *3 (-869)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-492 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-1123)) (-5 *1 (-565)))) ((*1 *2 *1) (-12 (-4 *1 (-633 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (-12 (-4 *3 (-194)) (-4 *1 (-741 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-914 *3))) (-5 *1 (-914 *3)) (-4 *3 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1075)) (-4 *1 (-1009 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1086)))) ((*1 *1 *2) (-12 (-5 *2 (-980 *3)) (-4 *3 (-1075)) (-4 *1 (-1089 *3 *4 *5)) (-4 *5 (-633 (-1191))) (-4 *4 (-815)) (-4 *5 (-869)))) ((*1 *1 *2) (-3836 (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-3252 (-4 *3 (-43 (-433 (-592))))) (-4 *3 (-43 (-592))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))) (-12 (-5 *2 (-980 (-592))) (-4 *1 (-1089 *3 *4 *5)) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191)))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869))))) ((*1 *1 *2) (-12 (-5 *2 (-980 (-433 (-592)))) (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-43 (-433 (-592)))) (-4 *5 (-633 (-1191))) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-658 *7)) (|:| -2165 *8))) (-4 *7 (-1089 *4 *5 *6)) (-4 *8 (-1094 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1173)) (-5 *1 (-1092 *4 *5 *6 *7 *8)))) ((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1103)))) ((*1 *1 *2) (-12 (-4 *1 (-1112 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *2)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119)))) ((*1 *1 *2) (-12 (-4 *1 (-1122 *3 *4 *5 *2 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *2 (-1119)) (-4 *6 (-1119)))) ((*1 *1 *2) (-12 (-4 *1 (-1122 *3 *4 *2 *5 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *2 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)))) ((*1 *1 *2) (-12 (-4 *1 (-1122 *3 *2 *4 *5 *6)) (-4 *3 (-1119)) (-4 *2 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)))) ((*1 *1 *2) (-12 (-4 *1 (-1122 *2 *3 *4 *5 *6)) (-4 *2 (-1119)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-658 *7)) (|:| -2165 *8))) (-4 *7 (-1089 *4 *5 *6)) (-4 *8 (-1128 *4 *5 *6 *7)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1173)) (-5 *1 (-1159 *4 *5 *6 *7 *8)))) ((*1 *1 *2 *3 *2) (-12 (-5 *2 (-877)) (-5 *3 (-592)) (-5 *1 (-1206)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-877)) (-5 *3 (-592)) (-5 *1 (-1206)))) ((*1 *2 *3) (-12 (-5 *3 (-802 *4 (-879 *5))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *5 (-658 (-1191))) (-5 *2 (-802 *4 (-879 *6))) (-5 *1 (-1304 *4 *5 *6)) (-14 *6 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-980 *4)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-980 (-1051 (-433 *4)))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-802 *4 (-879 *6))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *6 (-658 (-1191))) (-5 *2 (-980 (-1051 (-433 *4)))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-5 *2 (-1187 (-1051 (-433 *4)))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191))) (-14 *6 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-1160 *4 (-558 (-879 *6)) (-879 *6) (-802 *4 (-879 *6)))) (-4 *4 (-13 (-867) (-323) (-171) (-1049))) (-14 *6 (-658 (-1191))) (-5 *2 (-658 (-802 *4 (-879 *6)))) (-5 *1 (-1304 *4 *5 *6)) (-14 *5 (-658 (-1191)))))) 
+(((*1 *2) (-12 (-4 *3 (-1075)) (-5 *2 (-986 (-729 *3 *4))) (-5 *1 (-729 *3 *4)) (-4 *4 (-1255 *3)))) ((*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-1229)) (-5 *3 (-944)) (-5 *4 (-790)) (-5 *5 (-592)) (-5 *1 (-982))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1191)) (-4 *5 (-13 (-323) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-609 *3)) (-5 *1 (-452 *5 *3)) (-4 *3 (-13 (-1211) (-29 *5)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-980 (-433 (-592)))) (-5 *4 (-1191)) (-5 *5 (-1113 (-862 (-237)))) (-5 *2 (-658 (-237))) (-5 *1 (-316))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-1173)) (-4 *1 (-389 *2 *4)) (-4 *2 (-1119)) (-4 *4 (-1119)))) ((*1 *1 *2) (-12 (-4 *1 (-389 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-971 *4)) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)))) ((*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-252 *5 (-790))) (-14 *5 (-790)) (-5 *1 (-935 *3 *2 *4 *5)) (-4 *2 (-346 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-592)) (-5 *2 (-1285)) (-5 *1 (-1034))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-790)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-998 *5 *3)) (-4 *3 (-1255 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-168))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-790)) (-4 *5 (-194)))) ((*1 *1 *1 *2 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-790)) (-4 *5 (-194)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-538 (-433 (-592)) (-254 *5 (-790)) (-879 *4) (-264 *4 (-433 (-592))))) (-5 *3 (-658 (-879 *4))) (-14 *4 (-658 (-1191))) (-14 *5 (-790)) (-5 *1 (-539 *4 *5))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-388)) (-5 *1 (-785 *2 *3)) (-4 *2 (-725 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-1089 *4 *5 *6)) (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-658 (-1291 *4 *5 *6 *7))) (-5 *1 (-1291 *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *9)) (-5 *4 (-1 (-141) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1089 *6 *7 *8)) (-4 *6 (-582)) (-4 *7 (-815)) (-4 *8 (-869)) (-5 *2 (-658 (-1291 *6 *7 *8 *9))) (-5 *1 (-1291 *6 *7 *8 *9))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-388)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-137)) (-5 *2 (-264 (-4466 (QUOTE X) (QUOTE -3820)) *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-405)) (-5 *1 (-206))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))) (-5 *1 (-617 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *1 *2) (-12 (-5 *1 (-1054 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-261 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *1) (-4 *1 (-1084)))) 
+(((*1 *1 *1) (-5 *1 (-1087)))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-460)) (-5 *2 (-658 (-3 (|:| -4095 (-1191)) (|:| |bounds| (-658 (-3 (|:| S (-1191)) (|:| P (-980 (-592))))))))) (-5 *1 (-1195))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (-5 *1 (-206))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *2)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *2 (-1089 *3 *4 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-1199 (-1106 *3) (-1106 *3))) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582)))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-826 *4 *2)) (-4 *2 (-13 (-29 *4) (-1211) (-987))))) ((*1 *1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1 *1) (-5 *1 (-877))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *2 *3) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-1175 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-658 *5))) (-4 *5 (-346 *4 *6)) (-4 *6 (-252 *7 *2)) (-14 *7 *2) (-4 *4 (-1075)) (-5 *2 (-790)) (-5 *1 (-799 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *6 (-252 *7 *2)) (-14 *7 *2) (-5 *2 (-790)) (-5 *1 (-956 *5 *3 *6 *7 *4)) (-4 *3 (-346 *5 *6)) (-4 *4 (-999 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-592)) (-4 *6 (-388)) (-4 *7 (-252 *8 *2)) (-14 *8 *2) (-5 *2 (-790)) (-5 *1 (-956 *6 *3 *7 *8 *4)) (-4 *3 (-346 *6 *7)) (-4 *4 (-999 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 *14)) (-4 *14 (-280 *13)) (-4 *13 (-560 *5 *6 *7 *8 *9 *10 *11 *12 *15)) (-4 *15 (-137)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-977 *5 *8 (-879 *6))) (-4 *8 (-252 (-1699 *6) *3)) (-4 *9 (-999 *5)) (-4 *10 (-665 *5)) (-4 *11 (-947 *5 *10)) (-4 *12 (-257 *11)) (-5 *3 (-790)) (-5 *2 (-592)) (-5 *1 (-282 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-790)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-489))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-444 *2)) (-4 *2 (-582))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-181 *2)) (-4 *2 (-574)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1000))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-168))) (-5 *1 (-163)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-163))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-658 (-516 *4 *5))) (-5 *3 (-658 (-879 *4))) (-14 *4 (-658 (-1191))) (-4 *5 (-477)) (-5 *1 (-500 *4 *5 *6)) (-4 *6 (-477))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *6)) (-5 *4 (-1 *6 (-790) (-1280 (-1187 *6)))) (-5 *5 (-658 (-790))) (-4 *6 (-13 (-582) (-477))) (-5 *2 (-706 (-1187 *6))) (-5 *1 (-369 *6 *7)) (-4 *7 (-52 *6 (-790)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-790)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-815)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *6 (-869)) (-5 *2 (-141)) (-5 *1 (-474 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-471)) (-5 *3 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-592)) (|has| *1 (-6 -4616)) (-4 *1 (-430)) (-5 *2 (-944))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-323) (-1065 (-592)) (-654 (-592)) (-171))) (-5 *1 (-826 *4 *2)) (-4 *2 (-13 (-29 *4) (-1211) (-987)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-281 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-561 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2 *1) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-5 *2 (-877)) (-5 *1 (-562 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *7 (-999 *3)) (-4 *10 (-257 *9)) (-4 *11 (-137))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-670 *3)) (-4 *3 (-1075)) (-4 *3 (-388)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-790)) (-5 *4 (-1 *5 *5)) (-4 *5 (-388)) (-5 *1 (-673 *5 *2)) (-4 *2 (-670 *5))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-993 *3 *2)) (-4 *3 (-1119))))) 
+(((*1 *2) (-12 (-4 *3 (-582)) (-5 *2 (-658 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-443 *3))))) 
+(((*1 *1 *1 *1) (-5 *1 (-141))) ((*1 *1 *1 *1) (-4 *1 (-153))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-592)) (-5 *3 (-790)) (-5 *1 (-589))))) 
+(((*1 *1 *1 *2 *1) (-12 (-5 *1 (-157 *2)) (-4 *2 (-1119)))) ((*1 *1 *2) (-12 (-5 *1 (-157 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-252 *3 *2)) (-4 *2 (-1225)) (-4 *2 (-1075)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-877)))) ((*1 *1 *1) (-5 *1 (-877))) ((*1 *2 *3 *3) (-12 (-5 *3 (-971 (-237))) (-5 *2 (-237)) (-5 *1 (-1222)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1278 *2)) (-4 *2 (-1225)) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-790)) (-4 *4 (-323)) (-4 *6 (-1255 *4)) (-5 *2 (-1280 (-658 *6))) (-5 *1 (-481 *4 *6)) (-5 *5 (-658 *6))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |cycle?| (-141)) (|:| -3989 (-790)) (|:| |period| (-790)))) (-5 *1 (-1171 *4)) (-4 *4 (-1225)) (-5 *3 (-790))))) 
+(((*1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1194))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-39)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *6 (-944)) (-4 *5 (-323)) (-4 *3 (-1255 *5)) (-5 *2 (-2 (|:| |plist| (-658 *3)) (|:| |modulo| *5))) (-5 *1 (-486 *5 *3)) (-5 *4 (-658 *3))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477))) (-5 *2 (-862 *4)) (-5 *1 (-329 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1211) (-456 *3))) (-14 *5 (-1191)) (-14 *6 *4))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477))) (-5 *2 (-862 *4)) (-5 *1 (-1265 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1211) (-456 *3))) (-14 *5 (-1191)) (-14 *6 *4)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1137)) (-5 *1 (-133)))) ((*1 *2 *1) (-12 (-4 *1 (-159)) (-5 *2 (-790)))) ((*1 *2 *3 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-399 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-399 *3)) (-4 *3 (-1225)) (-4 *3 (-1119)) (-5 *2 (-592)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-141) *4)) (-4 *1 (-399 *4)) (-4 *4 (-1225)) (-5 *2 (-592)))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-592)) (-5 *3 (-163)))) ((*1 *2 *1 *1 *2) (-12 (-4 *1 (-1158)) (-5 *2 (-592))))) 
+(((*1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1203 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-1119))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *2 (-2 (|:| |stiffness| (-405)) (|:| |stability| (-405)) (|:| |expense| (-405)) (|:| |accuracy| (-405)) (|:| |intermediateResults| (-405)))) (-5 *1 (-825))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-57)) (-5 *1 (-914 *4)) (-4 *4 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 (-790) *2)) (-5 *4 (-790)) (-4 *2 (-1119)) (-5 *1 (-695 *2)))) ((*1 *2 *2) (-12 (-5 *2 (-1 *3 (-790) *3)) (-4 *3 (-1119)) (-5 *1 (-698 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-729 *3 *2)) (-4 *2 (-1255 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 *4)))) (-5 *1 (-662 *3 *4 *5)) (-4 *3 (-1119)) (-4 *4 (-23)) (-14 *5 *4)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-658 *6))))) 
+(((*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-433 *6)) (|:| |h| *6) (|:| |c1| (-433 *6)) (|:| |c2| (-433 *6)) (|:| -4132 *6))) (-5 *1 (-1044 *5 *6)) (-5 *3 (-433 *6))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-27) (-456 *4))) (-4 *4 (-13 (-869) (-582) (-1065 (-592)))) (-4 *7 (-1255 (-433 *6))) (-5 *1 (-577 *4 *5 *6 *7 *2)) (-4 *2 (-362 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-971 *4))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-141)) (-5 *1 (-954))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1173)) (-5 *1 (-808))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-926 (-592))) (-5 *1 (-940)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-592))) (-5 *2 (-926 (-592))) (-5 *1 (-940))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-194)) (-4 *2 (-23)) (-5 *1 (-306 *3 *4 *2 *5 *6 *7)) (-4 *4 (-1255 *3)) (-14 *5 (-1 *4 *4 *2)) (-14 *6 (-1 (-3 *2 "failed") *2 *2)) (-14 *7 (-1 (-3 *4 "failed") *4 *4 *2)))) ((*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-728 *3 *2 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) ((*1 *2) (-12 (-4 *2 (-1255 *3)) (-5 *1 (-729 *3 *2)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-732 *3 *2 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) ((*1 *2) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-582) (-477))) (-5 *2 (-658 *4)) (-5 *1 (-369 *4 *5)) (-4 *5 (-52 *4 *3))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-790)) (-5 *1 (-126 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-237)) (-5 *2 (-332 (-405))) (-5 *1 (-321))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-195 *2)) (-4 *2 (-323)))) ((*1 *2 *3) (-12 (-5 *2 (-1193 (-433 (-592)))) (-5 *1 (-204)) (-5 *3 (-592)))) ((*1 *1 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1225)))) ((*1 *1 *1) (-4 *1 (-890 *2))) ((*1 *1 *1) (-12 (-4 *1 (-1002 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-814)) (-4 *4 (-869))))) 
+(((*1 *2 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-39)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-96 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-234 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-518 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-592)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4625)) (-5 *2 (-790)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-1301 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-865))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (-790) "arbitrary")) (-5 *1 (-489))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *7)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *2 (-1285)) (-5 *1 (-474 *4 *5 *6 *7))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1255 *3)) (-4 *3 (-1075))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-165)))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-166)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-238)))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-240)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1226)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1228)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1230))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1075)) (-14 *3 (-658 (-1191))))) ((*1 *1 *1) (-12 (-5 *1 (-235 *2 *3)) (-4 *2 (-13 (-1075) (-869))) (-14 *3 (-658 (-1191)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *2 *5)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-815)) (-4 *2 (-284 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-579 *3)) (-4 *3 (-13 (-430) (-1211))) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-867)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1091 *4 *3)) (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-141))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-433 (-980 *4))) (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-1065 (-592)) (-171))) (-5 *1 (-598 *4))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *3)))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *4 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *4)))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-332 (-237))) (-5 *1 (-321)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |num| (-914 *3)) (|:| |den| (-914 *3)))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |var| (-658 (-1191))) (|:| |pred| (-57)))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *4 (-977 *5 *7 (-879 *6))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *3 (-999 *5)) (-4 *8 (-665 *5)) (-4 *9 (-947 *5 *8)) (-4 *10 (-257 *9)) (-4 *12 (-137)) (-4 *2 (-280 *11)) (-5 *1 (-282 *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (-4 *11 (-560 *5 *6 *4 *7 *3 *8 *9 *10 *12))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1280 *4)) (-4 *4 (-654 (-592))) (-5 *2 (-1280 (-433 (-592)))) (-5 *1 (-1305 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-37 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-43 *2)) (-4 *2 (-194)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-388)) (-14 *6 (-1280 (-706 *3))) (-5 *1 (-49 *3 *4 *5 *6)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))))) ((*1 *1 *2) (-12 (-5 *2 (-1142 (-592) (-631 (-53)))) (-5 *1 (-53)))) ((*1 *2 *3) (-12 (-5 *2 (-57)) (-5 *1 (-56 *3)) (-4 *3 (-1225)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4466) (-715)))) (-5 *1 (-66 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715)))) (-5 *1 (-68 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-359 (-4466 (QUOTE X)) (-4466) (-715))) (-5 *1 (-69 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-359 (-4466) (-4466 (QUOTE X) (QUOTE HESS)) (-715)))) (-5 *1 (-70 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-359 (-4466) (-4466 (QUOTE XC)) (-715))) (-5 *1 (-71 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715)))) (-5 *1 (-76 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) (-5 *1 (-79 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X) (QUOTE EPS)) (-4466 (QUOTE -3820)) (-715)))) (-5 *1 (-80 *3 *4 *5)) (-14 *3 (-1191)) (-14 *4 (-1191)) (-14 *5 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE EPS)) (-4466 (QUOTE YA) (QUOTE YB)) (-715)))) (-5 *1 (-81 *3 *4 *5)) (-14 *3 (-1191)) (-14 *4 (-1191)) (-14 *5 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-359 (-4466) (-4466 (QUOTE X)) (-715))) (-5 *1 (-82 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-359 (-4466) (-4466 (QUOTE X)) (-715))) (-5 *1 (-83 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE XC)) (-715)))) (-5 *1 (-84 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) (-5 *1 (-85 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466) (-4466 (QUOTE X)) (-715)))) (-5 *1 (-86 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715)))) (-5 *1 (-87 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-359 (-4466 (QUOTE X) (QUOTE -3820)) (-4466) (-715)))) (-5 *1 (-88 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-359 (-4466 (QUOTE X)) (-4466) (-715)))) (-5 *1 (-89 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X)) (-4466) (-715)))) (-5 *1 (-90 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715)))) (-5 *1 (-91 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-359 (-4466 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4466) (-715)))) (-5 *1 (-92 *3)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-359 (-4466 (QUOTE X)) (-4466 (QUOTE -3820)) (-715))) (-5 *1 (-94 *3)) (-14 *3 (-1191)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-1032 2)) (-5 *1 (-132)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-132)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-4 *1 (-137)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-162 *3 *4 *5))) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)) (-4 *5 (-194)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *5)) (-4 *5 (-194)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)) (-14 *4 (-790)))) ((*1 *1 *2) (-12 (-5 *2 (-1156 *4 *5)) (-14 *4 (-790)) (-4 *5 (-194)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)))) ((*1 *1 *2) (-12 (-5 *2 (-254 *4 *5)) (-14 *4 (-790)) (-4 *5 (-194)) (-5 *1 (-162 *3 *4 *5)) (-14 *3 (-592)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 (-706 *4))) (-4 *4 (-194)) (-5 *2 (-1280 (-706 (-433 (-980 *4))))) (-5 *1 (-203 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-13 (-869) (-10 -8 (-15 -3927 ((-1173) $ (-1191))) (-15 -3536 ((-1285) $)) (-15 -3948 ((-1285) $))))) (-5 *1 (-227 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1032 10)) (-5 *1 (-230)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-230)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-255 *3)) (-4 *3 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-1075)) (-5 *1 (-255 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1 *3 (-944))) (-5 *1 (-255 *3)) (-4 *3 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3 (-944))) (-4 *3 (-1075)) (-5 *1 (-255 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-262 *3)) (-4 *3 (-869)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-869)) (-5 *1 (-262 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1111 (-332 *4))) (-4 *4 (-13 (-869) (-582) (-633 (-405)))) (-5 *2 (-1111 (-405))) (-5 *1 (-273 *4)))) ((*1 *1 *2) (-12 (-4 *1 (-284 *2)) (-4 *2 (-869)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-293)))) ((*1 *2 *1) (-12 (-4 *2 (-1255 *3)) (-5 *1 (-306 *3 *2 *4 *5 *6 *7)) (-4 *3 (-194)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1264 *4 *5 *6)) (-4 *4 (-13 (-27) (-1211) (-456 *3))) (-14 *5 (-1191)) (-14 *6 *4) (-4 *3 (-13 (-869) (-1065 (-592)) (-654 (-592)) (-477))) (-5 *1 (-329 *3 *4 *5 *6)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-350)))) ((*1 *2 *1) (-12 (-5 *2 (-332 *5)) (-5 *1 (-359 *3 *4 *5)) (-14 *3 (-658 (-1191))) (-14 *4 (-658 (-1191))) (-4 *5 (-413)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *2 (-349 *4)) (-5 *1 (-371 *3 *4 *2)) (-4 *3 (-349 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-373)) (-4 *2 (-349 *4)) (-5 *1 (-371 *2 *4 *3)) (-4 *3 (-349 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *2 (-1302 *3 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *2 (-1293 *3 *4)))) ((*1 *1 *2) (-12 (-4 *1 (-400 *2 *3)) (-4 *2 (-869)) (-4 *3 (-194)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-409)))) ((*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-409)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-409)))) ((*1 *1 *2) (-12 (-5 *2 (-706 (-715))) (-4 *1 (-409)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-410)))) ((*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-410)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-410)))) ((*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-1173)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-4 *1 (-415)))) ((*1 *2 *3) (-12 (-5 *2 (-420)) (-5 *1 (-419 *3)) (-4 *3 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-420)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-422)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-191 (-405))))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-405)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-592)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-191 (-405)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-405))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-592))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-710)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-715)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-332 (-717)))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-710))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-715))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-332 (-717))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-350)) (-5 *1 (-424 *3 *4 *5 *6)) (-14 *3 (-1191)) (-14 *4 (-3 (|:| |fst| (-460)) (|:| -4191 "void"))) (-14 *5 (-658 (-1191))) (-14 *6 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-351 *4)) (-4 *4 (-13 (-869) (-21))) (-5 *1 (-453 *3 *4)) (-4 *3 (-13 (-194) (-43 (-433 (-592))))))) ((*1 *1 *2) (-12 (-5 *1 (-453 *2 *3)) (-4 *2 (-13 (-194) (-43 (-433 (-592))))) (-4 *3 (-13 (-869) (-21))))) ((*1 *1 *2) (-12 (-5 *2 (-433 (-980 (-433 *3)))) (-4 *3 (-582)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-980 (-433 *3))) (-4 *3 (-582)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-433 *3)) (-4 *3 (-582)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1142 *3 (-631 *1))) (-4 *3 (-1075)) (-4 *3 (-869)) (-4 *1 (-456 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1123)) (-5 *1 (-460)))) ((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-460)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-460)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-460)))) ((*1 *1 *2) (-12 (-5 *2 (-460)) (-5 *1 (-463)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-463)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-465)))) ((*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-465)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-465)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-715))) (-4 *1 (-465)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1195)) (|:| -3702 (-658 (-350))))) (-4 *1 (-466)))) ((*1 *1 *2) (-12 (-5 *2 (-350)) (-4 *1 (-466)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-350))) (-4 *1 (-466)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 (-433 (-980 *3)))) (-4 *3 (-194)) (-14 *6 (-1280 (-706 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-658 (-971 (-237))))) (-5 *1 (-497)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-497)))) ((*1 *1 *2) (-12 (-5 *2 (-1264 *3 *4 *5)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3) (-5 *1 (-503 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-503 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-1032 16)) (-5 *1 (-521)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-521)))) ((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-524)))) ((*1 *1 *2) (-12 (-5 *2 (-1142 (-592) (-631 (-528)))) (-5 *1 (-528)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-535)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-4 *3 (-194)) (-5 *1 (-626 *3 *2)) (-4 *2 (-763 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-632 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (-12 (-4 *1 (-636 *2)) (-4 *2 (-1075)))) ((*1 *2 *1) (-12 (-5 *2 (-1298 *3 *4)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) ((*1 *2 *1) (-12 (-5 *2 (-1293 *3 *4)) (-5 *1 (-642 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-14 *5 (-944)))) ((*1 *1 *2) (-12 (-4 *3 (-194)) (-5 *1 (-650 *3 *2)) (-4 *2 (-763 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-388)) (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))))) ((*1 *1 *2) (-12 (-5 *2 (-1171 (-2 (|:| |k| (-592)) (|:| |c| *3)))) (-4 *3 (-388)) (-4 *1 (-665 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-693 *3)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-841 *3)) (-5 *1 (-688 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-986 (-986 (-986 *3)))) (-5 *1 (-691 *3)) (-4 *3 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-986 (-986 (-986 *3)))) (-4 *3 (-1119)) (-5 *1 (-691 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-841 *3)) (-5 *1 (-693 *3)) (-4 *3 (-869)))) ((*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-698 *3)) (-4 *3 (-1119)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *2)) (-4 *4 (-399 *3)) (-4 *2 (-399 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-191 (-405))) (-5 *1 (-710)))) ((*1 *1 *2) (-12 (-5 *2 (-191 (-717))) (-5 *1 (-710)))) ((*1 *1 *2) (-12 (-5 *2 (-191 (-715))) (-5 *1 (-710)))) ((*1 *1 *2) (-12 (-5 *2 (-191 (-592))) (-5 *1 (-710)))) ((*1 *1 *2) (-12 (-5 *2 (-191 (-405))) (-5 *1 (-710)))) ((*1 *1 *2) (-12 (-5 *2 (-717)) (-5 *1 (-715)))) ((*1 *2 *1) (-12 (-5 *2 (-405)) (-5 *1 (-715)))) ((*1 *2 *3) (-12 (-5 *3 (-332 (-592))) (-5 *2 (-332 (-717))) (-5 *1 (-717)))) ((*1 *1 *2) (-12 (-5 *1 (-719 *2)) (-4 *2 (-1119)))) ((*1 *2 *3) (-12 (-5 *3 (-877)) (-5 *2 (-1173)) (-5 *1 (-727)))) ((*1 *2 *1) (-12 (-4 *2 (-194)) (-5 *1 (-728 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-729 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -1825 *3) (|:| -3215 *4))) (-5 *1 (-730 *3 *4 *5)) (-4 *3 (-869)) (-4 *4 (-1119)) (-14 *5 (-1 (-141) *2 *2)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -1825 *3) (|:| -3215 *4))) (-4 *3 (-869)) (-4 *4 (-1119)) (-5 *1 (-730 *3 *4 *5)) (-14 *5 (-1 (-141) *2 *2)))) ((*1 *2 *1) (-12 (-4 *2 (-194)) (-5 *1 (-732 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| -1487 *3) (|:| -1493 *4)))) (-4 *3 (-1075)) (-4 *4 (-743)) (-5 *1 (-752 *3 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-433 (-761 *3 *4))) (-14 *3 (-1191)) (-4 *4 (-13 (-1075) (-869) (-582))) (-5 *1 (-760 *3 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-980 *4)) (-4 *4 (-1075)) (-5 *1 (-761 *3 *4)) (-14 *3 (-1191)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *3)) (-14 *3 (-1191)) (-5 *1 (-761 *3 *4)) (-4 *4 (-1075)))) ((*1 *1 *2) (-12 (-5 *1 (-761 *3 *2)) (-14 *3 (-1191)) (-4 *2 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-782)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (|:| |mdnia| (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) (-5 *1 (-788)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *1 (-788)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *1 (-788)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-788)))) ((*1 *2 *3) (-12 (-5 *2 (-793)) (-5 *1 (-792 *3)) (-4 *3 (-1225)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |xinit| (-237)) (|:| |xend| (-237)) (|:| |fn| (-1280 (-332 (-237)))) (|:| |yinit| (-658 (-237))) (|:| |intvals| (-658 (-237))) (|:| |g| (-332 (-237))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))) (-5 *1 (-830)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-830)))) ((*1 *2 *1) (-12 (-4 *2 (-922 *3)) (-5 *1 (-839 *3 *2 *4)) (-4 *3 (-1119)) (-14 *4 *3))) ((*1 *1 *2) (-12 (-4 *3 (-1119)) (-14 *4 *3) (-5 *1 (-839 *3 *2 *4)) (-4 *2 (-922 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-846)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (|:| |lsa| (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))))) (-5 *1 (-860)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *1 (-860)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (-5 *1 (-860)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-860)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *3)) (-14 *3 (-1191)) (-5 *1 (-874 *3 *4 *5 *6)) (-4 *4 (-1075)) (-14 *5 (-121 *4)) (-14 *6 (-1 *4 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-876)))) ((*1 *1 *2) (-12 (-5 *2 (-980 *3)) (-4 *3 (-1075)) (-5 *1 (-880 *3 *4 *5 *6)) (-14 *4 (-658 (-1191))) (-14 *5 (-658 (-790))) (-14 *6 (-790)))) ((*1 *2 *1) (-12 (-5 *2 (-980 *3)) (-5 *1 (-880 *3 *4 *5 *6)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))) (-14 *5 (-658 (-790))) (-14 *6 (-790)))) ((*1 *1 *2) (-12 (-5 *2 (-179)) (-5 *1 (-896)))) ((*1 *2 *3) (-12 (-5 *3 (-980 (-53))) (-5 *2 (-332 (-592))) (-5 *1 (-897)))) ((*1 *2 *3) (-12 (-5 *3 (-433 (-980 (-53)))) (-5 *2 (-332 (-592))) (-5 *1 (-897)))) ((*1 *1 *2) (-12 (-5 *1 (-915 *2)) (-4 *2 (-869)))) ((*1 *2 *1) (-12 (-5 *2 (-841 *3)) (-5 *1 (-915 *3)) (-4 *3 (-869)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |pde| (-658 (-332 (-237)))) (|:| |constraints| (-658 (-2 (|:| |start| (-237)) (|:| |finish| (-237)) (|:| |grid| (-790)) (|:| |boundaryType| (-592)) (|:| |dStart| (-706 (-237))) (|:| |dFinish| (-706 (-237)))))) (|:| |f| (-658 (-658 (-332 (-237))))) (|:| |st| (-1173)) (|:| |tol| (-237)))) (-5 *1 (-920)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-920)))) ((*1 *2 *1) (-12 (-5 *2 (-1212 *3)) (-5 *1 (-923 *3)) (-4 *3 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-927 *3))) (-4 *3 (-1119)) (-5 *1 (-926 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-927 *3))) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-927 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-658 *3))) (-4 *3 (-1119)) (-5 *1 (-927 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-433 (-444 *3))) (-4 *3 (-323)) (-5 *1 (-937 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-433 *3)) (-5 *1 (-937 *3)) (-4 *3 (-323)))) ((*1 *2 *3) (-12 (-5 *3 (-513)) (-5 *2 (-332 *4)) (-5 *1 (-942 *4)) (-4 *4 (-13 (-869) (-582))))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-388)) (-4 *1 (-999 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1000)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-433 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592)))) ((*1 *2 *3) (-12 (-5 *2 (-1285)) (-5 *1 (-1061 *3)) (-4 *3 (-1225)))) ((*1 *2 *3) (-12 (-5 *3 (-327)) (-5 *1 (-1061 *2)) (-4 *2 (-1225)))) ((*1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1062 *3 *4 *5 *2 *6)) (-4 *2 (-977 *3 *4 *5)) (-14 *6 (-658 *2)))) ((*1 *1 *2) (-12 (-4 *1 (-1065 *2)) (-4 *2 (-1225)))) ((*1 *2 *3) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-1070 *3)) (-4 *3 (-582)))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1075)))) ((*1 *2 *1) (-12 (-5 *2 (-706 *5)) (-5 *1 (-1079 *3 *4 *5)) (-14 *3 (-790)) (-14 *4 (-790)) (-4 *5 (-1075)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-869)) (-5 *1 (-1143 *3 *4 *2)) (-4 *2 (-977 *3 (-558 *4) *4)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *2 (-869)) (-5 *1 (-1143 *3 *2 *4)) (-4 *4 (-977 *3 (-558 *2) *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-877)))) ((*1 *2 *1) (-12 (-5 *2 (-706 *4)) (-5 *1 (-1156 *3 *4)) (-14 *3 (-790)) (-4 *4 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-168)) (-4 *1 (-1158)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1225)) (-5 *1 (-1171 *3)))) ((*1 *2 *3) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-1175 *3)) (-4 *3 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1181 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1188 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1189 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1252 *4 *3)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3) (-5 *1 (-1189 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1190)))) ((*1 *1 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1191)))) ((*1 *2 *1) (-12 (-5 *2 (-1199 (-1191) (-463))) (-5 *1 (-1195)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1198 *3)) (-4 *3 (-1119)))) ((*1 *2 *3) (-12 (-5 *2 (-1206)) (-5 *1 (-1205 *3)) (-4 *3 (-1119)))) ((*1 *1 *2) (-12 (-5 *2 (-877)) (-5 *1 (-1206)))) ((*1 *1 *2) (-12 (-5 *2 (-980 *3)) (-4 *3 (-1075)) (-5 *1 (-1220 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-1220 *3)) (-4 *3 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-986 *3)) (-4 *3 (-1225)) (-5 *1 (-1223 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 (QUOTE |x|))) (-5 *1 (-1237 *3)) (-4 *3 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-1252 (QUOTE |x|) *3)) (-4 *3 (-1075)) (-5 *1 (-1237 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *1 (-1241 *3 *2)) (-4 *2 (-1270 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1243 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1113 *3)) (-4 *3 (-1225)) (-5 *1 (-1246 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *3)) (-14 *3 (-1191)) (-5 *1 (-1252 *3 *4)) (-4 *4 (-1075)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *1 (-1262 *3 *2)) (-4 *2 (-1239 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1264 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1271 *3 *4 *5)) (-4 *3 (-1075)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1252 *4 *3)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-14 *5 *3) (-5 *1 (-1271 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1276 *4)) (-14 *4 (-1191)) (-5 *1 (-1275 *3 *4)) (-4 *3 (-1075)))) ((*1 *1 *2) (-12 (-5 *2 (-1252 *4 *3)) (-4 *3 (-1075)) (-14 *4 (-1191)) (-5 *1 (-1275 *3 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-1191)) (-5 *1 (-1276 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1281)))) ((*1 *2 *3) (-12 (-5 *3 (-497)) (-5 *2 (-1281)) (-5 *1 (-1284)))) ((*1 *2 *1) (-12 (-5 *2 (-877)) (-5 *1 (-1285)))) ((*1 *1 *2) (-12 (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-815)) (-14 *6 (-658 *4)) (-5 *1 (-1290 *3 *4 *5 *2 *6 *7 *8)) (-4 *2 (-977 *3 *5 *4)) (-14 *7 (-658 (-790))) (-14 *8 (-790)))) ((*1 *2 *1) (-12 (-4 *2 (-977 *3 *5 *4)) (-5 *1 (-1290 *3 *4 *5 *2 *6 *7 *8)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-815)) (-14 *6 (-658 *4)) (-14 *7 (-658 (-790))) (-14 *8 (-790)))) ((*1 *1 *2) (-12 (-4 *1 (-1292 *2)) (-4 *2 (-1075)))) ((*1 *1 *2) (-12 (-4 *1 (-1295 *2 *3)) (-4 *2 (-869)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-5 *2 (-1302 *3 *4)) (-5 *1 (-1298 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) ((*1 *2 *1) (-12 (-5 *2 (-1293 *3 *4)) (-5 *1 (-1298 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) ((*1 *1 *2) (-12 (-5 *2 (-681 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *1 (-1298 *3 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-1301 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-865))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-1191))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-57))) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *5 (-582)) (-5 *2 (-2 (|:| |minor| (-658 (-944))) (|:| -2042 *3) (|:| |minors| (-658 (-658 (-944)))) (|:| |ops| (-658 *3)))) (-5 *1 (-95 *5 *3)) (-5 *4 (-944)) (-4 *3 (-670 *5))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-923 *2)) (-4 *2 (-1119)))) ((*1 *1 *2) (-12 (-5 *1 (-923 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-381 *3)) (-4 *3 (-373))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-658 *7)) (-5 *3 (-592)) (-4 *7 (-977 *4 *5 *6)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-5 *1 (-474 *4 *5 *6 *7))))) 
+(((*1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *1) (-5 *1 (-1194)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-2 (|:| |gen| *3) (|:| -1430 *4)))) (-4 *3 (-1119)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-662 *3 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *2 (-13 (-456 *4) (-908 *3) (-633 (-914 *3)))) (-5 *1 (-1097 *3 *4 *2)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))))) ((*1 *2 *1) (-12 (-4 *2 (-1119)) (-5 *1 (-1180 *3 *2)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-631 *4)) (-5 *1 (-630 *3 *4)) (-4 *3 (-869)) (-4 *4 (-869))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *5 (-631 *4)) (-5 *6 (-1191)) (-4 *4 (-13 (-456 *7) (-27) (-1211))) (-4 *7 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2195 (-658 *4)))) (-5 *1 (-594 *7 *4 *3)) (-4 *3 (-670 *4)) (-4 *3 (-1119))))) 
+(((*1 *1) (-5 *1 (-587)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-278))) (-5 *4 (-1191)) (-5 *2 (-141)) (-5 *1 (-278))))) 
+(((*1 *2 *1) (-12 (-4 *4 (-1119)) (-5 *2 (-911 *3 *5)) (-5 *1 (-907 *3 *4 *5)) (-4 *3 (-1119)) (-4 *5 (-683 *4))))) 
+(((*1 *1) (-5 *1 (-237))) ((*1 *1) (-5 *1 (-405)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-433 (-980 (-191 (-592))))) (-5 *2 (-658 (-191 *4))) (-5 *1 (-404 *4)) (-4 *4 (-13 (-388) (-867))))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-433 (-980 (-191 (-592)))))) (-5 *4 (-658 (-1191))) (-5 *2 (-658 (-658 (-191 *5)))) (-5 *1 (-404 *5)) (-4 *5 (-13 (-388) (-867)))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-477)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *3 (-1089 *5 *6 *7)) (-5 *2 (-658 (-2 (|:| |val| (-658 *3)) (|:| -2165 *4)))) (-5 *1 (-1127 *5 *6 *7 *3 *4)) (-4 *4 (-1094 *5 *6 *7 *3))))) 
+(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-592)) (-4 *1 (-704 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-355 *3 *4 *5 *6)) (-4 *3 (-388)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-4 *6 (-362 *3 *4 *5)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-1187 *4)) (-5 *1 (-381 *4)) (-4 *4 (-373))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1255 *2)) (-4 *2 (-1235)) (-5 *1 (-172 *2 *4 *3)) (-4 *3 (-1255 (-433 *4)))))) 
+(((*1 *1) (-5 *1 (-163)))) 
+(((*1 *2 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-592)) (-4 *3 (-194)) (-4 *5 (-399 *3)) (-4 *6 (-399 *3)) (-5 *1 (-705 *3 *5 *6 *2)) (-4 *2 (-704 *3 *5 *6))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *1 (-585 *2)) (-4 *2 (-574))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-843)) (-5 *4 (-57)) (-5 *2 (-1285)) (-5 *1 (-853))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *4 (-582)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-2 (|:| |bas| (-505 *4 *5 *6 *7)) (|:| -3349 (-658 *7)))) (-5 *1 (-1006 *4 *5 *6 *7)) (-5 *3 (-658 *7))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-332 *3)) (-4 *3 (-582)) (-4 *3 (-869))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-4 *1 (-249 *3)))) ((*1 *1) (-12 (-4 *1 (-249 *2)) (-4 *2 (-1119))))) 
+(((*1 *2) (-12 (-5 *2 (-2 (|:| -2369 (-658 (-1191))) (|:| -2781 (-658 (-1191))))) (-5 *1 (-1233))))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-1293 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)) (-5 *1 (-681 *3 *4)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-681 *3 *4)) (-5 *1 (-1298 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-869)) (-5 *2 (-2 (|:| -1487 (-592)) (|:| |var| (-631 *1)))) (-4 *1 (-456 *3))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1129))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-346 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-814)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-408 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1119)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1171 *3)) (-5 *1 (-618 *3)) (-4 *3 (-1075)))) ((*1 *2 *1) (-12 (-5 *2 (-658 *3)) (-5 *1 (-752 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-743)))) ((*1 *2 *1) (-12 (-4 *1 (-871 *3)) (-4 *3 (-1075)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1270 *3)) (-4 *3 (-1075)) (-5 *2 (-1171 *3))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-143)) (-5 *4 (-658 *2)) (-5 *1 (-142 *2)) (-4 *2 (-1119)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *4 (-658 *4))) (-4 *4 (-1119)) (-5 *1 (-142 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1119)) (-5 *1 (-142 *4)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-143)) (-5 *2 (-1 *4 (-658 *4))) (-5 *1 (-142 *4)) (-4 *4 (-1119)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-661 *3)) (-4 *3 (-1075)) (-5 *1 (-731 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1075)) (-5 *1 (-856 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-2 (|:| |num| (-1280 *4)) (|:| |den| *4)))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-877)))) ((*1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-2 (|:| -3511 (-658 *6)) (|:| -1774 (-658 *6))))))) 
+(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-96 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-125)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-234 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-518 *3)) (-4 *3 (-1119)) (-4 *3 (-869)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1028 *3)) (-4 *3 (-1119)) (-4 *3 (-1119)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1161 *3)) (-4 *3 (-1119)) (-4 *3 (-1119))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-690 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-4 *2 (-252 *5 (-790))) (-5 *1 (-935 *4 *3 *2 *5)) (-4 *3 (-346 *4 *2)) (-14 *5 (-790))))) 
+(((*1 *2 *3 *4 *4 *3) (|partial| -12 (-5 *4 (-631 *3)) (-4 *3 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-594 *5 *3 *6)) (-4 *6 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-332 *4)) (-4 *4 (-13 (-850) (-869) (-1075))) (-5 *2 (-1173)) (-5 *1 (-848 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-332 *5)) (-5 *4 (-141)) (-4 *5 (-13 (-850) (-869) (-1075))) (-5 *2 (-1173)) (-5 *1 (-848 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-844)) (-5 *4 (-332 *5)) (-4 *5 (-13 (-850) (-869) (-1075))) (-5 *2 (-1285)) (-5 *1 (-848 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-844)) (-5 *4 (-332 *6)) (-5 *5 (-141)) (-4 *6 (-13 (-850) (-869) (-1075))) (-5 *2 (-1285)) (-5 *1 (-848 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-850)) (-5 *2 (-1173)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-850)) (-5 *3 (-141)) (-5 *2 (-1173)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-850)) (-5 *3 (-844)) (-5 *2 (-1285)))) ((*1 *2 *3 *1 *4) (-12 (-4 *1 (-850)) (-5 *3 (-844)) (-5 *4 (-141)) (-5 *2 (-1285))))) 
+(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-414)) (-5 *1 (-462)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-414)) (-5 *1 (-462))))) 
+(((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-141))))) 
+(((*1 *1) (-5 *1 (-163))) ((*1 *1 *1) (-5 *1 (-168))) ((*1 *1 *1) (-4 *1 (-1158)))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-159)) (-5 *3 (-790)) (-5 *2 (-1285))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3))))) 
+(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-867)) (-5 *1 (-319 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-388)) (-4 *1 (-349 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-1255 *4)) (-4 *4 (-1235)) (-4 *1 (-362 *4 *3 *5)) (-4 *5 (-1255 (-433 *3))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-1280 *1)) (-4 *4 (-194)) (-4 *1 (-392 *4)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1280 *4)) (-5 *3 (-1280 *1)) (-4 *4 (-194)) (-4 *1 (-396 *4 *5)) (-4 *5 (-1255 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-194)) (-4 *1 (-435 *3 *4)) (-4 *4 (-1255 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1280 *3)) (-4 *3 (-194)) (-4 *1 (-443 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-388)) (-5 *1 (-553 *2 *4 *5 *3)) (-4 *3 (-704 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2)) (|has| *2 (-6 (-4627 "*"))) (-4 *2 (-1075)))) ((*1 *2 *3) (-12 (-4 *4 (-399 *2)) (-4 *5 (-399 *2)) (-4 *2 (-194)) (-5 *1 (-705 *2 *4 *5 *3)) (-4 *3 (-704 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1140 *3 *2 *4 *5)) (-4 *4 (-252 *3 *2)) (-4 *5 (-252 *3 *2)) (|has| *2 (-6 (-4627 "*"))) (-4 *2 (-1075))))) 
+(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *1 *1 *1) (-4 *1 (-675))) ((*1 *1 *1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-1187 (-1187 *4)))) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-5 *2 (-3 (-658 *8) "failed" "Infinite" (-592))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *8 (-999 *4))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-980 (-592))) (-5 *2 (-350)) (-5 *1 (-352)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-1111 (-980 (-592)))) (-5 *2 (-350)) (-5 *1 (-352)))) ((*1 *1 *2 *2 *2) (-12 (-5 *2 (-790)) (-5 *1 (-691 *3)) (-4 *3 (-1075)) (-4 *3 (-1119))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1212 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-342 *2 *3)) (-4 *2 (-1119)) (-4 *3 (-158)) (-4 *3 (-814))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-4 *4 (-13 (-323) (-171))) (-4 *5 (-13 (-869) (-633 (-1191)))) (-4 *6 (-815)) (-5 *2 (-658 (-2 (|:| |eqzro| (-658 *7)) (|:| |neqzro| (-658 *7)) (|:| |wcond| (-658 (-980 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1280 (-433 (-980 *4)))) (|:| -2195 (-658 (-1280 (-433 (-980 *4)))))))))) (-5 *1 (-951 *4 *5 *6 *7)) (-4 *7 (-977 *4 *6 *5))))) 
+(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *1 *1 *1) (-4 *1 (-675))) ((*1 *1 *1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-327)) (-5 *1 (-312)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-1173))) (-5 *2 (-327)) (-5 *1 (-312)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-327)) (-5 *1 (-312)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-1173))) (-5 *3 (-1173)) (-5 *2 (-327)) (-5 *1 (-312))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-790)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-983)) (-5 *2 (-658 (-658 (-971 (-237))))))) ((*1 *2 *1) (-12 (-4 *1 (-1003)) (-5 *2 (-658 (-658 (-971 (-237)))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-1032 *3)) (-14 *3 (-592))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-582) (-477))) (-5 *2 (-658 *4)) (-5 *1 (-369 *4 *5)) (-4 *5 (-52 *4 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-4 *1 (-526))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *1 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-849 *2 *3)) (-4 *2 (-725 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| -12 (-5 *3 (-631 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1191))) (-5 *5 (-1187 *2)) (-4 *2 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *1 (-588 *6 *2 *7)) (-4 *7 (-1119)))) ((*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| -12 (-5 *3 (-631 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1191))) (-5 *5 (-433 (-1187 *2))) (-4 *2 (-13 (-456 *6) (-27) (-1211))) (-4 *6 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *1 (-588 *6 *2 *7)) (-4 *7 (-1119))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1191)) (-4 *5 (-633 (-914 (-592)))) (-4 *5 (-908 (-592))) (-4 *5 (-13 (-869) (-1065 (-592)) (-477) (-654 (-592)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-595 *5 *3)) (-4 *3 (-644)) (-4 *3 (-13 (-27) (-1211) (-456 *5)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-388)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2934 *1))) (-4 *1 (-871 *3))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-388)) (-4 *5 (-399 *4)) (-4 *6 (-399 *4)) (-5 *1 (-694 *4 *5 *6 *2)) (-4 *2 (-704 *4 *5 *6))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-4 *1 (-526))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 *6)) (-4 *5 (-1119)) (-4 *6 (-1225)) (-5 *2 (-1 *6 *5)) (-5 *1 (-655 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 *2)) (-4 *5 (-1119)) (-4 *2 (-1225)) (-5 *1 (-655 *5 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 *6)) (-5 *4 (-658 *5)) (-4 *6 (-1119)) (-4 *5 (-1225)) (-5 *2 (-1 *5 *6)) (-5 *1 (-655 *6 *5)))) ((*1 *2 *3 *4 *5 *2) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 *2)) (-4 *5 (-1119)) (-4 *2 (-1225)) (-5 *1 (-655 *5 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-1 *6 *5)) (-5 *3 (-658 *5)) (-5 *4 (-658 *6)) (-4 *5 (-1119)) (-4 *6 (-1225)) (-5 *1 (-655 *5 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 *2)) (-5 *6 (-1 *2 *5)) (-4 *5 (-1119)) (-4 *2 (-1225)) (-5 *1 (-655 *5 *2)))) ((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1158)) (-5 *3 (-168)) (-5 *2 (-790))))) 
+(((*1 *1 *1 *1) (-4 *1 (-323))) ((*1 *1 *1 *1) (-5 *1 (-790))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1283))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1219 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-658 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-137)) (-5 *2 (-592)) (-5 *1 (-491 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-280 *12)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-894 *4 *5 *6)) (-4 (-884 *4) (-394)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-4 *6 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-944)) (-5 *2 (-592)) (-5 *1 (-895 *4 *5 *6)) (-4 *4 (-394)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-137))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-4 *1 (-526))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-980 *4)) (-4 *4 (-1075)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-980 *5)) (-5 *4 (-944)) (-4 *5 (-1075)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-582)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-433 (-980 *5))) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-332 *4)) (-4 *4 (-582)) (-4 *4 (-869)) (-4 *4 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-332 *5)) (-5 *4 (-944)) (-4 *5 (-582)) (-4 *5 (-869)) (-4 *5 (-633 *2)) (-5 *2 (-405)) (-5 *1 (-807 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-778))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1173)) (-5 *1 (-281 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *1 *1) (-4 *1 (-526))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *3 (-977 *4 *6 (-879 *5))) (-4 *6 (-252 (-1699 *5) (-790))) (-4 *7 (-999 *4)) (-4 *8 (-665 *4)) (-4 *9 (-947 *4 *8)) (-4 *10 (-560 *4 *5 *3 *6 *7 *8 *9 *2 *12)) (-4 *12 (-137)) (-4 *2 (-257 *9)) (-5 *1 (-491 *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-658 *13)) (-5 *5 (-658 *9)) (-4 *9 (-999 *6)) (-4 *13 (-280 *12)) (-4 *6 (-388)) (-4 *12 (-560 *6 *7 *3 *8 *9 *10 *11 *2 *14)) (-4 *14 (-137)) (-14 *7 (-658 (-1191))) (-4 *3 (-977 *6 *8 (-879 *7))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *10 (-665 *6)) (-4 *11 (-947 *6 *10)) (-4 *2 (-257 *11)) (-5 *1 (-580 *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14)))) ((*1 *2 *3) (-12 (-5 *3 (-264 *5 *4)) (-4 *4 (-373)) (-14 *5 (-658 (-1191))) (-5 *2 (-258 (-949 *4))) (-5 *1 (-894 *4 *5 *6)) (-4 *6 (-137)))) ((*1 *2 *3) (-12 (-5 *3 (-264 *5 *4)) (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-5 *2 (-258 (-948 *4))) (-5 *1 (-895 *4 *5 *6)) (-4 *6 (-137))))) 
+(((*1 *1 *1 *1) (-4 *1 (-323))) ((*1 *1 *1 *1) (-5 *1 (-790))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-2 (|:| -4500 (-1187 *6)) (|:| -3215 (-592))))) (-4 *6 (-323)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-592)) (-5 *1 (-759 *4 *5 *6 *7)) (-4 *7 (-977 *6 *4 *5))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-589))))) 
+(((*1 *1) (-5 *1 (-845)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-1187 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *1 *1) (-4 *1 (-526))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-790))) (-5 *3 (-141)) (-5 *1 (-1179 *4 *5)) (-14 *4 (-944)) (-4 *5 (-1075))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-5 *2 (-1 *6 *5)) (-5 *1 (-700 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-456 *4)) (-5 *1 (-457 *4 *2)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *1 *1) (-4 *1 (-526))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-704 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-399 *2)) (-4 *4 (-399 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-141)) (-5 *2 (-1285)) (-5 *1 (-58))))) 
+(((*1 *2 *2 *2 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-631 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1191))) (-4 *2 (-13 (-456 *5) (-27) (-1211))) (-4 *5 (-13 (-477) (-1065 (-592)) (-869) (-171) (-654 (-592)))) (-5 *1 (-594 *5 *2 *6)) (-4 *6 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-706 (-433 (-980 (-592))))) (-5 *2 (-658 (-706 (-332 (-592))))) (-5 *1 (-1059))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-658 *1)) (-4 *1 (-1151 *3))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-658 (-592))) (-5 *3 (-141)) (-5 *1 (-1129))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-1207))))) 
+(((*1 *1 *1) (-4 *1 (-116))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))) (-5 *2 (-658 (-1097 *3 *4 *5))) (-5 *1 (-1098 *3 *4 *5)) (-4 *5 (-13 (-456 *4) (-908 *3) (-633 (-914 *3))))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1122 *2 *3 *4 *5 *6)) (-4 *2 (-1119)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *2)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119))))) 
+(((*1 *2) (|partial| -12 (-4 *3 (-582)) (-4 *3 (-194)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2195 (-658 *1)))) (-4 *1 (-392 *3)))) ((*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-478 *3 *4 *5 *6)) (|:| -2195 (-658 (-478 *3 *4 *5 *6))))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-433 (-980 *4))) (-4 *4 (-323)) (-5 *2 (-433 (-444 (-980 *4)))) (-5 *1 (-1069 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-885))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-467 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *1 *1) (-4 *1 (-116))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1122 *2 *3 *4 *5 *6)) (-4 *2 (-1119)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-592)) (-4 *6 (-815)) (-4 *7 (-869)) (-4 *8 (-323)) (-4 *9 (-977 *8 *6 *7)) (-5 *2 (-2 (|:| -3489 (-1187 *9)) (|:| |polval| (-1187 *8)))) (-5 *1 (-759 *6 *7 *8 *9)) (-5 *3 (-1187 *9)) (-5 *4 (-1187 *8))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1203 *4 *5)) (-4 *4 (-1119)) (-4 *5 (-1119))))) 
+(((*1 *1 *1) (-4 *1 (-582)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-346 *2 *3)) (-4 *3 (-814)) (-4 *2 (-1075)) (-4 *2 (-477)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-1255 (-592))) (-5 *2 (-658 (-592))) (-5 *1 (-520 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-477)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *3 (-477))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-332 (-237))) (-5 *2 (-332 (-405))) (-5 *1 (-321))))) 
+(((*1 *1 *1) (-4 *1 (-116))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-658 *6)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-927 *3))) (-5 *1 (-926 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-206)))) ((*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-316)))) ((*1 *2 *3) (-12 (-5 *3 (-1113 (-862 (-237)))) (-5 *2 (-237)) (-5 *1 (-321))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *4 *5 *6 *7)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *7 (-1119)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141)) (-5 *1 (-538 *3 *4 *5 *6)) (-4 *6 (-977 *3 *4 *5))))) 
+(((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *1 *1) (-4 *1 (-116))) ((*1 *1 *1 *1) (-5 *1 (-237))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *1 *1 *1) (-5 *1 (-405))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-1285)) (-5 *1 (-488))))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *3 (-194)))) ((*1 *2 *3 *3 *2) (-12 (-5 *2 (-592)) (-5 *3 (-1229)) (-5 *1 (-982)))) ((*1 *2 *3 *3) (-12 (-4 *2 (-582)) (-5 *1 (-998 *2 *3)) (-4 *3 (-1255 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-194))))) 
+(((*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1095 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-5 *2 (-1285)) (-5 *1 (-1127 *3 *4 *5 *6 *7)) (-4 *7 (-1094 *3 *4 *5 *6))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-4 *1 (-579 *3)) (-4 *3 (-13 (-430) (-1211))))) ((*1 *1 *2) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211))))) ((*1 *1 *2 *2) (-12 (-4 *1 (-579 *2)) (-4 *2 (-13 (-430) (-1211)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388))))) 
+(((*1 *1 *1) (-4 *1 (-116))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-4 *7 (-1255 *5)) (-4 *4 (-741 *5 *7)) (-5 *2 (-2 (|:| -3253 (-706 *6)) (|:| |vec| (-1280 *5)))) (-5 *1 (-833 *5 *6 *7 *4 *3)) (-4 *6 (-670 *5)) (-4 *3 (-670 *4))))) 
+(((*1 *2 *3 *2) (-12 (-4 *1 (-809)) (-5 *2 (-1063)) (-5 *3 (-2 (|:| |fn| (-332 (-237))) (|:| -2166 (-658 (-1113 (-862 (-237))))) (|:| |abserr| (-237)) (|:| |relerr| (-237)))))) ((*1 *2 *3 *2) (-12 (-4 *1 (-809)) (-5 *2 (-1063)) (-5 *3 (-2 (|:| |var| (-1191)) (|:| |fn| (-332 (-237))) (|:| -2166 (-1113 (-862 (-237)))) (|:| |abserr| (-237)) (|:| |relerr| (-237))))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-971 *3)) (-4 *3 (-13 (-388) (-1211) (-1030))) (-5 *1 (-196 *3))))) 
+(((*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-986 (-237))) (-5 *3 (-1137)) (-5 *4 (-237)) (-5 *1 (-135))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-658 *1)) (-5 *3 (-658 (-790))) (-5 *4 (-592)) (-4 *1 (-665 *5)) (-4 *5 (-388))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-477))) (-5 *1 (-1217 *3 *2)) (-4 *2 (-13 (-456 *3) (-1211)))))) 
+(((*1 *1 *1) (-4 *1 (-116))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-1097 *3 *4 *5))) (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))) (-4 *5 (-13 (-456 *4) (-908 *3) (-633 (-914 *3)))) (-5 *1 (-1098 *3 *4 *5))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-790)) (-5 *1 (-805 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-194))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-332 (-237)))) (-5 *4 (-790)) (-5 *2 (-706 (-237))) (-5 *1 (-285))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1005 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-582)) (-5 *2 (-141))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-1151 *3)) (-4 *3 (-1075)))) ((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-433 *1)) (-4 *1 (-1255 *3)) (-4 *3 (-1075)) (-4 *3 (-582)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-582))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *1 *1) (-4 *1 (-1214)))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-428)) (-5 *2 (-790)))) ((*1 *1 *1) (-4 *1 (-428)))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-1229)) (-5 *3 (-592)) (-5 *1 (-982))))) 
+(((*1 *2 *3 *4 *3 *4 *3 *5 *5) (-12 (-5 *3 (-1137)) (-5 *5 (-237)) (-5 *2 (-658 (-986 *5))) (-5 *1 (-135)) (-5 *4 (-986 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-954))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *1 *1) (-4 *1 (-1214)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-869) (-1065 (-592)))) (-5 *1 (-202 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 (-191 *3)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-477) (-869) (-1065 (-592)) (-654 (-592)))) (-5 *1 (-1215 *3 *2)) (-4 *2 (-13 (-27) (-1211) (-456 *3)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592))))) 
+(((*1 *1 *1) (|partial| -4 *1 (-169))) ((*1 *1 *1) (-4 *1 (-373))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-169)) (-4 *1 (-931))))) 
+(((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-141)) (-5 *1 (-391 *3 *4)) (-4 *3 (-392 *4)))) ((*1 *2) (-12 (-4 *1 (-392 *3)) (-4 *3 (-194)) (-5 *2 (-141))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *1 *1) (-4 *1 (-1214)))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1187 *1)) (-4 *1 (-1040))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-845)) (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *1 *2 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-4 *4 (-1119)) (-4 *5 (-13 (-1075) (-908 *4) (-869) (-633 (-914 *4)))) (-5 *1 (-1097 *4 *5 *2)) (-4 *2 (-13 (-456 *5) (-908 *4) (-633 (-914 *4)))))) ((*1 *1 *2 *2) (-12 (-4 *3 (-1119)) (-4 *4 (-13 (-1075) (-908 *3) (-869) (-633 (-914 *3)))) (-5 *1 (-1097 *3 *4 *2)) (-4 *2 (-13 (-456 *4) (-908 *3) (-633 (-914 *3))))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-1280 (-592))) (-5 *3 (-592)) (-5 *1 (-1129)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-1280 (-592))) (-5 *3 (-658 (-592))) (-5 *4 (-592)) (-5 *1 (-1129))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-658 *6)) (-4 *6 (-346 *5 *7)) (-4 *7 (-252 *8 (-790))) (-14 *8 (-790)) (-4 *5 (-388)) (-5 *2 (-141)) (-5 *1 (-956 *5 *6 *7 *8 *4)) (-4 *4 (-999 *5))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *1 *1) (-4 *1 (-1214)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-323) (-171))) (-4 *4 (-13 (-869) (-633 (-1191)))) (-4 *5 (-815)) (-5 *1 (-951 *3 *4 *5 *2)) (-4 *2 (-977 *3 *5 *4))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-195 *2)) (-4 *2 (-323)))) ((*1 *2 *1) (-12 (-5 *1 (-937 *2)) (-4 *2 (-323)))) ((*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582)) (-4 *2 (-323)))) ((*1 *2 *1) (-12 (-4 *1 (-1084)) (-5 *2 (-592))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-4 *4 (-582)) (-4 *5 (-1255 *4)) (-5 *2 (-2 (|:| -4104 (-639 *4 *5)) (|:| -4134 (-433 *5)))) (-5 *1 (-639 *4 *5)) (-5 *3 (-433 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-1179 *3 *4))) (-5 *1 (-1179 *3 *4)) (-14 *3 (-944)) (-4 *4 (-1075)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-477)) (-4 *3 (-1075)) (-5 *2 (-2 (|:| |primePart| *1) (|:| |commonPart| *1))) (-4 *1 (-1255 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1173)) (-5 *1 (-1204))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-658 (-193))))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-351 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *1 *1) (-4 *1 (-1214)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-53))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-53))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-4 (-53) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-53)) (-658 (-489)))) (-5 *1 (-506)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-13 (-373) (-633 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-508 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-508 *4)) (-4 *4 (-1065 *3)) (-4 *4 (-13 (-373) (-633 (-592)))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-592)))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-4 (-433 (-592)) (-1065 *3)) (-4 (-592) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-592))) (-658 (-489)))) (-5 *1 (-509)))) ((*1 *2 *3) (-12 (-5 *3 (-658 *4)) (-4 *4 (-388)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790))))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 *5)) (-5 *4 (-658 (-489))) (-4 *5 (-388)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-869) (-582))) (-14 *9 (-1 *5 *8)) (-5 *2 (-658 (-2 (|:| -1325 *7) (|:| -4346 (-790))))) (-5 *1 (-510 *5 *6 *7 *8 *9 *10)) (-4 *6 (-477)) (-4 *7 (-13 (-456 (-592)) (-582) (-1065 *8) (-1065 (-1191)) (-1065 (-592)) (-182) (-922 (-1191)) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-4 *7 (-13 (-869) (-582))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-658 (-2 (|:| -1325 *6) (|:| -4346 (-790)))) (-658 *4) (-658 (-489)))) (-5 *1 (-510 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1065 *3)) (-4 *5 (-1065 *3)) (-4 *4 (-388)) (-4 *5 (-477)) (-4 *6 (-13 (-456 (-592)) (-582) (-1065 *7) (-1065 *3) (-1065 (-592)) (-182) (-922 *3) (-10 -8 (-15 * ($ $ $)) (-15 -3313 ($ $ $)) (-15 ** ($ $ $)) (-15 -3838 ($ $)) (-15 -2782 ($ $)) (-15 -4559 ((-141) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-980 (-592))))) (-5 *4 (-658 (-489))) (-5 *2 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790))))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-4 (-433 (-980 (-592))) (-1065 *3)) (-4 (-980 (-592)) (-1065 *3)) (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-332 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-980 (-592)))) (-658 (-489)))) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-433 (-761 *4 (-592))))) (-14 *4 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-433 (-761 *5 (-592))))) (-5 *4 (-658 (-489))) (-14 *5 (-1191)) (-5 *2 (-658 (-2 (|:| -1325 (-760 *5 (-592))) (|:| -4346 (-790))))) (-5 *1 (-512 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1 (-658 (-2 (|:| -1325 (-760 *4 (-592))) (|:| -4346 (-790)))) (-658 (-433 (-761 *4 (-592)))) (-658 (-489)))) (-5 *1 (-512 *4)) (-14 *4 *3)))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1255 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *3 (-1089 *6 *7 *8)) (-5 *2 (-658 (-2 (|:| |val| *3) (|:| -2165 *4)))) (-5 *1 (-1127 *6 *7 *8 *3 *4)) (-4 *4 (-1094 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-658 (-2 (|:| |val| (-658 *8)) (|:| -2165 *9)))) (-5 *5 (-141)) (-4 *8 (-1089 *6 *7 *4)) (-4 *9 (-1094 *6 *7 *4 *8)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *4 (-869)) (-5 *2 (-658 (-2 (|:| |val| *8) (|:| -2165 *9)))) (-5 *1 (-1127 *6 *7 *4 *8 *9))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1017 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *7 (-1089 *4 *5 *6)) (-5 *2 (-141)) (-5 *1 (-1126 *4 *5 *6 *7 *3)) (-4 *3 (-1094 *4 *5 *6 *7))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-351 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *1 *1) (-4 *1 (-1214)))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1089 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869))))) 
+(((*1 *1 *2 *3) (-12 (-4 *1 (-408 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1119)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-5 *2 (-1171 *3)) (-5 *1 (-1175 *3)) (-4 *3 (-1075)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-841 *4)) (-4 *4 (-869)) (-4 *1 (-1295 *4 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)) (-5 *2 (-1187 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-349 *3)) (-4 *3 (-388)) (-4 *3 (-394)) (-5 *2 (-1187 *3))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-943)) (-5 *2 (-2 (|:| -1487 (-658 *1)) (|:| -2934 *1))) (-5 *3 (-658 *1))))) 
+(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1191)) (-4 *5 (-13 (-477) (-869) (-171) (-1065 (-592)) (-654 (-592)))) (-5 *2 (-2 (|:| -3191 *3) (|:| |coeff| *3))) (-5 *1 (-583 *5 *3)) (-4 *3 (-13 (-27) (-1211) (-456 *5)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-1113 (-237))) (-5 *2 (-954)) (-5 *1 (-952 *3)) (-4 *3 (-633 (-565))))) ((*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-1191)) (-5 *5 (-1113 (-237))) (-5 *2 (-954)) (-5 *1 (-952 *3)) (-4 *3 (-633 (-565))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-953)))) ((*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-953)))) ((*1 *1 *2 *2 *2 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-953)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *1 *2 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *1 *2 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-658 (-1 (-237) (-237)))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-658 (-1 (-237) (-237)))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-237) (-237))) (-5 *3 (-1113 (-237))) (-5 *1 (-954))))) 
+(((*1 *2) (-12 (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-977 *3 *6 (-879 *4))) (-4 *6 (-252 (-1699 *4) (-790))) (-4 *7 (-999 *3)) (-4 *8 (-665 *3)) (-4 *9 (-947 *3 *8)) (-4 *10 (-257 *9)) (-4 *11 (-560 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-137)) (-5 *2 (-658 *12)) (-5 *1 (-491 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-280 *11)))) ((*1 *2) (-12 (-5 *2 (-658 (-281 (-561 *3 *4 *5)))) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-658 (-281 (-537 *3 *4 *5)))) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1302 *4 *2)) (-4 *1 (-400 *4 *2)) (-4 *4 (-869)) (-4 *2 (-194)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1295 *3 *2)) (-4 *3 (-869)) (-4 *2 (-1075)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-841 *4)) (-4 *1 (-1295 *4 *2)) (-4 *4 (-869)) (-4 *2 (-1075)))) ((*1 *2 *1 *3) (-12 (-4 *2 (-1075)) (-5 *1 (-1301 *2 *3)) (-4 *3 (-865))))) 
+(((*1 *1 *1) (-4 *1 (-644))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-862 (-405))) (-5 *2 (-862 (-237))) (-5 *1 (-321))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-451 *3)) (-4 *3 (-1119)) (-5 *2 (-790))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-658 *3)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-5 *2 (-658 *8)) (-5 *1 (-991 *5 *6 *3 *7 *8)) (-4 *8 (-999 *5))))) 
+(((*1 *2) (-12 (-4 *2 (-194)) (-5 *1 (-187 *3 *2)) (-4 *3 (-188 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-396 *2 *4)) (-4 *4 (-1255 *2)) (-4 *2 (-194)))) ((*1 *2) (-12 (-4 *4 (-1255 *2)) (-4 *2 (-194)) (-5 *1 (-434 *3 *2 *4)) (-4 *3 (-435 *2 *4)))) ((*1 *2) (-12 (-4 *1 (-435 *2 *3)) (-4 *3 (-1255 *2)) (-4 *2 (-194)))) ((*1 *2) (-12 (-4 *3 (-1255 *2)) (-5 *2 (-592)) (-5 *1 (-787 *3 *4)) (-4 *4 (-435 *2 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *2 (-869)) (-4 *3 (-194)))) ((*1 *2 *3) (-12 (-4 *2 (-582)) (-5 *1 (-998 *2 *3)) (-4 *3 (-1255 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1255 *2)) (-4 *2 (-1075)) (-4 *2 (-194))))) 
+(((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| -2042 (-658 *9)) (|:| -2165 *4) (|:| |ineq| (-658 *9)))) (-5 *1 (-1017 *6 *7 *8 *9 *4)) (-5 *3 (-658 *9)) (-4 *4 (-1094 *6 *7 *8 *9)))) ((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-141)) (-4 *6 (-477)) (-4 *7 (-815)) (-4 *8 (-869)) (-4 *9 (-1089 *6 *7 *8)) (-5 *2 (-2 (|:| -2042 (-658 *9)) (|:| -2165 *4) (|:| |ineq| (-658 *9)))) (-5 *1 (-1126 *6 *7 *8 *9 *4)) (-5 *3 (-658 *9)) (-4 *4 (-1094 *6 *7 *8 *9))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-980 *4))) (-4 *4 (-477)) (-5 *2 (-141)) (-5 *1 (-385 *4 *5)) (-14 *5 (-658 (-1191))))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-802 *4 (-879 *5)))) (-4 *4 (-477)) (-14 *5 (-658 (-1191))) (-5 *2 (-141)) (-5 *1 (-643 *4 *5))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *7 (-252 (-1699 *5) (-790))) (-4 *8 (-999 *4)) (-4 *9 (-665 *4)) (-4 *10 (-947 *4 *9)) (-4 *11 (-257 *10)) (-4 *12 (-560 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-137)) (-5 *2 (-1285)) (-5 *1 (-282 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-280 *12))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-902 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-902 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-971 (-237)) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-904 (-1 (-237) (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-904 (-1 (-237) (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-270)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-902 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-902 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *5)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1111 (-405))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-904 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *6)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-904 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1150 (-237))) (-5 *1 (-274 *5))))) 
+(((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-871 *2)) (-4 *2 (-1075)) (-4 *2 (-388))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-234 *2)) (-4 *2 (-1119)))) ((*1 *2 *1) (-12 (-4 *1 (-1023 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-5 *1 (-1028 *2)) (-4 *2 (-1119))))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-574)))) 
+(((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-894 *3 *4 *5)) (-4 *3 (-373)) (-14 *4 (-658 (-1191))) (-4 *5 (-137)))) ((*1 *2) (-12 (-5 *2 (-1285)) (-5 *1 (-895 *3 *4 *5)) (-4 *3 (-388)) (-14 *4 (-658 (-1191))) (-4 *5 (-137))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 *1)) (-4 *1 (-392 *4)) (-4 *4 (-194)) (-5 *2 (-658 (-980 *4))))) ((*1 *2) (-12 (-4 *4 (-194)) (-5 *2 (-658 (-980 *4))) (-5 *1 (-442 *3 *4)) (-4 *3 (-443 *4)))) ((*1 *2) (-12 (-4 *1 (-443 *3)) (-4 *3 (-194)) (-5 *2 (-658 (-980 *3))))) ((*1 *2) (-12 (-5 *2 (-658 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3))))) ((*1 *2 *3) (-12 (-5 *3 (-1280 (-478 *4 *5 *6 *7))) (-5 *2 (-658 (-980 *4))) (-5 *1 (-478 *4 *5 *6 *7)) (-4 *4 (-582)) (-4 *4 (-194)) (-14 *5 (-944)) (-14 *6 (-658 (-1191))) (-14 *7 (-1280 (-706 *4)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-270)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1281)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-900 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-270)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-900 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1281)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-902 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-902 (-1 (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-971 (-237)) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-237) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-971 (-237)) (-237) (-237))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-904 (-1 (-237) (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-904 (-1 (-237) (-237) (-237)))) (-5 *4 (-1113 (-405))) (-5 *2 (-1282)) (-5 *1 (-270)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-310 *7)) (-5 *4 (-1191)) (-5 *5 (-658 (-278))) (-4 *7 (-456 *6)) (-4 *6 (-13 (-582) (-869) (-1065 (-592)))) (-5 *2 (-1281)) (-5 *1 (-271 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1111 (-405))) (-5 *2 (-1281)) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-900 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1281)) (-5 *1 (-274 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-900 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1281)) (-5 *1 (-274 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-902 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1282)) (-5 *1 (-274 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-902 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1282)) (-5 *1 (-274 *5)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1111 (-405))) (-5 *2 (-1282)) (-5 *1 (-274 *3)) (-4 *3 (-13 (-633 (-565)) (-1119))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-904 *6)) (-5 *4 (-1111 (-405))) (-5 *5 (-658 (-278))) (-4 *6 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1282)) (-5 *1 (-274 *6)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-904 *5)) (-5 *4 (-1111 (-405))) (-4 *5 (-13 (-633 (-565)) (-1119))) (-5 *2 (-1282)) (-5 *1 (-274 *5)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-1281)) (-5 *1 (-275)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-658 (-237))) (-5 *4 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-275)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-971 (-237)))) (-5 *2 (-1281)) (-5 *1 (-275)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-971 (-237)))) (-5 *4 (-658 (-278))) (-5 *2 (-1281)) (-5 *1 (-275)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-658 (-237))) (-5 *2 (-1282)) (-5 *1 (-275)))) ((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-658 (-237))) (-5 *4 (-658 (-278))) (-5 *2 (-1282)) (-5 *1 (-275))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-405)) (-5 *1 (-118))))) 
+(((*1 *2 *3 *3 *1) (-12 (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-3 *3 (-658 *1))) (-4 *1 (-1094 *4 *5 *6 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1075)) (-5 *2 (-141)) (-5 *1 (-469 *4 *3)) (-4 *3 (-1255 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1089 *3 *4 *5)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1262 *3 *4)) (-4 *3 (-1075)) (-4 *4 (-1239 *3)) (-5 *2 (-433 (-592)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-971 *2)) (-5 *1 (-1011 *2)) (-4 *2 (-1075))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-937 *3)) (-4 *3 (-323))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-332 (-592))) (|:| -3958 (-332 (-405))) (|:| CF (-332 (-191 (-405)))) (|:| |switch| (-1190)))) (-5 *1 (-1190))))) 
+(((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-715)))) ((*1 *2 *2) (-12 (-5 *2 (-592)) (-5 *1 (-715))))) 
+(((*1 *1 *1) (-4 *1 (-644))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-143)) (-5 *3 (-658 *1)) (-4 *1 (-318)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-318)) (-5 *2 (-143)))) ((*1 *1 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-631 *3)) (-4 *3 (-869)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-143)) (-5 *3 (-658 *5)) (-5 *4 (-790)) (-4 *5 (-869)) (-5 *1 (-631 *5))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-299 *2)) (-4 *2 (-1225)) (-4 *2 (-1119)))) ((*1 *1 *1) (-12 (-4 *1 (-711 *2)) (-4 *2 (-1119))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-877))) (-5 *1 (-877)))) ((*1 *1 *1 *1) (-5 *1 (-877)))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-706 *3)) (-4 *3 (-1075)) (-5 *1 (-707 *3))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-420)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1173))) (-5 *1 (-1206))))) 
+(((*1 *1 *1) (-4 *1 (-644))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-645 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030) (-1211)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1142 (-592) (-631 (-53)))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *3 (-1021 *2)) (-4 *4 (-1255 *3)) (-4 *2 (-323)) (-5 *1 (-439 *2 *3 *4 *5)) (-4 *5 (-13 (-435 *3 *4) (-1065 *3))))) ((*1 *2 *1) (-12 (-4 *3 (-582)) (-4 *3 (-869)) (-5 *2 (-1142 *3 (-631 *1))) (-4 *1 (-456 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1142 (-592) (-631 (-528)))) (-5 *1 (-528)))) ((*1 *2 *1) (-12 (-4 *4 (-194)) (-4 *2 (|SubsetCategory| (-743) *4)) (-5 *1 (-637 *3 *4 *2)) (-4 *3 (-43 *4)))) ((*1 *2 *1) (-12 (-4 *4 (-194)) (-4 *2 (|SubsetCategory| (-743) *4)) (-5 *1 (-676 *3 *4 *2)) (-4 *3 (-734 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-405)) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-405)) (-5 *1 (-278))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-944)) (-5 *2 (-141)) (-5 *1 (-255 *4)) (-4 *4 (-1075))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3548 (-804 *3)) (|:| |coef2| (-804 *3)))) (-5 *1 (-804 *3)) (-4 *3 (-582)) (-4 *3 (-1075)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-582)) (-4 *3 (-1075)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *2 (-2 (|:| -3548 *1) (|:| |coef2| *1))) (-4 *1 (-1089 *3 *4 *5))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 (-2 (|:| |lcmfij| *3) (|:| |totdeg| (-790)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *3 (-815)) (-4 *6 (-977 *4 *3 *5)) (-4 *4 (-477)) (-4 *5 (-869)) (-5 *1 (-474 *4 *3 *5 *6))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-388)) (-14 *5 (-658 (-1191))) (-4 *7 (-252 (-1699 *5) (-790))) (-5 *2 (-658 (-658 (-1187 (-1187 *4))))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-5 *3 (-658 (-1187 (-1187 *4)))) (-4 *6 (-977 *4 *7 (-879 *5))) (-4 *8 (-999 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-1171 (-980 *4)) (-1171 (-980 *4)))) (-5 *1 (-1288 *4)) (-4 *4 (-388))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *8 (-999 *5)) (-4 *4 (-947 *5 *2)) (-4 *9 (-257 *4)) (-4 *10 (-560 *5 *6 *3 *7 *8 *2 *4 *9 *12)) (-4 *12 (-137)) (-4 *2 (-665 *5)) (-5 *1 (-491 *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (-4 *11 (-280 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-264 *6 *5)) (-5 *4 (-949 *5)) (-4 *5 (-373)) (-14 *6 (-658 (-1191))) (-5 *2 (-801 (-884 *5))) (-5 *1 (-894 *5 *6 *7)) (-4 *7 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-264 *6 *5)) (-5 *4 (-948 *5)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-5 *2 (-801 *5)) (-5 *1 (-895 *5 *6 *7)) (-4 *7 (-137)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 *2)) (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *2 (-665 *5)) (-5 *1 (-898 *5 *6 *3 *7 *8 *2 *9)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)) (-4 *9 (-947 *5 *2)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *2 (-665 *5)) (-5 *1 (-898 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)) (-4 *4 (-947 *5 *2)))) ((*1 *2 *3 *3 *4) (-12 (-4 *5 (-388)) (-14 *6 (-658 (-1191))) (-4 *7 (-252 (-1699 *6) (-790))) (-4 *2 (-665 *5)) (-5 *1 (-898 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-977 *5 *7 (-879 *6))) (-4 *8 (-999 *5)) (-4 *4 (-947 *5 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-592)) (-4 *6 (-388)) (-14 *7 (-658 (-1191))) (-4 *8 (-252 (-1699 *7) (-790))) (-4 *2 (-665 *6)) (-5 *1 (-898 *6 *7 *3 *8 *9 *2 *4)) (-4 *3 (-977 *6 *8 (-879 *7))) (-4 *9 (-999 *6)) (-4 *4 (-947 *6 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1142 (-592) (-631 (-53)))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *3 (-323)) (-4 *4 (-1021 *3)) (-4 *5 (-1255 *4)) (-5 *2 (-1280 *6)) (-5 *1 (-439 *3 *4 *5 *6)) (-4 *6 (-13 (-435 *4 *5) (-1065 *4))))) ((*1 *2 *1) (-12 (-4 *3 (-1075)) (-4 *3 (-869)) (-5 *2 (-1142 *3 (-631 *1))) (-4 *1 (-456 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1142 (-592) (-631 (-528)))) (-5 *1 (-528)))) ((*1 *2 *1) (-12 (-4 *3 (-194)) (-4 *2 (-43 *3)) (-5 *1 (-637 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-743) *3)))) ((*1 *2 *1) (-12 (-4 *3 (-194)) (-4 *2 (-734 *3)) (-5 *1 (-676 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-743) *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1021 *2)) (-4 *2 (-582))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-533 *2)) (-14 *2 (-592)))) ((*1 *1 *1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1075)) (-4 *5 (-815)) (-4 *3 (-869)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-977 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1075)) (-5 *2 (-2 (|:| -2230 *1) (|:| -3027 *1))) (-4 *1 (-1255 *3))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1190)) (-5 *1 (-350))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1241 *3 *2)) (-4 *3 (-1075)) (-4 *2 (-1270 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *3 (-658 (-278))) (-5 *1 (-276)))) ((*1 *1 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-278)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-497)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-1113 (-405)))) (-5 *1 (-497))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-890 *3)) (-5 *2 (-592)))) ((*1 *1 *1) (-4 *1 (-1030))) ((*1 *1 *2) (-12 (-5 *2 (-592)) (-4 *1 (-1040)))) ((*1 *1 *2) (-12 (-5 *2 (-433 (-592))) (-4 *1 (-1040)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1040)) (-5 *2 (-790)))) ((*1 *1 *1) (-4 *1 (-1040)))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-658 (-980 *4))) (-5 *3 (-658 (-1191))) (-4 *4 (-477)) (-5 *1 (-941 *4))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1171 *4)) (-5 *3 (-1 (-658 *4) *4)) (-4 *4 (-1225)) (-5 *1 (-1167 *4))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1187 *3)) (-4 *3 (-373)) (-5 *1 (-381 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1094 *4 *5 *6 *3)) (-4 *4 (-477)) (-4 *5 (-815)) (-4 *6 (-869)) (-4 *3 (-1089 *4 *5 *6)) (-5 *2 (-141))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-896)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944)) (-5 *4 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1281)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2) (-12 (-4 *2 (-13 (-456 *3) (-1030))) (-5 *1 (-294 *3 *2)) (-4 *3 (-13 (-869) (-582))))) ((*1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *1) (-5 *1 (-513))) ((*1 *1) (-4 *1 (-1211)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-869)) (-5 *2 (-2 (|:| |f1| (-658 *4)) (|:| |f2| (-658 (-658 (-658 *4)))) (|:| |f3| (-658 (-658 *4))) (|:| |f4| (-658 (-658 (-658 *4)))))) (-5 *1 (-1197 *4)) (-5 *3 (-658 (-658 (-658 *4))))))) 
+(((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *2 (-658 (-986 (-237)))) (-5 *1 (-135)) (-5 *4 (-986 (-237)))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-858)) (-5 *3 (-2 (|:| |fn| (-332 (-237))) (|:| -3703 (-658 (-237))) (|:| |lb| (-658 (-862 (-237)))) (|:| |cf| (-658 (-332 (-237)))) (|:| |ub| (-658 (-862 (-237)))))) (-5 *2 (-1063)))) ((*1 *2 *3) (-12 (-4 *1 (-858)) (-5 *3 (-2 (|:| |lfn| (-658 (-332 (-237)))) (|:| -3703 (-658 (-237))))) (-5 *2 (-1063))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-392 *2)) (-4 *2 (-194))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 (-592))) (-5 *1 (-55 *3 *4)) (-4 *3 (-1075)) (-14 *4 (-658 (-1191))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1270 *3)) (-5 *1 (-296 *3 *4 *2)) (-4 *2 (-1241 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-433 (-592)))) (-4 *4 (-1239 *3)) (-5 *1 (-297 *3 *4 *2 *5)) (-4 *2 (-1262 *3 *4)) (-4 *5 (-1012 *4)))) ((*1 *1 *1) (-4 *1 (-301))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *1 *2) (-12 (-5 *2 (-681 *3 *4)) (-4 *3 (-869)) (-4 *4 (-13 (-194) (-734 (-433 (-592))))) (-5 *1 (-642 *3 *4 *5)) (-14 *5 (-944)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1176 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-43 (-433 (-592)))) (-5 *1 (-1177 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-790)) (-4 *4 (-13 (-1075) (-734 (-433 (-592))))) (-4 *5 (-869)) (-5 *1 (-1294 *4 *5 *2)) (-4 *2 (-1299 *5 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-1298 *3 *4)) (-4 *4 (-734 (-433 (-592)))) (-4 *3 (-869)) (-4 *4 (-194))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-405) (-405))) (-5 *4 (-405)) (-5 *2 (-2 (|:| -2324 *4) (|:| -1615 *4) (|:| |totalpts| (-592)) (|:| |success| (-141)))) (-5 *1 (-811)) (-5 *5 (-592))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-293))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-592)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1225)) (-4 *4 (-399 *2)) (-4 *5 (-399 *2)))) ((*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-305 *3 *2)) (-4 *3 (-1119)) (-4 *2 (-1225))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-977 *3 *4 *5)) (-4 *3 (-477)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-474 *3 *4 *5 *6))))) 
+(((*1 *1 *1) (-5 *1 (-141))) ((*1 *1 *1) (-4 *1 (-153))) ((*1 *1 *1 *2) (-12 (-4 *1 (-260)) (-5 *2 (-592)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-502)) (-5 *2 (-592)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-743)) (-5 *2 (-790)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-944)) (-5 *1 (-1106 *3)) (-4 *3 (-13 (-869) (-582))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1131)) (-5 *2 (-944))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $))))))))) ((*1 *2 *2 *2) (-12 (-4 *3 (-582)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *3 (-631 $)) $)) (-15 -1456 ((-1142 *3 (-631 $)) $)) (-15 -1683 ($ (-1142 *3 (-631 $))))))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-658 *2)) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *4 (-631 $)) $)) (-15 -1456 ((-1142 *4 (-631 $)) $)) (-15 -1683 ($ (-1142 *4 (-631 $))))))) (-4 *4 (-582)) (-5 *1 (-46 *4 *2)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-658 (-631 *2))) (-4 *2 (-13 (-388) (-318) (-10 -8 (-15 -1448 ((-1142 *4 (-631 $)) $)) (-15 -1456 ((-1142 *4 (-631 $)) $)) (-15 -1683 ($ (-1142 *4 (-631 $))))))) (-4 *4 (-582)) (-5 *1 (-46 *4 *2))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-533 *2)) (-14 *2 (-592)))) ((*1 *1 *1) (-5 *1 (-1137)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194))))) 
+(((*1 *1) (-5 *1 (-179)))) 
+(((*1 *1 *1 *1) (-5 *1 (-141))) ((*1 *1 *1 *1) (-4 *1 (-153)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1285)) (-5 *1 (-844))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-790)) (-4 *3 (-1075)) (-4 *1 (-704 *3 *4 *5)) (-4 *4 (-399 *3)) (-4 *5 (-399 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1278 *3)) (-4 *3 (-23)) (-4 *3 (-1225))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-931)) (-5 *2 (-444 (-1187 *1))) (-5 *3 (-1187 *1))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-141)) (-4 *5 (-13 (-388) (-867))) (-5 *2 (-658 (-2 (|:| -2033 (-658 *3)) (|:| -1615 *5)))) (-5 *1 (-200 *5 *3)) (-4 *3 (-1255 (-191 *5))))) ((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-388) (-867))) (-5 *2 (-658 (-2 (|:| -2033 (-658 *3)) (|:| -1615 *4)))) (-5 *1 (-200 *4 *3)) (-4 *3 (-1255 (-191 *4)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-983)) (-5 *2 (-1113 (-237))))) ((*1 *2 *1) (-12 (-4 *1 (-1003)) (-5 *2 (-1113 (-237)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-658 (-237)))) (-5 *1 (-953))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-790)) (-5 *1 (-610 *2)) (-4 *2 (-574)))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| -4226 *3) (|:| -3215 (-790)))) (-5 *1 (-610 *3)) (-4 *3 (-574))))) 
+(((*1 *1 *2 *2 *1) (-12 (-5 *1 (-660 *2)) (-4 *2 (-1119))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-489))) (-5 *2 (-141)) (-5 *1 (-488)))) ((*1 *1 *2) (-12 (-5 *2 (-141)) (-5 *1 (-489))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -1961 (-433 (-592))) (|:| -1954 (-433 (-592))))) (-5 *2 (-433 (-592))) (-5 *1 (-1047 *4)) (-4 *4 (-1255 (-592)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-658 (-980 (-592)))) (-5 *1 (-463)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-706 (-237))) (-5 *2 (-1123)) (-5 *1 (-778)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-5 *4 (-706 (-592))) (-5 *2 (-1123)) (-5 *1 (-778))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-869)) (-5 *2 (-1198 (-658 *4))) (-5 *1 (-1197 *4)) (-5 *3 (-658 *4))))) 
+(((*1 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-394)))) ((*1 *2) (-12 (-5 *2 (-1280 (-1120 *3 *4))) (-5 *1 (-1120 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-592)) (-5 *2 (-658 (-2 (|:| -4500 *3) (|:| -4525 *4)))) (-5 *1 (-712 *3)) (-4 *3 (-1255 *4))))) 
+(((*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1225)) (-5 *2 (-790)) (-5 *1 (-251 *3 *4 *5)) (-4 *3 (-252 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-342 *3 *4)) (-4 *3 (-1119)) (-4 *4 (-158)) (-5 *2 (-790)))) ((*1 *2) (-12 (-4 *4 (-388)) (-5 *2 (-790)) (-5 *1 (-348 *3 *4)) (-4 *3 (-349 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-386 *3)) (-4 *3 (-1119)))) ((*1 *2) (-12 (-4 *1 (-394)) (-5 *2 (-790)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-412 *3)) (-4 *3 (-1119)))) ((*1 *2) (-12 (-4 *4 (-1119)) (-5 *2 (-790)) (-5 *1 (-450 *3 *4)) (-4 *3 (-451 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-662 *3 *4 *5)) (-4 *3 (-1119)) (-4 *4 (-23)) (-14 *5 *4))) ((*1 *2) (-12 (-4 *4 (-194)) (-4 *5 (-1255 *4)) (-5 *2 (-790)) (-5 *1 (-740 *3 *4 *5)) (-4 *3 (-741 *4 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-790)) (-5 *1 (-841 *3)) (-4 *3 (-869)))) ((*1 *2) (-12 (-5 *2 (-592)) (-5 *1 (-1034)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-867) (-388))) (-5 *1 (-1085 *2 *3)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1121 *3)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) ((*1 *2 *1) (-12 (-5 *2 (-1121 *3)) (-5 *1 (-927 *3)) (-4 *3 (-1119))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1151 *3)) (-4 *3 (-1075)) (-5 *2 (-658 (-658 (-658 (-971 *3)))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-141))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-268 *4 *3 *5 *6)) (-4 *4 (-1075)) (-4 *3 (-869)) (-4 *5 (-284 *3)) (-4 *6 (-815)) (-5 *2 (-658 (-790))))) ((*1 *2 *1) (-12 (-4 *1 (-268 *3 *4 *5 *6)) (-4 *3 (-1075)) (-4 *4 (-869)) (-4 *5 (-284 *4)) (-4 *6 (-815)) (-5 *2 (-658 (-790)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3 *2 *4 *5 *6)) (-4 *3 (-1119)) (-4 *4 (-1119)) (-4 *5 (-1119)) (-4 *6 (-1119)) (-4 *2 (-1119))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1119)) (-4 *2 (-1225))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1187 *7)) (-5 *3 (-592)) (-4 *7 (-977 *6 *4 *5)) (-4 *4 (-815)) (-4 *5 (-869)) (-4 *6 (-1075)) (-5 *1 (-340 *4 *5 *6 *7))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-658 *3)) (-4 *3 (-1119)) (-5 *1 (-927 *3))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-400 *3 *4)) (-4 *3 (-869)) (-4 *4 (-194)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1299 *3 *4)) (-4 *3 (-869)) (-4 *4 (-1075))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-944)) (-5 *1 (-808))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-188 *2)) (-4 *2 (-194)) (-4 *2 (-1084)))) ((*1 *1 *1) (-12 (-5 *1 (-359 *2 *3 *4)) (-14 *2 (-658 (-1191))) (-14 *3 (-658 (-1191))) (-4 *4 (-413)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-457 *3 *2)) (-4 *2 (-456 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-819 *2)) (-4 *2 (-194)) (-4 *2 (-1084)))) ((*1 *1 *1) (-4 *1 (-867))) ((*1 *2 *1) (-12 (-4 *1 (-1025 *2)) (-4 *2 (-194)) (-4 *2 (-1084)))) ((*1 *1 *1) (-4 *1 (-1084))) ((*1 *1 *1) (-4 *1 (-1153)))) 
+(((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-1137)) (-5 *4 (-986 (-237))) (-5 *2 (-237)) (-5 *1 (-135))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-415)) (-5 *2 (-141))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |llcmres| *1) (|:| |coeff1| *1) (|:| |coeff2| *1))) (-4 *1 (-678))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 (-141) *9)) (-5 *5 (-1 (-141) *9 *9)) (-4 *9 (-1089 *6 *7 *8)) (-4 *6 (-582)) (-4 *7 (-815)) (-4 *8 (-869)) (-5 *2 (-2 (|:| |bas| *1) (|:| -3349 (-658 *9)))) (-5 *3 (-658 *9)) (-4 *1 (-1219 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1 (-141) *8 *8)) (-4 *8 (-1089 *5 *6 *7)) (-4 *5 (-582)) (-4 *6 (-815)) (-4 *7 (-869)) (-5 *2 (-2 (|:| |bas| *1) (|:| -3349 (-658 *8)))) (-5 *3 (-658 *8)) (-4 *1 (-1219 *5 *6 *7 *8))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1119)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-57)) (-5 *1 (-851))))) 
+(((*1 *1 *1) (-5 *1 (-1087)))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-433 (-980 *3))) (-5 *1 (-478 *3 *4 *5 *6)) (-4 *3 (-582)) (-4 *3 (-194)) (-14 *4 (-944)) (-14 *5 (-658 (-1191))) (-14 *6 (-1280 (-706 *3)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1187 (-592))) (-5 *1 (-970)) (-5 *3 (-592))))) 
+(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-388)) (-5 *1 (-918 *2 *3)) (-4 *2 (-1255 *3))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1119)) (-4 *2 (-1225))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-388))))) 
+(((*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-388) (-171) (-1065 (-592)))) (-4 *5 (-1255 *4)) (-5 *2 (-658 (-433 *5))) (-5 *1 (-1044 *4 *5)) (-5 *3 (-433 *5))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-592))) (-4 *3 (-1075)) (-5 *1 (-617 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-592))) (-4 *1 (-1239 *3)) (-4 *3 (-1075)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-592))) (-4 *1 (-1270 *3)) (-4 *3 (-1075))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-141) *4 *4)) (-4 *4 (-1225)) (-5 *1 (-1149 *4 *2)) (-4 *2 (-13 (-625 (-592) *4) (-10 -7 (-6 -4625) (-6 -4626)))))) ((*1 *2 *2) (-12 (-4 *3 (-869)) (-4 *3 (-1225)) (-5 *1 (-1149 *3 *2)) (-4 *2 (-13 (-625 (-592) *3) (-10 -7 (-6 -4625) (-6 -4626))))))) 
+(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-904 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-399 *2)) (-4 *2 (-1225)))) ((*1 *2 *2) (-12 (-4 *3 (-1075)) (-5 *1 (-469 *3 *2)) (-4 *2 (-1255 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-662 *2 *3 *4)) (-4 *2 (-1119)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1187 *4)) (-4 *4 (-373)) (-5 *2 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-5 *1 (-370 *4))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-1119)) (-4 *3 (-922 *5)) (-5 *2 (-1280 *3)) (-5 *1 (-708 *5 *3 *6 *4)) (-4 *6 (-399 *3)) (-4 *4 (-13 (-399 *5) (-10 -7 (-6 -4625))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-790)) (-5 *2 (-1 (-405))) (-5 *1 (-1067))))) 
+(((*1 *1 *1 *2) (|partial| -12 (-5 *2 (-944)) (-5 *1 (-1120 *3 *4)) (-14 *3 *2) (-14 *4 *2)))) 
+(((*1 *1 *1) (-12 (-4 *2 (-477)) (-4 *3 (-869)) (-4 *4 (-815)) (-5 *1 (-1016 *2 *3 *4 *5)) (-4 *5 (-977 *2 *4 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283)))) ((*1 *2 *2) (-12 (-5 *2 (-896)) (-5 *1 (-1283))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-693 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-5 *1 (-841 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (-12 (-5 *1 (-915 *2)) (-4 *2 (-869)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-1219 *2 *3 *4 *5)) (-4 *2 (-582)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *5 (-1089 *2 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-790)) (-4 *1 (-1267 *3)) (-4 *3 (-1225)))) ((*1 *1 *1) (-12 (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *1 (-900 *2)) (-4 *2 (-1225)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *1 (-902 *2)) (-4 *2 (-1225)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-5 *1 (-904 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *1 (-294 *3 *2)) (-4 *2 (-13 (-456 *3) (-1030)))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *4 (-388)) (-5 *2 (-658 *1)) (-4 *1 (-37 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-388)) (-5 *2 (-658 *1)) (-4 *1 (-37 *3)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-925 *3)) (-4 *3 (-1119)) (-5 *2 (-1121 *3)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1119)) (-5 *2 (-1121 (-658 *4))) (-5 *1 (-926 *4)) (-5 *3 (-658 *4)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1119)) (-5 *2 (-1121 (-1121 *4))) (-5 *1 (-926 *4)) (-5 *3 (-1121 *4)))) ((*1 *2 *1 *3) (-12 (-5 *2 (-1121 *3)) (-5 *1 (-926 *3)) (-4 *3 (-1119)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-790)) (-4 *4 (-388)) (-5 *2 (-658 *1)) (-4 *1 (-999 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-388)) (-5 *2 (-658 *1)) (-4 *1 (-999 *3))))) 
+(((*1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-665 *3)) (-5 *2 (-658 *1)) (-4 *1 (-947 *3 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-914 *3)) (-4 *3 (-1119))))) 
+(((*1 *1 *1) (-12 (|has| *1 (-6 -4625)) (-4 *1 (-175 *2)) (-4 *2 (-1225)) (-4 *2 (-1119))))) 
+(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1191)) (-4 *5 (-13 (-582) (-1065 (-592)) (-171))) (-5 *2 (-2 (|:| -3191 (-433 (-980 *5))) (|:| |coeff| (-433 (-980 *5))))) (-5 *1 (-598 *5)) (-5 *3 (-433 (-980 *5)))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-1229)) (-5 *4 (-592)) (-5 *2 (-1285)) (-5 *1 (-982))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-141)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592))))) ((*1 *2 *3 *2) (-12 (-5 *2 (-141)) (-5 *1 (-149 *3)) (-4 *3 (-1255 (-592)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-444 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1255 (-53))))) ((*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |less| (-151 *3)) (|:| |greater| (-151 *3)))) (-5 *1 (-151 *3)) (-4 *3 (-869)))) ((*1 *2 *1) (-12 (-4 *3 (-1119)) (-5 *2 (-658 *1)) (-4 *1 (-257 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-609 *4)) (-4 *4 (-13 (-29 *3) (-1211))) (-4 *3 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *1 (-607 *3 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-609 (-433 (-980 *3)))) (-4 *3 (-13 (-477) (-1065 (-592)) (-869) (-654 (-592)))) (-5 *1 (-612 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1255 *5)) (-4 *5 (-388)) (-5 *2 (-2 (|:| -1947 *3) (|:| |special| *3))) (-5 *1 (-744 *5 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1280 *5)) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-658 (-658 (-706 *5)))) (-5 *1 (-1057 *5)) (-5 *3 (-658 (-706 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1280 (-1280 *5))) (-4 *5 (-388)) (-4 *5 (-1075)) (-5 *2 (-658 (-658 (-706 *5)))) (-5 *1 (-1057 *5)) (-5 *3 (-658 (-706 *5))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-163)) (-5 *2 (-658 *1)) (-4 *1 (-1158)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-168)) (-5 *2 (-658 *1)) (-4 *1 (-1158))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-332 (-405))) (-5 *2 (-332 (-237))) (-5 *1 (-321))))) 
+(((*1 *1) (-5 *1 (-168)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-582) (-171))) (-5 *1 (-566 *3 *2)) (-4 *2 (-1270 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-4 *4 (-1255 *3)) (-4 *5 (-741 *3 *4)) (-5 *1 (-570 *3 *4 *5 *2)) (-4 *2 (-1270 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-388) (-394) (-633 (-592)))) (-5 *1 (-571 *3 *2)) (-4 *2 (-1270 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1171 *3)) (-4 *3 (-13 (-582) (-171))) (-5 *1 (-1166 *3))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-658 (-592))))) ((*1 *2 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-658 (-592)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1280 (-658 (-2 (|:| -2324 *4) (|:| -1825 (-1137)))))) (-4 *4 (-373)) (-5 *2 (-790)) (-5 *1 (-370 *4)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-375 *3 *4)) (-14 *3 (-944)) (-14 *4 (-944)))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-376 *3 *4)) (-4 *3 (-373)) (-14 *4 (-3 (-1187 *3) (-1280 (-658 (-2 (|:| -2324 *3) (|:| -1825 (-1137))))))))) ((*1 *2) (-12 (-5 *2 (-790)) (-5 *1 (-377 *3 *4)) (-4 *3 (-373)) (-14 *4 (-944))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-497)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1281)))) ((*1 *2 *1) (-12 (-5 *2 (-592)) (-5 *1 (-1282))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-1012 *2)) (-4 *2 (-1211))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-148 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-869)) (-5 *2 (-658 (-658 (-658 *4)))) (-5 *1 (-1197 *4)) (-5 *3 (-658 (-658 *4)))))) 
+(((*1 *2) (-12 (-4 *1 (-362 *3 *4 *5)) (-4 *3 (-1235)) (-4 *4 (-1255 *3)) (-4 *5 (-1255 (-433 *4))) (-5 *2 (-706 (-433 *4)))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-141)) (-5 *1 (-143))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-658 *6)) (-4 *6 (-1089 *3 *4 *5)) (-4 *3 (-477)) (-4 *3 (-582)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-1006 *3 *4 *5 *6))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-670 *2)) (-4 *2 (-1075)) (-4 *2 (-388)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-388)) (-5 *1 (-673 *4 *2)) (-4 *2 (-670 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1089 *2 *3 *4)) (-4 *2 (-1075)) (-4 *3 (-815)) (-4 *4 (-869)) (-4 *2 (-582))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-460))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-658 (-1191))) (-5 *2 (-1285)) (-5 *1 (-1194)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-658 (-1191))) (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194)))) ((*1 *2 *3 *4 *1) (-12 (-5 *4 (-658 (-1191))) (-5 *3 (-1191)) (-5 *2 (-1285)) (-5 *1 (-1194))))) 
+(((*1 *1) (-5 *1 (-825)))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1171 (-658 (-592)))) (-5 *1 (-905)) (-5 *3 (-658 (-592)))))) 
+(((*1 *1 *1) (-12 (|has| *1 (-6 -4626)) (-4 *1 (-1267 *2)) (-4 *2 (-1225))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *3 (-658 (-2 (|:| |scalar| (-433 (-592))) (|:| |coeff| (-1187 *2)) (|:| |logand| (-1187 *2))))) (-5 *4 (-658 (-2 (|:| |integrand| *2) (|:| |intvar| *2)))) (-4 *2 (-388)) (-5 *1 (-609 *2))))) 
+(((*1 *2 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-388) (-10 -8 (-15 ** ($ $ (-433 (-592))))))) (-5 *1 (-1145 *3 *2)) (-4 *3 (-1255 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1173)) (-5 *2 (-1285)) (-5 *1 (-462))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-683 *2)) (-4 *2 (-1225)))) ((*1 *2 *1) (-12 (-4 *1 (-999 *3)) (-4 *3 (-388)) (-5 *2 (-658 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-658 (-1191))) (-5 *1 (-1191))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1140 *3 *4 *2 *5)) (-4 *4 (-1075)) (-4 *5 (-252 *3 *4)) (-4 *2 (-252 *3 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-405)) (-5 *2 (-1285)) (-5 *1 (-1282))))) 
+(((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-896)) (-5 *5 (-944)) (-5 *6 (-658 (-278))) (-5 *2 (-497)) (-5 *1 (-1284)))) ((*1 *2 *3) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *2 (-497)) (-5 *1 (-1284)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-658 (-658 (-971 (-237))))) (-5 *4 (-658 (-278))) (-5 *2 (-497)) (-5 *1 (-1284))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *3 (-658 *6)) (-4 *6 (-869)) (-4 *4 (-388)) (-4 *5 (-815)) (-5 *1 (-538 *4 *5 *6 *2)) (-4 *2 (-977 *4 *5 *6)))) ((*1 *1 *1 *2) (-12 (-4 *3 (-388)) (-4 *4 (-815)) (-4 *5 (-869)) (-5 *1 (-538 *3 *4 *5 *2)) (-4 *2 (-977 *3 *4 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-37 *3)) (-4 *3 (-388)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-658 *1)) (-5 *3 (-790)) (-4 *1 (-37 *4)) (-4 *4 (-388)))) ((*1 *2 *2) (-12 (-5 *2 (-658 *1)) (-4 *1 (-999 *3)) (-4 *3 (-388)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-658 *1)) (-5 *3 (-790)) (-4 *1 (-999 *4)) (-4 *4 (-388))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1191)) (-4 *5 (-388)) (-5 *2 (-1171 (-1171 (-980 *5)))) (-5 *1 (-1288 *5)) (-5 *4 (-1171 (-980 *5)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-706 *5)) (-4 *5 (-1075)) (-5 *1 (-1079 *3 *4 *5)) (-14 *3 (-790)) (-14 *4 (-790))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-658 (-1191))) (-5 *3 (-1191)) (-5 *1 (-565)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-721 *3)) (-4 *3 (-633 (-565))))) ((*1 *2 *3 *2 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-721 *3)) (-4 *3 (-633 (-565))))) ((*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-1191)) (-5 *1 (-721 *3)) (-4 *3 (-633 (-565))))) ((*1 *2 *3 *2 *4) (-12 (-5 *4 (-658 (-1191))) (-5 *2 (-1191)) (-5 *1 (-721 *3)) (-4 *3 (-633 (-565)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-579 *3)) (-4 *3 (-13 (-430) (-1211))) (-5 *2 (-141)))) ((*1 *2 *1) (-12 (-4 *1 (-867)) (-5 *2 (-141)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1091 *4 *3)) (-4 *4 (-13 (-867) (-388))) (-4 *3 (-1255 *4)) (-5 *2 (-141))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-690 *3)) (-4 *3 (-1225)) (-5 *2 (-141))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-582)) (-5 *2 (-658 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-443 *4))))) 
+(((*1 *2 *2 *2 *3 *3) (-12 (-5 *2 (-1229)) (-5 *3 (-592)) (-5 *1 (-982))))) 
+(((*1 *1 *1) (-5 *1 (-1087)))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-318)) (-5 *3 (-1191)) (-5 *2 (-141)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-318)) (-5 *2 (-141)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-150)) (-5 *2 (-141)) (-5 *1 (-1106 *4)) (-4 *4 (-13 (-869) (-582)))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-658 *2)) (-4 *2 (-1225))))) 
+(((*1 *2 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1255 *5)) (-4 *5 (-13 (-388) (-171) (-1065 (-592)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-433 *6)) (|:| |c| (-433 *6)) (|:| -4132 *6))) (-5 *1 (-1043 *5 *6)) (-5 *3 (-433 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1187 *1)) (-5 *4 (-1191)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1187 *1)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-980 *1)) (-4 *1 (-27)) (-5 *2 (-658 *1)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1191)) (-4 *4 (-13 (-869) (-582))) (-5 *2 (-658 *1)) (-4 *1 (-29 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-13 (-869) (-582))) (-5 *2 (-658 *1)) (-4 *1 (-29 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-141)) (-5 *1 (-846))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-617 *2)) (-4 *2 (-43 (-433 (-592)))) (-4 *2 (-1075))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-582)) (-5 *2 (-141))))) 
+(((*1 *2 *1 *2 *3) (|partial| -12 (-5 *2 (-1173)) (-5 *3 (-592)) (-5 *1 (-1087))))) 
+((-1312 . 843298) (-1313 . 843246) (-1314 . 843162) (-1315 . 843110) (-1316 . 842696) (-1317 . 842456) (-1318 . 842397) (-1319 . 842175) (-1320 . 842143) (-1321 . 842066) (-1322 . 841973) (-1323 . 841902) (-1324 . 841663) (-1325 . 841234) (-1326 . 841121) (-1327 . 840986) (-1328 . 840669) (-1329 . 840409) (-1330 . 840059) (-1331 . 839987) (-1332 . 839879) (-1333 . 839626) (-1334 . 839557) (-1335 . 839423) (-1336 . 839203) (-1337 . 839124) (-1338 . 839032) (-1339 . 839004) (-1340 . 838738) (-1341 . 838686) (-1342 . 838578) (-1343 . 838406) (-1344 . 838250) (-1345 . 838179) (-1346 . 838050) (-1347 . 837937) (-1348 . 837856) (-1349 . 837789) (-1350 . 837637) (-1351 . 837190) (-1352 . 837012) (-1353 . 836589) (-1354 . 836561) (-1355 . 836480) (-1356 . 835352) (-1357 . 835196) (-1358 . 835016) (-1359 . 834803) (-1360 . 834709) (-1361 . 834638) (-1362 . 834547) (-1363 . 833878) (-1364 . 833775) (-1365 . 833559) (-1366 . 833147) (-1367 . 833047) (-1368 . 832928) (-1369 . 832832) (-1370 . 832759) (-1371 . 832592) (-1372 . 832455) (-1373 . 832239) (-1374 . 832177) (-1375 . 831892) (-1376 . 831650) (-1377 . 831485) (-1378 . 831430) (-1379 . 831355) (-1380 . 831265) (-1381 . 831190) (-1382 . 831016) (-1383 . 830984) (-1384 . 830917) (-1385 . 830842) (-1386 . 830739) (-1387 . 830262) (-1388 . 830184) (-1389 . 830076) (-1390 . 830024) (-1391 . 829922) (-1392 . 829436) (-1393 . 829368) (-1394 . 829187) (-1395 . 829113) (-1396 . 828957) (-1397 . 828882) (-1398 . 828749) (-1399 . 828479) (-1400 . 828427) (-1401 . 828331) (-1402 . 828184) (-1403 . 827226) (-1404 . 827099) (-1405 . 826947) (-1406 . 826847) (-1407 . 826599) (-1408 . 826448) (-1409 . 826325) (-1410 . 826263) (-1411 . 826081) (-1412 . 826015) (-1413 . 825897) (-1414 . 825568) (-1415 . 825501) (-1416 . 825419) (-1417 . 825220) (-1418 . 825167) (-1419 . 825102) (-1420 . 825074) (-1421 . 825004) (-1422 . 824919) (-1423 . 824068) (-1424 . 823716) (-1425 . 823580) (-1426 . 823359) (-1427 . 823256) (-1428 . 823204) (-1429 . 823002) (-1430 . 821851) (-1431 . 821796) (-1432 . 821461) (-1433 . 821345) (-1434 . 821125) (-1435 . 820871) (-1436 . 820623) (-1437 . 820485) (-1438 . 820433) (-1439 . 820349) (-1440 . 820244) (-1441 . 820138) (-1442 . 819756) (-1443 . 819469) (-1444 . 819390) (-1445 . 819334) (-1446 . 819093) (-1447 . 819002) (-1448 . 818328) (-1449 . 816762) (-1450 . 816642) (-1451 . 816395) (-1452 . 816182) (-1453 . 815896) (-1454 . 815807) (-1455 . 815681) (-1456 . 815027) (-1457 . 814888) (-1458 . 814764) (-1459 . 814684) (-1460 . 814594) (-1461 . 814469) (-1462 . 814170) (-1463 . 814031) (-1464 . 813933) (-1465 . 813778) (-1466 . 813705) (-1467 . 813630) (-1468 . 813529) (-1469 . 813331) (-1470 . 813179) (-1471 . 813043) (-1472 . 809177) (-1473 . 808541) (-1474 . 808318) (-1475 . 808281) (-1476 . 808117) (-1477 . 808033) (-1478 . 805798) (-1479 . 805446) (-1480 . 805195) (-1481 . 804622) (-1482 . 803948) (-1483 . 803736) (-1484 . 803665) (-1485 . 803584) (-1486 . 803445) (-1487 . 803104) (-1488 . 802490) (-1489 . 801371) (-1490 . 801149) (-1491 . 801044) (-1492 . 800856) (-1493 . 800594) (-1494 . 800402) (-1495 . 799696) (-1496 . 799361) (-1497 . 798857) (-1498 . 798782) (-1499 . 798590) (-1500 . 794666) (-1501 . 793960) (-1502 . 793874) (-1503 . 793820) (-1504 . 793420) (-1505 . 793195) (-1506 . 793043) (-1507 . 792389) (-1508 . 792296) (-1509 . 792113) (-1510 . 792046) (-1511 . 791863) (-1512 . 791494) (-1513 . 791423) (-1514 . 791356) (-1515 . 790808) (-1516 . 790656) (-1517 . 790528) (-1518 . 790473) (-1519 . 790206) (-1520 . 790035) (-1521 . 789487) (-1522 . 789435) (-1523 . 789306) (-1524 . 789232) (-1525 . 789149) (-1526 . 789056) (-1527 . 788508) (-1528 . 788251) (-1529 . 788100) (-1530 . 787994) (-1531 . 787893) (-1532 . 787691) (-1533 . 787038) (-1534 . 786934) (-1535 . 786818) (-1536 . 786713) (-1537 . 786618) (-1538 . 786250) (-1539 . 786046) (-1540 . 785393) (-1541 . 785338) (-1542 . 785112) (-1543 . 784787) (-1544 . 784346) (-1545 . 784271) (-1546 . 783556) (-1547 . 783522) (-1548 . 783389) (-1549 . 783241) (-1550 . 783001) (-1551 . 782787) (-1552 . 782240) (-1553 . 782159) (-1554 . 781795) (-1555 . 781764) (-1556 . 781656) (-1557 . 781417) (-1558 . 781284) (-1559 . 780737) (-1560 . 780659) (-1561 . 780604) (-1562 . 780491) (-1563 . 780133) (-1564 . 780000) (-1565 . 779867) (-1566 . 779665) (-1567 . 779118) (-1568 . 779065) (-1569 . 778984) (-1570 . 778909) (-1571 . 778799) (-1572 . 778548) (-1573 . 778481) (-1574 . 778383) (-1575 . 777730) (-1576 . 777623) (-1577 . 777485) (-1578 . 777401) (-1579 . 777282) (-1580 . 777207) (-1581 . 776554) (-1582 . 776480) (-1583 . 776452) (-1584 . 776397) (-1585 . 776202) (-1586 . 776106) (-1587 . 775107) (-1588 . 774454) (-1589 . 774382) (-1590 . 774332) (-1591 . 773551) (-1592 . 773517) (-1593 . 773433) (-1594 . 772886) (-1595 . 772212) (-1596 . 772074) (-1597 . 771872) (-1598 . 771772) (-1599 . 771676) (-1600 . 770839) (-1601 . 770292) (-1602 . 770150) (-1603 . 770014) (-1604 . 769943) (-1605 . 769657) (-1606 . 769104) (-1607 . 769051) (-1608 . 768974) (-1609 . 768427) (-1610 . 768303) (-1611 . 768224) (-1612 . 768149) (-1613 . 768005) (-1614 . 767915) (-1615 . 767616) (-1616 . 767550) (-1617 . 767004) (-1618 . 766632) (-1619 . 766540) (-1620 . 766465) (-1621 . 766178) (-1622 . 765922) (-1623 . 765856) (-1624 . 765310) (-1625 . 764809) (-1626 . 764237) (-1627 . 764164) (-1628 . 764080) (-1629 . 763996) (-1630 . 763450) (-1631 . 763361) (-1632 . 763290) (-1633 . 763205) (-1634 . 763086) (-1635 . 762982) (-1636 . 762436) (-1637 . 761661) (-1638 . 761415) (-1639 . 761288) (-1640 . 761232) (-1641 . 760742) (-1642 . 760196) (-1643 . 760019) (-1644 . 759936) (-1645 . 759778) (-1646 . 759214) (-1647 . 758727) (-1648 . 758671) (-1649 . 758538) (-1650 . 758471) (-1651 . 758264) (-1652 . 758162) (-1653 . 758038) (-1654 . 757950) (-1655 . 757736) (-1656 . 757651) (-1657 . 757586) (-1658 . 757438) (-1659 . 757265) (-1660 . 757237) (-1661 . 757127) (-1662 . 757038) (-1663 . 756890) (-1664 . 756771) (-1665 . 756557) (-1666 . 756256) (-1667 . 756203) (-1668 . 756086) (-1669 . 755993) (-1670 . 755965) (-1671 . 755666) (-1672 . 755575) (-1673 . 755279) (-1674 . 755141) (-1675 . 755112) (-1676 . 755081) (-1677 . 754924) (-1678 . 754854) (-1679 . 754742) (-1680 . 754520) (-1681 . 754443) (-1682 . 754392) (-1683 . 730883) (-1684 . 730758) (-1685 . 730423) (-1686 . 730386) (-1687 . 730271) (-1688 . 730082) (-1689 . 729513) (-1690 . 729376) (-1691 . 729137) (-1692 . 729024) (-1693 . 728849) (-1694 . 728774) (-1695 . 728410) (-1696 . 728335) (-1697 . 728183) (-1698 . 728026) (-1699 . 727276) (-1700 . 726968) (-1701 . 726894) (-1702 . 726820) (-1703 . 726696) (-1704 . 726016) (-1705 . 725864) (-1706 . 725796) (-1707 . 725744) (-1708 . 725643) (-1709 . 725417) (-1710 . 725314) (-1711 . 725036) (-1712 . 724898) (-1713 . 724760) (-1714 . 724682) (-1715 . 724500) (-1716 . 724336) (-1717 . 724237) (-1718 . 723832) (-1719 . 723743) (-1720 . 723655) (-1721 . 723155) (-1722 . 722755) (-1723 . 722581) (-1724 . 722172) (-1725 . 722121) (-1726 . 721970) (-1727 . 721936) (-1728 . 721784) (-1729 . 721478) (-1730 . 721363) (-1731 . 721293) (-1732 . 721197) (-1733 . 721107) (-1734 . 721032) (-1735 . 720830) (-1736 . 720262) (-1737 . 720098) (-1738 . 720009) (-1739 . 719935) (-1740 . 719714) (-1741 . 719505) (-1742 . 719339) (-1743 . 719230) (-1744 . 719118) (-1745 . 719063) (-1746 . 718940) (-1747 . 718550) (-1748 . 718065) (-1749 . 717735) (-1750 . 717631) (-1751 . 717415) (-1752 . 716911) (-1753 . 716750) (-1754 . 716718) (-1755 . 716686) (-1756 . 716605) (-1757 . 716502) (-1758 . 716442) (-1759 . 716335) (-1760 . 716147) (-1761 . 715860) (-1762 . 715463) (-1763 . 715313) (-1764 . 714905) (-1765 . 714848) (-1766 . 714796) (-1767 . 714658) (-1768 . 714489) (-1769 . 714420) (-1770 . 714290) (-1771 . 714182) (-1772 . 714088) (-1773 . 714017) (-1774 . 713851) (-1775 . 713711) (-1776 . 713536) (-1777 . 713329) (-1778 . 708870) (-1779 . 707739) (-1780 . 707387) (-1781 . 707310) (-1782 . 707250) (-1783 . 707219) (-1784 . 707134) (-1785 . 707030) (-1786 . 706952) (-1787 . 706807) (-1788 . 706570) (-1789 . 706495) (-1790 . 706343) (-1791 . 706193) (-1792 . 706084) (-1793 . 705940) (-1794 . 705827) (-1795 . 705475) (-1796 . 705394) (-1797 . 705264) (-1798 . 705214) (-1799 . 704950) (-1800 . 704634) (-1801 . 704539) (-1802 . 704374) (-1803 . 704158) (-1804 . 703937) (-1805 . 703804) (-1806 . 702925) (-1807 . 702792) (-1808 . 702706) (-1809 . 696317) (-1810 . 696154) (-1811 . 696099) (-1812 . 695827) (-1813 . 695737) (-1814 . 695532) (-1815 . 695327) (-1816 . 695254) (-1817 . 695185) (-1818 . 695066) (-1819 . 694992) (-1820 . 694536) (-1821 . 694461) (-1822 . 693992) (-1823 . 693916) (-1824 . 693808) (-1825 . 693502) (-1826 . 693473) (-1827 . 693410) (-1828 . 693355) (-1829 . 693119) (-1830 . 693009) (-1831 . 692394) (-1832 . 692301) (-1833 . 692228) (-1834 . 692169) (-1835 . 689732) (-1836 . 689594) (-1837 . 689323) (-1838 . 689253) (-1839 . 689153) (-1840 . 689081) (-1841 . 689004) (-1842 . 688890) (-1843 . 688745) (-1844 . 688472) (-1845 . 688265) (-1846 . 688125) (-1847 . 687985) (-1848 . 687933) (-1849 . 687612) (-1850 . 687520) (-1851 . 687467) (-1852 . 687184) (-1853 . 687131) (-1854 . 687057) (-1855 . 686961) (-1856 . 686858) (-1857 . 686708) (-1858 . 686674) (-1859 . 686339) (-1860 . 686255) (-1861 . 686130) (-1862 . 685971) (-1863 . 685846) (-1864 . 685663) (-1865 . 685529) (-1866 . 685469) (-1867 . 685380) (-1868 . 684866) (-1869 . 684811) (-1870 . 684500) (-1871 . 684387) (-1872 . 684261) (-1873 . 684209) (-1874 . 684016) (-1875 . 683948) (-1876 . 683848) (-1877 . 683656) (-1878 . 683521) (-1879 . 682826) (-1880 . 682692) (-1881 . 682589) (-1882 . 682489) (-1883 . 682290) (-1884 . 681746) (-1885 . 681633) (-1886 . 681443) (-1887 . 681353) (-1888 . 681140) (-1889 . 681064) (-1890 . 680997) (-1891 . 680914) (-1892 . 680717) (-1893 . 680520) (-1894 . 680467) (-1895 . 680414) (-1896 . 680227) (-1897 . 679990) (-1898 . 679755) (-1899 . 679695) (-1900 . 679627) (-1901 . 679554) (-1902 . 679489) (-1903 . 679294) (-1904 . 679242) (-1905 . 679089) (-1906 . 677599) (-1907 . 677506) (-1908 . 677424) (-1909 . 677280) (-1910 . 677161) (-1911 . 677070) (-1912 . 676970) (-1913 . 676904) (-1914 . 676424) (-1915 . 676367) (-1916 . 676271) (-1917 . 676200) (-1918 . 675683) (-1919 . 675610) (-1920 . 675480) (-1921 . 675344) (-1922 . 675187) (-1923 . 675120) (-1924 . 675007) (-1925 . 674944) (-1926 . 672507) (-1927 . 672319) (-1928 . 672220) (-1929 . 671701) (-1930 . 671383) (-1931 . 671279) (-1932 . 671176) (-1933 . 671121) (-1934 . 671022) (-1935 . 670852) (-1936 . 670147) (-1937 . 668526) (-1938 . 668151) (-1939 . 667905) (-1940 . 667109) (-1941 . 667033) (-1942 . 666911) (-1943 . 666723) (-1944 . 666670) (-1945 . 666427) (-1946 . 666288) (-1947 . 666212) (-1948 . 666139) (-1949 . 666049) (-1950 . 665996) (-1951 . 665749) (-1952 . 665683) (-1953 . 665593) (-1954 . 665265) (-1955 . 665197) (-1956 . 665123) (-1957 . 664830) (-1958 . 664714) (-1959 . 664611) (-1960 . 664561) (-1961 . 664233) (-1962 . 664136) (-1963 . 664081) (-1964 . 663359) (-1965 . 663055) (-1966 . 662946) (-1967 . 662854) (-1968 . 662706) (-1969 . 662564) (-1970 . 662509) (-1971 . 662401) (-1972 . 662328) (-1973 . 662226) (-1974 . 662091) (-1975 . 661995) (-1976 . 661671) (-1977 . 661446) (-1978 . 661370) (-1979 . 661133) (-1980 . 661053) (-1981 . 660985) (-1982 . 660929) (-1983 . 660771) (-1984 . 660624) (-1985 . 660590) (-1986 . 658856) (-1987 . 658807) (-1988 . 658725) (-1989 . 658621) (-1990 . 658153) (-1991 . 658069) (-1992 . 657981) (-1993 . 657922) (-1994 . 656492) (-1995 . 656419) (-1996 . 656336) (-1997 . 656249) (-1998 . 656165) (-1999 . 656012) (-2000 . 655771) (-2001 . 654309) (-2002 . 654086) (-2003 . 654034) (-2004 . 653226) (-2005 . 653005) (-2006 . 652914) (-2007 . 652855) (-2008 . 649117) (-2009 . 649034) (-2010 . 648699) (-2011 . 648646) (-2012 . 648243) (-2013 . 648154) (-2014 . 648004) (-2015 . 647646) (-2016 . 647594) (-2017 . 647506) (-2018 . 647319) (-2019 . 646895) (-2020 . 646820) (-2021 . 646625) (-2022 . 646505) (-2023 . 646404) (-2024 . 646260) (-2025 . 646000) (-2026 . 645896) (-2027 . 645391) (-2028 . 645339) (-2029 . 645194) (-2030 . 645076) (-2031 . 645006) (-2032 . 644953) (-2033 . 644524) (-2034 . 644416) (-2035 . 644363) (-2036 . 644308) (-2037 . 644205) (-2038 . 643788) (-2039 . 643688) (-2040 . 643589) (-2041 . 643508) (-2042 . 643357) (-2043 . 643247) (-2044 . 643173) (-2045 . 642738) (-2046 . 642602) (-2047 . 642552) (-2048 . 642480) (-2049 . 642153) (-2050 . 641937) (-2051 . 641649) (-2052 . 641546) (-2053 . 641469) (-2054 . 641174) (-2055 . 641024) (-2056 . 640864) (-2057 . 640814) (-2058 . 640741) (-2059 . 640410) (-2060 . 640321) (-2061 . 639137) (-2062 . 639076) (-2063 . 639009) (-2064 . 638910) (-2065 . 638817) (-2066 . 638698) (-2067 . 638536) (-2068 . 638446) (-2069 . 638382) (-2070 . 638306) (-2071 . 638243) (-2072 . 638152) (-2073 . 637930) (-2074 . 637877) (-2075 . 637793) (-2076 . 637741) (-2077 . 637649) (-2078 . 637518) (-2079 . 637295) (-2080 . 637188) (-2081 . 636833) (-2082 . 636805) (-2083 . 636565) (-2084 . 636450) (-2085 . 636374) (-2086 . 636239) (-2087 . 636140) (-2088 . 635737) (-2089 . 635653) (-2090 . 634256) (-2091 . 634096) (-2092 . 633927) (-2093 . 633733) (-2094 . 633578) (-2095 . 633477) (-2096 . 633341) (-2097 . 633260) (-2098 . 633184) (-2099 . 633081) (-2100 . 633003) (-2101 . 632921) (-2102 . 632706) (-2103 . 632656) (-2104 . 632565) (-2105 . 632324) (-2106 . 632003) (-2107 . 631927) (-2108 . 631718) (-2109 . 631574) (-2110 . 631411) (-2111 . 631304) (-2112 . 630960) (-2113 . 628833) (-2114 . 628576) (-2115 . 627934) (-2116 . 627816) (-2117 . 627470) (-2118 . 627322) (-2119 . 627068) (-2120 . 626706) (-2121 . 626586) (-2122 . 626513) (-2123 . 626441) (-2124 . 626338) (-2125 . 626274) (-2126 . 625775) (-2127 . 625671) (-2128 . 625598) (-2129 . 625306) (-2130 . 625235) (-2131 . 625170) (-2132 . 624968) (-2133 . 624893) (-2134 . 624812) (-2135 . 624597) (-2136 . 624510) (-2137 . 624349) (-2138 . 624098) (-2139 . 623828) (-2140 . 623773) (-2141 . 623236) (-2142 . 623165) (-2143 . 623113) (-2144 . 623010) (-2145 . 622553) (-2146 . 622439) (-2147 . 622389) (-2148 . 622320) (-2149 . 622265) (-2150 . 621952) (-2151 . 621882) (-2152 . 621659) (-2153 . 621592) (-2154 . 621473) (-2155 . 621392) (-2156 . 621169) (-2157 . 620854) (-2158 . 620776) (-2159 . 620511) (-2160 . 620386) (-2161 . 620283) (-2162 . 620109) (-2163 . 619826) (-2164 . 619732) (-2165 . 619670) (-2166 . 619532) (-2167 . 619390) (-2168 . 619316) (-2169 . 619249) (-2170 . 618910) (-2171 . 618778) (-2172 . 618377) (-2173 . 618287) (-2174 . 618089) (-2175 . 617956) (-2176 . 617849) (-2177 . 617735) (-2178 . 617410) (-2179 . 617329) (-2180 . 617238) (-2181 . 616925) (-2182 . 616856) (-2183 . 616782) (-2184 . 616711) (-2185 . 616610) (-2186 . 616492) (-2187 . 616293) (-2188 . 616222) (-2189 . 615859) (-2190 . 615768) (-2191 . 615705) (-2192 . 615580) (-2193 . 615504) (-2194 . 615430) (-2195 . 614605) (-2196 . 614521) (-2197 . 614441) (-2198 . 613948) (-2199 . 613550) (-2200 . 613518) (-2201 . 613446) (-2202 . 613394) (-2203 . 613247) (-2204 . 613213) (-2205 . 613160) (-2206 . 612576) (-2207 . 612425) (-2208 . 612369) (-2209 . 612258) (-2210 . 612092) (-2211 . 612010) (-2212 . 611759) (-2213 . 611680) (-2214 . 611363) (-2215 . 610644) (-2216 . 610540) (-2217 . 610487) (-2218 . 610414) (-2219 . 609993) (-2220 . 609790) (-2221 . 609650) (-2222 . 609341) (-2223 . 609260) (-2224 . 609134) (-2225 . 608177) (-2226 . 608054) (-2227 . 607508) (-2228 . 607398) (-2229 . 607219) (-2230 . 606980) (-2231 . 605846) (-2232 . 605639) (-2233 . 605572) (-2234 . 605517) (-2235 . 605450) (-2236 . 605186) (-2237 . 605134) (-2238 . 605058) (-2239 . 604934) (-2240 . 604830) (-2241 . 604213) (-2242 . 604095) (-2243 . 603928) (-2244 . 603805) (-2245 . 603342) (-2246 . 603268) (-2247 . 603028) (-2248 . 601159) (-2249 . 601068) (-2250 . 600965) (-2251 . 600850) (-2252 . 600758) (-2253 . 600706) (-2254 . 600575) (-2255 . 600451) (-2256 . 600359) (-2257 . 599397) (-2258 . 599346) (-2259 . 599268) (-2260 . 599218) (-2261 . 599128) (-2262 . 599061) (-2263 . 598945) (-2264 . 598804) (-2265 . 598672) (-2266 . 598002) (-2267 . 597844) (-2268 . 597605) (-2269 . 596709) (-2270 . 596034) (-2271 . 595866) (-2272 . 595492) (-2273 . 595316) (-2274 . 595173) (-2275 . 595094) (-2276 . 594980) (-2277 . 594748) (-2278 . 594693) (-2279 . 594502) (-2280 . 594267) (-2281 . 593954) (-2282 . 593713) (-2283 . 593544) (-2284 . 593473) (-2285 . 593379) (-2286 . 593234) (-2287 . 593049) (-2288 . 592869) (-2289 . 592676) (-2290 . 592537) (-2291 . 592485) (-2292 . 592403) (-2293 . 592275) (-2294 . 592022) (-2295 . 591955) (-2296 . 591887) (-2297 . 591735) (-2298 . 591575) (-2299 . 591401) (-2300 . 591301) (-2301 . 591228) (-2302 . 591063) (-2303 . 590652) (-2304 . 590554) (-2305 . 590360) (-2306 . 590175) (-2307 . 590122) (-2308 . 590001) (-2309 . 589812) (-2310 . 589744) (-2311 . 589655) (-2312 . 589199) (-2313 . 589111) (-2314 . 588513) (-2315 . 588415) (-2316 . 588366) (-2317 . 587757) (-2318 . 587657) (-2319 . 587487) (-2320 . 587343) (-2321 . 587257) (-2322 . 587194) (-2323 . 586858) (-2324 . 586604) (-2325 . 586524) (-2326 . 586452) (-2327 . 586370) (-2328 . 586059) (-2329 . 585901) (-2330 . 585827) (-2331 . 585618) (-2332 . 585057) (-2333 . 584828) (-2334 . 584762) (-2335 . 584709) (-2336 . 584639) (-2337 . 584560) (-2338 . 584410) (-2339 . 584258) (-2340 . 584145) (-2341 . 584034) (-2342 . 583816) (-2343 . 583727) (-2344 . 583605) (-2345 . 583538) (-2346 . 583034) (-2347 . 582892) (-2348 . 582520) (-2349 . 582381) (-2350 . 582337) (-2351 . 582249) (-2352 . 581963) (-2353 . 580844) (-2354 . 580404) (-2355 . 580332) (-2356 . 580187) (-2357 . 580118) (-2358 . 580021) (-2359 . 579869) (-2360 . 579796) (-2361 . 579667) (-2362 . 579296) (-2363 . 579225) (-2364 . 579122) (-2365 . 578838) (-2366 . 578674) (-2367 . 578597) (-2368 . 578526) (-2369 . 578469) (-2370 . 578416) (-2371 . 578141) (-2372 . 578008) (-2373 . 577918) (-2374 . 577663) (-2375 . 577395) (-2376 . 577306) (-2377 . 577061) (-2378 . 577009) (-2379 . 576688) (-2380 . 576562) (-2381 . 576452) (-2382 . 576310) (-2383 . 576230) (-2384 . 576108) (-2385 . 576009) (-2386 . 575943) (-2387 . 575827) (-2388 . 575636) (-2389 . 575533) (-2390 . 575174) (-2391 . 575066) (-2392 . 575014) (-2393 . 574943) (-2394 . 574891) (-2395 . 574775) (-2396 . 574682) (-2397 . 574608) (-2398 . 574454) (-2399 . 574397) (-2400 . 569333) (-2401 . 569231) (-2402 . 569178) (-2403 . 567447) (-2404 . 567376) (-2405 . 567301) (-2406 . 567187) (-2407 . 566930) (-2408 . 566855) (-2409 . 566721) (-2410 . 566664) (-2411 . 566478) (-2412 . 566331) (-2413 . 566282) (-2414 . 566230) (-2415 . 566131) (-2416 . 566064) (-2417 . 566012) (-2418 . 565864) (-2419 . 565760) (-2420 . 565625) (-2421 . 565572) (-2422 . 565488) (-2423 . 565352) (-2424 . 565164) (-2425 . 565107) (-2426 . 565007) (-2427 . 564496) (-2428 . 564386) (-2429 . 564294) (-2430 . 564166) (-2431 . 564020) (-2432 . 563961) (-2433 . 563812) (-2434 . 563701) (-2435 . 562769) (-2436 . 562688) (-2437 . 562577) (-2438 . 562267) (-2439 . 562121) (-2440 . 562018) (-2441 . 561605) (-2442 . 561408) (-2443 . 560602) (-2444 . 560504) (-2445 . 560102) (-2446 . 559998) (-2447 . 559575) (-2448 . 559076) (-2449 . 558977) (-2450 . 558687) (-2451 . 558539) (-2452 . 558430) (-2453 . 558326) (-2454 . 558274) (-2455 . 558191) (-2456 . 558087) (-2457 . 557968) (-2458 . 557811) (-2459 . 557711) (-2460 . 557577) (-2461 . 557502) (-2462 . 557371) (-2463 . 556769) (-2464 . 556669) (-2465 . 556566) (-2466 . 556374) (-2467 . 556222) (-2468 . 556020) (-2469 . 555959) (-2470 . 555904) (-2471 . 555852) (-2472 . 554629) (-2473 . 554549) (-2474 . 554359) (-2475 . 554307) (-2476 . 554234) (-2477 . 554155) (-2478 . 554088) (-2479 . 553584) (-2480 . 553531) (-2481 . 553423) (-2482 . 553294) (-2483 . 553037) (-2484 . 552963) (-2485 . 552783) (-2486 . 552567) (-2487 . 552460) (-2488 . 552380) (-2489 . 552280) (-2490 . 552073) (-2491 . 551855) (-2492 . 551653) (-2493 . 551476) (-2494 . 551381) (-2495 . 551216) (-2496 . 551128) (-2497 . 551032) (-2498 . 550847) (-2499 . 550776) (-2500 . 550541) (-2501 . 550452) (-2502 . 550424) (-2503 . 550306) (-2504 . 550129) (-2505 . 550030) (-2506 . 549771) (-2507 . 549594) (-2508 . 549478) (-2509 . 549294) (-2510 . 548947) (-2511 . 548890) (-2512 . 548621) (-2513 . 548545) (-2514 . 548427) (-2515 . 548366) (-2516 . 548088) (-2517 . 547932) (-2518 . 547766) (-2519 . 547638) (-2520 . 547601) (-2521 . 547152) (-2522 . 547053) (-2523 . 546872) (-2524 . 546813) (-2525 . 546737) (-2526 . 546639) (-2527 . 546569) (-2528 . 546450) (-2529 . 546234) (-2530 . 546077) (-2531 . 546019) (-2532 . 545785) (-2533 . 545726) (-2534 . 545576) (-2535 . 545094) (-2536 . 544842) (-2537 . 544787) (-2538 . 544703) (-2539 . 544630) (-2540 . 544563) (-2541 . 544314) (-2542 . 544213) (-2543 . 544039) (-2544 . 543754) (-2545 . 543661) (-2546 . 543519) (-2547 . 543401) (-2548 . 543334) (-2549 . 543136) (-2550 . 542828) (-2551 . 542775) (-2552 . 542572) (-2553 . 542446) (-2554 . 541764) (-2555 . 541736) (-2556 . 541631) (-2557 . 541557) (-2558 . 541449) (-2559 . 541393) (-2560 . 541344) (-2561 . 540719) (-2562 . 540608) (-2563 . 540495) (-2564 . 539954) (-2565 . 539852) (-2566 . 539749) (-2567 . 539541) (-2568 . 539436) (-2569 . 538489) (-2570 . 538153) (-2571 . 538050) (-2572 . 537952) (-2573 . 537890) (-2574 . 537785) (-2575 . 537681) (-2576 . 537440) (-2577 . 537391) (-2578 . 536972) (-2579 . 536647) (-2580 . 536495) (-2581 . 536225) (-2582 . 535904) (-2583 . 535098) (-2584 . 534884) (-2585 . 534785) (-2586 . 534702) (-2587 . 534649) (-2588 . 534565) (-2589 . 533790) (-2590 . 533723) (-2591 . 533615) (-2592 . 533467) (-2593 . 533152) (-2594 . 533099) (-2595 . 532962) (-2596 . 532756) (-2597 . 532651) (-2598 . 532393) (-2599 . 532018) (-2600 . 531856) (-2601 . 531015) (-2602 . 530944) (-2603 . 530842) (-2604 . 530484) (-2605 . 530347) (-2606 . 530049) (-2607 . 529946) (-2608 . 529451) (-2609 . 529318) (-2610 . 529219) (-2611 . 529044) (-2612 . 528991) (-2613 . 528867) (-2614 . 528770) (-2615 . 528580) (-2616 . 528471) (-2617 . 525516) (-2618 . 525365) (-2619 . 525091) (-2620 . 524996) (-2621 . 524766) (-2622 . 524529) (-2623 . 524476) (-2624 . 524243) (-2625 . 524174) (-2626 . 524086) (-2627 . 524016) (-2628 . 523945) (-2629 . 523839) (-2630 . 523759) (-2631 . 523531) (-2632 . 523402) (-2633 . 523327) (-2634 . 523223) (-2635 . 523054) (-2636 . 522882) (-2637 . 522795) (-2638 . 522591) (-2639 . 522384) (-2640 . 522276) (-2641 . 522003) (-2642 . 521361) (-2643 . 521156) (-2644 . 520886) (-2645 . 520747) (-2646 . 520679) (-2647 . 520491) (-2648 . 520373) (-2649 . 520287) (-2650 . 520158) (-2651 . 520008) (-2652 . 519907) (-2653 . 519824) (-2654 . 519685) (-2655 . 519330) (-2656 . 519278) (-2657 . 519189) (-2658 . 518987) (-2659 . 518849) (-2660 . 518654) (-2661 . 518577) (-2662 . 518549) (-2663 . 518314) (-2664 . 518134) (-2665 . 516763) (-2666 . 516694) (-2667 . 515628) (-2668 . 515509) (-2669 . 515216) (-2670 . 515187) (-2671 . 514591) (-2672 . 514452) (-2673 . 514044) (-2674 . 513933) (-2675 . 513861) (-2676 . 513768) (-2677 . 513661) (-2678 . 513290) (-2679 . 513205) (-2680 . 513177) (-2681 . 513103) (-2682 . 512996) (-2683 . 512842) (-2684 . 512761) (-2685 . 512282) (-2686 . 512254) (** . 509104) (-2688 . 508683) (-2689 . 508580) (-2690 . 508489) (-2691 . 508382) (-2692 . 507599) (-2693 . 507380) (-2694 . 507255) (-2695 . 507162) (-2696 . 507087) (-2697 . 507015) (-2698 . 506948) (-2699 . 506896) (-2700 . 506846) (-2701 . 506407) (-2702 . 506303) (-2703 . 506231) (-2704 . 506164) (-2705 . 506084) (-2706 . 506003) (-2707 . 505886) (-2708 . 505794) (-2709 . 505686) (-2710 . 505451) (-2711 . 505244) (-2712 . 504948) (-2713 . 504679) (-2714 . 504617) (-2715 . 504172) (-2716 . 504020) (-2717 . 503968) (-2718 . 503911) (-2719 . 503739) (-2720 . 503686) (-2721 . 503410) (-2722 . 503220) (-2723 . 503068) (-2724 . 502637) (-2725 . 502381) (-2726 . 502285) (-2727 . 502046) (-2728 . 501611) (-2729 . 501221) (-2730 . 501034) (-2731 . 487192) (-2732 . 487064) (-2733 . 484398) (-2734 . 484236) (-2735 . 484099) (-2736 . 484006) (-2737 . 483926) (-2738 . 483812) (-2739 . 483657) (-2740 . 483544) (-2741 . 483137) (-2742 . 482045) (-2743 . 481986) (-2744 . 481886) (-2745 . 481765) (-2746 . 481572) (-2747 . 481331) (-2748 . 481097) (-2749 . 480957) (-2750 . 480774) (-2751 . 480443) (-2752 . 480198) (-2753 . 479893) (-2754 . 479834) (-2755 . 479698) (-2756 . 479504) (-2757 . 479447) (-2758 . 479306) (-2759 . 479224) (-2760 . 479165) (-2761 . 478884) (-2762 . 478777) (-2763 . 478652) (-2764 . 478571) (-2765 . 478430) (-2766 . 478359) (-2767 . 478211) (-2768 . 478090) (-2769 . 478038) (-2770 . 477421) (-2771 . 476852) (-2772 . 476768) (-2773 . 476671) (-2774 . 476596) (-2775 . 476537) (-2776 . 476417) (-2777 . 476324) (-2778 . 476191) (-2779 . 476107) (-2780 . 472183) (-2781 . 472126) (-2782 . 471910) (-2783 . 471793) (-2784 . 471698) (-2785 . 471601) (-2786 . 471378) (-2787 . 471270) (-2788 . 470940) (-2789 . 470799) (-2790 . 470691) (-2791 . 469694) (-2792 . 469510) (-2793 . 467795) (-2794 . 467548) (-2795 . 467496) (-2796 . 467468) (-2797 . 467342) (-2798 . 467103) (-2799 . 467011) (-2800 . 466870) (-2801 . 466775) (-2802 . 466409) (-2803 . 466317) (-2804 . 466185) (-2805 . 466068) (-2806 . 460236) (-2807 . 459090) (-2808 . 458958) (-2809 . 458145) (-2810 . 457998) (-2811 . 457702) (-2812 . 457576) (-2813 . 457452) (-2814 . 457289) (-2815 . 457164) (-2816 . 457026) (-2817 . 456929) (-2818 . 456867) (-2819 . 456489) (-2820 . 456395) (-2821 . 455060) (-2822 . 454950) (-2823 . 454800) (-2824 . 454621) (-2825 . 454005) (-2826 . 453739) (-2827 . 453600) (-2828 . 453428) (-2829 . 453264) (-2830 . 453116) (-2831 . 452919) (-2832 . 452841) (-2833 . 452694) (-2834 . 452541) (-2835 . 452469) (-2836 . 452059) (-2837 . 452028) (-2838 . 451708) (-2839 . 451572) (-2840 . 451048) (-2841 . 450879) (-2842 . 450666) (-2843 . 450600) (-2844 . 450566) (-2845 . 450280) (-2846 . 449945) (-2847 . 449845) (-2848 . 449765) (-2849 . 449602) (-2850 . 449521) (-2851 . 449418) (-2852 . 448503) (-2853 . 448323) (-2854 . 448201) (-2855 . 448141) (-2856 . 446536) (-2857 . 446373) (-2858 . 446289) (-2859 . 446107) (-2860 . 445730) (-2861 . 445646) (-2862 . 445552) (-2863 . 445439) (-2864 . 445222) (-2865 . 445153) (-2866 . 445085) (-2867 . 444594) (-2868 . 444303) (-2869 . 443970) (-2870 . 443833) (-2871 . 443680) (-2872 . 443546) (-2873 . 443245) (-2874 . 443136) (-2875 . 443030) (-2876 . 442957) (-2877 . 442903) (-2878 . 442823) (-2879 . 442680) (-2880 . 442512) (-2881 . 439673) (-2882 . 439555) (-2883 . 439480) (-2884 . 439273) (-2885 . 439151) (-2886 . 439042) (-2887 . 438989) (-2888 . 438908) (-2889 . 438713) (-2890 . 438152) (-2891 . 438056) (-2892 . 437510) (-2893 . 437383) (-2894 . 437148) (-2895 . 437057) (-2896 . 436984) (-2897 . 436931) (-2898 . 436882) (-2899 . 436825) (-2900 . 436689) (-2901 . 436557) (-2902 . 436466) (-2903 . 436218) (-2904 . 436126) (-2905 . 436070) (-2906 . 435891) (-2907 . 435789) (-2908 . 435516) (-2909 . 435297) (-2910 . 435133) (-2911 . 435042) (-2912 . 434911) (-2913 . 434663) (-2914 . 434539) (-2915 . 434206) (-2916 . 434118) (-2917 . 434044) (-2918 . 433968) (-2919 . 433879) (-2920 . 433804) (-2921 . 433650) (-2922 . 433471) (-2923 . 433359) (-2924 . 433203) (-2925 . 433074) (-2926 . 432963) (-2927 . 432892) (-2928 . 432833) (-2929 . 432655) (-2930 . 432309) (-2931 . 432192) (-2932 . 432068) (-2933 . 431384) (-2934 . 430807) (-2935 . 430557) (-2936 . 430466) (-2937 . 430269) (-2938 . 430195) (-2939 . 430082) (-2940 . 429846) (-2941 . 429689) (-2942 . 428728) (-2943 . 428094) (-2944 . 427819) (-2945 . 427678) (-2946 . 427578) (-2947 . 427042) (-2948 . 423118) (-2949 . 423037) (-2950 . 422936) (-2951 . 422316) (-2952 . 421970) (-2953 . 421833) (-2954 . 421745) (-2955 . 421673) (-2956 . 421472) (-2957 . 421297) (-2958 . 421217) (-2959 . 421023) (-2960 . 420939) (-2961 . 420841) (-2962 . 420707) (-2963 . 420534) (-2964 . 420319) (-2965 . 420199) (-2966 . 420132) (-2967 . 420051) (-2968 . 420002) (-2969 . 419751) (-2970 . 419674) (-2971 . 419371) (-2972 . 419278) (-2973 . 419126) (-2974 . 419073) (-2975 . 418976) (-2976 . 418734) (-2977 . 418562) (-2978 . 418250) (-2979 . 417966) (-2980 . 417862) (-2981 . 417781) (-2982 . 417417) (-2983 . 417365) (-2984 . 417293) (-2985 . 417163) (-2986 . 416950) (-2987 . 416774) (-2988 . 416623) (-2989 . 416556) (-2990 . 416293) (-2991 . 416195) (-2992 . 416081) (-2993 . 416007) (-2994 . 415900) (-2995 . 415842) (-2996 . 415687) (-2997 . 415659) (-2998 . 415575) (-2999 . 415466) (-3000 . 415409) (-3001 . 414970) (-3002 . 414276) (-3003 . 414180) (-3004 . 413818) (-3005 . 413583) (-3006 . 412383) (-3007 . 412331) (-3008 . 412206) (-3009 . 412135) (-3010 . 411999) (-3011 . 411764) (-3012 . 411712) (-3013 . 411077) (-3014 . 410391) (-3015 . 410334) (-3016 . 408223) (-3017 . 408154) (-3018 . 408048) (-3019 . 407917) (-3020 . 407807) (-3021 . 407690) (-3022 . 407599) (-3023 . 407475) (-3024 . 407326) (-3025 . 407274) (-3026 . 407163) (-3027 . 406962) (-3028 . 406840) (-3029 . 406722) (-3030 . 406529) (-3031 . 406422) (-3032 . 405831) (-3033 . 405710) (-3034 . 405619) (-3035 . 405097) (-3036 . 404997) (-3037 . 404702) (-3038 . 403835) (-3039 . 403663) (-3040 . 403574) (-3041 . 403545) (-3042 . 403492) (-3043 . 403403) (-3044 . 403300) (-3045 . 403166) (-3046 . 403019) (-3047 . 402937) (-3048 . 402855) (-3049 . 402827) (-3050 . 402724) (-3051 . 402382) (-3052 . 401604) (-3053 . 401427) (-3054 . 401330) (-3055 . 401239) (-3056 . 401029) (-3057 . 400869) (-3058 . 400671) (-3059 . 400409) (-3060 . 400254) (-3061 . 400199) (-3062 . 400111) (-3063 . 399924) (-3064 . 399849) (-3065 . 399722) (-3066 . 399299) (-3067 . 399208) (-3068 . 399156) (-3069 . 398950) (-3070 . 398642) (-3071 . 398484) (-3072 . 398386) (-3073 . 398089) (-3074 . 397907) (-3075 . 397611) (-3076 . 397346) (-3077 . 397294) (-3078 . 397183) (-3079 . 397073) (-3080 . 396923) (-3081 . 396641) (-3082 . 395700) (-3083 . 395606) (-3084 . 395539) (-3085 . 394925) (-3086 . 394619) (-3087 . 394297) (-3088 . 394208) (-3089 . 394138) (-3090 . 387749) (-3091 . 387663) (-3092 . 387540) (-3093 . 387276) (-3094 . 387159) (-3095 . 387075) (-3096 . 386868) (-3097 . 386794) (-3098 . 385835) (-3099 . 385757) (-3100 . 384914) (-3101 . 384835) (-3102 . 384736) (-3103 . 384574) (-3104 . 384500) (-3105 . 384402) (-3106 . 384312) (-3107 . 384138) (-3108 . 383697) (-3109 . 383535) (-3110 . 383420) (-3111 . 382930) (-3112 . 382672) (-3113 . 382208) (-3114 . 382119) (-3115 . 382047) (-3116 . 381953) (-3117 . 381849) (-3118 . 381603) (-3119 . 381529) (-3120 . 381293) (-3121 . 381000) (-3122 . 380609) (-3123 . 380457) (-3124 . 380426) (-3125 . 380299) (-3126 . 380122) (-3127 . 380064) (-3128 . 379739) (-3129 . 379580) (-3130 . 379423) (-3131 . 379219) (-3132 . 378996) (-3133 . 378157) (-3134 . 378017) (-3135 . 377865) (-3136 . 377740) (-3137 . 377585) (-3138 . 377352) (-3139 . 377227) (-3140 . 377174) (-3141 . 377102) (-3142 . 376817) (-3143 . 376458) (-3144 . 376235) (-3145 . 375993) (-3146 . 375940) (-3147 . 375666) (-3148 . 375259) (-3149 . 375129) (-3150 . 375005) (-3151 . 374949) (-3152 . 374917) (-3153 . 374760) (-3154 . 374664) (-3155 . 374517) (-3156 . 374366) (-3157 . 374268) (-3158 . 374160) (-3159 . 373797) (-3160 . 373672) (-3161 . 373464) (-3162 . 366624) (-3163 . 366564) (-3164 . 365349) (-3165 . 365175) (-3166 . 364211) (-3167 . 364161) (-3168 . 364108) (-3169 . 364038) (-3170 . 363947) (-3171 . 363769) (-3172 . 363496) (-3173 . 363361) (-3174 . 363026) (-3175 . 362849) (-3176 . 362687) (-3177 . 362535) (-3178 . 361982) (-3179 . 361811) (-3180 . 361541) (-3181 . 361412) (-3182 . 361325) (-3183 . 360424) (-3184 . 360367) (-3185 . 360275) (-3186 . 359901) (-3187 . 359819) (-3188 . 359619) (-3189 . 359467) (-3190 . 359433) (-3191 . 359378) (-3192 . 359224) (-3193 . 359105) (-3194 . 358886) (-3195 . 358616) (-3196 . 358432) (-3197 . 358365) (-3198 . 358252) (-3199 . 357947) (-3200 . 357866) (-3201 . 357791) (-3202 . 357759) (-3203 . 357703) (-3204 . 357468) (-3205 . 357364) (-3206 . 357288) (-3207 . 357190) (-3208 . 357037) (-3209 . 356970) (-3210 . 356241) (-3211 . 356091) (-3212 . 355984) (-3213 . 355924) (-3214 . 355833) (-3215 . 355375) (-3216 . 355258) (-3217 . 355148) (-3218 . 354943) (-3219 . 354405) (-3220 . 354371) (-3221 . 354282) (-3222 . 354110) (-3223 . 353889) (-3224 . 353565) (-3225 . 353495) (-3226 . 353415) (-3227 . 353334) (-3228 . 353193) (-3229 . 352687) (-3230 . 352539) (-3231 . 352458) (-3232 . 352381) (-3233 . 352306) (-3234 . 352188) (-3235 . 352114) (-3236 . 352086) (-3237 . 351938) (-3238 . 351847) (-3239 . 351696) (-3240 . 351596) (-3241 . 351246) (-3242 . 350641) (-3243 . 350493) (-3244 . 350409) (-3245 . 349958) (-3246 . 349876) (-3247 . 349646) (-3248 . 349565) (-3249 . 349481) (-3250 . 349221) (-3251 . 349111) (-3252 . 348995) (-3253 . 348896) (-3254 . 348474) (-3255 . 347773) (-3256 . 347692) (-3257 . 347515) (-3258 . 347444) (-3259 . 347233) (-3260 . 347196) (-3261 . 347168) (-3262 . 346603) (-3263 . 346295) (-3264 . 346176) (-3265 . 346109) (-3266 . 345809) (-3267 . 345683) (-3268 . 345593) (-3269 . 345359) (-3270 . 344965) (-3271 . 344869) (-3272 . 344778) (-3273 . 344692) (-3274 . 344321) (-3275 . 344196) (-3276 . 343957) (-3277 . 343731) (-3278 . 343515) (-3279 . 343287) (-3280 . 343176) (-3281 . 343011) (-3282 . 342882) (-3283 . 342796) (-3284 . 342635) (-3285 . 342531) (-3286 . 342445) (-3287 . 342326) (-3288 . 342252) (-3289 . 342150) (-3290 . 342083) (-3291 . 341969) (-3292 . 341369) (-3293 . 341231) (-3294 . 341039) (-3295 . 340965) (-3296 . 340719) (-3297 . 340576) (-3298 . 340411) (-3299 . 340295) (-3300 . 338788) (-3301 . 338527) (-3302 . 338199) (-3303 . 338003) (-3304 . 337841) (-3305 . 337304) (-3306 . 335705) (-3307 . 335605) (-3308 . 335529) (-3309 . 335294) (-3310 . 335198) (-3311 . 335166) (-3312 . 335115) (-3313 . 332731) (-3314 . 332675) (-3315 . 331787) (-3316 . 331655) (-3317 . 331552) (-3318 . 331480) (-3319 . 331157) (-3320 . 330976) (-3321 . 330508) (-3322 . 330401) (-3323 . 330029) (-3324 . 329733) (-3325 . 329440) (-3326 . 329384) (-3327 . 329356) (-3328 . 329171) (-3329 . 329118) (-3330 . 328775) (-3331 . 328714) (-3332 . 328344) (-3333 . 328264) (-3334 . 328154) (-3335 . 328081) (-3336 . 327975) (-3337 . 327794) (-3338 . 327658) (-3339 . 327449) (-3340 . 327353) (-3341 . 327269) (-3342 . 327202) (-3343 . 327033) (-3344 . 326742) (-3345 . 326612) (-3346 . 326489) (-3347 . 326407) (-3348 . 326323) (-3349 . 326107) (-3350 . 325995) (-3351 . 319464) (-3352 . 319314) (-3353 . 319262) (-3354 . 319194) (-3355 . 319064) (-3356 . 318798) (-3357 . 318616) (-3358 . 318262) (-3359 . 317969) (-3360 . 317898) (-3361 . 317870) (-3362 . 317743) (-3363 . 317489) (-3364 . 317438) (-3365 . 317325) (-3366 . 317086) (-3367 . 317000) (-3368 . 316623) (-3369 . 315929) (-3370 . 315823) (-3371 . 314684) (-3372 . 314492) (-3373 . 314352) (-3374 . 314204) (-3375 . 313478) (-3376 . 313401) (-3377 . 313250) (-3378 . 313110) (-3379 . 313054) (-3380 . 312882) (-3381 . 312811) (-3382 . 312508) (-3383 . 312316) (-3384 . 312266) (-3385 . 311692) (-3386 . 311540) (-3387 . 311390) (-3388 . 311312) (-3389 . 310972) (-3390 . 310392) (-3391 . 310073) (-3392 . 309974) (-3393 . 309895) (-3394 . 309791) (-3395 . 309313) (-3396 . 309254) (-3397 . 309137) (-3398 . 309038) (-3399 . 308493) (-3400 . 308396) (-3401 . 308043) (-3402 . 307948) (-3403 . 307802) (-3404 . 307706) (-3405 . 306894) (-3406 . 306718) (-3407 . 306158) (-3408 . 306066) (-3409 . 305965) (-3410 . 305869) (-3411 . 305816) (-3412 . 303668) (-3413 . 303537) (-3414 . 303387) (-3415 . 303262) (-3416 . 303135) (-3417 . 302842) (-3418 . 302730) (-3419 . 302651) (-3420 . 302479) (-3421 . 302405) (-3422 . 302281) (-3423 . 302157) (-3424 . 301768) (-3425 . 301609) (-3426 . 301502) (-3427 . 300944) (-3428 . 300823) (-3429 . 300765) (-3430 . 300634) (-3431 . 300405) (-3432 . 300324) (-3433 . 300213) (-3434 . 300092) (-3435 . 299978) (-3436 . 299714) (-3437 . 299562) (-3438 . 299464) (-3439 . 299120) (-3440 . 299018) (-3441 . 298872) (-3442 . 298701) (-3443 . 298511) (-3444 . 298459) (-3445 . 298360) (-3446 . 298284) (-3447 . 298232) (-3448 . 298072) (-3449 . 297747) (-3450 . 297676) (-3451 . 297579) (-3452 . 296236) (-3453 . 296140) (-3454 . 295832) (-3455 . 295722) (-3456 . 295663) (-3457 . 295582) (-3458 . 295487) (-3459 . 295391) (-3460 . 295288) (-3461 . 294801) (-3462 . 294630) (-3463 . 294443) (-3464 . 294275) (-3465 . 294142) (-3466 . 293510) (-3467 . 293482) (-3468 . 293247) (-3469 . 293090) (-3470 . 292774) (-3471 . 292641) (-3472 . 292535) (-3473 . 292357) (-3474 . 291408) (-3475 . 291320) (-3476 . 291234) (-3477 . 290845) (-3478 . 290691) (-3479 . 290597) (-3480 . 290415) (-3481 . 290044) (-3482 . 289958) (-3483 . 289889) (-3484 . 289794) (-3485 . 289648) (-3486 . 289496) (-3487 . 289444) (-3488 . 289358) (-3489 . 289265) (-3490 . 289206) (-3491 . 288941) (-3492 . 288864) (-3493 . 288778) (-3494 . 288613) (-3495 . 288475) (-3496 . 288423) (-3497 . 288118) (-3498 . 288032) (-3499 . 287916) (-3500 . 287712) (-3501 . 287571) (-3502 . 287498) (-3503 . 287412) (-3504 . 287055) (-3505 . 286996) (-3506 . 286837) (-3507 . 282913) (-3508 . 282690) (-3509 . 282604) (-3510 . 282401) (-3511 . 282244) (-3512 . 281595) (-3513 . 281524) (-3514 . 281356) (-3515 . 281192) (-3516 . 281094) (-3517 . 280939) (-3518 . 280853) (-3519 . 280800) (-3520 . 280677) (-3521 . 280489) (-3522 . 280321) (-3523 . 280235) (-3524 . 279782) (-3525 . 279689) (-3526 . 279450) (-3527 . 279346) (-3528 . 279260) (-3529 . 278791) (-3530 . 278723) (-3531 . 278671) (-3532 . 278546) (-3533 . 278454) (-3534 . 278359) (-3535 . 278284) (-3536 . 277495) (-3537 . 277393) (-3538 . 277312) (-3539 . 277226) (-3540 . 276959) (-3541 . 276848) (-3542 . 276707) (-3543 . 276610) (-3544 . 276524) (-3545 . 276372) (-3546 . 276234) (-3547 . 276021) (-3548 . 274802) (-3549 . 274691) (-3550 . 274529) (-3551 . 274443) (-3552 . 273510) (-3553 . 273458) (-3554 . 273266) (-3555 . 272425) (-3556 . 272322) (-3557 . 272236) (-3558 . 272005) (-3559 . 271890) (-3560 . 271638) (-3561 . 271450) (-3562 . 271366) (-3563 . 271280) (-3564 . 271173) (-3565 . 271076) (-3566 . 270702) (-3567 . 269792) (-3568 . 269564) (-3569 . 269491) (-3570 . 269398) (-3571 . 269331) (-3572 . 269197) (-3573 . 269101) (-3574 . 268959) (-3575 . 268543) (-3576 . 268410) (-3577 . 268351) (-3578 . 268256) (-3579 . 268197) (-3580 . 267754) (-3581 . 267556) (-3582 . 267407) (-3583 . 267047) (-3584 . 266955) (-3585 . 266905) (-3586 . 266577) (-3587 . 266395) (-3588 . 266317) (-3589 . 266283) (-3590 . 266191) (-3591 . 265664) (-3592 . 265124) (-3593 . 265038) (-3594 . 264835) (-3595 . 264425) (-3596 . 264324) (-3597 . 264235) (-3598 . 264163) (-3599 . 264089) (-3600 . 263890) (-3601 . 263811) (-3602 . 263556) (-3603 . 263470) (-3604 . 263328) (-3605 . 262489) (-3606 . 262126) (-3607 . 261871) (-3608 . 261699) (-3609 . 261380) (-3610 . 257456) (-3611 . 257131) (-3612 . 256996) (-3613 . 256746) (-3614 . 256672) (-3615 . 256586) (-3616 . 255769) (-3617 . 255672) (-3618 . 255547) (-3619 . 255196) (-3620 . 255095) (-3621 . 254802) (-3622 . 254645) (-3623 . 254611) (-3624 . 254496) (-3625 . 254407) (-3626 . 253583) (-3627 . 253494) (-3628 . 253408) (-3629 . 253116) (-3630 . 253045) (-3631 . 252986) (-3632 . 252934) (-3633 . 252771) (-3634 . 252475) (-3635 . 252140) (-3636 . 252069) (-3637 . 251870) (-3638 . 251784) (-3639 . 251694) (-3640 . 251585) (-3641 . 251443) (-3642 . 251170) (-3643 . 251010) (-3644 . 248611) (-3645 . 248555) (-3646 . 248445) (-3647 . 248095) (-3648 . 248043) (-3649 . 247885) (-3650 . 246977) (-3651 . 246662) (-3652 . 246607) (-3653 . 246325) (-3654 . 246187) (-3655 . 246061) (-3656 . 245875) (-3657 . 242265) (-3658 . 242061) (-3659 . 241970) (-3660 . 241911) (-3661 . 241858) (-3662 . 241772) (-3663 . 241691) (-3664 . 241502) (-3665 . 241364) (-3666 . 241213) (-3667 . 241176) (-3668 . 241035) (-3669 . 240901) (-3670 . 240743) (-3671 . 240556) (-3672 . 240467) (-3673 . 240348) (-3674 . 240069) (-3675 . 239983) (-3676 . 239931) (-3677 . 239842) (-3678 . 238605) (-3679 . 238023) (-3680 . 237865) (-3681 . 237710) (-3682 . 237336) (-3683 . 237088) (-3684 . 236956) (-3685 . 236872) (-3686 . 236776) (-3687 . 236643) (-3688 . 236273) (-3689 . 236178) (-3690 . 236122) (-3691 . 236055) (-3692 . 235922) (-3693 . 235828) (-3694 . 235657) (-3695 . 235562) (-3696 . 235412) (-3697 . 235326) (-3698 . 235229) (-3699 . 235066) (-3700 . 234914) (-3701 . 234792) (-3702 . 233834) (-3703 . 233715) (-3704 . 233629) (-3705 . 233516) (-3706 . 233382) (-3707 . 233256) (-3708 . 233163) (-3709 . 233077) (-3710 . 232839) (-3711 . 232458) (-3712 . 232336) (-3713 . 232253) (-3714 . 232180) (-3715 . 232094) (-3716 . 232011) (-3717 . 231889) (-3718 . 231732) (-3719 . 231543) (-3720 . 231420) (-3721 . 231225) (-3722 . 230793) (-3723 . 230701) (-3724 . 230592) (-3725 . 230225) (-3726 . 230083) (-3727 . 230016) (-3728 . 229878) (-3729 . 229786) (-3730 . 229676) (-3731 . 229414) (-3732 . 229261) (-3733 . 229145) (-3734 . 229045) (-3735 . 228898) (-3736 . 228747) (-3737 . 228675) (-3738 . 228572) (-3739 . 228425) (-3740 . 227857) (-3741 . 227731) (-3742 . 227570) (-3743 . 227147) (-3744 . 227022) (-3745 . 226917) (-3746 . 226721) (-3747 . 226572) (-3748 . 226366) (-3749 . 226248) (-3750 . 226115) (-3751 . 225958) (-3752 . 225844) (-3753 . 225729) (-3754 . 225642) (-3755 . 225537) (-3756 . 225449) (-3757 . 225320) (-3758 . 225265) (-3759 . 225125) (-3760 . 225023) (-3761 . 224944) (-3762 . 224829) (-3763 . 224745) (-3764 . 224541) (-3765 . 224379) (-3766 . 224206) (-3767 . 222852) (-3768 . 222734) (-3769 . 222570) (-3770 . 222468) (-3771 . 221742) (-3772 . 221064) (-3773 . 220964) (-3774 . 220875) (-3775 . 220451) (-3776 . 220364) (-3777 . 220279) (-3778 . 220161) (-3779 . 220087) (-3780 . 219994) (-3781 . 219614) (-3782 . 219549) (-3783 . 219459) (-3784 . 219362) (-3785 . 218027) (-3786 . 217721) (-3787 . 217608) (-3788 . 217536) (-3789 . 217481) (-3790 . 217431) (-3791 . 217379) (-3792 . 216682) (-3793 . 216240) (-3794 . 216156) (-3795 . 215965) (-3796 . 215516) (-3797 . 215463) (-3798 . 215360) (-3799 . 215165) (-3800 . 215107) (-3801 . 215035) (-3802 . 214650) (-3803 . 214553) (-3804 . 214222) (-3805 . 214114) (-3806 . 214086) (-3807 . 213848) (-3808 . 213816) (-3809 . 213788) (-3810 . 213699) (-3811 . 213575) (-3812 . 213495) (-3813 . 213404) (-3814 . 213206) (-3815 . 213035) (-3816 . 212920) (-3817 . 212619) (-3818 . 212555) (-3819 . 212455) (-3820 . 212197) (-3821 . 211844) (-3822 . 211277) (-3823 . 211128) (-3824 . 210997) (-3825 . 210794) (-3826 . 210596) (-3827 . 210544) (-3828 . 210445) (-3829 . 210323) (-3830 . 210142) (-3831 . 210087) (-3832 . 210035) (-3833 . 209915) (-3834 . 209835) (-3835 . 209783) (-3836 . 209628) (-3837 . 209547) (-3838 . 209330) (-3839 . 209131) (-3840 . 208995) (-3841 . 208939) (-12 . 208784) (-3843 . 208390) (-3844 . 208258) (-3845 . 208071) (-3846 . 207956) (-3847 . 207804) (-3848 . 207670) (-3849 . 207592) (-3850 . 207419) (-3851 . 207304) (-3852 . 207252) (-3853 . 206881) (-3854 . 206803) (-3855 . 206706) (-3856 . 206362) (-3857 . 206217) (-3858 . 206038) (-3859 . 205647) (-3860 . 205445) (-3861 . 205393) (-3862 . 205255) (-3863 . 204703) (-3864 . 204626) (-3865 . 204553) (-3866 . 204409) (-3867 . 203894) (-3868 . 203822) (-3869 . 203769) (-3870 . 203591) (-3871 . 203453) (-3872 . 203309) (-3873 . 203219) (-3874 . 203067) (-3875 . 202954) (-3876 . 202405) (-3877 . 202356) (-3878 . 202189) (-3879 . 202063) (-3880 . 202035) (-3881 . 201924) (-3882 . 201779) (-3883 . 201705) (-3884 . 201328) (-3885 . 201217) (-3886 . 201107) (-3887 . 200976) (-3888 . 200628) (-3889 . 200524) (-3890 . 200442) (-3891 . 199000) (-3892 . 198926) (-3893 . 198769) (* . 194116) (-3895 . 194033) (-3896 . 193793) (-3897 . 193508) (-3898 . 193389) (-3899 . 193337) (-3900 . 193255) (-3901 . 193206) (-3902 . 192575) (-3903 . 191639) (-3904 . 191339) (-3905 . 191035) (-3906 . 190290) (-3907 . 190190) (-3908 . 189924) (-3909 . 189857) (-3910 . 189784) (-3911 . 189729) (-3912 . 189572) (-3913 . 189497) (-3914 . 189445) (-3915 . 189413) (-3916 . 189324) (-3917 . 189156) (-3918 . 187995) (-3919 . 187572) (-3920 . 187227) (-3921 . 187185) (-3922 . 187102) (-3923 . 186994) (-3924 . 186832) (-3925 . 186779) (-3926 . 186638) (-3927 . 181538) (-3928 . 181385) (-3929 . 181262) (-3930 . 181188) (-3931 . 180445) (-3932 . 179060) (-3933 . 179004) (-3934 . 178796) (-3935 . 178692) (-3936 . 178421) (-3937 . 178283) (-3938 . 177708) (-3939 . 177613) (-3940 . 176343) (-3941 . 176100) (-3942 . 176013) (-3943 . 175897) (-3944 . 175823) (-3945 . 175580) (-3946 . 175471) (-3947 . 175372) (-3948 . 174992) (-3949 . 174726) (-3950 . 174648) (-3951 . 174412) (-3952 . 173439) (-3953 . 173335) (-3954 . 173163) (-3955 . 173091) (-3956 . 173023) (-3957 . 172601) (-3958 . 172525) (-3959 . 172203) (-3960 . 171789) (-3961 . 171312) (-3962 . 170609) (-3963 . 170540) (-3964 . 170348) (-3965 . 170209) (-3966 . 170136) (-3967 . 169874) (-3968 . 169805) (-3969 . 168703) (-3970 . 168427) (-3971 . 167987) (-3972 . 167897) (-3973 . 167692) (-3974 . 167574) (-3975 . 167522) (-3976 . 167386) (-3977 . 167274) (-3978 . 166674) (-3979 . 166598) (-3980 . 166564) (-3981 . 166466) (-3982 . 166408) (-3983 . 165999) (-3984 . 165924) (-3985 . 165798) (-3986 . 165764) (-3987 . 165068) (-3988 . 164697) (-3989 . 164635) (-3990 . 164391) (-3991 . 164269) (-3992 . 164175) (-3993 . 163636) (-3994 . 163559) (-3995 . 163470) (-3996 . 163028) (-3997 . 162925) (-3998 . 162897) (-3999 . 162816) (-4000 . 162715) (-4001 . 162657) (-4002 . 162205) (-4003 . 162094) (-4004 . 161426) (-4005 . 152533) (-4006 . 152240) (-4007 . 152088) (-4008 . 151888) (-4009 . 151779) (-4010 . 150954) (-4011 . 150638) (-4012 . 150607) (-4013 . 150534) (-4014 . 150437) (-4015 . 149850) (-4016 . 149654) (-4017 . 149501) (-4018 . 149236) (-4019 . 149129) (-4020 . 149044) (-4021 . 148965) (-4022 . 148875) (-4023 . 147956) (-4024 . 147809) (-4025 . 147669) (-4026 . 147567) (-4027 . 147435) (-4028 . 146423) (-4029 . 146099) (-4030 . 145961) (-4031 . 145811) (-4032 . 145685) (-4033 . 145595) (-4034 . 145359) (-4035 . 145300) (-4036 . 145038) (-4037 . 144823) (-4038 . 144719) (-4039 . 144621) (-4040 . 144593) (-4041 . 144479) (-4042 . 144172) (-4043 . 143963) (-4044 . 143697) (-4045 . 143623) (-4046 . 143490) (-4047 . 143275) (-4048 . 143126) (-4049 . 143001) (-4050 . 142909) (-4051 . 142819) (-4052 . 142483) (-4053 . 142322) (-4054 . 142177) (-4055 . 141725) (-4056 . 141042) (-4057 . 140675) (-4058 . 140367) (-4059 . 140217) (-4060 . 140060) (-4061 . 139397) (-4062 . 139307) (-4063 . 139232) (-4064 . 139122) (-4065 . 138411) (-4066 . 138198) (-4067 . 138117) (-4068 . 138024) (-4069 . 137957) (-4070 . 137923) (-4071 . 137841) (-4072 . 137140) (-4073 . 137053) (-4074 . 136919) (-4075 . 136811) (-4076 . 136628) (-4077 . 136483) (-4078 . 136413) (-4079 . 136313) (-4080 . 136285) (-4081 . 136196) (-4082 . 136143) (-4083 . 136087) (-4084 . 135695) (-4085 . 134476) (-4086 . 134204) (-4087 . 134125) (-4088 . 134070) (-4089 . 133967) (-4090 . 133844) (-4091 . 133786) (-4092 . 133752) (-4093 . 133680) (-4094 . 133522) (-4095 . 133119) (-4096 . 132396) (-4097 . 131830) (-4098 . 131632) (-4099 . 131542) (-4100 . 131421) (-4101 . 131369) (-4102 . 131272) (-4103 . 130907) (-4104 . 130817) (-4105 . 130742) (-4106 . 130590) (-4107 . 130514) (-4108 . 130410) (-4109 . 130304) (-4110 . 130234) (-4111 . 130182) (-4112 . 130108) (-4113 . 129955) (-4114 . 129900) (-4115 . 129820) (-4116 . 129552) (-4117 . 129466) (-4118 . 129230) (-4119 . 129027) (-4120 . 128899) (-4121 . 128703) (-4122 . 128636) (-4123 . 128347) (-4124 . 128263) (-4125 . 128080) (-4126 . 125643) (-4127 . 125488) (-4128 . 125436) (-4129 . 125248) (-4130 . 124874) (-4131 . 124406) (-4132 . 124333) (-4133 . 124178) (-4134 . 124019) (-4135 . 123749) (-4136 . 123571) (-4137 . 123250) (-4138 . 122484) (-4139 . 122431) (-4140 . 122382) (-4141 . 122313) (-4142 . 121096) (-4143 . 120999) (-4144 . 120782) (-4145 . 120606) (-4146 . 120477) (-4147 . 120408) (-4148 . 120230) (-4149 . 119683) (-4150 . 119586) (-4151 . 119534) (-4152 . 119410) (-4153 . 119172) (-4154 . 118988) (-4155 . 118805) (-4156 . 118635) (-4157 . 118496) (-4158 . 118378) (-4159 . 118179) (-4160 . 118114) (-4161 . 117975) (-4162 . 117919) (-4163 . 117600) (-4164 . 117410) (-4165 . 117183) (-4166 . 113259) (-4167 . 113090) (-4168 . 113005) (-4169 . 112951) (-4170 . 111256) (-4171 . 111222) (-4172 . 110985) (-4173 . 110851) (-4174 . 110700) (-4175 . 109513) (-4176 . 109371) (-4177 . 109292) (-4178 . 109167) (-4179 . 109003) (-4180 . 108646) (-4181 . 108543) (-4182 . 107788) (-4183 . 107722) (-4184 . 107667) (-4185 . 107636) (-4186 . 107077) (-4187 . 106948) (-4188 . 106732) (-4189 . 106637) (-4190 . 106469) (-4191 . 106440) (-4192 . 106285) (-4193 . 106218) (-4194 . 106066) (-4195 . 105979) (-4196 . 105882) (-4197 . 105692) (-4198 . 104663) (-4199 . 104614) (-4200 . 104563) (-4201 . 104486) (-4202 . 104412) (-4203 . 104294) (-4204 . 104010) (-4205 . 103919) (-4206 . 103470) (-4207 . 103367) (-4208 . 103300) (-4209 . 103217) (-4210 . 102166) (-4211 . 102048) (-4212 . 101995) (-4213 . 101786) (-4214 . 101607) (-4215 . 101493) (-4216 . 101203) (-4217 . 101121) (-4218 . 101024) (-4219 . 100953) (-4220 . 100887) (-4221 . 100740) (-4222 . 100645) (-4223 . 100320) (-4224 . 100206) (-4225 . 100097) (-4226 . 99857) (-4227 . 99719) (-4228 . 99553) (-4229 . 99484) (-4230 . 99370) (-4231 . 99268) (-4232 . 98988) (-4233 . 98196) (-4234 . 98126) (-4235 . 98008) (-4236 . 97956) (-4237 . 97848) (-4238 . 97597) (-4239 . 97353) (-4240 . 97235) (-4241 . 97101) (-4242 . 96891) (-4243 . 96618) (-4244 . 96443) (-4245 . 96381) (-4246 . 95438) (-4247 . 95365) (-4248 . 95312) (-4249 . 94789) (-4250 . 94426) (-4251 . 94309) (-4252 . 94181) (-4253 . 93866) (-4254 . 93748) (-4255 . 93439) (-4256 . 93390) (-4257 . 93147) (-4258 . 93069) (-4259 . 92993) (-4260 . 92891) (-4261 . 92544) (-4262 . 92394) (-4263 . 92047) (-4264 . 91944) (-4265 . 91885) (-4266 . 91771) (-4267 . 91642) (-4268 . 91517) (-4269 . 91209) (-4270 . 90802) (-4271 . 90712) (-4272 . 90610) (-4273 . 90528) (-4274 . 90232) (-4275 . 90076) (-4276 . 89936) (-4277 . 89664) (-4278 . 89612) (-4279 . 89507) (-4280 . 89272) (-4281 . 89171) (-4282 . 89116) (-4283 . 88985) (-4284 . 88862) (-4285 . 88713) (-4286 . 88582) (-4287 . 88504) (-4288 . 88447) (-4289 . 88339) (-4290 . 87716) (-4291 . 87682) (-4292 . 87447) (-4293 . 87152) (-4294 . 87052) (-4295 . 86893) (-4296 . 86785) (-4297 . 86619) (-4298 . 86384) (-4299 . 86189) (-4300 . 86112) (-4301 . 86039) (-4302 . 85940) (-4303 . 85912) (-4304 . 84877) (-4305 . 84797) (-4306 . 84707) (-4307 . 84602) (-4308 . 84452) (-4309 . 84207) (-4310 . 84057) (-4311 . 83989) (-4312 . 83915) (-4313 . 83798) (-4314 . 83656) (-4315 . 83556) (-4316 . 83503) (-4317 . 83380) (-4318 . 83194) (-4319 . 83103) (-4320 . 82802) (-4321 . 82657) (-4322 . 82175) (-4323 . 82052) (-4324 . 82000) (-4325 . 81864) (-4326 . 81756) (-4327 . 81645) (-4328 . 81528) (-4329 . 81414) (-4330 . 81362) (-4331 . 81164) (-4332 . 81028) (-4333 . 80996) (-4334 . 80867) (-4335 . 80698) (-4336 . 80485) (-4337 . 80401) (-4338 . 80160) (-4339 . 80034) (-4340 . 79981) (-4341 . 79787) (-4342 . 79696) (-4343 . 79611) (-4344 . 79472) (-4345 . 78886) (-4346 . 76602) (-4347 . 76433) (-4348 . 75924) (-4349 . 75720) (-4350 . 75669) (-4351 . 71988) (-4352 . 71921) (-4353 . 71742) (-4354 . 71689) (-4355 . 70588) (-4356 . 70535) (-4357 . 70232) (-4358 . 70094) (-4359 . 69995) (-4360 . 69967) (-4361 . 69871) (-4362 . 69579) (-4363 . 69485) (-4364 . 69387) (-4365 . 68889) (-4366 . 68783) (-4367 . 68485) (-4368 . 64308) (-4369 . 63904) (-4370 . 63851) (-4371 . 63699) (-4372 . 63614) (-4373 . 63485) (-4374 . 63379) (-4375 . 63235) (-4376 . 62860) (-4377 . 62506) (-4378 . 62431) (-4379 . 62208) (-4380 . 62149) (-4381 . 62092) (-4382 . 61871) (-4383 . 61806) (-4384 . 61731) (-4385 . 61668) (-4386 . 61593) (-4387 . 61538) (-4388 . 61479) (-4389 . 60547) (-4390 . 60060) (-4391 . 59972) (-4392 . 59800) (-4393 . 59725) (-4394 . 59038) (-4395 . 58964) (-4396 . 58906) (-4397 . 58835) (-4398 . 58315) (-4399 . 58061) (-4400 . 58027) (-4401 . 57899) (-4402 . 57828) (-4403 . 57714) (-4404 . 57393) (-4405 . 57236) (-4406 . 56925) (-4407 . 56873) (-4408 . 56702) (-4409 . 56618) (-4410 . 56114) (-4411 . 56062) (-4412 . 55999) (-4413 . 55947) (-4414 . 55760) (-4415 . 55580) (-4416 . 55372) (-4417 . 55317) (-4418 . 55255) (-4419 . 55173) (-4420 . 55074) (-4421 . 54536) (-4422 . 54318) (-4423 . 54085) (-4424 . 53932) (-4425 . 53828) (-4426 . 53644) (-4427 . 53571) (-4428 . 53380) (-4429 . 53135) (-4430 . 52808) (-4431 . 52757) (-4432 . 52659) (-4433 . 52517) (-4434 . 52402) (-4435 . 52330) (-4436 . 52005) (-4437 . 51848) (-4438 . 51583) (-4439 . 51411) (-4440 . 51325) (-4441 . 51207) (-4442 . 50703) (-4443 . 50650) (-4444 . 50597) (-4445 . 50389) (-4446 . 50172) (-4447 . 50063) (-4448 . 49780) (-4449 . 49303) (-4450 . 49251) (-4451 . 49136) (-4452 . 49062) (-4453 . 48542) (-4454 . 48382) (-4455 . 48145) (-4456 . 48094) (-4457 . 47939) (-4458 . 47686) (-4459 . 47116) (-4460 . 47060) (-4461 . 46877) (-4462 . 46789) (-4463 . 46712) (-4464 . 46519) (-4465 . 46416) (-4466 . 43878) (-4467 . 43251) (-4468 . 43199) (-4469 . 43129) (-4470 . 42758) (-4471 . 42698) (-4472 . 42555) (-4473 . 42462) (-4474 . 40498) (-4475 . 40428) (-4476 . 40300) (-4477 . 40266) (-4478 . 40061) (-4479 . 40005) (-4480 . 37968) (-4481 . 37695) (-4482 . 37622) (-4483 . 37472) (-4484 . 37419) (-4485 . 37170) (-4486 . 37108) (-4487 . 36921) (-4488 . 36728) (-4489 . 36529) (-4490 . 36394) (-4491 . 35818) (-4492 . 34353) (-4493 . 34144) (-4494 . 34077) (-4495 . 33995) (-4496 . 33913) (-4497 . 33844) (-4498 . 33740) (-4499 . 33484) (-4500 . 27902) (-4501 . 27667) (-4502 . 27614) (-4503 . 27491) (-4504 . 27388) (-4505 . 27305) (-4506 . 26968) (-4507 . 25981) (-4508 . 25816) (-4509 . 25631) (-4510 . 25546) (-4511 . 25457) (-4512 . 25379) (-4513 . 25326) (-4514 . 25191) (-4515 . 25040) (-4516 . 24684) (-4517 . 24368) (-4518 . 24090) (-4519 . 23937) (-4520 . 23863) (-4521 . 23706) (-4522 . 23355) (-4523 . 23281) (-4524 . 23042) (-4525 . 20599) (-4526 . 19049) (-4527 . 18924) (-4528 . 18574) (-4529 . 18166) (-4530 . 17492) (-4531 . 17295) (-4532 . 17185) (-4533 . 16369) (-4534 . 16184) (-4535 . 16064) (-4536 . 16012) (-4537 . 15641) (-4538 . 15576) (-4539 . 15508) (-4540 . 15253) (-4541 . 15178) (-4542 . 15089) (-4543 . 14955) (-4544 . 14847) (-4545 . 14645) (-4546 . 13468) (-4547 . 13412) (-4548 . 13356) (-4549 . 13203) (-4550 . 12631) (-4551 . 12265) (-4552 . 11559) (-4553 . 11355) (-4554 . 11236) (-4555 . 11101) (-4556 . 10897) (-4557 . 10824) (-4558 . 10690) (-4559 . 10377) (-4560 . 9948) (-4561 . 9917) (-4562 . 9834) (-4563 . 9645) (-4564 . 9321) (-4565 . 9195) (-4566 . 8888) (-4567 . 8807) (-4568 . 8699) (-4569 . 8542) (-4570 . 7982) (-4571 . 7818) (-4572 . 7441) (-4573 . 6835) (-4574 . 6573) (-4575 . 6380) (-4576 . 6291) (-4577 . 6056) (-4578 . 5937) (-4579 . 4821) (-4580 . 4581) (-4581 . 4497) (-4582 . 4404) (-4583 . 4304) (-4584 . 4133) (-4585 . 4023) (-4586 . 3813) (-4587 . 3691) (-4588 . 3662) (-4589 . 3609) (-4590 . 3546) (-4591 . 3496) (-4592 . 3380) (-4593 . 2247) (-4594 . 2115) (-4595 . 2043) (-4596 . 1803) (-4597 . 1695) (-4598 . 1597) (-4599 . 1014) (-4600 . 910) (-4601 . 575) (-4602 . 427) (-4603 . 279) (-4604 . 101) (-4605 . 30)) 
\ No newline at end of file
diff --git a/src/share/algebra/users.daase/index.kaf b/src/share/algebra/users.daase/index.kaf
index d60dd34..4909966 100644
--- a/src/share/algebra/users.daase/index.kaf
+++ b/src/share/algebra/users.daase/index.kaf
@@ -1,4 +1,4 @@
-235020              (|ProjectiveAlgebraicSetPackage|)
+236822              (|ProjectiveAlgebraicSetPackage|)
 (|ProjectiveAlgebraicSetPackage|)
 (|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |BlowUpPackage| |DesingTreePackage| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField|)
 (|AffinePlane|)
@@ -54,10 +54,11 @@
 (|ExpertSystemContinuityPackage|)
 (|AlgebraicFunction| |AlgebraicManipulations| |AlgebraicNumber| |ApplyRules| |Asp8| |BasicOperatorFunctions1| |CombinatorialFunction| |CommonOperators| |ComplexTrigonometricManipulations| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |FortranExpression| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |Guess| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationTools| |Kernel| |KernelFunctions2| |LaplaceTransform| |LiouvillianFunction| |ModuleOperator| |MyExpression| |NonLinearFirstOrderODESolver| |Operator| |Pattern| |PatternFunctions2| |PatternMatchKernel| |PatternMatchPushDown| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |RecurrenceOperator| |Switch| |TranscendentalManipulations| |TrigonometricManipulations| |d01WeightsPackage| |d01anfAnnaType| |d01asfAnnaType|)
 (|AlgebraicFunction| |CombinatorialFunction| |ElementaryFunction| |ExpressionSpace&| |FunctionSpace&| |FunctionalSpecialFunction| |KernelFunctions2| |LiouvillianFunction| |RecurrenceOperator|)
+(|StochasticDifferential|)
 (|BalancedBinaryTree| |BinarySearchTree| |BinaryTournament|)
 (|SetOfMIntegersInOneToN|)
 (|DesingTreePackage|)
-(|AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |AnyFunctions1| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BasicType&| |BezoutMatrix| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |BitAggregate&| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclicStreamTools| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |EvaluateCycleIndicators| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemContinuityPackage1| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |FGLMIfCanPackage| |Factored| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |File| |FileName| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerLinearDependence| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegralDomain&| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KeyedAccessFile| |KeyedDictionary&| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagPolynomialRootsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |None| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedSet&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |Palette| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |Pattern| |PatternFunctions1| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PolToPol| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SegmentFunctions2| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamTaylorSeriesOperations| |StreamTensor| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |TableauxBumpers| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U32Vector| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UniversalSegmentFunctions2| |UserDefinedPartialOrdering| |Variable| |Vector| |VectorFunctions2| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |AnyFunctions1| |ApplicationProgramInterface| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BasicType&| |BezoutMatrix| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |BitAggregate&| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclicStreamTools| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |EvaluateCycleIndicators| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemContinuityPackage1| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |FGLMIfCanPackage| |Factored| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |File| |FileName| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerLinearDependence| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegralDomain&| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KeyedAccessFile| |KeyedDictionary&| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagPolynomialRootsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |None| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedSet&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |Palette| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |Pattern| |PatternFunctions1| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PolToPol| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SegmentFunctions2| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamTaylorSeriesOperations| |StreamTensor| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |TableauxBumpers| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UniversalSegmentFunctions2| |UserDefinedPartialOrdering| |Variable| |Vector| |VectorFunctions2| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|PrimitiveRatDE| |RationalLODE|)
 (|GaloisGroupFactorizer|)
 (|CliffordAlgebra| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |Equation| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |HomogeneousDirectProduct| |InnerFiniteField| |InnerPrimeField| |OrderedDirectProduct| |PrimeField| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |RectangularMatrix| |SplitHomogeneousDirectProduct|)
@@ -117,7 +118,7 @@
 (|FunctionSpaceComplexIntegration| |FunctionSpaceIntegration|)
 (|ElementaryIntegration|)
 (|ElementaryIntegration|)
-(|AlgebraicNumber| |ApplyRules| |ArrayStack| |AssociationList| |BalancedBinaryTree| |BalancedPAdicRational| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |CharacterClass| |Complex| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |DataList| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |DoubleFloatMatrix| |DoubleFloatVector| |EigenPackage| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |EqTable| |Equation| |EquationFunctions2| |Evalable&| |ExpertSystemContinuityPackage| |ExponentialExpansion| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FlexibleArray| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FortranProgram| |Fraction| |FullyEvalableOver&| |FunctionSpace&| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InnerAlgebraicNumber| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |InnerTable| |KeyedAccessFile| |LaplaceTransform| |Library| |LieExponentials| |LieSquareMatrix| |List| |ListMultiDictionary| |MachineComplex| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |Octonion| |OneDimensionalArray| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PatternMatch| |PendantTree| |Point| |Polynomial| |PolynomialCategory&| |PolynomialIdeals| |PowerSeriesLimitPackage| |PrimitiveArray| |Quaternion| |Queue| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionLimitPackage| |RationalRicDE| |RectangularMatrix| |RecurrenceOperator| |RegularChain| |RegularTriangularSet| |Result| |RetractSolvePackage| |RewriteRule| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |Stream| |String| |StringTable| |SystemSolvePackage| |Table| |TaylorSeries| |ThreeDimensionalMatrix| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |Tree| |TwoDimensionalArray| |U32Vector| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |Vector| |WuWenTsunTriangularSet| |d01AgentsPackage| |d01TransformFunctionType| |d02AgentsPackage| |d03AgentsPackage|)
+(|AlgebraicNumber| |ApplyRules| |ArrayStack| |AssociationList| |BalancedBinaryTree| |BalancedPAdicRational| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |CharacterClass| |Complex| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |DataList| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |DoubleFloatMatrix| |DoubleFloatVector| |EigenPackage| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |EqTable| |Equation| |EquationFunctions2| |Evalable&| |ExpertSystemContinuityPackage| |ExponentialExpansion| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FlexibleArray| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FortranProgram| |Fraction| |FullyEvalableOver&| |FunctionSpace&| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InnerAlgebraicNumber| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |InnerTable| |KeyedAccessFile| |LaplaceTransform| |Library| |LieExponentials| |LieSquareMatrix| |List| |ListMultiDictionary| |MachineComplex| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |Octonion| |OneDimensionalArray| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PatternMatch| |PendantTree| |Point| |Polynomial| |PolynomialCategory&| |PolynomialIdeals| |PowerSeriesLimitPackage| |PrimitiveArray| |Quaternion| |Queue| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionLimitPackage| |RationalRicDE| |RectangularMatrix| |RecurrenceOperator| |RegularChain| |RegularTriangularSet| |Result| |RetractSolvePackage| |RewriteRule| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |StochasticDifferential| |Stream| |String| |StringTable| |SystemSolvePackage| |Table| |TaylorSeries| |ThreeDimensionalMatrix| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |Tree| |TwoDimensionalArray| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |Vector| |WuWenTsunTriangularSet| |d01AgentsPackage| |d01TransformFunctionType| |d02AgentsPackage| |d03AgentsPackage|)
 (|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AttributeButtons| |RoutinesTable| |d01AgentsPackage|)
 (|ParametricLinearEquations|)
 (|InnerModularGcd|)
@@ -128,12 +129,12 @@
 (|d02AgentsPackage| |e04nafAnnaType|)
 (|FunctionSpaceToExponentialExpansion|)
 (|ExponentialExpansion| |FunctionSpaceToExponentialExpansion| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
-(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |ComplexTrigonometricManipulations| |DeRhamComplex| |DegreeReductionPackage| |DrawNumericHack| |ElementaryFunctionSign| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpressionFunctions2| |ExpressionToOpenMath| |ExpressionTubePlot| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranProgram| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |GnuDraw| |GuessAlgebraicNumber| |GuessFinite| |GuessFiniteFunctions| |GuessInteger| |GuessPolynomial| |InnerAlgebraicNumber| |IntegrationResultRFToFunction| |MachineInteger| |MappingPackage4| |MeshCreationRoutinesForThreeDimensions| |MyExpression| |Numeric| |PatternMatchAssertions| |PiCoercions| |PolynomialAN2Expression| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SimplifyAlgebraicNumberConvertPackage| |Switch| |ToolsForSign| |TransSolvePackage| |TransSolvePackageService| |TrigonometricManipulations| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |ComplexTrigonometricManipulations| |DeRhamComplex| |DegreeReductionPackage| |DrawNumericHack| |ElementaryFunctionSign| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpressionFunctions2| |ExpressionToOpenMath| |ExpressionTubePlot| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranProgram| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |GnuDraw| |GuessAlgebraicNumber| |GuessFinite| |GuessFiniteFunctions| |GuessInteger| |GuessPolynomial| |InnerAlgebraicNumber| |IntegrationResultRFToFunction| |MachineInteger| |MappingPackage4| |MeshCreationRoutinesForThreeDimensions| |MyExpression| |Numeric| |PatternMatchAssertions| |PiCoercions| |PolynomialAN2Expression| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SimplifyAlgebraicNumberConvertPackage| |StochasticDifferential| |Switch| |ToolsForSign| |TransSolvePackage| |TransSolvePackageService| |TrigonometricManipulations| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|AnnaOrdinaryDifferentialEquationPackage| |ExpertSystemToolsPackage| |FortranExpression| |InnerAlgebraicNumber| |MachineInteger| |Numeric| |TransSolvePackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |e04AgentsPackage|)
 (|RecurrenceOperator|)
 (|Expression| |ExpressionFunctions2| |FunctionSpaceFunctions2| |InnerTrigonometricManipulations|)
 (|AntiSymm| |DeRhamComplex|)
-(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicMultFact| |AlgebraicNumber| |BalancedFactorisation| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DirichletRing| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DoubleFloat| |EigenPackage| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |Equation| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSquareFreeDecomposition| |Float| |Fraction| |FullPartialFractionExpansion| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerSolve| |Guess| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNumericEigenPackage| |InnerPrimeField| |Integer| |IntegerFactorizationPackage| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LinearOrdinaryDifferentialOperatorFactorizer| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonomialExtensionTools| |MultFiniteFactorize| |MultivariateFactorize| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NumberFieldIntegralBasis| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |Pi| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuasiAlgebraicSet| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionSign| |RationalRicDE| |RealClosure| |RealZeroPackage| |RomanNumeral| |RootsFindingPackage| |SAERationalFunctionAlgFactor| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SturmHabichtPackage| |SupFractionFactorizer| |SystemSolvePackage| |TransSolvePackage| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WildFunctionFieldIntegralBasis|)
+(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicMultFact| |AlgebraicNumber| |BalancedFactorisation| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DirichletRing| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DoubleFloat| |EigenPackage| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |Equation| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSquareFreeDecomposition| |Float| |Fraction| |FullPartialFractionExpansion| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerSolve| |Guess| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNumericEigenPackage| |InnerPrimeField| |Integer| |IntegerFactorizationPackage| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LinearOrdinaryDifferentialOperatorFactorizer| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonomialExtensionTools| |MultFiniteFactorize| |MultivariateFactorize| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NumberFieldIntegralBasis| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |Pi| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuasiAlgebraicSet| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionSign| |RationalRicDE| |RealClosure| |RealZeroPackage| |RomanNumeral| |RootsFindingPackage| |SAERationalFunctionAlgFactor| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SturmHabichtPackage| |SupFractionFactorizer| |SystemSolvePackage| |TransSolvePackage| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WildFunctionFieldIntegralBasis|)
 (|ComplexCategory&| |Integer| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate|)
 (|ChangeOfVariable| |PolynomialRoots| |TranscendentalManipulations|)
 (|FunctionSpaceUnivariatePolynomialFactor| |Integer| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |RationalFunctionFactor| |UnivariatePolynomialCategory&|)
@@ -152,7 +153,7 @@
 (|FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension|)
 (|FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldExtension| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldPolynomialPackage2| |MultFiniteFactorize|)
 (|SparseUnivariatePolynomial|)
-(|FiniteFieldFactorizationWithSizeParseBySideEffect|)
+(|FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect|)
 (|DirectProductFunctions2| |InnerCommonDenominator| |ListFunctions2| |MatrixLinearAlgebraFunctions| |OneDimensionalArrayFunctions2| |PrimitiveArrayFunctions2| |VectorFunctions2|)
 (|OneDimensionalArrayAggregate&|)
 (|GaloisGroupUtilities|)
@@ -165,7 +166,7 @@
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranPackage| |FortranType| |SimpleFortranProgram| |SymbolTable|)
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranCode| |FortranPackage| |SymbolTable| |TheSymbolTable|)
 (|FourierSeries|)
-(|AbelianMonoidRing&| |AlgFactor| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp31| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp80| |Asp9| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |CoerceVectorMatrixPackage| |CombinatorialFunction| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ContinuedFraction| |CycleIndicators| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DoubleResultantPackage| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionFunctions2| |FractionalIdeal| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |GuessInteger| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerModularGcd| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |Integer| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieSquareMatrix| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |NormalizationPackage| |NumberTheoreticPolynomialFunctions| |Numeric| |ODEIntegration| |Octonion| |OctonionCategory&| |OnePointCompletion| |OrderedCompletion| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrthogonalPolynomialFunctions| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursionUnivariate| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PureAlgebraicLODE| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StructuralConstantsPackage| |SturmHabichtPackage| |SupFractionFactorizer| |SymmetricPolynomial| |SystemSolvePackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ToolsForSign| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |TwoDimensionalPlotClipping| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |XExponentialPackage| |XPBWPolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01WeightsPackage| |d01aqfAnnaType| |d02AgentsPackage| |e04AgentsPackage| |e04ucfAnnaType|)
+(|AbelianMonoidRing&| |AlgFactor| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp31| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp80| |Asp9| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |CoerceVectorMatrixPackage| |CombinatorialFunction| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ContinuedFraction| |CycleIndicators| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DoubleResultantPackage| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionFunctions2| |FractionalIdeal| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |GuessInteger| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerModularGcd| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |Integer| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieSquareMatrix| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |NormalizationPackage| |NumberTheoreticPolynomialFunctions| |Numeric| |ODEIntegration| |Octonion| |OctonionCategory&| |OnePointCompletion| |OrderedCompletion| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrthogonalPolynomialFunctions| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursionUnivariate| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PureAlgebraicLODE| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StructuralConstantsPackage| |SturmHabichtPackage| |SupFractionFactorizer| |SymmetricPolynomial| |SystemSolvePackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ToolsForSign| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |TwoDimensionalPlotClipping| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |XExponentialPackage| |XPBWPolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01WeightsPackage| |d01aqfAnnaType| |d02AgentsPackage| |e04AgentsPackage| |e04ucfAnnaType|)
 (|FractionFreeFastGaussianFractions| |Guess|)
 (|Guess|)
 (|FiniteDivisor| |FiniteDivisorFunctions2| |FractionalIdealFunctions2| |FramedModule| |HyperellipticFiniteDivisor| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational|)
@@ -223,7 +224,7 @@
 (|IndexedDirectProductAbelianMonoid|)
 (|IndexedDirectProductOrderedAbelianMonoidSup|)
 (|IndexedExponents|)
-(|DifferentialSparseMultivariatePolynomial| |Expression| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |OrderlyDifferentialPolynomial| |Polynomial| |SequentialDifferentialPolynomial| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |TaylorSeries|)
+(|DifferentialSparseMultivariatePolynomial| |Expression| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |OrderlyDifferentialPolynomial| |Polynomial| |SequentialDifferentialPolynomial| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |StochasticDifferential| |TaylorSeries|)
 (|FlexibleArray| |Heap| |IntegerCombinatoricFunctions| |IntegerNumberTheoryFunctions|)
 (|List|)
 (|IndexedTwoDimensionalArray| |IndexedVector| |OneDimensionalArray|)
@@ -252,9 +253,9 @@
 (|Table|)
 (|SparseMultivariateTaylorSeries| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
 (|ComplexTrigonometricManipulations| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |TrigonometricManipulations|)
-(|AssociationList| |BalancedPAdicRational| |BasicOperatorFunctions1| |BinaryExpansion| |Bits| |Boolean| |CharacterClass| |CommonOperators| |Complex| |ComplexCategory&| |ComplexDoubleFloatVector| |DataList| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleFloatVector| |EqTable| |ExponentialExpansion| |Export3D| |Expression| |Factored| |FlexibleArray| |Float| |FortranPackage| |FortranProgram| |Fraction| |FunctionSpace&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GnuDraw| |HashTable| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerTable| |InputFormFunctions1| |Integer| |IntegerNumberSystem&| |Kernel| |KeyedAccessFile| |Library| |LiouvillianFunction| |List| |ListMultiDictionary| |MachineComplex| |MachineInteger| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OpenMathPackage| |OrderedVariableList| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |Pi| |Point| |Polynomial| |PolynomialCategory&| |PrimitiveArray| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadixExpansion| |RectangularMatrix| |RecursivePolynomialCategory&| |RegularChain| |RegularTriangularSet| |Result| |RomanNumeral| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SingleInteger| |SparseMultivariatePolynomial| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |Table| |TemplateUtilities| |TopLevelDrawFunctions| |U32Vector| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |Vector| |WuWenTsunTriangularSet|)
+(|AssociationList| |BalancedPAdicRational| |BasicOperatorFunctions1| |BinaryExpansion| |Bits| |Boolean| |CharacterClass| |CommonOperators| |Complex| |ComplexCategory&| |ComplexDoubleFloatVector| |DataList| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleFloatVector| |EqTable| |ExponentialExpansion| |Export3D| |Expression| |Factored| |FlexibleArray| |Float| |FortranPackage| |FortranProgram| |Fraction| |FunctionSpace&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GnuDraw| |HashTable| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerTable| |InputFormFunctions1| |Integer| |IntegerNumberSystem&| |Kernel| |KeyedAccessFile| |Library| |LiouvillianFunction| |List| |ListMultiDictionary| |MachineComplex| |MachineInteger| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OpenMathPackage| |OrderedVariableList| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |Pi| |Point| |Polynomial| |PolynomialCategory&| |PrimitiveArray| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadixExpansion| |RectangularMatrix| |RecursivePolynomialCategory&| |RegularChain| |RegularTriangularSet| |Result| |RomanNumeral| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SingleInteger| |SparseMultivariatePolynomial| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |Table| |TemplateUtilities| |TopLevelDrawFunctions| |U16Vector| |U32Vector| |U8Vector| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |Vector| |WuWenTsunTriangularSet|)
 (|FunctionSpace&|)
-(|AbelianGroup&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ArrayStack| |Asp10| |Asp19| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp55| |Asp73| |Asp74| |Asp77| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |Bezier| |BezoutMatrix| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Color| |CombinatorialFunction| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |EigenPackage| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtensibleLinearAggregate&| |Factored| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingPointSystem&| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GrayCode| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Group&| |Guess| |GuessFinite| |GuessFiniteFunctions| |HTMLFormat| |HallBasis| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperbolicFunctionCategory&| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfinitlyClosePoint| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |LeftAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListToMap| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |MakeFloatCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonAssociativeRing&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |PartitionsAndPermutations| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPolynomialCategory| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |PiCoercions| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialCategory&| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RationalFactorize| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReductionOfOrder| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stream| |StreamAggregate&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StructuralConstantsPackage| |SturmHabichtPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TemplateUtilities| |TexFormat| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U32Vector| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |Vector| |VectorCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianGroup&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ArrayStack| |Asp10| |Asp19| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp55| |Asp73| |Asp74| |Asp77| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |Bezier| |BezoutMatrix| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Color| |CombinatorialFunction| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |EigenPackage| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtensibleLinearAggregate&| |Factored| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingPointSystem&| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GrayCode| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Group&| |Guess| |GuessFinite| |GuessFiniteFunctions| |HTMLFormat| |HallBasis| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperbolicFunctionCategory&| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfinitlyClosePoint| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |LeftAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListToMap| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |MakeFloatCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonAssociativeRing&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |PartitionsAndPermutations| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPolynomialCategory| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |PiCoercions| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialCategory&| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RationalFactorize| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReductionOfOrder| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |StochasticDifferential| |Stream| |StreamAggregate&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StructuralConstantsPackage| |SturmHabichtPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TemplateUtilities| |TexFormat| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |Vector| |VectorCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|RandomIntegerDistributions|)
 (|ComplexRootFindingPackage| |GaloisGroupUtilities| |Guess| |IntegerNumberSystem&| |IrrRepSymNatPackage| |MultivariateLifting| |RepresentationPackage1| |SetOfMIntegersInOneToN| |SymmetricGroupCombinatoricFunctions|)
 (|CyclotomicPolynomialPackage| |Factored| |GaussianFactorizationPackage| |IntegerNumberSystem&| |NumberFieldIntegralBasis|)
@@ -301,8 +302,8 @@
 (|SystemSolvePackage|)
 (|InterpolateFormsPackage| |LinearSystemFromPowerSeriesPackage|)
 (|Expression| |PowerSeriesLimitPackage|)
-(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttachPredicates| |AttributeButtons| |AxiomServer| |BagAggregate&| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |Bezier| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |BoundIntegerRoots| |CRApackage| |CardinalNumber| |CartesianTensor| |CartesianTensorFunctions2| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DictionaryOperations&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DisplayPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |ErrorFunctions| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Evalable&| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |FGLMIfCanPackage| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GnuDraw| |GosperSummationMethod| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductObject| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerEvalable&| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegrationFunctionsTable| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |Kernel| |KernelFunctions2| |KeyedAccessFile| |KeyedDictionary&| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListFunctions2| |ListFunctions3| |ListMonoidOps| |ListMultiDictionary| |ListToMap| |LocalParametrizationOfSimplePointPackage| |LyndonWord| |MPolyCatFunctions2| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonoidRingFunctions2| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormRetractPackage| |NormalizationPackage| |NumberFieldIntegralBasis| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODEIntensityFunctionsTable| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathError| |OpenMathPackage| |OppositeMonogenicLinearOperator| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximants| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |PartialFractionPackage| |Partition| |PartitionsAndPermutations| |Pattern| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchTools| |PendantTree| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolyGroebner| |Polynomial| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSign| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetAggregate&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SmithNormalForm| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |Stream| |StreamAggregate&| |StreamFunctions2| |StreamTaylorSeriesOperations| |StreamTensor| |StreamTranscendentalFunctions| |String| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TexFormat| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U32Vector| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |VectorCategory&| |VectorFunctions2| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
-(|AlgebraPackage| |Asp19| |Asp55| |DirichletRing| |ElementaryFunctionSign| |FiniteSetAggregateFunctions2| |FramedNonAssociativeAlgebra&| |GaloisGroupFactorizer| |GenericNonAssociativeAlgebra| |Guess| |LieSquareMatrix| |MatrixCommonDenominator| |PAdicWildFunctionFieldIntegralBasis| |PermutationGroupExamples| |RealSolvePackage| |TaylorSolve| |ThreeSpace| |TwoDimensionalPlotClipping| |UnivariateTaylorSeriesODESolver|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttachPredicates| |AttributeButtons| |AxiomServer| |BagAggregate&| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |Bezier| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |CRApackage| |CardinalNumber| |CartesianTensor| |CartesianTensorFunctions2| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DictionaryOperations&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DisplayPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |ErrorFunctions| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Evalable&| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |FGLMIfCanPackage| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |Finite&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GnuDraw| |GosperSummationMethod| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductObject| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerEvalable&| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegrationFunctionsTable| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |Kernel| |KernelFunctions2| |KeyedAccessFile| |KeyedDictionary&| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListFunctions2| |ListFunctions3| |ListMonoidOps| |ListMultiDictionary| |ListToMap| |LocalParametrizationOfSimplePointPackage| |LyndonWord| |MPolyCatFunctions2| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonoidRingFunctions2| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormRetractPackage| |NormalizationPackage| |NumberFieldIntegralBasis| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODEIntensityFunctionsTable| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathError| |OpenMathPackage| |OppositeMonogenicLinearOperator| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximants| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |PartialFractionPackage| |Partition| |PartitionsAndPermutations| |Pattern| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchTools| |PendantTree| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolyGroebner| |Polynomial| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSign| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetAggregate&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SmithNormalForm| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |Stream| |StreamAggregate&| |StreamFunctions2| |StreamTaylorSeriesOperations| |StreamTensor| |StreamTranscendentalFunctions| |String| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TexFormat| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |VectorCategory&| |VectorFunctions2| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AlgebraPackage| |Asp19| |Asp55| |DirichletRing| |ElementaryFunctionSign| |FiniteSetAggregateFunctions2| |FramedNonAssociativeAlgebra&| |GaloisGroupFactorizer| |GenericNonAssociativeAlgebra| |Guess| |LieSquareMatrix| |MatrixCommonDenominator| |MatrixManipulation| |PAdicWildFunctionFieldIntegralBasis| |PermutationGroupExamples| |RealSolvePackage| |TaylorSolve| |ThreeSpace| |TwoDimensionalPlotClipping| |UnivariateTaylorSeriesODESolver|)
 (|FreeGroup| |FreeMonoid| |InnerFreeAbelianMonoid|)
 (|IntegerFactorizationPackage|)
 (|Expression| |FunctionSpace&| |RationalFunction|)
@@ -366,7 +367,7 @@
 (|BlowUpPackage|)
 (|ElementaryFunctionODESolver|)
 (|RationalRicDE|)
-(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |ArrayStack| |Asp19| |Asp20| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp41| |Asp42| |Asp55| |Asp74| |Asp77| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |Automorphism| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicOperator| |BasicOperatorFunctions1| |BezoutMatrix| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |Bits| |BlowUpPackage| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CRApackage| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |CommonOperators| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CyclicStreamTools| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialRing&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DoubleResultantPackage| |DrawComplex| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |EuclideanDomain&| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FieldOfPrimeCharacteristic&| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GrayCode| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerSolve| |Group&| |Guess| |GuessOption| |GuessOptionFunctions0| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KernelFunctions2| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MakeCachableSet| |MappingPackage1| |MappingPackageInternalHacks1| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |ParametricPlaneCurve| |ParametricPlaneCurveFunctions2| |ParametricSpaceCurve| |ParametricSpaceCurveFunctions2| |ParametricSurface| |ParametricSurfaceFunctions2| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |Partition| |Pattern| |PatternFunctions2| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPushDown| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |PoincareBirkhoffWittLyndonBasis| |Point| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolationAlgorithms| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpressionOf| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U32Vector| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Vector| |VectorCategory&| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01aqfAnnaType| |d01fcfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |ArrayStack| |Asp19| |Asp20| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp41| |Asp42| |Asp55| |Asp74| |Asp77| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |Automorphism| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicOperator| |BasicOperatorFunctions1| |BezoutMatrix| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |Bits| |BlowUpPackage| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CRApackage| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |CommonOperators| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CyclicStreamTools| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialRing&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DoubleResultantPackage| |DrawComplex| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |EuclideanDomain&| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FieldOfPrimeCharacteristic&| |FindOrderFinite| |Finite&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GrayCode| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerSolve| |Group&| |Guess| |GuessOption| |GuessOptionFunctions0| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KernelFunctions2| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MakeCachableSet| |MappingPackage1| |MappingPackageInternalHacks1| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |ParametricPlaneCurve| |ParametricPlaneCurveFunctions2| |ParametricSpaceCurve| |ParametricSpaceCurveFunctions2| |ParametricSurface| |ParametricSurfaceFunctions2| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |Partition| |Pattern| |PatternFunctions2| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPushDown| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |PoincareBirkhoffWittLyndonBasis| |Point| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolationAlgorithms| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpressionOf| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Vector| |VectorCategory&| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01aqfAnnaType| |d01fcfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|AlgebraicFunction| |Any| |AnyFunctions1| |BasicOperator| |BasicOperatorFunctions1| |CombinatorialFunction| |CommonOperators| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionalSpecialFunction| |LaplaceTransform| |LiouvillianFunction| |ModuleOperator| |NoneFunctions1| |RecurrenceOperator|)
 (|AnyFunctions1| |ModuleOperator|)
 (|InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |LexTriangularPackage| |RationalUnivariateRepresentationPackage| |ZeroDimensionalSolvePackage|)
@@ -397,7 +398,7 @@
 (|AffineAlgebraicSetComputeWithGroebnerBasis| |DesingTreePackage| |DistributedMultivariatePolynomial| |FGLMIfCanPackage| |GeneralDistributedMultivariatePolynomial| |GroebnerSolve| |Guess| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InterpolateFormsPackage| |LexTriangularPackage| |LinGroebnerPackage| |LocalParametrizationOfSimplePointPackage| |MultivariatePolynomial| |PolToPol| |ProjectiveAlgebraicSetPackage| |QuasiAlgebraicSet2| |RationalUnivariateRepresentationPackage| |RegularChain| |ZeroDimensionalSolvePackage|)
 (|FullPartialFractionExpansion|)
 (|FullPartialFractionExpansion| |LinearOrdinaryDifferentialOperatorsOps| |OrderlyDifferentialPolynomial|)
-(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CRApackage| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DictionaryOperations&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionODESolver| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EqTable| |Equation| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionToOpenMath| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionSpace&| |GaloisGroupFactorizationUtilities| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteTuple| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |LeftAlgebra&| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixCategory&| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeRing&| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PrimeField| |PrimitiveArray| |PrintPackage| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |QuotientFieldCategory&| |RadicalFunctionField| |RadixExpansion| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealZeroPackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |ScriptFormulaFormat1| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |SquareMatrixCategory&| |Stack| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TexFormat1| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctionsForCompiledFunctions| |Tree| |TriangularSetCategory&| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalViewport| |U32Vector| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UniversalSegment| |Variable| |Vector| |Void| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CRApackage| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DictionaryOperations&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionODESolver| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EqTable| |Equation| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionToOpenMath| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionSpace&| |GaloisGroupFactorizationUtilities| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteTuple| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |LeftAlgebra&| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixCategory&| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeRing&| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PrimeField| |PrimitiveArray| |PrintPackage| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |QuotientFieldCategory&| |RadicalFunctionField| |RadixExpansion| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealZeroPackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |ScriptFormulaFormat1| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TexFormat1| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctionsForCompiledFunctions| |Tree| |TriangularSetCategory&| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalViewport| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UniversalSegment| |Variable| |Vector| |Void| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|DirichletRing| |GenUFactorize| |Guess| |IndexCard| |InternalRationalUnivariateRepresentationPackage| |NormalizationPackage| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |SparseUnivariatePolynomialExpressions| |TabulatedComputationPackage| |TaylorSolve| |ZeroDimensionalSolvePackage|)
 (|PAdicRational|)
 (|BalancedPAdicRational| |PAdicRational|)
@@ -460,11 +461,11 @@
 (|InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |QuasiComponentPackage| |RationalUnivariateRepresentationPackage| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |WuWenTsunTriangularSet| |ZeroDimensionalSolvePackage|)
 (|RadicalSolvePackage|)
 (|PolynomialCategory&|)
-(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AbelianSemiGroup&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |Asp19| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AttributeButtons| |Automorphism| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |Bezier| |BinaryExpansion| |BlowUpPackage| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |Complex| |ComplexCategory&| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DesingTreePackage| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatSpecialFunctions| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionTubePlot| |Factored| |FactoringUtilities| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |Float| |FloatingPointSystem&| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GnuDraw| |GraphImage| |GrayCode| |Group&| |Guess| |GuessOptionFunctions0| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LiouvillianFunction| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularField| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |Monad&| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MultFiniteFactorize| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NagEigenPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeAlgebra&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |Numeric| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |ParametricLinearEquations| |PartialFraction| |Partition| |PatternMatchIntegration| |Permanent| |Permutation| |PermutationGroupExamples| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialSolveByFormulas| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RealClosedField&| |RealClosure| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RecursivePolynomialCategory&| |ReduceLODE| |RegularTriangularSetCategory&| |RepeatedDoubling| |RepeatedSquaring| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |Ruleset| |SemiGroup&| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamTranscendentalFunctions| |SturmHabichtPackage| |SubSpace| |SymmetricFunctions| |SymmetricPolynomial| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TubePlotTools| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AbelianSemiGroup&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |Asp19| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AttributeButtons| |Automorphism| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |Bezier| |BinaryExpansion| |BlowUpPackage| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |Complex| |ComplexCategory&| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DesingTreePackage| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatSpecialFunctions| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionTubePlot| |Factored| |FactoringUtilities| |Finite&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |Float| |FloatingPointSystem&| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GnuDraw| |GraphImage| |GrayCode| |Group&| |Guess| |GuessOptionFunctions0| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LiouvillianFunction| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MatrixManipulation| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularField| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |Monad&| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MultFiniteFactorize| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NagEigenPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeAlgebra&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |Numeric| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |ParametricLinearEquations| |PartialFraction| |Partition| |PatternMatchIntegration| |Permanent| |Permutation| |PermutationGroupExamples| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialSolveByFormulas| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RealClosedField&| |RealClosure| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RecursivePolynomialCategory&| |ReduceLODE| |RegularTriangularSetCategory&| |RepeatedDoubling| |RepeatedSquaring| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |Ruleset| |SemiGroup&| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StochasticDifferential| |StreamTranscendentalFunctions| |SturmHabichtPackage| |SubSpace| |SymmetricFunctions| |SymmetricPolynomial| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TubePlotTools| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U32VectorPolynomialOperations| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|DefiniteIntegrationTools| |ElementaryFunctionSign| |LaplaceTransform| |d01AgentsPackage|)
 (|AssociatedEquations|)
 (|FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldNormalBasis| |InterfaceGroebnerPackage|)
-(|BlasLevelOne| |Character| |DistinctDegreeFactorize| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |IndexedFlexibleArray| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |LinearSystemMatrixPackage| |MatrixLinearAlgebraFunctions| |ModMonic| |NumberFormats| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |RadicalFunctionField| |ReductionOfOrder| |StorageEfficientMatrixOperations| |SubResultantPackage| |Symbol| |ThreeDimensionalMatrix| |TranscendentalIntegration| |Tuple|)
+(|BlasLevelOne| |Character| |DistinctDegreeFactorize| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |IndexedFlexibleArray| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |LinearSystemMatrixPackage| |MatrixLinearAlgebraFunctions| |ModMonic| |NumberFormats| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |RadicalFunctionField| |ReductionOfOrder| |StorageEfficientMatrixOperations| |SubResultantPackage| |Symbol| |ThreeDimensionalMatrix| |TranscendentalIntegration| |Tuple| |U32VectorPolynomialOperations|)
 (|FunctionSpacePrimitiveElement|)
 (|PrimitiveRatRicDE| |RationalLODE| |RationalRicDE|)
 (|RationalRicDE|)
@@ -521,21 +522,21 @@
 (|Any| |AnyFunctions1| |ApplicationProgramInterface| |AxiomServer| |FortranCode| |FortranPackage| |FortranProgram| |FortranScalarType| |InputForm| |NAGLinkSupportPackage| |NumberFormats| |OpenMathPackage| |Result| |SymbolTable|)
 (|SExpression|)
 (|ScriptFormulaFormat1|)
-(|AnnaNumericalIntegrationPackage| |Asp19| |Asp8| |CombinatorialFunction| |DrawComplex| |ElementaryFunctionDefiniteIntegration| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpressionTubePlot| |FortranCode| |FortranCodePackage1| |FunctionSpaceSum| |GraphImage| |Guess| |InnerPolySum| |LiouvillianFunction| |MeshCreationRoutinesForThreeDimensions| |ParametricLinearEquations| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotFunctions1| |PlotTools| |RandomIntegerDistributions| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SegmentBinding| |SegmentBindingFunctions2| |SegmentFunctions2| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalPlotClipping| |UniversalSegment| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d03AgentsPackage| |e04AgentsPackage| |e04gcfAnnaType|)
+(|AnnaNumericalIntegrationPackage| |Asp19| |Asp8| |CombinatorialFunction| |DrawComplex| |ElementaryFunctionDefiniteIntegration| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpressionTubePlot| |FortranCode| |FortranCodePackage1| |FunctionSpaceSum| |GraphImage| |Guess| |InnerPolySum| |LiouvillianFunction| |MatrixManipulation| |MeshCreationRoutinesForThreeDimensions| |ParametricLinearEquations| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotFunctions1| |PlotTools| |RandomIntegerDistributions| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SegmentBinding| |SegmentBindingFunctions2| |SegmentFunctions2| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalPlotClipping| |UniversalSegment| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d03AgentsPackage| |e04AgentsPackage| |e04gcfAnnaType|)
 (|AnnaNumericalIntegrationPackage| |Asp19| |Asp8| |CombinatorialFunction| |DrawNumericHack| |ElementaryFunctionDefiniteIntegration| |Expression| |FortranCode| |FortranCodePackage1| |FunctionSpaceSum| |GnuDraw| |Guess| |LiouvillianFunction| |MyExpression| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SegmentBindingFunctions2| |TopLevelDrawFunctions|)
 (|DrawNumericHack| |RationalFunctionSum|)
 (|SegmentBindingFunctions2| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions|)
 (|SequentialDifferentialPolynomial|)
 (|ApplicationProgramInterface| |BasicOperator| |BasicStochasticDifferential| |ExpressionSpace&| |Factored| |GaloisGroupFactorizer| |GeneralPolynomialSet| |IntegerPrimesPackage| |ModularHermitianRowReduction| |MonoidRing| |ParametricLinearEquations| |Pattern| |Permutation| |PermutationGroup| |PolynomialSetCategory&| |QuasiAlgebraicSet| |RandomDistributions| |SymmetricGroupCombinatoricFunctions| |ThreeDimensionalViewport| |ThreeSpace|)
 (|AlgebraicFunctionField| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |RadicalFunctionField|)
-(|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |Commutator| |Complex| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionSign| |EqTable| |Equation| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NottinghamGroup| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedCompletionFunctions2| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchIntegration| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |Queue| |RadicalFunctionField| |RadixExpansion| |RandomDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RealClosure| |RectangularMatrix| |Reference| |RegularChain| |RegularTriangularSet| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |Stream| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Symbol| |SymmetricPolynomial| |Table| |TaylorSeries| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |Tree| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |U32Vector| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UniversalSegment| |Variable| |Vector| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |Commutator| |Complex| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionSign| |EqTable| |Equation| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NottinghamGroup| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedCompletionFunctions2| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchIntegration| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |Queue| |RadicalFunctionField| |RadixExpansion| |RandomDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RealClosure| |RectangularMatrix| |Reference| |RegularChain| |RegularTriangularSet| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |StochasticDifferential| |Stream| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Symbol| |SymmetricPolynomial| |Table| |TaylorSeries| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |Tree| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UniversalSegment| |Variable| |Vector| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|ExponentialOfUnivariatePuiseuxSeries| |GeneralUnivariatePowerSeries| |InnerSparseUnivariatePowerSeries| |ModMonic| |MultivariateSquareFree| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseUnivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
 (|TranscendentalRischDESystem|)
 (|Kernel| |MakeCachableSet|)
-(|AlgebraicFunction| |AlgebraicManipulations| |AlgebraicNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |DifferentialSparseMultivariatePolynomial| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |Expression| |ExpressionSpaceODESolver| |FunctionSpace&| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GosperSummationMethod| |Guess| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |LaplaceTransform| |MRationalFactorize| |MultFiniteFactorize| |MultivariatePolynomial| |MyExpression| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |ODEIntegration| |OrderlyDifferentialPolynomial| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PointsOfFiniteOrder| |Polynomial| |PureAlgebraicIntegration| |RecurrenceOperator| |SequentialDifferentialPolynomial| |TransSolvePackage| |TranscendentalManipulations|)
+(|AlgebraicFunction| |AlgebraicManipulations| |AlgebraicNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |DifferentialSparseMultivariatePolynomial| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |Expression| |ExpressionSpaceODESolver| |FunctionSpace&| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GosperSummationMethod| |Guess| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |LaplaceTransform| |MRationalFactorize| |MultFiniteFactorize| |MultivariatePolynomial| |MyExpression| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |ODEIntegration| |OrderlyDifferentialPolynomial| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PointsOfFiniteOrder| |Polynomial| |PureAlgebraicIntegration| |RecurrenceOperator| |SequentialDifferentialPolynomial| |StochasticDifferential| |TransSolvePackage| |TranscendentalManipulations|)
 (|TaylorSeries|)
 (|SparseUnivariatePuiseuxSeries|)
-(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BlowUpPackage| |BoundIntegerRoots| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CyclotomicPolynomialPackage| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleResultantPackage| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |FGLMIfCanPackage| |Factored| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteRankNonAssociativeAlgebra&| |Float| |FloatingComplexPackage| |FortranExpression| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GcdDomain&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerSolve| |Guess| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LeadingCoefDetermination| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |LocalParametrizationOfSimplePointPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MatrixCategory&| |ModMonic| |ModularField| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberTheoreticPolynomialFunctions| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialNumberTheoryFunctions| |PolynomialSquareFree| |PolynomialToUnivariatePolynomial| |PrimeField| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |ProjectiveAlgebraicSetPackage| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RomanNumeral| |RootsFindingPackage| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SupFractionFactorizer| |SymmetricFunctions| |SystemSolvePackage| |TangentExpansions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WeierstrassPreparation| |WeightedPolynomials| |ZeroDimensionalSolvePackage|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BlowUpPackage| |BoundIntegerRoots| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CyclotomicPolynomialPackage| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleResultantPackage| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |FGLMIfCanPackage| |Factored| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteRankNonAssociativeAlgebra&| |Float| |FloatingComplexPackage| |FortranExpression| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GcdDomain&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerSolve| |Guess| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LeadingCoefDetermination| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |LocalParametrizationOfSimplePointPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MatrixCategory&| |ModMonic| |ModularField| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberTheoreticPolynomialFunctions| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialNumberTheoryFunctions| |PolynomialSquareFree| |PolynomialToUnivariatePolynomial| |PrimeField| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |ProjectiveAlgebraicSetPackage| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RomanNumeral| |RootsFindingPackage| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SupFractionFactorizer| |SymmetricFunctions| |SystemSolvePackage| |TangentExpansions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |U32VectorPolynomialOperations| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WeierstrassPreparation| |WeightedPolynomials| |ZeroDimensionalSolvePackage|)
 (|ExpressionSolve| |TaylorSolve|)
 (|AlgebraicIntegration| |DefiniteIntegrationTools| |ElementaryFunctionLODESolver| |FiniteFieldPolynomialPackage2| |FunctionSpace&| |FunctionSpaceReduce| |GenusZeroIntegration| |Guess| |InnerAlgebraicNumber| |InnerPolySum| |InnerTrigonometricManipulations| |IntegrationResultFunctions2| |MultivariateLifting| |Pi| |PiCoercions| |PointsOfFiniteOrder| |PolynomialCategoryQuotientFunctions| |PureAlgebraicIntegration| |RadicalSolvePackage| |RealClosedField&| |TranscendentalIntegration| |TranscendentalManipulations|)
 (|LinearOrdinaryDifferentialOperator| |UnivariateSkewPolynomial|)
@@ -557,21 +558,21 @@
 (|DirichletRing| |EllipticFunctionsUnivariateTaylorSeries| |InfiniteProductFiniteField| |InnerTaylorSeries| |SparseMultivariateTaylorSeries| |StreamInfiniteProduct| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |UnivariateLaurentSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |WeierstrassPreparation|)
 (|ElementaryFunctionsUnivariateLaurentSeries| |InfiniteProductFiniteField| |SparseMultivariateTaylorSeries| |StreamInfiniteProduct| |StreamTranscendentalFunctionsNonCommutative| |UnivariateTaylorSeriesCategory&|)
 (|UnivariateTaylorSeriesCategory&|)
-(|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DictionaryOperations&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |ErrorFunctions| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionTubePlot| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerMod| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |Interval| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |MoreSystemCommands| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |OperationsQuery| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |ParametricLinearEquations| |PartialFraction| |Partition| |Pattern| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |RadicalFunctionField| |RadixExpansion| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalUnivariateRepresentationPackage| |RealClosure| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |Stack| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TemplateUtilities| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalManipulations| |Tree| |TrigonometricManipulations| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |U32Vector| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UniversalSegment| |Variable| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DictionaryOperations&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |ErrorFunctions| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionTubePlot| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerMod| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |Interval| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |MoreSystemCommands| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |OperationsQuery| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |ParametricLinearEquations| |PartialFraction| |Partition| |Pattern| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |RadicalFunctionField| |RadixExpansion| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalUnivariateRepresentationPackage| |RealClosure| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |Stack| |StochasticDifferential| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TemplateUtilities| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalManipulations| |Tree| |TrigonometricManipulations| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UniversalSegment| |Variable| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|InnerNumericFloatSolvePackage| |TranscendentalIntegration|)
 (|Export3D| |ThreeSpace|)
 (|MeshCreationRoutinesForThreeDimensions| |SubSpace| |ThreeDimensionalViewport| |ThreeSpace|)
 (|EigenPackage| |PolynomialIdeals| |RadicalEigenPackage| |RadicalSolvePackage|)
 (|Expression|)
 (|Asp12| |Asp30| |Asp35| |Asp55| |Asp74| |Asp8| |FortranCode|)
-(|AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |AttributeButtons| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |Boolean| |CombinatorialFunction| |CommonOperators| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DesingTreePackage| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |FGLMIfCanPackage| |Factored| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasisExtensionByPolynomial| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranType| |Fraction| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |InnerSparseUnivariatePowerSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InverseLaplaceTransform| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |LexTriangularPackage| |Library| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |LiouvillianFunction| |List| |ListMultiDictionary| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |MonogenicAlgebra&| |Multiset| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODEIntegration| |Octonion| |OctonionCategory&| |OpenMathDevice| |OpenMathError| |OpenMathErrorKind| |OrdSetInts| |OrderedDirectProduct| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OutputForm| |PAdicRational| |PAdicRationalConstructor| |ParametricLinearEquations| |PartialFractionPackage| |Pattern| |PatternFunctions2| |PatternMatch| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchSymbol| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PlotFunctions1| |PolToPol| |Polynomial| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PowerSeriesLimitPackage| |PrimitiveElement| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QueryEquation| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosure| |RealSolvePackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |RepresentationPackage1| |Result| |RetractSolvePackage| |RewriteRule| |RomanNumeral| |RoutinesTable| |RuleCalled| |SExpression| |SegmentBinding| |SegmentBindingFunctions2| |SequentialDifferentialPolynomial| |Set| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StructuralConstantsPackage| |Switch| |Symbol| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TheSymbolTable| |ThreeDimensionalMatrix| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Variable| |Vector| |WeierstrassPreparation| |XPolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |AttributeButtons| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |Boolean| |CombinatorialFunction| |CommonOperators| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DesingTreePackage| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |FGLMIfCanPackage| |Factored| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasisExtensionByPolynomial| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranType| |Fraction| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |InnerSparseUnivariatePowerSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InverseLaplaceTransform| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |LexTriangularPackage| |Library| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |LiouvillianFunction| |List| |ListMultiDictionary| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |MonogenicAlgebra&| |Multiset| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODEIntegration| |Octonion| |OctonionCategory&| |OpenMathDevice| |OpenMathError| |OpenMathErrorKind| |OrdSetInts| |OrderedDirectProduct| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OutputForm| |PAdicRational| |PAdicRationalConstructor| |ParametricLinearEquations| |PartialFractionPackage| |Pattern| |PatternFunctions2| |PatternMatch| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchSymbol| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PlotFunctions1| |PolToPol| |Polynomial| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PowerSeriesLimitPackage| |PrimitiveElement| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QueryEquation| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosure| |RealSolvePackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |RepresentationPackage1| |Result| |RetractSolvePackage| |RewriteRule| |RomanNumeral| |RoutinesTable| |RuleCalled| |SExpression| |SegmentBinding| |SegmentBindingFunctions2| |SequentialDifferentialPolynomial| |Set| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StochasticDifferential| |StructuralConstantsPackage| |Switch| |Symbol| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TheSymbolTable| |ThreeDimensionalMatrix| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Variable| |Vector| |WeierstrassPreparation| |XPolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranPackage| |FortranProgram| |TheSymbolTable|)
 (|TangentExpansions|)
 (|IrrRepSymNatPackage| |RepresentationPackage1|)
 (|CycleIndicators| |EvaluateCycleIndicators|)
 (|PureAlgebraicLODE|)
 (|EigenPackage| |NonLinearSolvePackage| |RadicalSolvePackage| |RetractSolvePackage| |TransSolvePackage|)
-(|AlgebraicFunctionField| |BasicStochasticDifferential| |Complex| |DiscreteLogarithmPackage| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |InnerFiniteField| |InnerPrimeField| |MachineComplex| |Multiset| |PrimeField| |PseudoAlgebraicClosureOfFiniteField| |RadicalFunctionField| |RandomDistributions| |Result| |SimpleAlgebraicExtension| |SymbolTable| |TransSolvePackage|)
+(|AlgebraicFunctionField| |BasicStochasticDifferential| |Complex| |DiscreteLogarithmPackage| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |InnerFiniteField| |InnerPrimeField| |MachineComplex| |Multiset| |PrimeField| |PseudoAlgebraicClosureOfFiniteField| |RadicalFunctionField| |RandomDistributions| |Result| |SimpleAlgebraicExtension| |StochasticDifferential| |SymbolTable| |TransSolvePackage|)
 (|TableauxBumpers|)
 (|QuasiComponentPackage| |RegularTriangularSetGcdPackage| |SquareFreeQuasiComponentPackage| |SquareFreeRegularTriangularSetGcdPackage|)
 (|ElementaryFunctionStructurePackage|)
@@ -602,6 +603,9 @@
 (|TopLevelDrawFunctionsForCompiledFunctions|)
 (|GnuDraw| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |ViewportPackage|)
 (|MultFiniteFactorize| |SparseUnivariatePolynomial|)
+(|U16Matrix|)
+(|U32Matrix| |U32VectorPolynomialOperations|)
+(|U8Matrix|)
 (|Guess| |NottinghamGroup| |RecurrenceOperator| |UnivariateFormalPowerSeriesFunctions|)
 (|Guess|)
 (|UnivariateLaurentSeriesFunctions2| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesFunctions2|)
@@ -620,7 +624,7 @@
 (|PadeApproximantPackage| |RationalRicDE| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesFunctions2| |UnivariatePuiseuxSeries|)
 (|GeneralPackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField|)
 (|UnivariateLaurentSeriesFunctions2|)
-(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AssociationList| |AxiomServer| |Bits| |ComplexDoubleFloatVector| |DataList| |DisplayPackage| |DoubleFloatVector| |ExtensibleLinearAggregate&| |FlexibleArray| |Float| |GaloisGroupUtilities| |GenerateUnivariatePowerSeries| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerNormalBasisFieldFunctions| |LazyStreamAggregate&| |List| |ListAggregate&| |MathMLFormat| |NeitherSparseOrDensePowerSeries| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |Point| |PrimitiveArray| |Stream| |StreamAggregate&| |String| |StringAggregate&| |Symbol| |TemplateUtilities| |TexFormat| |U32Vector| |UniversalSegmentFunctions2| |Vector|)
+(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AssociationList| |AxiomServer| |Bits| |ComplexDoubleFloatVector| |DataList| |DisplayPackage| |DoubleFloatVector| |ExtensibleLinearAggregate&| |FlexibleArray| |Float| |GaloisGroupUtilities| |GenerateUnivariatePowerSeries| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerNormalBasisFieldFunctions| |LazyStreamAggregate&| |List| |ListAggregate&| |MathMLFormat| |NeitherSparseOrDensePowerSeries| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |Point| |PrimitiveArray| |Stream| |StreamAggregate&| |String| |StringAggregate&| |Symbol| |TemplateUtilities| |TexFormat| |U16Vector| |U32Vector| |U8Vector| |UniversalSegmentFunctions2| |Vector|)
 (|GenerateUnivariatePowerSeries|)
 (|FunctionSpace&| |Polynomial| |UserDefinedVariableOrdering|)
 (|GeneralUnivariatePowerSeries| |MyUnivariatePolynomial| |PolynomialToUnivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
@@ -628,7 +632,7 @@
 (|AlgebraicHermiteIntegration| |AlgebraicIntegrate| |Asp10| |Asp19| |Asp20| |Asp31| |Asp35| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp78| |Asp8| |Asp80| |FramedNonAssociativeAlgebraFunctions2| |GenExEuclid| |GenericNonAssociativeAlgebra| |LinearDependence| |SimpleAlgebraicExtension|)
 (|GraphImage| |MeshCreationRoutinesForThreeDimensions| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalViewport| |ViewportPackage|)
 (|TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions|)
-(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |ApplicationProgramInterface| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociationList| |AttributeButtons| |AxiomServer| |BasicStochasticDifferential| |BinaryFile| |Bits| |BlowUpPackage| |CommonOperators| |Complex| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |DataList| |Database| |DesingTreePackage| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DoubleFloat| |DoubleFloatVector| |EqTable| |EuclideanGroebnerBasisPackage| |Export3D| |ExpressionToOpenMath| |File| |FiniteAlgebraicExtensionField&| |FiniteFieldCategory&| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteLinearAggregateSort| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranTemplate| |Fraction| |FramedNonAssociativeAlgebra&| |FunctionSpaceReduce| |GaloisGroupFactorizer| |GaloisGroupUtilities| |GenUFactorize| |GeneralPackageForAlgebraicFunctionField| |GeneralSparseTable| |GenericNonAssociativeAlgebra| |GnuDraw| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |HomogeneousDirectProduct| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerNormalBasisFieldFunctions| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |Integer| |IntegrationFunctionsTable| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Kernel| |KeyedAccessFile| |Library| |List| |LocalParametrizationOfSimplePointPackage| |MachineFloat| |MakeCachableSet| |MathMLFormat| |MoreSystemCommands| |NAGLinkSupportPackage| |NagEigenPackage| |NagIntegrationPackage| |NagLinearEquationSolvingPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage| |NeitherSparseOrDensePowerSeries| |NormalizationPackage| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntensityFunctionsTable| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathConnection| |OpenMathDevice| |OpenMathPackage| |OpenMathServerPackage| |OrderedDirectProduct| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PermutationGroup| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |Point| |PointsOfFiniteOrder| |PrimitiveArray| |PrintPackage| |ProjectiveAlgebraicSetPackage| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuasiComponentPackage| |RadicalFunctionField| |RandomNumberSource| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResolveLatticeCompletion| |Result| |RoutinesTable| |ScriptFormulaFormat| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SortPackage| |SortedCache| |SparseTable| |SparseUnivariatePolynomialExpressions| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |SystemODESolver| |Table| |TabulatedComputationPackage| |TaylorSolve| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalViewport| |TwoDimensionalViewport| |U32Vector| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |ZeroDimensionalSolvePackage| |e04AgentsPackage|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |ApplicationProgramInterface| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociationList| |AttributeButtons| |AxiomServer| |BasicStochasticDifferential| |BinaryFile| |Bits| |BlowUpPackage| |CommonOperators| |Complex| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |DataList| |Database| |DesingTreePackage| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DoubleFloat| |DoubleFloatVector| |EqTable| |EuclideanGroebnerBasisPackage| |Export3D| |ExpressionToOpenMath| |File| |FiniteAlgebraicExtensionField&| |FiniteFieldCategory&| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteLinearAggregateSort| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranTemplate| |Fraction| |FramedNonAssociativeAlgebra&| |FunctionSpaceReduce| |GaloisGroupFactorizer| |GaloisGroupUtilities| |GenUFactorize| |GeneralPackageForAlgebraicFunctionField| |GeneralSparseTable| |GenericNonAssociativeAlgebra| |GnuDraw| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |HomogeneousDirectProduct| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerNormalBasisFieldFunctions| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |Integer| |IntegrationFunctionsTable| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Kernel| |KeyedAccessFile| |Library| |List| |LocalParametrizationOfSimplePointPackage| |MachineFloat| |MakeCachableSet| |MathMLFormat| |MoreSystemCommands| |NAGLinkSupportPackage| |NagEigenPackage| |NagIntegrationPackage| |NagLinearEquationSolvingPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage| |NeitherSparseOrDensePowerSeries| |NormalizationPackage| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntensityFunctionsTable| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathConnection| |OpenMathDevice| |OpenMathPackage| |OpenMathServerPackage| |OrderedDirectProduct| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PermutationGroup| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |Point| |PointsOfFiniteOrder| |PrimitiveArray| |PrintPackage| |ProjectiveAlgebraicSetPackage| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuasiComponentPackage| |RadicalFunctionField| |RandomNumberSource| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResolveLatticeCompletion| |Result| |RoutinesTable| |ScriptFormulaFormat| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SortPackage| |SortedCache| |SparseTable| |SparseUnivariatePolynomialExpressions| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |StochasticDifferential| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |SystemODESolver| |Table| |TabulatedComputationPackage| |TaylorSolve| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalViewport| |TwoDimensionalViewport| |U16Vector| |U32Vector| |U32VectorPolynomialOperations| |U8Vector| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |ZeroDimensionalSolvePackage| |e04AgentsPackage|)
 (|OrdinaryWeightedPolynomials|)
 (|PAdicWildFunctionFieldIntegralBasis|)
 (|LieExponentials| |LiePolynomial| |XPBWPolynomial| |XPolynomial| |XRecursivePolynomial|)
@@ -663,4 +667,4 @@
 (|AnnaNumericalOptimizationPackage|)
 (|AnnaNumericalOptimizationPackage|)
 (|AnnaNumericalOptimizationPackage|)
-(("e04ucfAnnaType" 0 234983) ("e04nafAnnaType" 0 234946) ("e04mbfAnnaType" 0 234909) ("e04jafAnnaType" 0 234872) ("e04gcfAnnaType" 0 234835) ("e04fdfAnnaType" 0 234798) ("e04dgfAnnaType" 0 234761) ("e04AgentsPackage" 0 234622) ("d03eefAnnaType" 0 234579) ("d03AgentsPackage" 0 234560) ("d02ejfAnnaType" 0 234516) ("d02cjfAnnaType" 0 234472) ("d02bhfAnnaType" 0 234428) ("d02bbfAnnaType" 0 234384) ("d02AgentsPackage" 0 234314) ("d01gbfAnnaType" 0 234278) ("d01fcfAnnaType" 0 234242) ("d01asfAnnaType" 0 234206) ("d01aqfAnnaType" 0 234170) ("d01apfAnnaType" 0 234134) ("d01anfAnnaType" 0 234098) ("d01amfAnnaType" 0 234062) ("d01alfAnnaType" 0 234026) ("d01akfAnnaType" 0 233990) ("d01ajfAnnaType" 0 233954) ("d01WeightsPackage" 0 233901) ("d01TransformFunctionType" 0 233865) ("d01AgentsPackage" 0 233612) ("XRecursivePolynomial" 0 233563) ("XPolynomialRing" 0 233536) ("XPBWPolynomial" 0 233516) ("XDistributedPolynomial" 0 233426) ("WildFunctionFieldIntegralBasis" 0 233386) ("WeightedPolynomials" 0 233354) ("Void" 0 229038) ("ViewportPackage" 0 228950) ("ViewDefaultsPackage" 0 228738) ("VectorSpace&" 0 NIL) ("VectorFunctions2" 0 228429) ("VectorCategory&" 0 NIL) ("Vector" 0 223313) ("Variable" 0 222938) ("UserDefinedPartialOrdering" 0 222876) ("UniversalSegmentFunctions2" 0 222842) ("UniversalSegment" 0 221999) ("UnivariateTaylorSeriesFunctions2" 0 221961) ("UnivariateTaylorSeriesCategory&" 0 NIL) ("UnivariateTaylorSeriesCZero" 0 221832) ("UnivariateTaylorSeries" 0 221671) ("UnivariateSkewPolynomialCategoryOps" 0 221636) ("UnivariateSkewPolynomialCategory&" 0 NIL) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 221573) ("UnivariatePuiseuxSeriesConstructorCategory&" 0 NIL) ("UnivariatePuiseuxSeriesConstructor" 0 221513) ("UnivariatePuiseuxSeries" 0 221292) ("UnivariatePowerSeriesCategory&" 0 NIL) ("UnivariatePolynomialSquareFree" 0 221173) ("UnivariatePolynomialDivisionPackage" 0 221128) ("UnivariatePolynomialDecompositionPackage" 0 221102) ("UnivariatePolynomialCommonDenominator" 0 220889) ("UnivariatePolynomialCategoryFunctions2" 0 219765) ("UnivariatePolynomialCategory&" 0 NIL) ("UnivariatePolynomial" 0 219456) ("UnivariateLaurentSeriesFunctions2" 0 219418) ("UnivariateLaurentSeriesConstructorCategory&" 0 NIL) ("UnivariateLaurentSeriesConstructor" 0 219390) ("UnivariateLaurentSeries" 0 219290) ("UnivariateFormalPowerSeriesFunctions" 0 219280) ("UnivariateFormalPowerSeries" 0 219192) ("UniqueFactorizationDomain&" 0 NIL) ("UnaryRecursiveAggregate&" 0 NIL) ("TwoFactorize" 0 219139) ("TwoDimensionalViewport" 0 218966) ("TwoDimensionalPlotClipping" 0 218920) ("TwoDimensionalArrayCategory&" 0 NIL) ("TwoDimensionalArray" 0 218904) ("TubePlotTools" 0 218863) ("TubePlot" 0 218778) ("TrigonometricManipulations" 0 218593) ("TrigonometricFunctionCategory&" 0 NIL) ("TriangularSetCategory&" 0 NIL) ("TriangularMatrixOperations" 0 218403) ("Tree" 0 218361) ("TranscendentalRischDESystem" 0 218333) ("TranscendentalRischDE" 0 218289) ("TranscendentalManipulations" 0 218173) ("TranscendentalIntegration" 0 218105) ("TranscendentalHermiteIntegration" 0 218075) ("TranscendentalFunctionCategory&" 0 NIL) ("TransSolvePackageService" 0 218053) ("TopLevelDrawFunctionsForCompiledFunctions" 0 218027) ("TopLevelDrawFunctions" 0 218015) ("ToolsForSign" 0 217908) ("ThreeSpace" 0 217656) ("ThreeDimensionalViewport" 0 217529) ("ThreeDimensionalMatrix" 0 217486) ("TheSymbolTable" 0 217436) ("TextFile" 0 217395) ("TexFormat" 0 217380) ("TemplateUtilities" 0 217360) ("TaylorSolve" 0 217340) ("TaylorSeries" 0 217313) ("TangentExpansions" 0 217274) ("TabulatedComputationPackage" 0 217138) ("Tableau" 0 217118) ("TableAggregate&" 0 NIL) ("Table" 0 216488) ("SystemSolvePackage" 0 216383) ("SystemODESolver" 0 216361) ("SymmetricPolynomial" 0 216315) ("SymmetricGroupCombinatoricFunctions" 0 216266) ("SymmetricFunctions" 0 216244) ("SymbolTable" 0 215965) ("Symbol" 0 207862) ("Switch" 0 207799) ("SupFractionFactorizer" 0 207784) ("SuchThat" 0 207704) ("SubSpaceComponentProperty" 0 207610) ("SubSpace" 0 207584) ("SubResultantPackage" 0 207522) ("StringAggregate&" 0 NIL) ("String" 0 196336) ("StreamTranscendentalFunctionsNonCommutative" 0 196300) ("StreamTranscendentalFunctions" 0 196087) ("StreamTaylorSeriesOperations" 0 195658) ("StreamInfiniteProduct" 0 195592) ("StreamFunctions3" 0 195399) ("StreamFunctions2" 0 194896) ("StreamFunctions1" 0 194858) ("StreamAggregate&" 0 NIL) ("Stream" 0 192995) ("StorageEfficientMatrixOperations" 0 192984) ("Stack" 0 192946) ("SquareMatrixCategory&" 0 NIL) ("SquareMatrix" 0 192813) ("SquareFreeRegularTriangularSetGcdPackage" 0 192686) ("SquareFreeRegularTriangularSet" 0 192589) ("SquareFreeRegularSetDecompositionPackage" 0 192554) ("SquareFreeQuasiComponentPackage" 0 192377) ("SplittingTree" 0 192350) ("SplittingNode" 0 192307) ("SparseUnivariateTaylorSeries" 0 192241) ("SparseUnivariateSkewPolynomial" 0 192175) ("SparseUnivariatePolynomialFunctions2" 0 191661) ("SparseUnivariatePolynomialExpressions" 0 191627) ("SparseUnivariatePolynomial" 0 184988) ("SparseUnivariateLaurentSeries" 0 184954) ("SparseMultivariateTaylorSeries" 0 184937) ("SparseMultivariatePolynomial" 0 183705) ("SortedCache" 0 183676) ("SmithNormalForm" 0 183644) ("SingletonAsOrderedSet" 0 182947) ("SingleInteger" 0 175339) ("SimpleAlgebraicExtension" 0 175208) ("SetCategory&" 0 NIL) ("SetAggregate&" 0 NIL) ("Set" 0 174770) ("SequentialDifferentialVariable" 0 174733) ("SemiGroup&" 0 NIL) ("SegmentFunctions2" 0 174618) ("SegmentBindingFunctions2" 0 174576) ("SegmentBinding" 0 174209) ("Segment" 0 173145) ("ScriptFormulaFormat" 0 173120) ("SExpressionOf" 0 173104) ("SExpression" 0 172875) ("RoutinesTable" 0 172284) ("RootsFindingPackage" 0 172148) ("Ring&" 0 NIL) ("RightOpenIntervalRootCharacterization" 0 172132) ("RewriteRule" 0 172087) ("RetractableTo&" 0 NIL) ("RetractSolvePackage" 0 172061) ("Result" 0 170990) ("RepeatedSquaring" 0 170749) ("RepeatedDoubling" 0 170566) ("RegularTriangularSetGcdPackage" 0 170508) ("RegularTriangularSetCategory&" 0 NIL) ("RegularTriangularSet" 0 170491) ("RegularSetDecompositionPackage" 0 170466) ("RegularChain" 0 170411) ("Reference" 0 170028) ("ReductionOfOrder" 0 169995) ("ReduceLODE" 0 169973) ("RecursivePolynomialCategory&" 0 NIL) ("RecursiveAggregate&" 0 NIL) ("RecurrenceOperator" 0 169963) ("RectangularMatrixCategory&" 0 NIL) ("RealZeroPackage" 0 169883) ("RealSolvePackage" 0 169855) ("RealRootCharacterizationCategory&" 0 NIL) ("RealPolynomialUtilitiesPackage" 0 169813) ("RealNumberSystem&" 0 NIL) ("RealClosure" 0 169781) ("RealClosedField&" 0 NIL) ("RationalRicDE" 0 169691) ("RationalLODE" 0 169552) ("RationalIntegration" 0 169431) ("RationalFunctionSign" 0 169373) ("RationalFunctionIntegration" 0 169339) ("RationalFunctionFactor" 0 169306) ("RationalFunction" 0 169258) ("RationalFactorize" 0 169028) ("RandomNumberSource" 0 168948) ("RadixExpansion" 0 168886) ("RadicalSolvePackage" 0 168864) ("RadicalCategory&" 0 NIL) ("QuotientFieldCategoryFunctions2" 0 168841) ("QuotientFieldCategory&" 0 NIL) ("Queue" 0 168829) ("QueryEquation" 0 168816) ("QuaternionCategory&" 0 NIL) ("Quaternion" 0 168803) ("QuasiComponentPackage" 0 168689) ("QuasiAlgebraicSet" 0 168666) ("QuadraticForm" 0 168646) ("PushVariables" 0 168619) ("PureAlgebraicIntegration" 0 168542) ("PseudoRemainderSequence" 0 168457) ("PseudoLinearNormalForm" 0 168437) ("PseudoAlgebraicClosureOfRationalNumber" 0 168320) ("PseudoAlgebraicClosureOfFiniteField" 0 168049) ("ProjectiveSpace" 0 168029) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 167916) ("ProjectivePlane" 0 167811) ("ProjectiveAlgebraicSetPackage" 0 167718) ("Product" 0 167677) ("PrintPackage" 0 167651) ("PrimitiveRatRicDE" 0 167633) ("PrimitiveRatDE" 0 167580) ("PrimitiveElement" 0 167546) ("PrimitiveArray" 0 166817) ("PrimeField" 0 166724) ("PrecomputedAssociatedEquations" 0 166700) ("PowerSeriesLimitPackage" 0 166608) ("PowerSeriesCategory&" 0 NIL) ("PositiveInteger" 0 156907) ("PolynomialSquareFree" 0 156883) ("PolynomialSolveByFormulas" 0 156859) ("PolynomialSetUtilitiesPackage" 0 156462) ("PolynomialSetCategory&" 0 NIL) ("PolynomialRoots" 0 156359) ("PolynomialRing" 0 156191) ("PolynomialPackageForCurve" 0 156094) ("PolynomialNumberTheoryFunctions" 0 156040) ("PolynomialInterpolationAlgorithms" 0 156012) ("PolynomialIdeals" 0 155961) ("PolynomialGcdPackage" 0 155885) ("PolynomialFunctions2" 0 155689) ("PolynomialFactorizationExplicit&" 0 NIL) ("PolynomialFactorizationByRecursionUnivariate" 0 155626) ("PolynomialFactorizationByRecursion" 0 155602) ("PolynomialDecomposition" 0 155572) ("PolynomialCategoryQuotientFunctions" 0 155173) ("PolynomialCategoryLifting" 0 154538) ("PolynomialCategory&" 0 NIL) ("Polynomial" 0 152168) ("PolyGroebner" 0 152122) ("PolToPol" 0 152085) ("PointsOfFiniteOrderTools" 0 152031) ("PointsOfFiniteOrder" 0 152008) ("PointPackage" 0 151867) ("Point" 0 151431) ("PoincareBirkhoffWittLyndonBasis" 0 151394) ("PlotTools" 0 151379) ("Plot3D" 0 151312) ("Plot" 0 151175) ("Plcs" 0 151116) ("PlaneAlgebraicCurvePlot" 0 151072) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 151020) ("Places" 0 150983) ("PiCoercions" 0 150961) ("Pi" 0 150925) ("PermutationGroup" 0 150896) ("Permutation" 0 150801) ("PatternMatchTools" 0 150738) ("PatternMatchSymbol" 0 150727) ("PatternMatchResultFunctions2" 0 150680) ("PatternMatchResult" 0 149262) ("PatternMatchQuotientFieldCategory" 0 149235) ("PatternMatchPushDown" 0 149114) ("PatternMatchPolynomialCategory" 0 149077) ("PatternMatchListResult" 0 149032) ("PatternMatchListAggregate" 0 149015) ("PatternMatchKernel" 0 148972) ("PatternMatchIntegration" 0 148853) ("PatternMatchIntegerNumberSystem" 0 148828) ("PatternMatchFunctionSpace" 0 148813) ("PatternFunctions1" 0 148743) ("Pattern" 0 147210) ("PartitionsAndPermutations" 0 147110) ("Partition" 0 146993) ("PartialDifferentialRing&" 0 NIL) ("ParametrizationPackage" 0 146874) ("ParametricSurface" 0 146774) ("ParametricSpaceCurve" 0 146671) ("ParametricPlaneCurve" 0 146568) ("ParadoxicalCombinatorsForStreams" 0 146367) ("Palette" 0 146165) ("PackageForPoly" 0 145858) ("PAdicRationalConstructor" 0 145816) ("PAdicInteger" 0 145798) ("OutputPackage" 0 145428) ("OutputForm" 0 135684) ("OrderlyDifferentialVariable" 0 135578) ("OrderlyDifferentialPolynomial" 0 135545) ("OrderedVariableList" 0 134992) ("OrderedSet&" 0 NIL) ("OrderedRing&" 0 NIL) ("OrderedFreeMonoid" 0 134840) ("OrderedCompletionFunctions2" 0 134769) ("OrderedCompletion" 0 133986) ("OrdSetInts" 0 133952) ("OpenMathPackage" 0 133926) ("OpenMathErrorKind" 0 133908) ("OpenMathEncoding" 0 133730) ("OpenMathDevice" 0 133548) ("OpenMathConnection" 0 133522) ("OnePointCompletionFunctions2" 0 133489) ("OnePointCompletion" 0 132676) ("OneDimensionalArrayAggregate&" 0 NIL) ("OneDimensionalArray" 0 132607) ("OctonionCategory&" 0 NIL) ("ODETools" 0 132559) ("ODEIntensityFunctionsTable" 0 132496) ("ODEIntegration" 0 132387) ("NumericalPDEProblem" 0 132344) ("NumericalOptimizationProblem" 0 132288) ("NumericalODEProblem" 0 132244) ("NumericalIntegrationProblem" 0 132181) ("NumericTubePlot" 0 132135) ("NumericRealEigenPackage" 0 132114) ("Numeric" 0 132075) ("NumberTheoreticPolynomialFunctions" 0 132045) ("NumberFormats" 0 132015) ("NormalizationPackage" 0 131842) ("NoneFunctions1" 0 131807) ("None" 0 131506) ("NonNegativeInteger" 0 115837) ("NonLinearSolvePackage" 0 115819) ("NonLinearFirstOrderODESolver" 0 115787) ("NonAssociativeRng&" 0 NIL) ("NonAssociativeRing&" 0 NIL) ("NonAssociativeAlgebra&" 0 NIL) ("NewtonPolygon" 0 115769) ("NewtonInterpolation" 0 115759) ("NewSparseUnivariatePolynomialFunctions2" 0 115723) ("NewSparseUnivariatePolynomial" 0 115645) ("NewSparseMultivariatePolynomial" 0 115533) ("NeitherSparseOrDensePowerSeries" 0 115446) ("NagPartialDifferentialEquationsPackage" 0 115427) ("NagOrdinaryDifferentialEquationsPackage" 0 115357) ("NagOptimisationPackage" 0 115201) ("NagIntegrationPackage" 0 115029) ("NagEigenPackage" 0 115008) ("NPCoef" 0 114984) ("NAGLinkSupportPackage" 0 114572) ("MyUnivariatePolynomial" 0 114555) ("MyExpression" 0 114525) ("MultivariateSquareFree" 0 114461) ("MultivariateLifting" 0 114373) ("MultivariateFactorize" 0 114040) ("Multiset" 0 113981) ("MultipleMap" 0 113906) ("MultiVariableCalculusFunctions" 0 113812) ("MultFiniteFactorize" 0 113738) ("MoreSystemCommands" 0 113659) ("MonomialExtensionTools" 0 113540) ("MonoidRing" 0 113515) ("Monoid&" 0 NIL) ("MonogenicAlgebra&" 0 NIL) ("MonadWithUnit&" 0 NIL) ("Monad&" 0 NIL) ("MoebiusTransform" 0 113493) ("ModuleOperator" 0 113480) ("ModuleMonomial" 0 113452) ("Module&" 0 NIL) ("ModularRing" 0 113412) ("ModularHermitianRowReduction" 0 113207) ("ModularDistinctDegreeFactorizer" 0 113150) ("ModMonic" 0 113040) ("MeshCreationRoutinesForThreeDimensions" 0 112994) ("MergeThing" 0 112981) ("MatrixLinearAlgebraFunctions" 0 112954) ("MatrixCommonDenominator" 0 112844) ("MatrixCategoryFunctions2" 0 112463) ("MatrixCategory&" 0 NIL) ("Matrix" 0 107579) ("MappingPackageInternalHacks3" 0 107559) ("MappingPackageInternalHacks2" 0 107539) ("MappingPackageInternalHacks1" 0 107519) ("MappingPackage1" 0 107425) ("MakeUnaryCompiledFunction" 0 107365) ("MakeFunction" 0 107306) ("MakeFloatCompiledFunction" 0 107242) ("MakeBinaryCompiledFunction" 0 107194) ("Magma" 0 107163) ("MachineInteger" 0 107129) ("MachineFloat" 0 107060) ("MRationalFactorize" 0 106896) ("MPolyCatRationalFunctionFactorizer" 0 106786) ("MPolyCatPolyFactorizer" 0 106749) ("MPolyCatFunctions3" 0 106736) ("MPolyCatFunctions2" 0 106649) ("LyndonWord" 0 106562) ("Logic&" 0 NIL) ("Localize" 0 106545) ("LocalParametrizationOfSimplePointPackage" 0 106452) ("LocalAlgebra" 0 106439) ("ListToMap" 0 106388) ("ListMultiDictionary" 0 106356) ("ListMonoidOps" 0 106304) ("ListFunctions2" 0 105885) ("ListAggregate&" 0 NIL) ("List" 0 88398) ("LiouvillianFunction" 0 88357) ("LinesOpPack" 0 88292) ("LinearSystemPolynomialPackage" 0 88269) ("LinearSystemMatrixPackage" 0 87935) ("LinearSystemFromPowerSeriesPackage" 0 87907) ("LinearPolynomialEquationByFractions" 0 87786) ("LinearOrdinaryDifferentialOperatorsOps" 0 87747) ("LinearOrdinaryDifferentialOperatorFactorizer" 0 87714) ("LinearOrdinaryDifferentialOperatorCategory&" 0 NIL) ("LinearOrdinaryDifferentialOperator2" 0 87681) ("LinearOrdinaryDifferentialOperator1" 0 87517) ("LinearOrdinaryDifferentialOperator" 0 87439) ("LinearDependence" 0 87411) ("LinearAggregate&" 0 NIL) ("LinGroebnerPackage" 0 87374) ("LiePolynomial" 0 87337) ("LieAlgebra&" 0 NIL) ("LexTriangularPackage" 0 87305) ("LeftAlgebra&" 0 NIL) ("LeadingCoefDetermination" 0 87265) ("LazyStreamAggregate&" 0 NIL) ("LaurentPolynomial" 0 87194) ("Kovacic" 0 87161) ("KeyedDictionary&" 0 NIL) ("KeyedAccessFile" 0 87149) ("KernelFunctions2" 0 87134) ("Kernel" 0 85285) ("IrredPolyOverFiniteField" 0 85245) ("Interval" 0 85198) ("IntersectionDivisorPackage" 0 85154) ("InterpolateFormsPackage" 0 85110) ("InternalRationalUnivariateRepresentationPackage" 0 85036) ("InternalPrintPackage" 0 84928) ("InterfaceGroebnerPackage" 0 84881) ("IntegrationTools" 0 84572) ("IntegrationResultToFunction" 0 84477) ("IntegrationResultRFToFunction" 0 84437) ("IntegrationResultFunctions2" 0 84238) ("IntegrationResult" 0 83866) ("IntegrationFunctionsTable" 0 83811) ("IntegralDomain&" 0 NIL) ("IntegralBasisTools" 0 83682) ("IntegralBasisPolynomialTools" 0 83642) ("IntegerSolveLinearPolynomialEquation" 0 83630) ("IntegerRoots" 0 83445) ("IntegerRetractions" 0 83413) ("IntegerPrimesPackage" 0 82981) ("IntegerNumberTheoryFunctions" 0 82880) ("IntegerNumberSystem&" 0 NIL) ("IntegerMod" 0 82860) ("IntegerLinearDependence" 0 82821) ("IntegerFactorizationPackage" 0 82697) ("IntegerCombinatoricFunctions" 0 82481) ("IntegerBits" 0 82450) ("Integer" 0 66866) ("InputFormFunctions1" 0 66847) ("InputForm" 0 64609) ("InnerTrigonometricManipulations" 0 64481) ("InnerTaylorSeries" 0 64391) ("InnerTable" 0 64381) ("InnerSparseUnivariatePowerSeries" 0 64284) ("InnerPrimeField" 0 64250) ("InnerPolySum" 0 64226) ("InnerPolySign" 0 64143) ("InnerPAdicInteger" 0 64103) ("InnerNumericFloatSolvePackage" 0 64006) ("InnerNumericEigenPackage" 0 63949) ("InnerNormalBasisFieldFunctions" 0 63901) ("InnerMultFact" 0 63855) ("InnerMatrixQuotientFieldFunctions" 0 63822) ("InnerMatrixLinearAlgebraFunctions" 0 63753) ("InnerIndexedTwoDimensionalArray" 0 63675) ("InnerFreeAbelianMonoid" 0 63634) ("InnerEvalable&" 0 NIL) ("InnerCommonDenominator" 0 63388) ("InnerAlgebraicNumber" 0 63368) ("InnerAlgFactor" 0 63299) ("InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField" 0 63247) ("InfinitlyClosePoint" 0 63173) ("InfiniteTuple" 0 63119) ("InfClsPt" 0 63082) ("IndexedVector" 0 63055) ("IndexedString" 0 63044) ("IndexedOneDimensionalArray" 0 62975) ("IndexedList" 0 62966) ("IndexedFlexibleArray" 0 62879) ("IndexedExponents" 0 62603) ("IndexedDirectProductOrderedAbelianMonoidSup" 0 62582) ("IndexedDirectProductOrderedAbelianMonoid" 0 62534) ("IndexedDirectProductObject" 0 62496) ("IndexedDirectProductAbelianMonoid" 0 62416) ("IndexedDirectProductAbelianGroup" 0 62401) ("IndexedBits" 0 62392) ("IndexedAggregate&" 0 NIL) ("IdealDecompositionPackage" 0 62369) ("HyperbolicFunctionCategory&" 0 NIL) ("HomogeneousDistributedMultivariatePolynomial" 0 62300) ("HomogeneousDirectProduct" 0 62219) ("HomogeneousAggregate&" 0 NIL) ("HeuGcd" 0 62207) ("HashTable" 0 62151) ("HallBasis" 0 62130) ("GuessOptionFunctions0" 0 62120) ("GuessOption" 0 62086) ("GuessFiniteFunctions" 0 62070) ("Guess" 0 61970) ("Group&" 0 NIL) ("GroebnerPackage" 0 61741) ("GroebnerInternalPackage" 0 61614) ("GrayCode" 0 61600) ("GraphicsDefaults" 0 61500) ("GraphImage" 0 61412) ("GradedModule&" 0 NIL) ("GradedAlgebra&" 0 NIL) ("GosperSummationMethod" 0 61369) ("GenusZeroIntegration" 0 61340) ("GeneralizedMultivariateFactorize" 0 61268) ("GeneralTriangularSet" 0 61209) ("GeneralSparseTable" 0 61193) ("GeneralPolynomialSet" 0 61002) ("GeneralPolynomialGcdPackage" 0 60978) ("GeneralPackageForAlgebraicFunctionField" 0 60891) ("GeneralHenselPackage" 0 60805) ("GeneralDistributedMultivariatePolynomial" 0 60720) ("GenUFactorize" 0 60668) ("GenExEuclid" 0 60494) ("GcdDomain&" 0 NIL) ("GaloisGroupUtilities" 0 60456) ("GaloisGroupPolynomialUtilities" 0 60430) ("GaloisGroupFactorizer" 0 60382) ("GaloisGroupFactorizationUtilities" 0 60339) ("FunctionalSpecialFunction" 0 60324) ("FunctionSpaceUnivariatePolynomialFactor" 0 60225) ("FunctionSpaceToUnivariatePowerSeries" 0 60185) ("FunctionSpacePrimitiveElement" 0 60108) ("FunctionSpaceIntegration" 0 59870) ("FunctionSpaceFunctions2" 0 59786) ("FunctionSpaceComplexIntegration" 0 59757) ("FunctionSpaceAttachPredicates" 0 59710) ("FunctionSpaceAssertions" 0 59643) ("FunctionSpace&" 0 NIL) ("FunctionFieldCategoryFunctions2" 0 59615) ("FunctionFieldCategory&" 0 NIL) ("FullyRetractableTo&" 0 NIL) ("FullyLinearlyExplicitRingOver&" 0 NIL) ("FullyEvalableOver&" 0 NIL) ("FreeMonoid" 0 59593) ("FreeModule1" 0 59517) ("FreeModule" 0 59412) ("FreeGroup" 0 59382) ("FreeAbelianGroup" 0 59363) ("FramedNonAssociativeAlgebra&" 0 NIL) ("FramedModule" 0 59345) ("FramedAlgebra&" 0 NIL) ("FractionalIdealFunctions2" 0 59317) ("FractionalIdeal" 0 59149) ("FractionFreeFastGaussianFractions" 0 59139) ("FractionFreeFastGaussian" 0 59093) ("Fraction" 0 51275) ("FourierComponent" 0 51257) ("FortranType" 0 50967) ("FortranScalarType" 0 50687) ("FortranPackage" 0 50477) ("FortranOutputStackPackage" 0 50232) ("FortranExpression" 0 50067) ("FortranCode" 0 49800) ("FloatingRealPackage" 0 49779) ("FloatingPointSystem&" 0 NIL) ("Float" 0 47925) ("FlexibleArray" 0 47900) ("FiniteSetAggregate&" 0 NIL) ("FiniteRankNonAssociativeAlgebra&" 0 NIL) ("FiniteRankAlgebra&" 0 NIL) ("FiniteLinearAggregateSort" 0 47866) ("FiniteLinearAggregateFunctions2" 0 47687) ("FiniteLinearAggregate&" 0 NIL) ("FiniteFieldSquareFreeDecomposition" 0 47633) ("FiniteFieldSolveLinearPolynomialEquation" 0 47602) ("FiniteFieldPolynomialPackage" 0 47400) ("FiniteFieldNormalBasisExtensionByPolynomial" 0 47339) ("FiniteFieldFunctions" 0 47186) ("FiniteFieldFactorizationWithSizeParseBySideEffect" 0 47124) ("FiniteFieldExtensionByPolynomial" 0 47039) ("FiniteFieldExtension" 0 47018) ("FiniteFieldCyclicGroupExtensionByPolynomial" 0 46957) ("FiniteFieldCategory&" 0 NIL) ("FiniteDivisorCategory&" 0 NIL) ("FiniteDivisor" 0 46821) ("FiniteAlgebraicExtensionField&" 0 NIL) ("FiniteAbelianMonoidRingFunctions2" 0 46783) ("FiniteAbelianMonoidRing&" 0 NIL) ("FileName" 0 46402) ("File" 0 46348) ("FieldOfPrimeCharacteristic&" 0 NIL) ("Field&" 0 NIL) ("FactorisationOverPseudoAlgebraicClosureOfRationalNumber" 0 46239) ("FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber" 0 46188) ("FactoringUtilities" 0 46100) ("FactoredFunctions2" 0 45905) ("FactoredFunctions" 0 45836) ("FactoredFunctionUtilities" 0 45721) ("Factored" 0 41266) ("ExtensionField&" 0 NIL) ("ExtensibleLinearAggregate&" 0 NIL) ("ExtAlgBasis" 0 41237) ("ExpressionSpaceFunctions2" 0 41139) ("ExpressionSpace&" 0 NIL) ("ExpressionSolve" 0 41116) ("ExpressionFunctions2" 0 40739) ("Expression" 0 38928) ("ExponentialOfUnivariatePuiseuxSeries" 0 38813) ("ExponentialExpansion" 0 38773) ("ExpertSystemToolsPackage2" 0 38735) ("ExpertSystemToolsPackage1" 0 38714) ("ExpertSystemToolsPackage" 0 38223) ("ExpertSystemContinuityPackage" 0 38185) ("Exit" 0 37915) ("Evalable&" 0 NIL) ("EuclideanModularRing" 0 37895) ("EuclideanGroebnerBasisPackage" 0 37865) ("EuclideanDomain&" 0 NIL) ("ErrorFunctions" 0 37657) ("Equation" 0 34341) ("EltableAggregate&" 0 NIL) ("ElementaryRischDESystem" 0 34315) ("ElementaryRischDE" 0 34289) ("ElementaryIntegration" 0 34226) ("ElementaryFunctionsUnivariatePuiseuxSeries" 0 34186) ("ElementaryFunctionsUnivariateLaurentSeries" 0 34115) ("ElementaryFunctionStructurePackage" 0 33785) ("ElementaryFunctionSign" 0 33423) ("ElementaryFunctionODESolver" 0 33390) ("ElementaryFunctionCategory&" 0 NIL) ("ElementaryFunction" 0 33375) ("EigenPackage" 0 33351) ("DrawOptionFunctions1" 0 33326) ("DrawOptionFunctions0" 0 33122) ("DrawOption" 0 32950) ("DoubleResultantPackage" 0 32927) ("DoubleFloatVector" 0 32905) ("DoubleFloatSpecialFunctions" 0 32889) ("DoubleFloat" 0 30757) ("Divisor" 0 30534) ("DivisionRing&" 0 NIL) ("DistributedMultivariatePolynomial" 0 30129) ("DistinctDegreeFactorize" 0 29810) ("DisplayPackage" 0 29784) ("DiscreteLogarithmPackage" 0 29759) ("DirectProductCategory&" 0 NIL) ("DirectProduct" 0 29197) ("DifferentialVariableCategory&" 0 NIL) ("DifferentialSparseMultivariatePolynomial" 0 29087) ("DifferentialRing&" 0 NIL) ("DifferentialPolynomialCategory&" 0 NIL) ("DifferentialExtension&" 0 NIL) ("DictionaryOperations&" 0 NIL) ("Dictionary&" 0 NIL) ("DesingTreePackage" 0 29014) ("DesingTree" 0 28927) ("DegreeReductionPackage" 0 28903) ("DefiniteIntegrationTools" 0 28823) ("Database" 0 28803) ("DataList" 0 28790) ("CyclotomicPolynomialPackage" 0 28742) ("CyclicStreamTools" 0 28708) ("CoordinateSystems" 0 28666) ("ContinuedFraction" 0 28551) ("ConstantLODE" 0 28518) ("ComplexRootPackage" 0 28459) ("ComplexPatternMatch" 0 28438) ("ComplexPattern" 0 28417) ("ComplexIntegerSolveLinearPolynomialEquation" 0 28396) ("ComplexFunctions2" 0 28364) ("ComplexFactorization" 0 28296) ("ComplexDoubleFloatVector" 0 28267) ("ComplexCategory&" 0 NIL) ("Complex" 0 27681) ("CommuteUnivariatePolynomialCategory" 0 27534) ("Commutator" 0 27513) ("CommonOperators" 0 27360) ("CommonDenominator" 0 27226) ("CombinatorialFunction" 0 27211) ("Color" 0 27112) ("Collection&" 0 NIL) ("CoerceVectorMatrixPackage" 0 27048) ("ChineseRemainderToolsForIntegralBases" 0 27008) ("CharacteristicPolynomialInMonogenicalAlgebra" 0 26986) ("CharacterClass" 0 26913) ("Character" 0 26591) ("ChangeOfVariable" 0 26491) ("CartesianTensor" 0 26461) ("CardinalNumber" 0 25744) ("BrillhartTests" 0 25718) ("BoundIntegerRoots" 0 25684) ("Boolean" 0 7548) ("BlowUpPackage" 0 7526) ("Bits" 0 7499) ("BitAggregate&" 0 NIL) ("BinaryTreeCategory&" 0 NIL) ("BinaryTree" 0 7438) ("BinaryRecursiveAggregate&" 0 NIL) ("BasicType&" 0 NIL) ("BasicOperatorFunctions1" 0 7245) ("BasicOperator" 0 5838) ("BasicFunctions" 0 5804) ("BalancedPAdicInteger" 0 5778) ("BalancedFactorisation" 0 5739) ("BagAggregate&" 0 NIL) ("Automorphism" 0 5559) ("AttributeButtons" 0 5285) ("AssociationList" 0 5133) ("AssociatedLieAlgebra" 0 5113) ("Asp9" 0 5018) ("Asp80" 0 4974) ("Asp8" 0 4879) ("Asp78" 0 4835) ("Asp77" 0 4791) ("Asp74" 0 4731) ("Asp73" 0 4671) ("Asp7" 0 4559) ("Asp6" 0 4533) ("Asp55" 0 4489) ("Asp50" 0 4445) ("Asp49" 0 4384) ("Asp42" 0 4340) ("Asp41" 0 4296) ("Asp4" 0 4236) ("Asp35" 0 4210) ("Asp34" 0 4174) ("Asp33" 0 4130) ("Asp31" 0 4069) ("Asp30" 0 4033) ("Asp29" 0 4013) ("Asp28" 0 3959) ("Asp27" 0 3939) ("Asp24" 0 3895) ("Asp20" 0 3851) ("Asp19" 0 3807) ("Asp12" 0 3763) ("Asp10" 0 3719) ("Asp1" 0 3533) ("ArcTrigonometricFunctionCategory&" 0 NIL) ("ApplyUnivariateSkewPolynomial" 0 3493) ("ApplyRules" 0 3437) ("AnyFunctions1" 0 2370) ("Any" 0 1020) ("AntiSymm" 0 1002) ("AnnaNumericalOptimizationPackage" 0 981) ("AnnaNumericalIntegrationPackage" 0 952) ("AlgebraicallyClosedFunctionSpace&" 0 NIL) ("AlgebraicallyClosedField&" 0 NIL) ("AlgebraicNumber" 0 779) ("AlgebraicManipulations" 0 493) ("AlgebraicIntegration" 0 467) ("AlgebraicHermiteIntegration" 0 444) ("AlgebraicFunction" 0 429) ("AlgebraGivenByStructuralConstants" 0 396) ("Algebra&" 0 NIL) ("AlgFactor" 0 289) ("Aggregate&" 0 NIL) ("AffineSpace" 0 273) ("AffinePlane" 0 88) ("AffineAlgebraicSetComputeWithResultant" 0 54) ("AffineAlgebraicSetComputeWithGroebnerBasis" 0 20) ("AbelianSemiGroup&" 0 NIL) ("AbelianMonoidRing&" 0 NIL) ("AbelianMonoid&" 0 NIL) ("AbelianGroup&" 0 NIL))
\ No newline at end of file
+(("e04ucfAnnaType" 0 236785) ("e04nafAnnaType" 0 236748) ("e04mbfAnnaType" 0 236711) ("e04jafAnnaType" 0 236674) ("e04gcfAnnaType" 0 236637) ("e04fdfAnnaType" 0 236600) ("e04dgfAnnaType" 0 236563) ("e04AgentsPackage" 0 236424) ("d03eefAnnaType" 0 236381) ("d03AgentsPackage" 0 236362) ("d02ejfAnnaType" 0 236318) ("d02cjfAnnaType" 0 236274) ("d02bhfAnnaType" 0 236230) ("d02bbfAnnaType" 0 236186) ("d02AgentsPackage" 0 236116) ("d01gbfAnnaType" 0 236080) ("d01fcfAnnaType" 0 236044) ("d01asfAnnaType" 0 236008) ("d01aqfAnnaType" 0 235972) ("d01apfAnnaType" 0 235936) ("d01anfAnnaType" 0 235900) ("d01amfAnnaType" 0 235864) ("d01alfAnnaType" 0 235828) ("d01akfAnnaType" 0 235792) ("d01ajfAnnaType" 0 235756) ("d01WeightsPackage" 0 235703) ("d01TransformFunctionType" 0 235667) ("d01AgentsPackage" 0 235414) ("XRecursivePolynomial" 0 235365) ("XPolynomialRing" 0 235338) ("XPBWPolynomial" 0 235318) ("XDistributedPolynomial" 0 235228) ("WildFunctionFieldIntegralBasis" 0 235188) ("WeightedPolynomials" 0 235156) ("Void" 0 230760) ("ViewportPackage" 0 230672) ("ViewDefaultsPackage" 0 230460) ("VectorSpace&" 0 NIL) ("VectorFunctions2" 0 230151) ("VectorCategory&" 0 NIL) ("Vector" 0 225035) ("Variable" 0 224660) ("UserDefinedPartialOrdering" 0 224598) ("UniversalSegmentFunctions2" 0 224564) ("UniversalSegment" 0 223698) ("UnivariateTaylorSeriesFunctions2" 0 223660) ("UnivariateTaylorSeriesCategory&" 0 NIL) ("UnivariateTaylorSeriesCZero" 0 223531) ("UnivariateTaylorSeries" 0 223370) ("UnivariateSkewPolynomialCategoryOps" 0 223335) ("UnivariateSkewPolynomialCategory&" 0 NIL) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 223272) ("UnivariatePuiseuxSeriesConstructorCategory&" 0 NIL) ("UnivariatePuiseuxSeriesConstructor" 0 223212) ("UnivariatePuiseuxSeries" 0 222991) ("UnivariatePowerSeriesCategory&" 0 NIL) ("UnivariatePolynomialSquareFree" 0 222872) ("UnivariatePolynomialDivisionPackage" 0 222827) ("UnivariatePolynomialDecompositionPackage" 0 222801) ("UnivariatePolynomialCommonDenominator" 0 222588) ("UnivariatePolynomialCategoryFunctions2" 0 221464) ("UnivariatePolynomialCategory&" 0 NIL) ("UnivariatePolynomial" 0 221155) ("UnivariateLaurentSeriesFunctions2" 0 221117) ("UnivariateLaurentSeriesConstructorCategory&" 0 NIL) ("UnivariateLaurentSeriesConstructor" 0 221089) ("UnivariateLaurentSeries" 0 220989) ("UnivariateFormalPowerSeriesFunctions" 0 220979) ("UnivariateFormalPowerSeries" 0 220891) ("UniqueFactorizationDomain&" 0 NIL) ("UnaryRecursiveAggregate&" 0 NIL) ("U8Vector" 0 220878) ("U32Vector" 0 220832) ("U16Vector" 0 220818) ("TwoFactorize" 0 220765) ("TwoDimensionalViewport" 0 220592) ("TwoDimensionalPlotClipping" 0 220546) ("TwoDimensionalArrayCategory&" 0 NIL) ("TwoDimensionalArray" 0 220530) ("TubePlotTools" 0 220489) ("TubePlot" 0 220404) ("TrigonometricManipulations" 0 220219) ("TrigonometricFunctionCategory&" 0 NIL) ("TriangularSetCategory&" 0 NIL) ("TriangularMatrixOperations" 0 220029) ("Tree" 0 219987) ("TranscendentalRischDESystem" 0 219959) ("TranscendentalRischDE" 0 219915) ("TranscendentalManipulations" 0 219799) ("TranscendentalIntegration" 0 219731) ("TranscendentalHermiteIntegration" 0 219701) ("TranscendentalFunctionCategory&" 0 NIL) ("TransSolvePackageService" 0 219679) ("TopLevelDrawFunctionsForCompiledFunctions" 0 219653) ("TopLevelDrawFunctions" 0 219641) ("ToolsForSign" 0 219534) ("ThreeSpace" 0 219282) ("ThreeDimensionalViewport" 0 219155) ("ThreeDimensionalMatrix" 0 219112) ("TheSymbolTable" 0 219062) ("TextFile" 0 219021) ("TexFormat" 0 219006) ("TemplateUtilities" 0 218986) ("TaylorSolve" 0 218966) ("TaylorSeries" 0 218939) ("TangentExpansions" 0 218900) ("TabulatedComputationPackage" 0 218764) ("Tableau" 0 218744) ("TableAggregate&" 0 NIL) ("Table" 0 218089) ("SystemSolvePackage" 0 217984) ("SystemODESolver" 0 217962) ("SymmetricPolynomial" 0 217916) ("SymmetricGroupCombinatoricFunctions" 0 217867) ("SymmetricFunctions" 0 217845) ("SymbolTable" 0 217566) ("Symbol" 0 209438) ("Switch" 0 209375) ("SupFractionFactorizer" 0 209360) ("SuchThat" 0 209280) ("SubSpaceComponentProperty" 0 209186) ("SubSpace" 0 209160) ("SubResultantPackage" 0 209098) ("StringAggregate&" 0 NIL) ("String" 0 197829) ("StreamTranscendentalFunctionsNonCommutative" 0 197793) ("StreamTranscendentalFunctions" 0 197580) ("StreamTaylorSeriesOperations" 0 197151) ("StreamInfiniteProduct" 0 197085) ("StreamFunctions3" 0 196892) ("StreamFunctions2" 0 196389) ("StreamFunctions1" 0 196351) ("StreamAggregate&" 0 NIL) ("Stream" 0 194488) ("StorageEfficientMatrixOperations" 0 194477) ("Stack" 0 194439) ("SquareMatrixCategory&" 0 NIL) ("SquareMatrix" 0 194306) ("SquareFreeRegularTriangularSetGcdPackage" 0 194179) ("SquareFreeRegularTriangularSet" 0 194082) ("SquareFreeRegularSetDecompositionPackage" 0 194047) ("SquareFreeQuasiComponentPackage" 0 193870) ("SplittingTree" 0 193843) ("SplittingNode" 0 193800) ("SparseUnivariateTaylorSeries" 0 193734) ("SparseUnivariateSkewPolynomial" 0 193668) ("SparseUnivariatePolynomialFunctions2" 0 193154) ("SparseUnivariatePolynomialExpressions" 0 193120) ("SparseUnivariatePolynomial" 0 186449) ("SparseUnivariateLaurentSeries" 0 186415) ("SparseMultivariateTaylorSeries" 0 186398) ("SparseMultivariatePolynomial" 0 185141) ("SortedCache" 0 185112) ("SmithNormalForm" 0 185080) ("SingletonAsOrderedSet" 0 184383) ("SingleInteger" 0 176660) ("SimpleAlgebraicExtension" 0 176529) ("SetCategory&" 0 NIL) ("SetAggregate&" 0 NIL) ("Set" 0 176091) ("SequentialDifferentialVariable" 0 176054) ("SemiGroup&" 0 NIL) ("SegmentFunctions2" 0 175939) ("SegmentBindingFunctions2" 0 175897) ("SegmentBinding" 0 175530) ("Segment" 0 174445) ("ScriptFormulaFormat" 0 174420) ("SExpressionOf" 0 174404) ("SExpression" 0 174175) ("RoutinesTable" 0 173584) ("RootsFindingPackage" 0 173448) ("Ring&" 0 NIL) ("RightOpenIntervalRootCharacterization" 0 173432) ("RewriteRule" 0 173387) ("RetractableTo&" 0 NIL) ("RetractSolvePackage" 0 173361) ("Result" 0 172290) ("RepeatedSquaring" 0 172049) ("RepeatedDoubling" 0 171866) ("RegularTriangularSetGcdPackage" 0 171808) ("RegularTriangularSetCategory&" 0 NIL) ("RegularTriangularSet" 0 171791) ("RegularSetDecompositionPackage" 0 171766) ("RegularChain" 0 171711) ("Reference" 0 171328) ("ReductionOfOrder" 0 171295) ("ReduceLODE" 0 171273) ("RecursivePolynomialCategory&" 0 NIL) ("RecursiveAggregate&" 0 NIL) ("RecurrenceOperator" 0 171263) ("RectangularMatrixCategory&" 0 NIL) ("RealZeroPackage" 0 171183) ("RealSolvePackage" 0 171155) ("RealRootCharacterizationCategory&" 0 NIL) ("RealPolynomialUtilitiesPackage" 0 171113) ("RealNumberSystem&" 0 NIL) ("RealClosure" 0 171081) ("RealClosedField&" 0 NIL) ("RationalRicDE" 0 170991) ("RationalLODE" 0 170852) ("RationalIntegration" 0 170731) ("RationalFunctionSign" 0 170673) ("RationalFunctionIntegration" 0 170639) ("RationalFunctionFactor" 0 170606) ("RationalFunction" 0 170558) ("RationalFactorize" 0 170328) ("RandomNumberSource" 0 170248) ("RadixExpansion" 0 170186) ("RadicalSolvePackage" 0 170164) ("RadicalCategory&" 0 NIL) ("QuotientFieldCategoryFunctions2" 0 170141) ("QuotientFieldCategory&" 0 NIL) ("Queue" 0 170129) ("QueryEquation" 0 170116) ("QuaternionCategory&" 0 NIL) ("Quaternion" 0 170103) ("QuasiComponentPackage" 0 169989) ("QuasiAlgebraicSet" 0 169966) ("QuadraticForm" 0 169946) ("PushVariables" 0 169919) ("PureAlgebraicIntegration" 0 169842) ("PseudoRemainderSequence" 0 169757) ("PseudoLinearNormalForm" 0 169737) ("PseudoAlgebraicClosureOfRationalNumber" 0 169620) ("PseudoAlgebraicClosureOfFiniteField" 0 169349) ("ProjectiveSpace" 0 169329) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 169216) ("ProjectivePlane" 0 169111) ("ProjectiveAlgebraicSetPackage" 0 169018) ("Product" 0 168977) ("PrintPackage" 0 168951) ("PrimitiveRatRicDE" 0 168933) ("PrimitiveRatDE" 0 168880) ("PrimitiveElement" 0 168846) ("PrimitiveArray" 0 168058) ("PrimeField" 0 167965) ("PrecomputedAssociatedEquations" 0 167941) ("PowerSeriesLimitPackage" 0 167849) ("PowerSeriesCategory&" 0 NIL) ("PositiveInteger" 0 158060) ("PolynomialSquareFree" 0 158036) ("PolynomialSolveByFormulas" 0 158012) ("PolynomialSetUtilitiesPackage" 0 157615) ("PolynomialSetCategory&" 0 NIL) ("PolynomialRoots" 0 157512) ("PolynomialRing" 0 157344) ("PolynomialPackageForCurve" 0 157247) ("PolynomialNumberTheoryFunctions" 0 157193) ("PolynomialInterpolationAlgorithms" 0 157165) ("PolynomialIdeals" 0 157114) ("PolynomialGcdPackage" 0 157038) ("PolynomialFunctions2" 0 156842) ("PolynomialFactorizationExplicit&" 0 NIL) ("PolynomialFactorizationByRecursionUnivariate" 0 156779) ("PolynomialFactorizationByRecursion" 0 156755) ("PolynomialDecomposition" 0 156725) ("PolynomialCategoryQuotientFunctions" 0 156326) ("PolynomialCategoryLifting" 0 155691) ("PolynomialCategory&" 0 NIL) ("Polynomial" 0 153321) ("PolyGroebner" 0 153275) ("PolToPol" 0 153238) ("PointsOfFiniteOrderTools" 0 153184) ("PointsOfFiniteOrder" 0 153161) ("PointPackage" 0 153020) ("Point" 0 152584) ("PoincareBirkhoffWittLyndonBasis" 0 152547) ("PlotTools" 0 152532) ("Plot3D" 0 152465) ("Plot" 0 152328) ("Plcs" 0 152269) ("PlaneAlgebraicCurvePlot" 0 152225) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 152173) ("Places" 0 152136) ("PiCoercions" 0 152114) ("Pi" 0 152078) ("PermutationGroup" 0 152049) ("Permutation" 0 151954) ("PatternMatchTools" 0 151891) ("PatternMatchSymbol" 0 151880) ("PatternMatchResultFunctions2" 0 151833) ("PatternMatchResult" 0 150415) ("PatternMatchQuotientFieldCategory" 0 150388) ("PatternMatchPushDown" 0 150267) ("PatternMatchPolynomialCategory" 0 150230) ("PatternMatchListResult" 0 150185) ("PatternMatchListAggregate" 0 150168) ("PatternMatchKernel" 0 150125) ("PatternMatchIntegration" 0 150006) ("PatternMatchIntegerNumberSystem" 0 149981) ("PatternMatchFunctionSpace" 0 149966) ("PatternFunctions1" 0 149896) ("Pattern" 0 148363) ("PartitionsAndPermutations" 0 148263) ("Partition" 0 148146) ("PartialDifferentialRing&" 0 NIL) ("ParametrizationPackage" 0 148027) ("ParametricSurface" 0 147927) ("ParametricSpaceCurve" 0 147824) ("ParametricPlaneCurve" 0 147721) ("ParadoxicalCombinatorsForStreams" 0 147520) ("Palette" 0 147318) ("PackageForPoly" 0 147011) ("PAdicRationalConstructor" 0 146969) ("PAdicInteger" 0 146951) ("OutputPackage" 0 146581) ("OutputForm" 0 136754) ("OrderlyDifferentialVariable" 0 136648) ("OrderlyDifferentialPolynomial" 0 136615) ("OrderedVariableList" 0 136062) ("OrderedSet&" 0 NIL) ("OrderedRing&" 0 NIL) ("OrderedFreeMonoid" 0 135910) ("OrderedCompletionFunctions2" 0 135839) ("OrderedCompletion" 0 135056) ("OrdSetInts" 0 135022) ("OpenMathPackage" 0 134996) ("OpenMathErrorKind" 0 134978) ("OpenMathEncoding" 0 134800) ("OpenMathDevice" 0 134618) ("OpenMathConnection" 0 134592) ("OnePointCompletionFunctions2" 0 134559) ("OnePointCompletion" 0 133746) ("OneDimensionalArrayAggregate&" 0 NIL) ("OneDimensionalArray" 0 133677) ("OctonionCategory&" 0 NIL) ("ODETools" 0 133629) ("ODEIntensityFunctionsTable" 0 133566) ("ODEIntegration" 0 133457) ("NumericalPDEProblem" 0 133414) ("NumericalOptimizationProblem" 0 133358) ("NumericalODEProblem" 0 133314) ("NumericalIntegrationProblem" 0 133251) ("NumericTubePlot" 0 133205) ("NumericRealEigenPackage" 0 133184) ("Numeric" 0 133145) ("NumberTheoreticPolynomialFunctions" 0 133115) ("NumberFormats" 0 133085) ("NormalizationPackage" 0 132912) ("NoneFunctions1" 0 132877) ("None" 0 132576) ("NonNegativeInteger" 0 116734) ("NonLinearSolvePackage" 0 116716) ("NonLinearFirstOrderODESolver" 0 116684) ("NonAssociativeRng&" 0 NIL) ("NonAssociativeRing&" 0 NIL) ("NonAssociativeAlgebra&" 0 NIL) ("NewtonPolygon" 0 116666) ("NewtonInterpolation" 0 116656) ("NewSparseUnivariatePolynomialFunctions2" 0 116620) ("NewSparseUnivariatePolynomial" 0 116542) ("NewSparseMultivariatePolynomial" 0 116430) ("NeitherSparseOrDensePowerSeries" 0 116343) ("NagPartialDifferentialEquationsPackage" 0 116324) ("NagOrdinaryDifferentialEquationsPackage" 0 116254) ("NagOptimisationPackage" 0 116098) ("NagIntegrationPackage" 0 115926) ("NagEigenPackage" 0 115905) ("NPCoef" 0 115881) ("NAGLinkSupportPackage" 0 115469) ("MyUnivariatePolynomial" 0 115452) ("MyExpression" 0 115422) ("MultivariateSquareFree" 0 115358) ("MultivariateLifting" 0 115270) ("MultivariateFactorize" 0 114937) ("Multiset" 0 114878) ("MultipleMap" 0 114803) ("MultiVariableCalculusFunctions" 0 114709) ("MultFiniteFactorize" 0 114635) ("MoreSystemCommands" 0 114556) ("MonomialExtensionTools" 0 114437) ("MonoidRing" 0 114412) ("Monoid&" 0 NIL) ("MonogenicAlgebra&" 0 NIL) ("MonadWithUnit&" 0 NIL) ("Monad&" 0 NIL) ("MoebiusTransform" 0 114390) ("ModuleOperator" 0 114377) ("ModuleMonomial" 0 114349) ("Module&" 0 NIL) ("ModularRing" 0 114309) ("ModularHermitianRowReduction" 0 114104) ("ModularDistinctDegreeFactorizer" 0 114047) ("ModMonic" 0 113937) ("MeshCreationRoutinesForThreeDimensions" 0 113891) ("MergeThing" 0 113878) ("MatrixLinearAlgebraFunctions" 0 113851) ("MatrixCommonDenominator" 0 113741) ("MatrixCategoryFunctions2" 0 113360) ("MatrixCategory&" 0 NIL) ("Matrix" 0 108476) ("MappingPackageInternalHacks3" 0 108456) ("MappingPackageInternalHacks2" 0 108436) ("MappingPackageInternalHacks1" 0 108416) ("MappingPackage1" 0 108322) ("MakeUnaryCompiledFunction" 0 108262) ("MakeFunction" 0 108203) ("MakeFloatCompiledFunction" 0 108139) ("MakeBinaryCompiledFunction" 0 108091) ("Magma" 0 108060) ("MachineInteger" 0 108026) ("MachineFloat" 0 107957) ("MRationalFactorize" 0 107793) ("MPolyCatRationalFunctionFactorizer" 0 107683) ("MPolyCatPolyFactorizer" 0 107646) ("MPolyCatFunctions3" 0 107633) ("MPolyCatFunctions2" 0 107546) ("LyndonWord" 0 107459) ("Logic&" 0 NIL) ("Localize" 0 107442) ("LocalParametrizationOfSimplePointPackage" 0 107349) ("LocalAlgebra" 0 107336) ("ListToMap" 0 107285) ("ListMultiDictionary" 0 107253) ("ListMonoidOps" 0 107201) ("ListFunctions2" 0 106761) ("ListAggregate&" 0 NIL) ("List" 0 89063) ("LiouvillianFunction" 0 89022) ("LinesOpPack" 0 88957) ("LinearSystemPolynomialPackage" 0 88934) ("LinearSystemMatrixPackage" 0 88600) ("LinearSystemFromPowerSeriesPackage" 0 88572) ("LinearPolynomialEquationByFractions" 0 88451) ("LinearOrdinaryDifferentialOperatorsOps" 0 88412) ("LinearOrdinaryDifferentialOperatorFactorizer" 0 88379) ("LinearOrdinaryDifferentialOperatorCategory&" 0 NIL) ("LinearOrdinaryDifferentialOperator2" 0 88346) ("LinearOrdinaryDifferentialOperator1" 0 88182) ("LinearOrdinaryDifferentialOperator" 0 88104) ("LinearDependence" 0 88076) ("LinearAggregate&" 0 NIL) ("LinGroebnerPackage" 0 88039) ("LiePolynomial" 0 88002) ("LieAlgebra&" 0 NIL) ("LexTriangularPackage" 0 87970) ("LeftAlgebra&" 0 NIL) ("LeadingCoefDetermination" 0 87930) ("LazyStreamAggregate&" 0 NIL) ("LaurentPolynomial" 0 87859) ("Kovacic" 0 87826) ("KeyedDictionary&" 0 NIL) ("KeyedAccessFile" 0 87814) ("KernelFunctions2" 0 87799) ("Kernel" 0 85950) ("IrredPolyOverFiniteField" 0 85910) ("Interval" 0 85863) ("IntersectionDivisorPackage" 0 85819) ("InterpolateFormsPackage" 0 85775) ("InternalRationalUnivariateRepresentationPackage" 0 85701) ("InternalPrintPackage" 0 85593) ("InterfaceGroebnerPackage" 0 85546) ("IntegrationTools" 0 85237) ("IntegrationResultToFunction" 0 85142) ("IntegrationResultRFToFunction" 0 85102) ("IntegrationResultFunctions2" 0 84903) ("IntegrationResult" 0 84531) ("IntegrationFunctionsTable" 0 84476) ("IntegralDomain&" 0 NIL) ("IntegralBasisTools" 0 84347) ("IntegralBasisPolynomialTools" 0 84307) ("IntegerSolveLinearPolynomialEquation" 0 84295) ("IntegerRoots" 0 84110) ("IntegerRetractions" 0 84078) ("IntegerPrimesPackage" 0 83646) ("IntegerNumberTheoryFunctions" 0 83545) ("IntegerNumberSystem&" 0 NIL) ("IntegerMod" 0 83525) ("IntegerLinearDependence" 0 83486) ("IntegerFactorizationPackage" 0 83362) ("IntegerCombinatoricFunctions" 0 83146) ("IntegerBits" 0 83115) ("Integer" 0 67353) ("InputFormFunctions1" 0 67334) ("InputForm" 0 65073) ("InnerTrigonometricManipulations" 0 64945) ("InnerTaylorSeries" 0 64855) ("InnerTable" 0 64845) ("InnerSparseUnivariatePowerSeries" 0 64748) ("InnerPrimeField" 0 64714) ("InnerPolySum" 0 64690) ("InnerPolySign" 0 64607) ("InnerPAdicInteger" 0 64567) ("InnerNumericFloatSolvePackage" 0 64470) ("InnerNumericEigenPackage" 0 64413) ("InnerNormalBasisFieldFunctions" 0 64365) ("InnerMultFact" 0 64319) ("InnerMatrixQuotientFieldFunctions" 0 64286) ("InnerMatrixLinearAlgebraFunctions" 0 64217) ("InnerIndexedTwoDimensionalArray" 0 64139) ("InnerFreeAbelianMonoid" 0 64098) ("InnerEvalable&" 0 NIL) ("InnerCommonDenominator" 0 63852) ("InnerAlgebraicNumber" 0 63832) ("InnerAlgFactor" 0 63763) ("InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField" 0 63711) ("InfinitlyClosePoint" 0 63637) ("InfiniteTuple" 0 63583) ("InfClsPt" 0 63546) ("IndexedVector" 0 63519) ("IndexedString" 0 63508) ("IndexedOneDimensionalArray" 0 63439) ("IndexedList" 0 63430) ("IndexedFlexibleArray" 0 63343) ("IndexedExponents" 0 63042) ("IndexedDirectProductOrderedAbelianMonoidSup" 0 63021) ("IndexedDirectProductOrderedAbelianMonoid" 0 62973) ("IndexedDirectProductObject" 0 62935) ("IndexedDirectProductAbelianMonoid" 0 62855) ("IndexedDirectProductAbelianGroup" 0 62840) ("IndexedBits" 0 62831) ("IndexedAggregate&" 0 NIL) ("IdealDecompositionPackage" 0 62808) ("HyperbolicFunctionCategory&" 0 NIL) ("HomogeneousDistributedMultivariatePolynomial" 0 62739) ("HomogeneousDirectProduct" 0 62658) ("HomogeneousAggregate&" 0 NIL) ("HeuGcd" 0 62646) ("HashTable" 0 62590) ("HallBasis" 0 62569) ("GuessOptionFunctions0" 0 62559) ("GuessOption" 0 62525) ("GuessFiniteFunctions" 0 62509) ("Guess" 0 62409) ("Group&" 0 NIL) ("GroebnerPackage" 0 62180) ("GroebnerInternalPackage" 0 62053) ("GrayCode" 0 62039) ("GraphicsDefaults" 0 61939) ("GraphImage" 0 61851) ("GradedModule&" 0 NIL) ("GradedAlgebra&" 0 NIL) ("GosperSummationMethod" 0 61808) ("GenusZeroIntegration" 0 61779) ("GeneralizedMultivariateFactorize" 0 61707) ("GeneralTriangularSet" 0 61648) ("GeneralSparseTable" 0 61632) ("GeneralPolynomialSet" 0 61441) ("GeneralPolynomialGcdPackage" 0 61417) ("GeneralPackageForAlgebraicFunctionField" 0 61330) ("GeneralHenselPackage" 0 61244) ("GeneralDistributedMultivariatePolynomial" 0 61159) ("GenUFactorize" 0 61107) ("GenExEuclid" 0 60933) ("GcdDomain&" 0 NIL) ("GaloisGroupUtilities" 0 60895) ("GaloisGroupPolynomialUtilities" 0 60869) ("GaloisGroupFactorizer" 0 60821) ("GaloisGroupFactorizationUtilities" 0 60778) ("FunctionalSpecialFunction" 0 60763) ("FunctionSpaceUnivariatePolynomialFactor" 0 60664) ("FunctionSpaceToUnivariatePowerSeries" 0 60624) ("FunctionSpacePrimitiveElement" 0 60547) ("FunctionSpaceIntegration" 0 60309) ("FunctionSpaceFunctions2" 0 60225) ("FunctionSpaceComplexIntegration" 0 60196) ("FunctionSpaceAttachPredicates" 0 60149) ("FunctionSpaceAssertions" 0 60082) ("FunctionSpace&" 0 NIL) ("FunctionFieldCategoryFunctions2" 0 60054) ("FunctionFieldCategory&" 0 NIL) ("FullyRetractableTo&" 0 NIL) ("FullyLinearlyExplicitRingOver&" 0 NIL) ("FullyEvalableOver&" 0 NIL) ("FreeMonoid" 0 60032) ("FreeModule1" 0 59956) ("FreeModule" 0 59851) ("FreeGroup" 0 59821) ("FreeAbelianGroup" 0 59802) ("FramedNonAssociativeAlgebra&" 0 NIL) ("FramedModule" 0 59784) ("FramedAlgebra&" 0 NIL) ("FractionalIdealFunctions2" 0 59756) ("FractionalIdeal" 0 59588) ("FractionFreeFastGaussianFractions" 0 59578) ("FractionFreeFastGaussian" 0 59532) ("Fraction" 0 51657) ("FourierComponent" 0 51639) ("FortranType" 0 51349) ("FortranScalarType" 0 51069) ("FortranPackage" 0 50859) ("FortranOutputStackPackage" 0 50614) ("FortranExpression" 0 50449) ("FortranCode" 0 50182) ("FloatingRealPackage" 0 50161) ("FloatingPointSystem&" 0 NIL) ("Float" 0 48307) ("FlexibleArray" 0 48282) ("FiniteSetAggregate&" 0 NIL) ("FiniteRankNonAssociativeAlgebra&" 0 NIL) ("FiniteRankAlgebra&" 0 NIL) ("FiniteLinearAggregateSort" 0 48248) ("FiniteLinearAggregateFunctions2" 0 48069) ("FiniteLinearAggregate&" 0 NIL) ("FiniteFieldSquareFreeDecomposition" 0 47988) ("FiniteFieldSolveLinearPolynomialEquation" 0 47957) ("FiniteFieldPolynomialPackage" 0 47755) ("FiniteFieldNormalBasisExtensionByPolynomial" 0 47694) ("FiniteFieldFunctions" 0 47541) ("FiniteFieldFactorizationWithSizeParseBySideEffect" 0 47479) ("FiniteFieldExtensionByPolynomial" 0 47394) ("FiniteFieldExtension" 0 47373) ("FiniteFieldCyclicGroupExtensionByPolynomial" 0 47312) ("FiniteFieldCategory&" 0 NIL) ("FiniteDivisorCategory&" 0 NIL) ("FiniteDivisor" 0 47176) ("FiniteAlgebraicExtensionField&" 0 NIL) ("FiniteAbelianMonoidRingFunctions2" 0 47138) ("FiniteAbelianMonoidRing&" 0 NIL) ("Finite&" 0 NIL) ("FileName" 0 46757) ("File" 0 46703) ("FieldOfPrimeCharacteristic&" 0 NIL) ("Field&" 0 NIL) ("FactorisationOverPseudoAlgebraicClosureOfRationalNumber" 0 46594) ("FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber" 0 46543) ("FactoringUtilities" 0 46455) ("FactoredFunctions2" 0 46260) ("FactoredFunctions" 0 46191) ("FactoredFunctionUtilities" 0 46076) ("Factored" 0 41594) ("ExtensionField&" 0 NIL) ("ExtensibleLinearAggregate&" 0 NIL) ("ExtAlgBasis" 0 41565) ("ExpressionSpaceFunctions2" 0 41467) ("ExpressionSpace&" 0 NIL) ("ExpressionSolve" 0 41444) ("ExpressionFunctions2" 0 41067) ("Expression" 0 39231) ("ExponentialOfUnivariatePuiseuxSeries" 0 39116) ("ExponentialExpansion" 0 39076) ("ExpertSystemToolsPackage2" 0 39038) ("ExpertSystemToolsPackage1" 0 39017) ("ExpertSystemToolsPackage" 0 38526) ("ExpertSystemContinuityPackage" 0 38488) ("Exit" 0 38218) ("Evalable&" 0 NIL) ("EuclideanModularRing" 0 38198) ("EuclideanGroebnerBasisPackage" 0 38168) ("EuclideanDomain&" 0 NIL) ("ErrorFunctions" 0 37960) ("Equation" 0 34561) ("EltableAggregate&" 0 NIL) ("ElementaryRischDESystem" 0 34535) ("ElementaryRischDE" 0 34509) ("ElementaryIntegration" 0 34446) ("ElementaryFunctionsUnivariatePuiseuxSeries" 0 34406) ("ElementaryFunctionsUnivariateLaurentSeries" 0 34335) ("ElementaryFunctionStructurePackage" 0 34005) ("ElementaryFunctionSign" 0 33643) ("ElementaryFunctionODESolver" 0 33610) ("ElementaryFunctionCategory&" 0 NIL) ("ElementaryFunction" 0 33595) ("EigenPackage" 0 33571) ("DrawOptionFunctions1" 0 33546) ("DrawOptionFunctions0" 0 33342) ("DrawOption" 0 33170) ("DoubleResultantPackage" 0 33147) ("DoubleFloatVector" 0 33125) ("DoubleFloatSpecialFunctions" 0 33109) ("DoubleFloat" 0 30977) ("Divisor" 0 30754) ("DivisionRing&" 0 NIL) ("DistributedMultivariatePolynomial" 0 30349) ("DistinctDegreeFactorize" 0 30030) ("DisplayPackage" 0 30004) ("DiscreteLogarithmPackage" 0 29979) ("DirectProductCategory&" 0 NIL) ("DirectProduct" 0 29417) ("DifferentialVariableCategory&" 0 NIL) ("DifferentialSparseMultivariatePolynomial" 0 29307) ("DifferentialRing&" 0 NIL) ("DifferentialPolynomialCategory&" 0 NIL) ("DifferentialExtension&" 0 NIL) ("DictionaryOperations&" 0 NIL) ("Dictionary&" 0 NIL) ("DesingTreePackage" 0 29234) ("DesingTree" 0 29147) ("DegreeReductionPackage" 0 29123) ("DefiniteIntegrationTools" 0 29043) ("Database" 0 29023) ("DataList" 0 29010) ("CyclotomicPolynomialPackage" 0 28962) ("CyclicStreamTools" 0 28928) ("CoordinateSystems" 0 28886) ("ContinuedFraction" 0 28771) ("ConstantLODE" 0 28738) ("ComplexRootPackage" 0 28679) ("ComplexPatternMatch" 0 28658) ("ComplexPattern" 0 28637) ("ComplexIntegerSolveLinearPolynomialEquation" 0 28616) ("ComplexFunctions2" 0 28584) ("ComplexFactorization" 0 28516) ("ComplexDoubleFloatVector" 0 28487) ("ComplexCategory&" 0 NIL) ("Complex" 0 27901) ("CommuteUnivariatePolynomialCategory" 0 27754) ("Commutator" 0 27733) ("CommonOperators" 0 27580) ("CommonDenominator" 0 27446) ("CombinatorialFunction" 0 27431) ("Color" 0 27332) ("Collection&" 0 NIL) ("CoerceVectorMatrixPackage" 0 27268) ("ChineseRemainderToolsForIntegralBases" 0 27228) ("CharacteristicPolynomialInMonogenicalAlgebra" 0 27206) ("CharacterClass" 0 27133) ("Character" 0 26811) ("ChangeOfVariable" 0 26711) ("CartesianTensor" 0 26681) ("CardinalNumber" 0 25964) ("BrillhartTests" 0 25938) ("BoundIntegerRoots" 0 25904) ("Boolean" 0 7575) ("BlowUpPackage" 0 7553) ("Bits" 0 7526) ("BitAggregate&" 0 NIL) ("BinaryTreeCategory&" 0 NIL) ("BinaryTree" 0 7465) ("BinaryRecursiveAggregate&" 0 NIL) ("BasicType&" 0 NIL) ("BasicStochasticDifferential" 0 7438) ("BasicOperatorFunctions1" 0 7245) ("BasicOperator" 0 5838) ("BasicFunctions" 0 5804) ("BalancedPAdicInteger" 0 5778) ("BalancedFactorisation" 0 5739) ("BagAggregate&" 0 NIL) ("Automorphism" 0 5559) ("AttributeButtons" 0 5285) ("AssociationList" 0 5133) ("AssociatedLieAlgebra" 0 5113) ("Asp9" 0 5018) ("Asp80" 0 4974) ("Asp8" 0 4879) ("Asp78" 0 4835) ("Asp77" 0 4791) ("Asp74" 0 4731) ("Asp73" 0 4671) ("Asp7" 0 4559) ("Asp6" 0 4533) ("Asp55" 0 4489) ("Asp50" 0 4445) ("Asp49" 0 4384) ("Asp42" 0 4340) ("Asp41" 0 4296) ("Asp4" 0 4236) ("Asp35" 0 4210) ("Asp34" 0 4174) ("Asp33" 0 4130) ("Asp31" 0 4069) ("Asp30" 0 4033) ("Asp29" 0 4013) ("Asp28" 0 3959) ("Asp27" 0 3939) ("Asp24" 0 3895) ("Asp20" 0 3851) ("Asp19" 0 3807) ("Asp12" 0 3763) ("Asp10" 0 3719) ("Asp1" 0 3533) ("ArcTrigonometricFunctionCategory&" 0 NIL) ("ApplyUnivariateSkewPolynomial" 0 3493) ("ApplyRules" 0 3437) ("AnyFunctions1" 0 2370) ("Any" 0 1020) ("AntiSymm" 0 1002) ("AnnaNumericalOptimizationPackage" 0 981) ("AnnaNumericalIntegrationPackage" 0 952) ("AlgebraicallyClosedFunctionSpace&" 0 NIL) ("AlgebraicallyClosedField&" 0 NIL) ("AlgebraicNumber" 0 779) ("AlgebraicManipulations" 0 493) ("AlgebraicIntegration" 0 467) ("AlgebraicHermiteIntegration" 0 444) ("AlgebraicFunction" 0 429) ("AlgebraGivenByStructuralConstants" 0 396) ("Algebra&" 0 NIL) ("AlgFactor" 0 289) ("Aggregate&" 0 NIL) ("AffineSpace" 0 273) ("AffinePlane" 0 88) ("AffineAlgebraicSetComputeWithResultant" 0 54) ("AffineAlgebraicSetComputeWithGroebnerBasis" 0 20) ("AbelianSemiGroup&" 0 NIL) ("AbelianMonoidRing&" 0 NIL) ("AbelianMonoid&" 0 NIL) ("AbelianGroup&" 0 NIL))
\ No newline at end of file
